deleteAnalyzer method
Deletes the specified analyzer. When you delete an analyzer, IAM Access Analyzer is disabled for the account or organization in the current or specific Region. All findings that were generated by the analyzer are deleted. You cannot undo this action.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analyzerName :
The name of the analyzer to delete.
Parameter clientToken :
A client token.
Implementation
Future<void> deleteAnalyzer({
required String analyzerName,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/analyzer/${Uri.encodeComponent(analyzerName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}