deleteServiceLinkedAnalyzer method

Future<void> deleteServiceLinkedAnalyzer({
  1. required String analyzerName,
  2. String? clientToken,
})

Deletes a service-linked analyzer. This operation can be invoked by both authorized Amazon Web Services services and customers.

When invoked by a customer, IAM Access Analyzer performs a callback to the managing service to verify whether the analyzer is still in use and can be deleted. If the service indicates the analyzer is still in use, the deletion is rejected with ConflictException.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analyzerName : The name of the service-linked analyzer to delete. Service-linked analyzer names follow the format _AccessAnalyzerFor{ServiceName}-{Id}.

Parameter clientToken : A client token.

Implementation

Future<void> deleteServiceLinkedAnalyzer({
  required String analyzerName,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/service-linked-analyzer/${Uri.encodeComponent(analyzerName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}