getAccessPreview method

Future<GetAccessPreviewResponse> getAccessPreview({
  1. required String accessPreviewId,
  2. required String analyzerArn,
})

Retrieves information about an access preview for the specified analyzer.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accessPreviewId : The unique ID for the access preview.

Parameter analyzerArn : The ARN of the analyzer used to generate the access preview.

Implementation

Future<GetAccessPreviewResponse> getAccessPreview({
  required String accessPreviewId,
  required String analyzerArn,
}) async {
  final $query = <String, List<String>>{
    'analyzerArn': [analyzerArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/access-preview/${Uri.encodeComponent(accessPreviewId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetAccessPreviewResponse.fromJson(response);
}