getFindingRecommendation method

Future<GetFindingRecommendationResponse> getFindingRecommendation({
  1. required String analyzerArn,
  2. required String id,
  3. int? maxResults,
  4. String? nextToken,
})

Retrieves information about a finding recommendation for the specified analyzer.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analyzerArn : The ARN of the analyzer used to generate the finding recommendation.

Parameter id : The unique ID for the finding recommendation.

Parameter maxResults : The maximum number of results to return in the response.

Parameter nextToken : A token used for pagination of results returned.

Implementation

Future<GetFindingRecommendationResponse> getFindingRecommendation({
  required String analyzerArn,
  required String id,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    'analyzerArn': [analyzerArn],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/recommendation/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetFindingRecommendationResponse.fromJson(response);
}