getFindingsStatistics method

Future<GetFindingsStatisticsResponse> getFindingsStatistics({
  1. required String analyzerArn,
})

Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analyzerArn : The ARN of the analyzer used to generate the statistics.

Implementation

Future<GetFindingsStatisticsResponse> getFindingsStatistics({
  required String analyzerArn,
}) async {
  final $payload = <String, dynamic>{
    'analyzerArn': analyzerArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/analyzer/findings/statistics',
    exceptionFnMap: _exceptionFns,
  );
  return GetFindingsStatisticsResponse.fromJson(response);
}