listAccessPreviewFindings method
Retrieves a list of access preview findings generated by the specified access preview.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accessPreviewId :
The unique ID for the access preview.
Parameter analyzerArn :
The ARN
of the analyzer used to generate the access.
Parameter filter :
Criteria to filter the returned findings.
Parameter maxResults :
The maximum number of results to return in the response.
Parameter nextToken :
A token used for pagination of results returned.
Implementation
Future<ListAccessPreviewFindingsResponse> listAccessPreviewFindings({
required String accessPreviewId,
required String analyzerArn,
Map<String, Criterion>? filter,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'analyzerArn': analyzerArn,
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/access-preview/${Uri.encodeComponent(accessPreviewId)}',
exceptionFnMap: _exceptionFns,
);
return ListAccessPreviewFindingsResponse.fromJson(response);
}