listAccessPreviews method
Retrieves a list of access previews for the specified analyzer.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analyzerArn :
The ARN
of the analyzer used to generate the access preview.
Parameter maxResults :
The maximum number of results to return in the response.
Parameter nextToken :
A token used for pagination of results returned.
Implementation
Future<ListAccessPreviewsResponse> listAccessPreviews({
required String analyzerArn,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
'analyzerArn': [analyzerArn],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/access-preview',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAccessPreviewsResponse.fromJson(response);
}