updateFindings method
Updates the status for the specified findings.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analyzerArn :
The ARN
of the analyzer that generated the findings to update.
Parameter status :
The state represents the action to take to update the finding Status. Use
ARCHIVE to change an Active finding to an Archived finding.
Use ACTIVE to change an Archived finding to an Active
finding.
Parameter clientToken :
A client token.
Parameter ids :
The IDs of the findings to update.
Parameter resourceArn :
The ARN of the resource identified in the finding.
Implementation
Future<void> updateFindings({
required String analyzerArn,
required FindingStatusUpdate status,
String? clientToken,
List<String>? ids,
String? resourceArn,
}) async {
final $payload = <String, dynamic>{
'analyzerArn': analyzerArn,
'status': status.value,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (ids != null) 'ids': ids,
if (resourceArn != null) 'resourceArn': resourceArn,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/finding',
exceptionFnMap: _exceptionFns,
);
}