Account class

Operations for Amazon Web Services Account Management

Constructors

Account({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptPrimaryEmailUpdate({required String accountId, required String otp, required String primaryEmail}) Future<AcceptPrimaryEmailUpdateResponse>
Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteAlternateContact({required AlternateContactType alternateContactType, String? accountId}) Future<void>
Deletes the specified alternate contact from an Amazon Web Services account.
disableRegion({required String regionName, String? accountId}) Future<void>
Disables (opts-out) a particular Region for an account.
enableRegion({required String regionName, String? accountId}) Future<void>
Enables (opts-in) a particular Region for an account.
getAccountInformation({String? accountId}) Future<GetAccountInformationResponse>
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state. To use this API, an IAM user or role must have the account:GetAccountInformation IAM permission.
getAlternateContact({required AlternateContactType alternateContactType, String? accountId}) Future<GetAlternateContactResponse>
Retrieves the specified alternate contact attached to an Amazon Web Services account.
getContactInformation({String? accountId}) Future<GetContactInformationResponse>
Retrieves the primary contact information of an Amazon Web Services account.
getGovCloudAccountInformation({String? standardAccountId}) Future<GetGovCloudAccountInformationResponse>
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state. To use this API, an IAM user or role must have the account:GetGovCloudAccountInformation IAM permission.
getPrimaryEmail({required String accountId}) Future<GetPrimaryEmailResponse>
Retrieves the primary email address for the specified account.
getRegionOptStatus({required String regionName, String? accountId}) Future<GetRegionOptStatusResponse>
Retrieves the opt-in status of a particular Region.
listRegions({String? accountId, int? maxResults, String? nextToken, List<RegionOptStatus>? regionOptStatusContains}) Future<ListRegionsResponse>
Lists all the Regions for a given account and their respective opt-in statuses. Optionally, this list can be filtered by the region-opt-status-contains parameter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAccountName({required String accountName, String? accountId}) Future<void>
Updates the account name of the specified account. To use this API, IAM principals must have the account:PutAccountName IAM permission.
putAlternateContact({required AlternateContactType alternateContactType, required String emailAddress, required String name, required String phoneNumber, required String title, String? accountId}) Future<void>
Modifies the specified alternate contact attached to an Amazon Web Services account.
putContactInformation({required ContactInformation contactInformation, String? accountId}) Future<void>
Updates the primary contact information of an Amazon Web Services account.
startPrimaryEmailUpdate({required String accountId, required String primaryEmail}) Future<StartPrimaryEmailUpdateResponse>
Starts the process to update the primary email address for the specified account.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited