acceptPrimaryEmailUpdate method

Future<AcceptPrimaryEmailUpdateResponse> acceptPrimaryEmailUpdate({
  1. required String accountId,
  2. required String otp,
  3. required String primaryEmail,
})

Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter accountId : Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.

This operation can only be called from the management account or the delegated administrator account of an organization for a member account.

Parameter otp : The OTP code sent to the PrimaryEmail specified on the StartPrimaryEmailUpdate API call.

Parameter primaryEmail : The new primary email address for use with the specified account. This must match the PrimaryEmail from the StartPrimaryEmailUpdate API call.

Implementation

Future<AcceptPrimaryEmailUpdateResponse> acceptPrimaryEmailUpdate({
  required String accountId,
  required String otp,
  required String primaryEmail,
}) async {
  final $payload = <String, dynamic>{
    'AccountId': accountId,
    'Otp': otp,
    'PrimaryEmail': primaryEmail,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/acceptPrimaryEmailUpdate',
    exceptionFnMap: _exceptionFns,
  );
  return AcceptPrimaryEmailUpdateResponse.fromJson(response);
}