deleteAlternateContact method

Future<void> deleteAlternateContact({
  1. required AlternateContactType alternateContactType,
  2. String? accountId,
})

Deletes the specified alternate contact from an Amazon Web Services account.

For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter alternateContactType : Specifies which of the alternate contacts to delete.

Parameter accountId : Specifies the 12 digit account ID number of the Amazon Web Services account that you want to access or modify with this operation.

If you do not specify this parameter, it defaults to the Amazon Web Services account of the identity used to call the operation.

To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account, and the specified account ID must be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated administrator account assigned. To call this operation on an account that is not a member of an organization, then don't specify this parameter, and call the operation using an identity belonging to the account whose contacts you wish to retrieve or modify.

Implementation

Future<void> deleteAlternateContact({
  required AlternateContactType alternateContactType,
  String? accountId,
}) async {
  final $payload = <String, dynamic>{
    'AlternateContactType': alternateContactType.value,
    if (accountId != null) 'AccountId': accountId,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/deleteAlternateContact',
    exceptionFnMap: _exceptionFns,
  );
}