enableRegion method
Enables (opts-in) a particular Region for an account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter regionName :
Specifies the Region-code for a given Region name (for example,
af-south-1). When you enable a Region, Amazon Web Services
performs actions to prepare your account in that Region, such as
distributing your IAM resources to the Region. This process takes a few
minutes for most accounts, but it can take several hours. You cannot use
the Region until this process is complete. Furthermore, you cannot disable
the Region until the enabling process is fully completed.
Parameter accountId :
Specifies the 12-digit account ID number of the Amazon Web Services
account that you want to access or modify with this operation. If you
don't specify this parameter, it defaults to the Amazon Web Services
account of the identity used to call the operation. To use this parameter,
the caller must be an identity in the organization's
management account or a delegated administrator account. The specified
account ID must be a member account in the same organization. The
organization must have all
features enabled, and the organization must have trusted
access enabled for the Account Management service, and optionally a delegated
admin account assigned.
To call this operation on an account that is not a member of an
organization, don't specify this parameter. Instead, call the operation
using an identity belonging to the account whose contacts you wish to
retrieve or modify.
Implementation
Future<void> enableRegion({
required String regionName,
String? accountId,
}) async {
final $payload = <String, dynamic>{
'RegionName': regionName,
if (accountId != null) 'AccountId': accountId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/enableRegion',
exceptionFnMap: _exceptionFns,
);
}