getRegionOptStatus method

Future<GetRegionOptStatusResponse> getRegionOptStatus({
  1. required String regionName,
  2. String? accountId,
})

Retrieves the opt-in status of a particular Region.

May throw AccessDeniedException. May throw InternalServerException. May throw TooManyRequestsException. May throw ValidationException.

Parameter regionName : Specifies the Region-code for a given Region name (for example, af-south-1). This function will return the status of whatever Region you pass into this parameter.

Parameter accountId : Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation. If you don't specify this parameter, it defaults to the Amazon Web Services account of the identity used to call the operation. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned. To call this operation on an account that is not a member of an organization, don't specify this parameter. Instead, call the operation using an identity belonging to the account whose contacts you wish to retrieve or modify.

Implementation

Future<GetRegionOptStatusResponse> getRegionOptStatus({
  required String regionName,
  String? accountId,
}) async {
  final $payload = <String, dynamic>{
    'RegionName': regionName,
    if (accountId != null) 'AccountId': accountId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/getRegionOptStatus',
    exceptionFnMap: _exceptionFns,
  );
  return GetRegionOptStatusResponse.fromJson(response);
}