listRegions method
Lists all the Regions for a given account and their respective opt-in
statuses. Optionally, this list can be filtered by the
region-opt-status-contains parameter.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter accountId :
Specifies the 12-digit account ID number of the Amazon Web Services
account that you want to access or modify with this operation. If you
don't specify this parameter, it defaults to the Amazon Web Services
account of the identity used to call the operation. To use this parameter,
the caller must be an identity in the organization's
management account or a delegated administrator account. The specified
account ID must be a member account in the same organization. The
organization must have all
features enabled, and the organization must have trusted
access enabled for the Account Management service, and optionally a delegated
admin account assigned.
To call this operation on an account that is not a member of an
organization, don't specify this parameter. Instead, call the operation
using an identity belonging to the account whose contacts you wish to
retrieve or modify.
Parameter maxResults :
The total number of items to return in the command’s output. If the total
number of items available is more than the value specified, a
NextToken is provided in the command’s output. To resume
pagination, provide the NextToken value in the
starting-token argument of a subsequent command. Do not use
the NextToken response element directly outside of the Amazon
Web Services CLI. For usage examples, see Pagination
in the Amazon Web Services Command Line Interface User Guide.
Parameter nextToken :
A token used to specify where to start paginating. This is the
NextToken from a previously truncated response. For usage
examples, see Pagination
in the Amazon Web Services Command Line Interface User Guide.
Parameter regionOptStatusContains :
A list of Region statuses (Enabling, Enabled, Disabling, Disabled,
Enabled_by_default) to use to filter the list of Regions for a given
account. For example, passing in a value of ENABLING will only return a
list of Regions with a Region status of ENABLING.
Implementation
Future<ListRegionsResponse> listRegions({
String? accountId,
int? maxResults,
String? nextToken,
List<RegionOptStatus>? regionOptStatusContains,
}) async {
final $payload = <String, dynamic>{
if (accountId != null) 'AccountId': accountId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (regionOptStatusContains != null)
'RegionOptStatusContains':
regionOptStatusContains.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listRegions',
exceptionFnMap: _exceptionFns,
);
return ListRegionsResponse.fromJson(response);
}