putContactInformation method
- required ContactInformation contactInformation,
- String? accountId,
Updates the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see Update the primary contact for your Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter contactInformation :
Contains the details of the primary contact information associated with an
Amazon Web Services account.
Parameter accountId :
Specifies the 12-digit account ID number of the Amazon Web Services
account that you want to access or modify with this operation. If you
don't specify this parameter, it defaults to the Amazon Web Services
account of the identity used to call the operation. To use this parameter,
the caller must be an identity in the organization's
management account or a delegated administrator account. The specified
account ID must be a member account in the same organization. The
organization must have all
features enabled, and the organization must have trusted
access enabled for the Account Management service, and optionally a delegated
administrator account assigned.
To call this operation on an account that is not a member of an
organization, don't specify this parameter. Instead, call the operation
using an identity belonging to the account whose contacts you wish to
retrieve or modify.
Implementation
Future<void> putContactInformation({
required ContactInformation contactInformation,
String? accountId,
}) async {
final $payload = <String, dynamic>{
'ContactInformation': contactInformation,
if (accountId != null) 'AccountId': accountId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/putContactInformation',
exceptionFnMap: _exceptionFns,
);
}