Acm class

You can use Certificate Manager (ACM) to manage SSL/TLS certificates for your Amazon Web Services-based websites and applications. For more information about using ACM, see the Certificate Manager User Guide.

Constructors

Acm({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false, String? serviceType})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTagsToCertificate({required String certificateArn, required List<Tag> tags}) → Future<void>
Adds one or more tags to an ACM certificate. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a key and an optional value. You specify the certificate on input by its Amazon Resource Name (ARN). You specify the tag by using a key-value pair. You can apply a tag to just one certificate if you want to identify a specific characteristic of that certificate, or you can apply the same tag to multiple certificates if you want to filter for a common relationship among those certificates. Similarly, you can apply the same tag to multiple resources if you want to specify a relationship among those resources. For example, you can add the same tag to an ACM certificate and an Elastic Load Balancing load balancer to indicate that they are both used by the same website. For more information, see Tagging ACM certificates.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAcmeDomainValidation({required String acmeEndpointArn, required String domainName, required PrevalidationOptions prevalidationOptions, String? idempotencyToken, List<Tag>? tags}) → Future<CreateAcmeDomainValidationResponse>
Creates a domain validation for an ACME endpoint. Domain validations authorize the endpoint to issue certificates for specified domain names. You configure prevalidation to prove domain ownership.
createAcmeEndpoint({required AcmeAuthorizationBehavior authorizationBehavior, required CertificateAuthority certificateAuthority, List<Tag>? certificateTags, AcmeContact? contact, String? idempotencyToken, List<Tag>? tags}) → Future<CreateAcmeEndpointResponse>
Creates an ACME endpoint, which is a managed ACME server with a unique endpoint URL. After creation, ACME clients can use the endpoint URL to automate certificate issuance using the ACME protocol.
createAcmeExternalAccountBinding({required String acmeEndpointArn, required String roleArn, Expiration? expiration, String? idempotencyToken, List<Tag>? tags}) → Future<CreateAcmeExternalAccountBindingResponse>
Creates an external account binding (EAB) for an ACME endpoint. An EAB provides credentials that authorize an ACME client to register an account with the endpoint. Each EAB is associated with an IAM role that controls what certificate operations the ACME client can perform.
deleteAcmeDomainValidation({required String acmeDomainValidationArn}) → Future<void>
Deletes a domain validation. After deletion, the ACME endpoint can no longer issue certificates for the associated domain.
deleteAcmeEndpoint({required String acmeEndpointArn}) → Future<void>
Deletes an ACME endpoint. After deletion, the endpoint URL is no longer accessible and ACME clients cannot issue certificates through it. Any existing external account bindings and domain validations associated with the endpoint are also deleted.
deleteAcmeExternalAccountBinding({required String acmeExternalAccountBindingArn}) → Future<void>
Deletes an external account binding. Previously fetched credentials for this binding will no longer be usable for account registration. A deleted binding cannot be recovered.
deleteCertificate({required String certificateArn}) → Future<void>
Deletes a certificate and its associated private key. If this action succeeds, the certificate is not available for use by Amazon Web Services services integrated with ACM. Deleting a certificate is eventually consistent. The may be a short delay before the certificate no longer appears in the list that can be displayed by calling the ListCertificates action or be retrieved by calling the GetCertificate action.
describeAcmeAccount({required String accountUrl, required String acmeEndpointArn}) → Future<DescribeAcmeAccountResponse>
Returns detailed metadata about the specified ACME account, including its status, public key thumbprint, and associated external account binding.
describeAcmeDomainValidation({required String acmeDomainValidationArn}) → Future<DescribeAcmeDomainValidationResponse>
Returns detailed metadata about the specified domain validation, including its status, domain scope, and DNS resource records required for validation.
describeAcmeEndpoint({required String acmeEndpointArn}) → Future<DescribeAcmeEndpointResponse>
Returns detailed metadata about the specified ACME endpoint, including its status, URL, authorization behavior, and certificate authority configuration.
describeAcmeExternalAccountBinding({required String acmeExternalAccountBindingArn}) → Future<DescribeAcmeExternalAccountBindingResponse>
Returns detailed metadata about the specified external account binding, including the associated IAM role, expiration time, and usage history.
describeCertificate({required String certificateArn}) → Future<DescribeCertificateResponse>
Returns detailed metadata about the specified ACM certificate.
exportCertificate({required String certificateArn, required Uint8List passphrase}) → Future<ExportCertificateResponse>
Exports a private certificate issued by a private certificate authority (CA) or a public certificate for use anywhere. The exported file contains the certificate, the certificate chain, and the encrypted private key associated with the public key that is embedded in the certificate. For security, you must assign a passphrase for the private key when exporting it.
getAccountConfiguration() → Future<GetAccountConfigurationResponse>
Returns the account configuration options associated with an Amazon Web Services account.
getAcmeExternalAccountBindingCredentials({required String acmeExternalAccountBindingArn}) → Future<GetAcmeExternalAccountBindingCredentialsResponse>
Retrieves the key ID and MAC key credentials for an external account binding. These credentials are used by ACME clients during account registration to bind to the endpoint.
getCertificate({required String certificateArn}) → Future<GetCertificateResponse>
Retrieves a certificate and its certificate chain. The certificate may be either a public or private certificate issued using the ACM RequestCertificate action, or a certificate imported into ACM using the ImportCertificate action. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs. All of the certificates are base64 encoded. You can use OpenSSL to decode the certificates and inspect individual fields.
importCertificate({required Uint8List certificate, required Uint8List privateKey, String? certificateArn, Uint8List? certificateChain, List<Tag>? tags}) → Future<ImportCertificateResponse>
Imports a certificate into Certificate Manager (ACM) to use with services that are integrated with ACM. Note that integrated services allow only certificate types and keys they support to be associated with their resources. Further, their support differs depending on whether the certificate is imported into IAM or into ACM. For more information, see the documentation for each service. For more information about importing certificates into ACM, see Importing Certificates in the Certificate Manager User Guide. Note the following guidelines when importing third party certificates:
listAcmeAccounts({required String acmeEndpointArn, int? maxResults, String? nextToken}) → Future<ListAcmeAccountsResponse>
Retrieves a list of ACME accounts registered with the specified ACME endpoint. ACME accounts are created when clients use external account binding credentials to register.
listAcmeDomainValidations({required String acmeEndpointArn, int? maxResults, String? nextToken}) → Future<ListAcmeDomainValidationsResponse>
Retrieves a list of domain validations for the specified ACME endpoint.
listAcmeEndpoints({int? maxResults, String? nextToken}) → Future<ListAcmeEndpointsResponse>
Retrieves a list of ACME endpoints in your account. Use this operation to view all configured ACME endpoints and their current status.
listAcmeExternalAccountBindings({required String acmeEndpointArn, int? maxResults, String? nextToken}) → Future<ListAcmeExternalAccountBindingsResponse>
Retrieves a list of external account bindings for the specified ACME endpoint.
listCertificates({List<CertificateKeyPairOrigin>? certificateKeyPairOrigins, List<CertificateStatus>? certificateStatuses, Filters? includes, int? maxItems, String? nextToken, SortBy? sortBy, SortOrder? sortOrder}) → Future<ListCertificatesResponse>
Retrieves a list of certificate ARNs and domain names. You can request that only certificates that match a specific status be listed. You can also filter by specific attributes of the certificate. Default filtering returns only RSA_2048 certificates. For more information, see Filters.
listTagsForCertificate({required String certificateArn}) → Future<ListTagsForCertificateResponse>
Lists the tags that have been applied to the ACM certificate. Use the certificate's Amazon Resource Name (ARN) to specify the certificate. To add a tag to an ACM certificate, use the AddTagsToCertificate action. To delete a tag, use the RemoveTagsFromCertificate action.
listTagsForResource({required String resourceArn}) → Future<ListTagsForResourceResponse>
Lists the tags associated with an ACM resource. To add one or more tags, use the TagResource action. To remove one or more tags, use the UntagResource action.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAccountConfiguration({required String idempotencyToken, ExpiryEventsConfiguration? expiryEvents}) → Future<void>
Adds or modifies account-level configurations in ACM.
removeTagsFromCertificate({required String certificateArn, required List<Tag> tags}) → Future<void>
Remove one or more tags from an ACM certificate. A tag consists of a key-value pair. If you do not specify the value portion of the tag when calling this function, the tag will be removed regardless of value. If you specify a value, the tag is removed only if it is associated with the specified value. To add tags to a certificate, use the AddTagsToCertificate action. To view all of the tags that have been applied to a specific ACM certificate, use the ListTagsForCertificate action.
renewCertificate({required String certificateArn}) → Future<void>
Renews an eligible ACM certificate. In order to renew your Amazon Web Services Private CA certificates with ACM, you must first grant the ACM service principal permission to do so. For more information, see Testing Managed Renewal in the ACM User Guide.
requestCertificate({required String domainName, String? certificateAuthorityArn, List<DomainValidationOption>? domainValidationOptions, String? idempotencyToken, KeyAlgorithm? keyAlgorithm, CertificateManagedBy? managedBy, CertificateOptions? options, List<String>? subjectAlternativeNames, List<Tag>? tags, ValidationMethod? validationMethod}) → Future<RequestCertificateResponse>
Requests an ACM certificate for use with other Amazon Web Services services. To request an ACM certificate, you must specify a fully qualified domain name (FQDN) in the DomainName parameter. You can also specify additional FQDNs in the SubjectAlternativeNames parameter.
resendValidationEmail({required String certificateArn, required String domain, required String validationDomain}) → Future<void>
Resends the email that requests domain ownership validation. The domain owner or an authorized representative must approve the ACM certificate before it can be issued. The certificate can be approved by clicking a link in the mail to navigate to the Amazon certificate approval website and then clicking I Approve. However, the validation email can be blocked by spam filters. Therefore, if you do not receive the original mail, you can request that the mail be resent within 72 hours of requesting the ACM certificate. If more than 72 hours have elapsed since your original request or since your last attempt to resend validation mail, you must request a new certificate. For more information about setting up your contact email addresses, see Configure Email for your Domain.
revokeAcmeAccount({required String accountUrl, required String acmeEndpointArn}) → Future<void>
Revokes an ACME account, preventing it from requesting or revoking certificates. This operation is irreversible.
revokeAcmeExternalAccountBinding({required String acmeExternalAccountBindingArn}) → Future<void>
Revokes an external account binding, preventing new ACME accounts from being registered using this binding. Existing ACME accounts that were previously registered using the binding are not affected and must be revoked separately.
revokeCertificate({required String certificateArn, required RevocationReason revocationReason}) → Future<RevokeCertificateResponse>
Revokes a public ACM certificate. You can only revoke certificates that have been previously exported.
searchCertificates({CertificateFilterStatement? filterStatement, int? maxResults, String? nextToken, SearchCertificatesSortBy? sortBy, SearchCertificatesSortOrder? sortOrder}) → Future<SearchCertificatesResponse>
Retrieves a list of certificates matching search criteria. You can filter certificates by X.509 attributes and ACM specific properties like certificate status, type and renewal eligibility. This operation provides more flexible filtering than ListCertificates by supporting complex filter statements.
tagResource({required String resourceArn, required List<Tag> tags}) → Future<void>
Adds one or more tags to an ACM resource. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a key and an optional value. To remove one or more tags, use the UntagResource action. To view all of the tags that have been applied to a resource, use the ListTagsForResource action.
toString() → String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) → Future<void>
Removes one or more tags from an ACM resource. To add one or more tags, use the TagResource action. To view all of the tags that have been applied to a resource, use the ListTagsForResource action.
updateAcmeDomainValidation({required String acmeDomainValidationArn, PrevalidationOptions? prevalidationOptions}) → Future<void>
Updates the prevalidation configuration of an existing domain validation.
updateAcmeEndpoint({required String acmeEndpointArn, AcmeAuthorizationBehavior? authorizationBehavior, CertificateAuthority? certificateAuthority, AcmeContact? contact}) → Future<void>
Updates the configuration of an existing ACME endpoint. You can change the authorization behavior, contact requirement, or certificate authority settings.
updateCertificateOptions({required String certificateArn, required CertificateOptions options}) → Future<void>
Updates a certificate. You can use this function to specify whether to export your certificate. Certificate transparency logging opt-out is no longer available. For more information, see Certificate Transparency Logging and Certificate Manager Exportable Managed Certificates.

Operators

operator ==(Object other) → bool
The equality operator.
inherited