describeCertificate method

Future<DescribeCertificateResponse> describeCertificate({
  1. required String certificateArn,
})

Returns detailed metadata about the specified ACM certificate.

If you have just created a certificate using the RequestCertificate action, there is a delay of several seconds before you can retrieve information about it.

May throw InvalidArnException. May throw ResourceNotFoundException.

Parameter certificateArn : The Amazon Resource Name (ARN) of the ACM certificate. The ARN must have the following form:

arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012

For more information about ARNs, see Amazon Resource Names (ARNs).

Implementation

Future<DescribeCertificateResponse> describeCertificate({
  required String certificateArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CertificateManager.DescribeCertificate'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CertificateArn': certificateArn,
    },
  );

  return DescribeCertificateResponse.fromJson(jsonResponse.body);
}