updateCertificateOptions method

Future<void> updateCertificateOptions({
  1. required String certificateArn,
  2. required CertificateOptions options,
})

Updates a certificate. You can use this function to specify whether to opt in to or out of recording your certificate in a certificate transparency log and exporting. For more information, see Opting Out of Certificate Transparency Logging and Certificate Manager Exportable Managed Certificates.

May throw InvalidArnException. May throw InvalidStateException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter certificateArn : ARN of the requested certificate to update. This must be of the form:

arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012

Parameter options : Use to update the options for your certificate. Currently, you can specify whether to add your certificate to a transparency log or export your certificate. Certificate transparency makes it possible to detect SSL/TLS certificates that have been mistakenly or maliciously issued. Certificates that have not been logged typically produce an error message in a browser.

Implementation

Future<void> updateCertificateOptions({
  required String certificateArn,
  required CertificateOptions options,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CertificateManager.UpdateCertificateOptions'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CertificateArn': certificateArn,
      'Options': options,
    },
  );
}