createCertificateAuthority method
- required CertificateAuthorityConfiguration certificateAuthorityConfiguration,
- required CertificateAuthorityType certificateAuthorityType,
- String? idempotencyToken,
- KeyStorageSecurityStandard? keyStorageSecurityStandard,
- RevocationConfiguration? revocationConfiguration,
- List<
Tag> ? tags, - CertificateAuthorityUsageMode? usageMode,
Creates a root or subordinate private certificate authority (CA). You must specify the CA configuration, an optional configuration for Online Certificate Status Protocol (OCSP) and/or a certificate revocation list (CRL), the CA type, and an optional idempotency token to avoid accidental creation of multiple CAs. The CA configuration specifies the name of the algorithm and key size to be used to create the CA private key, the type of signing algorithm that the CA uses, and X.500 subject information. The OCSP configuration can optionally specify a custom URL for the OCSP responder. The CRL configuration specifies the CRL expiration period in days (the validity period of the CRL), the Amazon S3 bucket that will contain the CRL, and a CNAME alias for the S3 bucket that is included in certificates issued by the CA. If successful, this action returns the Amazon Resource Name (ARN) of the CA. Amazon Web Services Private CA assets that are stored in Amazon S3 can be protected with encryption. For more information, see Encrypting Your CRLs.
May throw InvalidArgsException.
May throw InvalidPolicyException.
May throw InvalidTagException.
May throw LimitExceededException.
Parameter certificateAuthorityConfiguration :
Name and bit size of the private key algorithm, the name of the signing
algorithm, and X.500 certificate subject information.
Parameter certificateAuthorityType :
The type of the certificate authority.
Parameter idempotencyToken :
Custom string that can be used to distinguish between calls to the
CreateCertificateAuthority action. Idempotency tokens for
CreateCertificateAuthority time out after five minutes. Therefore,
if you call CreateCertificateAuthority multiple times with the same
idempotency token within five minutes, Amazon Web Services Private CA
recognizes that you are requesting only certificate authority and will
issue only one. If you change the idempotency token for each call, Amazon
Web Services Private CA recognizes that you are requesting multiple
certificate authorities.
Parameter keyStorageSecurityStandard :
Specifies a cryptographic key management compliance standard for handling
and protecting CA keys.
Default: FIPS_140_2_LEVEL_3_OR_HIGHER
For information about security standard support in different Amazon Web Services Regions, see Storage and security compliance of Amazon Web Services Private CA private keys.
Parameter revocationConfiguration :
Contains information to enable support for Online Certificate Status
Protocol (OCSP), certificate revocation list (CRL), both protocols, or
neither. By default, both certificate validation mechanisms are disabled.
The following requirements apply to revocation configurations.
-
A configuration disabling CRLs or OCSP must contain only the
Enabled=Falseparameter, and will fail if other parameters such asCustomCnameorExpirationInDaysare included. -
In a CRL configuration, the
S3BucketNameparameter must conform to Amazon S3 bucket naming rules. - A configuration containing a custom Canonical Name (CNAME) parameter for CRLs or OCSP must conform to RFC2396 restrictions on the use of special characters in a CNAME.
- In a CRL or OCSP configuration, the value of a CNAME parameter must not include a protocol prefix such as "http://" or "https://".
Parameter tags :
Key-value pairs that will be attached to the new private CA. You can
associate up to 50 tags with a private CA. For information using tags with
IAM to manage permissions, see Controlling
Access Using IAM Tags.
Parameter usageMode :
Specifies whether the CA issues general-purpose certificates that
typically require a revocation mechanism, or short-lived certificates that
may optionally omit revocation because they expire quickly. Short-lived
certificate validity is limited to seven days.
The default value is GENERAL_PURPOSE.
Implementation
Future<CreateCertificateAuthorityResponse> createCertificateAuthority({
required CertificateAuthorityConfiguration
certificateAuthorityConfiguration,
required CertificateAuthorityType certificateAuthorityType,
String? idempotencyToken,
KeyStorageSecurityStandard? keyStorageSecurityStandard,
RevocationConfiguration? revocationConfiguration,
List<Tag>? tags,
CertificateAuthorityUsageMode? usageMode,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ACMPrivateCA.CreateCertificateAuthority'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CertificateAuthorityConfiguration': certificateAuthorityConfiguration,
'CertificateAuthorityType': certificateAuthorityType.value,
if (idempotencyToken != null) 'IdempotencyToken': idempotencyToken,
if (keyStorageSecurityStandard != null)
'KeyStorageSecurityStandard': keyStorageSecurityStandard.value,
if (revocationConfiguration != null)
'RevocationConfiguration': revocationConfiguration,
if (tags != null) 'Tags': tags,
if (usageMode != null) 'UsageMode': usageMode.value,
},
);
return CreateCertificateAuthorityResponse.fromJson(jsonResponse.body);
}