batchGetDiscoverableRegistryRecord method

Future<BatchGetDiscoverableRegistryRecordResponse> batchGetDiscoverableRegistryRecord({
  1. required List<RegistryRecordsEntry> entries,
})

Retrieves multiple discoverable registry records by ID from a single registry. Records that cannot be retrieved are reported individually in the errors list rather than failing the entire request.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter entries : The registry-scoped groups of record IDs to retrieve. Currently, you can specify exactly one entry.

Implementation

Future<BatchGetDiscoverableRegistryRecordResponse>
    batchGetDiscoverableRegistryRecord({
  required List<RegistryRecordsEntry> entries,
}) async {
  final $payload = <String, dynamic>{
    'entries': entries,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/discoverable-records-batch',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetDiscoverableRegistryRecordResponse.fromJson(response);
}