listDiscoverableRegistryRecords method

Future<ListDiscoverableRegistryRecordsResponse> listDiscoverableRegistryRecords({
  1. required String registryId,
  2. List<RegistryRecordFilter>? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Lists the discoverable registry records in a registry. You can optionally filter and paginate the results.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter filters : The filters to apply to the discoverable registry record list.

Parameter maxResults : The maximum number of records to return in a single page. Valid values are 1 through 100.

Parameter nextToken : The pagination token returned by a previous request. Use this value to retrieve the next page of results.

Implementation

Future<ListDiscoverableRegistryRecordsResponse>
    listDiscoverableRegistryRecords({
  required String registryId,
  List<RegistryRecordFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/registries/${Uri.encodeComponent(registryId)}/discoverable-records-list',
    exceptionFnMap: _exceptionFns,
  );
  return ListDiscoverableRegistryRecordsResponse.fromJson(response);
}