deleteRegistryRecord method

Future<void> deleteRegistryRecord({
  1. required String recordId,
  2. required String registryId,
})

Deletes a registry record

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter recordId : The identifier of the registry record to delete (ARN or ID)

Parameter registryId : The identifier of the registry containing the record (ARN or ID)

Implementation

Future<void> deleteRegistryRecord({
  required String recordId,
  required String registryId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/registries/${Uri.encodeComponent(registryId)}/records/${Uri.encodeComponent(recordId)}',
    exceptionFnMap: _exceptionFns,
  );
}