getRegistryRecord method

Future<GetRegistryRecordResponse> getRegistryRecord({
  1. required String recordId,
  2. required String registryId,
})

Retrieves the details of a registry record

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter recordId : The identifier of the registry record to retrieve (ARN or ID)

Parameter registryId : The identifier of the registry containing the record (ARN or ID)

Implementation

Future<GetRegistryRecordResponse> getRegistryRecord({
  required String recordId,
  required String registryId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/registries/${Uri.encodeComponent(registryId)}/records/${Uri.encodeComponent(recordId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRegistryRecordResponse.fromJson(response);
}