updateRegistryRecordStatus method
Updates the status of a registry record as part of the registry's curation workflow, for example to approve or reject a record that is pending approval, or to deprecate an approved record so that it is no longer discoverable
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter recordId :
The identifier of the registry record to update the status of (ARN or ID)
Parameter registryId :
The identifier of the registry containing the record (ARN or ID)
Parameter status :
The target status for the registry record
Parameter statusReason :
The reason for the status change, for example why the record was approved,
rejected, or deprecated
Implementation
Future<UpdateRegistryRecordStatusResponse> updateRegistryRecordStatus({
required String recordId,
required String registryId,
required RegistryRecordStatus status,
required String statusReason,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
'statusReason': statusReason,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/registries/${Uri.encodeComponent(registryId)}/records/${Uri.encodeComponent(recordId)}/status',
exceptionFnMap: _exceptionFns,
);
return UpdateRegistryRecordStatusResponse.fromJson(response);
}