AIOps class

The CloudWatch investigations feature is a generative AI-powered assistant that can help you respond to incidents in your system. It uses generative AI to scan your system's telemetry and quickly surface suggestions that might be related to your issue. These suggestions include metrics, logs, deployment events, and root-cause hypotheses.

You can use API actions to create, manage, and delete investigation groups and investigation group policies. To start and manage investigations, you must use the CloudWatch console.

Constructors

AIOps({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createInvestigationGroup({required String name, required String roleArn, Map<String, List<String>>? chatbotNotificationChannel, List<CrossAccountConfiguration>? crossAccountConfigurations, EncryptionConfiguration? encryptionConfiguration, bool? isCloudTrailEventHistoryEnabled, int? retentionInDays, List<String>? tagKeyBoundaries, Map<String, String>? tags}) Future<CreateInvestigationGroupOutput>
Creates an investigation group in your account. Creating an investigation group is a one-time setup task for each Region in your account. It is a necessary task to be able to perform investigations.
deleteInvestigationGroup({required String identifier}) Future<void>
Deletes the specified investigation group from your account. You can currently have one investigation group per Region in your account. After you delete an investigation group, you can later create a new investigation group in the same Region.
deleteInvestigationGroupPolicy({required String identifier}) Future<void>
Removes the IAM resource policy from being associated with the investigation group that you specify.
getInvestigationGroup({required String identifier}) Future<GetInvestigationGroupResponse>
Returns the configuration information for the specified investigation group.
getInvestigationGroupPolicy({required String identifier}) Future<GetInvestigationGroupPolicyResponse>
Returns the JSON of the IAM resource policy associated with the specified investigation group in a string. For example, {"Version":"2012-10-17","Statement":[{"Effect":"Allow","Principal":{"Service":"aiops.alarms.cloudwatch.amazonaws.com"},"Action":["aiops:CreateInvestigation","aiops:CreateInvestigationEvent"],"Resource":"","Condition":{"StringEquals":{"aws:SourceAccount":"111122223333"},"ArnLike":{"aws:SourceArn":"arn:aws:cloudwatch:us-east-1:111122223333:alarm:"}}}]}.
listInvestigationGroups({int? maxResults, String? nextToken}) Future<ListInvestigationGroupsOutput>
Returns the ARN and name of each investigation group in the account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Displays the tags associated with a CloudWatch investigations resource. Currently, investigation groups support tagging.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putInvestigationGroupPolicy({required String identifier, required String policy}) Future<PutInvestigationGroupPolicyResponse>
Creates an IAM resource policy and assigns it to the specified investigation group.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one or more tags (key-value pairs) to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from the specified resource.
updateInvestigationGroup({required String identifier, Map<String, List<String>>? chatbotNotificationChannel, List<CrossAccountConfiguration>? crossAccountConfigurations, EncryptionConfiguration? encryptionConfiguration, bool? isCloudTrailEventHistoryEnabled, String? roleArn, List<String>? tagKeyBoundaries}) Future<void>
Updates the configuration of the specified investigation group.

Operators

operator ==(Object other) bool
The equality operator.
inherited