deleteInvestigationGroup method

Future<void> deleteInvestigationGroup({
  1. required String identifier,
})

Deletes the specified investigation group from your account. You can currently have one investigation group per Region in your account. After you delete an investigation group, you can later create a new investigation group in the same Region.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter identifier : Specify either the name or the ARN of the investigation group that you want to delete.

Implementation

Future<void> deleteInvestigationGroup({
  required String identifier,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/investigationGroups/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}