deleteInvestigationGroupPolicy method

Future<void> deleteInvestigationGroupPolicy({
  1. required String identifier,
})

Removes the IAM resource policy from being associated with the investigation group that you specify.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : Specify either the name or the ARN of the investigation group that you want to remove the policy from.

Implementation

Future<void> deleteInvestigationGroupPolicy({
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/investigationGroups/${Uri.encodeComponent(identifier)}/policy',
    exceptionFnMap: _exceptionFns,
  );
}