getInvestigationGroupPolicy method

Future<GetInvestigationGroupPolicyResponse> getInvestigationGroupPolicy({
  1. required String identifier,
})

Returns the JSON of the IAM resource policy associated with the specified investigation group in a string. For example, {"Version":"2012-10-17","Statement":[{"Effect":"Allow","Principal":{"Service":"aiops.alarms.cloudwatch.amazonaws.com"},"Action":["aiops:CreateInvestigation","aiops:CreateInvestigationEvent"],"Resource":"","Condition":{"StringEquals":{"aws:SourceAccount":"111122223333"},"ArnLike":{"aws:SourceArn":"arn:aws:cloudwatch:us-east-1:111122223333:alarm:"}}}]}.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : Specify either the name or the ARN of the investigation group that you want to view the policy of.

Implementation

Future<GetInvestigationGroupPolicyResponse> getInvestigationGroupPolicy({
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/investigationGroups/${Uri.encodeComponent(identifier)}/policy',
    exceptionFnMap: _exceptionFns,
  );
  return GetInvestigationGroupPolicyResponse.fromJson(response);
}