deleteAnomalyDetector method

Future<void> deleteAnomalyDetector({
  1. required String anomalyDetectorId,
  2. required String workspaceId,
  3. String? clientToken,
})

Removes an anomaly detector from a workspace. This operation is idempotent.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter anomalyDetectorId : The identifier of the anomaly detector to delete.

Parameter workspaceId : The identifier of the workspace containing the anomaly detector to delete.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementation

Future<void> deleteAnomalyDetector({
  required String anomalyDetectorId,
  required String workspaceId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/anomalydetectors/${Uri.encodeComponent(anomalyDetectorId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}