deleteQueryLoggingConfiguration method

Future<void> deleteQueryLoggingConfiguration({
  1. required String workspaceId,
  2. String? clientToken,
})

Deletes the query logging configuration for the specified workspace.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter workspaceId : The ID of the workspace from which to delete the query logging configuration.

Parameter clientToken : (Optional) A unique, case-sensitive identifier that you can provide to ensure the idempotency of the request.

Implementation

Future<void> deleteQueryLoggingConfiguration({
  required String workspaceId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/logging/query',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}