deleteRuleGroupsNamespace method
Deletes one rule groups namespace and its associated rule groups definition.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the rule groups namespace to delete.
Parameter workspaceId :
The ID of the workspace containing the rule groups namespace and
definition to delete.
Parameter clientToken :
A unique identifier that you can provide to ensure the idempotency of the
request. Case-sensitive.
Implementation
Future<void> deleteRuleGroupsNamespace({
required String name,
required String workspaceId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/rulegroupsnamespaces/${Uri.encodeComponent(name)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}