deleteScraperLoggingConfiguration method

Future<void> deleteScraperLoggingConfiguration({
  1. required String scraperId,
  2. String? clientToken,
})

Deletes the logging configuration for a Amazon Managed Service for Prometheus scraper.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter scraperId : The ID of the scraper whose logging configuration will be deleted.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the request is processed exactly once.

Implementation

Future<void> deleteScraperLoggingConfiguration({
  required String scraperId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/scrapers/${Uri.encodeComponent(scraperId)}/logging-configuration',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}