describeAnomalyDetector method

Future<DescribeAnomalyDetectorResponse> describeAnomalyDetector({
  1. required String anomalyDetectorId,
  2. required String workspaceId,
})

Retrieves detailed information about a specific anomaly detector, including its status and configuration.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter anomalyDetectorId : The identifier of the anomaly detector to describe.

Parameter workspaceId : The identifier of the workspace containing the anomaly detector.

Implementation

Future<DescribeAnomalyDetectorResponse> describeAnomalyDetector({
  required String anomalyDetectorId,
  required String workspaceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/anomalydetectors/${Uri.encodeComponent(anomalyDetectorId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAnomalyDetectorResponse.fromJson(response);
}