describeLoggingConfiguration method
Future<DescribeLoggingConfigurationResponse>
describeLoggingConfiguration({
- required String workspaceId,
Returns complete information about the current rules and alerting logging configuration of the workspace.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace to describe the logging configuration for.
Implementation
Future<DescribeLoggingConfigurationResponse> describeLoggingConfiguration({
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/workspaces/${Uri.encodeComponent(workspaceId)}/logging',
exceptionFnMap: _exceptionFns,
);
return DescribeLoggingConfigurationResponse.fromJson(response);
}