describeScraperLoggingConfiguration method

Future<DescribeScraperLoggingConfigurationResponse> describeScraperLoggingConfiguration({
  1. required String scraperId,
})

Describes the logging configuration for a Amazon Managed Service for Prometheus scraper.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter scraperId : The ID of the scraper whose logging configuration will be described.

Implementation

Future<DescribeScraperLoggingConfigurationResponse>
    describeScraperLoggingConfiguration({
  required String scraperId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/scrapers/${Uri.encodeComponent(scraperId)}/logging-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeScraperLoggingConfigurationResponse.fromJson(response);
}