describeWorkspaceConfiguration method

Future<DescribeWorkspaceConfigurationResponse> describeWorkspaceConfiguration({
  1. required String workspaceId,
})

Use this operation to return information about the configuration of a workspace. The configuration details returned include workspace configuration status, label set limits, and retention period.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter workspaceId : The ID of the workspace that you want to retrieve information for. To find the IDs of your workspaces, use the ListWorkspaces operation.

Implementation

Future<DescribeWorkspaceConfigurationResponse>
    describeWorkspaceConfiguration({
  required String workspaceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeWorkspaceConfigurationResponse.fromJson(response);
}