listRuleGroupsNamespaces method
Returns a list of rule groups namespaces in a workspace.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace containing the rule groups namespaces.
Parameter maxResults :
The maximum number of results to return. The default is 100.
Parameter name :
Use this parameter to filter the rule groups namespaces that are returned.
Only the namespaces with names that begin with the value that you specify
are returned.
Parameter nextToken :
The token for the next set of items to return. You receive this token from
a previous call, and use it to get the next page of results. The other
parameters must be the same as the initial call.
For example, if your initial request has maxResults of 10,
and there are 12 rule groups namespaces to return, then your initial
request will return 10 and a nextToken. Using the next token
in a subsequent call will return the remaining 2 namespaces.
Implementation
Future<ListRuleGroupsNamespacesResponse> listRuleGroupsNamespaces({
required String workspaceId,
int? maxResults,
String? name,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (name != null) 'name': [name],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/rulegroupsnamespaces',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRuleGroupsNamespacesResponse.fromJson(response);
}