updateLoggingConfiguration method
Updates the log group ARN or the workspace ID of the current rules and alerting logging configuration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter logGroupArn :
The ARN of the CloudWatch log group to which the vended log data will be
published.
Parameter workspaceId :
The ID of the workspace to update the logging configuration for.
Parameter clientToken :
A unique identifier that you can provide to ensure the idempotency of the
request. Case-sensitive.
Implementation
Future<UpdateLoggingConfigurationResponse> updateLoggingConfiguration({
required String logGroupArn,
required String workspaceId,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'logGroupArn': logGroupArn,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/workspaces/${Uri.encodeComponent(workspaceId)}/logging',
exceptionFnMap: _exceptionFns,
);
return UpdateLoggingConfigurationResponse.fromJson(response);
}