Amplify class

Amplify enables developers to develop and deploy cloud-powered mobile and web apps. Amplify Hosting provides a continuous delivery and hosting service for web applications. For more information, see the Amplify Hosting User Guide. The Amplify Framework is a comprehensive set of SDKs, libraries, tools, and documentation for client app development. For more information, see the Amplify Framework.

Constructors

Amplify({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApp({required String name, String? accessToken, AutoBranchCreationConfig? autoBranchCreationConfig, List<String>? autoBranchCreationPatterns, String? basicAuthCredentials, String? buildSpec, CacheConfig? cacheConfig, String? computeRoleArn, String? customHeaders, List<CustomRule>? customRules, String? description, bool? enableAutoBranchCreation, bool? enableBasicAuth, bool? enableBranchAutoBuild, bool? enableBranchAutoDeletion, Map<String, String>? environmentVariables, String? iamServiceRoleArn, JobConfig? jobConfig, String? oauthToken, Platform? platform, String? repository, Map<String, String>? tags}) Future<CreateAppResult>
Creates a new Amplify app.
createBackendEnvironment({required String appId, required String environmentName, String? deploymentArtifacts, String? stackName}) Future<CreateBackendEnvironmentResult>
Creates a new backend environment for an Amplify app.
createBranch({required String appId, required String branchName, Backend? backend, String? backendEnvironmentArn, String? basicAuthCredentials, String? buildSpec, String? computeRoleArn, String? description, String? displayName, bool? enableAutoBuild, bool? enableBasicAuth, bool? enableNotification, bool? enablePerformanceMode, bool? enablePullRequestPreview, bool? enableSkewProtection, Map<String, String>? environmentVariables, String? framework, String? pullRequestEnvironmentName, Stage? stage, Map<String, String>? tags, String? ttl}) Future<CreateBranchResult>
Creates a new branch for an Amplify app.
createDeployment({required String appId, required String branchName, Map<String, String>? fileMap}) Future<CreateDeploymentResult>
Creates a deployment for a manually deployed Amplify app. Manually deployed apps are not connected to a Git repository.
createDomainAssociation({required String appId, required String domainName, required List<SubDomainSetting> subDomainSettings, List<String>? autoSubDomainCreationPatterns, String? autoSubDomainIAMRole, CertificateSettings? certificateSettings, bool? enableAutoSubDomain}) Future<CreateDomainAssociationResult>
Creates a new domain association for an Amplify app. This action associates a custom domain with the Amplify app
createWebhook({required String appId, required String branchName, String? description}) Future<CreateWebhookResult>
Creates a new webhook on an Amplify app.
deleteApp({required String appId}) Future<DeleteAppResult>
Deletes an existing Amplify app specified by an app ID.
deleteBackendEnvironment({required String appId, required String environmentName}) Future<DeleteBackendEnvironmentResult>
Deletes a backend environment for an Amplify app.
deleteBranch({required String appId, required String branchName}) Future<DeleteBranchResult>
Deletes a branch for an Amplify app.
deleteDomainAssociation({required String appId, required String domainName}) Future<DeleteDomainAssociationResult>
Deletes a domain association for an Amplify app.
deleteJob({required String appId, required String branchName, required String jobId}) Future<DeleteJobResult>
Deletes a job for a branch of an Amplify app.
deleteWebhook({required String webhookId}) Future<DeleteWebhookResult>
Deletes a webhook.
generateAccessLogs({required String appId, required String domainName, DateTime? endTime, DateTime? startTime}) Future<GenerateAccessLogsResult>
Returns the website access logs for a specific time range using a presigned URL.
getApp({required String appId}) Future<GetAppResult>
Returns an existing Amplify app specified by an app ID.
getArtifactUrl({required String artifactId}) Future<GetArtifactUrlResult>
Returns the artifact info that corresponds to an artifact id.
getBackendEnvironment({required String appId, required String environmentName}) Future<GetBackendEnvironmentResult>
Returns a backend environment for an Amplify app.
getBranch({required String appId, required String branchName}) Future<GetBranchResult>
Returns a branch for an Amplify app.
getDomainAssociation({required String appId, required String domainName}) Future<GetDomainAssociationResult>
Returns the domain information for an Amplify app.
getJob({required String appId, required String branchName, required String jobId}) Future<GetJobResult>
Returns a job for a branch of an Amplify app.
getWebhook({required String webhookId}) Future<GetWebhookResult>
Returns the webhook information that corresponds to a specified webhook ID.
listApps({int? maxResults, String? nextToken}) Future<ListAppsResult>
Returns a list of the existing Amplify apps.
listArtifacts({required String appId, required String branchName, required String jobId, int? maxResults, String? nextToken}) Future<ListArtifactsResult>
Returns a list of end-to-end testing artifacts for a specified app, branch, and job.
listBackendEnvironments({required String appId, String? environmentName, int? maxResults, String? nextToken}) Future<ListBackendEnvironmentsResult>
Lists the backend environments for an Amplify app.
listBranches({required String appId, int? maxResults, String? nextToken}) Future<ListBranchesResult>
Lists the branches of an Amplify app.
listDomainAssociations({required String appId, int? maxResults, String? nextToken}) Future<ListDomainAssociationsResult>
Returns the domain associations for an Amplify app.
listJobs({required String appId, required String branchName, int? maxResults, String? nextToken}) Future<ListJobsResult>
Lists the jobs for a branch of an Amplify app.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of tags for a specified Amazon Resource Name (ARN).
listWebhooks({required String appId, int? maxResults, String? nextToken}) Future<ListWebhooksResult>
Returns a list of webhooks for an Amplify app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startDeployment({required String appId, required String branchName, String? jobId, String? sourceUrl, SourceUrlType? sourceUrlType}) Future<StartDeploymentResult>
Starts a deployment for a manually deployed app. Manually deployed apps are not connected to a Git repository.
startJob({required String appId, required String branchName, required JobType jobType, String? commitId, String? commitMessage, DateTime? commitTime, String? jobId, String? jobReason}) Future<StartJobResult>
Starts a new job for a branch of an Amplify app.
stopJob({required String appId, required String branchName, required String jobId}) Future<StopJobResult>
Stops a job that is in progress for a branch of an Amplify app.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Tags the resource with a tag key and value.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Untags a resource with a specified Amazon Resource Name (ARN).
updateApp({required String appId, String? accessToken, AutoBranchCreationConfig? autoBranchCreationConfig, List<String>? autoBranchCreationPatterns, String? basicAuthCredentials, String? buildSpec, CacheConfig? cacheConfig, String? computeRoleArn, String? customHeaders, List<CustomRule>? customRules, String? description, bool? enableAutoBranchCreation, bool? enableBasicAuth, bool? enableBranchAutoBuild, bool? enableBranchAutoDeletion, Map<String, String>? environmentVariables, String? iamServiceRoleArn, JobConfig? jobConfig, String? name, String? oauthToken, Platform? platform, String? repository}) Future<UpdateAppResult>
Updates an existing Amplify app.
updateBranch({required String appId, required String branchName, Backend? backend, String? backendEnvironmentArn, String? basicAuthCredentials, String? buildSpec, String? computeRoleArn, String? description, String? displayName, bool? enableAutoBuild, bool? enableBasicAuth, bool? enableNotification, bool? enablePerformanceMode, bool? enablePullRequestPreview, bool? enableSkewProtection, Map<String, String>? environmentVariables, String? framework, String? pullRequestEnvironmentName, Stage? stage, String? ttl}) Future<UpdateBranchResult>
Updates a branch for an Amplify app.
updateDomainAssociation({required String appId, required String domainName, List<String>? autoSubDomainCreationPatterns, String? autoSubDomainIAMRole, CertificateSettings? certificateSettings, bool? enableAutoSubDomain, List<SubDomainSetting>? subDomainSettings}) Future<UpdateDomainAssociationResult>
Creates a new domain association for an Amplify app.
updateWebhook({required String webhookId, String? branchName, String? description}) Future<UpdateWebhookResult>
Updates a webhook.

Operators

operator ==(Object other) bool
The equality operator.
inherited