getJob method

Future<GetJobResult> getJob({
  1. required String appId,
  2. required String branchName,
  3. required String jobId,
})

Returns a job for a branch of an Amplify app.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException. May throw UnauthorizedException.

Parameter appId : The unique ID for an Amplify app.

Parameter branchName : The name of the branch to use for the job.

Parameter jobId : The unique ID for the job.

Implementation

Future<GetJobResult> getJob({
  required String appId,
  required String branchName,
  required String jobId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/apps/${Uri.encodeComponent(appId)}/branches/${Uri.encodeComponent(branchName)}/jobs/${Uri.encodeComponent(jobId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetJobResult.fromJson(response);
}