listBranches method

Future<ListBranchesResult> listBranches({
  1. required String appId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the branches of an Amplify app.

May throw BadRequestException. May throw InternalFailureException. May throw UnauthorizedException.

Parameter appId : The unique ID for an Amplify app.

Parameter maxResults : The maximum number of records to list in a single response.

Parameter nextToken : A pagination token. Set to null to start listing branches from the start. If a non-null pagination token is returned in a result, pass its value in here to list more branches.

Implementation

Future<ListBranchesResult> listBranches({
  required String appId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/apps/${Uri.encodeComponent(appId)}/branches',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListBranchesResult.fromJson(response);
}