listWebhooks method
Returns a list of webhooks for an Amplify app.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw UnauthorizedException.
Parameter appId :
The unique ID for an Amplify app.
Parameter maxResults :
The maximum number of records to list in a single response.
Parameter nextToken :
A pagination token. Set to null to start listing webhooks from the start.
If non-null,the pagination token is returned in a result. Pass its value
in here to list more webhooks.
Implementation
Future<ListWebhooksResult> listWebhooks({
required String appId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/apps/${Uri.encodeComponent(appId)}/webhooks',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListWebhooksResult.fromJson(response);
}