stopJob method
Stops a job that is in progress for a branch of an Amplify app.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter appId :
The unique ID for an Amplify app.
Parameter branchName :
The name of the branch to use for the stop job request.
Parameter jobId :
The unique id for the job.
Implementation
Future<StopJobResult> stopJob({
required String appId,
required String branchName,
required String jobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/apps/${Uri.encodeComponent(appId)}/branches/${Uri.encodeComponent(branchName)}/jobs/${Uri.encodeComponent(jobId)}/stop',
exceptionFnMap: _exceptionFns,
);
return StopJobResult.fromJson(response);
}