updateBackendJob method

Future<UpdateBackendJobResponse> updateBackendJob({
  1. required String appId,
  2. required String backendEnvironmentName,
  3. required String jobId,
  4. String? operation,
  5. String? status,
})

Updates a specific job.

May throw BadRequestException. May throw GatewayTimeoutException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter appId : The app ID.

Parameter backendEnvironmentName : The name of the backend environment.

Parameter jobId : The ID for the job.

Parameter operation : Filters the list of response objects to include only those with the specified operation name.

Parameter status : Filters the list of response objects to include only those with the specified status.

Implementation

Future<UpdateBackendJobResponse> updateBackendJob({
  required String appId,
  required String backendEnvironmentName,
  required String jobId,
  String? operation,
  String? status,
}) async {
  final $payload = <String, dynamic>{
    if (operation != null) 'operation': operation,
    if (status != null) 'status': status,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/backend/${Uri.encodeComponent(appId)}/job/${Uri.encodeComponent(backendEnvironmentName)}/${Uri.encodeComponent(jobId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateBackendJobResponse.fromJson(response);
}