exportThemes method

Future<ExportThemesResponse> exportThemes({
  1. required String appId,
  2. required String environmentName,
  3. String? nextToken,
})

Exports theme configurations to code that is ready to integrate into an Amplify app.

May throw InternalServerException. May throw InvalidParameterException.

Parameter appId : The unique ID of the Amplify app to export the themes to.

Parameter environmentName : The name of the backend environment that is part of the Amplify app.

Parameter nextToken : The token to request the next page of results.

Implementation

Future<ExportThemesResponse> exportThemes({
  required String appId,
  required String environmentName,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/export/app/${Uri.encodeComponent(appId)}/environment/${Uri.encodeComponent(environmentName)}/themes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ExportThemesResponse.fromJson(response);
}