getCodegenJob method

Future<GetCodegenJobResponse> getCodegenJob({
  1. required String appId,
  2. required String environmentName,
  3. required String id,
})

Returns an existing code generation job.

May throw InternalServerException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter appId : The unique ID of the Amplify app associated with the code generation job.

Parameter environmentName : The name of the backend environment that is a part of the Amplify app associated with the code generation job.

Parameter id : The unique ID of the code generation job.

Implementation

Future<GetCodegenJobResponse> getCodegenJob({
  required String appId,
  required String environmentName,
  required String id,
}) async {
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/app/${Uri.encodeComponent(appId)}/environment/${Uri.encodeComponent(environmentName)}/codegen-jobs/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return GetCodegenJobResponse(
    job: CodegenJob.fromJson($json),
  );
}