putMetadataFlag method

Future<void> putMetadataFlag({
  1. required String appId,
  2. required PutMetadataFlagBody body,
  3. required String environmentName,
  4. required String featureName,
})

Stores the metadata information about a feature on a form.

May throw InvalidParameterException. May throw UnauthorizedException.

Parameter appId : The unique ID for the Amplify app.

Parameter body : The metadata information to store.

Parameter environmentName : The name of the backend environment that is part of the Amplify app.

Parameter featureName : The name of the feature associated with the metadata.

Implementation

Future<void> putMetadataFlag({
  required String appId,
  required PutMetadataFlagBody body,
  required String environmentName,
  required String featureName,
}) async {
  await _protocol.send(
    payload: body,
    method: 'PUT',
    requestUri:
        '/app/${Uri.encodeComponent(appId)}/environment/${Uri.encodeComponent(environmentName)}/metadata/features/${Uri.encodeComponent(featureName)}',
    exceptionFnMap: _exceptionFns,
  );
}