amplify_ui_builder_2021_08_11 library

Classes

AmplifyUIBuilder
The Amplify UI Builder API provides a programmatic interface for creating and configuring user interface (UI) component libraries and themes for use in your Amplify applications. You can then connect these UI components to an application's backend Amazon Web Services resources.
AwsClientCredentials
AWS credentials.