deleteDomainNameAccessAssociation method
Deletes the DomainNameAccessAssociation resource.
Only the AWS account that created the DomainNameAccessAssociation resource can delete it. To stop an access association source in another AWS account from accessing your private custom domain name, use the RejectDomainNameAccessAssociation operation.
May throw BadRequestException.
May throw ConflictException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter domainNameAccessAssociationArn :
The ARN of the domain name access association resource.
Implementation
Future<void> deleteDomainNameAccessAssociation({
required String domainNameAccessAssociationArn,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/domainnameaccessassociations/${Uri.encodeComponent(domainNameAccessAssociationArn)}',
exceptionFnMap: _exceptionFns,
);
}