getBasePathMapping method
Describe a BasePathMapping resource.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter basePath :
The base path name that callers of the API must provide as part of the URL
after the domain name. This value must be unique for all of the mappings
across a single API. Specify '(none)' if you do not want callers to
specify any base path name after the domain name.
Parameter domainName :
The domain name of the BasePathMapping resource to be described.
Parameter domainNameId :
The identifier for the domain name resource. Supported only for private
custom domain names.
Implementation
Future<BasePathMapping> getBasePathMapping({
required String basePath,
required String domainName,
String? domainNameId,
}) async {
final $query = <String, List<String>>{
if (domainNameId != null) 'domainNameId': [domainNameId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domainnames/${Uri.encodeComponent(domainName)}/basepathmappings/${Uri.encodeComponent(basePath)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return BasePathMapping.fromJson(response);
}