getDomainNameAccessAssociations method
Represents a collection on DomainNameAccessAssociations resources.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter limit :
The maximum number of returned results per page. The default value is 25
and the maximum value is 500.
Parameter position :
The current pagination position in the paged result set.
Parameter resourceOwner :
The owner of the domain name access association. Use SELF to
only list the domain name access associations owned by your own account.
Use OTHER_ACCOUNTS to list the domain name access
associations with your private custom domain names that are owned by other
AWS accounts.
Implementation
Future<DomainNameAccessAssociations> getDomainNameAccessAssociations({
int? limit,
String? position,
ResourceOwner? resourceOwner,
}) async {
final $query = <String, List<String>>{
if (limit != null) 'limit': [limit.toString()],
if (position != null) 'position': [position],
if (resourceOwner != null) 'resourceOwner': [resourceOwner.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domainnameaccessassociations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DomainNameAccessAssociations.fromJson(response);
}