putMethod method
- required String authorizationType,
- required String httpMethod,
- required String resourceId,
- required String restApiId,
- bool? apiKeyRequired,
- List<
String> ? authorizationScopes, - String? authorizerId,
- String? operationName,
- Map<
String, String> ? requestModels, - Map<
String, bool> ? requestParameters, - String? requestValidatorId,
Add a method to an existing Resource resource.
May throw BadRequestException.
May throw ConflictException.
May throw LimitExceededException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter authorizationType :
The method's authorization type. Valid values are NONE for
open access, AWS_IAM for using AWS IAM permissions,
CUSTOM for using a custom authorizer, or
COGNITO_USER_POOLS for using a Cognito user pool.
Parameter httpMethod :
Specifies the method request's HTTP method type.
Parameter resourceId :
The Resource identifier for the new Method resource.
Parameter restApiId :
The string identifier of the associated RestApi.
Parameter apiKeyRequired :
Specifies whether the method required a valid ApiKey.
Parameter authorizationScopes :
A list of authorization scopes configured on the method. The scopes are
used with a COGNITO_USER_POOLS authorizer to authorize the
method invocation. The authorization works by matching the method scopes
against the scopes parsed from the access token in the incoming request.
The method invocation is authorized if any method scopes matches a claimed
scope in the access token. Otherwise, the invocation is not authorized.
When the method scope is configured, the client must provide an access
token instead of an identity token for authorization purposes.
Parameter authorizerId :
Specifies the identifier of an Authorizer to use on this Method, if the
type is CUSTOM or COGNITO_USER_POOLS. The authorizer identifier is
generated by API Gateway when you created the authorizer.
Parameter operationName :
A human-friendly operation identifier for the method. For example, you can
assign the operationName of ListPets for the
GET /pets method in the PetStore example.
Parameter requestModels :
Specifies the Model resources used for the request's content type. Request
models are represented as a key/value map, with a content type as the key
and a Model name as the value.
Parameter requestParameters :
A key-value map defining required or optional method request parameters
that can be accepted by API Gateway. A key defines a method request
parameter name matching the pattern of
method.request.{location}.{name}, where location
is querystring, path, or header and
name is a valid and unique parameter name. The value
associated with the key is a Boolean flag indicating whether the parameter
is required (true) or optional (false). The
method request parameter names defined here are available in Integration
to be mapped to integration request parameters or body-mapping templates.
Parameter requestValidatorId :
The identifier of a RequestValidator for validating the method request.
Implementation
Future<Method> putMethod({
required String authorizationType,
required String httpMethod,
required String resourceId,
required String restApiId,
bool? apiKeyRequired,
List<String>? authorizationScopes,
String? authorizerId,
String? operationName,
Map<String, String>? requestModels,
Map<String, bool>? requestParameters,
String? requestValidatorId,
}) async {
final $payload = <String, dynamic>{
'authorizationType': authorizationType,
if (apiKeyRequired != null) 'apiKeyRequired': apiKeyRequired,
if (authorizationScopes != null)
'authorizationScopes': authorizationScopes,
if (authorizerId != null) 'authorizerId': authorizerId,
if (operationName != null) 'operationName': operationName,
if (requestModels != null) 'requestModels': requestModels,
if (requestParameters != null) 'requestParameters': requestParameters,
if (requestValidatorId != null) 'requestValidatorId': requestValidatorId,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/restapis/${Uri.encodeComponent(restApiId)}/resources/${Uri.encodeComponent(resourceId)}/methods/${Uri.encodeComponent(httpMethod)}',
exceptionFnMap: _exceptionFns,
);
return Method.fromJson(response);
}