listProductRestEndpointPages method

Future<ListProductRestEndpointPagesResponse> listProductRestEndpointPages({
  1. required String portalProductId,
  2. String? maxResults,
  3. String? nextToken,
  4. String? resourceOwnerAccountId,
})

Lists the product REST endpoint pages of a portal product.

May throw AccessDeniedException. May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter portalProductId : The portal product identifier.

Parameter maxResults : The maximum number of elements to be returned for this resource.

Parameter nextToken : The next page of elements from this collection. Not valid for the last element of the collection.

Parameter resourceOwnerAccountId : The account ID of the resource owner of the portal product.

Implementation

Future<ListProductRestEndpointPagesResponse> listProductRestEndpointPages({
  required String portalProductId,
  String? maxResults,
  String? nextToken,
  String? resourceOwnerAccountId,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults],
    if (nextToken != null) 'nextToken': [nextToken],
    if (resourceOwnerAccountId != null)
      'resourceOwnerAccountId': [resourceOwnerAccountId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/portalproducts/${Uri.encodeComponent(portalProductId)}/productrestendpointpages',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListProductRestEndpointPagesResponse.fromJson(response);
}