updatePortal method

Future<UpdatePortalResponse> updatePortal({
  1. required String portalId,
  2. Authorization? authorization,
  3. EndpointConfigurationRequest? endpointConfiguration,
  4. List<String>? includedPortalProductArns,
  5. String? logoUri,
  6. PortalContent? portalContent,
  7. String? rumAppMonitorName,
})

Updates a portal.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter portalId : The portal identifier.

Parameter authorization : The authorization of the portal.

Parameter endpointConfiguration : Represents an endpoint configuration.

Parameter includedPortalProductArns : The ARNs of the portal products included in the portal.

Parameter logoUri : The logo URI.

Parameter portalContent : Contains the content that is visible to portal consumers including the themes, display names, and description.

Parameter rumAppMonitorName : The CloudWatch RUM app monitor name.

Implementation

Future<UpdatePortalResponse> updatePortal({
  required String portalId,
  Authorization? authorization,
  EndpointConfigurationRequest? endpointConfiguration,
  List<String>? includedPortalProductArns,
  String? logoUri,
  PortalContent? portalContent,
  String? rumAppMonitorName,
}) async {
  final $payload = <String, dynamic>{
    if (authorization != null) 'authorization': authorization,
    if (endpointConfiguration != null)
      'endpointConfiguration': endpointConfiguration,
    if (includedPortalProductArns != null)
      'includedPortalProductArns': includedPortalProductArns,
    if (logoUri != null) 'logoUri': logoUri,
    if (portalContent != null) 'portalContent': portalContent,
    if (rumAppMonitorName != null) 'rumAppMonitorName': rumAppMonitorName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/v2/portals/${Uri.encodeComponent(portalId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdatePortalResponse.fromJson(response);
}