createApplication method

Future<Application> createApplication({
  1. required String name,
  2. String? description,
  3. Map<String, String>? tags,
})

Creates an application. In AppConfig, an application is simply an organizational construct like a folder. This organizational construct has a relationship with some unit of executable code. For example, you could create an application called MyMobileApp to organize and manage configuration data for a mobile application installed by your users.

May throw BadRequestException. May throw InternalServerException. May throw ServiceQuotaExceededException.

Parameter name : A name for the application.

Parameter description : A description of the application.

Parameter tags : Metadata to assign to the application. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.

Implementation

Future<Application> createApplication({
  required String name,
  String? description,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'Name': name,
    if (description != null) 'Description': description,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/applications',
    exceptionFnMap: _exceptionFns,
  );
  return Application.fromJson(response);
}