deleteEnvironment method
Deletes an environment.
To prevent users from unintentionally deleting actively-used environments, enable deletion protection.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
Parameter applicationId :
The application ID that includes the environment that you want to delete.
Parameter environmentId :
The ID of the environment that you want to delete.
Parameter deletionProtectionCheck :
A parameter to configure deletion protection. Deletion protection prevents
a user from deleting an environment if your application called either GetLatestConfiguration
or in the environment during the specified interval.
This parameter supports the following values:
-
BYPASS: Instructs AppConfig to bypass the deletion protection check and delete a configuration profile even if deletion protection would have otherwise prevented it. -
APPLY: Instructs the deletion protection check to run, even if deletion protection is disabled at the account level.APPLYalso forces the deletion protection check to run against resources created in the past hour, which are normally excluded from deletion protection checks. -
ACCOUNT_DEFAULT: The default setting, which instructs AppConfig to implement the deletion protection value specified in theUpdateAccountSettingsAPI.
Implementation
Future<void> deleteEnvironment({
required String applicationId,
required String environmentId,
DeletionProtectionCheck? deletionProtectionCheck,
}) async {
final headers = <String, String>{
if (deletionProtectionCheck != null)
'x-amzn-deletion-protection-check': deletionProtectionCheck.value,
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/environments/${Uri.encodeComponent(environmentId)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}