getDeployment method

Future<Deployment> getDeployment({
  1. required String applicationId,
  2. required int deploymentNumber,
  3. required String environmentId,
})

Retrieves information about a configuration deployment.

May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException.

Parameter applicationId : The ID of the application that includes the deployment you want to get.

Parameter deploymentNumber : The sequence number of the deployment.

Parameter environmentId : The ID of the environment that includes the deployment you want to get.

Implementation

Future<Deployment> getDeployment({
  required String applicationId,
  required int deploymentNumber,
  required String environmentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/environments/${Uri.encodeComponent(environmentId)}/deployments/${Uri.encodeComponent(deploymentNumber.toString())}',
    exceptionFnMap: _exceptionFns,
  );
  return Deployment.fromJson(response);
}