getDeploymentStrategy method

Future<DeploymentStrategy> getDeploymentStrategy({
  1. required String deploymentStrategyId,
})

Retrieves information about a deployment strategy. A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.

May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException.

Parameter deploymentStrategyId : The ID of the deployment strategy to get.

Implementation

Future<DeploymentStrategy> getDeploymentStrategy({
  required String deploymentStrategyId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/deploymentstrategies/${Uri.encodeComponent(deploymentStrategyId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeploymentStrategy.fromJson(response);
}