listApplications method

Future<Applications> listApplications({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all applications in your Amazon Web Services account.

May throw BadRequestException. May throw InternalServerException.

Parameter maxResults : The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

Parameter nextToken : A token to start the list. Next token is a pagination token generated by AppConfig to describe what page the previous List call ended on. For the first List request, the nextToken should not be set. On subsequent calls, the nextToken parameter should be set to the previous responses nextToken value. Use this token to get the next set of results.

Implementation

Future<Applications> listApplications({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'next_token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return Applications.fromJson(response);
}