updateExtension method
Updates an AppConfig extension. For more information about extensions, see Extending workflows in the AppConfig User Guide.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
Parameter extensionIdentifier :
The name, the ID, or the Amazon Resource Name (ARN) of the extension.
Parameter actions :
The actions defined in the extension.
Parameter description :
Information about the extension.
Parameter parameters :
One or more parameters for the actions called by the extension.
Parameter versionNumber :
The extension version number.
Implementation
Future<Extension> updateExtension({
required String extensionIdentifier,
Map<ActionPoint, List<Action>>? actions,
String? description,
Map<String, Parameter>? parameters,
int? versionNumber,
}) async {
final $payload = <String, dynamic>{
if (actions != null)
'Actions': actions.map((k, e) => MapEntry(k.value, e)),
if (description != null) 'Description': description,
if (parameters != null) 'Parameters': parameters,
if (versionNumber != null) 'VersionNumber': versionNumber,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/extensions/${Uri.encodeComponent(extensionIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return Extension.fromJson(response);
}