AppFabric class
Amazon Web Services AppFabric quickly connects software as a service (SaaS) applications across your organization. This allows IT and security teams to easily manage and secure applications using a standard schema, and employees can complete everyday tasks faster using generative artificial intelligence (AI). You can use these APIs to complete AppFabric tasks, such as setting up audit log ingestions or viewing user access. For more information about AppFabric, including the required permissions to use the service, see the Amazon Web Services AppFabric Administration Guide. For more information about using the Command Line Interface (CLI) to manage your AppFabric resources, see the AppFabric section of the CLI Reference.
Constructors
- AppFabric({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetUserAccessTasks(
{required String appBundleIdentifier, required List< String> taskIdList}) → Future<BatchGetUserAccessTasksResponse> - Gets user access details in a batch request.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
connectAppAuthorization(
{required String appAuthorizationIdentifier, required String appBundleIdentifier, AuthRequest? authRequest}) → Future< ConnectAppAuthorizationResponse> - Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application.
-
createAppAuthorization(
{required String app, required String appBundleIdentifier, required AuthType authType, required Credential credential, required Tenant tenant, String? clientToken, List< Tag> ? tags}) → Future<CreateAppAuthorizationResponse> - Creates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
createAppBundle(
{String? clientToken, String? customerManagedKeyIdentifier, List< Tag> ? tags}) → Future<CreateAppBundleResponse> - Creates an app bundle to collect data from an application using AppFabric.
-
createIngestion(
{required String app, required String appBundleIdentifier, required IngestionType ingestionType, required String tenantId, String? clientToken, List< Tag> ? tags}) → Future<CreateIngestionResponse> - Creates a data ingestion for an application.
-
createIngestionDestination(
{required String appBundleIdentifier, required DestinationConfiguration destinationConfiguration, required String ingestionIdentifier, required ProcessingConfiguration processingConfiguration, String? clientToken, List< Tag> ? tags}) → Future<CreateIngestionDestinationResponse> - Creates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
-
deleteAppAuthorization(
{required String appAuthorizationIdentifier, required String appBundleIdentifier}) → Future< void> - Deletes an app authorization. You must delete the associated ingestion before you can delete an app authorization.
-
deleteAppBundle(
{required String appBundleIdentifier}) → Future< void> - Deletes an app bundle. You must delete all associated app authorizations before you can delete an app bundle.
-
deleteIngestion(
{required String appBundleIdentifier, required String ingestionIdentifier}) → Future< void> - Deletes an ingestion. You must stop (disable) the ingestion and you must delete all associated ingestion destinations before you can delete an app ingestion.
-
deleteIngestionDestination(
{required String appBundleIdentifier, required String ingestionDestinationIdentifier, required String ingestionIdentifier}) → Future< void> - Deletes an ingestion destination.
-
getAppAuthorization(
{required String appAuthorizationIdentifier, required String appBundleIdentifier}) → Future< GetAppAuthorizationResponse> - Returns information about an app authorization.
-
getAppBundle(
{required String appBundleIdentifier}) → Future< GetAppBundleResponse> - Returns information about an app bundle.
-
getIngestion(
{required String appBundleIdentifier, required String ingestionIdentifier}) → Future< GetIngestionResponse> - Returns information about an ingestion.
-
getIngestionDestination(
{required String appBundleIdentifier, required String ingestionDestinationIdentifier, required String ingestionIdentifier}) → Future< GetIngestionDestinationResponse> - Returns information about an ingestion destination.
-
listAppAuthorizations(
{required String appBundleIdentifier, int? maxResults, String? nextToken}) → Future< ListAppAuthorizationsResponse> - Returns a list of all app authorizations configured for an app bundle.
-
listAppBundles(
{int? maxResults, String? nextToken}) → Future< ListAppBundlesResponse> - Returns a list of app bundles.
-
listIngestionDestinations(
{required String appBundleIdentifier, required String ingestionIdentifier, int? maxResults, String? nextToken}) → Future< ListIngestionDestinationsResponse> - Returns a list of all ingestion destinations configured for an ingestion.
-
listIngestions(
{required String appBundleIdentifier, int? maxResults, String? nextToken}) → Future< ListIngestionsResponse> - Returns a list of all ingestions configured for an app bundle.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startIngestion(
{required String appBundleIdentifier, required String ingestionIdentifier}) → Future< void> - Starts (enables) an ingestion, which collects data from an application.
-
startUserAccessTasks(
{required String appBundleIdentifier, required String email}) → Future< StartUserAccessTasksResponse> - Starts the tasks to search user access status for a specific email address.
-
stopIngestion(
{required String appBundleIdentifier, required String ingestionIdentifier}) → Future< void> - Stops (disables) an ingestion.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag or tags from a resource.
-
updateAppAuthorization(
{required String appAuthorizationIdentifier, required String appBundleIdentifier, Credential? credential, Tenant? tenant}) → Future< UpdateAppAuthorizationResponse> - Updates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
updateIngestionDestination(
{required String appBundleIdentifier, required DestinationConfiguration destinationConfiguration, required String ingestionDestinationIdentifier, required String ingestionIdentifier}) → Future< UpdateIngestionDestinationResponse> - Updates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited