batchGetUserAccessTasks method

Future<BatchGetUserAccessTasksResponse> batchGetUserAccessTasks({
  1. required String appBundleIdentifier,
  2. required List<String> taskIdList,
})

Gets user access details in a batch request.

This action polls data from the tasks that are kicked off by the StartUserAccessTasks action.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter appBundleIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the app bundle to use for the request.

Parameter taskIdList : The tasks IDs to use for the request.

Implementation

Future<BatchGetUserAccessTasksResponse> batchGetUserAccessTasks({
  required String appBundleIdentifier,
  required List<String> taskIdList,
}) async {
  final $payload = <String, dynamic>{
    'appBundleIdentifier': appBundleIdentifier,
    'taskIdList': taskIdList,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/useraccess/batchget',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetUserAccessTasksResponse.fromJson(response);
}