deleteIngestion method
Deletes an ingestion. You must stop (disable) the ingestion and you must delete all associated ingestion destinations before you can delete an app ingestion.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter appBundleIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the app bundle to use for the request.
Parameter ingestionIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the ingestion to use for the request.
Implementation
Future<void> deleteIngestion({
required String appBundleIdentifier,
required String ingestionIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/appbundles/${Uri.encodeComponent(appBundleIdentifier)}/ingestions/${Uri.encodeComponent(ingestionIdentifier)}',
exceptionFnMap: _exceptionFns,
);
}