deleteIngestionDestination method
Deletes an ingestion destination.
This deletes the association between an ingestion and it's destination. It doesn't delete previously ingested data or the storage destination, such as the Amazon S3 bucket where the data is delivered. If the ingestion destination is deleted while the associated ingestion is enabled, the ingestion will fail and is eventually disabled.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter appBundleIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the app bundle to use for the request.
Parameter ingestionDestinationIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the ingestion destination to use for the request.
Parameter ingestionIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the ingestion to use for the request.
Implementation
Future<void> deleteIngestionDestination({
required String appBundleIdentifier,
required String ingestionDestinationIdentifier,
required String ingestionIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/appbundles/${Uri.encodeComponent(appBundleIdentifier)}/ingestions/${Uri.encodeComponent(ingestionIdentifier)}/ingestiondestinations/${Uri.encodeComponent(ingestionDestinationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
}