getAppAuthorization method

Future<GetAppAuthorizationResponse> getAppAuthorization({
  1. required String appAuthorizationIdentifier,
  2. required String appBundleIdentifier,
})

Returns information about an app authorization.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter appAuthorizationIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the app authorization to use for the request.

Parameter appBundleIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the app bundle to use for the request.

Implementation

Future<GetAppAuthorizationResponse> getAppAuthorization({
  required String appAuthorizationIdentifier,
  required String appBundleIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/appbundles/${Uri.encodeComponent(appBundleIdentifier)}/appauthorizations/${Uri.encodeComponent(appAuthorizationIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetAppAuthorizationResponse.fromJson(response);
}