getIngestionDestination method

Future<GetIngestionDestinationResponse> getIngestionDestination({
  1. required String appBundleIdentifier,
  2. required String ingestionDestinationIdentifier,
  3. required String ingestionIdentifier,
})

Returns information about an ingestion destination.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter appBundleIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the app bundle to use for the request.

Parameter ingestionDestinationIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the ingestion destination to use for the request.

Parameter ingestionIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the ingestion to use for the request.

Implementation

Future<GetIngestionDestinationResponse> getIngestionDestination({
  required String appBundleIdentifier,
  required String ingestionDestinationIdentifier,
  required String ingestionIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/appbundles/${Uri.encodeComponent(appBundleIdentifier)}/ingestions/${Uri.encodeComponent(ingestionIdentifier)}/ingestiondestinations/${Uri.encodeComponent(ingestionDestinationIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetIngestionDestinationResponse.fromJson(response);
}