startUserAccessTasks method

Future<StartUserAccessTasksResponse> startUserAccessTasks({
  1. required String appBundleIdentifier,
  2. required String email,
})

Starts the tasks to search user access status for a specific email address.

The tasks are stopped when the user access status data is found. The tasks are terminated when the API calls to the application time out.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter appBundleIdentifier : The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of the app bundle to use for the request.

Parameter email : The email address of the target user.

Implementation

Future<StartUserAccessTasksResponse> startUserAccessTasks({
  required String appBundleIdentifier,
  required String email,
}) async {
  final $payload = <String, dynamic>{
    'appBundleIdentifier': appBundleIdentifier,
    'email': email,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/useraccess/start',
    exceptionFnMap: _exceptionFns,
  );
  return StartUserAccessTasksResponse.fromJson(response);
}