updateIngestionDestination method
Updates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter appBundleIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the app bundle to use for the request.
Parameter destinationConfiguration :
Contains information about the destination of ingested data.
Parameter ingestionDestinationIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the ingestion destination to use for the request.
Parameter ingestionIdentifier :
The Amazon Resource Name (ARN) or Universal Unique Identifier (UUID) of
the ingestion to use for the request.
Implementation
Future<UpdateIngestionDestinationResponse> updateIngestionDestination({
required String appBundleIdentifier,
required DestinationConfiguration destinationConfiguration,
required String ingestionDestinationIdentifier,
required String ingestionIdentifier,
}) async {
final $payload = <String, dynamic>{
'destinationConfiguration': destinationConfiguration,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/appbundles/${Uri.encodeComponent(appBundleIdentifier)}/ingestions/${Uri.encodeComponent(ingestionIdentifier)}/ingestiondestinations/${Uri.encodeComponent(ingestionDestinationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateIngestionDestinationResponse.fromJson(response);
}