AppIntegrations class

The Amazon AppIntegrations service enables you to configure and reuse connections to external applications.

For information about how you can use external applications with Connect Customer, see the following topics in the Connect Customer Administrator Guide:

Constructors

AppIntegrations({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApplication({required ApplicationSourceConfig applicationSourceConfig, required String name, required String namespace, ApplicationConfig? applicationConfig, ApplicationType? applicationType, String? clientToken, String? description, IframeConfig? iframeConfig, int? initializationTimeout, bool? isService, List<String>? permissions, List<Publication>? publications, List<Subscription>? subscriptions, Map<String, String>? tags}) Future<CreateApplicationResponse>
Creates and persists an Application resource.
createDataIntegration({required String kmsKey, required String name, String? clientToken, String? description, FileConfiguration? fileConfiguration, Map<String, Map<String, List<String>>>? objectConfiguration, ScheduleConfiguration? scheduleConfig, String? sourceURI, Map<String, String>? tags}) Future<CreateDataIntegrationResponse>
Creates and persists a DataIntegration resource.
createDataIntegrationAssociation({required String dataIntegrationIdentifier, Map<String, String>? clientAssociationMetadata, String? clientId, String? clientToken, String? destinationURI, ExecutionConfiguration? executionConfiguration, Map<String, Map<String, List<String>>>? objectConfiguration}) Future<CreateDataIntegrationAssociationResponse>
Creates and persists a DataIntegrationAssociation resource.
createEventIntegration({required String eventBridgeBus, required EventFilter eventFilter, required String name, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateEventIntegrationResponse>
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus. No objects are created in the your account, only metadata that is persisted on the EventIntegration control plane.
deleteApplication({required String arn}) Future<void>
Deletes the Application. Only Applications that don't have any Application Associations can be deleted.
deleteDataIntegration({required String dataIntegrationIdentifier}) Future<void>
Deletes the DataIntegration. Only DataIntegrations that don't have any DataIntegrationAssociations can be deleted. Deleting a DataIntegration also deletes the underlying Amazon AppFlow flow and service linked role.
deleteEventIntegration({required String name}) Future<void>
Deletes the specified existing event integration. If the event integration is associated with clients, the request is rejected.
getApplication({required String arn}) Future<GetApplicationResponse>
Get an Application resource.
getDataIntegration({required String identifier}) Future<GetDataIntegrationResponse>
Returns information about the DataIntegration.
getEventIntegration({required String name}) Future<GetEventIntegrationResponse>
Returns information about the event integration.
listApplicationAssociations({required String applicationId, int? maxResults, String? nextToken}) Future<ListApplicationAssociationsResponse>
Returns a paginated list of application associations for an application.
listApplications({ApplicationType? applicationType, int? maxResults, String? nextToken}) Future<ListApplicationsResponse>
Lists applications in the account.
listDataIntegrationAssociations({required String dataIntegrationIdentifier, int? maxResults, String? nextToken}) Future<ListDataIntegrationAssociationsResponse>
Returns a paginated list of DataIntegration associations in the account.
listDataIntegrations({int? maxResults, String? nextToken}) Future<ListDataIntegrationsResponse>
Returns a paginated list of DataIntegrations in the account.
listEventIntegrationAssociations({required String eventIntegrationName, int? maxResults, String? nextToken}) Future<ListEventIntegrationAssociationsResponse>
Returns a paginated list of event integration associations in the account.
listEventIntegrations({int? maxResults, String? nextToken}) Future<ListEventIntegrationsResponse>
Returns a paginated list of event integrations in the account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for the specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds the specified tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified resource.
updateApplication({required String arn, ApplicationConfig? applicationConfig, ApplicationSourceConfig? applicationSourceConfig, ApplicationType? applicationType, String? description, IframeConfig? iframeConfig, int? initializationTimeout, bool? isService, String? name, List<String>? permissions, List<Publication>? publications, List<Subscription>? subscriptions}) Future<void>
Updates and persists an Application resource.
updateDataIntegration({required String identifier, String? description, String? name}) Future<void>
Updates the description of a DataIntegration.
updateDataIntegrationAssociation({required String dataIntegrationAssociationIdentifier, required String dataIntegrationIdentifier, required ExecutionConfiguration executionConfiguration}) Future<void>
Updates and persists a DataIntegrationAssociation resource.
updateEventIntegration({required String name, String? description}) Future<void>
Updates the description of an event integration.

Operators

operator ==(Object other) bool
The equality operator.
inherited