listApplications method

Future<ListApplicationsResponse> listApplications({
  1. ApplicationType? applicationType,
  2. int? maxResults,
  3. String? nextToken,
})

Lists applications in the account.

May throw AccessDeniedException. May throw InternalServiceError. May throw InvalidRequestException. May throw ThrottlingException.

Parameter applicationType : The type of application.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListApplicationsResponse> listApplications({
  ApplicationType? applicationType,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (applicationType != null) 'applicationType': [applicationType.value],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListApplicationsResponse.fromJson(response);
}