listDataIntegrations method
Returns a paginated list of DataIntegrations in the account.
May throw AccessDeniedException.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListDataIntegrationsResponse> listDataIntegrations({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/dataIntegrations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataIntegrationsResponse.fromJson(response);
}