createVirtualNode method
Creates a virtual node within a service mesh.
A virtual node acts as a logical pointer to a particular task group, such as an Amazon ECS service or a Kubernetes deployment. When you create a virtual node, you can specify the service discovery information for your task group, and whether the proxy running in a task group will communicate with other proxies using Transport Layer Security (TLS).
You define a listener for any inbound traffic that your
virtual node expects. Any virtual service that your virtual node expects
to communicate to is specified as a backend.
The response metadata for your new virtual node contains the
arn that is associated with the virtual node. Set this value
to the full ARN; for example,
arn:aws:appmesh:us-west-2:123456789012:myMesh/default/virtualNode/myApp)
as the APPMESH_RESOURCE_ARN environment variable for your
task group's Envoy proxy container in your task definition or pod spec.
This is then mapped to the node.id and
node.cluster Envoy parameters.
For more information about virtual nodes, see Virtual
nodes. You must be using 1.15.0 or later of the Envoy
image when setting these variables. For more information aboutApp Mesh
Envoy variables, see Envoy
image in the App Mesh User Guide.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter meshName :
The name of the service mesh to create the virtual node in.
Parameter spec :
The virtual node specification to apply.
Parameter virtualNodeName :
The name to use for the virtual node.
Parameter clientToken :
Unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Up to 36 letters, numbers, hyphens, and
underscores are allowed.
Parameter meshOwner :
The Amazon Web Services IAM account ID of the service mesh owner. If the
account ID is not your own, then the account that you specify must share
the mesh with your account before you can create the resource in the
service mesh. For more information about mesh sharing, see Working
with shared meshes.
Parameter tags :
Optional metadata that you can apply to the virtual node to assist with
categorization and organization. Each tag consists of a key and an
optional value, both of which you define. Tag keys can have a maximum
character length of 128 characters, and tag values can have a maximum
length of 256 characters.
Implementation
Future<CreateVirtualNodeOutput> createVirtualNode({
required String meshName,
required VirtualNodeSpec spec,
required String virtualNodeName,
String? clientToken,
String? meshOwner,
List<TagRef>? tags,
}) async {
final $query = <String, List<String>>{
if (meshOwner != null) 'meshOwner': [meshOwner],
};
final $payload = <String, dynamic>{
'spec': spec,
'virtualNodeName': virtualNodeName,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'tags': tags,
};
final response = await _protocol.sendRaw(
payload: $payload,
method: 'PUT',
requestUri:
'/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualNodes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return CreateVirtualNodeOutput(
virtualNode: VirtualNodeData.fromJson($json),
);
}