deleteVirtualNode method
Deletes an existing virtual node.
You must delete any virtual services that list a virtual node as a service provider before you can delete the virtual node itself.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ResourceInUseException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter meshName :
The name of the service mesh to delete the virtual node in.
Parameter virtualNodeName :
The name of the virtual node to delete.
Parameter meshOwner :
The Amazon Web Services IAM account ID of the service mesh owner. If the
account ID is not your own, then it's the ID of the account that shared
the mesh with your account. For more information about mesh sharing, see
Working
with shared meshes.
Implementation
Future<DeleteVirtualNodeOutput> deleteVirtualNode({
required String meshName,
required String virtualNodeName,
String? meshOwner,
}) async {
final $query = <String, List<String>>{
if (meshOwner != null) 'meshOwner': [meshOwner],
};
final response = await _protocol.sendRaw(
payload: null,
method: 'DELETE',
requestUri:
'/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualNodes/${Uri.encodeComponent(virtualNodeName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return DeleteVirtualNodeOutput(
virtualNode: VirtualNodeData.fromJson($json),
);
}