deleteVirtualRouter method

Future<DeleteVirtualRouterOutput> deleteVirtualRouter({
  1. required String meshName,
  2. required String virtualRouterName,
  3. String? meshOwner,
})

Deletes an existing virtual router.

You must delete any routes associated with the virtual router before you can delete the router itself.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ResourceInUseException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter meshName : The name of the service mesh to delete the virtual router in.

Parameter virtualRouterName : The name of the virtual router to delete.

Parameter meshOwner : The Amazon Web Services IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes.

Implementation

Future<DeleteVirtualRouterOutput> deleteVirtualRouter({
  required String meshName,
  required String virtualRouterName,
  String? meshOwner,
}) async {
  final $query = <String, List<String>>{
    if (meshOwner != null) 'meshOwner': [meshOwner],
  };
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualRouters/${Uri.encodeComponent(virtualRouterName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return DeleteVirtualRouterOutput(
    virtualRouter: VirtualRouterData.fromJson($json),
  );
}