describeVirtualService method

Future<DescribeVirtualServiceOutput> describeVirtualService({
  1. required String meshName,
  2. required String virtualServiceName,
  3. String? meshOwner,
})

Describes an existing virtual service.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter meshName : The name of the service mesh that the virtual service resides in.

Parameter virtualServiceName : The name of the virtual service to describe.

Parameter meshOwner : The Amazon Web Services IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes.

Implementation

Future<DescribeVirtualServiceOutput> describeVirtualService({
  required String meshName,
  required String virtualServiceName,
  String? meshOwner,
}) async {
  final $query = <String, List<String>>{
    if (meshOwner != null) 'meshOwner': [meshOwner],
  };
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualServices/${Uri.encodeComponent(virtualServiceName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return DescribeVirtualServiceOutput(
    virtualService: VirtualServiceData.fromJson($json),
  );
}