listMeshes method
Returns a list of existing service meshes.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter limit :
The maximum number of results returned by ListMeshes in
paginated output. When you use this parameter, ListMeshes
returns only limit results in a single page along with a
nextToken response element. You can see the remaining results
of the initial request by sending another ListMeshes request
with the returned nextToken value. This value can be between
1 and 100. If you don't use this parameter, ListMeshes
returns up to 100 results and a nextToken value if
applicable.
Parameter nextToken :
The nextToken value returned from a previous paginated
ListMeshes request where limit was used and the
results exceeded the value of that parameter. Pagination continues from
the end of the previous results that returned the nextToken
value.
Implementation
Future<ListMeshesOutput> listMeshes({
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final $query = <String, List<String>>{
if (limit != null) 'limit': [limit.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v20190125/meshes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMeshesOutput.fromJson(response);
}