listVirtualServices method
Returns a list of existing virtual services in a service mesh.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter meshName :
The name of the service mesh to list virtual services in.
Parameter limit :
The maximum number of results returned by ListVirtualServices
in paginated output. When you use this parameter,
ListVirtualServices returns only limit results
in a single page along with a nextToken response element. You
can see the remaining results of the initial request by sending another
ListVirtualServices request with the returned
nextToken value. This value can be between 1 and 100. If you
don't use this parameter, ListVirtualServices returns up to
100 results and a nextToken value if applicable.
Parameter meshOwner :
The Amazon Web Services IAM account ID of the service mesh owner. If the
account ID is not your own, then it's the ID of the account that shared
the mesh with your account. For more information about mesh sharing, see
Working
with shared meshes.
Parameter nextToken :
The nextToken value returned from a previous paginated
ListVirtualServices request where limit was used
and the results exceeded the value of that parameter. Pagination continues
from the end of the previous results that returned the
nextToken value.
Implementation
Future<ListVirtualServicesOutput> listVirtualServices({
required String meshName,
int? limit,
String? meshOwner,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final $query = <String, List<String>>{
if (limit != null) 'limit': [limit.toString()],
if (meshOwner != null) 'meshOwner': [meshOwner],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualServices',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListVirtualServicesOutput.fromJson(response);
}