createAutoScalingConfiguration method
Create an App Runner automatic scaling configuration resource. App Runner requires this resource when you create or update App Runner services and you require non-default auto scaling settings. You can share an auto scaling configuration across multiple services.
Create multiple revisions of a configuration by calling this action
multiple times using the same AutoScalingConfigurationName.
The call returns incremental AutoScalingConfigurationRevision
values. When you create a service and configure an auto scaling
configuration resource, the service uses the latest active revision of the
auto scaling configuration by default. You can optionally configure the
service to use a specific revision.
Configure a higher MinSize to increase the spread of your App
Runner service over more Availability Zones in the Amazon Web Services
Region. The tradeoff is a higher minimal cost.
Configure a lower MaxSize to control your cost. The tradeoff
is lower responsiveness during peak demand.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ServiceQuotaExceededException.
Parameter autoScalingConfigurationName :
A name for the auto scaling configuration. When you use it for the first
time in an Amazon Web Services Region, App Runner creates revision number
1 of this name. When you use the same name in subsequent
calls, App Runner creates incremental revisions of the configuration.
This restriction is no longer in place. You can now manage
DefaultConfiguration the same way you manage your custom auto
scaling configurations. This means you can do the following with the
DefaultConfiguration that App Runner provides:
-
Create new revisions of the
DefaultConfiguration. -
Delete the revisions of the
DefaultConfiguration. -
Delete the auto scaling configuration for which the App Runner
DefaultConfigurationwas created. -
If you delete the auto scaling configuration you can create another custom
auto scaling configuration with the same
DefaultConfigurationname. The originalDefaultConfigurationresource provided by App Runner remains in your account unless you make changes to it.
Parameter maxConcurrency :
The maximum number of concurrent requests that you want an instance to
process. If the number of concurrent requests exceeds this limit, App
Runner scales up your service.
Default: 100
Parameter maxSize :
The maximum number of instances that your service scales up to. At most
MaxSize instances actively serve traffic for your service.
Default: 25
Parameter minSize :
The minimum number of instances that App Runner provisions for your
service. The service always has at least MinSize provisioned
instances. Some of them actively serve traffic. The rest of them
(provisioned and inactive instances) are a cost-effective compute capacity
reserve and are ready to be quickly activated. You pay for memory usage of
all the provisioned instances. You pay for CPU usage of only the active
subset.
App Runner temporarily doubles the number of provisioned instances during deployments, to maintain the same capacity for both old and new code.
Default: 1
Parameter tags :
A list of metadata items that you can associate with your auto scaling
configuration resource. A tag is a key-value pair.
Implementation
Future<CreateAutoScalingConfigurationResponse>
createAutoScalingConfiguration({
required String autoScalingConfigurationName,
int? maxConcurrency,
int? maxSize,
int? minSize,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'maxConcurrency',
maxConcurrency,
1,
200,
);
_s.validateNumRange(
'maxSize',
maxSize,
1,
1152921504606846976,
);
_s.validateNumRange(
'minSize',
minSize,
1,
25,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.CreateAutoScalingConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AutoScalingConfigurationName': autoScalingConfigurationName,
if (maxConcurrency != null) 'MaxConcurrency': maxConcurrency,
if (maxSize != null) 'MaxSize': maxSize,
if (minSize != null) 'MinSize': minSize,
if (tags != null) 'Tags': tags,
},
);
return CreateAutoScalingConfigurationResponse.fromJson(jsonResponse.body);
}