deleteService method

Future<DeleteServiceResponse> deleteService({
  1. required String serviceArn,
})

Delete an App Runner service.

This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw InvalidStateException. May throw ResourceNotFoundException.

Parameter serviceArn : The Amazon Resource Name (ARN) of the App Runner service that you want to delete.

Implementation

Future<DeleteServiceResponse> deleteService({
  required String serviceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.DeleteService'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ServiceArn': serviceArn,
    },
  );

  return DeleteServiceResponse.fromJson(jsonResponse.body);
}