describeCustomDomains method

Future<DescribeCustomDomainsResponse> describeCustomDomains({
  1. required String serviceArn,
  2. int? maxResults,
  3. String? nextToken,
})

Return a description of custom domain names that are associated with an App Runner service.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter serviceArn : The Amazon Resource Name (ARN) of the App Runner service that you want associated custom domain names to be described for.

Parameter maxResults : The maximum number of results that each response (result page) can include. It's used for a paginated request.

If you don't specify MaxResults, the request retrieves all available results in a single response.

Parameter nextToken : A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones that are specified in the initial request.

If you don't specify NextToken, the request retrieves the first result page.

Implementation

Future<DescribeCustomDomainsResponse> describeCustomDomains({
  required String serviceArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    5,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.DescribeCustomDomains'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ServiceArn': serviceArn,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeCustomDomainsResponse.fromJson(jsonResponse.body);
}