describeService method

Future<DescribeServiceResponse> describeService({
  1. required String serviceArn,
})

Return a full description of an App Runner service.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter serviceArn : The Amazon Resource Name (ARN) of the App Runner service that you want a description for.

Implementation

Future<DescribeServiceResponse> describeService({
  required String serviceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.DescribeService'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ServiceArn': serviceArn,
    },
  );

  return DescribeServiceResponse.fromJson(jsonResponse.body);
}