listAutoScalingConfigurations method
Returns a list of active App Runner automatic scaling configurations in your Amazon Web Services account. You can query the revisions for a specific configuration name or the revisions for all active configurations in your account. You can optionally query only the latest revision of each requested name.
To retrieve a full description of a particular configuration revision,
call and provide one of the ARNs returned by
ListAutoScalingConfigurations.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
Parameter autoScalingConfigurationName :
The name of the App Runner auto scaling configuration that you want to
list. If specified, App Runner lists revisions that share this name. If
not specified, App Runner returns revisions of all active configurations.
Parameter latestOnly :
Set to true to list only the latest revision for each
requested configuration name.
Set to false to list all revisions for each requested
configuration name.
Default: true
Parameter maxResults :
The maximum number of results to include in each response (result page).
It's used for a paginated request.
If you don't specify MaxResults, the request retrieves all
available results in a single response.
Parameter nextToken :
A token from a previous result page. It's used for a paginated request.
The request retrieves the next result page. All other parameter values
must be identical to the ones that are specified in the initial request.
If you don't specify NextToken, the request retrieves the
first result page.
Implementation
Future<ListAutoScalingConfigurationsResponse> listAutoScalingConfigurations({
String? autoScalingConfigurationName,
bool? latestOnly,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.ListAutoScalingConfigurations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (autoScalingConfigurationName != null)
'AutoScalingConfigurationName': autoScalingConfigurationName,
if (latestOnly != null) 'LatestOnly': latestOnly,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListAutoScalingConfigurationsResponse.fromJson(jsonResponse.body);
}