listOperations method
Return a list of operations that occurred on an App Runner service.
The resulting list of OperationSummary objects is sorted in reverse chronological order. The first object on the list represents the last started operation.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter serviceArn :
The Amazon Resource Name (ARN) of the App Runner service that you want a
list of operations for.
Parameter maxResults :
The maximum number of results to include in each response (result page).
It's used for a paginated request.
If you don't specify MaxResults, the request retrieves all
available results in a single response.
Parameter nextToken :
A token from a previous result page. It's used for a paginated request.
The request retrieves the next result page. All other parameter values
must be identical to the ones specified in the initial request.
If you don't specify NextToken, the request retrieves the
first result page.
Implementation
Future<ListOperationsResponse> listOperations({
required String serviceArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.ListOperations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServiceArn': serviceArn,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListOperationsResponse.fromJson(jsonResponse.body);
}