listServices method
Returns a list of running App Runner services in your Amazon Web Services account.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
Parameter maxResults :
The maximum number of results to include in each response (result page).
It's used for a paginated request.
If you don't specify MaxResults, the request retrieves all
available results in a single response.
Parameter nextToken :
A token from a previous result page. Used for a paginated request. The
request retrieves the next result page. All other parameter values must be
identical to the ones specified in the initial request.
If you don't specify NextToken, the request retrieves the
first result page.
Implementation
Future<ListServicesResponse> listServices({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.ListServices'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListServicesResponse.fromJson(jsonResponse.body);
}