listServicesForAutoScalingConfiguration method

Future<ListServicesForAutoScalingConfigurationResponse> listServicesForAutoScalingConfiguration({
  1. required String autoScalingConfigurationArn,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of the associated App Runner services using an auto scaling configuration.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter autoScalingConfigurationArn : The Amazon Resource Name (ARN) of the App Runner auto scaling configuration that you want to list the services for.

The ARN can be a full auto scaling configuration ARN, or a partial ARN ending with either .../name or .../name/revision . If a revision isn't specified, the latest active revision is used.

Parameter maxResults : The maximum number of results to include in each response (result page). It's used for a paginated request.

If you don't specify MaxResults, the request retrieves all available results in a single response.

Parameter nextToken : A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones specified in the initial request.

If you don't specify NextToken, the request retrieves the first result page.

Implementation

Future<ListServicesForAutoScalingConfigurationResponse>
    listServicesForAutoScalingConfiguration({
  required String autoScalingConfigurationArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.ListServicesForAutoScalingConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AutoScalingConfigurationArn': autoScalingConfigurationArn,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListServicesForAutoScalingConfigurationResponse.fromJson(
      jsonResponse.body);
}