listVpcIngressConnections method
Return a list of App Runner VPC Ingress Connections in your Amazon Web Services account.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
Parameter filter :
The VPC Ingress Connections to be listed based on either the Service Arn
or Vpc Endpoint Id, or both.
Parameter maxResults :
The maximum number of results to include in each response (result page).
It's used for a paginated request.
If you don't specify MaxResults, the request retrieves all
available results in a single response.
Parameter nextToken :
A token from a previous result page. It's used for a paginated request.
The request retrieves the next result page. All other parameter values
must be identical to the ones that are specified in the initial request.
If you don't specify NextToken, the request retrieves the
first result page.
Implementation
Future<ListVpcIngressConnectionsResponse> listVpcIngressConnections({
ListVpcIngressConnectionsFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.ListVpcIngressConnections'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListVpcIngressConnectionsResponse.fromJson(jsonResponse.body);
}