resumeService method

Future<ResumeServiceResponse> resumeService({
  1. required String serviceArn,
})

Resume an active App Runner service. App Runner provisions compute capacity for the service.

This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw InvalidStateException. May throw ResourceNotFoundException.

Parameter serviceArn : The Amazon Resource Name (ARN) of the App Runner service that you want to resume.

Implementation

Future<ResumeServiceResponse> resumeService({
  required String serviceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.ResumeService'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ServiceArn': serviceArn,
    },
  );

  return ResumeServiceResponse.fromJson(jsonResponse.body);
}