tagResource method
Add tags to, or update the tag values of, an App Runner resource. A tag is a key-value pair.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw InvalidStateException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource that you want to update
tags for.
It must be the ARN of an App Runner resource.
Parameter tags :
A list of tag key-value pairs to add or update. If a key is new to the
resource, the tag is added with the provided value. If a key is already
associated with the resource, the value of the tag is updated.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'Tags': tags,
},
);
}