untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Remove tags from an App Runner resource.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw InvalidStateException. May throw ResourceNotFoundException.

Parameter resourceArn : The Amazon Resource Name (ARN) of the resource that you want to remove tags from.

It must be the ARN of an App Runner resource.

Parameter tagKeys : A list of tag keys that you want to remove.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceArn': resourceArn,
      'TagKeys': tagKeys,
    },
  );
}