updateVpcIngressConnection method

Future<UpdateVpcIngressConnectionResponse> updateVpcIngressConnection({
  1. required IngressVpcConfiguration ingressVpcConfiguration,
  2. required String vpcIngressConnectionArn,
})

Update an existing App Runner VPC Ingress Connection resource. The VPC Ingress Connection must be in one of the following states to be updated:

  • AVAILABLE
  • FAILED_CREATION
  • FAILED_UPDATE

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw InvalidStateException. May throw ResourceNotFoundException.

Parameter ingressVpcConfiguration : Specifications for the customer’s Amazon VPC and the related Amazon Web Services PrivateLink VPC endpoint that are used to update the VPC Ingress Connection resource.

Parameter vpcIngressConnectionArn : The Amazon Resource Name (Arn) for the App Runner VPC Ingress Connection resource that you want to update.

Implementation

Future<UpdateVpcIngressConnectionResponse> updateVpcIngressConnection({
  required IngressVpcConfiguration ingressVpcConfiguration,
  required String vpcIngressConnectionArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.UpdateVpcIngressConnection'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'IngressVpcConfiguration': ingressVpcConfiguration,
      'VpcIngressConnectionArn': vpcIngressConnectionArn,
    },
  );

  return UpdateVpcIngressConnectionResponse.fromJson(jsonResponse.body);
}