AppStream class

This is the Amazon WorkSpaces Applications API Reference. This documentation provides descriptions and syntax for each of the actions and data types in WorkSpaces Applications. WorkSpaces Applications is a fully managed, secure application streaming service that lets you stream desktop applications to users without rewriting applications. WorkSpaces Applications manages the AWS resources that are required to host and run your applications, scales automatically, and provides access to your users on demand. To learn more about WorkSpaces Applications, see the following resources:

Constructors

AppStream({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateAppBlockBuilderAppBlock({required String appBlockArn, required String appBlockBuilderName}) Future<AssociateAppBlockBuilderAppBlockResult>
Associates the specified app block builder with the specified app block.
associateApplicationFleet({required String applicationArn, required String fleetName}) Future<AssociateApplicationFleetResult>
Associates the specified application with the specified fleet. This is only supported for Elastic fleets.
associateApplicationToEntitlement({required String applicationIdentifier, required String entitlementName, required String stackName}) Future<void>
Associates an application to entitle.
associateFleet({required String fleetName, required String stackName}) Future<void>
Associates the specified fleet with the specified stack.
associateSoftwareToImageBuilder({required String imageBuilderName, required List<String> softwareNames}) Future<void>
Associates license included application(s) with an existing image builder instance.
batchAssociateUserStack({required List<UserStackAssociation> userStackAssociations}) Future<BatchAssociateUserStackResult>
Associates the specified users with the specified stacks. Users in a user pool cannot be assigned to stacks with fleets that are joined to an Active Directory domain.
batchDisassociateUserStack({required List<UserStackAssociation> userStackAssociations}) Future<BatchDisassociateUserStackResult>
Disassociates the specified users from the specified stacks.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
copyImage({required String destinationImageName, required String destinationRegion, required String sourceImageName, String? destinationImageDescription}) Future<CopyImageResponse>
Copies the image within the same region or to a new region within the same AWS account. Note that any tags you added to the image will not be copied.
createAppBlock({required String name, required S3Location sourceS3Location, String? description, String? displayName, PackagingType? packagingType, ScriptDetails? postSetupScriptDetails, ScriptDetails? setupScriptDetails, Map<String, String>? tags}) Future<CreateAppBlockResult>
Creates an app block.
createAppBlockBuilder({required String instanceType, required String name, required AppBlockBuilderPlatformType platform, required VpcConfig vpcConfig, List<AccessEndpoint>? accessEndpoints, String? description, bool? disableIMDSV1, String? displayName, bool? enableDefaultInternetAccess, String? iamRoleArn, Map<String, String>? tags}) Future<CreateAppBlockBuilderResult>
Creates an app block builder.
createAppBlockBuilderStreamingURL({required String appBlockBuilderName, int? validity}) Future<CreateAppBlockBuilderStreamingURLResult>
Creates a URL to start a create app block builder streaming session.
createApplication({required String appBlockArn, required S3Location iconS3Location, required List<String> instanceFamilies, required String launchPath, required String name, required List<PlatformType> platforms, String? description, String? displayName, String? launchParameters, Map<String, String>? tags, String? workingDirectory}) Future<CreateApplicationResult>
Creates an application.
createDirectoryConfig({required String directoryName, required List<String> organizationalUnitDistinguishedNames, CertificateBasedAuthProperties? certificateBasedAuthProperties, ServiceAccountCredentials? serviceAccountCredentials}) Future<CreateDirectoryConfigResult>
Creates a Directory Config object in WorkSpaces Applications. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
createEntitlement({required AppVisibility appVisibility, required List<EntitlementAttribute> attributes, required String name, required String stackName, String? description}) Future<CreateEntitlementResult>
Creates a new entitlement. Entitlements control access to specific applications within a stack, based on user attributes. Entitlements apply to SAML 2.0 federated user identities. WorkSpaces Applications user pool and streaming URL users are entitled to all applications in a stack. Entitlements don't apply to the desktop stream view application, or to applications managed by a dynamic app provider using the Dynamic Application Framework.
createExportImageTask({required String amiName, required String iamRoleArn, required String imageName, String? amiDescription, Map<String, String>? tagSpecifications}) Future<CreateExportImageTaskResult>
Creates a task to export a WorkSpaces Applications image to an EC2 AMI. This allows you to use your customized WorkSpaces Applications images with other AWS services or for backup purposes.
createFleet({required String instanceType, required String name, ComputeCapacity? computeCapacity, String? description, bool? disableIMDSV1, int? disconnectTimeoutInSeconds, String? displayName, DomainJoinInfo? domainJoinInfo, bool? enableDefaultInternetAccess, FleetType? fleetType, String? iamRoleArn, int? idleDisconnectTimeoutInSeconds, String? imageArn, String? imageName, int? maxConcurrentSessions, int? maxSessionsPerInstance, int? maxUserDurationInSeconds, PlatformType? platform, VolumeConfig? rootVolumeConfig, S3Location? sessionScriptS3Location, StreamView? streamView, Map<String, String>? tags, List<String>? usbDeviceFilterStrings, VpcConfig? vpcConfig}) Future<CreateFleetResult>
Creates a fleet. A fleet consists of streaming instances that your users access for their applications and desktops.
createImageBuilder({required String instanceType, required String name, List<AccessEndpoint>? accessEndpoints, String? appstreamAgentVersion, String? description, bool? disableIMDSV1, String? displayName, DomainJoinInfo? domainJoinInfo, bool? enableDefaultInternetAccess, String? iamRoleArn, String? imageArn, String? imageName, VolumeConfig? rootVolumeConfig, List<String>? softwaresToInstall, List<String>? softwaresToUninstall, Map<String, String>? tags, VpcConfig? vpcConfig}) Future<CreateImageBuilderResult>
Creates an image builder. An image builder is a virtual machine that is used to create an image.
createImageBuilderStreamingURL({required String name, int? validity}) Future<CreateImageBuilderStreamingURLResult>
Creates a URL to start an image builder streaming session.
createImportedImage({required String name, AgentSoftwareVersion? agentSoftwareVersion, List<ApplicationConfig>? appCatalogConfig, String? description, String? displayName, bool? dryRun, String? iamRoleArn, RuntimeValidationConfig? runtimeValidationConfig, String? sourceAmiId, Map<String, String>? tags, String? workspaceImageId}) Future<CreateImportedImageResult>
Creates a custom WorkSpaces Applications image by importing an EC2 AMI. This allows you to use your own customized AMI to create WorkSpaces Applications images that support additional instance types beyond the standard stream.* instances.
createStack({required String name, List<AccessEndpoint>? accessEndpoints, AgentAccessConfig? agentAccessConfig, ApplicationSettings? applicationSettings, ContentRedirection? contentRedirection, String? description, String? displayName, List<String>? embedHostDomains, String? feedbackURL, String? redirectURL, List<StorageConnector>? storageConnectors, StreamingExperienceSettings? streamingExperienceSettings, Map<String, String>? tags, List<UserSetting>? userSettings}) Future<CreateStackResult>
Creates a stack to start streaming applications to users. A stack consists of an associated fleet, user access policies, and storage configurations.
createStreamingURL({required String fleetName, required String stackName, required String userId, String? applicationId, String? sessionContext, int? validity}) Future<CreateStreamingURLResult>
Creates a temporary URL to start an WorkSpaces Applications streaming session for the specified user. A streaming URL enables application streaming to be tested without user setup.
createThemeForStack({required S3Location faviconS3Location, required S3Location organizationLogoS3Location, required String stackName, required ThemeStyling themeStyling, required String titleText, List<ThemeFooterLink>? footerLinks}) Future<CreateThemeForStackResult>
Creates custom branding that customizes the appearance of the streaming application catalog page.
createUpdatedImage({required String existingImageName, required String newImageName, bool? dryRun, String? newImageDescription, String? newImageDisplayName, Map<String, String>? newImageTags}) Future<CreateUpdatedImageResult>
Creates a new image with the latest Windows operating system updates, driver updates, and WorkSpaces Applications agent software.
createUsageReportSubscription() Future<CreateUsageReportSubscriptionResult>
Creates a usage report subscription. Usage reports are generated daily.
createUser({required AuthenticationType authenticationType, required String userName, String? firstName, String? lastName, MessageAction? messageAction}) Future<void>
Creates a new user in the user pool.
deleteAppBlock({required String name}) Future<void>
Deletes an app block.
deleteAppBlockBuilder({required String name}) Future<void>
Deletes an app block builder.
deleteApplication({required String name}) Future<void>
Deletes an application.
deleteDirectoryConfig({required String directoryName}) Future<void>
Deletes the specified Directory Config object from WorkSpaces Applications. This object includes the information required to join streaming instances to an Active Directory domain.
deleteEntitlement({required String name, required String stackName}) Future<void>
Deletes the specified entitlement.
deleteFleet({required String name}) Future<void>
Deletes the specified fleet.
deleteImage({required String name}) Future<DeleteImageResult>
Deletes the specified image. You cannot delete an image when it is in use. After you delete an image, you cannot provision new capacity using the image.
deleteImageBuilder({required String name}) Future<DeleteImageBuilderResult>
Deletes the specified image builder and releases the capacity.
deleteImagePermissions({required String name, required String sharedAccountId}) Future<void>
Deletes permissions for the specified private image. After you delete permissions for an image, AWS accounts to which you previously granted these permissions can no longer use the image.
deleteStack({required String name}) Future<void>
Deletes the specified stack. After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released.
deleteThemeForStack({required String stackName}) Future<void>
Deletes custom branding that customizes the appearance of the streaming application catalog page.
deleteUsageReportSubscription() Future<void>
Disables usage report generation.
deleteUser({required AuthenticationType authenticationType, required String userName}) Future<void>
Deletes a user from the user pool.
describeAppBlockBuilderAppBlockAssociations({String? appBlockArn, String? appBlockBuilderName, int? maxResults, String? nextToken}) Future<DescribeAppBlockBuilderAppBlockAssociationsResult>
Retrieves a list that describes one or more app block builder associations.
describeAppBlockBuilders({int? maxResults, List<String>? names, String? nextToken}) Future<DescribeAppBlockBuildersResult>
Retrieves a list that describes one or more app block builders.
describeAppBlocks({List<String>? arns, int? maxResults, String? nextToken}) Future<DescribeAppBlocksResult>
Retrieves a list that describes one or more app blocks.
describeApplicationFleetAssociations({String? applicationArn, String? fleetName, int? maxResults, String? nextToken}) Future<DescribeApplicationFleetAssociationsResult>
Retrieves a list that describes one or more application fleet associations. Either ApplicationArn or FleetName must be specified.
describeApplications({List<String>? arns, int? maxResults, String? nextToken}) Future<DescribeApplicationsResult>
Retrieves a list that describes one or more applications.
describeAppLicenseUsage({required String billingPeriod, int? maxResults, String? nextToken}) Future<DescribeAppLicenseUsageResult>
Retrieves license included application usage information.
describeDirectoryConfigs({List<String>? directoryNames, int? maxResults, String? nextToken}) Future<DescribeDirectoryConfigsResult>
Retrieves a list that describes one or more specified Directory Config objects for WorkSpaces Applications, if the names for these objects are provided. Otherwise, all Directory Config objects in the account are described. These objects include the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
describeEntitlements({required String stackName, int? maxResults, String? name, String? nextToken}) Future<DescribeEntitlementsResult>
Retrieves a list that describes one of more entitlements.
describeFleets({List<String>? names, String? nextToken}) Future<DescribeFleetsResult>
Retrieves a list that describes one or more specified fleets, if the fleet names are provided. Otherwise, all fleets in the account are described.
describeImageBuilders({int? maxResults, List<String>? names, String? nextToken}) Future<DescribeImageBuildersResult>
Retrieves a list that describes one or more specified image builders, if the image builder names are provided. Otherwise, all image builders in the account are described.
describeImagePermissions({required String name, int? maxResults, String? nextToken, List<String>? sharedAwsAccountIds}) Future<DescribeImagePermissionsResult>
Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own.
describeImages({List<String>? arns, int? maxResults, List<String>? names, String? nextToken, VisibilityType? type}) Future<DescribeImagesResult>
Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided. Otherwise, all images in the account are described.
describeSessions({required String fleetName, required String stackName, AuthenticationType? authenticationType, String? instanceId, int? limit, String? nextToken, String? userId}) Future<DescribeSessionsResult>
Retrieves a list that describes the streaming sessions for a specified stack and fleet. If a UserId is provided for the stack and fleet, only streaming sessions for that user are described. If an authentication type is not provided, the default is to authenticate users using a streaming URL.
describeSoftwareAssociations({required String associatedResource, int? maxResults, String? nextToken}) Future<DescribeSoftwareAssociationsResult>
Retrieves license included application associations for a specified resource.
describeStacks({List<String>? names, String? nextToken}) Future<DescribeStacksResult>
Retrieves a list that describes one or more specified stacks, if the stack names are provided. Otherwise, all stacks in the account are described.
describeThemeForStack({required String stackName}) Future<DescribeThemeForStackResult>
Retrieves a list that describes the theme for a specified stack. A theme is custom branding that customizes the appearance of the streaming application catalog page.
describeUsageReportSubscriptions({int? maxResults, String? nextToken}) Future<DescribeUsageReportSubscriptionsResult>
Retrieves a list that describes one or more usage report subscriptions.
describeUsers({required AuthenticationType authenticationType, int? maxResults, String? nextToken}) Future<DescribeUsersResult>
Retrieves a list that describes one or more specified users in the user pool.
describeUserStackAssociations({AuthenticationType? authenticationType, int? maxResults, String? nextToken, String? stackName, String? userName}) Future<DescribeUserStackAssociationsResult>
Retrieves a list that describes the UserStackAssociation objects. You must specify either or both of the following:
disableUser({required AuthenticationType authenticationType, required String userName}) Future<void>
Disables the specified user in the user pool. Users can't sign in to WorkSpaces Applications until they are re-enabled. This action does not delete the user.
disassociateAppBlockBuilderAppBlock({required String appBlockArn, required String appBlockBuilderName}) Future<void>
Disassociates a specified app block builder from a specified app block.
disassociateApplicationFleet({required String applicationArn, required String fleetName}) Future<void>
Disassociates the specified application from the fleet.
disassociateApplicationFromEntitlement({required String applicationIdentifier, required String entitlementName, required String stackName}) Future<void>
Deletes the specified application from the specified entitlement.
disassociateFleet({required String fleetName, required String stackName}) Future<void>
Disassociates the specified fleet from the specified stack.
disassociateSoftwareFromImageBuilder({required String imageBuilderName, required List<String> softwareNames}) Future<void>
Removes license included application(s) association(s) from an image builder instance.
drainSessionInstance({required String sessionId}) Future<void>
Drains the instance hosting the specified streaming session. The instance stops accepting new sessions while existing sessions continue uninterrupted. Once all sessions end, the instance is reclaimed and replaced. This only applies to multi-session fleets.
enableUser({required AuthenticationType authenticationType, required String userName}) Future<void>
Enables a user in the user pool. After being enabled, users can sign in to WorkSpaces Applications and open applications from the stacks to which they are assigned.
expireSession({required String sessionId}) Future<void>
Immediately stops the specified streaming session.
getExportImageTask({String? taskId}) Future<GetExportImageTaskResult>
Retrieves information about an export image task, including its current state, progress, and any error details.
listAssociatedFleets({required String stackName, String? nextToken}) Future<ListAssociatedFleetsResult>
Retrieves the name of the fleet that is associated with the specified stack.
listAssociatedStacks({required String fleetName, String? nextToken}) Future<ListAssociatedStacksResult>
Retrieves the name of the stack with which the specified fleet is associated.
listEntitledApplications({required String entitlementName, required String stackName, int? maxResults, String? nextToken}) Future<ListEntitledApplicationsResult>
Retrieves a list of entitled applications.
listExportImageTasks({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListExportImageTasksResult>
Lists export image tasks, with optional filtering and pagination. Use this operation to monitor the status of multiple export operations.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Retrieves a list of all tags for the specified WorkSpaces Applications resource. You can tag WorkSpaces Applications image builders, images, fleets, and stacks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startAppBlockBuilder({required String name}) Future<StartAppBlockBuilderResult>
Starts an app block builder.
startFleet({required String name}) Future<void>
Starts the specified fleet.
startImageBuilder({required String name, String? appstreamAgentVersion}) Future<StartImageBuilderResult>
Starts the specified image builder.
startSoftwareDeploymentToImageBuilder({required String imageBuilderName, bool? retryFailedDeployments}) Future<void>
Initiates license included applications deployment to an image builder instance.
stopAppBlockBuilder({required String name}) Future<StopAppBlockBuilderResult>
Stops an app block builder.
stopFleet({required String name}) Future<void>
Stops the specified fleet.
stopImageBuilder({required String name}) Future<StopImageBuilderResult>
Stops the specified image builder.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or overwrites one or more tags for the specified WorkSpaces Applications resource. You can tag WorkSpaces Applications image builders, images, fleets, and stacks.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Disassociates one or more specified tags from the specified WorkSpaces Applications resource.
updateAppBlockBuilder({required String name, List<AccessEndpoint>? accessEndpoints, List<AppBlockBuilderAttribute>? attributesToDelete, String? description, bool? disableIMDSV1, String? displayName, bool? enableDefaultInternetAccess, String? iamRoleArn, String? instanceType, PlatformType? platform, VpcConfig? vpcConfig}) Future<UpdateAppBlockBuilderResult>
Updates an app block builder.
updateApplication({required String name, String? appBlockArn, List<ApplicationAttribute>? attributesToDelete, String? description, String? displayName, S3Location? iconS3Location, String? launchParameters, String? launchPath, String? workingDirectory}) Future<UpdateApplicationResult>
Updates the specified application.
updateDirectoryConfig({required String directoryName, CertificateBasedAuthProperties? certificateBasedAuthProperties, List<String>? organizationalUnitDistinguishedNames, ServiceAccountCredentials? serviceAccountCredentials}) Future<UpdateDirectoryConfigResult>
Updates the specified Directory Config object in WorkSpaces Applications. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
updateEntitlement({required String name, required String stackName, AppVisibility? appVisibility, List<EntitlementAttribute>? attributes, String? description}) Future<UpdateEntitlementResult>
Updates the specified entitlement.
updateFleet({List<FleetAttribute>? attributesToDelete, ComputeCapacity? computeCapacity, bool? deleteVpcConfig, String? description, bool? disableIMDSV1, int? disconnectTimeoutInSeconds, String? displayName, DomainJoinInfo? domainJoinInfo, bool? enableDefaultInternetAccess, String? iamRoleArn, int? idleDisconnectTimeoutInSeconds, String? imageArn, String? imageName, String? instanceType, int? maxConcurrentSessions, int? maxSessionsPerInstance, int? maxUserDurationInSeconds, String? name, PlatformType? platform, VolumeConfig? rootVolumeConfig, S3Location? sessionScriptS3Location, StreamView? streamView, List<String>? usbDeviceFilterStrings, VpcConfig? vpcConfig}) Future<UpdateFleetResult>
Updates the specified fleet.
updateImagePermissions({required ImagePermissions imagePermissions, required String name, required String sharedAccountId}) Future<void>
Adds or updates permissions for the specified private image.
updateStack({required String name, List<AccessEndpoint>? accessEndpoints, AgentAccessConfigForUpdate? agentAccessConfig, ApplicationSettings? applicationSettings, List<StackAttribute>? attributesToDelete, ContentRedirection? contentRedirection, bool? deleteStorageConnectors, String? description, String? displayName, List<String>? embedHostDomains, String? feedbackURL, String? redirectURL, List<StorageConnector>? storageConnectors, StreamingExperienceSettings? streamingExperienceSettings, List<UserSetting>? userSettings}) Future<UpdateStackResult>
Updates the specified fields for the specified stack.
updateThemeForStack({required String stackName, List<ThemeAttribute>? attributesToDelete, S3Location? faviconS3Location, List<ThemeFooterLink>? footerLinks, S3Location? organizationLogoS3Location, ThemeState? state, ThemeStyling? themeStyling, String? titleText}) Future<UpdateThemeForStackResult>
Updates custom branding that customizes the appearance of the streaming application catalog page.

Operators

operator ==(Object other) bool
The equality operator.
inherited