createThemeForStack method
Creates custom branding that customizes the appearance of the streaming application catalog page.
May throw ConcurrentModificationException.
May throw InvalidAccountStatusException.
May throw LimitExceededException.
May throw OperationNotPermittedException.
May throw ResourceAlreadyExistsException.
May throw ResourceNotFoundException.
Parameter faviconS3Location :
The S3 location of the favicon. The favicon enables users to recognize
their application streaming site in a browser full of tabs or bookmarks.
It is displayed at the top of the browser tab for the application
streaming site during users' streaming sessions.
Parameter organizationLogoS3Location :
The organization logo that appears on the streaming application catalog
page.
Parameter stackName :
The name of the stack for the theme.
Parameter themeStyling :
The color theme that is applied to website links, text, and buttons. These
colors are also applied as accents in the background for the streaming
application catalog page.
Parameter titleText :
The title that is displayed at the top of the browser tab during users'
application streaming sessions.
Parameter footerLinks :
The links that are displayed in the footer of the streaming application
catalog page. These links are helpful resources for users, such as the
organization's IT support and product marketing sites.
Implementation
Future<CreateThemeForStackResult> createThemeForStack({
required S3Location faviconS3Location,
required S3Location organizationLogoS3Location,
required String stackName,
required ThemeStyling themeStyling,
required String titleText,
List<ThemeFooterLink>? footerLinks,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PhotonAdminProxyService.CreateThemeForStack'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FaviconS3Location': faviconS3Location,
'OrganizationLogoS3Location': organizationLogoS3Location,
'StackName': stackName,
'ThemeStyling': themeStyling.value,
'TitleText': titleText,
if (footerLinks != null) 'FooterLinks': footerLinks,
},
);
return CreateThemeForStackResult.fromJson(jsonResponse.body);
}