deleteStack method

Future<void> deleteStack({
  1. required String name,
})

Deletes the specified stack. After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released.

May throw ConcurrentModificationException. May throw OperationNotPermittedException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter name : The name of the stack.

Implementation

Future<void> deleteStack({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'PhotonAdminProxyService.DeleteStack'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}