describeAppBlockBuilders method
Retrieves a list that describes one or more app block builders.
May throw OperationNotPermittedException.
May throw ResourceNotFoundException.
Parameter maxResults :
The maximum size of each page of results. The maximum value is 25.
Parameter names :
The names of the app block builders.
Parameter nextToken :
The pagination token used to retrieve the next page of results for this
operation.
Implementation
Future<DescribeAppBlockBuildersResult> describeAppBlockBuilders({
int? maxResults,
List<String>? names,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PhotonAdminProxyService.DescribeAppBlockBuilders'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (names != null) 'Names': names,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeAppBlockBuildersResult.fromJson(jsonResponse.body);
}