describeAppBlocks method

Future<DescribeAppBlocksResult> describeAppBlocks({
  1. List<String>? arns,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves a list that describes one or more app blocks.

May throw OperationNotPermittedException. May throw ResourceNotFoundException.

Parameter arns : The ARNs of the app blocks.

Parameter maxResults : The maximum size of each page of results.

Parameter nextToken : The pagination token used to retrieve the next page of results for this operation.

Implementation

Future<DescribeAppBlocksResult> describeAppBlocks({
  List<String>? arns,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'PhotonAdminProxyService.DescribeAppBlocks'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (arns != null) 'Arns': arns,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeAppBlocksResult.fromJson(jsonResponse.body);
}