describeThemeForStack method

Future<DescribeThemeForStackResult> describeThemeForStack({
  1. required String stackName,
})

Retrieves a list that describes the theme for a specified stack. A theme is custom branding that customizes the appearance of the streaming application catalog page.

May throw OperationNotPermittedException. May throw ResourceNotFoundException.

Parameter stackName : The name of the stack for the theme.

Implementation

Future<DescribeThemeForStackResult> describeThemeForStack({
  required String stackName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'PhotonAdminProxyService.DescribeThemeForStack'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'StackName': stackName,
    },
  );

  return DescribeThemeForStackResult.fromJson(jsonResponse.body);
}