disassociateApplicationFromEntitlement method
Deletes the specified application from the specified entitlement.
May throw EntitlementNotFoundException.
May throw OperationNotPermittedException.
May throw ResourceNotFoundException.
Parameter applicationIdentifier :
The identifier of the application to remove from the entitlement.
Parameter entitlementName :
The name of the entitlement.
Parameter stackName :
The name of the stack with which the entitlement is associated.
Implementation
Future<void> disassociateApplicationFromEntitlement({
required String applicationIdentifier,
required String entitlementName,
required String stackName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'PhotonAdminProxyService.DisassociateApplicationFromEntitlement'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationIdentifier': applicationIdentifier,
'EntitlementName': entitlementName,
'StackName': stackName,
},
);
}