startAppBlockBuilder method
Starts an app block builder.
An app block builder can only be started when it's associated with an app block.
Starting an app block builder starts a new instance, which is equivalent to an elastic fleet instance with application builder assistance functionality.
May throw ConcurrentModificationException.
May throw InvalidAccountStatusException.
May throw LimitExceededException.
May throw OperationNotPermittedException.
May throw RequestLimitExceededException.
May throw ResourceNotAvailableException.
May throw ResourceNotFoundException.
Parameter name :
The name of the app block builder.
Implementation
Future<StartAppBlockBuilderResult> startAppBlockBuilder({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PhotonAdminProxyService.StartAppBlockBuilder'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
return StartAppBlockBuilderResult.fromJson(jsonResponse.body);
}