listApis method

Future<ListApisResponse> listApis({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the APIs in your AppSync account.

ListApis returns only the high level API details. For more detailed information about an API, use GetApi.

May throw BadRequestException. May throw InternalFailureException. May throw UnauthorizedException.

Parameter maxResults : The maximum number of results that you want the request to return.

Parameter nextToken : An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.

Implementation

Future<ListApisResponse> listApis({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    25,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v2/apis',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListApisResponse.fromJson(response);
}