listGraphqlApis method

Future<ListGraphqlApisResponse> listGraphqlApis({
  1. GraphQLApiType? apiType,
  2. int? maxResults,
  3. String? nextToken,
  4. Ownership? owner,
})

Lists your GraphQL APIs.

May throw BadRequestException. May throw InternalFailureException. May throw UnauthorizedException.

Parameter apiType : The value that indicates whether the GraphQL API is a standard API (GRAPHQL) or merged API (MERGED).

Parameter maxResults : The maximum number of results that you want the request to return.

Parameter nextToken : An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.

Parameter owner : The account owner of the GraphQL API.

Implementation

Future<ListGraphqlApisResponse> listGraphqlApis({
  GraphQLApiType? apiType,
  int? maxResults,
  String? nextToken,
  Ownership? owner,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    25,
  );
  final $query = <String, List<String>>{
    if (apiType != null) 'apiType': [apiType.value],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (owner != null) 'owner': [owner.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/apis',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListGraphqlApisResponse.fromJson(response);
}