Appflow class
Welcome to the Amazon AppFlow API reference. This guide is for developers who need detailed information about the Amazon AppFlow API operations, data types, and errors.
Amazon AppFlow is a fully managed integration service that enables you to securely transfer data between software as a service (SaaS) applications like Salesforce, Marketo, Slack, and ServiceNow, and Amazon Web Services like Amazon S3 and Amazon Redshift.
Use the following links to get started on the Amazon AppFlow API:
- Actions: An alphabetical list of all Amazon AppFlow API operations.
- Data types: An alphabetical list of all Amazon AppFlow data types.
- Common parameters: Parameters that all Query operations can use.
- Common errors: Client and server errors that all operations can return.
Amazon AppFlow API users can use vendor-specific mechanisms for OAuth, and
include applicable OAuth attributes (such as auth-code and
redirecturi) with the connector-specific
ConnectorProfileProperties when creating a new connector
profile using Amazon AppFlow API operations. For example, Salesforce users
can refer to the
Authorize Apps with OAuth documentation.
Constructors
- Appflow({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelFlowExecutions(
{required String flowName, List< String> ? executionIds}) → Future<CancelFlowExecutionsResponse> - Cancels active runs for a flow.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createConnectorProfile(
{required ConnectionMode connectionMode, required ConnectorProfileConfig connectorProfileConfig, required String connectorProfileName, required ConnectorType connectorType, String? clientToken, String? connectorLabel, String? kmsArn}) → Future< CreateConnectorProfileResponse> - Creates a new connector profile associated with your Amazon Web Services account. There is a soft quota of 100 connector profiles per Amazon Web Services account. If you need more connector profiles than this quota allows, you can submit a request to the Amazon AppFlow team through the Amazon AppFlow support channel. In each connector profile that you create, you can provide the credentials and properties for only one connector.
-
createFlow(
{required List< DestinationFlowConfig> destinationFlowConfigList, required String flowName, required SourceFlowConfig sourceFlowConfig, required List<Task> tasks, required TriggerConfig triggerConfig, String? clientToken, String? description, String? kmsArn, MetadataCatalogConfig? metadataCatalogConfig, Map<String, String> ? tags}) → Future<CreateFlowResponse> - Enables your application to create a new flow using Amazon AppFlow. You must create a connector profile before calling this API. Please note that the Request Syntax below shows syntax for multiple destinations, however, you can only transfer data to one item in this list at a time. Amazon AppFlow does not currently support flows to multiple destinations at once.
-
deleteConnectorProfile(
{required String connectorProfileName, bool? forceDelete}) → Future< void> - Enables you to delete an existing connector profile.
-
deleteFlow(
{required String flowName, bool? forceDelete}) → Future< void> - Enables your application to delete an existing flow. Before deleting the flow, Amazon AppFlow validates the request by checking the flow configuration and status. You can delete flows one at a time.
-
describeConnector(
{required ConnectorType connectorType, String? connectorLabel}) → Future< DescribeConnectorResponse> - Describes the given custom connector registered in your Amazon Web Services account. This API can be used for custom connectors that are registered in your account and also for Amazon authored connectors.
-
describeConnectorEntity(
{required String connectorEntityName, String? apiVersion, String? connectorProfileName, ConnectorType? connectorType}) → Future< DescribeConnectorEntityResponse> - Provides details regarding the entity used with the connector, with a description of the data model for each field in that entity.
-
describeConnectorProfiles(
{String? connectorLabel, List< String> ? connectorProfileNames, ConnectorType? connectorType, int? maxResults, String? nextToken}) → Future<DescribeConnectorProfilesResponse> -
Returns a list of
connector-profiledetails matching the providedconnector-profilenames andconnector-types. Both input lists are optional, and you can use them to filter the result. -
describeConnectors(
{List< ConnectorType> ? connectorTypes, int? maxResults, String? nextToken}) → Future<DescribeConnectorsResponse> -
Describes the connectors vended by Amazon AppFlow for specified connector
types. If you don't specify a connector type, this operation describes all
connectors vended by Amazon AppFlow. If there are more connectors than can
be returned in one page, the response contains a
nextTokenobject, which can be be passed in to the next call to theDescribeConnectorsAPI operation to retrieve the next page. -
describeFlow(
{required String flowName}) → Future< DescribeFlowResponse> - Provides a description of the specified flow.
-
describeFlowExecutionRecords(
{required String flowName, int? maxResults, String? nextToken}) → Future< DescribeFlowExecutionRecordsResponse> - Fetches the execution history of the flow.
-
listConnectorEntities(
{String? apiVersion, String? connectorProfileName, ConnectorType? connectorType, String? entitiesPath, int? maxResults, String? nextToken}) → Future< ListConnectorEntitiesResponse> - Returns the list of available connector entities supported by Amazon AppFlow. For example, you can query Salesforce for Account and Opportunity entities, or query ServiceNow for the Incident entity.
-
listConnectors(
{int? maxResults, String? nextToken}) → Future< ListConnectorsResponse> - Returns the list of all registered custom connectors in your Amazon Web Services account. This API lists only custom connectors registered in this account, not the Amazon Web Services authored connectors.
-
listFlows(
{int? maxResults, String? nextToken}) → Future< ListFlowsResponse> - Lists all of the flows associated with your account.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Retrieves the tags that are associated with a specified flow.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerConnector(
{String? clientToken, String? connectorLabel, ConnectorProvisioningConfig? connectorProvisioningConfig, ConnectorProvisioningType? connectorProvisioningType, String? description}) → Future< RegisterConnectorResponse> - Registers a new custom connector with your Amazon Web Services account. Before you can register the connector, you must deploy the associated AWS lambda function in your account.
-
resetConnectorMetadataCache(
{String? apiVersion, String? connectorEntityName, String? connectorProfileName, ConnectorType? connectorType, String? entitiesPath}) → Future< void> - Resets metadata about your connector entities that Amazon AppFlow stored in its cache. Use this action when you want Amazon AppFlow to return the latest information about the data that you have in a source application.
-
startFlow(
{required String flowName, String? clientToken}) → Future< StartFlowResponse> - Activates an existing flow. For on-demand flows, this operation runs the flow immediately. For schedule and event-triggered flows, this operation activates the flow.
-
stopFlow(
{required String flowName}) → Future< StopFlowResponse> -
Deactivates the existing flow. For on-demand flows, this operation returns
an
unsupportedOperationExceptionerror message. For schedule and event-triggered flows, this operation deactivates the flow. -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Applies a tag to the specified flow.
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterConnector(
{required String connectorLabel, bool? forceDelete}) → Future< void> - Unregisters the custom connector registered in your account that matches the connector label provided in the request.
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from the specified flow.
-
updateConnectorProfile(
{required ConnectionMode connectionMode, required ConnectorProfileConfig connectorProfileConfig, required String connectorProfileName, String? clientToken}) → Future< UpdateConnectorProfileResponse> - Updates a given connector profile associated with your account.
-
updateConnectorRegistration(
{required String connectorLabel, String? clientToken, ConnectorProvisioningConfig? connectorProvisioningConfig, String? description}) → Future< UpdateConnectorRegistrationResponse> - Updates a custom connector that you've previously registered. This operation updates the connector with one of the following:
-
updateFlow(
{required List< DestinationFlowConfig> destinationFlowConfigList, required String flowName, required SourceFlowConfig sourceFlowConfig, required List<Task> tasks, required TriggerConfig triggerConfig, String? clientToken, String? description, MetadataCatalogConfig? metadataCatalogConfig}) → Future<UpdateFlowResponse> - Updates an existing flow.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited