deleteFlow method

Future<void> deleteFlow({
  1. required String flowName,
  2. bool? forceDelete,
})

Enables your application to delete an existing flow. Before deleting the flow, Amazon AppFlow validates the request by checking the flow configuration and status. You can delete flows one at a time.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException.

Parameter flowName : The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only.

Parameter forceDelete : Indicates whether Amazon AppFlow should delete the flow, even if it is currently in use.

Implementation

Future<void> deleteFlow({
  required String flowName,
  bool? forceDelete,
}) async {
  final $payload = <String, dynamic>{
    'flowName': flowName,
    if (forceDelete != null) 'forceDelete': forceDelete,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/delete-flow',
    exceptionFnMap: _exceptionFns,
  );
}