describeConnector method

Future<DescribeConnectorResponse> describeConnector({
  1. required ConnectorType connectorType,
  2. String? connectorLabel,
})

Describes the given custom connector registered in your Amazon Web Services account. This API can be used for custom connectors that are registered in your account and also for Amazon authored connectors.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter connectorType : The connector type, such as CUSTOMCONNECTOR, Saleforce, Marketo. Please choose CUSTOMCONNECTOR for Lambda based custom connectors.

Parameter connectorLabel : The label of the connector. The label is unique for each ConnectorRegistration in your Amazon Web Services account. Only needed if calling for CUSTOMCONNECTOR connector type/.

Implementation

Future<DescribeConnectorResponse> describeConnector({
  required ConnectorType connectorType,
  String? connectorLabel,
}) async {
  final $payload = <String, dynamic>{
    'connectorType': connectorType.value,
    if (connectorLabel != null) 'connectorLabel': connectorLabel,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/describe-connector',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeConnectorResponse.fromJson(response);
}