describeConnectorProfiles method

Future<DescribeConnectorProfilesResponse> describeConnectorProfiles({
  1. String? connectorLabel,
  2. List<String>? connectorProfileNames,
  3. ConnectorType? connectorType,
  4. int? maxResults,
  5. String? nextToken,
})

Returns a list of connector-profile details matching the provided connector-profile names and connector-types. Both input lists are optional, and you can use them to filter the result.

If no names or connector-types are provided, returns all connector profiles in a paginated form. If there is no match, this operation returns an empty list.

May throw InternalServerException. May throw ValidationException.

Parameter connectorLabel : The name of the connector. The name is unique for each ConnectorRegistration in your Amazon Web Services account. Only needed if calling for CUSTOMCONNECTOR connector type/.

Parameter connectorProfileNames : The name of the connector profile. The name is unique for each ConnectorProfile in the Amazon Web Services account.

Parameter connectorType : The type of connector, such as Salesforce, Amplitude, and so on.

Parameter maxResults : Specifies the maximum number of items that should be returned in the result set. The default for maxResults is 20 (for all paginated API operations).

Parameter nextToken : The pagination token for the next page of data.

Implementation

Future<DescribeConnectorProfilesResponse> describeConnectorProfiles({
  String? connectorLabel,
  List<String>? connectorProfileNames,
  ConnectorType? connectorType,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (connectorLabel != null) 'connectorLabel': connectorLabel,
    if (connectorProfileNames != null)
      'connectorProfileNames': connectorProfileNames,
    if (connectorType != null) 'connectorType': connectorType.value,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/describe-connector-profiles',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeConnectorProfilesResponse.fromJson(response);
}