unregisterConnector method

Future<void> unregisterConnector({
  1. required String connectorLabel,
  2. bool? forceDelete,
})

Unregisters the custom connector registered in your account that matches the connector label provided in the request.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException.

Parameter connectorLabel : The label of the connector. The label is unique for each ConnectorRegistration in your Amazon Web Services account.

Parameter forceDelete : Indicates whether Amazon AppFlow should unregister the connector, even if it is currently in use in one or more connector profiles. The default value is false.

Implementation

Future<void> unregisterConnector({
  required String connectorLabel,
  bool? forceDelete,
}) async {
  final $payload = <String, dynamic>{
    'connectorLabel': connectorLabel,
    if (forceDelete != null) 'forceDelete': forceDelete,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/unregister-connector',
    exceptionFnMap: _exceptionFns,
  );
}