updateConnectorProfile method

Future<UpdateConnectorProfileResponse> updateConnectorProfile({
  1. required ConnectionMode connectionMode,
  2. required ConnectorProfileConfig connectorProfileConfig,
  3. required String connectorProfileName,
  4. String? clientToken,
})

Updates a given connector profile associated with your account.

May throw ConflictException. May throw ConnectorAuthenticationException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter connectionMode : Indicates the connection mode and if it is public or private.

Parameter connectorProfileConfig : Defines the connector-specific profile configuration and credentials.

Parameter connectorProfileName : The name of the connector profile and is unique for each ConnectorProfile in the Amazon Web Services account.

Parameter clientToken : The clientToken parameter is an idempotency token. It ensures that your UpdateConnectorProfile request completes only once. You choose the value to pass. For example, if you don't receive a response from your request, you can safely retry the request with the same clientToken parameter value.

If you omit a clientToken value, the Amazon Web Services SDK that you are using inserts a value for you. This way, the SDK can safely retry requests multiple times after a network error. You must provide your own value for other use cases.

If you specify input parameters that differ from your first request, an error occurs. If you use a different value for clientToken, Amazon AppFlow considers it a new call to UpdateConnectorProfile. The token is active for 8 hours.

Implementation

Future<UpdateConnectorProfileResponse> updateConnectorProfile({
  required ConnectionMode connectionMode,
  required ConnectorProfileConfig connectorProfileConfig,
  required String connectorProfileName,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'connectionMode': connectionMode.value,
    'connectorProfileConfig': connectorProfileConfig,
    'connectorProfileName': connectorProfileName,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-connector-profile',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateConnectorProfileResponse.fromJson(response);
}