updateConnectorRegistration method

Future<UpdateConnectorRegistrationResponse> updateConnectorRegistration({
  1. required String connectorLabel,
  2. String? clientToken,
  3. ConnectorProvisioningConfig? connectorProvisioningConfig,
  4. String? description,
})

Updates a custom connector that you've previously registered. This operation updates the connector with one of the following:

  • The latest version of the AWS Lambda function that's assigned to the connector
  • A new AWS Lambda function that you specify

May throw AccessDeniedException. May throw ConflictException. May throw ConnectorAuthenticationException. May throw ConnectorServerException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter connectorLabel : The name of the connector. The name is unique for each connector registration in your AWS account.

Parameter clientToken : The clientToken parameter is an idempotency token. It ensures that your UpdateConnectorRegistration request completes only once. You choose the value to pass. For example, if you don't receive a response from your request, you can safely retry the request with the same clientToken parameter value.

If you omit a clientToken value, the Amazon Web Services SDK that you are using inserts a value for you. This way, the SDK can safely retry requests multiple times after a network error. You must provide your own value for other use cases.

If you specify input parameters that differ from your first request, an error occurs. If you use a different value for clientToken, Amazon AppFlow considers it a new call to UpdateConnectorRegistration. The token is active for 8 hours.

Parameter description : A description about the update that you're applying to the connector.

Implementation

Future<UpdateConnectorRegistrationResponse> updateConnectorRegistration({
  required String connectorLabel,
  String? clientToken,
  ConnectorProvisioningConfig? connectorProvisioningConfig,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    'connectorLabel': connectorLabel,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (connectorProvisioningConfig != null)
      'connectorProvisioningConfig': connectorProvisioningConfig,
    if (description != null) 'description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-connector-registration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateConnectorRegistrationResponse.fromJson(response);
}