importApplicationUsage method

Future<ImportApplicationUsageResult> importApplicationUsage({
  1. required SourceS3Location sourceS3Location,
})

Ingests application usage data from Amazon Simple Storage Service (Amazon S3).

The data must already exist in the S3 location. As part of the action, AWS Application Cost Profiler copies the object from your S3 bucket to an S3 bucket owned by Amazon for processing asynchronously.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter sourceS3Location : Amazon S3 location to import application usage data from.

Implementation

Future<ImportApplicationUsageResult> importApplicationUsage({
  required SourceS3Location sourceS3Location,
}) async {
  final $payload = <String, dynamic>{
    'sourceS3Location': sourceS3Location,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/importApplicationUsage',
    exceptionFnMap: _exceptionFns,
  );
  return ImportApplicationUsageResult.fromJson(response);
}