listReportDefinitions method
Retrieves a list of all reports and their configurations for your AWS account.
The maximum number of reports is one.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token value from a previous call to access the next page of results.
Implementation
Future<ListReportDefinitionsResult> listReportDefinitions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/reportDefinition',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReportDefinitionsResult.fromJson(response);
}