batchDeleteAgents method

Future<BatchDeleteAgentsResponse> batchDeleteAgents({
  1. required List<DeleteAgent> deleteAgents,
})

Deletes one or more agents or collectors as specified by ID. Deleting an agent or collector does not delete the previously discovered data. To delete the data collected, use StartBatchDeleteConfigurationTask.

May throw AuthorizationErrorException. May throw InvalidParameterException. May throw InvalidParameterValueException. May throw ServerInternalErrorException.

Parameter deleteAgents : The list of agents to delete.

Implementation

Future<BatchDeleteAgentsResponse> batchDeleteAgents({
  required List<DeleteAgent> deleteAgents,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSPoseidonService_V2015_11_01.BatchDeleteAgents'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'deleteAgents': deleteAgents,
    },
  );

  return BatchDeleteAgentsResponse.fromJson(jsonResponse.body);
}