describeConfigurations method
Retrieves attributes for a list of configuration item IDs.
- server
- application
- process
- connection
For a complete list of outputs for each asset type, see Using the DescribeConfigurations Action in the Amazon Web Services Application Discovery Service User Guide.
May throw AuthorizationErrorException.
May throw HomeRegionNotSetException.
May throw InvalidParameterException.
May throw InvalidParameterValueException.
May throw ServerInternalErrorException.
Parameter configurationIds :
One or more configuration IDs.
Implementation
Future<DescribeConfigurationsResponse> describeConfigurations({
required List<String> configurationIds,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSPoseidonService_V2015_11_01.DescribeConfigurations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'configurationIds': configurationIds,
},
);
return DescribeConfigurationsResponse.fromJson(jsonResponse.body);
}