exportConfigurations method

Future<ExportConfigurationsResponse> exportConfigurations()

Deprecated. Use StartExportTask instead.

Exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data. Data includes tags and tag associations, processes, connections, servers, and system performance. This API returns an export ID that you can query using the DescribeExportConfigurations API. The system imposes a limit of two configuration exports in six hours.

May throw AuthorizationErrorException. May throw HomeRegionNotSetException. May throw InvalidParameterException. May throw InvalidParameterValueException. May throw OperationNotPermittedException. May throw ServerInternalErrorException.

Implementation

Future<ExportConfigurationsResponse> exportConfigurations() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSPoseidonService_V2015_11_01.ExportConfigurations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return ExportConfigurationsResponse.fromJson(jsonResponse.body);
}