getDiscoverySummary method

Future<GetDiscoverySummaryResponse> getDiscoverySummary()

Retrieves a short summary of discovered assets.

This API operation takes no request parameters and is called as is at the command prompt as shown in the example.

May throw AuthorizationErrorException. May throw HomeRegionNotSetException. May throw InvalidParameterException. May throw InvalidParameterValueException. May throw ServerInternalErrorException.

Implementation

Future<GetDiscoverySummaryResponse> getDiscoverySummary() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSPoseidonService_V2015_11_01.GetDiscoverySummary'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return GetDiscoverySummaryResponse.fromJson(jsonResponse.body);
}