listApplications method
Lists the IDs of the applications that you are monitoring.
May throw InternalServerException.
May throw ValidationException.
Parameter accountId :
The Amazon Web Services account ID for the resource group owner.
Parameter maxResults :
The maximum number of results to return in a single call. To retrieve the
remaining results, make another call with the returned
NextToken value.
Parameter nextToken :
The token to request the next page of results.
Implementation
Future<ListApplicationsResponse> listApplications({
String? accountId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
40,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'EC2WindowsBarleyService.ListApplications'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (accountId != null) 'AccountId': accountId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListApplicationsResponse.fromJson(jsonResponse.body);
}