application_insights_2018_11_25 library

Classes

ApplicationInsights
Amazon CloudWatch Application Insights is a service that helps you detect common problems with your applications. It enables you to pinpoint the source of issues in your applications (built with technologies such as Microsoft IIS, .NET, and Microsoft SQL Server), by providing key insights into detected problems.
AwsClientCredentials
AWS credentials.