ApplicationSignals class
Use CloudWatch Application Signals for comprehensive observability of your cloud-based applications. It enables real-time service health dashboards and helps you track long-term performance trends against your business goals. The application-centric view provides you with unified visibility across your applications, services, and dependencies, so you can proactively monitor and efficiently triage any issues that may arise, ensuring optimal customer experience.
Application Signals provides the following benefits:
- Automatically collect metrics and traces from your applications, and display key metrics such as call volume, availability, latency, faults, and errors.
- Create and monitor service level objectives (SLOs).
- See a map of your application topology that Application Signals automatically discovers, that gives you a visual representation of your applications, dependencies, and their connectivity.
Constructors
- ApplicationSignals({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetServiceLevelObjectiveBudgetReport(
{required List< String> sloIds, required DateTime timestamp}) → Future<BatchGetServiceLevelObjectiveBudgetReportOutput> - Use this operation to retrieve one or more service level objective (SLO) budget reports.
-
batchUpdateExclusionWindows(
{required List< String> sloIds, List<ExclusionWindow> ? addExclusionWindows, List<ExclusionWindow> ? removeExclusionWindows}) → Future<BatchUpdateExclusionWindowsOutput> - Add or remove time window exclusions for one or more Service Level Objectives (SLOs).
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createServiceLevelObjective(
{required String name, bool? autoInvestigationEnabled, List< BurnRateConfiguration> ? burnRateConfigurations, bool? createRecommendedSlo, String? description, Goal? goal, RequestBasedServiceLevelIndicatorConfig? requestBasedSliConfig, ServiceLevelIndicatorConfig? sliConfig, List<Tag> ? tags}) → Future<CreateServiceLevelObjectiveOutput> - Creates a service level objective (SLO), which can help you ensure that your critical business operations are meeting customer expectations. Use SLOs to set and track specific target levels for the reliability and availability of your applications and services. SLOs use service level indicators (SLIs) to calculate whether the application is performing at the level that you want.
-
deleteGroupingConfiguration(
) → Future< void> - Deletes the grouping configuration for this account. This removes all custom grouping attribute definitions that were previously configured.
-
deleteServiceLevelObjective(
{required String id}) → Future< void> - Deletes the specified service level objective.
-
getService(
{required DateTime endTime, required Map< String, String> keyAttributes, required DateTime startTime}) → Future<GetServiceOutput> - Returns information about a service discovered by Application Signals.
-
getServiceLevelObjective(
{required String id}) → Future< GetServiceLevelObjectiveOutput> - Returns information about one SLO created in the account.
-
listAuditFindings(
{required List< AuditTarget> auditTargets, required DateTime endTime, required DateTime startTime, List<String> ? auditors, DetailLevel? detailLevel, int? maxResults, String? nextToken}) → Future<ListAuditFindingsOutput> - Returns a list of audit findings that provide automated analysis of service behavior and root cause analysis. These findings help identify the most significant observations about your services, including performance issues, anomalies, and potential problems. The findings are generated using heuristic algorithms based on established troubleshooting patterns.
-
listEntityEvents(
{required DateTime endTime, required Map< String, String> entity, required DateTime startTime, int? maxResults, String? nextToken}) → Future<ListEntityEventsOutput> - Returns a list of change events for a specific entity, such as deployments, configuration changes, or other state-changing activities. This operation helps track the history of changes that may have affected service performance.
-
listGroupingAttributeDefinitions(
{String? awsAccountId, bool? includeLinkedAccounts, String? nextToken}) → Future< ListGroupingAttributeDefinitionsOutput> - Returns the current grouping configuration for this account, including all custom grouping attribute definitions that have been configured. These definitions determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings.
-
listServiceDependencies(
{required DateTime endTime, required Map< String, String> keyAttributes, required DateTime startTime, int? maxResults, String? nextToken}) → Future<ListServiceDependenciesOutput> - Returns a list of service dependencies of the service that you specify. A dependency is an infrastructure component that an operation of this service connects with. Dependencies can include Amazon Web Services services, Amazon Web Services resources, and third-party services.
-
listServiceDependents(
{required DateTime endTime, required Map< String, String> keyAttributes, required DateTime startTime, int? maxResults, String? nextToken}) → Future<ListServiceDependentsOutput> - Returns the list of dependents that invoked the specified service during the provided time range. Dependents include other services, CloudWatch Synthetics canaries, and clients that are instrumented with CloudWatch RUM app monitors.
-
listServiceLevelObjectiveExclusionWindows(
{required String id, int? maxResults, String? nextToken}) → Future< ListServiceLevelObjectiveExclusionWindowsOutput> - Retrieves all exclusion windows configured for a specific SLO.
-
listServiceLevelObjectives(
{DependencyConfig? dependencyConfig, bool? includeLinkedAccounts, Map< String, String> ? keyAttributes, int? maxResults, MetricSource? metricSource, List<MetricSourceType> ? metricSourceTypes, String? nextToken, String? operationName, String? sloOwnerAwsAccountId}) → Future<ListServiceLevelObjectivesOutput> - Returns a list of SLOs created in this account.
-
listServiceOperations(
{required DateTime endTime, required Map< String, String> keyAttributes, required DateTime startTime, int? maxResults, String? nextToken}) → Future<ListServiceOperationsOutput> - Returns a list of the operations of this service that have been discovered by Application Signals. Only the operations that were invoked during the specified time range are returned.
-
listServices(
{required DateTime endTime, required DateTime startTime, String? awsAccountId, bool? includeLinkedAccounts, int? maxResults, String? nextToken}) → Future< ListServicesOutput> - Returns a list of services that have been discovered by Application Signals. A service represents a minimum logical and transactional unit that completes a business function. Services are discovered through Application Signals instrumentation.
-
listServiceStates(
{required DateTime endTime, required DateTime startTime, List< AttributeFilter> ? attributeFilters, String? awsAccountId, bool? includeLinkedAccounts, int? maxResults, String? nextToken}) → Future<ListServiceStatesOutput> - Returns information about the last deployment and other change states of services. This API provides visibility into recent changes that may have affected service performance, helping with troubleshooting and change correlation.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Displays the tags associated with a CloudWatch resource. Tags can be assigned to service level objectives.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putGroupingConfiguration(
{required List< GroupingAttributeDefinition> groupingAttributeDefinitions}) → Future<PutGroupingConfigurationOutput> - Creates or updates the grouping configuration for this account. This operation allows you to define custom grouping attributes that determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings. These grouping attributes can then be used to organize and filter services in the Application Signals console and APIs.
-
startDiscovery(
) → Future< void> - Enables this Amazon Web Services account to be able to use CloudWatch Application Signals by creating the AWSServiceRoleForCloudWatchApplicationSignals service-linked role. This service- linked role has the following permissions:
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified CloudWatch resource, such as a service level objective.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from the specified resource.
-
updateServiceLevelObjective(
{required String id, bool? autoInvestigationEnabled, List< BurnRateConfiguration> ? burnRateConfigurations, String? description, Goal? goal, RequestBasedServiceLevelIndicatorConfig? requestBasedSliConfig, ServiceLevelIndicatorConfig? sliConfig}) → Future<UpdateServiceLevelObjectiveOutput> - Updates an existing service level objective (SLO). If you omit parameters, the previous values of those parameters are retained.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited