batchGetServiceLevelObjectiveBudgetReport method

Future<BatchGetServiceLevelObjectiveBudgetReportOutput> batchGetServiceLevelObjectiveBudgetReport({
  1. required List<String> sloIds,
  2. required DateTime timestamp,
})

Use this operation to retrieve one or more service level objective (SLO) budget reports.

An error budget is the amount of time or requests in an unhealthy state that your service can accumulate during an interval before your overall SLO budget health is breached and the SLO is considered to be unmet. For example, an SLO with a threshold of 99.95% and a monthly interval translates to an error budget of 21.9 minutes of downtime in a 30-day month.

Budget reports include a health indicator, the attainment value, and remaining budget.

For more information about SLO error budgets, see SLO concepts.

May throw ThrottlingException. May throw ValidationException.

Parameter sloIds : An array containing the IDs of the service level objectives that you want to include in the report.

Parameter timestamp : The date and time that you want the report to be for. It is expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.

Implementation

Future<BatchGetServiceLevelObjectiveBudgetReportOutput>
    batchGetServiceLevelObjectiveBudgetReport({
  required List<String> sloIds,
  required DateTime timestamp,
}) async {
  final $payload = <String, dynamic>{
    'SloIds': sloIds,
    'Timestamp': unixTimestampToJson(timestamp),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/budget-report',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetServiceLevelObjectiveBudgetReportOutput.fromJson(response);
}