batchUpdateExclusionWindows method

Future<BatchUpdateExclusionWindowsOutput> batchUpdateExclusionWindows({
  1. required List<String> sloIds,
  2. List<ExclusionWindow>? addExclusionWindows,
  3. List<ExclusionWindow>? removeExclusionWindows,
})

Add or remove time window exclusions for one or more Service Level Objectives (SLOs).

May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter sloIds : The list of SLO IDs to add or remove exclusion windows from.

Parameter addExclusionWindows : A list of exclusion windows to add to the specified SLOs. You can add up to 10 exclusion windows per SLO.

Parameter removeExclusionWindows : A list of exclusion windows to remove from the specified SLOs. The window configuration must match an existing exclusion window.

Implementation

Future<BatchUpdateExclusionWindowsOutput> batchUpdateExclusionWindows({
  required List<String> sloIds,
  List<ExclusionWindow>? addExclusionWindows,
  List<ExclusionWindow>? removeExclusionWindows,
}) async {
  final $payload = <String, dynamic>{
    'SloIds': sloIds,
    if (addExclusionWindows != null)
      'AddExclusionWindows': addExclusionWindows,
    if (removeExclusionWindows != null)
      'RemoveExclusionWindows': removeExclusionWindows,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/exclusion-windows',
    exceptionFnMap: _exceptionFns,
  );
  return BatchUpdateExclusionWindowsOutput.fromJson(response);
}