putGroupingConfiguration method
Future<PutGroupingConfigurationOutput>
putGroupingConfiguration({
- required List<
GroupingAttributeDefinition> groupingAttributeDefinitions,
Creates or updates the grouping configuration for this account. This operation allows you to define custom grouping attributes that determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings. These grouping attributes can then be used to organize and filter services in the Application Signals console and APIs.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter groupingAttributeDefinitions :
An array of grouping attribute definitions that specify how services
should be grouped. Each definition includes a friendly name, source keys
to derive the grouping value from, and an optional default value.
Implementation
Future<PutGroupingConfigurationOutput> putGroupingConfiguration({
required List<GroupingAttributeDefinition> groupingAttributeDefinitions,
}) async {
final $payload = <String, dynamic>{
'GroupingAttributeDefinitions': groupingAttributeDefinitions,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/grouping-configuration',
exceptionFnMap: _exceptionFns,
);
return PutGroupingConfigurationOutput.fromJson(response);
}