tagResource method
Assigns one or more tags (key-value pairs) to the specified CloudWatch resource, such as a service level objective.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the TagResource action with an alarm that already
has tags. If you specify a new tag key for the alarm, this tag is appended
to the list of tags associated with the alarm. If you specify a tag key
that is already associated with the alarm, the new tag value that you
specify replaces the previous value for that tag.
You can associate as many as 50 tags with a CloudWatch resource.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the CloudWatch resource that you want to
set tags for.
The ARN format of an Application Signals SLO is
arn:aws:cloudwatch:Region:account-id:slo:slo-name
For more information about ARN format, see Resource Types Defined by Amazon CloudWatch in the Amazon Web Services General Reference.
Parameter tags :
The list of key-value pairs to associate with the alarm.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final $payload = <String, dynamic>{
'ResourceArn': resourceArn,
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tag-resource',
exceptionFnMap: _exceptionFns,
);
}