ArcRegionSwitch class

Amazon Application Recovery Controller (ARC) Region switch helps you to quickly and reliably shift traffic away from an impaired Amazon Web Services Region to a healthy Region. With Region switch, you can create plans that define the steps to shift traffic for your application from one Amazon Web Services Region to another.

Region switch provides a structured approach to multi-Region failover, helping you to meet your recovery time objectives (RTOs) and maintain business continuity during regional disruptions.

For more information, see Region switch in ARC in the Amazon Application Recovery Controller User Guide.

Constructors

ArcRegionSwitch({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approvePlanExecutionStep({required Approval approval, required String executionId, required String planArn, required String stepName, String? comment}) Future<void>
Approves a step in a plan execution that requires manual approval. When you create a plan, you can include approval steps that require manual intervention before the execution can proceed. This operation allows you to provide that approval.
cancelPlanExecution({required String executionId, required String planArn, String? comment}) Future<void>
Cancels an in-progress plan execution. This operation stops the execution of the plan and prevents any further steps from being processed.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createPlan({required String executionRole, required String name, required RecoveryApproach recoveryApproach, required List<String> regions, required List<Workflow> workflows, Map<String, AssociatedAlarm>? associatedAlarms, String? description, String? primaryRegion, int? recoveryTimeObjectiveMinutes, ReportConfiguration? reportConfiguration, Map<String, String>? tags, List<Trigger>? triggers}) Future<CreatePlanResponse>
Creates a new Region switch plan. A plan defines the steps required to shift traffic from one Amazon Web Services Region to another.
deletePlan({required String arn}) Future<void>
Deletes a Region switch plan. You must specify the ARN of the plan to delete.
getPlan({required String arn}) Future<GetPlanResponse>
Retrieves detailed information about a Region switch plan. You must specify the ARN of the plan.
getPlanEvaluationStatus({required String planArn, int? maxResults, String? nextToken}) Future<GetPlanEvaluationStatusResponse>
Retrieves the evaluation status of a Region switch plan. The evaluation status provides information about the last time the plan was evaluated and any warnings or issues detected.
getPlanExecution({required String executionId, required String planArn, int? maxResults, String? nextToken}) Future<GetPlanExecutionResponse>
Retrieves detailed information about a specific plan execution. You must specify the plan ARN and execution ID.
getPlanInRegion({required String arn}) Future<GetPlanInRegionResponse>
Retrieves information about a Region switch plan in a specific Amazon Web Services Region. This operation is useful for getting Region-specific information about a plan.
listPlanExecutionEvents({required String executionId, required String planArn, int? maxResults, String? name, String? nextToken}) Future<ListPlanExecutionEventsResponse>
Lists the events that occurred during a plan execution. These events provide a detailed timeline of the execution process.
listPlanExecutions({required String planArn, int? maxResults, String? nextToken, ExecutionState? state}) Future<ListPlanExecutionsResponse>
Lists the executions of a Region switch plan. This operation returns information about both current and historical executions.
listPlans({int? maxResults, String? nextToken}) Future<ListPlansResponse>
Lists all Region switch plans in your Amazon Web Services account.
listPlansInRegion({int? maxResults, String? nextToken}) Future<ListPlansInRegionResponse>
Lists all Region switch plans in your Amazon Web Services account that are available in the current Amazon Web Services Region.
listRoute53HealthChecks({required String arn, String? hostedZoneId, int? maxResults, String? nextToken, String? recordName}) Future<ListRoute53HealthChecksResponse>
List the Amazon Route 53 health checks.
listRoute53HealthChecksInRegion({required String arn, String? hostedZoneId, int? maxResults, String? nextToken, String? recordName}) Future<ListRoute53HealthChecksInRegionResponse>
List the Amazon Route 53 health checks in a specific Amazon Web Services Region.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Lists the tags attached to a Region switch resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startPlanExecution({required ExecutionAction action, required String planArn, required String targetRegion, String? comment, String? latestVersion, ExecutionMode? mode, String? recoveryExecutionId}) Future<StartPlanExecutionResponse>
Starts the execution of a Region switch plan. You can execute a plan in either graceful or ungraceful mode.
tagResource({required String arn, required Map<String, String> tags}) Future<void>
Adds or updates tags for a Region switch resource. You can assign metadata to your resources in the form of tags, which are key-value pairs.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, required List<String> resourceTagKeys}) Future<void>
Removes tags from a Region switch resource.
updatePlan({required String arn, required String executionRole, required List<Workflow> workflows, Map<String, AssociatedAlarm>? associatedAlarms, String? description, int? recoveryTimeObjectiveMinutes, ReportConfiguration? reportConfiguration, List<Trigger>? triggers}) Future<UpdatePlanResponse>
Updates an existing Region switch plan. You can modify the plan's description, workflows, execution role, recovery time objective, associated alarms, and triggers.
updatePlanExecution({required UpdatePlanExecutionAction action, required String executionId, required String planArn, String? comment}) Future<void>
Updates an in-progress plan execution. This operation allows you to modify certain aspects of the execution, such as adding a comment or changing the action.
updatePlanExecutionStep({required UpdatePlanExecutionStepAction actionToTake, required String comment, required String executionId, required String planArn, required String stepName}) Future<void>
Updates a specific step in an in-progress plan execution. This operation allows you to modify the step's comment or action.

Operators

operator ==(Object other) bool
The equality operator.
inherited