getPlanEvaluationStatus method

Future<GetPlanEvaluationStatusResponse> getPlanEvaluationStatus({
  1. required String planArn,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves the evaluation status of a Region switch plan. The evaluation status provides information about the last time the plan was evaluated and any warnings or issues detected.

May throw AccessDeniedException. May throw ResourceNotFoundException.

Parameter planArn : The Amazon Resource Name (ARN) of the Region switch plan to retrieve evaluation status for.

Parameter maxResults : The number of objects that you want to return with this call.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a nextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's nextToken response to request the next page of results.

Implementation

Future<GetPlanEvaluationStatusResponse> getPlanEvaluationStatus({
  required String planArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'ArcRegionSwitch.GetPlanEvaluationStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'planArn': planArn,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return GetPlanEvaluationStatusResponse.fromJson(jsonResponse.body);
}