listPlanExecutionEvents method
Lists the events that occurred during a plan execution. These events provide a detailed timeline of the execution process.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
Parameter executionId :
The execution identifier of a plan execution.
Parameter planArn :
The Amazon Resource Name (ARN) of the plan.
Parameter maxResults :
The number of objects that you want to return with this call.
Parameter name :
The name of the plan execution event.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a nextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's nextToken response
to request the next page of results.
Implementation
Future<ListPlanExecutionEventsResponse> listPlanExecutionEvents({
required String executionId,
required String planArn,
int? maxResults,
String? name,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ArcRegionSwitch.ListPlanExecutionEvents'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'executionId': executionId,
'planArn': planArn,
if (maxResults != null) 'maxResults': maxResults,
if (name != null) 'name': name,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListPlanExecutionEventsResponse.fromJson(jsonResponse.body);
}