updatePlanExecutionStep method

Future<void> updatePlanExecutionStep({
  1. required UpdatePlanExecutionStepAction actionToTake,
  2. required String comment,
  3. required String executionId,
  4. required String planArn,
  5. required String stepName,
})

Updates a specific step in an in-progress plan execution. This operation allows you to modify the step's comment or action.

May throw AccessDeniedException. May throw ResourceNotFoundException.

Parameter actionToTake : The updated action to take for the step. This can be used to skip or retry a step.

Parameter comment : An optional comment about the plan execution.

Parameter executionId : The unique identifier of the plan execution containing the step to update.

Parameter planArn : The Amazon Resource Name (ARN) of the plan containing the execution step to update.

Parameter stepName : The name of the execution step to update.

Implementation

Future<void> updatePlanExecutionStep({
  required UpdatePlanExecutionStepAction actionToTake,
  required String comment,
  required String executionId,
  required String planArn,
  required String stepName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'ArcRegionSwitch.UpdatePlanExecutionStep'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'actionToTake': actionToTake.value,
      'comment': comment,
      'executionId': executionId,
      'planArn': planArn,
      'stepName': stepName,
    },
  );
}