deletePracticeRunConfiguration method

Future<DeletePracticeRunConfigurationResponse> deletePracticeRunConfiguration({
  1. required String resourceIdentifier,
})

Deletes the practice run configuration for a resource. Before you can delete a practice run configuration for a resource., you must disable zonal autoshift for the resource. Practice runs must be configured for zonal autoshift to be enabled.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceIdentifier : The identifier for the resource that you want to delete the practice run configuration for. The identifier is the Amazon Resource Name (ARN) for the resource.

Implementation

Future<DeletePracticeRunConfigurationResponse>
    deletePracticeRunConfiguration({
  required String resourceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/configuration/${Uri.encodeComponent(resourceIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeletePracticeRunConfigurationResponse.fromJson(response);
}