getAutoshiftObserverNotificationStatus method

Future<GetAutoshiftObserverNotificationStatusResponse> getAutoshiftObserverNotificationStatus()

Returns the status of the autoshift observer notification. Autoshift observer notifications notify you through Amazon EventBridge when there is an autoshift event for zonal autoshift. The status can be ENABLED or DISABLED. When ENABLED, a notification is sent when an autoshift is triggered. When DISABLED, notifications are not sent.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException.

Implementation

Future<GetAutoshiftObserverNotificationStatusResponse>
    getAutoshiftObserverNotificationStatus() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/autoshift-observer-notification',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutoshiftObserverNotificationStatusResponse.fromJson(response);
}