getManagedResource method

Future<GetManagedResourceResponse> getManagedResource({
  1. required String resourceIdentifier,
})

Get information about a resource that's been registered for zonal shifts with Amazon Application Recovery Controller in this Amazon Web Services Region. Resources that are registered for zonal shifts are managed resources in ARC. You can start zonal shifts and configure zonal autoshift for managed resources.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceIdentifier : The identifier for the resource that Amazon Web Services shifts traffic for. The identifier is the Amazon Resource Name (ARN) for the resource.

Amazon Application Recovery Controller currently supports enabling the following resources for zonal shift and zonal autoshift:

Implementation

Future<GetManagedResourceResponse> getManagedResource({
  required String resourceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/managedresources/${Uri.encodeComponent(resourceIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetManagedResourceResponse.fromJson(response);
}