listZonalShifts method

Future<ListZonalShiftsResponse> listZonalShifts({
  1. int? maxResults,
  2. String? nextToken,
  3. String? resourceIdentifier,
  4. ZonalShiftStatus? status,
})

Lists all active and completed zonal shifts in Amazon Application Recovery Controller in your Amazon Web Services account in this Amazon Web Services Region. ListZonalShifts returns customer-initiated zonal shifts, as well as practice run zonal shifts that ARC started on your behalf for zonal autoshift.

For more information about listing autoshifts, see ">ListAutoshifts.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The number of objects that you want to return with this call.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a nextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's nextToken response to request the next page of results.

Parameter resourceIdentifier : The identifier for the resource that you want to list zonal shifts for. The identifier is the Amazon Resource Name (ARN) for the resource.

Parameter status : A status for a zonal shift.

The Status for a zonal shift can have one of the following values:

  • ACTIVE: The zonal shift has been started and is active.
  • EXPIRED: The zonal shift has expired (the expiry time was exceeded).
  • CANCELED: The zonal shift was canceled.

Implementation

Future<ListZonalShiftsResponse> listZonalShifts({
  int? maxResults,
  String? nextToken,
  String? resourceIdentifier,
  ZonalShiftStatus? status,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (resourceIdentifier != null)
      'resourceIdentifier': [resourceIdentifier],
    if (status != null) 'status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/zonalshifts',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListZonalShiftsResponse.fromJson(response);
}