startPracticeRun method
Start an on-demand practice run zonal shift in Amazon Application Recovery Controller. With zonal autoshift enabled, you can start an on-demand practice run to verify preparedness at any time. Amazon Web Services also runs automated practice runs about weekly when you have enabled zonal autoshift.
For more information, see Considerations when you configure zonal autoshift in the Amazon Application Recovery Controller Developer Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter awayFrom :
The Availability Zone (for example, use1-az1) that traffic is
shifted away from for the resource that you specify for the practice run.
Parameter comment :
The initial comment that you enter about the practice run. Be aware that
this comment can be overwritten by Amazon Web Services if the automatic
check for balanced capacity fails. For more information, see
Capacity checks for practice runs in the Amazon Application Recovery
Controller Developer Guide.
Parameter resourceIdentifier :
The identifier for the resource that you want to start a practice run
zonal shift for. The identifier is the Amazon Resource Name (ARN) for the
resource.
Implementation
Future<StartPracticeRunResponse> startPracticeRun({
required String awayFrom,
required String comment,
required String resourceIdentifier,
}) async {
final $payload = <String, dynamic>{
'awayFrom': awayFrom,
'comment': comment,
'resourceIdentifier': resourceIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/practiceruns',
exceptionFnMap: _exceptionFns,
);
return StartPracticeRunResponse.fromJson(response);
}