startZonalShift method
You start a zonal shift to temporarily move load balancer traffic away from an Availability Zone in an Amazon Web Services Region, to help your application recover immediately, for example, from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone. You can start a zonal shift in ARC only for managed resources in your Amazon Web Services account in an Amazon Web Services Region. Resources are automatically registered with ARC by Amazon Web Services services.
Amazon Application Recovery Controller currently supports enabling the following resources for zonal shift and zonal autoshift:
- Amazon EC2 Auto Scaling groups
- Amazon Elastic Kubernetes Service
- Application Load Balancer
- Network Load Balancer
For more information, see Zonal shift in the Amazon Application Recovery Controller Developer Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter awayFrom :
The Availability Zone (for example, use1-az1) that traffic is
moved away from for a resource when you start a zonal shift. Until the
zonal shift expires or you cancel it, traffic for the resource is instead
moved to other Availability Zones in the Amazon Web Services Region.
Parameter comment :
A comment that you enter about the zonal shift. Only the latest comment is
retained; no comment history is maintained. A new comment overwrites any
existing comment string.
Parameter expiresIn :
The length of time that you want a zonal shift to be active, which ARC
converts to an expiry time (expiration time). Zonal shifts are temporary.
You can set a zonal shift to be active initially for up to three days (72
hours).
If you want to still keep traffic away from an Availability Zone, you can update the zonal shift and set a new expiration. You can also cancel a zonal shift, before it expires, for example, if you're ready to restore traffic to the Availability Zone.
To set a length of time for a zonal shift to be active, specify a whole number, and then one of the following, with no space:
- A lowercase letter m: To specify that the value is in minutes.
- A lowercase letter h: To specify that the value is in hours.
20h means the zonal shift expires in 20 hours.
120m means the zonal shift expires in 120 minutes (2 hours).
Parameter resourceIdentifier :
The identifier for the resource that Amazon Web Services shifts traffic
for. The identifier is the Amazon Resource Name (ARN) for the resource.
Amazon Application Recovery Controller currently supports enabling the following resources for zonal shift and zonal autoshift:
Implementation
Future<ZonalShift> startZonalShift({
required String awayFrom,
required String comment,
required String expiresIn,
required String resourceIdentifier,
}) async {
final $payload = <String, dynamic>{
'awayFrom': awayFrom,
'comment': comment,
'expiresIn': expiresIn,
'resourceIdentifier': resourceIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/zonalshifts',
exceptionFnMap: _exceptionFns,
);
return ZonalShift.fromJson(response);
}