updateAutoshiftObserverNotificationStatus method
- required AutoshiftObserverNotificationStatus status,
Update the status of autoshift observer notification. Autoshift observer notification enables you to be notified, through Amazon EventBridge, when there is an autoshift event for zonal autoshift.
If the status is ENABLED, ARC includes all autoshift events
when you use the EventBridge pattern Autoshift In Progress.
When the status is DISABLED, ARC includes only autoshift
events for autoshifts when one or more of your resources is included in
the autoshift.
For more information, see Notifications for practice runs and autoshifts in the Amazon Application Recovery Controller Developer Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter status :
The status to set for autoshift observer notification. If the status is
ENABLED, ARC includes all autoshift events when you use the
Amazon EventBridge pattern Autoshift In Progress. When the
status is DISABLED, ARC includes only autoshift events for
autoshifts when one or more of your resources is included in the
autoshift.
Implementation
Future<UpdateAutoshiftObserverNotificationStatusResponse>
updateAutoshiftObserverNotificationStatus({
required AutoshiftObserverNotificationStatus status,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/autoshift-observer-notification',
exceptionFnMap: _exceptionFns,
);
return UpdateAutoshiftObserverNotificationStatusResponse.fromJson(response);
}