Artifact class

This reference provides descriptions of the low-level AWS Artifact Service API.

Constructors

Artifact({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getAccountSettings() Future<GetAccountSettingsResponse>
Get the account settings for Artifact.
getReport({required String reportId, required String termToken, int? reportVersion}) Future<GetReportResponse>
Get the content for a single report.
getReportMetadata({required String reportId, int? reportVersion}) Future<GetReportMetadataResponse>
Get the metadata for a single report.
getTermForReport({required String reportId, int? reportVersion}) Future<GetTermForReportResponse>
Get the Term content associated with a single report.
listCustomerAgreements({int? maxResults, String? nextToken}) Future<ListCustomerAgreementsResponse>
List active customer-agreements applicable to calling identity.
listReports({int? maxResults, String? nextToken}) Future<ListReportsResponse>
List available reports.
listReportVersions({required String reportId, int? maxResults, String? nextToken}) Future<ListReportVersionsResponse>
List available report versions for a given report.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAccountSettings({NotificationSubscriptionStatus? notificationSubscriptionStatus}) Future<PutAccountSettingsResponse>
Put the account settings for Artifact.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited