listCustomerAgreements method
List active customer-agreements applicable to calling identity.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
Maximum number of resources to return in the paginated response.
Parameter nextToken :
Pagination token to request the next page of resources.
Implementation
Future<ListCustomerAgreementsResponse> listCustomerAgreements({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
300,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/customer-agreement/list',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCustomerAgreementsResponse.fromJson(response);
}