listReports method

Future<ListReportsResponse> listReports({
  1. int? maxResults,
  2. String? nextToken,
})

List available reports.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : Maximum number of resources to return in the paginated response.

Parameter nextToken : Pagination token to request the next page of resources.

Implementation

Future<ListReportsResponse> listReports({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    300,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/report/list',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListReportsResponse.fromJson(response);
}