createDataCatalog method
Creates (registers) a data catalog with the specified name and properties. Catalogs created are visible to all users of the same Amazon Web Services account.
For a FEDERATED catalog, this API operation creates the
following resources.
-
CFN Stack Name with a maximum length of 128 characters and prefix
athenafederatedcatalog-CATALOG_NAME_SANITIZEDwith length 23 characters. -
Lambda Function Name with a maximum length of 64 characters and prefix
athenafederatedcatalog_CATALOG_NAME_SANITIZEDwith length 23 characters. -
Glue Connection Name with a maximum length of 255 characters and a prefix
athenafederatedcatalog_CATALOG_NAME_SANITIZEDwith length 23 characters.
May throw InternalServerException.
May throw InvalidRequestException.
Parameter name :
The name of the data catalog to create. The catalog name must be unique
for the Amazon Web Services account and can use a maximum of 127
alphanumeric, underscore, at sign, or hyphen characters. The remainder of
the length constraint of 256 is reserved for use by Athena.
For FEDERATED type the catalog name has following
considerations and limits:
-
The catalog name allows special characters such as
_ , @ , \ , -. These characters are replaced with a hyphen (-) when creating the CFN Stack Name and with an underscore (_) when creating the Lambda Function and Glue Connection Name. -
The catalog name has a theoretical limit of 128 characters. However, since
we use it to create other resources that allow less characters and we
prepend a prefix to it, the actual catalog name limit for
FEDERATEDcatalog is 64 - 23 = 41 characters.
Parameter type :
The type of data catalog to create: LAMBDA for a federated
catalog, GLUE for an Glue Data Catalog, and HIVE
for an external Apache Hive metastore. FEDERATED is a
federated catalog for which Athena creates the connection and the Lambda
function for you based on the parameters that you pass.
For FEDERATED type, we do not support IAM identity center.
Parameter description :
A description of the data catalog to be created.
Parameter parameters :
Specifies the Lambda function or functions to use for creating the data
catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for
reading the actual data, use the following syntax. Both parameters are
required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and
data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
If you have one Lambda function that processes metadata and another for
reading the actual data, use the following syntax. Both parameters are
required.
-
The
GLUEtype takes a catalog ID parameter and is required. Thecatalog_idis the account ID of the Amazon Web Services account to which the Glue Data Catalog belongs.catalog-id=catalog_id-
The
GLUEdata catalog type also applies to the defaultAwsDataCatalogthat already exists in your account, of which you can have only one and cannot modify.
-
The
-
The
FEDERATEDdata catalog type uses one of the following parameters, but not both. Useconnection-arnfor an existing Glue connection. Useconnection-typeandconnection-propertiesto specify the configuration setting for a new connection.-
connection-arn: -
lambda-role-arn(optional): The execution role to use for the Lambda function. If not provided, one is created. -
connection-type:MYSQL|REDSHIFT|...., connection-properties:""For
<json_string>, use escaped JSON text, as in the following example."{"spill_bucket":"my_spill","spill_prefix":"athena-spill","host":"abc12345.snowflakecomputing.com","port":"1234","warehouse":"DEV_WH","database":"TEST","schema":"PUBLIC","SecretArn":"arn:aws:secretsmanager:ap-south-1:111122223333:secret:snowflake-XHb67j"}"
-
Parameter tags :
A list of comma separated tags to add to the data catalog that is created.
All the resources that are created by the CreateDataCatalog
API operation with FEDERATED type will have the tag
federated_athena_datacatalog="true". This includes the CFN
Stack, Glue Connection, Athena DataCatalog, and all the resources created
as part of the CFN Stack (Lambda Function, IAM policies/roles).
Implementation
Future<CreateDataCatalogOutput> createDataCatalog({
required String name,
required DataCatalogType type,
String? description,
Map<String, String>? parameters,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonAthena.CreateDataCatalog'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'Type': type.value,
if (description != null) 'Description': description,
if (parameters != null) 'Parameters': parameters,
if (tags != null) 'Tags': tags,
},
);
return CreateDataCatalogOutput.fromJson(jsonResponse.body);
}