deleteCapacityReservation method

Future<void> deleteCapacityReservation({
  1. required String name,
})

Deletes a cancelled capacity reservation. A reservation must be cancelled before it can be deleted. A deleted reservation is immediately removed from your account and can no longer be referenced, including by its ARN. A deleted reservation cannot be called by GetCapacityReservation, and deleted reservations do not appear in the output of ListCapacityReservations.

May throw InternalServerException. May throw InvalidRequestException.

Parameter name : The name of the capacity reservation to delete.

Implementation

Future<void> deleteCapacityReservation({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.DeleteCapacityReservation'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}