deleteNamedQuery method

Future<void> deleteNamedQuery({
  1. String? namedQueryId,
})

Deletes the named query if you have access to the workgroup in which the query was saved.

May throw InternalServerException. May throw InvalidRequestException.

Parameter namedQueryId : The unique ID of the query to delete.

Implementation

Future<void> deleteNamedQuery({
  String? namedQueryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.DeleteNamedQuery'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'NamedQueryId': namedQueryId ?? _s.generateIdempotencyToken(),
    },
  );
}