deletePreparedStatement method

Future<void> deletePreparedStatement({
  1. required String statementName,
  2. required String workGroup,
})

Deletes the prepared statement with the specified name from the specified workgroup.

May throw InternalServerException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter statementName : The name of the prepared statement to delete.

Parameter workGroup : The workgroup to which the statement to be deleted belongs.

Implementation

Future<void> deletePreparedStatement({
  required String statementName,
  required String workGroup,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.DeletePreparedStatement'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'StatementName': statementName,
      'WorkGroup': workGroup,
    },
  );
}