listDataCatalogs method

Future<ListDataCatalogsOutput> listDataCatalogs({
  1. int? maxResults,
  2. String? nextToken,
  3. String? workGroup,
})

Lists the data catalogs in the current Amazon Web Services account.

May throw InternalServerException. May throw InvalidRequestException.

Parameter maxResults : Specifies the maximum number of data catalogs to return.

Parameter nextToken : A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

Parameter workGroup : The name of the workgroup. Required if making an IAM Identity Center request.

Implementation

Future<ListDataCatalogsOutput> listDataCatalogs({
  int? maxResults,
  String? nextToken,
  String? workGroup,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    2,
    50,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.ListDataCatalogs'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (workGroup != null) 'WorkGroup': workGroup,
    },
  );

  return ListDataCatalogsOutput.fromJson(jsonResponse.body);
}