listTableMetadata method

Future<ListTableMetadataOutput> listTableMetadata({
  1. required String catalogName,
  2. required String databaseName,
  3. String? expression,
  4. int? maxResults,
  5. String? nextToken,
  6. String? workGroup,
})

Lists the metadata for the tables in the specified data catalog database.

May throw InternalServerException. May throw InvalidRequestException. May throw MetadataException.

Parameter catalogName : The name of the data catalog for which table metadata should be returned.

Parameter databaseName : The name of the database for which table metadata should be returned.

Parameter expression : A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.

Parameter maxResults : Specifies the maximum number of results to return.

Parameter nextToken : A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

Parameter workGroup : The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.

Implementation

Future<ListTableMetadataOutput> listTableMetadata({
  required String catalogName,
  required String databaseName,
  String? expression,
  int? maxResults,
  String? nextToken,
  String? workGroup,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.ListTableMetadata'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CatalogName': catalogName,
      'DatabaseName': databaseName,
      if (expression != null) 'Expression': expression,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (workGroup != null) 'WorkGroup': workGroup,
    },
  );

  return ListTableMetadataOutput.fromJson(jsonResponse.body);
}