terminateSession method

Future<TerminateSessionResponse> terminateSession({
  1. required String sessionId,
})

Terminates an active session. A TerminateSession call on a session that is already inactive (for example, in a FAILED, TERMINATED or TERMINATING state) succeeds but has no effect. Calculations running in the session when TerminateSession is called are forcefully stopped, but may display as FAILED instead of STOPPED.

May throw InternalServerException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter sessionId : The session ID.

Implementation

Future<TerminateSessionResponse> terminateSession({
  required String sessionId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.TerminateSession'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'SessionId': sessionId,
    },
  );

  return TerminateSessionResponse.fromJson(jsonResponse.body);
}