untagResource method
Removes one or more tags from an Athena resource.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter resourceARN :
Specifies the ARN of the resource from which tags are to be removed.
Parameter tagKeys :
A comma-separated list of one or more tag keys whose tags are to be
removed from the specified resource.
Implementation
Future<void> untagResource({
required String resourceARN,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonAthena.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'TagKeys': tagKeys,
},
);
}