AuditManager class

Welcome to the Audit Manager API reference. This guide is for developers who need detailed information about the Audit Manager API operations, data types, and errors.

Audit Manager is a service that provides automated evidence collection so that you can continually audit your Amazon Web Services usage. You can use it to assess the effectiveness of your controls, manage risk, and simplify compliance.

Audit Manager provides prebuilt frameworks that structure and automate assessments for a given compliance standard. Frameworks include a prebuilt collection of controls with descriptions and testing procedures. These controls are grouped according to the requirements of the specified compliance standard or regulation. You can also customize frameworks and controls to support internal audits with specific requirements.

Use the following links to get started with the Audit Manager API:

  • Actions: An alphabetical list of all Audit Manager API operations.
  • Data types: An alphabetical list of all Audit Manager data types.
  • Common parameters: Parameters that all operations can use.
  • Common errors: Client and server errors that all operations can return.
If you're new to Audit Manager, we recommend that you review the Audit Manager User Guide.

Constructors

AuditManager({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateAssessmentReportEvidenceFolder({required String assessmentId, required String evidenceFolderId}) Future<void>
Associates an evidence folder to an assessment report in an Audit Manager assessment.
batchAssociateAssessmentReportEvidence({required String assessmentId, required String evidenceFolderId, required List<String> evidenceIds}) Future<BatchAssociateAssessmentReportEvidenceResponse>
Associates a list of evidence to an assessment report in an Audit Manager assessment.
batchCreateDelegationByAssessment({required String assessmentId, required List<CreateDelegationRequest> createDelegationRequests}) Future<BatchCreateDelegationByAssessmentResponse>
Creates a batch of delegations for an assessment in Audit Manager.
batchDeleteDelegationByAssessment({required String assessmentId, required List<String> delegationIds}) Future<BatchDeleteDelegationByAssessmentResponse>
Deletes a batch of delegations for an assessment in Audit Manager.
batchDisassociateAssessmentReportEvidence({required String assessmentId, required String evidenceFolderId, required List<String> evidenceIds}) Future<BatchDisassociateAssessmentReportEvidenceResponse>
Disassociates a list of evidence from an assessment report in Audit Manager.
batchImportEvidenceToAssessmentControl({required String assessmentId, required String controlId, required String controlSetId, required List<ManualEvidence> manualEvidence}) Future<BatchImportEvidenceToAssessmentControlResponse>
Adds one or more pieces of evidence to a control in an Audit Manager assessment.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAssessment({required AssessmentReportsDestination assessmentReportsDestination, required String frameworkId, required String name, required List<Role> roles, required Scope scope, String? description, Map<String, String>? tags}) Future<CreateAssessmentResponse>
Creates an assessment in Audit Manager.
createAssessmentFramework({required List<CreateAssessmentFrameworkControlSet> controlSets, required String name, String? complianceType, String? description, Map<String, String>? tags}) Future<CreateAssessmentFrameworkResponse>
Creates a custom framework in Audit Manager.
createAssessmentReport({required String assessmentId, required String name, String? description, String? queryStatement}) Future<CreateAssessmentReportResponse>
Creates an assessment report for the specified assessment.
createControl({required List<CreateControlMappingSource> controlMappingSources, required String name, String? actionPlanInstructions, String? actionPlanTitle, String? description, Map<String, String>? tags, String? testingInformation}) Future<CreateControlResponse>
Creates a new custom control in Audit Manager.
deleteAssessment({required String assessmentId}) Future<void>
Deletes an assessment in Audit Manager.
deleteAssessmentFramework({required String frameworkId}) Future<void>
Deletes a custom framework in Audit Manager.
deleteAssessmentFrameworkShare({required String requestId, required ShareRequestType requestType}) Future<void>
Deletes a share request for a custom framework in Audit Manager.
deleteAssessmentReport({required String assessmentId, required String assessmentReportId}) Future<void>
Deletes an assessment report in Audit Manager.
deleteControl({required String controlId}) Future<void>
Deletes a custom control in Audit Manager.
deregisterAccount() Future<DeregisterAccountResponse>
Deregisters an account in Audit Manager.
deregisterOrganizationAdminAccount({String? adminAccountId}) Future<void>
Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager.
disassociateAssessmentReportEvidenceFolder({required String assessmentId, required String evidenceFolderId}) Future<void>
Disassociates an evidence folder from the specified assessment report in Audit Manager.
getAccountStatus() Future<GetAccountStatusResponse>
Gets the registration status of an account in Audit Manager.
getAssessment({required String assessmentId}) Future<GetAssessmentResponse>
Gets information about a specified assessment.
getAssessmentFramework({required String frameworkId}) Future<GetAssessmentFrameworkResponse>
Gets information about a specified framework.
getAssessmentReportUrl({required String assessmentId, required String assessmentReportId}) Future<GetAssessmentReportUrlResponse>
Gets the URL of an assessment report in Audit Manager.
getChangeLogs({required String assessmentId, String? controlId, String? controlSetId, int? maxResults, String? nextToken}) Future<GetChangeLogsResponse>
Gets a list of changelogs from Audit Manager.
getControl({required String controlId}) Future<GetControlResponse>
Gets information about a specified control.
getDelegations({int? maxResults, String? nextToken}) Future<GetDelegationsResponse>
Gets a list of delegations from an audit owner to a delegate.
getEvidence({required String assessmentId, required String controlSetId, required String evidenceFolderId, required String evidenceId}) Future<GetEvidenceResponse>
Gets information about a specified evidence item.
getEvidenceByEvidenceFolder({required String assessmentId, required String controlSetId, required String evidenceFolderId, int? maxResults, String? nextToken}) Future<GetEvidenceByEvidenceFolderResponse>
Gets all evidence from a specified evidence folder in Audit Manager.
getEvidenceFileUploadUrl({required String fileName}) Future<GetEvidenceFileUploadUrlResponse>
Creates a presigned Amazon S3 URL that can be used to upload a file as manual evidence. For instructions on how to use this operation, see Upload a file from your browser in the Audit Manager User Guide.
getEvidenceFolder({required String assessmentId, required String controlSetId, required String evidenceFolderId}) Future<GetEvidenceFolderResponse>
Gets an evidence folder from a specified assessment in Audit Manager.
getEvidenceFoldersByAssessment({required String assessmentId, int? maxResults, String? nextToken}) Future<GetEvidenceFoldersByAssessmentResponse>
Gets the evidence folders from a specified assessment in Audit Manager.
getEvidenceFoldersByAssessmentControl({required String assessmentId, required String controlId, required String controlSetId, int? maxResults, String? nextToken}) Future<GetEvidenceFoldersByAssessmentControlResponse>
Gets a list of evidence folders that are associated with a specified control in an Audit Manager assessment.
getInsights() Future<GetInsightsResponse>
Gets the latest analytics data for all your current active assessments.
getInsightsByAssessment({required String assessmentId}) Future<GetInsightsByAssessmentResponse>
Gets the latest analytics data for a specific active assessment.
getOrganizationAdminAccount() Future<GetOrganizationAdminAccountResponse>
Gets the name of the delegated Amazon Web Services administrator account for a specified organization.
getServicesInScope() Future<GetServicesInScopeResponse>
Gets a list of the Amazon Web Services services from which Audit Manager can collect evidence.
getSettings({required SettingAttribute attribute}) Future<GetSettingsResponse>
Gets the settings for a specified Amazon Web Services account.
listAssessmentControlInsightsByControlDomain({required String assessmentId, required String controlDomainId, int? maxResults, String? nextToken}) Future<ListAssessmentControlInsightsByControlDomainResponse>
Lists the latest analytics data for controls within a specific control domain and a specific active assessment.
listAssessmentFrameworks({required FrameworkType frameworkType, int? maxResults, String? nextToken}) Future<ListAssessmentFrameworksResponse>
Returns a list of the frameworks that are available in the Audit Manager framework library.
listAssessmentFrameworkShareRequests({required ShareRequestType requestType, int? maxResults, String? nextToken}) Future<ListAssessmentFrameworkShareRequestsResponse>
Returns a list of sent or received share requests for custom frameworks in Audit Manager.
listAssessmentReports({int? maxResults, String? nextToken}) Future<ListAssessmentReportsResponse>
Returns a list of assessment reports created in Audit Manager.
listAssessments({int? maxResults, String? nextToken, AssessmentStatus? status}) Future<ListAssessmentsResponse>
Returns a list of current and past assessments from Audit Manager.
listControlDomainInsights({int? maxResults, String? nextToken}) Future<ListControlDomainInsightsResponse>
Lists the latest analytics data for control domains across all of your active assessments.
listControlDomainInsightsByAssessment({required String assessmentId, int? maxResults, String? nextToken}) Future<ListControlDomainInsightsByAssessmentResponse>
Lists analytics data for control domains within a specified active assessment.
listControlInsightsByControlDomain({required String controlDomainId, int? maxResults, String? nextToken}) Future<ListControlInsightsByControlDomainResponse>
Lists the latest analytics data for controls within a specific control domain across all active assessments.
listControls({required ControlType controlType, String? controlCatalogId, int? maxResults, String? nextToken}) Future<ListControlsResponse>
Returns a list of controls from Audit Manager.
listKeywordsForDataSource({required DataSourceType source, int? maxResults, String? nextToken}) Future<ListKeywordsForDataSourceResponse>
Returns a list of keywords that are pre-mapped to the specified control data source.
listNotifications({int? maxResults, String? nextToken}) Future<ListNotificationsResponse>
Returns a list of all Audit Manager notifications.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of tags for the specified resource in Audit Manager.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAccount({String? delegatedAdminAccount, String? kmsKey}) Future<RegisterAccountResponse>
Enables Audit Manager for the specified Amazon Web Services account.
registerOrganizationAdminAccount({required String adminAccountId}) Future<RegisterOrganizationAdminAccountResponse>
Enables an Amazon Web Services account within the organization as the delegated administrator for Audit Manager.
startAssessmentFrameworkShare({required String destinationAccount, required String destinationRegion, required String frameworkId, String? comment}) Future<StartAssessmentFrameworkShareResponse>
Creates a share request for a custom framework in Audit Manager.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Tags the specified resource in Audit Manager.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag from a resource in Audit Manager.
updateAssessment({required String assessmentId, required Scope scope, String? assessmentDescription, String? assessmentName, AssessmentReportsDestination? assessmentReportsDestination, List<Role>? roles}) Future<UpdateAssessmentResponse>
Edits an Audit Manager assessment.
updateAssessmentControl({required String assessmentId, required String controlId, required String controlSetId, String? commentBody, ControlStatus? controlStatus}) Future<UpdateAssessmentControlResponse>
Updates a control within an assessment in Audit Manager.
updateAssessmentControlSetStatus({required String assessmentId, required String comment, required String controlSetId, required ControlSetStatus status}) Future<UpdateAssessmentControlSetStatusResponse>
Updates the status of a control set in an Audit Manager assessment.
updateAssessmentFramework({required List<UpdateAssessmentFrameworkControlSet> controlSets, required String frameworkId, required String name, String? complianceType, String? description}) Future<UpdateAssessmentFrameworkResponse>
Updates a custom framework in Audit Manager.
updateAssessmentFrameworkShare({required ShareRequestAction action, required String requestId, required ShareRequestType requestType}) Future<UpdateAssessmentFrameworkShareResponse>
Updates a share request for a custom framework in Audit Manager.
updateAssessmentStatus({required String assessmentId, required AssessmentStatus status}) Future<UpdateAssessmentStatusResponse>
Updates the status of an assessment in Audit Manager.
updateControl({required String controlId, required List<ControlMappingSource> controlMappingSources, required String name, String? actionPlanInstructions, String? actionPlanTitle, String? description, String? testingInformation}) Future<UpdateControlResponse>
Updates a custom control in Audit Manager.
updateSettings({AssessmentReportsDestination? defaultAssessmentReportsDestination, DefaultExportDestination? defaultExportDestination, List<Role>? defaultProcessOwners, DeregistrationPolicy? deregistrationPolicy, bool? evidenceFinderEnabled, String? kmsKey, String? snsTopic}) Future<UpdateSettingsResponse>
Updates Audit Manager settings for the current account.
validateAssessmentReportIntegrity({required String s3RelativePath}) Future<ValidateAssessmentReportIntegrityResponse>
Validates the integrity of an assessment report in Audit Manager.

Operators

operator ==(Object other) bool
The equality operator.
inherited