deleteAssessmentFrameworkShare method
Deletes a share request for a custom framework in Audit Manager.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter requestId :
The unique identifier for the share request to be deleted.
Parameter requestType :
Specifies whether the share request is a sent request or a received
request.
Implementation
Future<void> deleteAssessmentFrameworkShare({
required String requestId,
required ShareRequestType requestType,
}) async {
final $query = <String, List<String>>{
'requestType': [requestType.value],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/assessmentFrameworkShareRequests/${Uri.encodeComponent(requestId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}