deleteAssessmentReport method
Deletes an assessment report in Audit Manager.
When you run the DeleteAssessmentReport operation, Audit
Manager attempts to delete the following data:
- The specified assessment report that’s stored in your S3 bucket
- The associated metadata that’s stored in Audit Manager
DeleteAssessmentReport operation doesn’t fail. Instead, it
proceeds to delete the associated metadata only. You must then delete the
assessment report from the S3 bucket yourself.
This scenario happens when Audit Manager receives a 403
(Forbidden) or 404 (Not Found) error from Amazon S3.
To avoid this, make sure that your S3 bucket is available, and that you
configured the correct permissions for Audit Manager to delete resources
in your S3 bucket. For an example permissions policy that you can use, see
Assessment
report destination permissions in the Audit Manager User Guide.
For information about the issues that could cause a 403
(Forbidden) or 404 (Not Found) error from Amazon S3,
see List
of Error Codes in the Amazon Simple Storage Service API
Reference.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter assessmentId :
The unique identifier for the assessment.
Parameter assessmentReportId :
The unique identifier for the assessment report.
Implementation
Future<void> deleteAssessmentReport({
required String assessmentId,
required String assessmentReportId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/assessments/${Uri.encodeComponent(assessmentId)}/reports/${Uri.encodeComponent(assessmentReportId)}',
exceptionFnMap: _exceptionFns,
);
}