getEvidenceFileUploadUrl method
Creates a presigned Amazon S3 URL that can be used to upload a file as manual evidence. For instructions on how to use this operation, see Upload a file from your browser in the Audit Manager User Guide.
The following restrictions apply to this operation:
- Maximum size of an individual evidence file: 100 MB
- Number of daily manual evidence uploads per control: 100
- Supported file formats: See Supported file types for manual evidence in the Audit Manager User Guide
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter fileName :
The file that you want to upload. For a list of supported file formats,
see Supported
file types for manual evidence in the Audit Manager User Guide.
Implementation
Future<GetEvidenceFileUploadUrlResponse> getEvidenceFileUploadUrl({
required String fileName,
}) async {
final $query = <String, List<String>>{
'fileName': [fileName],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/evidenceFileUploadUrl',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetEvidenceFileUploadUrlResponse.fromJson(response);
}