getEvidenceFoldersByAssessmentControl method
Gets a list of evidence folders that are associated with a specified control in an Audit Manager assessment.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter assessmentId :
The identifier for the assessment.
Parameter controlId :
The identifier for the control.
Parameter controlSetId :
The identifier for the control set.
Parameter maxResults :
Represents the maximum number of results on a page or for an API request
call.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<GetEvidenceFoldersByAssessmentControlResponse>
getEvidenceFoldersByAssessmentControl({
required String assessmentId,
required String controlId,
required String controlSetId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/assessments/${Uri.encodeComponent(assessmentId)}/evidenceFolders-by-assessment-control/${Uri.encodeComponent(controlSetId)}/${Uri.encodeComponent(controlId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetEvidenceFoldersByAssessmentControlResponse.fromJson(response);
}