getServicesInScope method
Gets a list of the Amazon Web Services services from which Audit Manager can collect evidence.
Audit Manager defines which Amazon Web Services services are in scope for an assessment. Audit Manager infers this scope by examining the assessment’s controls and their data sources, and then mapping this information to one or more of the corresponding Amazon Web Services services that are in this list.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ValidationException.
Implementation
Future<GetServicesInScopeResponse> getServicesInScope() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/services',
exceptionFnMap: _exceptionFns,
);
return GetServicesInScopeResponse.fromJson(response);
}