updateSettings method

Future<UpdateSettingsResponse> updateSettings({
  1. AssessmentReportsDestination? defaultAssessmentReportsDestination,
  2. DefaultExportDestination? defaultExportDestination,
  3. List<Role>? defaultProcessOwners,
  4. DeregistrationPolicy? deregistrationPolicy,
  5. bool? evidenceFinderEnabled,
  6. String? kmsKey,
  7. String? snsTopic,
})

Updates Audit Manager settings for the current account.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter defaultAssessmentReportsDestination : The default S3 destination bucket for storing assessment reports.

Parameter defaultExportDestination : The default S3 destination bucket for storing evidence finder exports.

Parameter defaultProcessOwners : A list of the default audit owners.

Parameter deregistrationPolicy : The deregistration policy for your Audit Manager data. You can use this attribute to determine how your data is handled when you deregister Audit Manager.

Parameter evidenceFinderEnabled : Specifies whether the evidence finder feature is enabled. Change this attribute to enable or disable evidence finder.

Parameter kmsKey : The KMS key details.

Parameter snsTopic : The Amazon Simple Notification Service (Amazon SNS) topic that Audit Manager sends notifications to.

Implementation

Future<UpdateSettingsResponse> updateSettings({
  AssessmentReportsDestination? defaultAssessmentReportsDestination,
  DefaultExportDestination? defaultExportDestination,
  List<Role>? defaultProcessOwners,
  DeregistrationPolicy? deregistrationPolicy,
  bool? evidenceFinderEnabled,
  String? kmsKey,
  String? snsTopic,
}) async {
  final $payload = <String, dynamic>{
    if (defaultAssessmentReportsDestination != null)
      'defaultAssessmentReportsDestination':
          defaultAssessmentReportsDestination,
    if (defaultExportDestination != null)
      'defaultExportDestination': defaultExportDestination,
    if (defaultProcessOwners != null)
      'defaultProcessOwners': defaultProcessOwners,
    if (deregistrationPolicy != null)
      'deregistrationPolicy': deregistrationPolicy,
    if (evidenceFinderEnabled != null)
      'evidenceFinderEnabled': evidenceFinderEnabled,
    if (kmsKey != null) 'kmsKey': kmsKey,
    if (snsTopic != null) 'snsTopic': snsTopic,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/settings',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSettingsResponse.fromJson(response);
}