deleteWarmPool method

Future<void> deleteWarmPool({
  1. required String autoScalingGroupName,
  2. bool? forceDelete,
})

Deletes the warm pool for the specified Auto Scaling group.

For more information, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

May throw LimitExceededFault. May throw ResourceContentionFault. May throw ResourceInUseFault. May throw ScalingActivityInProgressFault.

Parameter autoScalingGroupName : The name of the Auto Scaling group.

Parameter forceDelete : Specifies that the warm pool is to be deleted along with all of its associated instances, without waiting for all instances to be terminated. This parameter also deletes any outstanding lifecycle actions associated with the warm pool instances.

Implementation

Future<void> deleteWarmPool({
  required String autoScalingGroupName,
  bool? forceDelete,
}) async {
  final $request = <String, String>{
    'AutoScalingGroupName': autoScalingGroupName,
    if (forceDelete != null) 'ForceDelete': forceDelete.toString(),
  };
  await _protocol.send(
    $request,
    action: 'DeleteWarmPool',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteWarmPoolResult',
  );
}