describeAutoScalingInstances method
Gets information about the Auto Scaling instances in the account and Region.
May throw InvalidNextToken.
May throw ResourceContentionFault.
Parameter instanceIds :
The IDs of the instances. If you omit this property, all Auto Scaling
instances are described. If you specify an ID that does not exist, it is
ignored with no error.
Array Members: Maximum number of 50 items.
Parameter maxRecords :
The maximum number of items to return with this call. The default value is
50 and the maximum value is 50.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<AutoScalingInstancesType> describeAutoScalingInstances({
List<String>? instanceIds,
int? maxRecords,
String? nextToken,
}) async {
final $request = <String, String>{
if (instanceIds != null)
if (instanceIds.isEmpty)
'InstanceIds': ''
else
for (var i1 = 0; i1 < instanceIds.length; i1++)
'InstanceIds.member.${i1 + 1}': instanceIds[i1],
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'DescribeAutoScalingInstances',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeAutoScalingInstancesResult',
);
return AutoScalingInstancesType.fromXml($result);
}