describeLaunchConfigurations method

Future<LaunchConfigurationsType> describeLaunchConfigurations({
  1. List<String>? launchConfigurationNames,
  2. int? maxRecords,
  3. String? nextToken,
})

Gets information about the launch configurations in the account and Region.

May throw InvalidNextToken. May throw ResourceContentionFault.

Parameter launchConfigurationNames : The launch configuration names. If you omit this property, all launch configurations are described.

Array Members: Maximum number of 50 items.

Parameter maxRecords : The maximum number of items to return with this call. The default value is 50 and the maximum value is 100.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<LaunchConfigurationsType> describeLaunchConfigurations({
  List<String>? launchConfigurationNames,
  int? maxRecords,
  String? nextToken,
}) async {
  final $request = <String, String>{
    if (launchConfigurationNames != null)
      if (launchConfigurationNames.isEmpty)
        'LaunchConfigurationNames': ''
      else
        for (var i1 = 0; i1 < launchConfigurationNames.length; i1++)
          'LaunchConfigurationNames.member.${i1 + 1}':
              launchConfigurationNames[i1],
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeLaunchConfigurations',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeLaunchConfigurationsResult',
  );
  return LaunchConfigurationsType.fromXml($result);
}