describeNotificationConfigurations method
Gets information about the Amazon SNS notifications that are configured for one or more Auto Scaling groups.
May throw InvalidNextToken.
May throw ResourceContentionFault.
Parameter autoScalingGroupNames :
The name of the Auto Scaling group.
Parameter maxRecords :
The maximum number of items to return with this call. The default value is
50 and the maximum value is 100.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<DescribeNotificationConfigurationsAnswer>
describeNotificationConfigurations({
List<String>? autoScalingGroupNames,
int? maxRecords,
String? nextToken,
}) async {
final $request = <String, String>{
if (autoScalingGroupNames != null)
if (autoScalingGroupNames.isEmpty)
'AutoScalingGroupNames': ''
else
for (var i1 = 0; i1 < autoScalingGroupNames.length; i1++)
'AutoScalingGroupNames.member.${i1 + 1}': autoScalingGroupNames[i1],
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'DescribeNotificationConfigurations',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeNotificationConfigurationsResult',
);
return DescribeNotificationConfigurationsAnswer.fromXml($result);
}