describeWarmPool method

Future<DescribeWarmPoolAnswer> describeWarmPool({
  1. required String autoScalingGroupName,
  2. int? maxRecords,
  3. String? nextToken,
})

Gets information about a warm pool and its instances.

For more information, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

May throw InvalidNextToken. May throw LimitExceededFault. May throw ResourceContentionFault.

Parameter autoScalingGroupName : The name of the Auto Scaling group.

Parameter maxRecords : The maximum number of instances to return with this call. The maximum value is 50.

Parameter nextToken : The token for the next set of instances to return. (You received this token from a previous call.)

Implementation

Future<DescribeWarmPoolAnswer> describeWarmPool({
  required String autoScalingGroupName,
  int? maxRecords,
  String? nextToken,
}) async {
  final $request = <String, String>{
    'AutoScalingGroupName': autoScalingGroupName,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeWarmPool',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeWarmPoolResult',
  );
  return DescribeWarmPoolAnswer.fromXml($result);
}