putScheduledUpdateGroupAction method

Future<void> putScheduledUpdateGroupAction({
  1. required String autoScalingGroupName,
  2. required String scheduledActionName,
  3. int? desiredCapacity,
  4. DateTime? endTime,
  5. int? maxSize,
  6. int? minSize,
  7. String? recurrence,
  8. DateTime? startTime,
  9. DateTime? time,
  10. String? timeZone,
})

Creates or updates a scheduled scaling action for an Auto Scaling group.

For more information, see Scheduled scaling in the Amazon EC2 Auto Scaling User Guide.

You can view the scheduled actions for an Auto Scaling group using the DescribeScheduledActions API call. If you are no longer using a scheduled action, you can delete it by calling the DeleteScheduledAction API.

If you try to schedule your action in the past, Amazon EC2 Auto Scaling returns an error message.

May throw AlreadyExistsFault. May throw LimitExceededFault. May throw ResourceContentionFault.

Parameter autoScalingGroupName : The name of the Auto Scaling group.

Parameter scheduledActionName : The name of this scaling action.

Parameter desiredCapacity : The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain. It can scale beyond this capacity if you add more scaling conditions.

Parameter endTime : The date and time for the recurring schedule to end, in UTC. For example, "2021-06-01T00:00:00Z".

Parameter maxSize : The maximum size of the Auto Scaling group.

Parameter minSize : The minimum size of the Auto Scaling group.

Parameter recurrence : The recurring schedule for this action. This format consists of five fields separated by white spaces: [Minute] [Hour] [Day_of_Month] [Month_of_Year] [Day_of_Week]. The value must be in quotes (for example, "30 0 1 1,6,12 *"). For more information about this format, see Crontab.

When StartTime and EndTime are specified with Recurrence, they form the boundaries of when the recurring action starts and stops.

Cron expressions use Universal Coordinated Time (UTC) by default.

Parameter startTime : The date and time for this action to start, in YYYY-MM-DDThh:mm:ssZ format in UTC/GMT only and in quotes (for example, "2021-06-01T00:00:00Z").

If you specify Recurrence and StartTime, Amazon EC2 Auto Scaling performs the action at this time, and then performs the action based on the specified recurrence.

Parameter time : This property is no longer used.

Parameter timeZone : Specifies the time zone for a cron expression. If a time zone is not provided, UTC is used by default.

Valid values are the canonical names of the IANA time zones, derived from the IANA Time Zone Database (such as Etc/GMT+9 or Pacific/Tahiti). For more information, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones.

Implementation

Future<void> putScheduledUpdateGroupAction({
  required String autoScalingGroupName,
  required String scheduledActionName,
  int? desiredCapacity,
  DateTime? endTime,
  int? maxSize,
  int? minSize,
  String? recurrence,
  DateTime? startTime,
  DateTime? time,
  String? timeZone,
}) async {
  final $request = <String, String>{
    'AutoScalingGroupName': autoScalingGroupName,
    'ScheduledActionName': scheduledActionName,
    if (desiredCapacity != null)
      'DesiredCapacity': desiredCapacity.toString(),
    if (endTime != null) 'EndTime': _s.iso8601ToJson(endTime),
    if (maxSize != null) 'MaxSize': maxSize.toString(),
    if (minSize != null) 'MinSize': minSize.toString(),
    if (recurrence != null) 'Recurrence': recurrence,
    if (startTime != null) 'StartTime': _s.iso8601ToJson(startTime),
    if (time != null) 'Time': _s.iso8601ToJson(time),
    if (timeZone != null) 'TimeZone': timeZone,
  };
  await _protocol.send(
    $request,
    action: 'PutScheduledUpdateGroupAction',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}