putWarmPool method
Creates or updates a warm pool for the specified Auto Scaling group. A warm pool is a pool of pre-initialized EC2 instances that sits alongside the Auto Scaling group. Whenever your application needs to scale out, the Auto Scaling group can draw on the warm pool to meet its new desired capacity.
This operation must be called from the Region in which the Auto Scaling group was created.
You can view the instances in the warm pool using the DescribeWarmPool API call. If you are no longer using a warm pool, you can delete it by calling the DeleteWarmPool API.
For more information, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
May throw InstanceRefreshInProgressFault.
May throw LimitExceededFault.
May throw ResourceContentionFault.
Parameter autoScalingGroupName :
The name of the Auto Scaling group.
Parameter instanceReusePolicy :
Indicates whether instances in the Auto Scaling group can be returned to
the warm pool on scale in. The default is to terminate instances in the
Auto Scaling group when the group scales in.
Parameter maxGroupPreparedCapacity :
Specifies the maximum number of instances that are allowed to be in the
warm pool or in any state except Terminated for the Auto
Scaling group. This is an optional property. Specify it only if you do not
want the warm pool size to be determined by the difference between the
group's maximum capacity and its desired capacity.
The size of the warm pool is dynamic. Only when
MaxGroupPreparedCapacity and MinSize are set to
the same value does the warm pool have an absolute size.
If the desired capacity of the Auto Scaling group is higher than the
MaxGroupPreparedCapacity, the capacity of the warm pool is 0,
unless you specify a value for MinSize. To remove a value
that you previously set, include the property but specify -1 for the
value.
Parameter minSize :
Specifies the minimum number of instances to maintain in the warm pool.
This helps you to ensure that there is always a certain number of warmed
instances available to handle traffic spikes. Defaults to 0 if not
specified.
Parameter poolState :
Sets the instance state to transition to after the lifecycle actions are
complete. Default is Stopped.
Implementation
Future<void> putWarmPool({
required String autoScalingGroupName,
InstanceReusePolicy? instanceReusePolicy,
int? maxGroupPreparedCapacity,
int? minSize,
WarmPoolState? poolState,
}) async {
_s.validateNumRange(
'maxGroupPreparedCapacity',
maxGroupPreparedCapacity,
-1,
1152921504606846976,
);
_s.validateNumRange(
'minSize',
minSize,
0,
1152921504606846976,
);
final $request = <String, String>{
'AutoScalingGroupName': autoScalingGroupName,
if (instanceReusePolicy != null)
for (var e1 in instanceReusePolicy.toQueryMap().entries)
'InstanceReusePolicy.${e1.key}': e1.value,
if (maxGroupPreparedCapacity != null)
'MaxGroupPreparedCapacity': maxGroupPreparedCapacity.toString(),
if (minSize != null) 'MinSize': minSize.toString(),
if (poolState != null) 'PoolState': poolState.value,
};
await _protocol.send(
$request,
action: 'PutWarmPool',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'PutWarmPoolResult',
);
}