resumeProcesses method
Resumes the specified suspended auto scaling processes, or all suspended process, for the specified Auto Scaling group.
For more information, see Suspend and resume Amazon EC2 Auto Scaling processes in the Amazon EC2 Auto Scaling User Guide.
May throw ResourceContentionFault.
May throw ResourceInUseFault.
Parameter autoScalingGroupName :
The name of the Auto Scaling group.
Parameter scalingProcesses :
One or more of the following processes:
-
Launch -
Terminate -
AddToLoadBalancer -
AlarmNotification -
AZRebalance -
HealthCheck -
InstanceRefresh -
ReplaceUnhealthy -
ScheduledActions
Implementation
Future<void> resumeProcesses({
required String autoScalingGroupName,
List<String>? scalingProcesses,
}) async {
final $request = <String, String>{
'AutoScalingGroupName': autoScalingGroupName,
if (scalingProcesses != null)
if (scalingProcesses.isEmpty)
'ScalingProcesses': ''
else
for (var i1 = 0; i1 < scalingProcesses.length; i1++)
'ScalingProcesses.member.${i1 + 1}': scalingProcesses[i1],
};
await _protocol.send(
$request,
action: 'ResumeProcesses',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}