rollbackInstanceRefresh method
- required String autoScalingGroupName,
Cancels an instance refresh that is in progress and rolls back any changes that it made. Amazon EC2 Auto Scaling replaces any instances that were replaced during the instance refresh. This restores your Auto Scaling group to the configuration that it was using before the start of the instance refresh.
This operation is part of the instance refresh feature in Amazon EC2 Auto Scaling, which helps you update instances in your Auto Scaling group after you make configuration changes.
A rollback is not supported in the following situations:
- There is no desired configuration specified for the instance refresh.
-
The Auto Scaling group has a launch template that uses an Amazon Web
Services Systems Manager parameter instead of an AMI ID for the
ImageIdproperty. -
The Auto Scaling group uses the launch template's
$Latestor$Defaultversion.
May throw ActiveInstanceRefreshNotFoundFault.
May throw IrreversibleInstanceRefreshFault.
May throw LimitExceededFault.
May throw ResourceContentionFault.
Parameter autoScalingGroupName :
The name of the Auto Scaling group.
Implementation
Future<RollbackInstanceRefreshAnswer> rollbackInstanceRefresh({
required String autoScalingGroupName,
}) async {
final $request = <String, String>{
'AutoScalingGroupName': autoScalingGroupName,
};
final $result = await _protocol.send(
$request,
action: 'RollbackInstanceRefresh',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RollbackInstanceRefreshResult',
);
return RollbackInstanceRefreshAnswer.fromXml($result);
}