startInstanceRefresh method

Future<StartInstanceRefreshAnswer> startInstanceRefresh({
  1. required String autoScalingGroupName,
  2. DesiredConfiguration? desiredConfiguration,
  3. RefreshPreferences? preferences,
  4. RefreshStrategy? strategy,
})

Starts an instance refresh.

This operation is part of the instance refresh feature in Amazon EC2 Auto Scaling, which helps you update instances in your Auto Scaling group. This feature is helpful, for example, when you have a new AMI or a new user data script. You just need to create a new launch template that specifies the new AMI or user data script. Then start an instance refresh to immediately begin the process of updating instances in the group.

If successful, the request's response contains a unique ID that you can use to track the progress of the instance refresh. To query its status, call the DescribeInstanceRefreshes API. To describe the instance refreshes that have already run, call the DescribeInstanceRefreshes API. To cancel an instance refresh that is in progress, use the CancelInstanceRefresh API.

An instance refresh might fail for several reasons, such as EC2 launch failures, misconfigured health checks, or not ignoring or allowing the termination of instances that are in Standby state or protected from scale in. You can monitor for failed EC2 launches using the scaling activities. To find the scaling activities, call the DescribeScalingActivities API.

If you enable auto rollback, your Auto Scaling group will be rolled back automatically when the instance refresh fails. You can enable this feature before starting an instance refresh by specifying the AutoRollback property in the instance refresh preferences. Otherwise, to roll back an instance refresh before it finishes, use the RollbackInstanceRefresh API.

May throw InstanceRefreshInProgressFault. May throw LimitExceededFault. May throw ResourceContentionFault.

Parameter autoScalingGroupName : The name of the Auto Scaling group.

Parameter desiredConfiguration : The desired configuration. For example, the desired configuration can specify a new launch template or a new version of the current launch template.

Once the instance refresh succeeds, Amazon EC2 Auto Scaling updates the settings of the Auto Scaling group to reflect the new desired configuration.

Parameter preferences : Sets your preferences for the instance refresh so that it performs as expected when you start it. Includes the instance warmup time, the minimum and maximum healthy percentages, and the behaviors that you want Amazon EC2 Auto Scaling to use if instances that are in Standby state or protected from scale in are found. You can also choose to enable additional features, such as the following:

  • Auto rollback
  • Checkpoints
  • CloudWatch alarms
  • Skip matching
  • Bake time

Parameter strategy : The strategy to use for the instance refresh. The default value is Rolling.

Implementation

Future<StartInstanceRefreshAnswer> startInstanceRefresh({
  required String autoScalingGroupName,
  DesiredConfiguration? desiredConfiguration,
  RefreshPreferences? preferences,
  RefreshStrategy? strategy,
}) async {
  final $request = <String, String>{
    'AutoScalingGroupName': autoScalingGroupName,
    if (desiredConfiguration != null)
      for (var e1 in desiredConfiguration.toQueryMap().entries)
        'DesiredConfiguration.${e1.key}': e1.value,
    if (preferences != null)
      for (var e1 in preferences.toQueryMap().entries)
        'Preferences.${e1.key}': e1.value,
    if (strategy != null) 'Strategy': strategy.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'StartInstanceRefresh',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'StartInstanceRefreshResult',
  );
  return StartInstanceRefreshAnswer.fromXml($result);
}