updateAutoScalingGroup method

Future<void> updateAutoScalingGroup({
  1. required String autoScalingGroupName,
  2. AvailabilityZoneDistribution? availabilityZoneDistribution,
  3. List<String>? availabilityZoneIds,
  4. AvailabilityZoneImpairmentPolicy? availabilityZoneImpairmentPolicy,
  5. List<String>? availabilityZones,
  6. bool? capacityRebalance,
  7. CapacityReservationSpecification? capacityReservationSpecification,
  8. String? context,
  9. int? defaultCooldown,
  10. int? defaultInstanceWarmup,
  11. DeletionProtection? deletionProtection,
  12. int? desiredCapacity,
  13. String? desiredCapacityType,
  14. int? healthCheckGracePeriod,
  15. String? healthCheckType,
  16. InstanceLifecyclePolicy? instanceLifecyclePolicy,
  17. InstanceMaintenancePolicy? instanceMaintenancePolicy,
  18. String? launchConfigurationName,
  19. LaunchTemplateSpecification? launchTemplate,
  20. int? maxInstanceLifetime,
  21. int? maxSize,
  22. int? minSize,
  23. MixedInstancesPolicy? mixedInstancesPolicy,
  24. bool? newInstancesProtectedFromScaleIn,
  25. String? placementGroup,
  26. String? serviceLinkedRoleARN,
  27. bool? skipZonalShiftValidation,
  28. List<String>? terminationPolicies,
  29. String? vPCZoneIdentifier,
})

We strongly recommend that all Auto Scaling groups use launch templates to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.

Updates the configuration for the specified Auto Scaling group.

To update an Auto Scaling group, specify the name of the group and the property that you want to change. Any properties that you don't specify are not changed by this update request. The new settings take effect on any scaling activities after this call returns.

If you associate a new launch configuration or template with an Auto Scaling group, all new instances will get the updated configuration. Existing instances continue to run with the configuration that they were originally launched with. When you update a group to specify a mixed instances policy instead of a launch configuration or template, existing instances may be replaced to match the new purchasing options that you specified in the policy. For example, if the group currently has 100% On-Demand capacity and the policy specifies 50% Spot capacity, this means that half of your instances will be gradually terminated and relaunched as Spot Instances. When replacing instances, Amazon EC2 Auto Scaling launches new instances before terminating the old ones, so that updating your group does not compromise the performance or availability of your application.

Note the following about changing DesiredCapacity, MaxSize, or MinSize:

  • If a scale-in activity occurs as a result of a new DesiredCapacity value that is lower than the current size of the group, the Auto Scaling group uses its termination policy to determine which instances to terminate.
  • If you specify a new value for MinSize without specifying a value for DesiredCapacity, and the new MinSize is larger than the current size of the group, this sets the group's DesiredCapacity to the new MinSize value.
  • If you specify a new value for MaxSize without specifying a value for DesiredCapacity, and the new MaxSize is smaller than the current size of the group, this sets the group's DesiredCapacity to the new MaxSize value.
To see which properties have been set, call the DescribeAutoScalingGroups API. To view the scaling policies for an Auto Scaling group, call the DescribePolicies API. If the group has scaling policies, you can update them by calling the PutScalingPolicy API.

May throw ResourceContentionFault. May throw ScalingActivityInProgressFault. May throw ServiceLinkedRoleFailure.

Parameter autoScalingGroupName : The name of the Auto Scaling group.

Parameter availabilityZoneDistribution : The instance capacity distribution across Availability Zones.

Parameter availabilityZoneIds : A list of Availability Zone IDs for the Auto Scaling group. You cannot specify both AvailabilityZones and AvailabilityZoneIds in the same request.

Parameter availabilityZoneImpairmentPolicy : The policy for Availability Zone impairment.

Parameter availabilityZones : One or more Availability Zones for the group.

Parameter capacityRebalance : Enables or disables Capacity Rebalancing. If Capacity Rebalancing is disabled, proactive replacement of at-risk Spot Instances does not occur. For more information, see Capacity Rebalancing in Auto Scaling to replace at-risk Spot Instances in the Amazon EC2 Auto Scaling User Guide.

Parameter capacityReservationSpecification : The capacity reservation specification for the Auto Scaling group.

Parameter context : Reserved.

Parameter defaultCooldown : Only needed if you use simple scaling policies.

The amount of time, in seconds, between one scaling activity ending and another one starting due to simple scaling policies. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

Parameter defaultInstanceWarmup : The amount of time, in seconds, until a new instance is considered to have finished initializing and resource consumption to become stable after it enters the InService state.

During an instance refresh, Amazon EC2 Auto Scaling waits for the warm-up period after it replaces an instance before it moves on to replacing the next instance. Amazon EC2 Auto Scaling also waits for the warm-up period before aggregating the metrics for new instances with existing instances in the Amazon CloudWatch metrics that are used for scaling, resulting in more reliable usage data. For more information, see Set the default instance warmup for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

Parameter deletionProtection : The deletion protection setting for the Auto Scaling group. This setting helps safeguard your Auto Scaling group and its instances by controlling whether the DeleteAutoScalingGroup operation is allowed. When deletion protection is enabled, users cannot delete the Auto Scaling group according to the specified protection level until the setting is changed back to a less restrictive level.

The valid values are none, prevent-force-deletion, and prevent-all-deletion.

Default: none

For more information, see Configure deletion protection for your Amazon EC2 Auto Scaling resources in the Amazon EC2 Auto Scaling User Guide.

Parameter desiredCapacity : The desired capacity is the initial capacity of the Auto Scaling group after this operation completes and the capacity it attempts to maintain. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group.

Parameter desiredCapacityType : The unit of measurement for the value specified for desired capacity. Amazon EC2 Auto Scaling supports DesiredCapacityType for attribute-based instance type selection only. For more information, see Create a mixed instances group using attribute-based instance type selection in the Amazon EC2 Auto Scaling User Guide.

By default, Amazon EC2 Auto Scaling specifies units, which translates into number of instances.

Valid values: units | vcpu | memory-mib

Parameter healthCheckGracePeriod : The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before checking the health status of an EC2 instance that has come into service and marking it unhealthy due to a failed health check. This is useful if your instances do not immediately pass their health checks after they enter the InService state. For more information, see Set the health check grace period for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

Parameter healthCheckType : A comma-separated value string of one or more health check types.

The valid values are EC2, EBS, ELB, and VPC_LATTICE. EC2 is the default health check and cannot be disabled. For more information, see Health checks for instances in an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

Only specify EC2 if you must clear a value that was previously set.

Parameter instanceLifecyclePolicy : The instance lifecycle policy for the Auto Scaling group. This policy controls instance behavior when an instance transitions through its lifecycle states. Configure retention triggers to specify when instances should move to a Retained state instead of automatic termination.

For more information, see Control instance retention with instance lifecycle policies in the Amazon EC2 Auto Scaling User Guide.

Parameter instanceMaintenancePolicy : An instance maintenance policy. For more information, see Set instance maintenance policy in the Amazon EC2 Auto Scaling User Guide.

Parameter launchConfigurationName : The name of the launch configuration. If you specify LaunchConfigurationName in your update request, you can't specify LaunchTemplate or MixedInstancesPolicy.

Parameter launchTemplate : The launch template and version to use to specify the updates. If you specify LaunchTemplate in your update request, you can't specify LaunchConfigurationName or MixedInstancesPolicy.

Parameter maxInstanceLifetime : The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). To clear a previously set value, specify a new value of 0. For more information, see Replacing Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide.

Parameter maxSize : The maximum size of the Auto Scaling group.

Parameter minSize : The minimum size of the Auto Scaling group.

Parameter mixedInstancesPolicy : The mixed instances policy. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide.

Parameter newInstancesProtectedFromScaleIn : Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Use instance scale-in protection in the Amazon EC2 Auto Scaling User Guide.

Parameter placementGroup : The name of an existing placement group into which to launch your instances. To remove the placement group setting, pass an empty string for placement-group. For more information about placement groups, see Placement groups in the Amazon EC2 User Guide.

Parameter serviceLinkedRoleARN : The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf. For more information, see Service-linked roles in the Amazon EC2 Auto Scaling User Guide.

Parameter skipZonalShiftValidation : If you enable zonal shift with cross-zone disabled load balancers, capacity could become imbalanced across Availability Zones. To skip the validation, specify true. For more information, see Auto Scaling group zonal shift in the Amazon EC2 Auto Scaling User Guide.

Parameter terminationPolicies : A policy or a list of policies that are used to select the instances to terminate. The policies are executed in the order that you list them. For more information, see Configure termination policies for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

Valid values: Default | AllocationStrategy | ClosestToNextInstanceHour | NewestInstance | OldestInstance | OldestLaunchConfiguration | OldestLaunchTemplate | arn:aws:lambda:region:account-id:function:my-function:my-alias

Parameter vPCZoneIdentifier : A comma-separated list of subnet IDs for a virtual private cloud (VPC). If you specify VPCZoneIdentifier with AvailabilityZones, the subnets that you specify must reside in those Availability Zones.

Implementation

Future<void> updateAutoScalingGroup({
  required String autoScalingGroupName,
  AvailabilityZoneDistribution? availabilityZoneDistribution,
  List<String>? availabilityZoneIds,
  AvailabilityZoneImpairmentPolicy? availabilityZoneImpairmentPolicy,
  List<String>? availabilityZones,
  bool? capacityRebalance,
  CapacityReservationSpecification? capacityReservationSpecification,
  String? context,
  int? defaultCooldown,
  int? defaultInstanceWarmup,
  DeletionProtection? deletionProtection,
  int? desiredCapacity,
  String? desiredCapacityType,
  int? healthCheckGracePeriod,
  String? healthCheckType,
  InstanceLifecyclePolicy? instanceLifecyclePolicy,
  InstanceMaintenancePolicy? instanceMaintenancePolicy,
  String? launchConfigurationName,
  LaunchTemplateSpecification? launchTemplate,
  int? maxInstanceLifetime,
  int? maxSize,
  int? minSize,
  MixedInstancesPolicy? mixedInstancesPolicy,
  bool? newInstancesProtectedFromScaleIn,
  String? placementGroup,
  String? serviceLinkedRoleARN,
  bool? skipZonalShiftValidation,
  List<String>? terminationPolicies,
  String? vPCZoneIdentifier,
}) async {
  final $request = <String, String>{
    'AutoScalingGroupName': autoScalingGroupName,
    if (availabilityZoneDistribution != null)
      for (var e1 in availabilityZoneDistribution.toQueryMap().entries)
        'AvailabilityZoneDistribution.${e1.key}': e1.value,
    if (availabilityZoneIds != null)
      if (availabilityZoneIds.isEmpty)
        'AvailabilityZoneIds': ''
      else
        for (var i1 = 0; i1 < availabilityZoneIds.length; i1++)
          'AvailabilityZoneIds.member.${i1 + 1}': availabilityZoneIds[i1],
    if (availabilityZoneImpairmentPolicy != null)
      for (var e1 in availabilityZoneImpairmentPolicy.toQueryMap().entries)
        'AvailabilityZoneImpairmentPolicy.${e1.key}': e1.value,
    if (availabilityZones != null)
      if (availabilityZones.isEmpty)
        'AvailabilityZones': ''
      else
        for (var i1 = 0; i1 < availabilityZones.length; i1++)
          'AvailabilityZones.member.${i1 + 1}': availabilityZones[i1],
    if (capacityRebalance != null)
      'CapacityRebalance': capacityRebalance.toString(),
    if (capacityReservationSpecification != null)
      for (var e1 in capacityReservationSpecification.toQueryMap().entries)
        'CapacityReservationSpecification.${e1.key}': e1.value,
    if (context != null) 'Context': context,
    if (defaultCooldown != null)
      'DefaultCooldown': defaultCooldown.toString(),
    if (defaultInstanceWarmup != null)
      'DefaultInstanceWarmup': defaultInstanceWarmup.toString(),
    if (deletionProtection != null)
      'DeletionProtection': deletionProtection.value,
    if (desiredCapacity != null)
      'DesiredCapacity': desiredCapacity.toString(),
    if (desiredCapacityType != null)
      'DesiredCapacityType': desiredCapacityType,
    if (healthCheckGracePeriod != null)
      'HealthCheckGracePeriod': healthCheckGracePeriod.toString(),
    if (healthCheckType != null) 'HealthCheckType': healthCheckType,
    if (instanceLifecyclePolicy != null)
      for (var e1 in instanceLifecyclePolicy.toQueryMap().entries)
        'InstanceLifecyclePolicy.${e1.key}': e1.value,
    if (instanceMaintenancePolicy != null)
      for (var e1 in instanceMaintenancePolicy.toQueryMap().entries)
        'InstanceMaintenancePolicy.${e1.key}': e1.value,
    if (launchConfigurationName != null)
      'LaunchConfigurationName': launchConfigurationName,
    if (launchTemplate != null)
      for (var e1 in launchTemplate.toQueryMap().entries)
        'LaunchTemplate.${e1.key}': e1.value,
    if (maxInstanceLifetime != null)
      'MaxInstanceLifetime': maxInstanceLifetime.toString(),
    if (maxSize != null) 'MaxSize': maxSize.toString(),
    if (minSize != null) 'MinSize': minSize.toString(),
    if (mixedInstancesPolicy != null)
      for (var e1 in mixedInstancesPolicy.toQueryMap().entries)
        'MixedInstancesPolicy.${e1.key}': e1.value,
    if (newInstancesProtectedFromScaleIn != null)
      'NewInstancesProtectedFromScaleIn':
          newInstancesProtectedFromScaleIn.toString(),
    if (placementGroup != null) 'PlacementGroup': placementGroup,
    if (serviceLinkedRoleARN != null)
      'ServiceLinkedRoleARN': serviceLinkedRoleARN,
    if (skipZonalShiftValidation != null)
      'SkipZonalShiftValidation': skipZonalShiftValidation.toString(),
    if (terminationPolicies != null)
      if (terminationPolicies.isEmpty)
        'TerminationPolicies': ''
      else
        for (var i1 = 0; i1 < terminationPolicies.length; i1++)
          'TerminationPolicies.member.${i1 + 1}': terminationPolicies[i1],
    if (vPCZoneIdentifier != null) 'VPCZoneIdentifier': vPCZoneIdentifier,
  };
  await _protocol.send(
    $request,
    action: 'UpdateAutoScalingGroup',
    version: '2011-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}