AutoScalingPlans class

Use AWS Auto Scaling to create scaling plans for your applications to automatically scale your scalable AWS resources.

Constructors

AutoScalingPlans({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createScalingPlan({required ApplicationSource applicationSource, required List<ScalingInstruction> scalingInstructions, required String scalingPlanName}) Future<CreateScalingPlanResponse>
Creates a scaling plan.
deleteScalingPlan({required String scalingPlanName, required int scalingPlanVersion}) Future<void>
Deletes the specified scaling plan.
describeScalingPlanResources({required String scalingPlanName, required int scalingPlanVersion, int? maxResults, String? nextToken}) Future<DescribeScalingPlanResourcesResponse>
Describes the scalable resources in the specified scaling plan.
describeScalingPlans({List<ApplicationSource>? applicationSources, int? maxResults, String? nextToken, List<String>? scalingPlanNames, int? scalingPlanVersion}) Future<DescribeScalingPlansResponse>
Describes one or more of your scaling plans.
getScalingPlanResourceForecastData({required DateTime endTime, required ForecastDataType forecastDataType, required String resourceId, required ScalableDimension scalableDimension, required String scalingPlanName, required int scalingPlanVersion, required ServiceNamespace serviceNamespace, required DateTime startTime}) Future<GetScalingPlanResourceForecastDataResponse>
Retrieves the forecast data for a scalable resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateScalingPlan({required String scalingPlanName, required int scalingPlanVersion, ApplicationSource? applicationSource, List<ScalingInstruction>? scalingInstructions}) Future<void>
Updates the specified scaling plan.

Operators

operator ==(Object other) bool
The equality operator.
inherited