B2Bi class

This is the Amazon Web Services B2B Data Interchange API Reference. It provides descriptions, API request parameters, and the XML response for each of the B2BI API actions.

B2BI enables automated exchange of EDI (electronic data interchange) based business-critical transactions at cloud scale, with elasticity and pay-as-you-go pricing. Businesses use EDI documents to exchange transactional data with trading partners, such as suppliers and end customers, using standardized formats such as X12.

Constructors

B2Bi({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCapability({required CapabilityConfiguration configuration, required String name, required CapabilityType type, String? clientToken, List<S3Location>? instructionsDocuments, List<Tag>? tags}) Future<CreateCapabilityResponse>
Instantiates a capability based on the specified parameters. A trading capability contains the information required to transform incoming EDI documents into JSON or XML outputs.
createPartnership({required List<String> capabilities, required String email, required String name, required String profileId, CapabilityOptions? capabilityOptions, String? clientToken, String? phone, List<Tag>? tags}) Future<CreatePartnershipResponse>
Creates a partnership between a customer and a trading partner, based on the supplied parameters. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.
createProfile({required String businessName, required Logging logging, required String name, required String phone, String? clientToken, String? email, List<Tag>? tags}) Future<CreateProfileResponse>
Creates a customer profile. You can have up to five customer profiles, each representing a distinct private network. A profile is the mechanism used to create the concept of a private network.
createStarterMappingTemplate({required MappingType mappingType, required TemplateDetails templateDetails, S3Location? outputSampleLocation}) Future<CreateStarterMappingTemplateResponse>
Amazon Web Services B2B Data Interchange uses a mapping template in JSONata or XSLT format to transform a customer input file into a JSON or XML file that can be converted to EDI.
createTransformer({required String name, String? clientToken, EdiType? ediType, FileFormat? fileFormat, InputConversion? inputConversion, Mapping? mapping, String? mappingTemplate, OutputConversion? outputConversion, String? sampleDocument, SampleDocuments? sampleDocuments, List<Tag>? tags}) Future<CreateTransformerResponse>
Creates a transformer. Amazon Web Services B2B Data Interchange currently supports two scenarios:
deleteCapability({required String capabilityId}) Future<void>
Deletes the specified capability. A trading capability contains the information required to transform incoming EDI documents into JSON or XML outputs.
deletePartnership({required String partnershipId}) Future<void>
Deletes the specified partnership. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.
deleteProfile({required String profileId}) Future<void>
Deletes the specified profile. A profile is the mechanism used to create the concept of a private network.
deleteTransformer({required String transformerId}) Future<void>
Deletes the specified transformer. A transformer can take an EDI file as input and transform it into a JSON-or XML-formatted document. Alternatively, a transformer can take a JSON-or XML-formatted document as input and transform it into an EDI file.
generateMapping({required String inputFileContent, required MappingType mappingType, required String outputFileContent}) Future<GenerateMappingResponse>
Takes sample input and output documents and uses Amazon Bedrock to generate a mapping automatically. Depending on the accuracy and other factors, you can then edit the mapping for your needs. To generate a mapping, perform the following steps:
getCapability({required String capabilityId}) Future<GetCapabilityResponse>
Retrieves the details for the specified capability. A trading capability contains the information required to transform incoming EDI documents into JSON or XML outputs.
getPartnership({required String partnershipId}) Future<GetPartnershipResponse>
Retrieves the details for a partnership, based on the partner and profile IDs specified. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.
getProfile({required String profileId}) Future<GetProfileResponse>
Retrieves the details for the profile specified by the profile ID. A profile is the mechanism used to create the concept of a private network.
getTransformer({required String transformerId}) Future<GetTransformerResponse>
Retrieves the details for the transformer specified by the transformer ID. A transformer can take an EDI file as input and transform it into a JSON-or XML-formatted document. Alternatively, a transformer can take a JSON-or XML-formatted document as input and transform it into an EDI file.
getTransformerJob({required String transformerId, required String transformerJobId}) Future<GetTransformerJobResponse>
Returns the details of the transformer run, based on the Transformer job ID.
listCapabilities({int? maxResults, String? nextToken}) Future<ListCapabilitiesResponse>
Lists the capabilities associated with your Amazon Web Services account for your current or specified region. A trading capability contains the information required to transform incoming EDI documents into JSON or XML outputs.
listPartnerships({int? maxResults, String? nextToken, String? profileId}) Future<ListPartnershipsResponse>
Lists the partnerships associated with your Amazon Web Services account for your current or specified region. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.
listProfiles({int? maxResults, String? nextToken}) Future<ListProfilesResponse>
Lists the profiles associated with your Amazon Web Services account for your current or specified region. A profile is the mechanism used to create the concept of a private network.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a capability, partnership, profile, or transformer.
listTransformers({int? maxResults, String? nextToken}) Future<ListTransformersResponse>
Lists the available transformers. A transformer can take an EDI file as input and transform it into a JSON-or XML-formatted document. Alternatively, a transformer can take a JSON-or XML-formatted document as input and transform it into an EDI file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTransformerJob({required S3Location inputFile, required S3Location outputLocation, required String transformerId, String? clientToken}) Future<StartTransformerJobResponse>
Runs a job, using a transformer, to parse input EDI (electronic data interchange) file into the output structures used by Amazon Web Services B2B Data Interchange.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are capability, partnership, profile, transformers and other entities.
testConversion({required ConversionSource source, required ConversionTarget target}) Future<TestConversionResponse>
This operation mimics the latter half of a typical Outbound EDI request. It takes an input JSON/XML in the B2Bi shape as input, converts it to an X12 EDI string, and return that string.
testMapping({required FileFormat fileFormat, required String inputFileContent, required String mappingTemplate}) Future<TestMappingResponse>
Maps the input file according to the provided template file. The API call downloads the file contents from the Amazon S3 location, and passes the contents in as a string, to the inputFileContent parameter.
testParsing({required EdiType ediType, required FileFormat fileFormat, required S3Location inputFile, AdvancedOptions? advancedOptions}) Future<TestParsingResponse>
Parses the input EDI (electronic data interchange) file. The input file has a file size limit of 250 KB.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Detaches a key-value pair from the specified resource, as identified by its Amazon Resource Name (ARN). Resources are capability, partnership, profile, transformers and other entities.
updateCapability({required String capabilityId, CapabilityConfiguration? configuration, List<S3Location>? instructionsDocuments, String? name}) Future<UpdateCapabilityResponse>
Updates some of the parameters for a capability, based on the specified parameters. A trading capability contains the information required to transform incoming EDI documents into JSON or XML outputs.
updatePartnership({required String partnershipId, List<String>? capabilities, CapabilityOptions? capabilityOptions, String? name}) Future<UpdatePartnershipResponse>
Updates some of the parameters for a partnership between a customer and trading partner. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.
updateProfile({required String profileId, String? businessName, String? email, String? name, String? phone}) Future<UpdateProfileResponse>
Updates the specified parameters for a profile. A profile is the mechanism used to create the concept of a private network.
updateTransformer({required String transformerId, EdiType? ediType, FileFormat? fileFormat, InputConversion? inputConversion, Mapping? mapping, String? mappingTemplate, String? name, OutputConversion? outputConversion, String? sampleDocument, SampleDocuments? sampleDocuments, TransformerStatus? status}) Future<UpdateTransformerResponse>
Updates the specified parameters for a transformer. A transformer can take an EDI file as input and transform it into a JSON-or XML-formatted document. Alternatively, a transformer can take a JSON-or XML-formatted document as input and transform it into an EDI file.

Operators

operator ==(Object other) bool
The equality operator.
inherited