deletePartnership method

Future<void> deletePartnership({
  1. required String partnershipId,
})

Deletes the specified partnership. A partnership represents the connection between you and your trading partner. It ties together a profile and one or more trading capabilities.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter partnershipId : Specifies the unique, system-generated identifier for a partnership.

Implementation

Future<void> deletePartnership({
  required String partnershipId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'B2BI.DeletePartnership'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'partnershipId': partnershipId,
    },
  );
}