getTransformer method

Future<GetTransformerResponse> getTransformer({
  1. required String transformerId,
})

Retrieves the details for the transformer specified by the transformer ID. A transformer can take an EDI file as input and transform it into a JSON-or XML-formatted document. Alternatively, a transformer can take a JSON-or XML-formatted document as input and transform it into an EDI file.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter transformerId : Specifies the system-assigned unique identifier for the transformer.

Implementation

Future<GetTransformerResponse> getTransformer({
  required String transformerId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'B2BI.GetTransformer'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'transformerId': transformerId,
    },
  );

  return GetTransformerResponse.fromJson(jsonResponse.body);
}