untagResource method
Detaches a key-value pair from the specified resource, as identified by its Amazon Resource Name (ARN). Resources are capability, partnership, profile, transformers and other entities.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceARN :
Specifies an Amazon Resource Name (ARN) for a specific Amazon Web Services
resource, such as a capability, partnership, profile, or transformer.
Parameter tagKeys :
Specifies the key-value pairs assigned to ARNs that you can use to group
and search for resources by type. You can attach this metadata to
resources (capabilities, partnerships, and so on) for any purpose.
Implementation
Future<void> untagResource({
required String resourceARN,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'B2BI.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'TagKeys': tagKeys,
},
);
}