Backup class
Backup is a unified backup service designed to protect Amazon Web Services services and their associated data. Backup simplifies the creation, migration, restoration, and deletion of backups, while also providing reporting and auditing.
Constructors
- Backup({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateBackupVaultMpaApprovalTeam(
{required String backupVaultName, required String mpaApprovalTeamArn, String? requesterComment}) → Future< void> - Associates an MPA approval team with a backup vault.
-
cancelLegalHold(
{required String cancelDescription, required String legalHoldId, int? retainRecordInDays}) → Future< void> - Removes the specified legal hold on a recovery point. This action can only be performed by a user with sufficient permissions.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBackupPlan(
{required BackupPlanInput backupPlan, Map< String, String> ? backupPlanTags, String? creatorRequestId}) → Future<CreateBackupPlanOutput> - Creates a backup plan using a backup plan name and backup rules. A backup plan is a document that contains information that Backup uses to schedule tasks that create recovery points for resources.
-
createBackupSelection(
{required String backupPlanId, required BackupSelection backupSelection, String? creatorRequestId}) → Future< CreateBackupSelectionOutput> - Creates a JSON document that specifies a set of resources to assign to a backup plan. For examples, see Assigning resources programmatically.
-
createBackupVault(
{required String backupVaultName, Map< String, String> ? backupVaultTags, String? creatorRequestId, String? encryptionKeyArn}) → Future<CreateBackupVaultOutput> -
Creates a logical container where backups are stored. A
CreateBackupVaultrequest includes a name, optionally one or more resource tags, an encryption key, and a request ID. -
createFramework(
{required List< FrameworkControl> frameworkControls, required String frameworkName, String? frameworkDescription, Map<String, String> ? frameworkTags, String? idempotencyToken}) → Future<CreateFrameworkOutput> - Creates a framework with one or more controls. A framework is a collection of controls that you can use to evaluate your backup practices. By using pre-built customizable controls to define your policies, you can evaluate whether your backup practices comply with your policies and which resources are not yet in compliance.
-
createLegalHold(
{required String description, required String title, String? idempotencyToken, RecoveryPointSelection? recoveryPointSelection, Map< String, String> ? tags}) → Future<CreateLegalHoldOutput> - Creates a legal hold on a recovery point (backup). A legal hold is a restraint on altering or deleting a backup until an authorized user cancels the legal hold. Any actions to delete or disassociate a recovery point will fail with an error if one or more active legal holds are on the recovery point.
-
createLogicallyAirGappedBackupVault(
{required String backupVaultName, required int maxRetentionDays, required int minRetentionDays, Map< String, String> ? backupVaultTags, String? creatorRequestId, String? encryptionKeyArn}) → Future<CreateLogicallyAirGappedBackupVaultOutput> - Creates a logical container to where backups may be copied.
-
createReportPlan(
{required ReportDeliveryChannel reportDeliveryChannel, required String reportPlanName, required ReportSetting reportSetting, String? idempotencyToken, String? reportPlanDescription, Map< String, String> ? reportPlanTags}) → Future<CreateReportPlanOutput> - Creates a report plan. A report plan is a document that contains information about the contents of the report and where Backup will deliver it.
-
createRestoreAccessBackupVault(
{required String sourceBackupVaultArn, String? backupVaultName, Map< String, String> ? backupVaultTags, String? creatorRequestId, String? requesterComment}) → Future<CreateRestoreAccessBackupVaultOutput> - Creates a restore access backup vault that provides temporary access to recovery points in a logically air-gapped backup vault, subject to MPA approval.
-
createRestoreTestingPlan(
{required RestoreTestingPlanForCreate restoreTestingPlan, String? creatorRequestId, Map< String, String> ? tags}) → Future<CreateRestoreTestingPlanOutput> - Creates a restore testing plan.
-
createRestoreTestingSelection(
{required String restoreTestingPlanName, required RestoreTestingSelectionForCreate restoreTestingSelection, String? creatorRequestId}) → Future< CreateRestoreTestingSelectionOutput> - This request can be sent after CreateRestoreTestingPlan request returns successfully. This is the second part of creating a resource testing plan, and it must be completed sequentially.
-
createTieringConfiguration(
{required TieringConfigurationInputForCreate tieringConfiguration, String? creatorRequestId, Map< String, String> ? tieringConfigurationTags}) → Future<CreateTieringConfigurationOutput> - Creates a tiering configuration.
-
deleteBackupPlan(
{required String backupPlanId}) → Future< DeleteBackupPlanOutput> - Deletes a backup plan. A backup plan can only be deleted after all associated selections of resources have been deleted. Deleting a backup plan deletes the current version of a backup plan. Previous versions, if any, will still exist.
-
deleteBackupSelection(
{required String backupPlanId, required String selectionId}) → Future< void> -
Deletes the resource selection associated with a backup plan that is
specified by the
SelectionId. -
deleteBackupVault(
{required String backupVaultName}) → Future< void> - Deletes the backup vault identified by its name. A vault can be deleted only if it is empty.
-
deleteBackupVaultAccessPolicy(
{required String backupVaultName}) → Future< void> - Deletes the policy document that manages permissions on a backup vault.
-
deleteBackupVaultLockConfiguration(
{required String backupVaultName}) → Future< void> - Deletes Backup Vault Lock from a backup vault specified by a backup vault name.
-
deleteBackupVaultNotifications(
{required String backupVaultName}) → Future< void> - Deletes event notifications for the specified backup vault.
-
deleteFramework(
{required String frameworkName}) → Future< void> - Deletes the framework specified by a framework name.
-
deleteRecoveryPoint(
{required String backupVaultName, required String recoveryPointArn}) → Future< void> - Deletes the recovery point specified by a recovery point ID.
-
deleteReportPlan(
{required String reportPlanName}) → Future< void> - Deletes the report plan specified by a report plan name.
-
deleteRestoreTestingPlan(
{required String restoreTestingPlanName}) → Future< void> - This request deletes the specified restore testing plan.
-
deleteRestoreTestingSelection(
{required String restoreTestingPlanName, required String restoreTestingSelectionName}) → Future< void> - Input the Restore Testing Plan name and Restore Testing Selection name.
-
deleteTieringConfiguration(
{required String tieringConfigurationName}) → Future< void> - Deletes the tiering configuration specified by a tiering configuration name.
-
describeBackupJob(
{required String backupJobId}) → Future< DescribeBackupJobOutput> -
Returns backup job details for the specified
BackupJobId. -
describeBackupVault(
{required String backupVaultName, String? backupVaultAccountId}) → Future< DescribeBackupVaultOutput> - Returns metadata about a backup vault specified by its name.
-
describeCopyJob(
{required String copyJobId}) → Future< DescribeCopyJobOutput> - Returns metadata associated with creating a copy of a resource.
-
describeFramework(
{required String frameworkName}) → Future< DescribeFrameworkOutput> -
Returns the framework details for the specified
FrameworkName. -
describeGlobalSettings(
) → Future< DescribeGlobalSettingsOutput> -
Describes whether the Amazon Web Services account has enabled different
cross-account management options, including cross-account backup,
multi-party approval, and delegated administrator. Returns an error if the
account is not a member of an Organizations organization. Example:
describe-global-settings --region us-west-2 -
describeProtectedResource(
{required String resourceArn}) → Future< DescribeProtectedResourceOutput> - Returns information about a saved resource, including the last time it was backed up, its Amazon Resource Name (ARN), and the Amazon Web Services service type of the saved resource.
-
describeRecoveryPoint(
{required String backupVaultName, required String recoveryPointArn, String? backupVaultAccountId}) → Future< DescribeRecoveryPointOutput> - Returns metadata associated with a recovery point, including ID, status, encryption, and lifecycle.
-
describeRegionSettings(
) → Future< DescribeRegionSettingsOutput> - Returns the current service opt-in settings for the Region. If service opt-in is enabled for a service, Backup tries to protect that service's resources in this Region, when the resource is included in an on-demand backup or scheduled backup plan. Otherwise, Backup does not try to protect that service's resources in this Region.
-
describeReportJob(
{required String reportJobId}) → Future< DescribeReportJobOutput> -
Returns the details associated with creating a report as specified by its
ReportJobId. -
describeReportPlan(
{required String reportPlanName}) → Future< DescribeReportPlanOutput> - Returns a list of all report plans for an Amazon Web Services account and Amazon Web Services Region.
-
describeRestoreJob(
{required String restoreJobId}) → Future< DescribeRestoreJobOutput> - Returns metadata associated with a restore job that is specified by a job ID.
-
describeScanJob(
{required String scanJobId}) → Future< DescribeScanJobOutput> - Returns scan job details for the specified ScanJobID.
-
disassociateBackupVaultMpaApprovalTeam(
{required String backupVaultName, String? requesterComment}) → Future< void> - Removes the association between an MPA approval team and a backup vault, disabling the MPA approval workflow for restore operations.
-
disassociateRecoveryPoint(
{required String backupVaultName, required String recoveryPointArn}) → Future< void> - Deletes the specified continuous backup recovery point from Backup and releases control of that continuous backup to the source service, such as Amazon RDS. The source service will continue to create and retain continuous backups using the lifecycle that you specified in your original backup plan.
-
disassociateRecoveryPointFromParent(
{required String backupVaultName, required String recoveryPointArn}) → Future< void> - This action to a specific child (nested) recovery point removes the relationship between the specified recovery point and its parent (composite) recovery point.
-
exportBackupPlanTemplate(
{required String backupPlanId}) → Future< ExportBackupPlanTemplateOutput> - Returns the backup plan that is specified by the plan ID as a backup template.
-
getBackupPlan(
{required String backupPlanId, int? maxScheduledRunsPreview, String? versionId}) → Future< GetBackupPlanOutput> -
Returns
BackupPlandetails for the specifiedBackupPlanId. The details are the body of a backup plan in JSON format, in addition to plan metadata. -
getBackupPlanFromJSON(
{required String backupPlanTemplateJson}) → Future< GetBackupPlanFromJSONOutput> - Returns a valid JSON document specifying a backup plan or an error.
-
getBackupPlanFromTemplate(
{required String backupPlanTemplateId}) → Future< GetBackupPlanFromTemplateOutput> -
Returns the template specified by its
templateIdas a backup plan. -
getBackupSelection(
{required String backupPlanId, required String selectionId}) → Future< GetBackupSelectionOutput> - Returns selection metadata and a document in JSON format that specifies a list of resources that are associated with a backup plan.
-
getBackupVaultAccessPolicy(
{required String backupVaultName}) → Future< GetBackupVaultAccessPolicyOutput> - Returns the access policy document that is associated with the named backup vault.
-
getBackupVaultNotifications(
{required String backupVaultName}) → Future< GetBackupVaultNotificationsOutput> - Returns event notifications for the specified backup vault.
-
getLegalHold(
{required String legalHoldId}) → Future< GetLegalHoldOutput> - This action returns details for a specified legal hold. The details are the body of a legal hold in JSON format, in addition to metadata.
-
getPITRMalwareScanResults(
{required String backupVaultName, required MalwareScanner malwareScanner, required String recoveryPointArn, required DateTime scanEndTime}) → Future< GetPITRMalwareScanResultsOutput> - Returns the malware scan results for a specified point in time within a continuous (point-in-time recovery) backup.
-
getRecoveryPointIndexDetails(
{required String backupVaultName, required String recoveryPointArn}) → Future< GetRecoveryPointIndexDetailsOutput> - This operation returns the metadata and details specific to the backup index associated with the specified recovery point.
-
getRecoveryPointRestoreMetadata(
{required String backupVaultName, required String recoveryPointArn, String? backupVaultAccountId}) → Future< GetRecoveryPointRestoreMetadataOutput> - Returns a set of metadata key-value pairs that were used to create the backup.
-
getRestoreJobMetadata(
{required String restoreJobId}) → Future< GetRestoreJobMetadataOutput> - This request returns the metadata for the specified restore job.
-
getRestoreTestingInferredMetadata(
{required String backupVaultName, required String recoveryPointArn, String? backupVaultAccountId}) → Future< GetRestoreTestingInferredMetadataOutput> -
This request returns the minimal required set of metadata needed to start
a restore job with secure default settings.
BackupVaultNameandRecoveryPointArnare required parameters.BackupVaultAccountIdis an optional parameter. -
getRestoreTestingPlan(
{required String restoreTestingPlanName}) → Future< GetRestoreTestingPlanOutput> -
Returns
RestoreTestingPlandetails for the specifiedRestoreTestingPlanName. The details are the body of a restore testing plan in JSON format, in addition to plan metadata. -
getRestoreTestingSelection(
{required String restoreTestingPlanName, required String restoreTestingSelectionName}) → Future< GetRestoreTestingSelectionOutput> - Returns RestoreTestingSelection, which displays resources and elements of the restore testing plan.
-
getSupportedResourceTypes(
) → Future< GetSupportedResourceTypesOutput> - Returns the Amazon Web Services resource types supported by Backup.
-
getTieringConfiguration(
{required String tieringConfigurationName}) → Future< GetTieringConfigurationOutput> -
Returns
TieringConfigurationdetails for the specifiedTieringConfigurationName. The details are the body of a tiering configuration in JSON format, in addition to configuration metadata. -
listBackupJobs(
{String? byAccountId, String? byBackupVaultName, DateTime? byCompleteAfter, DateTime? byCompleteBefore, DateTime? byCreatedAfter, DateTime? byCreatedBefore, String? byMessageCategory, String? byParentJobId, String? byResourceArn, String? byResourceType, BackupJobState? byState, int? maxResults, String? nextToken}) → Future< ListBackupJobsOutput> - Returns a list of existing backup jobs for an authenticated account for the last 30 days. For a longer period of time, consider using these monitoring tools.
-
listBackupJobSummaries(
{String? accountId, AggregationPeriod? aggregationPeriod, int? maxResults, String? messageCategory, String? nextToken, String? resourceType, BackupJobStatus? state}) → Future< ListBackupJobSummariesOutput> - This is a request for a summary of backup jobs created or running within the most recent 30 days. You can include parameters AccountID, State, ResourceType, MessageCategory, AggregationPeriod, MaxResults, or NextToken to filter results.
-
listBackupPlans(
{bool? includeDeleted, int? maxResults, String? nextToken}) → Future< ListBackupPlansOutput> - Lists the active backup plans for the account.
-
listBackupPlanTemplates(
{int? maxResults, String? nextToken}) → Future< ListBackupPlanTemplatesOutput> - Lists the backup plan templates.
-
listBackupPlanVersions(
{required String backupPlanId, int? maxResults, String? nextToken}) → Future< ListBackupPlanVersionsOutput> - Returns version metadata of your backup plans, including Amazon Resource Names (ARNs), backup plan IDs, creation and deletion dates, plan names, and version IDs.
-
listBackupSelections(
{required String backupPlanId, int? maxResults, String? nextToken}) → Future< ListBackupSelectionsOutput> - Returns an array containing metadata of the resources associated with the target backup plan.
-
listBackupVaults(
{VaultType? byVaultType, int? maxResults, String? nextToken}) → Future< ListBackupVaultsOutput> - Returns a list of recovery point storage containers along with information about them.
-
listCopyJobs(
{String? byAccountId, DateTime? byCompleteAfter, DateTime? byCompleteBefore, DateTime? byCreatedAfter, DateTime? byCreatedBefore, String? byDestinationVaultArn, String? byMessageCategory, String? byParentJobId, String? byResourceArn, String? byResourceType, String? bySourceRecoveryPointArn, CopyJobState? byState, int? maxResults, String? nextToken}) → Future< ListCopyJobsOutput> - Returns metadata about your copy jobs.
-
listCopyJobSummaries(
{String? accountId, AggregationPeriod? aggregationPeriod, int? maxResults, String? messageCategory, String? nextToken, String? resourceType, CopyJobStatus? state}) → Future< ListCopyJobSummariesOutput> - This request obtains a list of copy jobs created or running within the the most recent 30 days. You can include parameters AccountID, State, ResourceType, MessageCategory, AggregationPeriod, MaxResults, or NextToken to filter results.
-
listFrameworks(
{int? maxResults, String? nextToken}) → Future< ListFrameworksOutput> - Returns a list of all frameworks for an Amazon Web Services account and Amazon Web Services Region.
-
listIndexedRecoveryPoints(
{DateTime? createdAfter, DateTime? createdBefore, IndexStatus? indexStatus, int? maxResults, String? nextToken, String? resourceType, String? sourceResourceArn}) → Future< ListIndexedRecoveryPointsOutput> - This operation returns a list of recovery points that have an associated index, belonging to the specified account.
-
listLegalHolds(
{int? maxResults, String? nextToken}) → Future< ListLegalHoldsOutput> - This action returns metadata about active and previous legal holds.
-
listProtectedResources(
{int? maxResults, String? nextToken}) → Future< ListProtectedResourcesOutput> - Returns an array of resources successfully backed up by Backup, including the time the resource was saved, an Amazon Resource Name (ARN) of the resource, and a resource type.
-
listProtectedResourcesByBackupVault(
{required String backupVaultName, String? backupVaultAccountId, int? maxResults, String? nextToken}) → Future< ListProtectedResourcesByBackupVaultOutput> - This request lists the protected resources corresponding to each backup vault.
-
listRecoveryPointsByBackupVault(
{required String backupVaultName, String? backupVaultAccountId, String? byBackupPlanId, DateTime? byCreatedAfter, DateTime? byCreatedBefore, String? byParentRecoveryPointArn, String? byResourceArn, String? byResourceType, int? maxResults, String? nextToken}) → Future< ListRecoveryPointsByBackupVaultOutput> - Returns detailed information about the recovery points stored in a backup vault.
-
listRecoveryPointsByLegalHold(
{required String legalHoldId, int? maxResults, String? nextToken}) → Future< ListRecoveryPointsByLegalHoldOutput> - This action returns recovery point ARNs (Amazon Resource Names) of the specified legal hold.
-
listRecoveryPointsByResource(
{required String resourceArn, bool? managedByAWSBackupOnly, int? maxResults, String? nextToken}) → Future< ListRecoveryPointsByResourceOutput> - The information about the recovery points of the type specified by a resource Amazon Resource Name (ARN).
-
listReportJobs(
{DateTime? byCreationAfter, DateTime? byCreationBefore, String? byReportPlanName, String? byStatus, int? maxResults, String? nextToken}) → Future< ListReportJobsOutput> - Returns details about your report jobs.
-
listReportPlans(
{int? maxResults, String? nextToken}) → Future< ListReportPlansOutput> -
Returns a list of your report plans. For detailed information about a
single report plan, use
DescribeReportPlan. -
listRestoreAccessBackupVaults(
{required String backupVaultName, int? maxResults, String? nextToken}) → Future< ListRestoreAccessBackupVaultsOutput> - Returns a list of restore access backup vaults associated with a specified backup vault.
-
listRestoreJobs(
{String? byAccountId, DateTime? byCompleteAfter, DateTime? byCompleteBefore, DateTime? byCreatedAfter, DateTime? byCreatedBefore, String? byParentJobId, String? byResourceType, String? byRestoreTestingPlanArn, RestoreJobStatus? byStatus, int? maxResults, String? nextToken}) → Future< ListRestoreJobsOutput> - Returns a list of jobs that Backup initiated to restore a saved resource, including details about the recovery process.
-
listRestoreJobsByProtectedResource(
{required String resourceArn, DateTime? byRecoveryPointCreationDateAfter, DateTime? byRecoveryPointCreationDateBefore, RestoreJobStatus? byStatus, int? maxResults, String? nextToken}) → Future< ListRestoreJobsByProtectedResourceOutput> - This returns restore jobs that contain the specified protected resource.
-
listRestoreJobSummaries(
{String? accountId, AggregationPeriod? aggregationPeriod, int? maxResults, String? nextToken, String? resourceType, RestoreJobState? state}) → Future< ListRestoreJobSummariesOutput> - This request obtains a summary of restore jobs created or running within the the most recent 30 days. You can include parameters AccountID, State, ResourceType, AggregationPeriod, MaxResults, or NextToken to filter results.
-
listRestoreTestingPlans(
{int? maxResults, String? nextToken}) → Future< ListRestoreTestingPlansOutput> - Returns a list of restore testing plans.
-
listRestoreTestingSelections(
{required String restoreTestingPlanName, int? maxResults, String? nextToken}) → Future< ListRestoreTestingSelectionsOutput> -
Returns a list of restore testing selections. Can be filtered by
MaxResultsandRestoreTestingPlanName. -
listScanJobs(
{String? byAccountId, String? byBackupVaultName, DateTime? byCompleteAfter, DateTime? byCompleteBefore, MalwareScanner? byMalwareScanner, String? byRecoveryPointArn, String? byResourceArn, ScanResourceType? byResourceType, ScanResultStatus? byScanResultStatus, ScanState? byState, int? maxResults, String? nextToken}) → Future< ListScanJobsOutput> - Returns a list of existing scan jobs for an authenticated account for the last 30 days.
-
listScanJobSummaries(
{String? accountId, AggregationPeriod? aggregationPeriod, MalwareScanner? malwareScanner, int? maxResults, String? nextToken, String? resourceType, ScanResultStatus? scanResultStatus, ScanJobStatus? state}) → Future< ListScanJobSummariesOutput> - This is a request for a summary of scan jobs created or running within the most recent 30 days.
-
listTags(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListTagsOutput> - Returns the tags assigned to the resource, such as a target recovery point, backup plan, or backup vault.
-
listTieringConfigurations(
{int? maxResults, String? nextToken}) → Future< ListTieringConfigurationsOutput> - Returns a list of tiering configurations.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putBackupVaultAccessPolicy(
{required String backupVaultName, String? policy}) → Future< void> - Sets a resource-based policy that is used to manage access permissions on the target backup vault. Requires a backup vault name and an access policy document in JSON format.
-
putBackupVaultLockConfiguration(
{required String backupVaultName, int? changeableForDays, int? maxRetentionDays, int? minRetentionDays}) → Future< void> - Applies Backup Vault Lock to a backup vault, preventing attempts to delete any recovery point stored in or created in a backup vault. Vault Lock also prevents attempts to update the lifecycle policy that controls the retention period of any recovery point currently stored in a backup vault. If specified, Vault Lock enforces a minimum and maximum retention period for future backup and copy jobs that target a backup vault. For more information, see Backup Vault Lock.
-
putBackupVaultNotifications(
{required List< BackupVaultEvent> backupVaultEvents, required String backupVaultName, required String sNSTopicArn}) → Future<void> - Turns on notifications on a backup vault for the specified topic and events.
-
putRestoreValidationResult(
{required String restoreJobId, required RestoreValidationStatus validationStatus, String? validationStatusMessage}) → Future< void> -
This request allows you to send your independent self-run restore test
validation results.
RestoreJobIdandValidationStatusare required. Optionally, you can input aValidationStatusMessage. -
revokeRestoreAccessBackupVault(
{required String backupVaultName, required String restoreAccessBackupVaultArn, String? requesterComment}) → Future< void> - Revokes access to a restore access backup vault, removing the ability to restore from its recovery points and permanently deleting the vault.
-
startBackupJob(
{required String backupVaultName, required String iamRoleArn, required String resourceArn, Map< String, String> ? backupOptions, int? completeWindowMinutes, String? idempotencyToken, Index? index, Lifecycle? lifecycle, String? logicallyAirGappedBackupVaultArn, Map<String, String> ? recoveryPointTags, int? startWindowMinutes}) → Future<StartBackupJobOutput> - Starts an on-demand backup job for the specified resource.
-
startCopyJob(
{required String destinationBackupVaultArn, required String iamRoleArn, required String recoveryPointArn, required String sourceBackupVaultName, String? idempotencyToken, Lifecycle? lifecycle}) → Future< StartCopyJobOutput> - Starts a job to create a one-time copy of the specified resource.
-
startReportJob(
{required String reportPlanName, String? idempotencyToken}) → Future< StartReportJobOutput> - Starts an on-demand report job for the specified report plan.
-
startRestoreJob(
{required Map< String, String> metadata, required String recoveryPointArn, bool? copySourceTagsToRestoredResource, String? iamRoleArn, String? idempotencyToken, String? resourceType}) → Future<StartRestoreJobOutput> - Recovers the saved resource identified by an Amazon Resource Name (ARN).
-
startScanJob(
{required String backupVaultName, required String iamRoleArn, required MalwareScanner malwareScanner, required String recoveryPointArn, required ScanMode scanMode, required String scannerRoleArn, DateTime? continuousScanEndTime, String? idempotencyToken, String? scanBaseRecoveryPointArn}) → Future< StartScanJobOutput> - Starts scanning jobs for specific resources.
-
stopBackupJob(
{required String backupJobId}) → Future< void> - Attempts to cancel a job to create a one-time backup of a resource.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns a set of key-value pairs to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeyList}) → Future<void> - Removes a set of key-value pairs from a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)
-
updateBackupPlan(
{required BackupPlanInput backupPlan, required String backupPlanId}) → Future< UpdateBackupPlanOutput> - Updates the specified backup plan. The new version is uniquely identified by its ID.
-
updateFramework(
{required String frameworkName, List< FrameworkControl> ? frameworkControls, String? frameworkDescription, String? idempotencyToken}) → Future<UpdateFrameworkOutput> - Updates the specified framework.
-
updateGlobalSettings(
{Map< String, String> ? globalSettings}) → Future<void> -
Updates whether the Amazon Web Services account has enabled different
cross-account management options, including cross-account backup,
multi-party approval, and delegated administrator. Returns an error if the
account is not an Organizations management account. Use the
DescribeGlobalSettingsAPI to determine the current settings. -
updateRecoveryPointIndexSettings(
{required String backupVaultName, required Index index, required String recoveryPointArn, String? iamRoleArn}) → Future< UpdateRecoveryPointIndexSettingsOutput> - This operation updates the settings of a recovery point index.
-
updateRecoveryPointLifecycle(
{required String backupVaultName, required String recoveryPointArn, Lifecycle? lifecycle}) → Future< UpdateRecoveryPointLifecycleOutput> - Sets the transition lifecycle of a recovery point.
-
updateRegionSettings(
{Map< String, bool> ? resourceTypeManagementPreference, Map<String, bool> ? resourceTypeOptInPreference}) → Future<void> - Updates the current service opt-in settings for the Region.
-
updateReportPlan(
{required String reportPlanName, String? idempotencyToken, ReportDeliveryChannel? reportDeliveryChannel, String? reportPlanDescription, ReportSetting? reportSetting}) → Future< UpdateReportPlanOutput> - Updates the specified report plan.
-
updateRestoreTestingPlan(
{required RestoreTestingPlanForUpdate restoreTestingPlan, required String restoreTestingPlanName}) → Future< UpdateRestoreTestingPlanOutput> -
This request will send changes to your specified restore testing plan.
RestoreTestingPlanNamecannot be updated after it is created. -
updateRestoreTestingSelection(
{required String restoreTestingPlanName, required RestoreTestingSelectionForUpdate restoreTestingSelection, required String restoreTestingSelectionName}) → Future< UpdateRestoreTestingSelectionOutput> - Updates the specified restore testing selection.
-
updateTieringConfiguration(
{required TieringConfigurationInputForUpdate tieringConfiguration, required String tieringConfigurationName}) → Future< UpdateTieringConfigurationOutput> -
This request will send changes to your specified tiering configuration.
TieringConfigurationNamecannot be updated after it is created.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited