deleteBackupPlan method
Deletes a backup plan. A backup plan can only be deleted after all associated selections of resources have been deleted. Deleting a backup plan deletes the current version of a backup plan. Previous versions, if any, will still exist.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupPlanId :
Uniquely identifies a backup plan.
Implementation
Future<DeleteBackupPlanOutput> deleteBackupPlan({
required String backupPlanId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/backup/plans/${Uri.encodeComponent(backupPlanId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteBackupPlanOutput.fromJson(response);
}