deleteBackupSelection method
Deletes the resource selection associated with a backup plan that is
specified by the SelectionId.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupPlanId :
Uniquely identifies a backup plan.
Parameter selectionId :
Uniquely identifies the body of a request to assign a set of resources to
a backup plan.
Implementation
Future<void> deleteBackupSelection({
required String backupPlanId,
required String selectionId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/backup/plans/${Uri.encodeComponent(backupPlanId)}/selections/${Uri.encodeComponent(selectionId)}',
exceptionFnMap: _exceptionFns,
);
}