deleteBackupVaultAccessPolicy method
Deletes the policy document that manages permissions on a backup vault.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created. They consist of
lowercase letters, numbers, and hyphens.
Implementation
Future<void> deleteBackupVaultAccessPolicy({
required String backupVaultName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/access-policy',
exceptionFnMap: _exceptionFns,
);
}