deleteRestoreTestingPlan method

Future<void> deleteRestoreTestingPlan({
  1. required String restoreTestingPlanName,
})

This request deletes the specified restore testing plan.

Deletion can only successfully occur if all associated restore testing selections are deleted first.

May throw InvalidRequestException. May throw ServiceUnavailableException.

Parameter restoreTestingPlanName : Required unique name of the restore testing plan you wish to delete.

Implementation

Future<void> deleteRestoreTestingPlan({
  required String restoreTestingPlanName,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/restore-testing/plans/${Uri.encodeComponent(restoreTestingPlanName)}',
    exceptionFnMap: _exceptionFns,
  );
}