describeBackupVault method

Future<DescribeBackupVaultOutput> describeBackupVault({
  1. required String backupVaultName,
  2. String? backupVaultAccountId,
})

Returns metadata about a backup vault specified by its name.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Parameter backupVaultAccountId : The account ID of the specified backup vault.

Implementation

Future<DescribeBackupVaultOutput> describeBackupVault({
  required String backupVaultName,
  String? backupVaultAccountId,
}) async {
  final $query = <String, List<String>>{
    if (backupVaultAccountId != null)
      'backupVaultAccountId': [backupVaultAccountId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/backup-vaults/${Uri.encodeComponent(backupVaultName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeBackupVaultOutput.fromJson(response);
}