describeProtectedResource method

Future<DescribeProtectedResourceOutput> describeProtectedResource({
  1. required String resourceArn,
})

Returns information about a saved resource, including the last time it was backed up, its Amazon Resource Name (ARN), and the Amazon Web Services service type of the saved resource.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter resourceArn : An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.

Implementation

Future<DescribeProtectedResourceOutput> describeProtectedResource({
  required String resourceArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/resources/${Uri.encodeComponent(resourceArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeProtectedResourceOutput.fromJson(response);
}