describeRecoveryPoint method
Returns metadata associated with a recovery point, including ID, status, encryption, and lifecycle.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created.
Parameter recoveryPointArn :
An Amazon Resource Name (ARN) that uniquely identifies a recovery point;
for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Parameter backupVaultAccountId :
The account ID of the specified backup vault.
Implementation
Future<DescribeRecoveryPointOutput> describeRecoveryPoint({
required String backupVaultName,
required String recoveryPointArn,
String? backupVaultAccountId,
}) async {
final $query = <String, List<String>>{
if (backupVaultAccountId != null)
'backupVaultAccountId': [backupVaultAccountId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points/${Uri.encodeComponent(recoveryPointArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeRecoveryPointOutput.fromJson(response);
}