describeReportPlan method

Future<DescribeReportPlanOutput> describeReportPlan({
  1. required String reportPlanName,
})

Returns a list of all report plans for an Amazon Web Services account and Amazon Web Services Region.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter reportPlanName : The unique name of a report plan.

Implementation

Future<DescribeReportPlanOutput> describeReportPlan({
  required String reportPlanName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/audit/report-plans/${Uri.encodeComponent(reportPlanName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeReportPlanOutput.fromJson(response);
}