describeRestoreJob method
Returns metadata associated with a restore job that is specified by a job ID.
May throw DependencyFailureException.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter restoreJobId :
Uniquely identifies the job that restores a recovery point.
Implementation
Future<DescribeRestoreJobOutput> describeRestoreJob({
required String restoreJobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/restore-jobs/${Uri.encodeComponent(restoreJobId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeRestoreJobOutput.fromJson(response);
}