disassociateBackupVaultMpaApprovalTeam method

Future<void> disassociateBackupVaultMpaApprovalTeam({
  1. required String backupVaultName,
  2. String? requesterComment,
})

Removes the association between an MPA approval team and a backup vault, disabling the MPA approval workflow for restore operations.

May throw InvalidParameterValueException. May throw InvalidRequestException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of the backup vault from which to disassociate the MPA approval team.

Parameter requesterComment : An optional comment explaining the reason for disassociating the MPA approval team from the backup vault.

Implementation

Future<void> disassociateBackupVaultMpaApprovalTeam({
  required String backupVaultName,
  String? requesterComment,
}) async {
  final $payload = <String, dynamic>{
    if (requesterComment != null) 'RequesterComment': requesterComment,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/backup-vaults/${Uri.encodeComponent(backupVaultName)}/mpaApprovalTeam?delete',
    exceptionFnMap: _exceptionFns,
  );
}