disassociateRecoveryPoint method

Future<void> disassociateRecoveryPoint({
  1. required String backupVaultName,
  2. required String recoveryPointArn,
})

Deletes the specified continuous backup recovery point from Backup and releases control of that continuous backup to the source service, such as Amazon RDS. The source service will continue to create and retain continuous backups using the lifecycle that you specified in your original backup plan.

Does not support snapshot backup recovery points.

May throw InvalidParameterValueException. May throw InvalidRequestException. May throw InvalidResourceStateException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The unique name of an Backup vault.

Parameter recoveryPointArn : An Amazon Resource Name (ARN) that uniquely identifies an Backup recovery point.

Implementation

Future<void> disassociateRecoveryPoint({
  required String backupVaultName,
  required String recoveryPointArn,
}) async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points/${Uri.encodeComponent(recoveryPointArn)}/disassociate',
    exceptionFnMap: _exceptionFns,
  );
}