disassociateRecoveryPointFromParent method

Future<void> disassociateRecoveryPointFromParent({
  1. required String backupVaultName,
  2. required String recoveryPointArn,
})

This action to a specific child (nested) recovery point removes the relationship between the specified recovery point and its parent (composite) recovery point.

May throw InvalidParameterValueException. May throw InvalidRequestException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of a logical container where the child (nested) recovery point is stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Parameter recoveryPointArn : The Amazon Resource Name (ARN) that uniquely identifies the child (nested) recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

Implementation

Future<void> disassociateRecoveryPointFromParent({
  required String backupVaultName,
  required String recoveryPointArn,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points/${Uri.encodeComponent(recoveryPointArn)}/parentAssociation',
    exceptionFnMap: _exceptionFns,
  );
}