getBackupVaultAccessPolicy method
Future<GetBackupVaultAccessPolicyOutput>
getBackupVaultAccessPolicy({
- required String backupVaultName,
Returns the access policy document that is associated with the named backup vault.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created.
Implementation
Future<GetBackupVaultAccessPolicyOutput> getBackupVaultAccessPolicy({
required String backupVaultName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/access-policy',
exceptionFnMap: _exceptionFns,
);
return GetBackupVaultAccessPolicyOutput.fromJson(response);
}