getBackupVaultNotifications method
Future<GetBackupVaultNotificationsOutput>
getBackupVaultNotifications({
- required String backupVaultName,
Returns event notifications for the specified backup vault.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created.
Implementation
Future<GetBackupVaultNotificationsOutput> getBackupVaultNotifications({
required String backupVaultName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/notification-configuration',
exceptionFnMap: _exceptionFns,
);
return GetBackupVaultNotificationsOutput.fromJson(response);
}