getRecoveryPointIndexDetails method

Future<GetRecoveryPointIndexDetailsOutput> getRecoveryPointIndexDetails({
  1. required String backupVaultName,
  2. required String recoveryPointArn,
})

This operation returns the metadata and details specific to the backup index associated with the specified recovery point.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.

Accepted characters include lowercase letters, numbers, and hyphens.

Parameter recoveryPointArn : An ARN that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

Implementation

Future<GetRecoveryPointIndexDetailsOutput> getRecoveryPointIndexDetails({
  required String backupVaultName,
  required String recoveryPointArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points/${Uri.encodeComponent(recoveryPointArn)}/index',
    exceptionFnMap: _exceptionFns,
  );
  return GetRecoveryPointIndexDetailsOutput.fromJson(response);
}