listBackupJobSummaries method
This is a request for a summary of backup jobs created or running within the most recent 30 days. You can include parameters AccountID, State, ResourceType, MessageCategory, AggregationPeriod, MaxResults, or NextToken to filter results.
This request returns a summary that contains Region, Account, State, ResourceType, MessageCategory, StartTime, EndTime, and Count of included jobs.
May throw InvalidParameterValueException.
May throw ServiceUnavailableException.
Parameter accountId :
Returns the job count for the specified account.
If the request is sent from a member account or an account not part of Amazon Web Services Organizations, jobs within requestor's account will be returned.
Root, admin, and delegated administrator accounts can use the value ANY to return job counts from every account in the organization.
AGGREGATE_ALL aggregates job counts from all accounts within
the authenticated organization, then returns the sum.
Parameter aggregationPeriod :
The period for the returned results.
-
ONE_DAY- The daily job count for the prior 14 days. -
SEVEN_DAYS- The aggregated job count for the prior 7 days. -
FOURTEEN_DAYS- The aggregated job count for prior 14 days.
Parameter maxResults :
The maximum number of items to be returned.
The value is an integer. Range of accepted values is from 1 to 500.
Parameter messageCategory :
This parameter returns the job count for the specified message category.
Example accepted strings include AccessDenied,
Success, and InvalidParameters. See Monitoring
for a list of accepted MessageCategory strings.
The the value ANY returns count of all message categories.
AGGREGATE_ALL aggregates job counts for all message
categories and returns the sum.
Parameter nextToken :
The next item following a partial list of returned resources. For example,
if a request is made to return MaxResults number of
resources, NextToken allows you to return more items in your
list starting at the location pointed to by the next token.
Parameter resourceType :
Returns the job count for the specified resource type. Use request
GetSupportedResourceTypes to obtain strings for supported
resource types.
The the value ANY returns count of all resource types.
AGGREGATE_ALL aggregates job counts for all resource types
and returns the sum.
The type of Amazon Web Services resource to be backed up; for example, an Amazon Elastic Block Store (Amazon EBS) volume or an Amazon Relational Database Service (Amazon RDS) database.
Parameter state :
This parameter returns the job count for jobs with the specified state.
The the value ANY returns count of all states.
AGGREGATE_ALL aggregates job counts for all states and
returns the sum.
Completed with issues is a status found only in the Backup
console. For API, this status refers to jobs with a state of
COMPLETED and a MessageCategory with a value
other than SUCCESS; that is, the status is completed but
comes with a status message. To obtain the job count for Completed
with issues, run two GET requests, and subtract the second, smaller
number:
GET /audit/backup-job-summaries?AggregationPeriod=FOURTEEN_DAYS&State=COMPLETED
GET /audit/backup-job-summaries?AggregationPeriod=FOURTEEN_DAYS&MessageCategory=SUCCESS&State=COMPLETED
Implementation
Future<ListBackupJobSummariesOutput> listBackupJobSummaries({
String? accountId,
AggregationPeriod? aggregationPeriod,
int? maxResults,
String? messageCategory,
String? nextToken,
String? resourceType,
BackupJobStatus? state,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (accountId != null) 'AccountId': [accountId],
if (aggregationPeriod != null)
'AggregationPeriod': [aggregationPeriod.value],
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (messageCategory != null) 'MessageCategory': [messageCategory],
if (nextToken != null) 'NextToken': [nextToken],
if (resourceType != null) 'ResourceType': [resourceType],
if (state != null) 'State': [state.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/audit/backup-job-summaries',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListBackupJobSummariesOutput.fromJson(response);
}