listBackupJobs method
- String? byAccountId,
- String? byBackupVaultName,
- DateTime? byCompleteAfter,
- DateTime? byCompleteBefore,
- DateTime? byCreatedAfter,
- DateTime? byCreatedBefore,
- String? byMessageCategory,
- String? byParentJobId,
- String? byResourceArn,
- String? byResourceType,
- BackupJobState? byState,
- int? maxResults,
- String? nextToken,
Returns a list of existing backup jobs for an authenticated account for the last 30 days. For a longer period of time, consider using these monitoring tools.
May throw InvalidParameterValueException.
May throw ServiceUnavailableException.
Parameter byAccountId :
The account ID to list the jobs from. Returns only backup jobs associated
with the specified account ID.
If used from an Organizations management account, passing *
returns all jobs across the organization.
Parameter byBackupVaultName :
Returns only backup jobs that will be stored in the specified backup
vault. Backup vaults are identified by names that are unique to the
account used to create them and the Amazon Web Services Region where they
are created.
Parameter byCompleteAfter :
Returns only backup jobs completed after a date expressed in Unix format
and Coordinated Universal Time (UTC).
Parameter byCompleteBefore :
Returns only backup jobs completed before a date expressed in Unix format
and Coordinated Universal Time (UTC).
Parameter byCreatedAfter :
Returns only backup jobs that were created after the specified date.
Parameter byCreatedBefore :
Returns only backup jobs that were created before the specified date.
Parameter byMessageCategory :
This is an optional parameter that can be used to filter out jobs with a
MessageCategory which matches the value you input.
Example strings may include AccessDenied,
SUCCESS, AGGREGATE_ALL, and
InvalidParameters.
View Monitoring
The wildcard () returns count of all message categories.
AGGREGATE_ALL aggregates job counts for all message
categories and returns the sum.
Parameter byParentJobId :
This is a filter to list child (nested) jobs based on parent job ID.
Parameter byResourceArn :
Returns only backup jobs that match the specified resource Amazon Resource
Name (ARN).
Parameter byResourceType :
Returns only backup jobs for the specified resources:
-
Aurorafor Amazon Aurora -
CloudFormationfor CloudFormation -
DocumentDBfor Amazon DocumentDB (with MongoDB compatibility) -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
EKSfor Amazon Elastic Kubernetes Service -
FSxfor Amazon FSx -
Neptunefor Amazon Neptune -
RDSfor Amazon Relational Database Service -
Redshiftfor Amazon Redshift -
S3for Amazon Simple Storage Service (Amazon S3) -
SAP HANA on Amazon EC2for SAP HANA databases on Amazon Elastic Compute Cloud instances -
Storage Gatewayfor Storage Gateway -
Timestreamfor Amazon Timestream -
VirtualMachinefor VMware virtual machines
Parameter byState :
Returns only backup jobs that are in the specified state.
Completed with issues is a status found only in the Backup
console. For API, this status refers to jobs with a state of
COMPLETED and a MessageCategory with a value
other than SUCCESS; that is, the status is completed but
comes with a status message.
To obtain the job count for Completed with issues, run two
GET requests, and subtract the second, smaller number:
GET /backup-jobs/?state=COMPLETED
GET /backup-jobs/?messageCategory=SUCCESS&state=COMPLETED
Parameter maxResults :
The maximum number of items to be returned.
Parameter nextToken :
The next item following a partial list of returned items. For example, if
a request is made to return MaxResults number of items,
NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
Implementation
Future<ListBackupJobsOutput> listBackupJobs({
String? byAccountId,
String? byBackupVaultName,
DateTime? byCompleteAfter,
DateTime? byCompleteBefore,
DateTime? byCreatedAfter,
DateTime? byCreatedBefore,
String? byMessageCategory,
String? byParentJobId,
String? byResourceArn,
String? byResourceType,
BackupJobState? byState,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (byAccountId != null) 'accountId': [byAccountId],
if (byBackupVaultName != null) 'backupVaultName': [byBackupVaultName],
if (byCompleteAfter != null)
'completeAfter': [_s.iso8601ToJson(byCompleteAfter).toString()],
if (byCompleteBefore != null)
'completeBefore': [_s.iso8601ToJson(byCompleteBefore).toString()],
if (byCreatedAfter != null)
'createdAfter': [_s.iso8601ToJson(byCreatedAfter).toString()],
if (byCreatedBefore != null)
'createdBefore': [_s.iso8601ToJson(byCreatedBefore).toString()],
if (byMessageCategory != null) 'messageCategory': [byMessageCategory],
if (byParentJobId != null) 'parentJobId': [byParentJobId],
if (byResourceArn != null) 'resourceArn': [byResourceArn],
if (byResourceType != null) 'resourceType': [byResourceType],
if (byState != null) 'state': [byState.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/backup-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListBackupJobsOutput.fromJson(response);
}