listBackupPlanTemplates method
Lists the backup plan templates.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter maxResults :
The maximum number of items to return.
Parameter nextToken :
The next item following a partial list of returned items. For example, if
a request is made to return MaxResults number of items,
NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
Implementation
Future<ListBackupPlanTemplatesOutput> listBackupPlanTemplates({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/backup/template/plans',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListBackupPlanTemplatesOutput.fromJson(response);
}