listBackupVaults method
Returns a list of recovery point storage containers along with information about them.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter byShared :
This parameter will sort the list of vaults by shared vaults.
Parameter byVaultType :
This parameter will sort the list of vaults by vault type.
Parameter maxResults :
The maximum number of items to be returned.
Parameter nextToken :
The next item following a partial list of returned items. For example, if
a request is made to return MaxResults number of items,
NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
Implementation
Future<ListBackupVaultsOutput> listBackupVaults({
bool? byShared,
VaultType? byVaultType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (byShared != null) 'shared': [byShared.toString()],
if (byVaultType != null) 'vaultType': [byVaultType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/backup-vaults',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListBackupVaultsOutput.fromJson(response);
}