listFrameworks method
Returns a list of all frameworks for an Amazon Web Services account and Amazon Web Services Region.
May throw InvalidParameterValueException.
May throw ServiceUnavailableException.
Parameter maxResults :
The number of desired results from 1 to 1000. Optional. If unspecified,
the query will return 1 MB of data.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which can be used to return the next set of items in the list.
Implementation
Future<ListFrameworksOutput> listFrameworks({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/audit/frameworks',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFrameworksOutput.fromJson(response);
}