listLegalHolds method
This action returns metadata about active and previous legal holds.
May throw InvalidParameterValueException.
May throw ServiceUnavailableException.
Parameter maxResults :
The maximum number of resource list items to be returned.
Parameter nextToken :
The next item following a partial list of returned resources. For example,
if a request is made to return MaxResults number of
resources, NextToken allows you to return more items in your
list starting at the location pointed to by the next token.
Implementation
Future<ListLegalHoldsOutput> listLegalHolds({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/legal-holds',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListLegalHoldsOutput.fromJson(response);
}