listRecoveryPointsByBackupVault method

Future<ListRecoveryPointsByBackupVaultOutput> listRecoveryPointsByBackupVault({
  1. required String backupVaultName,
  2. String? backupVaultAccountId,
  3. String? byBackupPlanId,
  4. DateTime? byCreatedAfter,
  5. DateTime? byCreatedBefore,
  6. String? byParentRecoveryPointArn,
  7. String? byResourceArn,
  8. String? byResourceType,
  9. int? maxResults,
  10. String? nextToken,
})

Returns detailed information about the recovery points stored in a backup vault.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Parameter backupVaultAccountId : This parameter will sort the list of recovery points by account ID.

Parameter byBackupPlanId : Returns only recovery points that match the specified backup plan ID.

Parameter byCreatedAfter : Returns only recovery points that were created after the specified timestamp.

Parameter byCreatedBefore : Returns only recovery points that were created before the specified timestamp.

Parameter byParentRecoveryPointArn : This returns only recovery points that match the specified parent (composite) recovery point Amazon Resource Name (ARN).

Parameter byResourceArn : Returns only recovery points that match the specified resource Amazon Resource Name (ARN).

Parameter byResourceType : Returns only recovery points that match the specified resource type(s):

  • Aurora for Amazon Aurora
  • CloudFormation for CloudFormation
  • DocumentDB for Amazon DocumentDB (with MongoDB compatibility)
  • DynamoDB for Amazon DynamoDB
  • EBS for Amazon Elastic Block Store
  • EC2 for Amazon Elastic Compute Cloud
  • EFS for Amazon Elastic File System
  • EKS for Amazon Elastic Kubernetes Service
  • FSx for Amazon FSx
  • Neptune for Amazon Neptune
  • RDS for Amazon Relational Database Service
  • Redshift for Amazon Redshift
  • S3 for Amazon Simple Storage Service (Amazon S3)
  • SAP HANA on Amazon EC2 for SAP HANA databases on Amazon Elastic Compute Cloud instances
  • Storage Gateway for Storage Gateway
  • Timestream for Amazon Timestream
  • VirtualMachine for VMware virtual machines

Parameter maxResults : The maximum number of items to be returned.

Parameter nextToken : The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Implementation

Future<ListRecoveryPointsByBackupVaultOutput>
    listRecoveryPointsByBackupVault({
  required String backupVaultName,
  String? backupVaultAccountId,
  String? byBackupPlanId,
  DateTime? byCreatedAfter,
  DateTime? byCreatedBefore,
  String? byParentRecoveryPointArn,
  String? byResourceArn,
  String? byResourceType,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (backupVaultAccountId != null)
      'backupVaultAccountId': [backupVaultAccountId],
    if (byBackupPlanId != null) 'backupPlanId': [byBackupPlanId],
    if (byCreatedAfter != null)
      'createdAfter': [_s.iso8601ToJson(byCreatedAfter).toString()],
    if (byCreatedBefore != null)
      'createdBefore': [_s.iso8601ToJson(byCreatedBefore).toString()],
    if (byParentRecoveryPointArn != null)
      'parentRecoveryPointArn': [byParentRecoveryPointArn],
    if (byResourceArn != null) 'resourceArn': [byResourceArn],
    if (byResourceType != null) 'resourceType': [byResourceType],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRecoveryPointsByBackupVaultOutput.fromJson(response);
}