listRestoreAccessBackupVaults method

Future<ListRestoreAccessBackupVaultsOutput> listRestoreAccessBackupVaults({
  1. required String backupVaultName,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of restore access backup vaults associated with a specified backup vault.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupVaultName : The name of the backup vault for which to list associated restore access backup vaults.

Parameter maxResults : The maximum number of items to return in the response.

Parameter nextToken : The pagination token from a previous request to retrieve the next set of results.

Implementation

Future<ListRestoreAccessBackupVaultsOutput> listRestoreAccessBackupVaults({
  required String backupVaultName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/logically-air-gapped-backup-vaults/${Uri.encodeComponent(backupVaultName)}/restore-access-backup-vaults',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRestoreAccessBackupVaultsOutput.fromJson(response);
}