listRestoreTestingPlans method
Returns a list of restore testing plans.
May throw InvalidParameterValueException.
May throw ServiceUnavailableException.
Parameter maxResults :
The maximum number of items to be returned.
Parameter nextToken :
The next item following a partial list of returned items. For example, if
a request is made to return MaxResults number of items,
NextToken allows you to return more items in your list
starting at the location pointed to by the nexttoken.
Implementation
Future<ListRestoreTestingPlansOutput> listRestoreTestingPlans({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/restore-testing/plans',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRestoreTestingPlansOutput.fromJson(response);
}