listRestoreTestingSelections method

Future<ListRestoreTestingSelectionsOutput> listRestoreTestingSelections({
  1. required String restoreTestingPlanName,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of restore testing selections. Can be filtered by MaxResults and RestoreTestingPlanName.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter restoreTestingPlanName : Returns restore testing selections by the specified restore testing plan name.

Parameter maxResults : The maximum number of items to be returned.

Parameter nextToken : The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the nexttoken.

Implementation

Future<ListRestoreTestingSelectionsOutput> listRestoreTestingSelections({
  required String restoreTestingPlanName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/restore-testing/plans/${Uri.encodeComponent(restoreTestingPlanName)}/selections',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRestoreTestingSelectionsOutput.fromJson(response);
}