startReportJob method

Future<StartReportJobOutput> startReportJob({
  1. required String reportPlanName,
  2. String? idempotencyToken,
})

Starts an on-demand report job for the specified report plan.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter reportPlanName : The unique name of a report plan.

Parameter idempotencyToken : A customer-chosen string that you can use to distinguish between otherwise identical calls to StartReportJobInput. Retrying a successful request with the same idempotency token results in a success message with no action taken.

Implementation

Future<StartReportJobOutput> startReportJob({
  required String reportPlanName,
  String? idempotencyToken,
}) async {
  final $payload = <String, dynamic>{
    'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/audit/report-jobs/${Uri.encodeComponent(reportPlanName)}',
    exceptionFnMap: _exceptionFns,
  );
  return StartReportJobOutput.fromJson(response);
}