stopBackupJob method

Future<void> stopBackupJob({
  1. required String backupJobId,
})

Attempts to cancel a job to create a one-time backup of a resource.

This action is not supported for the following services:

  • Amazon Aurora
  • Amazon DocumentDB (with MongoDB compatibility)
  • Amazon FSx for Lustre
  • Amazon FSx for NetApp ONTAP
  • Amazon FSx for OpenZFS
  • Amazon FSx for Windows File Server
  • Amazon Neptune
  • SAP HANA databases on Amazon EC2 instances
  • Amazon RDS

May throw InvalidParameterValueException. May throw InvalidRequestException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter backupJobId : Uniquely identifies a request to Backup to back up a resource.

Implementation

Future<void> stopBackupJob({
  required String backupJobId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/backup-jobs/${Uri.encodeComponent(backupJobId)}',
    exceptionFnMap: _exceptionFns,
  );
}