untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeyList,
})

Removes a set of key-value pairs from a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)

This API is not supported for recovery points for resource types including Aurora, Amazon DocumentDB. Amazon EBS, Amazon FSx, Neptune, and Amazon RDS.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter resourceArn : An ARN that uniquely identifies a resource. The format of the ARN depends on the type of the tagged resource.

ARNs that do not include backup are incompatible with tagging. TagResource and UntagResource with invalid ARNs will result in an error. Acceptable ARN content can include arn:aws:backup:us-east. Invalid ARN content may look like arn:aws:ec2:us-east.

Parameter tagKeyList : The keys to identify which key-value tags to remove from a resource.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeyList,
}) async {
  final $payload = <String, dynamic>{
    'TagKeyList': tagKeyList,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/untag/${Uri.encodeComponent(resourceArn)}',
    exceptionFnMap: _exceptionFns,
  );
}