updateRestoreTestingSelection method

Future<UpdateRestoreTestingSelectionOutput> updateRestoreTestingSelection({
  1. required String restoreTestingPlanName,
  2. required RestoreTestingSelectionForUpdate restoreTestingSelection,
  3. required String restoreTestingSelectionName,
})

Updates the specified restore testing selection.

Most elements except the RestoreTestingSelectionName can be updated with this request.

You can use either protected resource ARNs or conditions, but not both.

May throw ConflictException. May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter restoreTestingPlanName : The restore testing plan name is required to update the indicated testing plan.

Parameter restoreTestingSelection : To update your restore testing selection, you can use either protected resource ARNs or conditions, but not both. That is, if your selection has ProtectedResourceArns, requesting an update with the parameter ProtectedResourceConditions will be unsuccessful.

Parameter restoreTestingSelectionName : The required restore testing selection name of the restore testing selection you wish to update.

Implementation

Future<UpdateRestoreTestingSelectionOutput> updateRestoreTestingSelection({
  required String restoreTestingPlanName,
  required RestoreTestingSelectionForUpdate restoreTestingSelection,
  required String restoreTestingSelectionName,
}) async {
  final $payload = <String, dynamic>{
    'RestoreTestingSelection': restoreTestingSelection,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/restore-testing/plans/${Uri.encodeComponent(restoreTestingPlanName)}/selections/${Uri.encodeComponent(restoreTestingSelectionName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRestoreTestingSelectionOutput.fromJson(response);
}