disassociateGatewayFromServer method

Future<DisassociateGatewayFromServerOutput> disassociateGatewayFromServer({
  1. required String gatewayArn,
})

Disassociates a backup gateway from the specified server. After the disassociation process finishes, the gateway can no longer access the virtual machines on the server.

May throw ConflictException. May throw ResourceNotFoundException.

Parameter gatewayArn : The Amazon Resource Name (ARN) of the gateway to disassociate.

Implementation

Future<DisassociateGatewayFromServerOutput> disassociateGatewayFromServer({
  required String gatewayArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'BackupOnPremises_v20210101.DisassociateGatewayFromServer'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GatewayArn': gatewayArn,
    },
  );

  return DisassociateGatewayFromServerOutput.fromJson(jsonResponse.body);
}