putBandwidthRateLimitSchedule method

Future<PutBandwidthRateLimitScheduleOutput> putBandwidthRateLimitSchedule({
  1. required List<BandwidthRateLimitInterval> bandwidthRateLimitIntervals,
  2. required String gatewayArn,
})

This action sets the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have a bandwidth rate limit schedule, which means no bandwidth rate limiting is in effect. Use this to initiate a gateway's bandwidth rate limit schedule.

May throw ResourceNotFoundException.

Parameter bandwidthRateLimitIntervals : An array containing bandwidth rate limit schedule intervals for a gateway. When no bandwidth rate limit intervals have been scheduled, the array is empty.

Parameter gatewayArn : The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.

Implementation

Future<PutBandwidthRateLimitScheduleOutput> putBandwidthRateLimitSchedule({
  required List<BandwidthRateLimitInterval> bandwidthRateLimitIntervals,
  required String gatewayArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'BackupOnPremises_v20210101.PutBandwidthRateLimitSchedule'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'BandwidthRateLimitIntervals': bandwidthRateLimitIntervals,
      'GatewayArn': gatewayArn,
    },
  );

  return PutBandwidthRateLimitScheduleOutput.fromJson(jsonResponse.body);
}