getSearchResultExportJob method

Future<GetSearchResultExportJobOutput> getSearchResultExportJob({
  1. required String exportJobIdentifier,
})

This operation retrieves the metadata of an export job.

An export job is an operation that transmits the results of a search job to a specified S3 bucket in a .csv file.

An export job allows you to retain results of a search beyond the search job's scheduled retention of 7 days.

May throw ResourceNotFoundException.

Parameter exportJobIdentifier : This is the unique string that identifies a specific export job.

Required for this operation.

Implementation

Future<GetSearchResultExportJobOutput> getSearchResultExportJob({
  required String exportJobIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/export-search-jobs/${Uri.encodeComponent(exportJobIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSearchResultExportJobOutput.fromJson(response);
}