listSearchJobResults method

Future<ListSearchJobResultsOutput> listSearchJobResults({
  1. required String searchJobIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

This operation returns a list of a specified search job.

May throw ResourceNotFoundException.

Parameter searchJobIdentifier : The unique string that specifies the search job.

Parameter maxResults : The maximum number of resource list items to be returned.

Parameter nextToken : The next item following a partial list of returned search job results.

For example, if a request is made to return MaxResults number of search job results, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Implementation

Future<ListSearchJobResultsOutput> listSearchJobResults({
  required String searchJobIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/search-jobs/${Uri.encodeComponent(searchJobIdentifier)}/search-results',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSearchJobResultsOutput.fromJson(response);
}