listSearchJobs method
This operation returns a list of search jobs belonging to an account.
Parameter byStatus :
Include this parameter to filter list by search job status.
Parameter maxResults :
The maximum number of resource list items to be returned.
Parameter nextToken :
The next item following a partial list of returned search jobs.
For example, if a request is made to return MaxResults number
of backups, NextToken allows you to return more items in your
list starting at the location pointed to by the next token.
Implementation
Future<ListSearchJobsOutput> listSearchJobs({
SearchJobState? byStatus,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (byStatus != null) 'Status': [byStatus.value],
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/search-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSearchJobsOutput.fromJson(response);
}