listSearchResultExportJobs method

Future<ListSearchResultExportJobsOutput> listSearchResultExportJobs({
  1. int? maxResults,
  2. String? nextToken,
  3. String? searchJobIdentifier,
  4. ExportJobStatus? status,
})

This operation exports search results of a search job to a specified destination S3 bucket.

May throw ResourceNotFoundException. May throw ServiceQuotaExceededException.

Parameter maxResults : The maximum number of resource list items to be returned.

Parameter nextToken : The next item following a partial list of returned backups included in a search job.

For example, if a request is made to return MaxResults number of backups, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Parameter searchJobIdentifier : The unique string that specifies the search job.

Parameter status : The search jobs to be included in the export job can be filtered by including this parameter.

Implementation

Future<ListSearchResultExportJobsOutput> listSearchResultExportJobs({
  int? maxResults,
  String? nextToken,
  String? searchJobIdentifier,
  ExportJobStatus? status,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
    if (searchJobIdentifier != null)
      'SearchJobIdentifier': [searchJobIdentifier],
    if (status != null) 'Status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/export-search-jobs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSearchResultExportJobsOutput.fromJson(response);
}