createComputeEnvironment method

Future<CreateComputeEnvironmentResponse> createComputeEnvironment({
  1. required String computeEnvironmentName,
  2. required CEType type,
  3. ComputeResource? computeResources,
  4. String? context,
  5. EksConfiguration? eksConfiguration,
  6. String? serviceRole,
  7. CEState? state,
  8. Map<String, String>? tags,
  9. int? unmanagedvCpus,
})

Creates an Batch compute environment. You can create MANAGED or UNMANAGED compute environments. MANAGED compute environments can use Amazon EC2 or Fargate resources. UNMANAGED compute environments can only use EC2 resources.

In a managed compute environment, Batch manages the capacity and instance types of the compute resources within the environment. This is based on the compute resource specification that you define or the launch template that you specify when you create the compute environment. Either, you can choose to use EC2 On-Demand Instances and EC2 Spot Instances. Or, you can use Fargate and Fargate Spot capacity in your managed compute environment. You can optionally set a maximum price so that Spot Instances only launch when the Spot Instance price is less than a specified percentage of the On-Demand price.

In an unmanaged compute environment, you can manage your own EC2 compute resources and have flexibility with how you configure your compute resources. For example, you can use custom AMIs. However, you must verify that each of your AMIs meet the Amazon ECS container instance AMI specification. For more information, see container instance AMIs in the Amazon Elastic Container Service Developer Guide. After you created your unmanaged compute environment, you can use the DescribeComputeEnvironments operation to find the Amazon ECS cluster that's associated with it. Then, launch your container instances into that Amazon ECS cluster. For more information, see Launching an Amazon ECS container instance in the Amazon Elastic Container Service Developer Guide.

May throw ClientException. May throw ServerException.

Parameter computeEnvironmentName : The name for your compute environment. It can be up to 128 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).

Parameter type : The type of the compute environment: MANAGED or UNMANAGED. For more information, see Compute Environments in the Batch User Guide.

Parameter computeResources : Details about the compute resources managed by the compute environment. This parameter is required for managed compute environments. For more information, see Compute Environments in the Batch User Guide.

Parameter context : Reserved.

Parameter eksConfiguration : The details for the Amazon EKS cluster that supports the compute environment.

Parameter serviceRole : The full Amazon Resource Name (ARN) of the IAM role that allows Batch to make calls to other Amazon Web Services services on your behalf. For more information, see Batch service IAM role in the Batch User Guide.

This automatic service-linked role creation only applies to MANAGED compute environments. For UNMANAGED compute environments, you must explicitly specify a serviceRole. If your specified role has a path other than /, then you must specify either the full role ARN (recommended) or prefix the role name with the path. For example, if a role with the name bar has a path of /foo/, specify /foo/bar as the role name. For more information, see Friendly names and paths in the IAM User Guide.

Parameter state : The state of the compute environment. A compute environment must be created in the ENABLED state.

If the state is ENABLED, then the compute environment accepts jobs from a queue and can scale out automatically based on queues.

If the state is ENABLED, then the Batch scheduler can attempt to place jobs from an associated job queue on the compute resources within the environment. If the compute environment is managed, then it can scale its instances out or in automatically, based on the job queue demand.

If the state is DISABLED, then the Batch scheduler doesn't attempt to place jobs within the environment. Jobs in a STARTING or RUNNING state continue to progress normally. Managed compute environments in the DISABLED state don't scale out. When an instance is idle, the instance scales down to the minvCpus value. However, the instance size doesn't change. For example, consider a c5.8xlarge instance with a minvCpus value of 4 and a desiredvCpus value of 36. This instance doesn't scale down to a c5.large instance.

Parameter tags : The tags that you apply to the compute environment to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging Amazon Web Services Resources in Amazon Web Services General Reference.

These tags can be updated or removed using the TagResource and UntagResource API operations. These tags don't propagate to the underlying compute resources.

Parameter unmanagedvCpus : The maximum number of vCPUs for an unmanaged compute environment. This parameter is only used for fair-share scheduling to reserve vCPU capacity for new share identifiers. If this parameter isn't provided for a fair-share job queue, no vCPU capacity is reserved.

Implementation

Future<CreateComputeEnvironmentResponse> createComputeEnvironment({
  required String computeEnvironmentName,
  required CEType type,
  ComputeResource? computeResources,
  String? context,
  EksConfiguration? eksConfiguration,
  String? serviceRole,
  CEState? state,
  Map<String, String>? tags,
  int? unmanagedvCpus,
}) async {
  final $payload = <String, dynamic>{
    'computeEnvironmentName': computeEnvironmentName,
    'type': type.value,
    if (computeResources != null) 'computeResources': computeResources,
    if (context != null) 'context': context,
    if (eksConfiguration != null) 'eksConfiguration': eksConfiguration,
    if (serviceRole != null) 'serviceRole': serviceRole,
    if (state != null) 'state': state.value,
    if (tags != null) 'tags': tags,
    if (unmanagedvCpus != null) 'unmanagedvCpus': unmanagedvCpus,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/createcomputeenvironment',
    exceptionFnMap: _exceptionFns,
  );
  return CreateComputeEnvironmentResponse.fromJson(response);
}