deleteComputeEnvironment method
Deletes an Batch compute environment.
Before you can delete a compute environment, you must set its state to
DISABLED with the UpdateComputeEnvironment API
operation and disassociate it from any job queues with the
UpdateJobQueue API operation. Compute environments that use Fargate
resources must terminate all active jobs on that compute environment
before deleting the compute environment. If this isn't done, the compute
environment enters an invalid state.
May throw ClientException.
May throw ServerException.
Parameter computeEnvironment :
The name or Amazon Resource Name (ARN) of the compute environment to
delete.
Implementation
Future<void> deleteComputeEnvironment({
required String computeEnvironment,
}) async {
final $payload = <String, dynamic>{
'computeEnvironment': computeEnvironment,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/deletecomputeenvironment',
exceptionFnMap: _exceptionFns,
);
}