deleteJobQueue method
Deletes the specified job queue. You must first disable submissions for a queue with the UpdateJobQueue operation. All jobs in the queue are eventually terminated when you delete a job queue.
It's not necessary to disassociate compute environments from a queue
before submitting a DeleteJobQueue request.
May throw ClientException.
May throw ServerException.
Parameter jobQueue :
The short name or full Amazon Resource Name (ARN) of the queue to delete.
Implementation
Future<void> deleteJobQueue({
required String jobQueue,
}) async {
final $payload = <String, dynamic>{
'jobQueue': jobQueue,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/deletejobqueue',
exceptionFnMap: _exceptionFns,
);
}