deleteQuotaShare method

Future<void> deleteQuotaShare({
  1. required String quotaShareArn,
})

Deletes the specified quota share. You must first disable submissions for the share by updating the state to DISABLED using the UpdateQuotaShare operation. All jobs in the share are eventually terminated when you delete a quota share.

May throw ClientException. May throw ServerException.

Parameter quotaShareArn : The Amazon Resource Name (ARN) of the quota share.

Implementation

Future<void> deleteQuotaShare({
  required String quotaShareArn,
}) async {
  final $payload = <String, dynamic>{
    'quotaShareArn': quotaShareArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/deletequotashare',
    exceptionFnMap: _exceptionFns,
  );
}