deleteServiceEnvironment method

Future<void> deleteServiceEnvironment({
  1. required String serviceEnvironment,
})

Deletes a Service environment. Before you can delete a service environment, you must first set its state to DISABLED with the UpdateServiceEnvironment API operation and disassociate it from any job queues with the UpdateJobQueue API operation.

May throw ClientException. May throw ServerException.

Parameter serviceEnvironment : The name or ARN of the service environment to delete.

Implementation

Future<void> deleteServiceEnvironment({
  required String serviceEnvironment,
}) async {
  final $payload = <String, dynamic>{
    'serviceEnvironment': serviceEnvironment,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/deleteserviceenvironment',
    exceptionFnMap: _exceptionFns,
  );
}