describeServiceEnvironments method

Future<DescribeServiceEnvironmentsResponse> describeServiceEnvironments({
  1. int? maxResults,
  2. String? nextToken,
  3. List<String>? serviceEnvironments,
})

Describes one or more of your service environments.

May throw ClientException. May throw ServerException.

Parameter maxResults : The maximum number of results returned by DescribeServiceEnvironments in paginated output. When this parameter is used, DescribeServiceEnvironments only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeServiceEnvironments request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then DescribeServiceEnvironments returns up to 100 results and a nextToken value if applicable.

Parameter nextToken : The nextToken value returned from a previous paginated DescribeServiceEnvironments request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Parameter serviceEnvironments : An array of service environment names or ARN entries.

Implementation

Future<DescribeServiceEnvironmentsResponse> describeServiceEnvironments({
  int? maxResults,
  String? nextToken,
  List<String>? serviceEnvironments,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (serviceEnvironments != null)
      'serviceEnvironments': serviceEnvironments,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/describeserviceenvironments',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeServiceEnvironmentsResponse.fromJson(response);
}