getJobQueueSnapshot method
Provides a snapshot of job queue state, including ordering of
RUNNABLE jobs, as well as capacity utilization for already
dispatched jobs. The first 100 RUNNABLE jobs in the job queue
are listed in order of dispatch. For job queues with an attached
quota-share policy, the first RUNNABLE job in each quota
share is also listed. Capacity utilization for the job queue is provided,
as well as break downs by share for job queues with attached fair-share or
quota-share scheduling policies.
May throw ClientException.
May throw ServerException.
Parameter jobQueue :
The job queue’s name or full queue Amazon Resource Name (ARN).
Implementation
Future<GetJobQueueSnapshotResponse> getJobQueueSnapshot({
required String jobQueue,
}) async {
final $payload = <String, dynamic>{
'jobQueue': jobQueue,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/getjobqueuesnapshot',
exceptionFnMap: _exceptionFns,
);
return GetJobQueueSnapshotResponse.fromJson(response);
}