listSchedulingPolicies method
Returns a list of Batch scheduling policies.
May throw ClientException.
May throw ServerException.
Parameter maxResults :
The maximum number of results that's returned by
ListSchedulingPolicies in paginated output. When this
parameter is used, ListSchedulingPolicies only returns
maxResults results in a single page and a
nextToken response element. You can see the remaining results
of the initial request by sending another
ListSchedulingPolicies request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, ListSchedulingPolicies returns up to
100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value that's returned from a previous paginated
ListSchedulingPolicies request where maxResults
was used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there
are no more results to return.
Implementation
Future<ListSchedulingPoliciesResponse> listSchedulingPolicies({
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/listschedulingpolicies',
exceptionFnMap: _exceptionFns,
);
return ListSchedulingPoliciesResponse.fromJson(response);
}