registerJobDefinition method
- required String jobDefinitionName,
- required JobDefinitionType type,
- ConsumableResourceProperties? consumableResourceProperties,
- ContainerProperties? containerProperties,
- EcsProperties? ecsProperties,
- EksProperties? eksProperties,
- NodeProperties? nodeProperties,
- Map<
String, String> ? parameters, - List<
PlatformCapability> ? platformCapabilities, - bool? propagateTags,
- RetryStrategy? retryStrategy,
- int? schedulingPriority,
- Map<
String, String> ? tags, - JobTimeout? timeout,
Registers an Batch job definition.
May throw ClientException.
May throw ServerException.
Parameter jobDefinitionName :
The name of the job definition to register. It can be up to 128 letters
long. It can contain uppercase and lowercase letters, numbers, hyphens
(-), and underscores (_).
Parameter type :
The type of job definition. For more information about multi-node parallel
jobs, see Creating
a multi-node parallel job definition in the Batch User Guide.
-
If the value is
container, then one of the following is required:containerProperties,ecsProperties, oreksProperties. -
If the value is
multinode, thennodePropertiesis required.
Parameter consumableResourceProperties :
Contains a list of consumable resources required by the job.
Parameter containerProperties :
An object with properties specific to Amazon ECS-based single-node
container-based jobs. If the job definition's type parameter
is container, then you must specify either
containerProperties or nodeProperties. This must
not be specified for Amazon EKS-based job definitions.
Parameter ecsProperties :
An object with properties that are specific to Amazon ECS-based jobs. This
must not be specified for Amazon EKS-based job definitions.
Parameter eksProperties :
An object with properties that are specific to Amazon EKS-based jobs. This
must not be specified for Amazon ECS based job definitions.
Parameter nodeProperties :
An object with properties specific to multi-node parallel jobs. If you
specify node properties for a job, it becomes a multi-node parallel job.
For more information, see Multi-node
Parallel Jobs in the Batch User Guide.
Parameter parameters :
Default parameter substitution placeholders to set in the job definition.
Parameters are specified as a key-value pair mapping. Parameters in a
SubmitJob request override any corresponding parameter
defaults from the job definition.
Parameter platformCapabilities :
The platform capabilities required by the job definition. If no value is
specified, it defaults to EC2. To run the job on Fargate
resources, specify FARGATE.
Parameter propagateTags :
Specifies whether to propagate the tags from the job or job definition to
the corresponding Amazon ECS task. If no value is specified, the tags are
not propagated. Tags can only be propagated to the tasks during task
creation. For tags with the same name, job tags are given priority over
job definitions tags. If the total number of combined tags from the job
and job definition is over 50, the job is moved to the FAILED
state.
Parameter retryStrategy :
The retry strategy to use for failed jobs that are submitted with this job
definition. Any retry strategy that's specified during a SubmitJob
operation overrides the retry strategy defined here. If a job is
terminated due to a timeout, it isn't retried.
Parameter schedulingPriority :
The scheduling priority for jobs that are submitted with this job
definition. This only affects jobs in job queues with a fair-share policy.
Jobs with a higher scheduling priority are scheduled before jobs with a
lower scheduling priority.
The minimum supported value is 0 and the maximum supported value is 9999.
Parameter tags :
The tags that you apply to the job definition to help you categorize and
organize your resources. Each tag consists of a key and an optional value.
For more information, see Tagging
Amazon Web Services Resources in Batch User Guide.
Parameter timeout :
The timeout configuration for jobs that are submitted with this job
definition, after which Batch terminates your jobs if they have not
finished. If a job is terminated due to a timeout, it isn't retried. The
minimum value for the timeout is 60 seconds. Any timeout configuration
that's specified during a SubmitJob operation overrides the timeout
configuration defined here. For more information, see Job
Timeouts in the Batch User Guide.
Implementation
Future<RegisterJobDefinitionResponse> registerJobDefinition({
required String jobDefinitionName,
required JobDefinitionType type,
ConsumableResourceProperties? consumableResourceProperties,
ContainerProperties? containerProperties,
EcsProperties? ecsProperties,
EksProperties? eksProperties,
NodeProperties? nodeProperties,
Map<String, String>? parameters,
List<PlatformCapability>? platformCapabilities,
bool? propagateTags,
RetryStrategy? retryStrategy,
int? schedulingPriority,
Map<String, String>? tags,
JobTimeout? timeout,
}) async {
final $payload = <String, dynamic>{
'jobDefinitionName': jobDefinitionName,
'type': type.value,
if (consumableResourceProperties != null)
'consumableResourceProperties': consumableResourceProperties,
if (containerProperties != null)
'containerProperties': containerProperties,
if (ecsProperties != null) 'ecsProperties': ecsProperties,
if (eksProperties != null) 'eksProperties': eksProperties,
if (nodeProperties != null) 'nodeProperties': nodeProperties,
if (parameters != null) 'parameters': parameters,
if (platformCapabilities != null)
'platformCapabilities':
platformCapabilities.map((e) => e.value).toList(),
if (propagateTags != null) 'propagateTags': propagateTags,
if (retryStrategy != null) 'retryStrategy': retryStrategy,
if (schedulingPriority != null) 'schedulingPriority': schedulingPriority,
if (tags != null) 'tags': tags,
if (timeout != null) 'timeout': timeout,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/registerjobdefinition',
exceptionFnMap: _exceptionFns,
);
return RegisterJobDefinitionResponse.fromJson(response);
}