submitJob method
- required String jobDefinition,
- required String jobName,
- required String jobQueue,
- ArrayProperties? arrayProperties,
- ConsumableResourceProperties? consumableResourcePropertiesOverride,
- ContainerOverrides? containerOverrides,
- List<
JobDependency> ? dependsOn, - EcsPropertiesOverride? ecsPropertiesOverride,
- EksPropertiesOverride? eksPropertiesOverride,
- NodeOverrides? nodeOverrides,
- Map<
String, String> ? parameters, - bool? propagateTags,
- RetryStrategy? retryStrategy,
- int? schedulingPriorityOverride,
- Map<
String, String> ? tags, - JobTimeout? timeout,
Submits an Batch job from a job definition. Parameters that are specified
during SubmitJob override parameters defined in the job definition.
vCPU and memory requirements that are specified in the
resourceRequirements objects in the job definition are the
exception. They can't be overridden this way using the memory
and vcpus parameters. Rather, you must specify updates to job
definition parameters in a resourceRequirements object that's
included in the containerOverrides parameter.
May throw ClientException.
May throw ServerException.
Parameter jobDefinition :
The job definition used by this job. This value can be one of
definition-name, definition-name:revision, or
the Amazon Resource Name (ARN) for the job definition, with or without the
revision
(arn:aws:batch:region:account:job-definition/definition-name:revision
, or
arn:aws:batch:region:account:job-definition/definition-name
).
If the revision is not specified, then the latest active revision is used.
Parameter jobName :
The name of the job. It can be up to 128 letters long. The first character
must be alphanumeric, can contain uppercase and lowercase letters,
numbers, hyphens (-), and underscores (_).
Parameter jobQueue :
The job queue where the job is submitted. You can specify either the name
or the Amazon Resource Name (ARN) of the queue.
Parameter arrayProperties :
The array properties for the submitted job, such as the size of the array.
The array size can be between 2 and 10,000. If you specify array
properties for a job, it becomes an array job. For more information, see
Array
Jobs in the Batch User Guide.
Parameter consumableResourcePropertiesOverride :
An object that contains overrides for the consumable resources of a job.
Parameter containerOverrides :
An object with properties that override the defaults for the job
definition that specify the name of a container in the specified job
definition and the overrides it should receive. You can override the
default command for a container, which is specified in the job definition
or the Docker image, with a command override. You can also
override existing environment variables on a container or add new
environment variables to it with an environment override.
Parameter dependsOn :
A list of dependencies for the job. A job can depend upon a maximum of 20
jobs. You can specify a SEQUENTIAL type dependency without
specifying a job ID for array jobs so that each child array job completes
sequentially, starting at index 0. You can also specify an
N_TO_N type dependency with a job ID for array jobs. In that
case, each index child of this job must wait for the corresponding index
child of each dependency to complete before it can begin.
Parameter ecsPropertiesOverride :
An object, with properties that override defaults for the job definition,
can only be specified for jobs that are run on Amazon ECS resources.
Parameter eksPropertiesOverride :
An object, with properties that override defaults for the job definition,
can only be specified for jobs that are run on Amazon EKS resources.
Parameter nodeOverrides :
A list of node overrides in JSON format that specify the node range to
target and the container overrides for that node range.
Parameter parameters :
Additional parameters passed to the job that replace parameter
substitution placeholders that are set in the job definition. Parameters
are specified as a key and value pair mapping. Parameters in a
SubmitJob request override any corresponding parameter
defaults from the job definition.
Parameter propagateTags :
Specifies whether to propagate the tags from the job or job definition to
the corresponding Amazon ECS task. If no value is specified, the tags
aren't propagated. Tags can only be propagated to the tasks during task
creation. For tags with the same name, job tags are given priority over
job definitions tags. If the total number of combined tags from the job
and job definition is over 50, the job is moved to the FAILED
state. When specified, this overrides the tag propagation setting in the
job definition.
Parameter retryStrategy :
The retry strategy to use for failed jobs from this SubmitJob
operation. When a retry strategy is specified here, it overrides the retry
strategy defined in the job definition.
Parameter schedulingPriorityOverride :
The scheduling priority for the job. This only affects jobs in job queues
with a fair-share policy. Jobs with a higher scheduling priority are
scheduled before jobs with a lower scheduling priority. This overrides any
scheduling priority in the job definition and works only within a single
share identifier.
The minimum supported value is 0 and the maximum supported value is 9999.
Parameter shareIdentifier :
The share identifier for the job. Don't specify this parameter if the job
queue doesn't have a fair-share scheduling policy. If the job queue has a
fair-share scheduling policy, then this parameter must be specified.
This string is limited to 255 alphanumeric characters, and can be followed by an asterisk (*).
Parameter tags :
The tags that you apply to the job request to help you categorize and
organize your resources. Each tag consists of a key and an optional value.
For more information, see Tagging
Amazon Web Services Resources in Amazon Web Services General
Reference.
Parameter timeout :
The timeout configuration for this SubmitJob operation. You can
specify a timeout duration after which Batch terminates your jobs if they
haven't finished. If a job is terminated due to a timeout, it isn't
retried. The minimum value for the timeout is 60 seconds. This
configuration overrides any timeout configuration specified in the job
definition. For array jobs, child jobs have the same timeout configuration
as the parent job. For more information, see Job
Timeouts in the Amazon Elastic Container Service Developer
Guide.
Implementation
Future<SubmitJobResponse> submitJob({
required String jobDefinition,
required String jobName,
required String jobQueue,
ArrayProperties? arrayProperties,
ConsumableResourceProperties? consumableResourcePropertiesOverride,
ContainerOverrides? containerOverrides,
List<JobDependency>? dependsOn,
EcsPropertiesOverride? ecsPropertiesOverride,
EksPropertiesOverride? eksPropertiesOverride,
NodeOverrides? nodeOverrides,
Map<String, String>? parameters,
bool? propagateTags,
RetryStrategy? retryStrategy,
int? schedulingPriorityOverride,
String? shareIdentifier,
Map<String, String>? tags,
JobTimeout? timeout,
}) async {
final $payload = <String, dynamic>{
'jobDefinition': jobDefinition,
'jobName': jobName,
'jobQueue': jobQueue,
if (arrayProperties != null) 'arrayProperties': arrayProperties,
if (consumableResourcePropertiesOverride != null)
'consumableResourcePropertiesOverride':
consumableResourcePropertiesOverride,
if (containerOverrides != null) 'containerOverrides': containerOverrides,
if (dependsOn != null) 'dependsOn': dependsOn,
if (ecsPropertiesOverride != null)
'ecsPropertiesOverride': ecsPropertiesOverride,
if (eksPropertiesOverride != null)
'eksPropertiesOverride': eksPropertiesOverride,
if (nodeOverrides != null) 'nodeOverrides': nodeOverrides,
if (parameters != null) 'parameters': parameters,
if (propagateTags != null) 'propagateTags': propagateTags,
if (retryStrategy != null) 'retryStrategy': retryStrategy,
if (schedulingPriorityOverride != null)
'schedulingPriorityOverride': schedulingPriorityOverride,
if (shareIdentifier != null) 'shareIdentifier': shareIdentifier,
if (tags != null) 'tags': tags,
if (timeout != null) 'timeout': timeout,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/submitjob',
exceptionFnMap: _exceptionFns,
);
return SubmitJobResponse.fromJson(response);
}