updateComputeEnvironment method

Future<UpdateComputeEnvironmentResponse> updateComputeEnvironment({
  1. required String computeEnvironment,
  2. ComputeResourceUpdate? computeResources,
  3. String? context,
  4. String? serviceRole,
  5. CEState? state,
  6. int? unmanagedvCpus,
  7. UpdatePolicy? updatePolicy,
})

Updates an Batch compute environment.

May throw ClientException. May throw ServerException.

Parameter computeEnvironment : The name or full Amazon Resource Name (ARN) of the compute environment to update.

Parameter computeResources : Details of the compute resources managed by the compute environment. Required for a managed compute environment. For more information, see Compute Environments in the Batch User Guide.

Parameter context : Reserved.

Parameter serviceRole : The full Amazon Resource Name (ARN) of the IAM role that allows Batch to make calls to other Amazon Web Services services on your behalf. For more information, see Batch service IAM role in the Batch User Guide. If your specified role has a path other than /, then you must either specify the full role ARN (recommended) or prefix the role name with the path.

Parameter state : The state of the compute environment. Compute environments in the ENABLED state can accept jobs from a queue and scale in or out automatically based on the workload demand of its associated queues.

If the state is ENABLED, then the Batch scheduler can attempt to place jobs from an associated job queue on the compute resources within the environment. If the compute environment is managed, then it can scale its instances out or in automatically, based on the job queue demand.

If the state is DISABLED, then the Batch scheduler doesn't attempt to place jobs within the environment. Jobs in a STARTING or RUNNING state continue to progress normally. Managed compute environments in the DISABLED state don't scale out. When an instance is idle, the instance scales down to the minvCpus value. However, the instance size doesn't change. For example, consider a c5.8xlarge instance with a minvCpus value of 4 and a desiredvCpus value of 36. This instance doesn't scale down to a c5.large instance.

Parameter unmanagedvCpus : The maximum number of vCPUs expected to be used for an unmanaged compute environment. Don't specify this parameter for a managed compute environment. This parameter is only used for fair-share scheduling to reserve vCPU capacity for new share identifiers. If this parameter isn't provided for a fair-share job queue, no vCPU capacity is reserved.

Parameter updatePolicy : Specifies the updated infrastructure update policy for the compute environment. For more information about infrastructure updates, see Updating compute environments in the Batch User Guide.

Implementation

Future<UpdateComputeEnvironmentResponse> updateComputeEnvironment({
  required String computeEnvironment,
  ComputeResourceUpdate? computeResources,
  String? context,
  String? serviceRole,
  CEState? state,
  int? unmanagedvCpus,
  UpdatePolicy? updatePolicy,
}) async {
  final $payload = <String, dynamic>{
    'computeEnvironment': computeEnvironment,
    if (computeResources != null) 'computeResources': computeResources,
    if (context != null) 'context': context,
    if (serviceRole != null) 'serviceRole': serviceRole,
    if (state != null) 'state': state.value,
    if (unmanagedvCpus != null) 'unmanagedvCpus': unmanagedvCpus,
    if (updatePolicy != null) 'updatePolicy': updatePolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/updatecomputeenvironment',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateComputeEnvironmentResponse.fromJson(response);
}