updateQuotaShare method
Updates a quota share.
May throw ClientException.
May throw ServerException.
Parameter quotaShareArn :
The Amazon Resource Name (ARN) of the quota share to update.
Parameter capacityLimits :
A list that specifies the quantity and type of compute capacity allocated
to the quota share.
Parameter preemptionConfiguration :
Specifies the preemption behavior for jobs in a quota share.
Parameter resourceSharingConfiguration :
Specifies whether a quota share reserves, lends, or both lends and borrows
idle compute capacity.
Parameter state :
The state of the quota share. If the quota share is ENABLED,
it is able to accept jobs. If the quota share is DISABLED,
new jobs won't be accepted but jobs already submitted can finish.
Implementation
Future<UpdateQuotaShareResponse> updateQuotaShare({
required String quotaShareArn,
List<QuotaShareCapacityLimit>? capacityLimits,
QuotaSharePreemptionConfiguration? preemptionConfiguration,
QuotaShareResourceSharingConfiguration? resourceSharingConfiguration,
QuotaShareState? state,
}) async {
final $payload = <String, dynamic>{
'quotaShareArn': quotaShareArn,
if (capacityLimits != null) 'capacityLimits': capacityLimits,
if (preemptionConfiguration != null)
'preemptionConfiguration': preemptionConfiguration,
if (resourceSharingConfiguration != null)
'resourceSharingConfiguration': resourceSharingConfiguration,
if (state != null) 'state': state.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/updatequotashare',
exceptionFnMap: _exceptionFns,
);
return UpdateQuotaShareResponse.fromJson(response);
}