updateServiceJob method

Future<UpdateServiceJobResponse> updateServiceJob({
  1. required String jobId,
  2. required int schedulingPriority,
})

Updates the priority of a specified service job in an Batch job queue.

May throw ClientException. May throw ServerException.

Parameter jobId : The Batch job ID of the job to update.

Parameter schedulingPriority : The scheduling priority for the job. This only affects jobs in job queues with a quota-share or fair-share scheduling policy. Jobs with a higher scheduling priority are scheduled before jobs with a lower scheduling priority within a share.

The minimum supported value is 0 and the maximum supported value is 9999.

Implementation

Future<UpdateServiceJobResponse> updateServiceJob({
  required String jobId,
  required int schedulingPriority,
}) async {
  final $payload = <String, dynamic>{
    'jobId': jobId,
    'schedulingPriority': schedulingPriority,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/updateservicejob',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateServiceJobResponse.fromJson(response);
}