bcm_data_exports library

Classes

AwsClientCredentials
AWS credentials.
BcmDataExports
You can use the Data Exports API to create customized exports from multiple Amazon Web Services cost management and billing datasets, such as cost and usage data and cost optimization recommendations.