BcmDataExports class

You can use the Data Exports API to create customized exports from multiple Amazon Web Services cost management and billing datasets, such as cost and usage data and cost optimization recommendations.

The Data Exports API provides the following endpoint:

  • https://bcm-data-exports.us-east-1.api.aws

Constructors

BcmDataExports({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createExport({required Export export, List<ResourceTag>? resourceTags}) Future<CreateExportResponse>
Creates a data export and specifies the data query, the delivery preference, and any optional resource tags.
deleteExport({required String exportArn}) Future<DeleteExportResponse>
Deletes an existing data export.
getExecution({required String executionId, required String exportArn}) Future<GetExecutionResponse>
Exports data based on the source data update.
getExport({required String exportArn}) Future<GetExportResponse>
Views the definition of an existing data export.
getTable({required String tableName, Map<String, String>? tableProperties}) Future<GetTableResponse>
Returns the metadata for the specified table and table properties. This includes the list of columns in the table schema, their data types, and column descriptions.
listExecutions({required String exportArn, int? maxResults, String? nextToken}) Future<ListExecutionsResponse>
Lists the historical executions for the export.
listExports({int? maxResults, String? nextToken}) Future<ListExportsResponse>
Lists all data export definitions.
listTables({int? maxResults, String? nextToken}) Future<ListTablesResponse>
Lists all available tables in data exports.
listTagsForResource({required String resourceArn, int? maxResults, String? nextToken}) Future<ListTagsForResourceResponse>
List tags associated with an existing data export.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required List<ResourceTag> resourceTags}) Future<void>
Adds tags for an existing data export definition.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> resourceTagKeys}) Future<void>
Deletes tags associated with an existing data export definition.
updateExport({required Export export, required String exportArn}) Future<UpdateExportResponse>
Updates an existing data export by overwriting all export parameters. All export parameters must be provided in the UpdateExport request.

Operators

operator ==(Object other) bool
The equality operator.
inherited