getTable method
Returns the metadata for the specified table and table properties. This includes the list of columns in the table schema, their data types, and column descriptions.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter tableName :
The name of the table.
Parameter tableProperties :
TableProperties are additional configurations you can provide to change
the data and schema of a table. Each table can have different
TableProperties. Tables are not required to have any TableProperties. Each
table property has a default value that it assumes if not specified.
Implementation
Future<GetTableResponse> getTable({
required String tableName,
Map<String, String>? tableProperties,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSBillingAndCostManagementDataExports.GetTable'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TableName': tableName,
if (tableProperties != null) 'TableProperties': tableProperties,
},
);
return GetTableResponse.fromJson(jsonResponse.body);
}