bcm_pricing_calculator library

Classes

AwsClientCredentials
AWS credentials.
BcmPricingCalculator
You can use the Pricing Calculator API to programmatically create estimates for your planned cloud use. You can model usage and commitments such as Savings Plans and Reserved Instances, and generate estimated costs using your discounts and benefit sharing preferences.