Bedrock class
Describes the API operations for creating, managing, fine-turning, and evaluating Amazon Bedrock models.
Constructors
- Bedrock({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchDeleteAdvancedPromptOptimizationJob(
{required List< String> jobIdentifiers}) → Future<BatchDeleteAdvancedPromptOptimizationJobResponse> - Deletes one or more advanced prompt optimization jobs.
-
batchDeleteEvaluationJob(
{required List< String> jobIdentifiers}) → Future<BatchDeleteEvaluationJobResponse> -
Deletes a batch of evaluation jobs. An evaluation job can only be deleted
if it has following status
FAILED,COMPLETED, andSTOPPED. You can request up to 25 model evaluation jobs be deleted in a single request. -
cancelAutomatedReasoningPolicyBuildWorkflow(
{required String buildWorkflowId, required String policyArn}) → Future< void> - Cancels a running Automated Reasoning policy build workflow. This stops the policy generation process and prevents further processing of the source documents.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAdvancedPromptOptimizationJob(
{required AdvancedPromptOptimizationInputConfig inputConfig, required String jobName, required List< ModelConfiguration> modelConfigurations, required AdvancedPromptOptimizationOutputConfig outputConfig, String? clientToken, String? encryptionKeyArn, String? jobDescription, List<Tag> ? tags}) → Future<CreateAdvancedPromptOptimizationJobResponse> - Creates an advanced prompt optimization job. The job optimizes your prompt templates for specific models using your evaluation dataset and criteria.
-
createAutomatedReasoningPolicy(
{required String name, String? clientRequestToken, String? description, String? kmsKeyId, AutomatedReasoningPolicyDefinition? policyDefinition, List< Tag> ? tags}) → Future<CreateAutomatedReasoningPolicyResponse> - Creates an Automated Reasoning policy for Amazon Bedrock Guardrails. Automated Reasoning policies use mathematical techniques to detect hallucinations, suggest corrections, and highlight unstated assumptions in the responses of your GenAI application.
-
createAutomatedReasoningPolicyTestCase(
{required AutomatedReasoningCheckResult expectedAggregatedFindingsResult, required String guardContent, required String policyArn, String? clientRequestToken, double? confidenceThreshold, String? queryContent}) → Future< CreateAutomatedReasoningPolicyTestCaseResponse> - Creates a test for an Automated Reasoning policy. Tests validate that your policy works as expected by providing sample inputs and expected outcomes. Use tests to verify policy behavior before deploying to production.
-
createAutomatedReasoningPolicyVersion(
{required String lastUpdatedDefinitionHash, required String policyArn, String? clientRequestToken, List< Tag> ? tags}) → Future<CreateAutomatedReasoningPolicyVersionResponse> - Creates a new version of an existing Automated Reasoning policy. This allows you to iterate on your policy rules while maintaining previous versions for rollback or comparison purposes.
-
createCustomModel(
{required String modelName, String? clientRequestToken, CustomModelDataSource? customModelDataSource, String? modelKmsKeyArn, ModelDataSource? modelSourceConfig, List< Tag> ? modelTags, String? roleArn}) → Future<CreateCustomModelResponse> - Creates a new custom model in Amazon Bedrock. After the model is active, you can use it for inference.
-
createCustomModelDeployment(
{required String modelArn, required String modelDeploymentName, String? clientRequestToken, String? description, List< Tag> ? tags}) → Future<CreateCustomModelDeploymentResponse> -
Deploys a custom model for on-demand inference in Amazon Bedrock. After
you deploy your custom model, you use the deployment's Amazon Resource
Name (ARN) as the
modelIdparameter when you submit prompts and generate responses with model inference. -
createEvaluationJob(
{required EvaluationConfig evaluationConfig, required EvaluationInferenceConfig inferenceConfig, required String jobName, required EvaluationOutputDataConfig outputDataConfig, required String roleArn, ApplicationType? applicationType, String? clientRequestToken, String? customerEncryptionKeyId, String? jobDescription, List< Tag> ? jobTags}) → Future<CreateEvaluationJobResponse> - Creates an evaluation job.
-
createFoundationModelAgreement(
{required String modelId, required String offerToken}) → Future< CreateFoundationModelAgreementResponse> - Request a model access agreement for the specified model.
-
createGuardrail(
{required String blockedInputMessaging, required String blockedOutputsMessaging, required String name, GuardrailAutomatedReasoningPolicyConfig? automatedReasoningPolicyConfig, String? clientRequestToken, GuardrailContentPolicyConfig? contentPolicyConfig, GuardrailContextualGroundingPolicyConfig? contextualGroundingPolicyConfig, GuardrailCrossRegionConfig? crossRegionConfig, String? description, String? kmsKeyId, GuardrailSensitiveInformationPolicyConfig? sensitiveInformationPolicyConfig, List< Tag> ? tags, GuardrailTopicPolicyConfig? topicPolicyConfig, GuardrailWordPolicyConfig? wordPolicyConfig}) → Future<CreateGuardrailResponse> - Creates a guardrail to block topics and to implement safeguards for your generative AI applications.
-
createGuardrailVersion(
{required String guardrailIdentifier, String? clientRequestToken, String? description}) → Future< CreateGuardrailVersionResponse> - Creates a version of the guardrail. Use this API to create a snapshot of the guardrail when you are satisfied with a configuration, or to compare the configuration with another version.
-
createInferenceProfile(
{required String inferenceProfileName, required InferenceProfileModelSource modelSource, String? clientRequestToken, String? description, List< Tag> ? tags}) → Future<CreateInferenceProfileResponse> - Creates an application inference profile to track metrics and costs when invoking a model. To create an application inference profile for a foundation model in one region, specify the ARN of the model in that region. To create an application inference profile for a foundation model across multiple regions, specify the ARN of the system-defined inference profile that contains the regions that you want to route requests to. For more information, see Increase throughput and resilience with cross-region inference in Amazon Bedrock. in the Amazon Bedrock User Guide.
-
createMarketplaceModelEndpoint(
{required EndpointConfig endpointConfig, required String endpointName, required String modelSourceIdentifier, bool? acceptEula, String? clientRequestToken, List< Tag> ? tags}) → Future<CreateMarketplaceModelEndpointResponse> - Creates an endpoint for a model from Amazon Bedrock Marketplace. The endpoint is hosted by Amazon SageMaker.
-
createModelCopyJob(
{required String sourceModelArn, required String targetModelName, String? clientRequestToken, String? modelKmsKeyId, List< Tag> ? targetModelTags}) → Future<CreateModelCopyJobResponse> - Copies a model to another region so that it can be used there. For more information, see Copy models to be used in other regions in the Amazon Bedrock User Guide.
-
createModelCustomizationJob(
{required String baseModelIdentifier, required String customModelName, required String jobName, required OutputDataConfig outputDataConfig, required String roleArn, required TrainingDataConfig trainingDataConfig, String? clientRequestToken, String? customModelKmsKeyId, List< Tag> ? customModelTags, CustomizationConfig? customizationConfig, CustomizationType? customizationType, Map<String, String> ? hyperParameters, List<Tag> ? jobTags, ValidationDataConfig? validationDataConfig, VpcConfig? vpcConfig}) → Future<CreateModelCustomizationJobResponse> - Creates a fine-tuning job to customize a base model.
-
createModelImportJob(
{required String importedModelName, required String jobName, required ModelDataSource modelDataSource, required String roleArn, String? clientRequestToken, String? importedModelKmsKeyId, List< Tag> ? importedModelTags, List<Tag> ? jobTags, VpcConfig? vpcConfig}) → Future<CreateModelImportJobResponse> - Creates a model import job to import model that you have customized in other environments, such as Amazon SageMaker. For more information, see Import a customized model
-
createModelInvocationJob(
{required ModelInvocationJobInputDataConfig inputDataConfig, required String jobName, required String modelId, required ModelInvocationJobOutputDataConfig outputDataConfig, required String roleArn, String? clientRequestToken, ModelInvocationType? modelInvocationType, List< Tag> ? tags, int? timeoutDurationInHours, VpcConfig? vpcConfig}) → Future<CreateModelInvocationJobResponse> - Creates a batch inference job to invoke a model on multiple prompts. Format your data according to Format your inference data and upload it to an Amazon S3 bucket. For more information, see Process multiple prompts with batch inference.
-
createPromptRouter(
{required PromptRouterTargetModel fallbackModel, required List< PromptRouterTargetModel> models, required String promptRouterName, required RoutingCriteria routingCriteria, String? clientRequestToken, String? description, List<Tag> ? tags}) → Future<CreatePromptRouterResponse> - Creates a prompt router that manages the routing of requests between multiple foundation models based on the routing criteria.
-
createProvisionedModelThroughput(
{required String modelId, required int modelUnits, required String provisionedModelName, String? clientRequestToken, CommitmentDuration? commitmentDuration, List< Tag> ? tags}) → Future<CreateProvisionedModelThroughputResponse> - Creates dedicated throughput for a base or custom model with the model units and for the duration that you specify. For pricing details, see Amazon Bedrock Pricing. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
-
deleteAutomatedReasoningPolicy(
{required String policyArn, bool? force}) → Future< void> - Deletes an Automated Reasoning policy or policy version. This operation is idempotent. If you delete a policy more than once, each call succeeds. Deleting a policy removes it permanently and cannot be undone.
-
deleteAutomatedReasoningPolicyBuildWorkflow(
{required String buildWorkflowId, required DateTime lastUpdatedAt, required String policyArn}) → Future< void> - Deletes an Automated Reasoning policy build workflow and its associated artifacts. This permanently removes the workflow history and any generated assets.
-
deleteAutomatedReasoningPolicyTestCase(
{required DateTime lastUpdatedAt, required String policyArn, required String testCaseId}) → Future< void> - Deletes an Automated Reasoning policy test. This operation is idempotent; if you delete a test more than once, each call succeeds.
-
deleteCustomModel(
{required String modelIdentifier}) → Future< void> - Deletes a custom model that you created earlier. For more information, see Custom models in the Amazon Bedrock User Guide.
-
deleteCustomModelDeployment(
{required String customModelDeploymentIdentifier}) → Future< void> - Deletes a custom model deployment. This operation stops the deployment and removes it from your account. After deletion, the deployment ARN can no longer be used for inference requests.
-
deleteEnforcedGuardrailConfiguration(
{required String configId}) → Future< void> - Deletes the account-level enforced guardrail configuration.
-
deleteFoundationModelAgreement(
{required String modelId}) → Future< void> - Delete the model access agreement for the specified model.
-
deleteGuardrail(
{required String guardrailIdentifier, String? guardrailVersion}) → Future< void> - Deletes a guardrail.
-
deleteImportedModel(
{required String modelIdentifier}) → Future< void> - Deletes a custom model that you imported earlier. For more information, see Import a customized model in the Amazon Bedrock User Guide.
-
deleteInferenceProfile(
{required String inferenceProfileIdentifier}) → Future< void> - Deletes an application inference profile. For more information, see Increase throughput and resilience with cross-region inference in Amazon Bedrock. in the Amazon Bedrock User Guide.
-
deleteMarketplaceModelEndpoint(
{required String endpointArn}) → Future< void> - Deletes an endpoint for a model from Amazon Bedrock Marketplace.
-
deleteModelInvocationLoggingConfiguration(
) → Future< void> - Delete the invocation logging.
-
deletePromptRouter(
{required String promptRouterArn}) → Future< void> - Deletes a specified prompt router. This action cannot be undone.
-
deleteProvisionedModelThroughput(
{required String provisionedModelId}) → Future< void> - Deletes a Provisioned Throughput. You can't delete a Provisioned Throughput before the commitment term is over. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
-
deleteResourcePolicy(
{required String resourceArn}) → Future< void> - Deletes a previously created Bedrock resource policy.
-
deregisterMarketplaceModelEndpoint(
{required String endpointArn}) → Future< void> - Deregisters an endpoint for a model from Amazon Bedrock Marketplace. This operation removes the endpoint's association with Amazon Bedrock but does not delete the underlying Amazon SageMaker endpoint.
-
exportAutomatedReasoningPolicyVersion(
{required String policyArn}) → Future< ExportAutomatedReasoningPolicyVersionResponse> - Exports the policy definition for an Automated Reasoning policy version. Returns the complete policy definition including rules, variables, and custom variable types in a structured format.
-
getAdvancedPromptOptimizationJob(
{required String jobIdentifier}) → Future< GetAdvancedPromptOptimizationJobResponse> - Gets information about an advanced prompt optimization job.
-
getAutomatedReasoningPolicy(
{required String policyArn}) → Future< GetAutomatedReasoningPolicyResponse> - Retrieves details about an Automated Reasoning policy or policy version. Returns information including the policy definition, metadata, and timestamps.
-
getAutomatedReasoningPolicyAnnotations(
{required String buildWorkflowId, required String policyArn}) → Future< GetAutomatedReasoningPolicyAnnotationsResponse> - Retrieves the current annotations for an Automated Reasoning policy build workflow. Annotations contain corrections to the rules, variables and types to be applied to the policy.
-
getAutomatedReasoningPolicyBuildWorkflow(
{required String buildWorkflowId, required String policyArn}) → Future< GetAutomatedReasoningPolicyBuildWorkflowResponse> - Retrieves detailed information about an Automated Reasoning policy build workflow, including its status, configuration, and metadata.
-
getAutomatedReasoningPolicyBuildWorkflowResultAssets(
{required AutomatedReasoningPolicyBuildResultAssetType assetType, required String buildWorkflowId, required String policyArn, String? assetId}) → Future< GetAutomatedReasoningPolicyBuildWorkflowResultAssetsResponse> - Retrieves the resulting assets from a completed Automated Reasoning policy build workflow, including build logs, quality reports, and generated policy artifacts.
-
getAutomatedReasoningPolicyNextScenario(
{required String buildWorkflowId, required String policyArn}) → Future< GetAutomatedReasoningPolicyNextScenarioResponse> - Retrieves the next test scenario for validating an Automated Reasoning policy. This is used during the interactive policy refinement process to test policy behavior.
-
getAutomatedReasoningPolicyTestCase(
{required String policyArn, required String testCaseId}) → Future< GetAutomatedReasoningPolicyTestCaseResponse> - Retrieves details about a specific Automated Reasoning policy test.
-
getAutomatedReasoningPolicyTestResult(
{required String buildWorkflowId, required String policyArn, required String testCaseId}) → Future< GetAutomatedReasoningPolicyTestResultResponse> - Retrieves the test result for a specific Automated Reasoning policy test. Returns detailed validation findings and execution status.
-
getCustomModel(
{required String modelIdentifier}) → Future< GetCustomModelResponse> - Get the properties associated with a Amazon Bedrock custom model that you have created. For more information, see Custom models in the Amazon Bedrock User Guide.
-
getCustomModelDeployment(
{required String customModelDeploymentIdentifier}) → Future< GetCustomModelDeploymentResponse> - Retrieves information about a custom model deployment, including its status, configuration, and metadata. Use this operation to monitor the deployment status and retrieve details needed for inference requests.
-
getEvaluationJob(
{required String jobIdentifier}) → Future< GetEvaluationJobResponse> - Gets information about an evaluation job, such as the status of the job.
-
getFoundationModel(
{required String modelIdentifier}) → Future< GetFoundationModelResponse> - Get details about a Amazon Bedrock foundation model.
-
getFoundationModelAvailability(
{required String modelId}) → Future< GetFoundationModelAvailabilityResponse> - Get information about the Foundation model availability.
-
getGuardrail(
{required String guardrailIdentifier, String? guardrailVersion}) → Future< GetGuardrailResponse> -
Gets details about a guardrail. If you don't specify a version, the
response returns details for the
DRAFTversion. -
getImportedModel(
{required String modelIdentifier}) → Future< GetImportedModelResponse> - Gets properties associated with a customized model you imported.
-
getInferenceProfile(
{required String inferenceProfileIdentifier}) → Future< GetInferenceProfileResponse> - Gets information about an inference profile. For more information, see Increase throughput and resilience with cross-region inference in Amazon Bedrock. in the Amazon Bedrock User Guide.
-
getMarketplaceModelEndpoint(
{required String endpointArn}) → Future< GetMarketplaceModelEndpointResponse> - Retrieves details about a specific endpoint for a model from Amazon Bedrock Marketplace.
-
getModelCopyJob(
{required String jobArn}) → Future< GetModelCopyJobResponse> - Retrieves information about a model copy job. For more information, see Copy models to be used in other regions in the Amazon Bedrock User Guide.
-
getModelCustomizationJob(
{required String jobIdentifier}) → Future< GetModelCustomizationJobResponse> - Retrieves the properties associated with a model-customization job, including the status of the job. For more information, see Custom models in the Amazon Bedrock User Guide.
-
getModelImportJob(
{required String jobIdentifier}) → Future< GetModelImportJobResponse> - Retrieves the properties associated with import model job, including the status of the job. For more information, see Import a customized model in the Amazon Bedrock User Guide.
-
getModelInvocationJob(
{required String jobIdentifier}) → Future< GetModelInvocationJobResponse> - Gets details about a batch inference job. For more information, see Monitor batch inference jobs
-
getModelInvocationLoggingConfiguration(
) → Future< GetModelInvocationLoggingConfigurationResponse> - Get the current configuration values for model invocation logging.
-
getPromptRouter(
{required String promptRouterArn}) → Future< GetPromptRouterResponse> - Retrieves details about a prompt router.
-
getProvisionedModelThroughput(
{required String provisionedModelId}) → Future< GetProvisionedModelThroughputResponse> - Returns details for a Provisioned Throughput. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> - Gets the resource policy document for a Bedrock resource
-
getUseCaseForModelAccess(
) → Future< GetUseCaseForModelAccessResponse> - Get usecase for model access.
-
listAdvancedPromptOptimizationJobs(
{int? maxResults, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder}) → Future< ListAdvancedPromptOptimizationJobsResponse> - Lists the advanced prompt optimization jobs in your account.
-
listAutomatedReasoningPolicies(
{int? maxResults, String? nextToken, String? policyArn}) → Future< ListAutomatedReasoningPoliciesResponse> - Lists all Automated Reasoning policies in your account, with optional filtering by policy ARN. This helps you manage and discover existing policies.
-
listAutomatedReasoningPolicyBuildWorkflows(
{required String policyArn, int? maxResults, String? nextToken}) → Future< ListAutomatedReasoningPolicyBuildWorkflowsResponse> - Lists all build workflows for an Automated Reasoning policy, showing the history of policy creation and modification attempts.
-
listAutomatedReasoningPolicyTestCases(
{required String policyArn, int? maxResults, String? nextToken}) → Future< ListAutomatedReasoningPolicyTestCasesResponse> - Lists tests for an Automated Reasoning policy. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
listAutomatedReasoningPolicyTestResults(
{required String buildWorkflowId, required String policyArn, int? maxResults, String? nextToken}) → Future< ListAutomatedReasoningPolicyTestResultsResponse> - Lists test results for an Automated Reasoning policy, showing how the policy performed against various test scenarios and validation checks.
-
listCustomModelDeployments(
{DateTime? createdAfter, DateTime? createdBefore, int? maxResults, String? modelArnEquals, String? nameContains, String? nextToken, SortModelsBy? sortBy, SortOrder? sortOrder, CustomModelDeploymentStatus? statusEquals}) → Future< ListCustomModelDeploymentsResponse> - Lists custom model deployments in your account. You can filter the results by creation time, name, status, and associated model. Use this operation to manage and monitor your custom model deployments.
-
listCustomModels(
{String? baseModelArnEquals, DateTime? creationTimeAfter, DateTime? creationTimeBefore, String? foundationModelArnEquals, bool? isOwned, int? maxResults, ModelStatus? modelStatus, String? nameContains, String? nextToken, SortModelsBy? sortBy, SortOrder? sortOrder}) → Future< ListCustomModelsResponse> -
Returns a list of the custom models that you have created with the
CreateModelCustomizationJoboperation. -
listEnforcedGuardrailsConfiguration(
{String? nextToken}) → Future< ListEnforcedGuardrailsConfigurationResponse> - Lists the account-level enforced guardrail configurations.
-
listEvaluationJobs(
{ApplicationType? applicationTypeEquals, DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? nameContains, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder, EvaluationJobStatus? statusEquals}) → Future< ListEvaluationJobsResponse> - Lists all existing evaluation jobs.
-
listFoundationModelAgreementOffers(
{required String modelId, OfferType? offerType}) → Future< ListFoundationModelAgreementOffersResponse> - Get the offers associated with the specified model.
-
listFoundationModels(
{ModelCustomization? byCustomizationType, InferenceType? byInferenceType, ModelModality? byOutputModality, String? byProvider}) → Future< ListFoundationModelsResponse> - Lists Amazon Bedrock foundation models that you can use. You can filter the results with the request parameters. For more information, see Foundation models in the Amazon Bedrock User Guide.
-
listGuardrails(
{String? guardrailIdentifier, int? maxResults, String? nextToken}) → Future< ListGuardrailsResponse> -
Lists details about all the guardrails in an account. To list the
DRAFTversion of all your guardrails, don't specify theguardrailIdentifierfield. To list all versions of a guardrail, specify the ARN of the guardrail in theguardrailIdentifierfield. -
listImportedModels(
{DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? nameContains, String? nextToken, SortModelsBy? sortBy, SortOrder? sortOrder}) → Future< ListImportedModelsResponse> - Returns a list of models you've imported. You can filter the results to return based on one or more criteria. For more information, see Import a customized model in the Amazon Bedrock User Guide.
-
listInferenceProfiles(
{int? maxResults, String? nextToken, InferenceProfileType? typeEquals}) → Future< ListInferenceProfilesResponse> - Returns a list of inference profiles that you can use. For more information, see Increase throughput and resilience with cross-region inference in Amazon Bedrock. in the Amazon Bedrock User Guide.
-
listMarketplaceModelEndpoints(
{int? maxResults, String? modelSourceEquals, String? nextToken}) → Future< ListMarketplaceModelEndpointsResponse> - Lists the endpoints for models from Amazon Bedrock Marketplace in your Amazon Web Services account.
-
listModelCopyJobs(
{DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder, String? sourceAccountEquals, String? sourceModelArnEquals, ModelCopyJobStatus? statusEquals, String? targetModelNameContains}) → Future< ListModelCopyJobsResponse> - Returns a list of model copy jobs that you have submitted. You can filter the jobs to return based on one or more criteria. For more information, see Copy models to be used in other regions in the Amazon Bedrock User Guide.
-
listModelCustomizationJobs(
{DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? nameContains, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder, FineTuningJobStatus? statusEquals}) → Future< ListModelCustomizationJobsResponse> - Returns a list of model customization jobs that you have submitted. You can filter the jobs to return based on one or more criteria.
-
listModelImportJobs(
{DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? nameContains, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder, ModelImportJobStatus? statusEquals}) → Future< ListModelImportJobsResponse> - Returns a list of import jobs you've submitted. You can filter the results to return based on one or more criteria. For more information, see Import a customized model in the Amazon Bedrock User Guide.
-
listModelInvocationJobs(
{int? maxResults, String? nameContains, String? nextToken, SortJobsBy? sortBy, SortOrder? sortOrder, ModelInvocationJobStatus? statusEquals, DateTime? submitTimeAfter, DateTime? submitTimeBefore}) → Future< ListModelInvocationJobsResponse> - Lists all batch inference jobs in the account. For more information, see View details about a batch inference job.
-
listPromptRouters(
{int? maxResults, String? nextToken, PromptRouterType? type}) → Future< ListPromptRoutersResponse> - Retrieves a list of prompt routers.
-
listProvisionedModelThroughputs(
{DateTime? creationTimeAfter, DateTime? creationTimeBefore, int? maxResults, String? modelArnEquals, String? nameContains, String? nextToken, SortByProvisionedModels? sortBy, SortOrder? sortOrder, ProvisionedModelStatus? statusEquals}) → Future< ListProvisionedModelThroughputsResponse> - Lists the Provisioned Throughputs in the account. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - List the tags associated with the specified resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putEnforcedGuardrailConfiguration(
{required AccountEnforcedGuardrailInferenceInputConfiguration guardrailInferenceConfig, String? configId}) → Future< PutEnforcedGuardrailConfigurationResponse> - Sets the account-level enforced guardrail configuration.
-
putModelInvocationLoggingConfiguration(
{required LoggingConfig loggingConfig}) → Future< void> - Set the configuration values for model invocation logging.
-
putResourcePolicy(
{required String resourceArn, required String resourcePolicy}) → Future< PutResourcePolicyResponse> - Adds a resource policy for a Bedrock resource.
-
putUseCaseForModelAccess(
{required Uint8List formData}) → Future< void> - Put usecase for model access.
-
registerMarketplaceModelEndpoint(
{required String endpointIdentifier, required String modelSourceIdentifier}) → Future< RegisterMarketplaceModelEndpointResponse> - Registers an existing Amazon SageMaker endpoint with Amazon Bedrock Marketplace, allowing it to be used with Amazon Bedrock APIs.
-
startAutomatedReasoningPolicyBuildWorkflow(
{required AutomatedReasoningPolicyBuildWorkflowType buildWorkflowType, required String policyArn, required AutomatedReasoningPolicyBuildWorkflowSource sourceContent, String? clientRequestToken}) → Future< StartAutomatedReasoningPolicyBuildWorkflowResponse> - Starts a new build workflow for an Automated Reasoning policy. This initiates the process of analyzing source documents and generating policy rules, variables, and types.
-
startAutomatedReasoningPolicyTestWorkflow(
{required String buildWorkflowId, required String policyArn, String? clientRequestToken, List< String> ? testCaseIds}) → Future<StartAutomatedReasoningPolicyTestWorkflowResponse> - Initiates a test workflow to validate Automated Reasoning policy tests. The workflow executes the specified tests against the policy and generates validation results.
-
stopAdvancedPromptOptimizationJob(
{required String jobIdentifier}) → Future< void> - Stops an advanced prompt optimization job that is in progress.
-
stopEvaluationJob(
{required String jobIdentifier}) → Future< void> - Stops an evaluation job that is current being created or running.
-
stopModelCustomizationJob(
{required String jobIdentifier}) → Future< void> - Stops an active model customization job. For more information, see Custom models in the Amazon Bedrock User Guide.
-
stopModelInvocationJob(
{required String jobIdentifier}) → Future< void> - Stops a batch inference job. You're only charged for tokens that were already processed. For more information, see Stop a batch inference job.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Associate tags with a resource. For more information, see Tagging resources in the Amazon Bedrock User Guide.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Remove one or more tags from a resource. For more information, see Tagging resources in the Amazon Bedrock User Guide.
-
updateAutomatedReasoningPolicy(
{required String policyArn, required AutomatedReasoningPolicyDefinition policyDefinition, String? description, String? name}) → Future< UpdateAutomatedReasoningPolicyResponse> - Updates an existing Automated Reasoning policy with new rules, variables, or configuration. This creates a new version of the policy while preserving the previous version.
-
updateAutomatedReasoningPolicyAnnotations(
{required List< AutomatedReasoningPolicyAnnotation> annotations, required String buildWorkflowId, required String lastUpdatedAnnotationSetHash, required String policyArn}) → Future<UpdateAutomatedReasoningPolicyAnnotationsResponse> - Updates the annotations for an Automated Reasoning policy build workflow. This allows you to modify extracted rules, variables, and types before finalizing the policy.
-
updateAutomatedReasoningPolicyTestCase(
{required AutomatedReasoningCheckResult expectedAggregatedFindingsResult, required String guardContent, required DateTime lastUpdatedAt, required String policyArn, required String testCaseId, String? clientRequestToken, double? confidenceThreshold, String? queryContent}) → Future< UpdateAutomatedReasoningPolicyTestCaseResponse> - Updates an existing Automated Reasoning policy test. You can modify the content, query, expected result, and confidence threshold.
-
updateCustomModelDeployment(
{required String customModelDeploymentIdentifier, required String modelArn}) → Future< UpdateCustomModelDeploymentResponse> - Updates a custom model deployment with a new custom model. This allows you to deploy updated models without creating new deployment endpoints.
-
updateGuardrail(
{required String blockedInputMessaging, required String blockedOutputsMessaging, required String guardrailIdentifier, required String name, GuardrailAutomatedReasoningPolicyConfig? automatedReasoningPolicyConfig, GuardrailContentPolicyConfig? contentPolicyConfig, GuardrailContextualGroundingPolicyConfig? contextualGroundingPolicyConfig, GuardrailCrossRegionConfig? crossRegionConfig, String? description, String? kmsKeyId, GuardrailSensitiveInformationPolicyConfig? sensitiveInformationPolicyConfig, GuardrailTopicPolicyConfig? topicPolicyConfig, GuardrailWordPolicyConfig? wordPolicyConfig}) → Future< UpdateGuardrailResponse> - Updates a guardrail with the values you specify.
-
updateMarketplaceModelEndpoint(
{required String endpointArn, required EndpointConfig endpointConfig, String? clientRequestToken}) → Future< UpdateMarketplaceModelEndpointResponse> - Updates the configuration of an existing endpoint for a model from Amazon Bedrock Marketplace.
-
updateProvisionedModelThroughput(
{required String provisionedModelId, String? desiredModelId, String? desiredProvisionedModelName}) → Future< void> - Updates the name or associated model for a Provisioned Throughput. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited