createFoundationModelAgreement method

Future<CreateFoundationModelAgreementResponse> createFoundationModelAgreement({
  1. required String modelId,
  2. required String offerToken,
})

Request a model access agreement for the specified model.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter modelId : Model Id of the model for the access request.

Parameter offerToken : An offer token encapsulates the information for an offer.

Implementation

Future<CreateFoundationModelAgreementResponse>
    createFoundationModelAgreement({
  required String modelId,
  required String offerToken,
}) async {
  final $payload = <String, dynamic>{
    'modelId': modelId,
    'offerToken': offerToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/create-foundation-model-agreement',
    exceptionFnMap: _exceptionFns,
  );
  return CreateFoundationModelAgreementResponse.fromJson(response);
}