deleteAutomatedReasoningPolicyBuildWorkflow method

Future<void> deleteAutomatedReasoningPolicyBuildWorkflow({
  1. required String buildWorkflowId,
  2. required DateTime lastUpdatedAt,
  3. required String policyArn,
})

Deletes an Automated Reasoning policy build workflow and its associated artifacts. This permanently removes the workflow history and any generated assets.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter buildWorkflowId : The unique identifier of the build workflow to delete.

Parameter lastUpdatedAt : The timestamp when the build workflow was last updated. This is used for optimistic concurrency control to prevent accidental deletion of workflows that have been modified.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to delete.

Implementation

Future<void> deleteAutomatedReasoningPolicyBuildWorkflow({
  required String buildWorkflowId,
  required DateTime lastUpdatedAt,
  required String policyArn,
}) async {
  final $query = <String, List<String>>{
    'updatedAt': [_s.iso8601ToJson(lastUpdatedAt).toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}