deleteAutomatedReasoningPolicyTestCase method

Future<void> deleteAutomatedReasoningPolicyTestCase({
  1. required DateTime lastUpdatedAt,
  2. required String policyArn,
  3. required String testCaseId,
})

Deletes an Automated Reasoning policy test. This operation is idempotent; if you delete a test more than once, each call succeeds.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter lastUpdatedAt : The timestamp when the test was last updated. This is used as a concurrency token to prevent conflicting modifications.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test.

Parameter testCaseId : The unique identifier of the test to delete.

Implementation

Future<void> deleteAutomatedReasoningPolicyTestCase({
  required DateTime lastUpdatedAt,
  required String policyArn,
  required String testCaseId,
}) async {
  final $query = <String, List<String>>{
    'updatedAt': [_s.iso8601ToJson(lastUpdatedAt).toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/test-cases/${Uri.encodeComponent(testCaseId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}