deleteCustomModelDeployment method
Deletes a custom model deployment. This operation stops the deployment and removes it from your account. After deletion, the deployment ARN can no longer be used for inference requests.
The following actions are related to the
DeleteCustomModelDeployment operation:
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter customModelDeploymentIdentifier :
The Amazon Resource Name (ARN) or name of the custom model deployment to
delete.
Implementation
Future<void> deleteCustomModelDeployment({
required String customModelDeploymentIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/model-customization/custom-model-deployments/${Uri.encodeComponent(customModelDeploymentIdentifier)}',
exceptionFnMap: _exceptionFns,
);
}