deleteProvisionedModelThroughput method

Future<void> deleteProvisionedModelThroughput({
  1. required String provisionedModelId,
})

Deletes a Provisioned Throughput. You can't delete a Provisioned Throughput before the commitment term is over. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter provisionedModelId : The Amazon Resource Name (ARN) or name of the Provisioned Throughput.

Implementation

Future<void> deleteProvisionedModelThroughput({
  required String provisionedModelId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/provisioned-model-throughput/${Uri.encodeComponent(provisionedModelId)}',
    exceptionFnMap: _exceptionFns,
  );
}