exportAutomatedReasoningPolicyVersion method

Future<ExportAutomatedReasoningPolicyVersionResponse> exportAutomatedReasoningPolicyVersion({
  1. required String policyArn,
})

Exports the policy definition for an Automated Reasoning policy version. Returns the complete policy definition including rules, variables, and custom variable types in a structured format.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy to export. Can be either the unversioned ARN for the draft policy or a versioned ARN for a specific policy version.

Implementation

Future<ExportAutomatedReasoningPolicyVersionResponse>
    exportAutomatedReasoningPolicyVersion({
  required String policyArn,
}) async {
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/export',
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return ExportAutomatedReasoningPolicyVersionResponse(
    policyDefinition: AutomatedReasoningPolicyDefinition.fromJson($json),
  );
}