getAutomatedReasoningPolicy method
Future<GetAutomatedReasoningPolicyResponse>
getAutomatedReasoningPolicy({
- required String policyArn,
Retrieves details about an Automated Reasoning policy or policy version. Returns information including the policy definition, metadata, and timestamps.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter policyArn :
The Amazon Resource Name (ARN) of the Automated Reasoning policy to
retrieve. Can be either the unversioned ARN for the draft policy or an ARN
for a specific policy version.
Implementation
Future<GetAutomatedReasoningPolicyResponse> getAutomatedReasoningPolicy({
required String policyArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}',
exceptionFnMap: _exceptionFns,
);
return GetAutomatedReasoningPolicyResponse.fromJson(response);
}