getAutomatedReasoningPolicyAnnotations method

Future<GetAutomatedReasoningPolicyAnnotationsResponse> getAutomatedReasoningPolicyAnnotations({
  1. required String buildWorkflowId,
  2. required String policyArn,
})

Retrieves the current annotations for an Automated Reasoning policy build workflow. Annotations contain corrections to the rules, variables and types to be applied to the policy.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter buildWorkflowId : The unique identifier of the build workflow whose annotations you want to retrieve.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy whose annotations you want to retrieve.

Implementation

Future<GetAutomatedReasoningPolicyAnnotationsResponse>
    getAutomatedReasoningPolicyAnnotations({
  required String buildWorkflowId,
  required String policyArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}/annotations',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedReasoningPolicyAnnotationsResponse.fromJson(response);
}