getAutomatedReasoningPolicyBuildWorkflow method

Future<GetAutomatedReasoningPolicyBuildWorkflowResponse> getAutomatedReasoningPolicyBuildWorkflow({
  1. required String buildWorkflowId,
  2. required String policyArn,
})

Retrieves detailed information about an Automated Reasoning policy build workflow, including its status, configuration, and metadata.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter buildWorkflowId : The unique identifier of the build workflow to retrieve.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to retrieve.

Implementation

Future<GetAutomatedReasoningPolicyBuildWorkflowResponse>
    getAutomatedReasoningPolicyBuildWorkflow({
  required String buildWorkflowId,
  required String policyArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedReasoningPolicyBuildWorkflowResponse.fromJson(response);
}