getAutomatedReasoningPolicyNextScenario method

Future<GetAutomatedReasoningPolicyNextScenarioResponse> getAutomatedReasoningPolicyNextScenario({
  1. required String buildWorkflowId,
  2. required String policyArn,
})

Retrieves the next test scenario for validating an Automated Reasoning policy. This is used during the interactive policy refinement process to test policy behavior.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter buildWorkflowId : The unique identifier of the build workflow associated with the test scenarios.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy for which you want to get the next test scenario.

Implementation

Future<GetAutomatedReasoningPolicyNextScenarioResponse>
    getAutomatedReasoningPolicyNextScenario({
  required String buildWorkflowId,
  required String policyArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}/scenarios',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedReasoningPolicyNextScenarioResponse.fromJson(response);
}