getAutomatedReasoningPolicyTestCase method

Future<GetAutomatedReasoningPolicyTestCaseResponse> getAutomatedReasoningPolicyTestCase({
  1. required String policyArn,
  2. required String testCaseId,
})

Retrieves details about a specific Automated Reasoning policy test.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test.

Parameter testCaseId : The unique identifier of the test to retrieve.

Implementation

Future<GetAutomatedReasoningPolicyTestCaseResponse>
    getAutomatedReasoningPolicyTestCase({
  required String policyArn,
  required String testCaseId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/test-cases/${Uri.encodeComponent(testCaseId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedReasoningPolicyTestCaseResponse.fromJson(response);
}