getAutomatedReasoningPolicyTestResult method

Future<GetAutomatedReasoningPolicyTestResultResponse> getAutomatedReasoningPolicyTestResult({
  1. required String buildWorkflowId,
  2. required String policyArn,
  3. required String testCaseId,
})

Retrieves the test result for a specific Automated Reasoning policy test. Returns detailed validation findings and execution status.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter buildWorkflowId : The build workflow identifier. The build workflow must display a COMPLETED status to get results.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy.

Parameter testCaseId : The unique identifier of the test for which to retrieve results.

Implementation

Future<GetAutomatedReasoningPolicyTestResultResponse>
    getAutomatedReasoningPolicyTestResult({
  required String buildWorkflowId,
  required String policyArn,
  required String testCaseId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}/test-cases/${Uri.encodeComponent(testCaseId)}/test-results',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedReasoningPolicyTestResultResponse.fromJson(response);
}