getCustomModel method

Future<GetCustomModelResponse> getCustomModel({
  1. required String modelIdentifier,
})

Get the properties associated with a Amazon Bedrock custom model that you have created. For more information, see Custom models in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter modelIdentifier : Name or Amazon Resource Name (ARN) of the custom model.

Implementation

Future<GetCustomModelResponse> getCustomModel({
  required String modelIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/custom-models/${Uri.encodeComponent(modelIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetCustomModelResponse.fromJson(response);
}