getCustomModelDeployment method

Future<GetCustomModelDeploymentResponse> getCustomModelDeployment({
  1. required String customModelDeploymentIdentifier,
})

Retrieves information about a custom model deployment, including its status, configuration, and metadata. Use this operation to monitor the deployment status and retrieve details needed for inference requests.

The following actions are related to the GetCustomModelDeployment operation:

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter customModelDeploymentIdentifier : The Amazon Resource Name (ARN) or name of the custom model deployment to retrieve information about.

Implementation

Future<GetCustomModelDeploymentResponse> getCustomModelDeployment({
  required String customModelDeploymentIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/model-customization/custom-model-deployments/${Uri.encodeComponent(customModelDeploymentIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetCustomModelDeploymentResponse.fromJson(response);
}