getEvaluationJob method

Future<GetEvaluationJobResponse> getEvaluationJob({
  1. required String jobIdentifier,
})

Gets information about an evaluation job, such as the status of the job.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter jobIdentifier : The Amazon Resource Name (ARN) of the evaluation job you want get information on.

Implementation

Future<GetEvaluationJobResponse> getEvaluationJob({
  required String jobIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/evaluation-jobs/${Uri.encodeComponent(jobIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetEvaluationJobResponse.fromJson(response);
}