getMarketplaceModelEndpoint method

Future<GetMarketplaceModelEndpointResponse> getMarketplaceModelEndpoint({
  1. required String endpointArn,
})

Retrieves details about a specific endpoint for a model from Amazon Bedrock Marketplace.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter endpointArn : The Amazon Resource Name (ARN) of the endpoint you want to get information about.

Implementation

Future<GetMarketplaceModelEndpointResponse> getMarketplaceModelEndpoint({
  required String endpointArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/marketplace-model/endpoints/${Uri.encodeComponent(endpointArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMarketplaceModelEndpointResponse.fromJson(response);
}