getModelCopyJob method

Future<GetModelCopyJobResponse> getModelCopyJob({
  1. required String jobArn,
})

Retrieves information about a model copy job. For more information, see Copy models to be used in other regions in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter jobArn : The Amazon Resource Name (ARN) of the model copy job.

Implementation

Future<GetModelCopyJobResponse> getModelCopyJob({
  required String jobArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/model-copy-jobs/${Uri.encodeComponent(jobArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetModelCopyJobResponse.fromJson(response);
}