listAutomatedReasoningPolicyBuildWorkflows method

Future<ListAutomatedReasoningPolicyBuildWorkflowsResponse> listAutomatedReasoningPolicyBuildWorkflows({
  1. required String policyArn,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all build workflows for an Automated Reasoning policy, showing the history of policy creation and modification attempts.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflows you want to list.

Parameter maxResults : The maximum number of build workflows to return in a single response. Valid range is 1-100.

Parameter nextToken : A pagination token from a previous request to continue listing build workflows from where the previous request left off.

Implementation

Future<ListAutomatedReasoningPolicyBuildWorkflowsResponse>
    listAutomatedReasoningPolicyBuildWorkflows({
  required String policyArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAutomatedReasoningPolicyBuildWorkflowsResponse.fromJson(
      response);
}