listInferenceProfiles method

Future<ListInferenceProfilesResponse> listInferenceProfiles({
  1. int? maxResults,
  2. String? nextToken,
  3. InferenceProfileType? typeEquals,
})

Returns a list of inference profiles that you can use. For more information, see Increase throughput and resilience with cross-region inference in Amazon Bedrock. in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

Parameter nextToken : If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

Parameter typeEquals : Filters for inference profiles that match the type you specify.

  • SYSTEM_DEFINED – The inference profile is defined by Amazon Bedrock. You can route inference requests across regions with these inference profiles.
  • APPLICATION – The inference profile was created by a user. This type of inference profile can track metrics and costs when invoking the model in it. The inference profile may route requests to one or multiple regions.

Implementation

Future<ListInferenceProfilesResponse> listInferenceProfiles({
  int? maxResults,
  String? nextToken,
  InferenceProfileType? typeEquals,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (typeEquals != null) 'type': [typeEquals.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/inference-profiles',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListInferenceProfilesResponse.fromJson(response);
}