registerMarketplaceModelEndpoint method
Registers an existing Amazon SageMaker endpoint with Amazon Bedrock Marketplace, allowing it to be used with Amazon Bedrock APIs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter endpointIdentifier :
The ARN of the Amazon SageMaker endpoint you want to register with Amazon
Bedrock Marketplace.
Parameter modelSourceIdentifier :
The ARN of the model from Amazon Bedrock Marketplace that is deployed on
the endpoint.
Implementation
Future<RegisterMarketplaceModelEndpointResponse>
registerMarketplaceModelEndpoint({
required String endpointIdentifier,
required String modelSourceIdentifier,
}) async {
final $payload = <String, dynamic>{
'modelSourceIdentifier': modelSourceIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/marketplace-model/endpoints/${Uri.encodeComponent(endpointIdentifier)}/registration',
exceptionFnMap: _exceptionFns,
);
return RegisterMarketplaceModelEndpointResponse.fromJson(response);
}