untagResource method

Future<void> untagResource({
  1. required String resourceARN,
  2. required List<String> tagKeys,
})

Remove one or more tags from a resource. For more information, see Tagging resources in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceARN : The Amazon Resource Name (ARN) of the resource to untag.

Parameter tagKeys : Tag keys of the tags to remove from the resource.

Implementation

Future<void> untagResource({
  required String resourceARN,
  required List<String> tagKeys,
}) async {
  final $payload = <String, dynamic>{
    'resourceARN': resourceARN,
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/untagResource',
    exceptionFnMap: _exceptionFns,
  );
}