updateAutomatedReasoningPolicyAnnotations method

Future<UpdateAutomatedReasoningPolicyAnnotationsResponse> updateAutomatedReasoningPolicyAnnotations({
  1. required List<AutomatedReasoningPolicyAnnotation> annotations,
  2. required String buildWorkflowId,
  3. required String lastUpdatedAnnotationSetHash,
  4. required String policyArn,
})

Updates the annotations for an Automated Reasoning policy build workflow. This allows you to modify extracted rules, variables, and types before finalizing the policy.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter annotations : The updated annotations containing modified rules, variables, and types for the policy.

Parameter buildWorkflowId : The unique identifier of the build workflow whose annotations you want to update.

Parameter lastUpdatedAnnotationSetHash : The hash value of the annotation set that you're updating. This is used for optimistic concurrency control to prevent conflicting updates.

Parameter policyArn : The Amazon Resource Name (ARN) of the Automated Reasoning policy whose annotations you want to update.

Implementation

Future<UpdateAutomatedReasoningPolicyAnnotationsResponse>
    updateAutomatedReasoningPolicyAnnotations({
  required List<AutomatedReasoningPolicyAnnotation> annotations,
  required String buildWorkflowId,
  required String lastUpdatedAnnotationSetHash,
  required String policyArn,
}) async {
  final $payload = <String, dynamic>{
    'annotations': annotations,
    'lastUpdatedAnnotationSetHash': lastUpdatedAnnotationSetHash,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}/annotations',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateAutomatedReasoningPolicyAnnotationsResponse.fromJson(response);
}