updateCustomModelDeployment method

Future<UpdateCustomModelDeploymentResponse> updateCustomModelDeployment({
  1. required String customModelDeploymentIdentifier,
  2. required String modelArn,
})

Updates a custom model deployment with a new custom model. This allows you to deploy updated models without creating new deployment endpoints.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter customModelDeploymentIdentifier : Identifier of the custom model deployment to update with the new custom model.

Parameter modelArn : ARN of the new custom model to deploy. This replaces the currently deployed model.

Implementation

Future<UpdateCustomModelDeploymentResponse> updateCustomModelDeployment({
  required String customModelDeploymentIdentifier,
  required String modelArn,
}) async {
  final $payload = <String, dynamic>{
    'modelArn': modelArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/model-customization/custom-model-deployments/${Uri.encodeComponent(customModelDeploymentIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateCustomModelDeploymentResponse.fromJson(response);
}