deleteFlow method

Future<DeleteFlowResponse> deleteFlow({
  1. required String flowIdentifier,
  2. bool? skipResourceInUseCheck,
})

Deletes a flow.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter flowIdentifier : The unique identifier of the flow.

Parameter skipResourceInUseCheck : By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Implementation

Future<DeleteFlowResponse> deleteFlow({
  required String flowIdentifier,
  bool? skipResourceInUseCheck,
}) async {
  final $query = <String, List<String>>{
    if (skipResourceInUseCheck != null)
      'skipResourceInUseCheck': [skipResourceInUseCheck.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/flows/${Uri.encodeComponent(flowIdentifier)}/',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFlowResponse.fromJson(response);
}