deleteFlowAlias method

Future<DeleteFlowAliasResponse> deleteFlowAlias({
  1. required String aliasIdentifier,
  2. required String flowIdentifier,
})

Deletes an alias of a flow.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter aliasIdentifier : The unique identifier of the alias to be deleted.

Parameter flowIdentifier : The unique identifier of the flow that the alias belongs to.

Implementation

Future<DeleteFlowAliasResponse> deleteFlowAlias({
  required String aliasIdentifier,
  required String flowIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(aliasIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFlowAliasResponse.fromJson(response);
}