deleteFlowVersion method

Future<DeleteFlowVersionResponse> deleteFlowVersion({
  1. required String flowIdentifier,
  2. required String flowVersion,
  3. bool? skipResourceInUseCheck,
})

Deletes a version of a flow.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter flowIdentifier : The unique identifier of the flow whose version that you want to delete

Parameter flowVersion : The version of the flow that you want to delete.

Parameter skipResourceInUseCheck : By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Implementation

Future<DeleteFlowVersionResponse> deleteFlowVersion({
  required String flowIdentifier,
  required String flowVersion,
  bool? skipResourceInUseCheck,
}) async {
  final $query = <String, List<String>>{
    if (skipResourceInUseCheck != null)
      'skipResourceInUseCheck': [skipResourceInUseCheck.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/versions/${Uri.encodeComponent(flowVersion)}/',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFlowVersionResponse.fromJson(response);
}