deleteKnowledgeBase method

Future<DeleteKnowledgeBaseResponse> deleteKnowledgeBase({
  1. required String knowledgeBaseId,
})

Deletes a knowledge base. Before deleting a knowledge base, you should disassociate the knowledge base from any agents that it is associated with by making a DisassociateAgentKnowledgeBase request.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter knowledgeBaseId : The unique identifier of the knowledge base to delete.

Implementation

Future<DeleteKnowledgeBaseResponse> deleteKnowledgeBase({
  required String knowledgeBaseId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/knowledgebases/${Uri.encodeComponent(knowledgeBaseId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteKnowledgeBaseResponse.fromJson(response);
}