disassociateAgentKnowledgeBase method

Future<void> disassociateAgentKnowledgeBase({
  1. required String agentId,
  2. required String agentVersion,
  3. required String knowledgeBaseId,
})

Disassociates a knowledge base from an agent.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter agentId : The unique identifier of the agent from which to disassociate the knowledge base.

Parameter agentVersion : The version of the agent from which to disassociate the knowledge base.

Parameter knowledgeBaseId : The unique identifier of the knowledge base to disassociate.

Implementation

Future<void> disassociateAgentKnowledgeBase({
  required String agentId,
  required String agentVersion,
  required String knowledgeBaseId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/agents/${Uri.encodeComponent(agentId)}/agentversions/${Uri.encodeComponent(agentVersion)}/knowledgebases/${Uri.encodeComponent(knowledgeBaseId)}/',
    exceptionFnMap: _exceptionFns,
  );
}