getAgentActionGroup method

Future<GetAgentActionGroupResponse> getAgentActionGroup({
  1. required String actionGroupId,
  2. required String agentId,
  3. required String agentVersion,
})

Gets information about an action group for an agent.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter actionGroupId : The unique identifier of the action group for which to get information.

Parameter agentId : The unique identifier of the agent that the action group belongs to.

Parameter agentVersion : The version of the agent that the action group belongs to.

Implementation

Future<GetAgentActionGroupResponse> getAgentActionGroup({
  required String actionGroupId,
  required String agentId,
  required String agentVersion,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/agents/${Uri.encodeComponent(agentId)}/agentversions/${Uri.encodeComponent(agentVersion)}/actiongroups/${Uri.encodeComponent(actionGroupId)}/',
    exceptionFnMap: _exceptionFns,
  );
  return GetAgentActionGroupResponse.fromJson(response);
}