getFlow method

Future<GetFlowResponse> getFlow({
  1. required String flowIdentifier,
  2. IncludedData? includedData,
})

Retrieves information about a flow. For more information, see Manage a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter flowIdentifier : The unique identifier of the flow.

Parameter includedData : Controls the scope of data returned. Set to METADATA_ONLY to return only resource metadata. Set to ALL_DATA or omit this field to return the full response.

Implementation

Future<GetFlowResponse> getFlow({
  required String flowIdentifier,
  IncludedData? includedData,
}) async {
  final $query = <String, List<String>>{
    if (includedData != null) 'includedData': [includedData.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/flows/${Uri.encodeComponent(flowIdentifier)}/',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetFlowResponse.fromJson(response);
}