getFlowAlias method

Future<GetFlowAliasResponse> getFlowAlias({
  1. required String aliasIdentifier,
  2. required String flowIdentifier,
})

Retrieves information about a flow. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter aliasIdentifier : The unique identifier of the alias for which to retrieve information.

Parameter flowIdentifier : The unique identifier of the flow that the alias belongs to.

Implementation

Future<GetFlowAliasResponse> getFlowAlias({
  required String aliasIdentifier,
  required String flowIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(aliasIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetFlowAliasResponse.fromJson(response);
}