getFlowVersion method

Future<GetFlowVersionResponse> getFlowVersion({
  1. required String flowIdentifier,
  2. required String flowVersion,
})

Retrieves information about a version of a flow. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter flowIdentifier : The unique identifier of the flow for which to get information.

Parameter flowVersion : The version of the flow for which to get information.

Implementation

Future<GetFlowVersionResponse> getFlowVersion({
  required String flowIdentifier,
  required String flowVersion,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/versions/${Uri.encodeComponent(flowVersion)}/',
    exceptionFnMap: _exceptionFns,
  );
  return GetFlowVersionResponse.fromJson(response);
}