prepareAgent method

Future<PrepareAgentResponse> prepareAgent({
  1. required String agentId,
})

Creates a DRAFT version of the agent that can be used for internal testing.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter agentId : The unique identifier of the agent for which to create a DRAFT version.

Implementation

Future<PrepareAgentResponse> prepareAgent({
  required String agentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/agents/${Uri.encodeComponent(agentId)}/',
    exceptionFnMap: _exceptionFns,
  );
  return PrepareAgentResponse.fromJson(response);
}