prepareFlow method

Future<PrepareFlowResponse> prepareFlow({
  1. required String flowIdentifier,
})

Prepares the DRAFT version of a flow so that it can be invoked. For more information, see Test a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter flowIdentifier : The unique identifier of the flow.

Implementation

Future<PrepareFlowResponse> prepareFlow({
  required String flowIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/flows/${Uri.encodeComponent(flowIdentifier)}/',
    exceptionFnMap: _exceptionFns,
  );
  return PrepareFlowResponse.fromJson(response);
}