updateFlowAlias method

Future<UpdateFlowAliasResponse> updateFlowAlias({
  1. required String aliasIdentifier,
  2. required String flowIdentifier,
  3. required String name,
  4. required List<FlowAliasRoutingConfigurationListItem> routingConfiguration,
  5. FlowAliasConcurrencyConfiguration? concurrencyConfiguration,
  6. String? description,
})

Modifies the alias of a flow. Include both fields that you want to keep and ones that you want to change. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter aliasIdentifier : The unique identifier of the alias.

Parameter flowIdentifier : The unique identifier of the flow.

Parameter name : The name of the alias.

Parameter routingConfiguration : Contains information about the version to which to map the alias.

Parameter concurrencyConfiguration : The configuration that specifies how nodes in the flow are executed in parallel.

Parameter description : A description for the alias.

Implementation

Future<UpdateFlowAliasResponse> updateFlowAlias({
  required String aliasIdentifier,
  required String flowIdentifier,
  required String name,
  required List<FlowAliasRoutingConfigurationListItem> routingConfiguration,
  FlowAliasConcurrencyConfiguration? concurrencyConfiguration,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    'name': name,
    'routingConfiguration': routingConfiguration,
    if (concurrencyConfiguration != null)
      'concurrencyConfiguration': concurrencyConfiguration,
    if (description != null) 'description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(aliasIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateFlowAliasResponse.fromJson(response);
}