completeResourceTokenAuth method

Future<void> completeResourceTokenAuth({
  1. required String sessionUri,
  2. required UserIdentifier userIdentifier,
})

Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter sessionUri : Unique identifier for the user's authentication session for retrieving OAuth2 tokens. This ID tracks the authorization flow state across multiple requests and responses during the OAuth2 authentication process.

Parameter userIdentifier : The OAuth2.0 token or user ID that was used to generate the workload access token used for initiating the user authorization flow to retrieve OAuth2.0 tokens.

Implementation

Future<void> completeResourceTokenAuth({
  required String sessionUri,
  required UserIdentifier userIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'sessionUri': sessionUri,
    'userIdentifier': userIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/identities/CompleteResourceTokenAuth',
    exceptionFnMap: _exceptionFns,
  );
}