deleteEvent method

Future<DeleteEventOutput> deleteEvent({
  1. required String actorId,
  2. required String eventId,
  3. required String memoryId,
  4. required String sessionId,
})

Deletes an event from an AgentCore Memory resource. When you delete an event, it is permanently removed.

To use this operation, you must have the bedrock-agentcore:DeleteEvent permission.

May throw AccessDeniedException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw ServiceException. May throw ServiceQuotaExceededException. May throw ThrottledException. May throw ValidationException.

Parameter actorId : The identifier of the actor associated with the event to delete.

Parameter eventId : The identifier of the event to delete.

Parameter memoryId : The identifier of the AgentCore Memory resource from which to delete the event.

Parameter sessionId : The identifier of the session containing the event to delete.

Implementation

Future<DeleteEventOutput> deleteEvent({
  required String actorId,
  required String eventId,
  required String memoryId,
  required String sessionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/memories/${Uri.encodeComponent(memoryId)}/actor/${Uri.encodeComponent(actorId)}/sessions/${Uri.encodeComponent(sessionId)}/events/${Uri.encodeComponent(eventId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteEventOutput.fromJson(response);
}