getBatchEvaluation method

Future<GetBatchEvaluationResponse> getBatchEvaluation({
  1. required String batchEvaluationId,
})

Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter batchEvaluationId : The unique identifier of the batch evaluation to retrieve.

Implementation

Future<GetBatchEvaluationResponse> getBatchEvaluation({
  required String batchEvaluationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/evaluations/batch-evaluate/${Uri.encodeComponent(batchEvaluationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetBatchEvaluationResponse.fromJson(response);
}