updateBrowserStream method

Future<UpdateBrowserStreamResponse> updateBrowserStream({
  1. required String browserIdentifier,
  2. required String sessionId,
  3. required StreamUpdate streamUpdate,
  4. String? clientToken,
})

Updates a browser stream. To use this operation, you must have permissions to perform the bedrock:UpdateBrowserStream action.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter browserIdentifier : The identifier of the browser.

Parameter sessionId : The identifier of the browser session.

Parameter streamUpdate : The update to apply to the browser stream.

Parameter clientToken : A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error.

Implementation

Future<UpdateBrowserStreamResponse> updateBrowserStream({
  required String browserIdentifier,
  required String sessionId,
  required StreamUpdate streamUpdate,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    'sessionId': [sessionId],
  };
  final $payload = <String, dynamic>{
    'streamUpdate': streamUpdate,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/browsers/${Uri.encodeComponent(browserIdentifier)}/sessions/streams/update',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateBrowserStreamResponse.fromJson(response);
}