createPaymentCredentialProvider method
Creates a new payment credential provider for storing authentication credentials used by payment connectors to communicate with external payment providers.
May throw AccessDeniedException.
May throw ConflictException.
May throw DecryptionFailure.
May throw EncryptionFailure.
May throw InternalServerException.
May throw ResourceLimitExceededException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter credentialProviderVendor :
The vendor type for the payment credential provider (e.g., CoinbaseCDP,
StripePrivy).
Parameter name :
Unique name for the payment credential provider.
Parameter providerConfigurationInput :
Configuration specific to the vendor, including API credentials.
Parameter tags :
Optional tags for resource organization.
Implementation
Future<CreatePaymentCredentialProviderResponse>
createPaymentCredentialProvider({
required PaymentCredentialProviderVendorType credentialProviderVendor,
required String name,
required PaymentProviderConfigurationInput providerConfigurationInput,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'credentialProviderVendor': credentialProviderVendor.value,
'name': name,
'providerConfigurationInput': providerConfigurationInput,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/identities/CreatePaymentCredentialProvider',
exceptionFnMap: _exceptionFns,
);
return CreatePaymentCredentialProviderResponse.fromJson(response);
}