deleteAgentRuntime method

Future<DeleteAgentRuntimeResponse> deleteAgentRuntime({
  1. required String agentRuntimeId,
  2. String? clientToken,
})

Deletes an Amazon Bedrock AgentCore Runtime.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter agentRuntimeId : The unique identifier of the AgentCore Runtime to delete.

Parameter clientToken : A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error.

Implementation

Future<DeleteAgentRuntimeResponse> deleteAgentRuntime({
  required String agentRuntimeId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/runtimes/${Uri.encodeComponent(agentRuntimeId)}/',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAgentRuntimeResponse.fromJson(response);
}