deleteGatewayTarget method
Deletes a gateway target.
You cannot delete a target that is in a pending authorization state
(CREATE_PENDING_AUTH, UPDATE_PENDING_AUTH, or
SYNCHRONIZE_PENDING_AUTH). Wait for the authorization to
complete or fail before deleting the target.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter gatewayIdentifier :
The unique identifier of the gateway associated with the target.
Parameter targetId :
The unique identifier of the gateway target to delete.
Implementation
Future<DeleteGatewayTargetResponse> deleteGatewayTarget({
required String gatewayIdentifier,
required String targetId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/gateways/${Uri.encodeComponent(gatewayIdentifier)}/targets/${Uri.encodeComponent(targetId)}/',
exceptionFnMap: _exceptionFns,
);
return DeleteGatewayTargetResponse.fromJson(response);
}