deleteOnlineEvaluationConfig method

Future<DeleteOnlineEvaluationConfigResponse> deleteOnlineEvaluationConfig({
  1. required String onlineEvaluationConfigId,
})

Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter onlineEvaluationConfigId : The unique identifier of the online evaluation configuration to delete.

Implementation

Future<DeleteOnlineEvaluationConfigResponse> deleteOnlineEvaluationConfig({
  required String onlineEvaluationConfigId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/online-evaluation-configs/${Uri.encodeComponent(onlineEvaluationConfigId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteOnlineEvaluationConfigResponse.fromJson(response);
}