deletePaymentCredentialProvider method

Future<void> deletePaymentCredentialProvider({
  1. required String name,
})

Deletes a payment credential provider and its associated stored credentials.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter name : The name of the payment credential provider to delete.

Implementation

Future<void> deletePaymentCredentialProvider({
  required String name,
}) async {
  final $payload = <String, dynamic>{
    'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/identities/DeletePaymentCredentialProvider',
    exceptionFnMap: _exceptionFns,
  );
}