deleteRegistry method

Future<DeleteRegistryResponse> deleteRegistry({
  1. required String registryId,
})

Deletes a registry. The registry must contain zero records before it can be deleted. This operation initiates the deletion process asynchronously.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter registryId : The identifier of the registry to delete. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

Implementation

Future<DeleteRegistryResponse> deleteRegistry({
  required String registryId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/registries/${Uri.encodeComponent(registryId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteRegistryResponse.fromJson(response);
}