updatePaymentCredentialProvider method
Future<UpdatePaymentCredentialProviderResponse>
updatePaymentCredentialProvider({
- required PaymentCredentialProviderVendorType credentialProviderVendor,
- required String name,
- required PaymentProviderConfigurationInput providerConfigurationInput,
Updates an existing payment credential provider with new authentication credentials.
May throw AccessDeniedException.
May throw ConflictException.
May throw DecryptionFailure.
May throw EncryptionFailure.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter credentialProviderVendor :
The vendor type for the payment credential provider (e.g., CoinbaseCDP,
StripePrivy).
Parameter name :
The name of the payment credential provider to update.
Parameter providerConfigurationInput :
Configuration specific to the vendor, including API credentials.
Implementation
Future<UpdatePaymentCredentialProviderResponse>
updatePaymentCredentialProvider({
required PaymentCredentialProviderVendorType credentialProviderVendor,
required String name,
required PaymentProviderConfigurationInput providerConfigurationInput,
}) async {
final $payload = <String, dynamic>{
'credentialProviderVendor': credentialProviderVendor.value,
'name': name,
'providerConfigurationInput': providerConfigurationInput,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/identities/UpdatePaymentCredentialProvider',
exceptionFnMap: _exceptionFns,
);
return UpdatePaymentCredentialProviderResponse.fromJson(response);
}