updateRegistry method

Future<UpdateRegistryResponse> updateRegistry({
  1. required String registryId,
  2. UpdatedApprovalConfiguration? approvalConfiguration,
  3. UpdatedAuthorizerConfiguration? authorizerConfiguration,
  4. UpdatedDescription? description,
  5. String? name,
})

Updates an existing registry. This operation uses PATCH semantics, so you only need to specify the fields you want to change.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter registryId : The identifier of the registry to update. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

Parameter approvalConfiguration : The updated approval configuration for registry records. The updated configuration only affects new records that move to PENDING_APPROVAL status after the change. Existing records already in PENDING_APPROVAL status are not affected.

Parameter authorizerConfiguration : The updated authorizer configuration for the registry. Changing the authorizer configuration can break existing consumers of the registry who are using the authorization type prior to the update.

Parameter description : The updated description of the registry. To clear the description, include the UpdatedDescription wrapper with optionalValue not specified.

Parameter name : The updated name of the registry.

Implementation

Future<UpdateRegistryResponse> updateRegistry({
  required String registryId,
  UpdatedApprovalConfiguration? approvalConfiguration,
  UpdatedAuthorizerConfiguration? authorizerConfiguration,
  UpdatedDescription? description,
  String? name,
}) async {
  final $payload = <String, dynamic>{
    if (approvalConfiguration != null)
      'approvalConfiguration': approvalConfiguration,
    if (authorizerConfiguration != null)
      'authorizerConfiguration': authorizerConfiguration,
    if (description != null) 'description': description,
    if (name != null) 'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/registries/${Uri.encodeComponent(registryId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRegistryResponse.fromJson(response);
}