getExecutionFlowSnapshot method
Retrieves the flow definition snapshot used for a flow execution. The snapshot represents the flow metadata and definition as it existed at the time the execution was started. Note that even if the flow is edited after an execution starts, the snapshot connected to the execution remains unchanged.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter executionIdentifier :
The unique identifier of the flow execution.
Parameter flowAliasIdentifier :
The unique identifier of the flow alias used for the flow execution.
Parameter flowIdentifier :
The unique identifier of the flow.
Implementation
Future<GetExecutionFlowSnapshotResponse> getExecutionFlowSnapshot({
required String executionIdentifier,
required String flowAliasIdentifier,
required String flowIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(flowAliasIdentifier)}/executions/${Uri.encodeComponent(executionIdentifier)}/flowsnapshot',
exceptionFnMap: _exceptionFns,
);
return GetExecutionFlowSnapshotResponse.fromJson(response);
}