getFlowExecution method

Future<GetFlowExecutionResponse> getFlowExecution({
  1. required String executionIdentifier,
  2. required String flowAliasIdentifier,
  3. required String flowIdentifier,
})

Retrieves details about a specific flow execution, including its status, start and end times, and any errors that occurred during execution.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter executionIdentifier : The unique identifier of the flow execution to retrieve.

Parameter flowAliasIdentifier : The unique identifier of the flow alias used for the execution.

Parameter flowIdentifier : The unique identifier of the flow.

Implementation

Future<GetFlowExecutionResponse> getFlowExecution({
  required String executionIdentifier,
  required String flowAliasIdentifier,
  required String flowIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(flowAliasIdentifier)}/executions/${Uri.encodeComponent(executionIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetFlowExecutionResponse.fromJson(response);
}