listFlowExecutions method
Lists all executions of a flow. Results can be paginated and include summary information about each execution, such as status, start and end times, and the execution's Amazon Resource Name (ARN).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter flowIdentifier :
The unique identifier of the flow to list executions for.
Parameter flowAliasIdentifier :
The unique identifier of the flow alias to list executions for.
Parameter maxResults :
The maximum number of flow executions to return in a single response. If
more executions exist than the specified maxResults value, a
token is included in the response so that the remaining results can be
retrieved.
Parameter nextToken :
A token to retrieve the next set of results. This value is returned in the
response if more results are available.
Implementation
Future<ListFlowExecutionsResponse> listFlowExecutions({
required String flowIdentifier,
String? flowAliasIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (flowAliasIdentifier != null)
'flowAliasIdentifier': [flowAliasIdentifier],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/flows/${Uri.encodeComponent(flowIdentifier)}/executions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFlowExecutionsResponse.fromJson(response);
}