createBlueprintVersion method

Future<CreateBlueprintVersionResponse> createBlueprintVersion({
  1. required String blueprintArn,
  2. String? clientToken,
})

Creates a new version of an existing Amazon Bedrock Data Automation Blueprint

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter blueprintArn : ARN generated at the server side when a Blueprint is created

Implementation

Future<CreateBlueprintVersionResponse> createBlueprintVersion({
  required String blueprintArn,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/blueprints/${Uri.encodeComponent(blueprintArn)}/versions/',
    exceptionFnMap: _exceptionFns,
  );
  return CreateBlueprintVersionResponse.fromJson(response);
}