getDataAutomationLibraryIngestionJob method

Future<GetDataAutomationLibraryIngestionJobResponse> getDataAutomationLibraryIngestionJob({
  1. required String jobArn,
  2. required String libraryArn,
})

API used to get status of data automation library ingestion job

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter jobArn : ARN of the DataAutomationLibraryIngestionJob

Parameter libraryArn : ARN generated at the server side when a DataAutomationLibrary is created

Implementation

Future<GetDataAutomationLibraryIngestionJobResponse>
    getDataAutomationLibraryIngestionJob({
  required String jobArn,
  required String libraryArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/data-automation-libraries/${Uri.encodeComponent(libraryArn)}/library-ingestion-jobs/${Uri.encodeComponent(jobArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDataAutomationLibraryIngestionJobResponse.fromJson(response);
}