converse method

Future<ConverseResponse> converse({
  1. required String modelId,
  2. Document? additionalModelRequestFields,
  3. List<String>? additionalModelResponseFieldPaths,
  4. GuardrailConfiguration? guardrailConfig,
  5. InferenceConfiguration? inferenceConfig,
  6. List<Message>? messages,
  7. OutputConfig? outputConfig,
  8. PerformanceConfiguration? performanceConfig,
  9. Map<String, PromptVariableValues>? promptVariables,
  10. Map<String, String>? requestMetadata,
  11. ServiceTier? serviceTier,
  12. List<SystemContentBlock>? system,
  13. ToolConfiguration? toolConfig,
})

Sends messages to the specified Amazon Bedrock model. Converse provides a consistent interface that works with all models that support messages. This allows you to write code once and use it with different models. If a model has unique inference parameters, you can also pass those unique parameters to the model.

Amazon Bedrock doesn't store any text, images, or documents that you provide as content. The data is only used to generate the response.

You can submit a prompt by including it in the messages field, specifying the modelId of a foundation model or inference profile to run inference on it, and including any other fields that are relevant to your use case.

You can also submit a prompt from Prompt management by specifying the ARN of the prompt version and including a map of variables to values in the promptVariables field. You can append more messages to the prompt by using the messages field. If you use a prompt from Prompt management, you can't include the following fields in the request: additionalModelRequestFields, inferenceConfig, system, or toolConfig. Instead, these fields must be defined through Prompt management. For more information, see Use a prompt from Prompt management.

For information about the Converse API, see Use the Converse API in the Amazon Bedrock User Guide. To use a guardrail, see Use a guardrail with the Converse API in the Amazon Bedrock User Guide. To use a tool with a model, see Tool use (Function calling) in the Amazon Bedrock User Guide

For example code, see Converse API examples in the Amazon Bedrock User Guide.

This operation requires permission for the bedrock:InvokeModel action. For troubleshooting some of the common errors you might encounter when using the Converse API, see Troubleshooting Amazon Bedrock API Error Codes in the Amazon Bedrock User Guide

May throw AccessDeniedException. May throw InternalServerException. May throw ModelErrorException. May throw ModelNotReadyException. May throw ModelTimeoutException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw ValidationException.

Parameter modelId : Specifies the model or throughput with which to run inference, or the prompt resource to use in inference. The value depends on the resource that you use:

The Converse API doesn't support imported models.

Parameter additionalModelRequestFields : Additional inference parameters that the model supports, beyond the base set of inference parameters that Converse and ConverseStream support in the inferenceConfig field. For more information, see Model parameters.

Parameter additionalModelResponseFieldPaths : Additional model parameters field paths to return in the response. Converse and ConverseStream return the requested fields as a JSON Pointer object in the additionalModelResponseFields field. The following is example JSON for additionalModelResponseFieldPaths.

[ "/stop_sequence" ]

For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation.

Converse and ConverseStream reject an empty JSON Pointer or incorrectly structured JSON Pointer with a 400 error code. if the JSON Pointer is valid, but the requested field is not in the model response, it is ignored by Converse.

Parameter guardrailConfig : Configuration information for a guardrail that you want to use in the request. If you include guardContent blocks in the content field in the messages field, the guardrail operates only on those messages. If you include no guardContent blocks, the guardrail operates on all messages in the request body and in any included prompt resource.

Parameter inferenceConfig : Inference parameters to pass to the model. Converse and ConverseStream support a base set of inference parameters. If you need to pass additional parameters that the model supports, use the additionalModelRequestFields request field.

Parameter messages : The messages that you want to send to the model.

Parameter outputConfig : Output configuration for a model response.

Parameter performanceConfig : Model performance settings for the request.

Parameter promptVariables : Contains a map of variables in a prompt from Prompt management to objects containing the values to fill in for them when running model invocation. This field is ignored if you don't specify a prompt resource in the modelId field.

Parameter requestMetadata : Key-value pairs that you can use to filter invocation logs.

Parameter serviceTier : Specifies the processing tier configuration used for serving the request.

Parameter system : A prompt that provides instructions or context to the model about the task it should perform, or the persona it should adopt during the conversation.

Parameter toolConfig : Configuration information for the tools that the model can use when generating a response.

For information about models that support tool use, see Supported models and model features.

Implementation

Future<ConverseResponse> converse({
  required String modelId,
  Document? additionalModelRequestFields,
  List<String>? additionalModelResponseFieldPaths,
  GuardrailConfiguration? guardrailConfig,
  InferenceConfiguration? inferenceConfig,
  List<Message>? messages,
  OutputConfig? outputConfig,
  PerformanceConfiguration? performanceConfig,
  Map<String, PromptVariableValues>? promptVariables,
  Map<String, String>? requestMetadata,
  ServiceTier? serviceTier,
  List<SystemContentBlock>? system,
  ToolConfiguration? toolConfig,
}) async {
  final $payload = <String, dynamic>{
    if (additionalModelRequestFields != null)
      'additionalModelRequestFields': additionalModelRequestFields,
    if (additionalModelResponseFieldPaths != null)
      'additionalModelResponseFieldPaths': additionalModelResponseFieldPaths,
    if (guardrailConfig != null) 'guardrailConfig': guardrailConfig,
    if (inferenceConfig != null) 'inferenceConfig': inferenceConfig,
    if (messages != null) 'messages': messages,
    if (outputConfig != null) 'outputConfig': outputConfig,
    if (performanceConfig != null) 'performanceConfig': performanceConfig,
    if (promptVariables != null) 'promptVariables': promptVariables,
    if (requestMetadata != null) 'requestMetadata': requestMetadata,
    if (serviceTier != null) 'serviceTier': serviceTier,
    if (system != null) 'system': system,
    if (toolConfig != null) 'toolConfig': toolConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/model/${Uri.encodeComponent(modelId)}/converse',
    exceptionFnMap: _exceptionFns,
  );
  return ConverseResponse.fromJson(response);
}