listAsyncInvokes method
Lists asynchronous invocations.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of invocations to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter sortBy :
How to sort the response.
Parameter sortOrder :
The sorting order for the response.
Parameter statusEquals :
Filter invocations by status.
Parameter submitTimeAfter :
Include invocations submitted after this time.
Parameter submitTimeBefore :
Include invocations submitted before this time.
Implementation
Future<ListAsyncInvokesResponse> listAsyncInvokes({
int? maxResults,
String? nextToken,
SortAsyncInvocationBy? sortBy,
SortOrder? sortOrder,
AsyncInvokeStatus? statusEquals,
DateTime? submitTimeAfter,
DateTime? submitTimeBefore,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (sortBy != null) 'sortBy': [sortBy.value],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
if (statusEquals != null) 'statusEquals': [statusEquals.value],
if (submitTimeAfter != null)
'submitTimeAfter': [_s.iso8601ToJson(submitTimeAfter).toString()],
if (submitTimeBefore != null)
'submitTimeBefore': [_s.iso8601ToJson(submitTimeBefore).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/async-invoke',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAsyncInvokesResponse.fromJson(response);
}