billing library

Classes

AwsClientCredentials
AWS credentials.
Billing
You can use the Billing API to programatically list the billing views available to you for a given time period. A billing view represents a set of billing data.