associateSourceViews method

Future<AssociateSourceViewsResponse> associateSourceViews({
  1. required String arn,
  2. required List<String> sourceViews,
})

Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.

May throw AccessDeniedException. May throw BillingViewHealthStatusException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the billing view to associate source views with.

Parameter sourceViews : A list of ARNs of the source billing views to associate.

Implementation

Future<AssociateSourceViewsResponse> associateSourceViews({
  required String arn,
  required List<String> sourceViews,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSBilling.AssociateSourceViews'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
      'sourceViews': sourceViews,
    },
  );

  return AssociateSourceViewsResponse.fromJson(jsonResponse.body);
}