deleteBillingView method

Future<DeleteBillingViewResponse> deleteBillingView({
  1. required String arn,
  2. bool? force,
})

Deletes the specified billing view.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

Parameter force : If set to true, forces deletion of the billing view even if it has derived resources (e.g. other billing views or budgets). Use with caution as this may break dependent resources.

Implementation

Future<DeleteBillingViewResponse> deleteBillingView({
  required String arn,
  bool? force,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSBilling.DeleteBillingView'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
      if (force != null) 'force': force,
    },
  );

  return DeleteBillingViewResponse.fromJson(jsonResponse.body);
}