disassociateSourceViews method
Removes the association between one or more source billing views and an existing billing view. This allows modifying the composition of aggregate billing views.
May throw AccessDeniedException.
May throw BillingViewHealthStatusException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) of the billing view to disassociate source
views from.
Parameter sourceViews :
A list of ARNs of the source billing views to disassociate.
Implementation
Future<DisassociateSourceViewsResponse> disassociateSourceViews({
required String arn,
required List<String> sourceViews,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSBilling.DisassociateSourceViews'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
'sourceViews': sourceViews,
},
);
return DisassociateSourceViewsResponse.fromJson(jsonResponse.body);
}