getBillingView method

Future<GetBillingViewResponse> getBillingView({
  1. required String arn,
})

Returns the metadata associated to the specified billing view ARN.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

Implementation

Future<GetBillingViewResponse> getBillingView({
  required String arn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSBilling.GetBillingView'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
    },
  );

  return GetBillingViewResponse.fromJson(jsonResponse.body);
}