listSourceViewsForBillingView method

Future<ListSourceViewsForBillingViewResponse> listSourceViewsForBillingView({
  1. required String arn,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the source views (managed Amazon Web Services billing views) associated with the billing view.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

Parameter maxResults : The number of entries a paginated response contains.

Parameter nextToken : The pagination token that is used on subsequent calls to list billing views.

Implementation

Future<ListSourceViewsForBillingViewResponse> listSourceViewsForBillingView({
  required String arn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSBilling.ListSourceViewsForBillingView'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListSourceViewsForBillingViewResponse.fromJson(jsonResponse.body);
}