deleteCustomLineItem method

Future<DeleteCustomLineItemOutput> deleteCustomLineItem({
  1. required String arn,
  2. CustomLineItemBillingPeriodRange? billingPeriodRange,
})

Deletes the custom line item identified by the given ARN in the current, or previous billing period.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The ARN of the custom line item to be deleted.

Implementation

Future<DeleteCustomLineItemOutput> deleteCustomLineItem({
  required String arn,
  CustomLineItemBillingPeriodRange? billingPeriodRange,
}) async {
  final $payload = <String, dynamic>{
    'Arn': arn,
    if (billingPeriodRange != null) 'BillingPeriodRange': billingPeriodRange,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/delete-custom-line-item',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteCustomLineItemOutput.fromJson(response);
}