listCustomLineItemVersions method
A paginated call to get a list of all custom line item versions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) for the custom line item.
Parameter filters :
A ListCustomLineItemVersionsFilter that specifies the billing
period range in which the custom line item versions are applied.
Parameter maxResults :
The maximum number of custom line item versions to retrieve.
Parameter nextToken :
The pagination token that's used on subsequent calls to retrieve custom
line item versions.
Implementation
Future<ListCustomLineItemVersionsOutput> listCustomLineItemVersions({
required String arn,
ListCustomLineItemVersionsFilter? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'Arn': arn,
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-custom-line-item-versions',
exceptionFnMap: _exceptionFns,
);
return ListCustomLineItemVersionsOutput.fromJson(response);
}