Braket class

The Amazon Braket API Reference provides information about the operations and structures supported by Amazon Braket.

To learn about the permissions required to call an Amazon Braket API action, see Actions, resources, and condition keys for Amazon Braket. Amazon Braket Python SDK and the AWS Command Line Interface can be used to make discovery and creation of API calls easier. For more information about Amazon Braket features, see What is Amazon Braket? and important terms and concepts in the Amazon Braket Developer Guide.

In this guide:

Available languages for AWS SDK: Code examples from the Amazon Braket Tutorials GitHub repository:

Constructors

Braket({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelJob({required String jobArn}) Future<CancelJobResponse>
Cancels an Amazon Braket hybrid job.
cancelQuantumTask({required String quantumTaskArn, String? clientToken}) Future<CancelQuantumTaskResponse>
Cancels the specified task.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createJob({required AlgorithmSpecification algorithmSpecification, required DeviceConfig deviceConfig, required InstanceConfig instanceConfig, required String jobName, required JobOutputDataConfig outputDataConfig, required String roleArn, List<Association>? associations, JobCheckpointConfig? checkpointConfig, String? clientToken, Map<String, String>? hyperParameters, List<InputFileConfig>? inputDataConfig, JobStoppingCondition? stoppingCondition, Map<String, String>? tags}) Future<CreateJobResponse>
Creates an Amazon Braket hybrid job.
createQuantumTask({required Object action, required String deviceArn, required String outputS3Bucket, required String outputS3KeyPrefix, required int shots, List<Association>? associations, String? clientToken, Object? deviceParameters, ExperimentalCapabilities? experimentalCapabilities, String? jobToken, Map<String, String>? tags}) Future<CreateQuantumTaskResponse>
Creates a quantum task.
createSpendingLimit({required String deviceArn, required String spendingLimit, String? clientToken, Map<String, String>? tags, TimePeriod? timePeriod}) Future<CreateSpendingLimitResponse>
Creates a spending limit for a specified quantum device. Spending limits help you control costs by setting maximum amounts that can be spent on quantum computing tasks within a specified time period. Simulators do not support spending limits.
deleteSpendingLimit({required String spendingLimitArn}) Future<void>
Deletes an existing spending limit. This operation permanently removes the spending limit and cannot be undone. After deletion, the associated device becomes unrestricted for spending.
getDevice({required String deviceArn}) Future<GetDeviceResponse>
Retrieves the devices available in Amazon Braket.
getJob({required String jobArn, List<HybridJobAdditionalAttributeName>? additionalAttributeNames}) Future<GetJobResponse>
Retrieves the specified Amazon Braket hybrid job.
getQuantumTask({required String quantumTaskArn, List<QuantumTaskAdditionalAttributeName>? additionalAttributeNames}) Future<GetQuantumTaskResponse>
Retrieves the specified quantum task.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Shows the tags associated with this resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchDevices({required List<SearchDevicesFilter> filters, int? maxResults, String? nextToken}) Future<SearchDevicesResponse>
Searches for devices using the specified filters.
searchJobs({required List<SearchJobsFilter> filters, int? maxResults, String? nextToken}) Future<SearchJobsResponse>
Searches for Amazon Braket hybrid jobs that match the specified filter values.
searchQuantumTasks({required List<SearchQuantumTasksFilter> filters, int? maxResults, String? nextToken}) Future<SearchQuantumTasksResponse>
Searches for tasks that match the specified filter values.
searchSpendingLimits({List<SearchSpendingLimitsFilter>? filters, int? maxResults, String? nextToken}) Future<SearchSpendingLimitsResponse>
Searches and lists spending limits based on specified filters. This operation supports pagination and allows filtering by various criteria to find specific spending limits. We recommend using pagination to ensure that the operation returns quickly and successfully.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Add a tag to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Remove tags from a resource.
updateSpendingLimit({required String spendingLimitArn, String? clientToken, String? spendingLimit, TimePeriod? timePeriod}) Future<void>
Updates an existing spending limit. You can modify the spending amount or time period. Changes take effect immediately.

Operators

operator ==(Object other) bool
The equality operator.
inherited