deleteSpendingLimit method

Future<void> deleteSpendingLimit({
  1. required String spendingLimitArn,
})

Deletes an existing spending limit. This operation permanently removes the spending limit and cannot be undone. After deletion, the associated device becomes unrestricted for spending.

May throw AccessDeniedException. May throw InternalServiceException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter spendingLimitArn : The Amazon Resource Name (ARN) of the spending limit to delete.

Implementation

Future<void> deleteSpendingLimit({
  required String spendingLimitArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/spending-limit/${Uri.encodeComponent(spendingLimitArn)}/delete',
    exceptionFnMap: _exceptionFns,
  );
}