searchDevices method

Future<SearchDevicesResponse> searchDevices({
  1. required List<SearchDevicesFilter> filters,
  2. int? maxResults,
  3. String? nextToken,
})

Searches for devices using the specified filters.

May throw AccessDeniedException. May throw InternalServiceException. May throw ThrottlingException. May throw ValidationException.

Parameter filters : Array of SearchDevicesFilter objects to use when searching for devices.

Parameter maxResults : The maximum number of results to return in the response.

Parameter nextToken : A token used for pagination of results returned in the response. Use the token returned from the previous request to continue search where the previous request ended.

Implementation

Future<SearchDevicesResponse> searchDevices({
  required List<SearchDevicesFilter> filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/devices',
    exceptionFnMap: _exceptionFns,
  );
  return SearchDevicesResponse.fromJson(response);
}