searchQuantumTasks method

Future<SearchQuantumTasksResponse> searchQuantumTasks({
  1. required List<SearchQuantumTasksFilter> filters,
  2. int? maxResults,
  3. String? nextToken,
})

Searches for tasks that match the specified filter values.

May throw AccessDeniedException. May throw InternalServiceException. May throw ThrottlingException. May throw ValidationException.

Parameter filters : Array of SearchQuantumTasksFilter objects to use when searching for quantum tasks.

Parameter maxResults : Maximum number of results to return in the response.

Parameter nextToken : A token used for pagination of results returned in the response. Use the token returned from the previous request to continue search where the previous request ended.

Implementation

Future<SearchQuantumTasksResponse> searchQuantumTasks({
  required List<SearchQuantumTasksFilter> filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/quantum-tasks',
    exceptionFnMap: _exceptionFns,
  );
  return SearchQuantumTasksResponse.fromJson(response);
}