deleteBudget method
Deletes a budget. You can delete your budget at any time.
May throw AccessDeniedException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
May throw ThrottlingException.
Parameter accountId :
The accountId that is associated with the budget that you
want to delete.
Parameter budgetName :
The name of the budget that you want to delete.
Implementation
Future<void> deleteBudget({
required String accountId,
required String budgetName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSBudgetServiceGateway.DeleteBudget'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccountId': accountId,
'BudgetName': budgetName,
},
);
}