describeBudget method

Future<DescribeBudgetResponse> describeBudget({
  1. required String accountId,
  2. required String budgetName,
  3. bool? showFilterExpression,
})

Describes a budget.

May throw AccessDeniedException. May throw InternalErrorException. May throw InvalidParameterException. May throw NotFoundException. May throw ThrottlingException.

Parameter accountId : The accountId that is associated with the budget that you want a description of.

Parameter budgetName : The name of the budget that you want a description of.

Parameter showFilterExpression : Specifies whether the response includes the filter expression associated with the budget. By showing the filter expression, you can see detailed filtering logic applied to the budget, such as Amazon Web Services services or tags that are being tracked.

Implementation

Future<DescribeBudgetResponse> describeBudget({
  required String accountId,
  required String budgetName,
  bool? showFilterExpression,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSBudgetServiceGateway.DescribeBudget'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AccountId': accountId,
      'BudgetName': budgetName,
      if (showFilterExpression != null)
        'ShowFilterExpression': showFilterExpression,
    },
  );

  return DescribeBudgetResponse.fromJson(jsonResponse.body);
}