updateNotification method
Updates a notification.
May throw AccessDeniedException.
May throw DuplicateRecordException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
May throw ThrottlingException.
Parameter accountId :
The accountId that is associated with the budget whose
notification you want to update.
Parameter budgetName :
The name of the budget whose notification you want to update.
Parameter newNotification :
The updated notification to be associated with a budget.
Parameter oldNotification :
The previous notification that is associated with a budget.
Implementation
Future<void> updateNotification({
required String accountId,
required String budgetName,
required Notification newNotification,
required Notification oldNotification,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSBudgetServiceGateway.UpdateNotification'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccountId': accountId,
'BudgetName': budgetName,
'NewNotification': newNotification,
'OldNotification': oldNotification,
},
);
}