budgets_2016_10_20 library

Classes

AwsClientCredentials
AWS credentials.
Budgets
Use the Amazon Web Services Budgets API to plan your service usage, service costs, and instance reservations. This API reference provides descriptions, syntax, and usage examples for each of the actions and data types for the Amazon Web Services Budgets feature.