Chatbot class
The AWS Chatbot API Reference provides descriptions, API request parameters, and the XML response for each of the AWS Chatbot API actions.
AWS Chatbot APIs are currently available in the following Regions:
-
US East (Ohio) -
us-east-2 -
US West (Oregon) -
us-west-2 -
Asia Pacific (Singapore) -
ap-southeast-1 -
Europe (Ireland) -
eu-west-1
Constructors
- Chatbot({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateToConfiguration(
{required String chatConfiguration, required String resource}) → Future< void> - Links a resource (for example, a custom action) to a channel configuration.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createChimeWebhookConfiguration(
{required String configurationName, required String iamRoleArn, required List< String> snsTopicArns, required String webhookDescription, required String webhookUrl, String? loggingLevel, List<Tag> ? tags}) → Future<CreateChimeWebhookConfigurationResult> - Creates an AWS Chatbot configuration for Amazon Chime.
-
createCustomAction(
{required String actionName, required CustomActionDefinition definition, String? aliasName, List< CustomActionAttachment> ? attachments, String? clientToken, List<Tag> ? tags}) → Future<CreateCustomActionResult> - Creates a custom action that can be invoked as an alias or as a button on a notification.
-
createMicrosoftTeamsChannelConfiguration(
{required String channelId, required String configurationName, required String iamRoleArn, required String teamId, required String tenantId, String? channelName, List< String> ? guardrailPolicyArns, String? loggingLevel, List<String> ? snsTopicArns, List<Tag> ? tags, String? teamName, bool? userAuthorizationRequired}) → Future<CreateTeamsChannelConfigurationResult> - Creates an AWS Chatbot configuration for Microsoft Teams.
-
createSlackChannelConfiguration(
{required String configurationName, required String iamRoleArn, required String slackChannelId, required String slackTeamId, List< String> ? guardrailPolicyArns, String? loggingLevel, String? slackChannelName, List<String> ? snsTopicArns, List<Tag> ? tags, bool? userAuthorizationRequired}) → Future<CreateSlackChannelConfigurationResult> - Creates an AWS Chatbot confugration for Slack.
-
deleteChimeWebhookConfiguration(
{required String chatConfigurationArn}) → Future< void> - Deletes a Amazon Chime webhook configuration for AWS Chatbot.
-
deleteCustomAction(
{required String customActionArn}) → Future< void> - Deletes a custom action.
-
deleteMicrosoftTeamsChannelConfiguration(
{required String chatConfigurationArn}) → Future< void> - Deletes a Microsoft Teams channel configuration for AWS Chatbot
-
deleteMicrosoftTeamsConfiguredTeam(
{required String teamId}) → Future< void> - Deletes the Microsoft Teams team authorization allowing for channels to be configured in that Microsoft Teams team. Note that the Microsoft Teams team must have no channels configured to remove it.
-
deleteMicrosoftTeamsUserIdentity(
{required String chatConfigurationArn, required String userId}) → Future< void> - Identifes a user level permission for a channel configuration.
-
deleteSlackChannelConfiguration(
{required String chatConfigurationArn}) → Future< void> - Deletes a Slack channel configuration for AWS Chatbot
-
deleteSlackUserIdentity(
{required String chatConfigurationArn, required String slackTeamId, required String slackUserId}) → Future< void> - Deletes a user level permission for a Slack channel configuration.
-
deleteSlackWorkspaceAuthorization(
{required String slackTeamId}) → Future< void> - Deletes the Slack workspace authorization that allows channels to be configured in that workspace. This requires all configured channels in the workspace to be deleted.
-
describeChimeWebhookConfigurations(
{String? chatConfigurationArn, int? maxResults, String? nextToken}) → Future< DescribeChimeWebhookConfigurationsResult> - Lists Amazon Chime webhook configurations optionally filtered by ChatConfigurationArn
-
describeSlackChannelConfigurations(
{String? chatConfigurationArn, int? maxResults, String? nextToken}) → Future< DescribeSlackChannelConfigurationsResult> - Lists Slack channel configurations optionally filtered by ChatConfigurationArn
-
describeSlackUserIdentities(
{String? chatConfigurationArn, int? maxResults, String? nextToken}) → Future< DescribeSlackUserIdentitiesResult> - Lists all Slack user identities with a mapped role.
-
describeSlackWorkspaces(
{int? maxResults, String? nextToken}) → Future< DescribeSlackWorkspacesResult> - List all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot.
-
disassociateFromConfiguration(
{required String chatConfiguration, required String resource}) → Future< void> - Unlink a resource, for example a custom action, from a channel configuration.
-
getAccountPreferences(
) → Future< GetAccountPreferencesResult> - Returns AWS Chatbot account preferences.
-
getCustomAction(
{required String customActionArn}) → Future< GetCustomActionResult> - Returns a custom action.
-
getMicrosoftTeamsChannelConfiguration(
{required String chatConfigurationArn}) → Future< GetTeamsChannelConfigurationResult> - Returns a Microsoft Teams channel configuration in an AWS account.
-
listAssociations(
{required String chatConfiguration, int? maxResults, String? nextToken}) → Future< ListAssociationsResult> - Lists resources associated with a channel configuration.
-
listCustomActions(
{int? maxResults, String? nextToken}) → Future< ListCustomActionsResult> - Lists custom actions defined in this account.
-
listMicrosoftTeamsChannelConfigurations(
{int? maxResults, String? nextToken, String? teamId}) → Future< ListTeamsChannelConfigurationsResult> - Lists all AWS Chatbot Microsoft Teams channel configurations in an AWS account.
-
listMicrosoftTeamsConfiguredTeams(
{int? maxResults, String? nextToken}) → Future< ListMicrosoftTeamsConfiguredTeamsResult> - Lists all authorized Microsoft Teams for an AWS Account
-
listMicrosoftTeamsUserIdentities(
{String? chatConfigurationArn, int? maxResults, String? nextToken}) → Future< ListMicrosoftTeamsUserIdentitiesResult> - A list all Microsoft Teams user identities with a mapped role.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
-
updateAccountPreferences(
{bool? trainingDataCollectionEnabled, bool? userAuthorizationRequired}) → Future< UpdateAccountPreferencesResult> - Updates AWS Chatbot account preferences.
-
updateChimeWebhookConfiguration(
{required String chatConfigurationArn, String? iamRoleArn, String? loggingLevel, List< String> ? snsTopicArns, String? webhookDescription, String? webhookUrl}) → Future<UpdateChimeWebhookConfigurationResult> - Updates a Amazon Chime webhook configuration.
-
updateCustomAction(
{required String customActionArn, required CustomActionDefinition definition, String? aliasName, List< CustomActionAttachment> ? attachments}) → Future<UpdateCustomActionResult> - Updates a custom action.
-
updateMicrosoftTeamsChannelConfiguration(
{required String channelId, required String chatConfigurationArn, String? channelName, List< String> ? guardrailPolicyArns, String? iamRoleArn, String? loggingLevel, List<String> ? snsTopicArns, bool? userAuthorizationRequired}) → Future<UpdateTeamsChannelConfigurationResult> - Updates an Microsoft Teams channel configuration.
-
updateSlackChannelConfiguration(
{required String chatConfigurationArn, required String slackChannelId, List< String> ? guardrailPolicyArns, String? iamRoleArn, String? loggingLevel, String? slackChannelName, List<String> ? snsTopicArns, bool? userAuthorizationRequired}) → Future<UpdateSlackChannelConfigurationResult> - Updates a Slack channel configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited