deleteSlackWorkspaceAuthorization method

Future<void> deleteSlackWorkspaceAuthorization({
  1. required String slackTeamId,
})

Deletes the Slack workspace authorization that allows channels to be configured in that workspace. This requires all configured channels in the workspace to be deleted.

May throw DeleteSlackWorkspaceAuthorizationFault. May throw InvalidParameterException.

Parameter slackTeamId : The ID of the Slack workspace authorized with AWS Chatbot.

Implementation

Future<void> deleteSlackWorkspaceAuthorization({
  required String slackTeamId,
}) async {
  final $payload = <String, dynamic>{
    'SlackTeamId': slackTeamId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/delete-slack-workspace-authorization',
    exceptionFnMap: _exceptionFns,
  );
}