describeSlackWorkspaces method

Future<DescribeSlackWorkspacesResult> describeSlackWorkspaces({
  1. int? maxResults,
  2. String? nextToken,
})

List all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot.

May throw DescribeSlackWorkspacesException. May throw InvalidParameterException. May throw InvalidRequestException.

Parameter maxResults : The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Implementation

Future<DescribeSlackWorkspacesResult> describeSlackWorkspaces({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/describe-slack-workspaces',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeSlackWorkspacesResult.fromJson(response);
}