listAssociations method
Lists resources associated with a channel configuration.
Parameter chatConfiguration :
The channel configuration to list associations for.
Parameter maxResults :
The maximum number of results to include in the response. If more results
exist than the specified MaxResults value, a token is included in the
response so that the remaining results can be retrieved.
Parameter nextToken :
An optional token returned from a prior request. Use this token for
pagination of results from this action. If this parameter is specified,
the response includes only results beyond the token, up to the value
specified by MaxResults.
Implementation
Future<ListAssociationsResult> listAssociations({
required String chatConfiguration,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'ChatConfiguration': chatConfiguration,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-associations',
exceptionFnMap: _exceptionFns,
);
return ListAssociationsResult.fromJson(response);
}