listMicrosoftTeamsChannelConfigurations method

Future<ListTeamsChannelConfigurationsResult> listMicrosoftTeamsChannelConfigurations({
  1. int? maxResults,
  2. String? nextToken,
  3. String? teamId,
})

Lists all AWS Chatbot Microsoft Teams channel configurations in an AWS account.

May throw InvalidParameterException. May throw InvalidRequestException. May throw ListTeamsChannelConfigurationsException.

Parameter maxResults : The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Parameter teamId : The ID of the Microsoft Teams authorized with AWS Chatbot.

To get the team ID, you must perform the initial authorization flow with Microsoft Teams in the AWS Chatbot console. Then you can copy and paste the team ID from the console. For more information, see Step 1: Configure a Microsoft Teams client in the AWS Chatbot Administrator Guide.

Implementation

Future<ListTeamsChannelConfigurationsResult>
    listMicrosoftTeamsChannelConfigurations({
  int? maxResults,
  String? nextToken,
  String? teamId,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (teamId != null) 'TeamId': teamId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-ms-teams-channel-configurations',
    exceptionFnMap: _exceptionFns,
  );
  return ListTeamsChannelConfigurationsResult.fromJson(response);
}