listMicrosoftTeamsConfiguredTeams method

Future<ListMicrosoftTeamsConfiguredTeamsResult> listMicrosoftTeamsConfiguredTeams({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all authorized Microsoft Teams for an AWS Account

May throw InvalidParameterException. May throw InvalidRequestException. May throw ListMicrosoftTeamsConfiguredTeamsException.

Parameter maxResults : The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Implementation

Future<ListMicrosoftTeamsConfiguredTeamsResult>
    listMicrosoftTeamsConfiguredTeams({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-ms-teams-configured-teams',
    exceptionFnMap: _exceptionFns,
  );
  return ListMicrosoftTeamsConfiguredTeamsResult.fromJson(response);
}