listMicrosoftTeamsUserIdentities method

Future<ListMicrosoftTeamsUserIdentitiesResult> listMicrosoftTeamsUserIdentities({
  1. String? chatConfigurationArn,
  2. int? maxResults,
  3. String? nextToken,
})

A list all Microsoft Teams user identities with a mapped role.

May throw InvalidParameterException. May throw InvalidRequestException. May throw ListMicrosoftTeamsUserIdentitiesException.

Parameter chatConfigurationArn : The Amazon Resource Name (ARN) of the MicrosoftTeamsChannelConfiguration associated with the user identities to list.

Parameter maxResults : The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Implementation

Future<ListMicrosoftTeamsUserIdentitiesResult>
    listMicrosoftTeamsUserIdentities({
  String? chatConfigurationArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (chatConfigurationArn != null)
      'ChatConfigurationArn': chatConfigurationArn,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-ms-teams-user-identities',
    exceptionFnMap: _exceptionFns,
  );
  return ListMicrosoftTeamsUserIdentitiesResult.fromJson(response);
}