untagResource method

Future<void> untagResource({
  1. required String resourceARN,
  2. required List<String> tagKeys,
})

Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.

May throw InternalServiceError. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter resourceARN : The value of the resource that will have the tag removed. An Amazon Resource Name (ARN) is an identifier for a specific AWS resource, such as a server, user, or role.

Parameter tagKeys : TagKeys are key-value pairs assigned to ARNs that can be used to group and search for resources by type. This metadata can be attached to resources for any purpose.

Implementation

Future<void> untagResource({
  required String resourceARN,
  required List<String> tagKeys,
}) async {
  final $payload = <String, dynamic>{
    'ResourceARN': resourceARN,
    'TagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/untag-resource',
    exceptionFnMap: _exceptionFns,
  );
}