chime library
Classes
- AwsClientCredentials
- AWS credentials.
- Chime
-
Most of these APIs are no longer supported and will not be updated.
We recommend using the latest versions in the Amazon
Chime SDK API reference, in the Amazon Chime SDK.
Using the latest versions requires migrating to dedicated namespaces. For more information, refer to Migrating from the Amazon Chime namespace in the Amazon Chime SDK Developer Guide. The Amazon Chime application programming interface (API) is designed so administrators can perform key tasks, such as creating and managing Amazon Chime accounts, users, and Voice Connectors. This guide provides detailed information about the Amazon Chime API, including operations, types, inputs and outputs, and error codes.
You can use an AWS SDK, the AWS Command Line Interface (AWS CLI), or the REST API to make API calls for Amazon Chime. We recommend using an AWS SDK or the AWS CLI. The page for each API action contains a See Also section that includes links to information about using the action with a language-specific AWS SDK or the AWS CLI.
- Using an AWS SDK
- You don't need to write code to calculate a signature for request authentication. The SDK clients authenticate your requests by using access keys that you provide. For more information about AWS SDKs, see the AWS Developer Center.
- Using the AWS CLI
- Use your access keys with the AWS CLI to make API calls. For information about setting up the AWS CLI, see Installing the AWS Command Line Interface in the AWS Command Line Interface User Guide. For a list of available Amazon Chime commands, see the Amazon Chime commands in the AWS CLI Command Reference.
- Using REST APIs
-
If you use REST to make API calls, you must authenticate your request by
providing a signature. Amazon Chime supports Signature Version 4. For more
information, see Signature
Version 4 Signing Process in the Amazon Web Services General
Reference.
When making REST API calls, use the service name
chimeand REST endpointhttps://service.chime.aws.amazon.com.