Chime class

Constructors

Chime({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associatePhoneNumberWithUser({required String accountId, required String e164PhoneNumber, required String userId}) Future<void>
Associates a phone number with the specified Amazon Chime user.
associateSigninDelegateGroupsWithAccount({required String accountId, required List<SigninDelegateGroup> signinDelegateGroups}) Future<void>
Associates the specified sign-in delegate groups with the specified Amazon Chime account.
batchCreateRoomMembership({required String accountId, required List<MembershipItem> membershipItemList, required String roomId}) Future<BatchCreateRoomMembershipResponse>
Adds up to 50 members to a chat room in an Amazon Chime Enterprise account. Members can be users or bots. The member role designates whether the member is a chat room administrator or a general chat room member.
batchDeletePhoneNumber({required List<String> phoneNumberIds}) Future<BatchDeletePhoneNumberResponse>
Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime Voice Connectors before they can be deleted.
batchSuspendUser({required String accountId, required List<String> userIdList}) Future<BatchSuspendUserResponse>
Suspends up to 50 users from a Team or EnterpriseLWA Amazon Chime account. For more information about different account types, see Managing Your Amazon Chime Accounts in the Amazon Chime Administration Guide.
batchUnsuspendUser({required String accountId, required List<String> userIdList}) Future<BatchUnsuspendUserResponse>
Removes the suspension from up to 50 previously suspended users for the specified Amazon Chime EnterpriseLWA account. Only users on EnterpriseLWA accounts can be unsuspended using this action. For more information about different account types, see Managing Your Amazon Chime Accounts in the account types, in the Amazon Chime Administration Guide.
batchUpdatePhoneNumber({required List<UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems}) Future<BatchUpdatePhoneNumberResponse>
Updates phone number product types or calling names. You can update one attribute at a time for each UpdatePhoneNumberRequestItem. For example, you can update the product type or the calling name.
batchUpdateUser({required String accountId, required List<UpdateUserRequestItem> updateUserRequestItems}) Future<BatchUpdateUserResponse>
Updates user details within the UpdateUserRequestItem object for up to 20 users for the specified Amazon Chime account. Currently, only LicenseType updates are supported for this action.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAccount({required String name}) Future<CreateAccountResponse>
Creates an Amazon Chime account under the administrator's AWS account. Only Team account types are currently supported for this action. For more information about different account types, see Managing Your Amazon Chime Accounts in the Amazon Chime Administration Guide.
createBot({required String accountId, required String displayName, String? domain}) Future<CreateBotResponse>
Creates a bot for an Amazon Chime Enterprise account.
createMeetingDialOut({required String fromPhoneNumber, required String joinToken, required String meetingId, required String toPhoneNumber}) Future<CreateMeetingDialOutResponse>
Uses the join token and call metadata in a meeting request (From number, To number, and so forth) to initiate an outbound call to a public switched telephone network (PSTN) and join them into a Chime meeting. Also ensures that the From number belongs to the customer.
createPhoneNumberOrder({required List<String> e164PhoneNumbers, required PhoneNumberProductType productType}) Future<CreatePhoneNumberOrderResponse>
Creates an order for phone numbers to be provisioned. For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.
createRoom({required String accountId, required String name, String? clientRequestToken}) Future<CreateRoomResponse>
Creates a chat room for the specified Amazon Chime Enterprise account.
createRoomMembership({required String accountId, required String memberId, required String roomId, RoomMembershipRole? role}) Future<CreateRoomMembershipResponse>
Adds a member to a chat room in an Amazon Chime Enterprise account. A member can be either a user or a bot. The member role designates whether the member is a chat room administrator or a general chat room member.
createUser({required String accountId, String? email, UserType? userType, String? username}) Future<CreateUserResponse>
Creates a user under the specified Amazon Chime account.
deleteAccount({required String accountId}) Future<void>
Deletes the specified Amazon Chime account. You must suspend all users before deleting Team account. You can use the BatchSuspendUser action to dodo.
deleteEventsConfiguration({required String accountId, required String botId}) Future<void>
Deletes the events configuration that allows a bot to receive outgoing events.
deletePhoneNumber({required String phoneNumberId}) Future<void>
Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime Voice Connectors before it can be deleted.
deleteRoom({required String accountId, required String roomId}) Future<void>
Deletes a chat room in an Amazon Chime Enterprise account.
deleteRoomMembership({required String accountId, required String memberId, required String roomId}) Future<void>
Removes a member from a chat room in an Amazon Chime Enterprise account.
disassociatePhoneNumberFromUser({required String accountId, required String userId}) Future<void>
Disassociates the primary provisioned phone number from the specified Amazon Chime user.
disassociateSigninDelegateGroupsFromAccount({required String accountId, required List<String> groupNames}) Future<void>
Disassociates the specified sign-in delegate groups from the specified Amazon Chime account.
getAccount({required String accountId}) Future<GetAccountResponse>
Retrieves details for the specified Amazon Chime account, such as account type and supported licenses.
getAccountSettings({required String accountId}) Future<GetAccountSettingsResponse>
Retrieves account settings for the specified Amazon Chime account ID, such as remote control and dialout settings. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.
getBot({required String accountId, required String botId}) Future<GetBotResponse>
Retrieves details for the specified bot, such as bot email address, bot type, status, and display name.
getEventsConfiguration({required String accountId, required String botId}) Future<GetEventsConfigurationResponse>
Gets details for an events configuration that allows a bot to receive outgoing events, such as an HTTPS endpoint or Lambda function ARN.
getGlobalSettings() Future<GetGlobalSettingsResponse>
Retrieves global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
getPhoneNumber({required String phoneNumberId}) Future<GetPhoneNumberResponse>
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
getPhoneNumberOrder({required String phoneNumberOrderId}) Future<GetPhoneNumberOrderResponse>
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
getPhoneNumberSettings() Future<GetPhoneNumberSettingsResponse>
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
getRetentionSettings({required String accountId}) Future<GetRetentionSettingsResponse>
Gets the retention settings for the specified Amazon Chime Enterprise account. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.
getRoom({required String accountId, required String roomId}) Future<GetRoomResponse>
Retrieves room details, such as the room name, for a room in an Amazon Chime Enterprise account.
getUser({required String accountId, required String userId}) Future<GetUserResponse>
Retrieves details for the specified user ID, such as primary email address, license type,and personal meeting PIN.
getUserSettings({required String accountId, required String userId}) Future<GetUserSettingsResponse>
Retrieves settings for the specified user ID, such as any associated phone number settings.
inviteUsers({required String accountId, required List<String> userEmailList, UserType? userType}) Future<InviteUsersResponse>
Sends email to a maximum of 50 users, inviting them to the specified Amazon Chime Team account. Only Team account types are currently supported for this action.
listAccounts({int? maxResults, String? name, String? nextToken, String? userEmail}) Future<ListAccountsResponse>
Lists the Amazon Chime accounts under the administrator's AWS account. You can filter accounts by account name prefix. To find out which Amazon Chime account a user belongs to, you can filter by the user's email address, which returns one account result.
listBots({required String accountId, int? maxResults, String? nextToken}) Future<ListBotsResponse>
Lists the bots associated with the administrator's Amazon Chime Enterprise account ID.
listPhoneNumberOrders({int? maxResults, String? nextToken}) Future<ListPhoneNumberOrdersResponse>
Lists the phone number orders for the administrator's Amazon Chime account.
listPhoneNumbers({PhoneNumberAssociationName? filterName, String? filterValue, int? maxResults, String? nextToken, PhoneNumberProductType? productType, PhoneNumberStatus? status}) Future<ListPhoneNumbersResponse>
Lists the phone numbers for the specified Amazon Chime account, Amazon Chime user, Amazon Chime Voice Connector, or Amazon Chime Voice Connector group.
listRoomMemberships({required String accountId, required String roomId, int? maxResults, String? nextToken}) Future<ListRoomMembershipsResponse>
Lists the membership details for the specified room in an Amazon Chime Enterprise account, such as the members' IDs, email addresses, and names.
listRooms({required String accountId, int? maxResults, String? memberId, String? nextToken}) Future<ListRoomsResponse>
Lists the room details for the specified Amazon Chime Enterprise account. Optionally, filter the results by a member ID (user ID or bot ID) to see a list of rooms that the member belongs to.
listSupportedPhoneNumberCountries({required PhoneNumberProductType productType}) Future<ListSupportedPhoneNumberCountriesResponse>
Lists supported phone number countries.
listUsers({required String accountId, int? maxResults, String? nextToken, String? userEmail, UserType? userType}) Future<ListUsersResponse>
Lists the users that belong to the specified Amazon Chime account. You can specify an email address to list only the user that the email address belongs to.
logoutUser({required String accountId, required String userId}) Future<void>
Logs out the specified user from all of the devices they are currently logged into.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putEventsConfiguration({required String accountId, required String botId, String? lambdaFunctionArn, String? outboundEventsHTTPSEndpoint}) Future<PutEventsConfigurationResponse>
Creates an events configuration that allows a bot to receive outgoing events sent by Amazon Chime. Choose either an HTTPS endpoint or a Lambda function ARN. For more information, see Bot.
putRetentionSettings({required String accountId, required RetentionSettings retentionSettings}) Future<PutRetentionSettingsResponse>
Puts retention settings for the specified Amazon Chime Enterprise account. We recommend using AWS CloudTrail to monitor usage of this API for your account. For more information, see Logging Amazon Chime API Calls with AWS CloudTrail in the Amazon Chime Administration Guide.
redactConversationMessage({required String accountId, required String conversationId, required String messageId}) Future<void>
Redacts the specified message from the specified Amazon Chime conversation.
redactRoomMessage({required String accountId, required String messageId, required String roomId}) Future<void>
Redacts the specified message from the specified Amazon Chime channel.
regenerateSecurityToken({required String accountId, required String botId}) Future<RegenerateSecurityTokenResponse>
Regenerates the security token for a bot.
resetPersonalPIN({required String accountId, required String userId}) Future<ResetPersonalPINResponse>
Resets the personal meeting PIN for the specified user on an Amazon Chime account. Returns the User object with the updated personal meeting PIN.
restorePhoneNumber({required String phoneNumberId}) Future<RestorePhoneNumberResponse>
Moves a phone number from the Deletion queue back into the phone number Inventory.
searchAvailablePhoneNumbers({String? areaCode, String? city, String? country, int? maxResults, String? nextToken, PhoneNumberType? phoneNumberType, String? state, String? tollFreePrefix}) Future<SearchAvailablePhoneNumbersResponse>
Searches for phone numbers that can be ordered. For US numbers, provide at least one of the following search filters: AreaCode, City, State, or TollFreePrefix. If you provide City, you must also provide State. Numbers outside the US only support the PhoneNumberType filter, which you must use.
toString() String
A string representation of this object.
inherited
updateAccount({required String accountId, License? defaultLicense, String? name}) Future<UpdateAccountResponse>
Updates account details for the specified Amazon Chime account. Currently, only account name and default license updates are supported for this action.
updateAccountSettings({required String accountId, required AccountSettings accountSettings}) Future<void>
Updates the settings for the specified Amazon Chime account. You can update settings for remote control of shared screens, or for the dial-out option. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.
updateBot({required String accountId, required String botId, bool? disabled}) Future<UpdateBotResponse>
Updates the status of the specified bot, such as starting or stopping the bot from running in your Amazon Chime Enterprise account.
updateGlobalSettings({BusinessCallingSettings? businessCalling, VoiceConnectorSettings? voiceConnector}) Future<void>
Updates global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
updatePhoneNumber({required String phoneNumberId, String? callingName, PhoneNumberProductType? productType}) Future<UpdatePhoneNumberResponse>
Updates phone number details, such as product type or calling name, for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type or the calling name in one action.
updatePhoneNumberSettings({required String callingName}) Future<void>
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.
updateRoom({required String accountId, required String roomId, String? name}) Future<UpdateRoomResponse>
Updates room details, such as the room name, for a room in an Amazon Chime Enterprise account.
updateRoomMembership({required String accountId, required String memberId, required String roomId, RoomMembershipRole? role}) Future<UpdateRoomMembershipResponse>
Updates room membership details, such as the member role, for a room in an Amazon Chime Enterprise account. The member role designates whether the member is a chat room administrator or a general chat room member. The member role can be updated only for user IDs.
updateUser({required String accountId, required String userId, AlexaForBusinessMetadata? alexaForBusinessMetadata, License? licenseType, UserType? userType}) Future<UpdateUserResponse>
Updates user details for a specified user ID. Currently, only LicenseType updates are supported for this action.
updateUserSettings({required String accountId, required String userId, required UserSettings userSettings}) Future<void>
Updates the settings for the specified user, such as phone number settings.

Operators

operator ==(Object other) bool
The equality operator.
inherited