batchDeletePhoneNumber method

Future<BatchDeletePhoneNumberResponse> batchDeletePhoneNumber({
  1. required List<String> phoneNumberIds,
})

Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime Voice Connectors before they can be deleted.

Phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter phoneNumberIds : List of phone number IDs.

Implementation

Future<BatchDeletePhoneNumberResponse> batchDeletePhoneNumber({
  required List<String> phoneNumberIds,
}) async {
  final $payload = <String, dynamic>{
    'PhoneNumberIds': phoneNumberIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/phone-numbers?operation=batch-delete',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeletePhoneNumberResponse.fromJson(response);
}