batchUnsuspendUser method
Removes the suspension from up to 50 previously suspended users for the
specified Amazon Chime EnterpriseLWA account. Only users on
EnterpriseLWA accounts can be unsuspended using this action.
For more information about different account types, see
Managing Your Amazon Chime Accounts in the account types, in the
Amazon Chime Administration Guide.
Previously suspended users who are unsuspended using this action are
returned to Registered status. Users who are not previously
suspended are ignored.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter userIdList :
The request containing the user IDs to unsuspend.
Implementation
Future<BatchUnsuspendUserResponse> batchUnsuspendUser({
required String accountId,
required List<String> userIdList,
}) async {
final $payload = <String, dynamic>{
'UserIdList': userIdList,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(accountId)}/users?operation=unsuspend',
exceptionFnMap: _exceptionFns,
);
return BatchUnsuspendUserResponse.fromJson(response);
}