batchUpdatePhoneNumber method
- required List<
UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems,
Updates phone number product types or calling names. You can update one
attribute at a time for each UpdatePhoneNumberRequestItem.
For example, you can update the product type or the calling name.
For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.
Updates to outbound calling names can take up to 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter updatePhoneNumberRequestItems :
The request containing the phone number IDs and product types or calling
names to update.
Implementation
Future<BatchUpdatePhoneNumberResponse> batchUpdatePhoneNumber({
required List<UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems,
}) async {
final $payload = <String, dynamic>{
'UpdatePhoneNumberRequestItems': updatePhoneNumberRequestItems,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/phone-numbers?operation=batch-update',
exceptionFnMap: _exceptionFns,
);
return BatchUpdatePhoneNumberResponse.fromJson(response);
}