deletePhoneNumber method
Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime Voice Connectors before it can be deleted.
Deleted phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter phoneNumberId :
The phone number ID.
Implementation
Future<void> deletePhoneNumber({
required String phoneNumberId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/phone-numbers/${Uri.encodeComponent(phoneNumberId)}',
exceptionFnMap: _exceptionFns,
);
}