getAccountSettings method

Future<GetAccountSettingsResponse> getAccountSettings({
  1. required String accountId,
})

Retrieves account settings for the specified Amazon Chime account ID, such as remote control and dialout settings. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter accountId : The Amazon Chime account ID.

Implementation

Future<GetAccountSettingsResponse> getAccountSettings({
  required String accountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(accountId)}/settings',
    exceptionFnMap: _exceptionFns,
  );
  return GetAccountSettingsResponse.fromJson(response);
}