getBot method

Future<GetBotResponse> getBot({
  1. required String accountId,
  2. required String botId,
})

Retrieves details for the specified bot, such as bot email address, bot type, status, and display name.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter accountId : The Amazon Chime account ID.

Parameter botId : The bot ID.

Implementation

Future<GetBotResponse> getBot({
  required String accountId,
  required String botId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(accountId)}/bots/${Uri.encodeComponent(botId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetBotResponse.fromJson(response);
}