getEventsConfiguration method
Gets details for an events configuration that allows a bot to receive outgoing events, such as an HTTPS endpoint or Lambda function ARN.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ResourceLimitExceededException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter botId :
The bot ID.
Implementation
Future<GetEventsConfigurationResponse> getEventsConfiguration({
required String accountId,
required String botId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(accountId)}/bots/${Uri.encodeComponent(botId)}/events-configuration',
exceptionFnMap: _exceptionFns,
);
return GetEventsConfigurationResponse.fromJson(response);
}