getPhoneNumberOrder method

Future<GetPhoneNumberOrderResponse> getPhoneNumberOrder({
  1. required String phoneNumberOrderId,
})

Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter phoneNumberOrderId : The ID for the phone number order.

Implementation

Future<GetPhoneNumberOrderResponse> getPhoneNumberOrder({
  required String phoneNumberOrderId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/phone-number-orders/${Uri.encodeComponent(phoneNumberOrderId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetPhoneNumberOrderResponse.fromJson(response);
}