getRetentionSettings method

Future<GetRetentionSettingsResponse> getRetentionSettings({
  1. required String accountId,
})

Gets the retention settings for the specified Amazon Chime Enterprise account. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter accountId : The Amazon Chime account ID.

Implementation

Future<GetRetentionSettingsResponse> getRetentionSettings({
  required String accountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(accountId)}/retention-settings',
    exceptionFnMap: _exceptionFns,
  );
  return GetRetentionSettingsResponse.fromJson(response);
}