getRoom method
Retrieves room details, such as the room name, for a room in an Amazon Chime Enterprise account.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter roomId :
The room ID.
Implementation
Future<GetRoomResponse> getRoom({
required String accountId,
required String roomId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(accountId)}/rooms/${Uri.encodeComponent(roomId)}',
exceptionFnMap: _exceptionFns,
);
return GetRoomResponse.fromJson(response);
}