resetPersonalPIN method
Resets the personal meeting PIN for the specified user on an Amazon Chime account. Returns the User object with the updated personal meeting PIN.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter userId :
The user ID.
Implementation
Future<ResetPersonalPINResponse> resetPersonalPIN({
required String accountId,
required String userId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(accountId)}/users/${Uri.encodeComponent(userId)}?operation=reset-personal-pin',
exceptionFnMap: _exceptionFns,
);
return ResetPersonalPINResponse.fromJson(response);
}