updateAccountSettings method
Future<void>
updateAccountSettings({
- required String accountId,
- required AccountSettings accountSettings,
Updates the settings for the specified Amazon Chime account. You can update settings for remote control of shared screens, or for the dial-out option. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter accountSettings :
The Amazon Chime account settings to update.
Implementation
Future<void> updateAccountSettings({
required String accountId,
required AccountSettings accountSettings,
}) async {
final $payload = <String, dynamic>{
'AccountSettings': accountSettings,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/accounts/${Uri.encodeComponent(accountId)}/settings',
exceptionFnMap: _exceptionFns,
);
}