updateRoom method
Updates room details, such as the room name, for a room in an Amazon Chime Enterprise account.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter accountId :
The Amazon Chime account ID.
Parameter roomId :
The room ID.
Parameter name :
The room name.
Implementation
Future<UpdateRoomResponse> updateRoom({
required String accountId,
required String roomId,
String? name,
}) async {
final $payload = <String, dynamic>{
if (name != null) 'Name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(accountId)}/rooms/${Uri.encodeComponent(roomId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateRoomResponse.fromJson(response);
}