ChimeSdkIdentity class

The Amazon Chime SDK Identity APIs in this section allow software developers to create and manage unique instances of their messaging applications. These APIs provide the overarching framework for creating and sending messages. For more information about the identity APIs, refer to Amazon Chime SDK identity.

Constructors

ChimeSdkIdentity({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAppInstance({required String name, String? clientRequestToken, String? metadata, List<Tag>? tags}) Future<CreateAppInstanceResponse>
Creates an Amazon Chime SDK messaging AppInstance under an AWS account. Only SDK messaging customers use this API. CreateAppInstance supports idempotency behavior as described in the AWS API Standard.
createAppInstanceAdmin({required String appInstanceAdminArn, required String appInstanceArn}) Future<CreateAppInstanceAdminResponse>
Promotes an AppInstanceUser or AppInstanceBot to an AppInstanceAdmin. The promoted entity can perform the following actions.
createAppInstanceBot({required String appInstanceArn, required Configuration configuration, String? clientRequestToken, String? metadata, String? name, List<Tag>? tags}) Future<CreateAppInstanceBotResponse>
Creates a bot under an Amazon Chime AppInstance. The request consists of a unique Configuration and Name for that bot.
createAppInstanceUser({required String appInstanceArn, required String appInstanceUserId, required String name, String? clientRequestToken, ExpirationSettings? expirationSettings, String? metadata, List<Tag>? tags}) Future<CreateAppInstanceUserResponse>
Creates a user under an Amazon Chime AppInstance. The request consists of a unique appInstanceUserId and Name for that user.
deleteAppInstance({required String appInstanceArn}) Future<void>
Deletes an AppInstance and all associated data asynchronously.
deleteAppInstanceAdmin({required String appInstanceAdminArn, required String appInstanceArn}) Future<void>
Demotes an AppInstanceAdmin to an AppInstanceUser or AppInstanceBot. This action does not delete the user.
deleteAppInstanceBot({required String appInstanceBotArn}) Future<void>
Deletes an AppInstanceBot.
deleteAppInstanceUser({required String appInstanceUserArn}) Future<void>
Deletes an AppInstanceUser.
deregisterAppInstanceUserEndpoint({required String appInstanceUserArn, required String endpointId}) Future<void>
Deregisters an AppInstanceUserEndpoint.
describeAppInstance({required String appInstanceArn}) Future<DescribeAppInstanceResponse>
Returns the full details of an AppInstance.
describeAppInstanceAdmin({required String appInstanceAdminArn, required String appInstanceArn}) Future<DescribeAppInstanceAdminResponse>
Returns the full details of an AppInstanceAdmin.
describeAppInstanceBot({required String appInstanceBotArn}) Future<DescribeAppInstanceBotResponse>
The AppInstanceBot's information.
describeAppInstanceUser({required String appInstanceUserArn}) Future<DescribeAppInstanceUserResponse>
Returns the full details of an AppInstanceUser.
describeAppInstanceUserEndpoint({required String appInstanceUserArn, required String endpointId}) Future<DescribeAppInstanceUserEndpointResponse>
Returns the full details of an AppInstanceUserEndpoint.
getAppInstanceRetentionSettings({required String appInstanceArn}) Future<GetAppInstanceRetentionSettingsResponse>
Gets the retention settings for an AppInstance.
listAppInstanceAdmins({required String appInstanceArn, int? maxResults, String? nextToken}) Future<ListAppInstanceAdminsResponse>
Returns a list of the administrators in the AppInstance.
listAppInstanceBots({required String appInstanceArn, int? maxResults, String? nextToken}) Future<ListAppInstanceBotsResponse>
Lists all AppInstanceBots created under a single AppInstance.
listAppInstances({int? maxResults, String? nextToken}) Future<ListAppInstancesResponse>
Lists all Amazon Chime AppInstances created under a single AWS account.
listAppInstanceUserEndpoints({required String appInstanceUserArn, int? maxResults, String? nextToken}) Future<ListAppInstanceUserEndpointsResponse>
Lists all the AppInstanceUserEndpoints created under a single AppInstanceUser.
listAppInstanceUsers({required String appInstanceArn, int? maxResults, String? nextToken}) Future<ListAppInstanceUsersResponse>
List all AppInstanceUsers created under a single AppInstance.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
Lists the tags applied to an Amazon Chime SDK identity resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAppInstanceRetentionSettings({required String appInstanceArn, required AppInstanceRetentionSettings appInstanceRetentionSettings}) Future<PutAppInstanceRetentionSettingsResponse>
Sets the amount of time in days that a given AppInstance retains data.
putAppInstanceUserExpirationSettings({required String appInstanceUserArn, ExpirationSettings? expirationSettings}) Future<PutAppInstanceUserExpirationSettingsResponse>
Sets the number of days before the AppInstanceUser is automatically deleted.
registerAppInstanceUserEndpoint({required String appInstanceUserArn, required EndpointAttributes endpointAttributes, required String resourceArn, required AppInstanceUserEndpointType type, AllowMessages? allowMessages, String? clientRequestToken, String? name}) Future<RegisterAppInstanceUserEndpointResponse>
Registers an endpoint under an Amazon Chime AppInstanceUser. The endpoint receives messages for a user. For push notifications, the endpoint is a mobile device used to receive mobile push notifications for a user.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Applies the specified tags to the specified Amazon Chime SDK identity resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified Amazon Chime SDK identity resource.
updateAppInstance({required String appInstanceArn, required String metadata, required String name}) Future<UpdateAppInstanceResponse>
Updates AppInstance metadata.
updateAppInstanceBot({required String appInstanceBotArn, required String metadata, required String name, Configuration? configuration}) Future<UpdateAppInstanceBotResponse>
Updates the name and metadata of an AppInstanceBot.
updateAppInstanceUser({required String appInstanceUserArn, required String metadata, required String name}) Future<UpdateAppInstanceUserResponse>
Updates the details of an AppInstanceUser. You can update names and metadata.
updateAppInstanceUserEndpoint({required String appInstanceUserArn, required String endpointId, AllowMessages? allowMessages, String? name}) Future<UpdateAppInstanceUserEndpointResponse>
Updates the details of an AppInstanceUserEndpoint. You can update the name and AllowMessage values.

Operators

operator ==(Object other) bool
The equality operator.
inherited