getMessagingSessionEndpoint method

Future<GetMessagingSessionEndpointResponse> getMessagingSessionEndpoint({
  1. NetworkType? networkType,
})

The details of the endpoint for the messaging session.

May throw ForbiddenException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter networkType : The type of network for the messaging session endpoint. Either IPv4 only or dual-stack (IPv4 and IPv6).

Implementation

Future<GetMessagingSessionEndpointResponse> getMessagingSessionEndpoint({
  NetworkType? networkType,
}) async {
  final $query = <String, List<String>>{
    if (networkType != null) 'network-type': [networkType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/endpoints/messaging-session',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetMessagingSessionEndpointResponse.fromJson(response);
}