ChimeSdkVoice class
The Amazon Chime SDK telephony APIs in this section enable developers to create PSTN calling solutions that use Amazon Chime SDK Voice Connectors, and Amazon Chime SDK SIP media applications. Developers can also order and manage phone numbers, create and manage Voice Connectors and SIP media applications, and run voice analytics.
Constructors
- ChimeSdkVoice({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associatePhoneNumbersWithVoiceConnector(
{required List< String> e164PhoneNumbers, required String voiceConnectorId, bool? forceAssociate}) → Future<AssociatePhoneNumbersWithVoiceConnectorResponse> - Associates phone numbers with the specified Amazon Chime SDK Voice Connector.
-
associatePhoneNumbersWithVoiceConnectorGroup(
{required List< String> e164PhoneNumbers, required String voiceConnectorGroupId, bool? forceAssociate}) → Future<AssociatePhoneNumbersWithVoiceConnectorGroupResponse> - Associates phone numbers with the specified Amazon Chime SDK Voice Connector group.
-
batchDeletePhoneNumber(
{required List< String> phoneNumberIds}) → Future<BatchDeletePhoneNumberResponse> - Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime SDK Voice Connectors before they can be deleted.
-
batchUpdatePhoneNumber(
{required List< UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems}) → Future<BatchUpdatePhoneNumberResponse> -
Updates phone number product types, calling names, or phone number names.
You can update one attribute at a time for each
UpdatePhoneNumberRequestItem. For example, you can update the product type, the calling name, or phone name. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createPhoneNumberOrder(
{required List< String> e164PhoneNumbers, required PhoneNumberProductType productType, String? name}) → Future<CreatePhoneNumberOrderResponse> - Creates an order for phone numbers to be provisioned. For numbers outside the U.S., you must use the Amazon Chime SDK SIP media application dial-in product type.
-
createProxySession(
{required List< Capability> capabilities, required List<String> participantPhoneNumbers, required String voiceConnectorId, int? expiryMinutes, GeoMatchLevel? geoMatchLevel, GeoMatchParams? geoMatchParams, String? name, NumberSelectionBehavior? numberSelectionBehavior}) → Future<CreateProxySessionResponse> - Creates a proxy session for the specified Amazon Chime SDK Voice Connector for the specified participant phone numbers.
-
createSipMediaApplication(
{required String awsRegion, required List< SipMediaApplicationEndpoint> endpoints, required String name, List<Tag> ? tags}) → Future<CreateSipMediaApplicationResponse> - Creates a SIP media application. For more information about SIP media applications, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
-
createSipMediaApplicationCall(
{required String fromPhoneNumber, required String sipMediaApplicationId, required String toPhoneNumber, Map< String, String> ? argumentsMap, Map<String, String> ? sipHeaders}) → Future<CreateSipMediaApplicationCallResponse> -
Creates an outbound call to a phone number from the phone number specified
in the request, and it invokes the endpoint of the specified
sipMediaApplicationId. -
createSipRule(
{required String name, required SipRuleTriggerType triggerType, required String triggerValue, bool? disabled, List< SipRuleTargetApplication> ? targetApplications}) → Future<CreateSipRuleResponse> - Creates a SIP rule, which can be used to run a SIP media application as a target for a specific trigger type. For more information about SIP rules, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
-
createVoiceConnector(
{required String name, required bool requireEncryption, VoiceConnectorAwsRegion? awsRegion, VoiceConnectorIntegrationType? integrationType, NetworkType? networkType, List< Tag> ? tags}) → Future<CreateVoiceConnectorResponse> - Creates an Amazon Chime SDK Voice Connector. For more information about Voice Connectors, see Managing Amazon Chime SDK Voice Connector groups in the Amazon Chime SDK Administrator Guide.
-
createVoiceConnectorGroup(
{required String name, List< VoiceConnectorItem> ? voiceConnectorItems}) → Future<CreateVoiceConnectorGroupResponse> -
Creates an Amazon Chime SDK Voice Connector group under the
administrator's AWS account. You can associate Amazon Chime SDK Voice
Connectors with the Voice Connector group by including
VoiceConnectorItemsin the request. -
createVoiceProfile(
{required String speakerSearchTaskId}) → Future< CreateVoiceProfileResponse> - Creates a voice profile, which consists of an enrolled user and their latest voice print. For more information about voice profiles and voice analytics, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
-
createVoiceProfileDomain(
{required String name, required ServerSideEncryptionConfiguration serverSideEncryptionConfiguration, String? clientRequestToken, String? description, List< Tag> ? tags}) → Future<CreateVoiceProfileDomainResponse> - Creates a voice profile domain, a collection of voice profiles, their voice prints, and encrypted enrollment audio. For more information about voice profile domains, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
-
deletePhoneNumber(
{required String phoneNumberId}) → Future< void> - Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime SDK Voice Connectors before it can be deleted.
-
deleteProxySession(
{required String proxySessionId, required String voiceConnectorId}) → Future< void> - Deletes the specified proxy session from the specified Amazon Chime SDK Voice Connector.
-
deleteSipMediaApplication(
{required String sipMediaApplicationId}) → Future< void> - Deletes a SIP media application.
-
deleteSipRule(
{required String sipRuleId}) → Future< void> - Deletes a SIP rule.
-
deleteVoiceConnector(
{required String voiceConnectorId}) → Future< void> - Deletes an Amazon Chime SDK Voice Connector. Any phone numbers associated with the Amazon Chime SDK Voice Connector must be disassociated from it before it can be deleted.
-
deleteVoiceConnectorEmergencyCallingConfiguration(
{required String voiceConnectorId}) → Future< void> - Deletes the emergency calling details from the specified Amazon Chime SDK Voice Connector.
-
deleteVoiceConnectorExternalSystemsConfiguration(
{required String voiceConnectorId}) → Future< void> - Deletes the external systems configuration for a Voice Connector.
-
deleteVoiceConnectorGroup(
{required String voiceConnectorGroupId}) → Future< void> -
Deletes an Amazon Chime SDK Voice Connector group. Any
VoiceConnectorItemsand phone numbers associated with the group must be removed before it can be deleted. -
deleteVoiceConnectorOrigination(
{required String voiceConnectorId}) → Future< void> - Deletes the origination settings for the specified Amazon Chime SDK Voice Connector.
-
deleteVoiceConnectorProxy(
{required String voiceConnectorId}) → Future< void> - Deletes the proxy configuration from the specified Amazon Chime SDK Voice Connector.
-
deleteVoiceConnectorStreamingConfiguration(
{required String voiceConnectorId}) → Future< void> - Deletes a Voice Connector's streaming configuration.
-
deleteVoiceConnectorTermination(
{required String voiceConnectorId}) → Future< void> - Deletes the termination settings for the specified Amazon Chime SDK Voice Connector.
-
deleteVoiceConnectorTerminationCredentials(
{required List< String> usernames, required String voiceConnectorId}) → Future<void> - Deletes the specified SIP credentials used by your equipment to authenticate during call termination.
-
deleteVoiceProfile(
{required String voiceProfileId}) → Future< void> - Deletes a voice profile, including its voice print and enrollment data. WARNING: This action is not reversible.
-
deleteVoiceProfileDomain(
{required String voiceProfileDomainId}) → Future< void> - Deletes all voice profiles in the domain. WARNING: This action is not reversible.
-
disassociatePhoneNumbersFromVoiceConnector(
{required List< String> e164PhoneNumbers, required String voiceConnectorId}) → Future<DisassociatePhoneNumbersFromVoiceConnectorResponse> - Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector.
-
disassociatePhoneNumbersFromVoiceConnectorGroup(
{required List< String> e164PhoneNumbers, required String voiceConnectorGroupId}) → Future<DisassociatePhoneNumbersFromVoiceConnectorGroupResponse> - Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector group.
-
getGlobalSettings(
) → Future< GetGlobalSettingsResponse> - Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
getPhoneNumber(
{required String phoneNumberId}) → Future< GetPhoneNumberResponse> - Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
-
getPhoneNumberOrder(
{required String phoneNumberOrderId}) → Future< GetPhoneNumberOrderResponse> - Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
-
getPhoneNumberSettings(
) → Future< GetPhoneNumberSettingsResponse> - Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
getProxySession(
{required String proxySessionId, required String voiceConnectorId}) → Future< GetProxySessionResponse> - Retrieves the specified proxy session details for the specified Amazon Chime SDK Voice Connector.
-
getSipMediaApplication(
{required String sipMediaApplicationId}) → Future< GetSipMediaApplicationResponse> - Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.
-
getSipMediaApplicationAlexaSkillConfiguration(
{required String sipMediaApplicationId}) → Future< GetSipMediaApplicationAlexaSkillConfigurationResponse> - Gets the Alexa Skill configuration for the SIP media application.
-
getSipMediaApplicationLoggingConfiguration(
{required String sipMediaApplicationId}) → Future< GetSipMediaApplicationLoggingConfigurationResponse> - Retrieves the logging configuration for the specified SIP media application.
-
getSipRule(
{required String sipRuleId}) → Future< GetSipRuleResponse> - Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.
-
getSpeakerSearchTask(
{required String speakerSearchTaskId, required String voiceConnectorId}) → Future< GetSpeakerSearchTaskResponse> - Retrieves the details of the specified speaker search task.
-
getVoiceConnector(
{required String voiceConnectorId}) → Future< GetVoiceConnectorResponse> - Retrieves details for the specified Amazon Chime SDK Voice Connector, such as timestamps,name, outbound host, and encryption requirements.
-
getVoiceConnectorEmergencyCallingConfiguration(
{required String voiceConnectorId}) → Future< GetVoiceConnectorEmergencyCallingConfigurationResponse> - Retrieves the emergency calling configuration details for the specified Voice Connector.
-
getVoiceConnectorExternalSystemsConfiguration(
{required String voiceConnectorId}) → Future< GetVoiceConnectorExternalSystemsConfigurationResponse> - Gets information about an external systems configuration for a Voice Connector.
-
getVoiceConnectorGroup(
{required String voiceConnectorGroupId}) → Future< GetVoiceConnectorGroupResponse> -
Retrieves details for the specified Amazon Chime SDK Voice Connector
group, such as timestamps,name, and associated
VoiceConnectorItems. -
getVoiceConnectorLoggingConfiguration(
{required String voiceConnectorId}) → Future< GetVoiceConnectorLoggingConfigurationResponse> - Retrieves the logging configuration settings for the specified Voice Connector. Shows whether SIP message logs are enabled for sending to Amazon CloudWatch Logs.
-
getVoiceConnectorOrigination(
{required String voiceConnectorId}) → Future< GetVoiceConnectorOriginationResponse> - Retrieves the origination settings for the specified Voice Connector.
-
getVoiceConnectorProxy(
{required String voiceConnectorId}) → Future< GetVoiceConnectorProxyResponse> - Retrieves the proxy configuration details for the specified Amazon Chime SDK Voice Connector.
-
getVoiceConnectorStreamingConfiguration(
{required String voiceConnectorId}) → Future< GetVoiceConnectorStreamingConfigurationResponse> - Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector. Shows whether media streaming is enabled for sending to Amazon Kinesis. It also shows the retention period, in hours, for the Amazon Kinesis data.
-
getVoiceConnectorTermination(
{required String voiceConnectorId}) → Future< GetVoiceConnectorTerminationResponse> - Retrieves the termination setting details for the specified Voice Connector.
-
getVoiceConnectorTerminationHealth(
{required String voiceConnectorId}) → Future< GetVoiceConnectorTerminationHealthResponse> -
Retrieves information about the last time a
SIP OPTIONSping was received from your SIP infrastructure for the specified Amazon Chime SDK Voice Connector. -
getVoiceProfile(
{required String voiceProfileId}) → Future< GetVoiceProfileResponse> - Retrieves the details of the specified voice profile.
-
getVoiceProfileDomain(
{required String voiceProfileDomainId}) → Future< GetVoiceProfileDomainResponse> - Retrieves the details of the specified voice profile domain.
-
getVoiceToneAnalysisTask(
{required bool isCaller, required String voiceConnectorId, required String voiceToneAnalysisTaskId}) → Future< GetVoiceToneAnalysisTaskResponse> - Retrieves the details of a voice tone analysis task.
-
listAvailableVoiceConnectorRegions(
) → Future< ListAvailableVoiceConnectorRegionsResponse> - Lists the available AWS Regions in which you can create an Amazon Chime SDK Voice Connector.
-
listPhoneNumberOrders(
{int? maxResults, String? nextToken}) → Future< ListPhoneNumberOrdersResponse> - Lists the phone numbers for an administrator's Amazon Chime SDK account.
-
listPhoneNumbers(
{PhoneNumberAssociationName? filterName, String? filterValue, int? maxResults, String? nextToken, PhoneNumberProductType? productType, String? status}) → Future< ListPhoneNumbersResponse> - Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime SDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector group.
-
listProxySessions(
{required String voiceConnectorId, int? maxResults, String? nextToken, ProxySessionStatus? status}) → Future< ListProxySessionsResponse> - Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.
-
listSipMediaApplications(
{int? maxResults, String? nextToken}) → Future< ListSipMediaApplicationsResponse> - Lists the SIP media applications under the administrator's AWS account.
-
listSipRules(
{int? maxResults, String? nextToken, String? sipMediaApplicationId}) → Future< ListSipRulesResponse> - Lists the SIP rules under the administrator's AWS account.
-
listSupportedPhoneNumberCountries(
{required PhoneNumberProductType productType}) → Future< ListSupportedPhoneNumberCountriesResponse> - Lists the countries that you can order phone numbers from.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Returns a list of the tags in a given resource.
-
listVoiceConnectorGroups(
{int? maxResults, String? nextToken}) → Future< ListVoiceConnectorGroupsResponse> - Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS account.
-
listVoiceConnectors(
{int? maxResults, String? nextToken}) → Future< ListVoiceConnectorsResponse> - Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.
-
listVoiceConnectorTerminationCredentials(
{required String voiceConnectorId}) → Future< ListVoiceConnectorTerminationCredentialsResponse> - Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.
-
listVoiceProfileDomains(
{int? maxResults, String? nextToken}) → Future< ListVoiceProfileDomainsResponse> - Lists the specified voice profile domains in the administrator's AWS account.
-
listVoiceProfiles(
{required String voiceProfileDomainId, int? maxResults, String? nextToken}) → Future< ListVoiceProfilesResponse> - Lists the voice profiles in a voice profile domain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putSipMediaApplicationAlexaSkillConfiguration(
{required String sipMediaApplicationId, SipMediaApplicationAlexaSkillConfiguration? sipMediaApplicationAlexaSkillConfiguration}) → Future< PutSipMediaApplicationAlexaSkillConfigurationResponse> - Updates the Alexa Skill configuration for the SIP media application.
-
putSipMediaApplicationLoggingConfiguration(
{required String sipMediaApplicationId, SipMediaApplicationLoggingConfiguration? sipMediaApplicationLoggingConfiguration}) → Future< PutSipMediaApplicationLoggingConfigurationResponse> - Updates the logging configuration for the specified SIP media application.
-
putVoiceConnectorEmergencyCallingConfiguration(
{required EmergencyCallingConfiguration emergencyCallingConfiguration, required String voiceConnectorId}) → Future< PutVoiceConnectorEmergencyCallingConfigurationResponse> - Updates a Voice Connector's emergency calling configuration.
-
putVoiceConnectorExternalSystemsConfiguration(
{required String voiceConnectorId, List< ContactCenterSystemType> ? contactCenterSystemTypes, List<SessionBorderControllerType> ? sessionBorderControllerTypes}) → Future<PutVoiceConnectorExternalSystemsConfigurationResponse> - Adds an external systems configuration to a Voice Connector.
-
putVoiceConnectorLoggingConfiguration(
{required LoggingConfiguration loggingConfiguration, required String voiceConnectorId}) → Future< PutVoiceConnectorLoggingConfigurationResponse> - Updates a Voice Connector's logging configuration.
-
putVoiceConnectorOrigination(
{required Origination origination, required String voiceConnectorId}) → Future< PutVoiceConnectorOriginationResponse> - Updates a Voice Connector's origination settings.
-
putVoiceConnectorProxy(
{required int defaultSessionExpiryMinutes, required List< String> phoneNumberPoolCountries, required String voiceConnectorId, bool? disabled, String? fallBackPhoneNumber}) → Future<PutVoiceConnectorProxyResponse> - Puts the specified proxy configuration to the specified Amazon Chime SDK Voice Connector.
-
putVoiceConnectorStreamingConfiguration(
{required StreamingConfiguration streamingConfiguration, required String voiceConnectorId}) → Future< PutVoiceConnectorStreamingConfigurationResponse> - Updates a Voice Connector's streaming configuration settings.
-
putVoiceConnectorTermination(
{required Termination termination, required String voiceConnectorId}) → Future< PutVoiceConnectorTerminationResponse> - Updates a Voice Connector's termination settings.
-
putVoiceConnectorTerminationCredentials(
{required String voiceConnectorId, List< Credential> ? credentials}) → Future<void> - Updates a Voice Connector's termination credentials.
-
restorePhoneNumber(
{required String phoneNumberId}) → Future< RestorePhoneNumberResponse> - Restores a deleted phone number.
-
searchAvailablePhoneNumbers(
{String? areaCode, String? city, String? country, int? maxResults, String? nextToken, PhoneNumberType? phoneNumberType, String? state, String? tollFreePrefix}) → Future< SearchAvailablePhoneNumbersResponse> - Searches the provisioned phone numbers in an organization.
-
startSpeakerSearchTask(
{required String transactionId, required String voiceConnectorId, required String voiceProfileDomainId, CallLegType? callLeg, String? clientRequestToken}) → Future< StartSpeakerSearchTaskResponse> - Starts a speaker search task.
-
startVoiceToneAnalysisTask(
{required LanguageCode languageCode, required String transactionId, required String voiceConnectorId, String? clientRequestToken}) → Future< StartVoiceToneAnalysisTaskResponse> - Starts a voice tone analysis task. For more information about voice tone analysis, see Using Amazon Chime SDK voice analytics in the Amazon Chime SDK Developer Guide.
-
stopSpeakerSearchTask(
{required String speakerSearchTaskId, required String voiceConnectorId}) → Future< void> - Stops a speaker search task.
-
stopVoiceToneAnalysisTask(
{required String voiceConnectorId, required String voiceToneAnalysisTaskId}) → Future< void> - Stops a voice tone analysis task.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Adds a tag to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes tags from a resource.
-
updateGlobalSettings(
{VoiceConnectorSettings? voiceConnector}) → Future< void> - Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
updatePhoneNumber(
{required String phoneNumberId, String? callingName, String? name, PhoneNumberProductType? productType}) → Future< UpdatePhoneNumberResponse> - Updates phone number details, such as product type, calling name, or phone number name for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type, calling name, or phone number name in one action.
-
updatePhoneNumberSettings(
{required String callingName}) → Future< void> - Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.
-
updateProxySession(
{required List< Capability> capabilities, required String proxySessionId, required String voiceConnectorId, int? expiryMinutes}) → Future<UpdateProxySessionResponse> - Updates the specified proxy session details, such as voice or SMS capabilities.
-
updateSipMediaApplication(
{required String sipMediaApplicationId, List< SipMediaApplicationEndpoint> ? endpoints, String? name}) → Future<UpdateSipMediaApplicationResponse> - Updates the details of the specified SIP media application.
-
updateSipMediaApplicationCall(
{required Map< String, String> arguments, required String sipMediaApplicationId, required String transactionId}) → Future<UpdateSipMediaApplicationCallResponse> - Invokes the AWS Lambda function associated with the SIP media application and transaction ID in an update request. The Lambda function can then return a new set of actions.
-
updateSipRule(
{required String name, required String sipRuleId, bool? disabled, List< SipRuleTargetApplication> ? targetApplications}) → Future<UpdateSipRuleResponse> - Updates the details of the specified SIP rule.
-
updateVoiceConnector(
{required String name, required bool requireEncryption, required String voiceConnectorId}) → Future< UpdateVoiceConnectorResponse> - Updates the details for the specified Amazon Chime SDK Voice Connector.
-
updateVoiceConnectorGroup(
{required String name, required String voiceConnectorGroupId, required List< VoiceConnectorItem> voiceConnectorItems}) → Future<UpdateVoiceConnectorGroupResponse> - Updates the settings for the specified Amazon Chime SDK Voice Connector group.
-
updateVoiceProfile(
{required String speakerSearchTaskId, required String voiceProfileId}) → Future< UpdateVoiceProfileResponse> - Updates the specified voice profile’s voice print and refreshes its expiration timestamp.
-
updateVoiceProfileDomain(
{required String voiceProfileDomainId, String? description, String? name}) → Future< UpdateVoiceProfileDomainResponse> - Updates the settings for the specified voice profile domain.
-
validateE911Address(
{required String awsAccountId, required String city, required String country, required String postalCode, required String state, required String streetInfo, required String streetNumber}) → Future< ValidateE911AddressResponse> - Validates an address to be used for 911 calls made with Amazon Chime SDK Voice Connectors. You can use validated addresses in a Presence Information Data Format Location Object file that you include in SIP requests. That helps ensure that addresses are routed to the appropriate Public Safety Answering Point.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited