batchUpdatePhoneNumber method

Future<BatchUpdatePhoneNumberResponse> batchUpdatePhoneNumber({
  1. required List<UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems,
})

Updates phone number product types, calling names, or phone number names. You can update one attribute at a time for each UpdatePhoneNumberRequestItem. For example, you can update the product type, the calling name, or phone name.

May throw BadRequestException. May throw ForbiddenException. May throw NotFoundException. May throw ServiceFailureException. May throw ServiceUnavailableException. May throw ThrottledClientException. May throw UnauthorizedClientException.

Parameter updatePhoneNumberRequestItems : Lists the phone numbers in the update request.

Implementation

Future<BatchUpdatePhoneNumberResponse> batchUpdatePhoneNumber({
  required List<UpdatePhoneNumberRequestItem> updatePhoneNumberRequestItems,
}) async {
  final $payload = <String, dynamic>{
    'UpdatePhoneNumberRequestItems': updatePhoneNumberRequestItems,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/phone-numbers?operation=batch-update',
    exceptionFnMap: _exceptionFns,
  );
  return BatchUpdatePhoneNumberResponse.fromJson(response);
}