getVoiceConnectorStreamingConfiguration method
Future<GetVoiceConnectorStreamingConfigurationResponse>
getVoiceConnectorStreamingConfiguration({
- required String voiceConnectorId,
Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector. Shows whether media streaming is enabled for sending to Amazon Kinesis. It also shows the retention period, in hours, for the Amazon Kinesis data.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter voiceConnectorId :
The Voice Connector ID.
Implementation
Future<GetVoiceConnectorStreamingConfigurationResponse>
getVoiceConnectorStreamingConfiguration({
required String voiceConnectorId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/voice-connectors/${Uri.encodeComponent(voiceConnectorId)}/streaming-configuration',
exceptionFnMap: _exceptionFns,
);
return GetVoiceConnectorStreamingConfigurationResponse.fromJson(response);
}