CleanRooms class
Welcome to the Clean Rooms API Reference.
Clean Rooms is an Amazon Web Services service that helps multiple parties to join their data together in a secure collaboration workspace. In the collaboration, members who can run queries and jobs and receive results can get insights into the collective datasets without either party getting access to the other party's raw data.
To learn more about Clean Rooms concepts, procedures, and best practices, see the Clean Rooms User Guide.
To learn more about SQL commands, functions, and conditions supported in Clean Rooms, see the Clean Rooms SQL Reference.
Constructors
- CleanRooms({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetCollaborationAnalysisTemplate(
{required List< String> analysisTemplateArns, required String collaborationIdentifier}) → Future<BatchGetCollaborationAnalysisTemplateOutput> - Retrieves multiple analysis templates within a collaboration by their Amazon Resource Names (ARNs).
-
batchGetSchema(
{required String collaborationIdentifier, required List< String> names}) → Future<BatchGetSchemaOutput> - Retrieves multiple schemas by their identifiers.
-
batchGetSchemaAnalysisRule(
{required String collaborationIdentifier, required List< SchemaAnalysisRuleRequest> schemaAnalysisRuleRequests}) → Future<BatchGetSchemaAnalysisRuleOutput> - Retrieves multiple analysis rule schemas.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAnalysisTemplate(
{required AnalysisFormat format, required String membershipIdentifier, required String name, required AnalysisSource source, List< AnalysisParameter> ? analysisParameters, String? description, ErrorMessageConfiguration? errorMessageConfiguration, AnalysisSchema? schema, SyntheticDataParameters? syntheticDataParameters, Map<String, String> ? tags}) → Future<CreateAnalysisTemplateOutput> - Creates a new analysis template.
-
createCollaboration(
{required String creatorDisplayName, required List< MemberAbility> creatorMemberAbilities, required String description, required List<MemberSpecification> members, required String name, required CollaborationQueryLogStatus queryLogStatus, List<SupportedS3Region> ? allowedResultRegions, AnalyticsEngine? analyticsEngine, List<AutoApprovedChangeType> ? autoApprovedChangeRequestTypes, MLMemberAbilities? creatorMLMemberAbilities, PaymentConfiguration? creatorPaymentConfiguration, DataEncryptionMetadata? dataEncryptionMetadata, bool? isMetricsEnabled, CollaborationJobLogStatus? jobLogStatus, Map<String, String> ? tags}) → Future<CreateCollaborationOutput> - Creates a new collaboration.
-
createCollaborationChangeRequest(
{required List< ChangeInput> changes, required String collaborationIdentifier}) → Future<CreateCollaborationChangeRequestOutput> - Creates a new change request to modify an existing collaboration. This enables post-creation modifications to collaborations through a structured API-driven approach.
-
createConfiguredAudienceModelAssociation(
{required String configuredAudienceModelArn, required String configuredAudienceModelAssociationName, required bool manageResourcePolicies, required String membershipIdentifier, String? description, Map< String, String> ? tags}) → Future<CreateConfiguredAudienceModelAssociationOutput> - Provides the details necessary to create a configured audience model association.
-
createConfiguredTable(
{required List< String> allowedColumns, required AnalysisMethod analysisMethod, required String name, required TableReference tableReference, String? description, List<SelectedAnalysisMethod> ? selectedAnalysisMethods, Map<String, String> ? tags}) → Future<CreateConfiguredTableOutput> - Creates a new configured table resource.
-
createConfiguredTableAnalysisRule(
{required ConfiguredTableAnalysisRulePolicy analysisRulePolicy, required ConfiguredTableAnalysisRuleType analysisRuleType, required String configuredTableIdentifier}) → Future< CreateConfiguredTableAnalysisRuleOutput> - Creates a new analysis rule for a configured table. Currently, only one analysis rule can be created for a given configured table.
-
createConfiguredTableAssociation(
{required String configuredTableIdentifier, required String membershipIdentifier, required String name, required String roleArn, String? description, Map< String, String> ? tags}) → Future<CreateConfiguredTableAssociationOutput> - Creates a configured table association. A configured table association links a configured table with a collaboration.
-
createConfiguredTableAssociationAnalysisRule(
{required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy, required ConfiguredTableAssociationAnalysisRuleType analysisRuleType, required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< CreateConfiguredTableAssociationAnalysisRuleOutput> - Creates a new analysis rule for an associated configured table.
-
createIdMappingTable(
{required IdMappingTableInputReferenceConfig inputReferenceConfig, required String membershipIdentifier, required String name, String? description, String? kmsKeyArn, Map< String, String> ? tags}) → Future<CreateIdMappingTableOutput> - Creates an ID mapping table.
-
createIdNamespaceAssociation(
{required IdNamespaceAssociationInputReferenceConfig inputReferenceConfig, required String membershipIdentifier, required String name, String? description, IdMappingConfig? idMappingConfig, Map< String, String> ? tags}) → Future<CreateIdNamespaceAssociationOutput> - Creates an ID namespace association.
-
createMembership(
{required String collaborationIdentifier, required MembershipQueryLogStatus queryLogStatus, MembershipProtectedJobResultConfiguration? defaultJobResultConfiguration, MembershipProtectedQueryResultConfiguration? defaultResultConfiguration, bool? isMetricsEnabled, MembershipJobLogStatus? jobLogStatus, MembershipPaymentConfiguration? paymentConfiguration, Map< String, String> ? tags}) → Future<CreateMembershipOutput> - Creates a membership for a specific collaboration identifier and joins the collaboration.
-
createPrivacyBudgetTemplate(
{required String membershipIdentifier, required PrivacyBudgetTemplateParametersInput parameters, required PrivacyBudgetType privacyBudgetType, PrivacyBudgetTemplateAutoRefresh? autoRefresh, Map< String, String> ? tags}) → Future<CreatePrivacyBudgetTemplateOutput> - Creates a privacy budget template for a specified collaboration. Each collaboration can have only one privacy budget template. If you need to change the privacy budget template, use the UpdatePrivacyBudgetTemplate operation.
-
deleteAnalysisTemplate(
{required String analysisTemplateIdentifier, required String membershipIdentifier}) → Future< void> - Deletes an analysis template.
-
deleteCollaboration(
{required String collaborationIdentifier}) → Future< void> - Deletes a collaboration. It can only be called by the collaboration owner.
-
deleteConfiguredAudienceModelAssociation(
{required String configuredAudienceModelAssociationIdentifier, required String membershipIdentifier}) → Future< void> - Provides the information necessary to delete a configured audience model association.
-
deleteConfiguredTable(
{required String configuredTableIdentifier}) → Future< void> - Deletes a configured table.
-
deleteConfiguredTableAnalysisRule(
{required ConfiguredTableAnalysisRuleType analysisRuleType, required String configuredTableIdentifier}) → Future< void> - Deletes a configured table analysis rule.
-
deleteConfiguredTableAssociation(
{required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< void> - Deletes a configured table association.
-
deleteConfiguredTableAssociationAnalysisRule(
{required ConfiguredTableAssociationAnalysisRuleType analysisRuleType, required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< void> - Deletes an analysis rule for a configured table association.
-
deleteIdMappingTable(
{required String idMappingTableIdentifier, required String membershipIdentifier}) → Future< void> - Deletes an ID mapping table.
-
deleteIdNamespaceAssociation(
{required String idNamespaceAssociationIdentifier, required String membershipIdentifier}) → Future< void> - Deletes an ID namespace association.
-
deleteMember(
{required String accountId, required String collaborationIdentifier}) → Future< void> - Removes the specified member from a collaboration. The removed member is placed in the Removed status and can't interact with the collaboration. The removed member's data is inaccessible to active members of the collaboration.
-
deleteMembership(
{required String membershipIdentifier}) → Future< void> - Deletes a specified membership. All resources under a membership must be deleted.
-
deletePrivacyBudgetTemplate(
{required String membershipIdentifier, required String privacyBudgetTemplateIdentifier}) → Future< void> - Deletes a privacy budget template for a specified collaboration.
-
getAnalysisTemplate(
{required String analysisTemplateIdentifier, required String membershipIdentifier}) → Future< GetAnalysisTemplateOutput> - Retrieves an analysis template.
-
getCollaboration(
{required String collaborationIdentifier}) → Future< GetCollaborationOutput> - Returns metadata about a collaboration.
-
getCollaborationAnalysisTemplate(
{required String analysisTemplateArn, required String collaborationIdentifier}) → Future< GetCollaborationAnalysisTemplateOutput> - Retrieves an analysis template within a collaboration.
-
getCollaborationChangeRequest(
{required String changeRequestIdentifier, required String collaborationIdentifier}) → Future< GetCollaborationChangeRequestOutput> - Retrieves detailed information about a specific collaboration change request.
-
getCollaborationConfiguredAudienceModelAssociation(
{required String collaborationIdentifier, required String configuredAudienceModelAssociationIdentifier}) → Future< GetCollaborationConfiguredAudienceModelAssociationOutput> - Retrieves a configured audience model association within a collaboration.
-
getCollaborationIdNamespaceAssociation(
{required String collaborationIdentifier, required String idNamespaceAssociationIdentifier}) → Future< GetCollaborationIdNamespaceAssociationOutput> - Retrieves an ID namespace association from a specific collaboration.
-
getCollaborationPrivacyBudgetTemplate(
{required String collaborationIdentifier, required String privacyBudgetTemplateIdentifier}) → Future< GetCollaborationPrivacyBudgetTemplateOutput> - Returns details about a specified privacy budget template.
-
getConfiguredAudienceModelAssociation(
{required String configuredAudienceModelAssociationIdentifier, required String membershipIdentifier}) → Future< GetConfiguredAudienceModelAssociationOutput> - Returns information about a configured audience model association.
-
getConfiguredTable(
{required String configuredTableIdentifier}) → Future< GetConfiguredTableOutput> - Retrieves a configured table.
-
getConfiguredTableAnalysisRule(
{required ConfiguredTableAnalysisRuleType analysisRuleType, required String configuredTableIdentifier}) → Future< GetConfiguredTableAnalysisRuleOutput> - Retrieves a configured table analysis rule.
-
getConfiguredTableAssociation(
{required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< GetConfiguredTableAssociationOutput> - Retrieves a configured table association.
-
getConfiguredTableAssociationAnalysisRule(
{required ConfiguredTableAssociationAnalysisRuleType analysisRuleType, required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< GetConfiguredTableAssociationAnalysisRuleOutput> - Retrieves the analysis rule for a configured table association.
-
getIdMappingTable(
{required String idMappingTableIdentifier, required String membershipIdentifier}) → Future< GetIdMappingTableOutput> - Retrieves an ID mapping table.
-
getIdNamespaceAssociation(
{required String idNamespaceAssociationIdentifier, required String membershipIdentifier}) → Future< GetIdNamespaceAssociationOutput> - Retrieves an ID namespace association.
-
getMembership(
{required String membershipIdentifier}) → Future< GetMembershipOutput> - Retrieves a specified membership for an identifier.
-
getPrivacyBudgetTemplate(
{required String membershipIdentifier, required String privacyBudgetTemplateIdentifier}) → Future< GetPrivacyBudgetTemplateOutput> - Returns details for a specified privacy budget template.
-
getProtectedJob(
{required String membershipIdentifier, required String protectedJobIdentifier}) → Future< GetProtectedJobOutput> - Returns job processing metadata.
-
getProtectedQuery(
{required String membershipIdentifier, required String protectedQueryIdentifier}) → Future< GetProtectedQueryOutput> - Returns query processing metadata.
-
getSchema(
{required String collaborationIdentifier, required String name}) → Future< GetSchemaOutput> - Retrieves the schema for a relation within a collaboration.
-
getSchemaAnalysisRule(
{required String collaborationIdentifier, required String name, required AnalysisRuleType type}) → Future< GetSchemaAnalysisRuleOutput> - Retrieves a schema analysis rule.
-
listAnalysisTemplates(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListAnalysisTemplatesOutput> - Lists analysis templates that the caller owns.
-
listCollaborationAnalysisTemplates(
{required String collaborationIdentifier, int? maxResults, String? nextToken}) → Future< ListCollaborationAnalysisTemplatesOutput> - Lists analysis templates within a collaboration.
-
listCollaborationChangeRequests(
{required String collaborationIdentifier, int? maxResults, String? nextToken, ChangeRequestStatus? status}) → Future< ListCollaborationChangeRequestsOutput> - Lists all change requests for a collaboration with pagination support. Returns change requests sorted by creation time.
-
listCollaborationConfiguredAudienceModelAssociations(
{required String collaborationIdentifier, int? maxResults, String? nextToken}) → Future< ListCollaborationConfiguredAudienceModelAssociationsOutput> - Lists configured audience model associations within a collaboration.
-
listCollaborationIdNamespaceAssociations(
{required String collaborationIdentifier, int? maxResults, String? nextToken}) → Future< ListCollaborationIdNamespaceAssociationsOutput> - Returns a list of the ID namespace associations in a collaboration.
-
listCollaborationPrivacyBudgets(
{required String collaborationIdentifier, required PrivacyBudgetType privacyBudgetType, String? accessBudgetResourceArn, int? maxResults, String? nextToken}) → Future< ListCollaborationPrivacyBudgetsOutput> - Returns an array that summarizes each privacy budget in a specified collaboration. The summary includes the collaboration ARN, creation time, creating account, and privacy budget details.
-
listCollaborationPrivacyBudgetTemplates(
{required String collaborationIdentifier, int? maxResults, String? nextToken}) → Future< ListCollaborationPrivacyBudgetTemplatesOutput> - Returns an array that summarizes each privacy budget template in a specified collaboration.
-
listCollaborations(
{int? maxResults, FilterableMemberStatus? memberStatus, String? nextToken}) → Future< ListCollaborationsOutput> - Lists collaborations the caller owns, is active in, or has been invited to.
-
listConfiguredAudienceModelAssociations(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListConfiguredAudienceModelAssociationsOutput> - Lists information about requested configured audience model associations.
-
listConfiguredTableAssociations(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListConfiguredTableAssociationsOutput> - Lists configured table associations for a membership.
-
listConfiguredTables(
{int? maxResults, String? nextToken}) → Future< ListConfiguredTablesOutput> - Lists configured tables.
-
listIdMappingTables(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListIdMappingTablesOutput> - Returns a list of ID mapping tables.
-
listIdNamespaceAssociations(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListIdNamespaceAssociationsOutput> - Returns a list of ID namespace associations.
-
listMembers(
{required String collaborationIdentifier, int? maxResults, String? nextToken}) → Future< ListMembersOutput> - Lists all members within a collaboration.
-
listMemberships(
{int? maxResults, String? nextToken, MembershipStatus? status}) → Future< ListMembershipsOutput> - Lists all memberships resources within the caller's account.
-
listPrivacyBudgets(
{required String membershipIdentifier, required PrivacyBudgetType privacyBudgetType, String? accessBudgetResourceArn, int? maxResults, String? nextToken}) → Future< ListPrivacyBudgetsOutput> - Returns detailed information about the privacy budgets in a specified membership.
-
listPrivacyBudgetTemplates(
{required String membershipIdentifier, int? maxResults, String? nextToken}) → Future< ListPrivacyBudgetTemplatesOutput> - Returns detailed information about the privacy budget templates in a specified membership.
-
listProtectedJobs(
{required String membershipIdentifier, int? maxResults, String? nextToken, ProtectedJobStatus? status}) → Future< ListProtectedJobsOutput> - Lists protected jobs, sorted by most recent job.
-
listProtectedQueries(
{required String membershipIdentifier, int? maxResults, String? nextToken, ProtectedQueryStatus? status}) → Future< ListProtectedQueriesOutput> - Lists protected queries, sorted by the most recent query.
-
listSchemas(
{required String collaborationIdentifier, int? maxResults, String? nextToken, SchemaType? schemaType}) → Future< ListSchemasOutput> - Lists the schemas for relations within a collaboration.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists all of the tags that have been added to a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
populateIdMappingTable(
{required String idMappingTableIdentifier, required String membershipIdentifier, JobType? jobType}) → Future< PopulateIdMappingTableOutput> - Defines the information that's necessary to populate an ID mapping table.
-
previewPrivacyImpact(
{required String membershipIdentifier, required PreviewPrivacyImpactParametersInput parameters}) → Future< PreviewPrivacyImpactOutput> - An estimate of the number of aggregation functions that the member who can query can run given epsilon and noise parameters.
-
startProtectedJob(
{required ProtectedJobParameters jobParameters, required String membershipIdentifier, required ProtectedJobType type, ProtectedJobComputeConfiguration? computeConfiguration, String? jobComputePayerAccountId, ProtectedJobResultConfigurationInput? resultConfiguration}) → Future< StartProtectedJobOutput> - Creates a protected job that is started by Clean Rooms.
-
startProtectedQuery(
{required String membershipIdentifier, required ProtectedQuerySQLParameters sqlParameters, required ProtectedQueryType type, ComputeConfiguration? computeConfiguration, String? queryComputePayerAccountId, ProtectedQueryResultConfiguration? resultConfiguration}) → Future< StartProtectedQueryOutput> - Creates a protected query that is started by Clean Rooms.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Tags a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag or list of tags from a resource.
-
updateAnalysisTemplate(
{required String analysisTemplateIdentifier, required String membershipIdentifier, String? description}) → Future< UpdateAnalysisTemplateOutput> - Updates the analysis template metadata.
-
updateCollaboration(
{required String collaborationIdentifier, AnalyticsEngine? analyticsEngine, String? description, String? name}) → Future< UpdateCollaborationOutput> - Updates collaboration metadata and can only be called by the collaboration owner.
-
updateCollaborationChangeRequest(
{required ChangeRequestAction action, required String changeRequestIdentifier, required String collaborationIdentifier}) → Future< UpdateCollaborationChangeRequestOutput> - Updates an existing collaboration change request. This operation allows approval actions for pending change requests in collaborations (APPROVE, DENY, CANCEL, COMMIT).
-
updateConfiguredAudienceModelAssociation(
{required String configuredAudienceModelAssociationIdentifier, required String membershipIdentifier, String? description, String? name}) → Future< UpdateConfiguredAudienceModelAssociationOutput> - Provides the details necessary to update a configured audience model association.
-
updateConfiguredTable(
{required String configuredTableIdentifier, List< String> ? allowedColumns, AnalysisMethod? analysisMethod, String? description, String? name, List<SelectedAnalysisMethod> ? selectedAnalysisMethods, TableReference? tableReference}) → Future<UpdateConfiguredTableOutput> - Updates a configured table.
-
updateConfiguredTableAnalysisRule(
{required ConfiguredTableAnalysisRulePolicy analysisRulePolicy, required ConfiguredTableAnalysisRuleType analysisRuleType, required String configuredTableIdentifier}) → Future< UpdateConfiguredTableAnalysisRuleOutput> - Updates a configured table analysis rule.
-
updateConfiguredTableAssociation(
{required String configuredTableAssociationIdentifier, required String membershipIdentifier, String? description, String? roleArn}) → Future< UpdateConfiguredTableAssociationOutput> - Updates a configured table association.
-
updateConfiguredTableAssociationAnalysisRule(
{required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy, required ConfiguredTableAssociationAnalysisRuleType analysisRuleType, required String configuredTableAssociationIdentifier, required String membershipIdentifier}) → Future< UpdateConfiguredTableAssociationAnalysisRuleOutput> - Updates the analysis rule for a configured table association.
-
updateIdMappingTable(
{required String idMappingTableIdentifier, required String membershipIdentifier, String? description, String? kmsKeyArn}) → Future< UpdateIdMappingTableOutput> - Provides the details that are necessary to update an ID mapping table.
-
updateIdNamespaceAssociation(
{required String idNamespaceAssociationIdentifier, required String membershipIdentifier, String? description, IdMappingConfig? idMappingConfig, String? name}) → Future< UpdateIdNamespaceAssociationOutput> - Provides the details that are necessary to update an ID namespace association.
-
updateMembership(
{required String membershipIdentifier, MembershipProtectedJobResultConfiguration? defaultJobResultConfiguration, MembershipProtectedQueryResultConfiguration? defaultResultConfiguration, MembershipJobLogStatus? jobLogStatus, UpdateMembershipPaymentConfiguration? membershipPaymentConfiguration, MembershipQueryLogStatus? queryLogStatus}) → Future< UpdateMembershipOutput> - Updates a membership.
-
updatePrivacyBudgetTemplate(
{required String membershipIdentifier, required String privacyBudgetTemplateIdentifier, required PrivacyBudgetType privacyBudgetType, PrivacyBudgetTemplateUpdateParameters? parameters}) → Future< UpdatePrivacyBudgetTemplateOutput> - Updates the privacy budget template for the specified collaboration.
-
updateProtectedJob(
{required String membershipIdentifier, required String protectedJobIdentifier, required TargetProtectedJobStatus targetStatus}) → Future< UpdateProtectedJobOutput> - Updates the processing of a currently running job.
-
updateProtectedQuery(
{required String membershipIdentifier, required String protectedQueryIdentifier, required TargetProtectedQueryStatus targetStatus}) → Future< UpdateProtectedQueryOutput> - Updates the processing of a currently running query.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited