batchGetCollaborationAnalysisTemplate method

Future<BatchGetCollaborationAnalysisTemplateOutput> batchGetCollaborationAnalysisTemplate({
  1. required List<String> analysisTemplateArns,
  2. required String collaborationIdentifier,
})

Retrieves multiple analysis templates within a collaboration by their Amazon Resource Names (ARNs).

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisTemplateArns : The Amazon Resource Name (ARN) associated with the analysis template within a collaboration.

Parameter collaborationIdentifier : A unique identifier for the collaboration that the analysis templates belong to. Currently accepts collaboration ID.

Implementation

Future<BatchGetCollaborationAnalysisTemplateOutput>
    batchGetCollaborationAnalysisTemplate({
  required List<String> analysisTemplateArns,
  required String collaborationIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisTemplateArns': analysisTemplateArns,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/batch-analysistemplates',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetCollaborationAnalysisTemplateOutput.fromJson(response);
}