createAnalysisTemplate method
- required AnalysisFormat format,
- required String membershipIdentifier,
- required String name,
- required AnalysisSource source,
- List<
AnalysisParameter> ? analysisParameters, - String? description,
- ErrorMessageConfiguration? errorMessageConfiguration,
- AnalysisSchema? schema,
- SyntheticDataParameters? syntheticDataParameters,
- Map<
String, String> ? tags,
Creates a new analysis template.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter format :
The format of the analysis template.
Parameter membershipIdentifier :
The identifier for a membership resource.
Parameter name :
The name of the analysis template.
Parameter source :
The information in the analysis template.
Parameter analysisParameters :
The parameters of the analysis template.
Parameter description :
The description of the analysis template.
Parameter errorMessageConfiguration :
The configuration that specifies the level of detail in error messages
returned by analyses using this template. When set to
DETAILED, error messages include more information to help
troubleshoot issues with PySpark jobs. Detailed error messages may expose
underlying data, including sensitive information. Recommended for faster
troubleshooting in development and testing environments.
Parameter syntheticDataParameters :
The parameters for generating synthetic data when running the analysis
template.
Parameter tags :
An optional label that you can assign to a resource when you create it.
Each tag consists of a key and an optional value, both of which you
define. When you use tagging, you can also use tag-based access control in
IAM policies to control access to this resource.
Implementation
Future<CreateAnalysisTemplateOutput> createAnalysisTemplate({
required AnalysisFormat format,
required String membershipIdentifier,
required String name,
required AnalysisSource source,
List<AnalysisParameter>? analysisParameters,
String? description,
ErrorMessageConfiguration? errorMessageConfiguration,
AnalysisSchema? schema,
SyntheticDataParameters? syntheticDataParameters,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'format': format.value,
'name': name,
'source': source,
if (analysisParameters != null) 'analysisParameters': analysisParameters,
if (description != null) 'description': description,
if (errorMessageConfiguration != null)
'errorMessageConfiguration': errorMessageConfiguration,
if (schema != null) 'schema': schema,
if (syntheticDataParameters != null)
'syntheticDataParameters': syntheticDataParameters,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/analysistemplates',
exceptionFnMap: _exceptionFns,
);
return CreateAnalysisTemplateOutput.fromJson(response);
}