createConfiguredTableAnalysisRule method

Future<CreateConfiguredTableAnalysisRuleOutput> createConfiguredTableAnalysisRule({
  1. required ConfiguredTableAnalysisRulePolicy analysisRulePolicy,
  2. required ConfiguredTableAnalysisRuleType analysisRuleType,
  3. required String configuredTableIdentifier,
})

Creates a new analysis rule for a configured table. Currently, only one analysis rule can be created for a given configured table.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRulePolicy : The analysis rule policy that was created for the configured table.

Parameter analysisRuleType : The type of analysis rule.

Parameter configuredTableIdentifier : The identifier for the configured table to create the analysis rule for. Currently accepts the configured table ID.

Implementation

Future<CreateConfiguredTableAnalysisRuleOutput>
    createConfiguredTableAnalysisRule({
  required ConfiguredTableAnalysisRulePolicy analysisRulePolicy,
  required ConfiguredTableAnalysisRuleType analysisRuleType,
  required String configuredTableIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisRulePolicy': analysisRulePolicy,
    'analysisRuleType': analysisRuleType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/configuredTables/${Uri.encodeComponent(configuredTableIdentifier)}/analysisRule',
    exceptionFnMap: _exceptionFns,
  );
  return CreateConfiguredTableAnalysisRuleOutput.fromJson(response);
}