createConfiguredTableAssociationAnalysisRule method

Future<CreateConfiguredTableAssociationAnalysisRuleOutput> createConfiguredTableAssociationAnalysisRule({
  1. required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy,
  2. required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  3. required String configuredTableAssociationIdentifier,
  4. required String membershipIdentifier,
})

Creates a new analysis rule for an associated configured table.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRulePolicy : The analysis rule policy that was created for the configured table association.

Parameter analysisRuleType : The type of analysis rule.

Parameter configuredTableAssociationIdentifier : The unique ID for the configured table association. Currently accepts the configured table association ID.

Parameter membershipIdentifier : A unique identifier for the membership that the configured table association belongs to. Currently accepts the membership ID.

Implementation

Future<CreateConfiguredTableAssociationAnalysisRuleOutput>
    createConfiguredTableAssociationAnalysisRule({
  required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy,
  required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  required String configuredTableAssociationIdentifier,
  required String membershipIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisRulePolicy': analysisRulePolicy,
    'analysisRuleType': analysisRuleType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredTableAssociations/${Uri.encodeComponent(configuredTableAssociationIdentifier)}/analysisRule',
    exceptionFnMap: _exceptionFns,
  );
  return CreateConfiguredTableAssociationAnalysisRuleOutput.fromJson(
      response);
}