createIdMappingTable method

Future<CreateIdMappingTableOutput> createIdMappingTable({
  1. required IdMappingTableInputReferenceConfig inputReferenceConfig,
  2. required String membershipIdentifier,
  3. required String name,
  4. String? description,
  5. String? kmsKeyArn,
  6. Map<String, String>? tags,
})

Creates an ID mapping table.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter inputReferenceConfig : The input reference configuration needed to create the ID mapping table.

Parameter membershipIdentifier : The unique identifier of the membership that contains the ID mapping table.

Parameter name : A name for the ID mapping table.

Parameter description : A description of the ID mapping table.

Parameter kmsKeyArn : The Amazon Resource Name (ARN) of the Amazon Web Services KMS key. This value is used to encrypt the mapping table data that is stored by Clean Rooms.

Parameter tags : An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.

Implementation

Future<CreateIdMappingTableOutput> createIdMappingTable({
  required IdMappingTableInputReferenceConfig inputReferenceConfig,
  required String membershipIdentifier,
  required String name,
  String? description,
  String? kmsKeyArn,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'inputReferenceConfig': inputReferenceConfig,
    'name': name,
    if (description != null) 'description': description,
    if (kmsKeyArn != null) 'kmsKeyArn': kmsKeyArn,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/idmappingtables',
    exceptionFnMap: _exceptionFns,
  );
  return CreateIdMappingTableOutput.fromJson(response);
}