deleteConfiguredTableAssociationAnalysisRule method

Future<void> deleteConfiguredTableAssociationAnalysisRule({
  1. required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  2. required String configuredTableAssociationIdentifier,
  3. required String membershipIdentifier,
})

Deletes an analysis rule for a configured table association.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRuleType : The type of the analysis rule that you want to delete.

Parameter configuredTableAssociationIdentifier : The identifier for the configured table association that's related to the analysis rule that you want to delete.

Parameter membershipIdentifier : A unique identifier for the membership that the configured table association belongs to. Currently accepts the membership ID.

Implementation

Future<void> deleteConfiguredTableAssociationAnalysisRule({
  required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  required String configuredTableAssociationIdentifier,
  required String membershipIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredTableAssociations/${Uri.encodeComponent(configuredTableAssociationIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
    exceptionFnMap: _exceptionFns,
  );
}