deleteIntermediateTable method

Future<void> deleteIntermediateTable({
  1. required String intermediateTableIdentifier,
  2. required String membershipIdentifier,
})

Deletes an intermediate table. When you delete the table, the service marks it as DELETED, removes its analysis rule and schema, and triggers storage cleanup. This operation is idempotent. Only the intermediate table owner can call this operation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter intermediateTableIdentifier : The unique identifier of the intermediate table to delete.

Parameter membershipIdentifier : The unique identifier of the membership that contains the intermediate table.

Implementation

Future<void> deleteIntermediateTable({
  required String intermediateTableIdentifier,
  required String membershipIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
}