deleteMember method

Future<void> deleteMember({
  1. required String accountId,
  2. required String collaborationIdentifier,
})

Removes the specified member from a collaboration. The removed member is placed in the Removed status and can't interact with the collaboration. The removed member's data is inaccessible to active members of the collaboration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accountId : The account ID of the member to remove.

Parameter collaborationIdentifier : The unique identifier for the associated collaboration.

Implementation

Future<void> deleteMember({
  required String accountId,
  required String collaborationIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/member/${Uri.encodeComponent(accountId)}',
    exceptionFnMap: _exceptionFns,
  );
}