deletePrivacyBudgetTemplate method
Deletes a privacy budget template for a specified collaboration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
A unique identifier for one of your memberships for a collaboration. The
privacy budget template is deleted from the collaboration that this
membership belongs to. Accepts a membership ID.
Parameter privacyBudgetTemplateIdentifier :
A unique identifier for your privacy budget template.
Implementation
Future<void> deletePrivacyBudgetTemplate({
required String membershipIdentifier,
required String privacyBudgetTemplateIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/privacybudgettemplates/${Uri.encodeComponent(privacyBudgetTemplateIdentifier)}',
exceptionFnMap: _exceptionFns,
);
}