getCollaborationChangeRequest method

Future<GetCollaborationChangeRequestOutput> getCollaborationChangeRequest({
  1. required String changeRequestIdentifier,
  2. required String collaborationIdentifier,
})

Retrieves detailed information about a specific collaboration change request.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter changeRequestIdentifier : A unique identifier for the change request to retrieve.

Parameter collaborationIdentifier : The identifier of the collaboration that the change request is made against.

Implementation

Future<GetCollaborationChangeRequestOutput> getCollaborationChangeRequest({
  required String changeRequestIdentifier,
  required String collaborationIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/changeRequests/${Uri.encodeComponent(changeRequestIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetCollaborationChangeRequestOutput.fromJson(response);
}