getIdMappingTable method

Future<GetIdMappingTableOutput> getIdMappingTable({
  1. required String idMappingTableIdentifier,
  2. required String membershipIdentifier,
})

Retrieves an ID mapping table.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter idMappingTableIdentifier : The unique identifier of the ID mapping table identifier that you want to retrieve.

Parameter membershipIdentifier : The unique identifier of the membership that contains the ID mapping table that you want to retrieve.

Implementation

Future<GetIdMappingTableOutput> getIdMappingTable({
  required String idMappingTableIdentifier,
  required String membershipIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/idmappingtables/${Uri.encodeComponent(idMappingTableIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetIdMappingTableOutput.fromJson(response);
}