getIntermediateTable method

Future<GetIntermediateTableOutput> getIntermediateTable({
  1. required String intermediateTableIdentifier,
  2. required String membershipIdentifier,
})

Retrieves an intermediate table. Returns the full details of the intermediate table, including schema, table dependencies, inherited constraints, child resources, and status. Only the intermediate table owner can call this operation.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter intermediateTableIdentifier : The unique identifier of the intermediate table to retrieve.

Parameter membershipIdentifier : The unique identifier of the membership that contains the intermediate table.

Implementation

Future<GetIntermediateTableOutput> getIntermediateTable({
  required String intermediateTableIdentifier,
  required String membershipIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetIntermediateTableOutput.fromJson(response);
}