getPrivacyBudgetTemplate method
Returns details for a specified privacy budget template.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
A unique identifier for one of your memberships for a collaboration. The
privacy budget template is retrieved from the collaboration that this
membership belongs to. Accepts a membership ID.
Parameter privacyBudgetTemplateIdentifier :
A unique identifier for your privacy budget template.
Implementation
Future<GetPrivacyBudgetTemplateOutput> getPrivacyBudgetTemplate({
required String membershipIdentifier,
required String privacyBudgetTemplateIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/privacybudgettemplates/${Uri.encodeComponent(privacyBudgetTemplateIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return GetPrivacyBudgetTemplateOutput.fromJson(response);
}