getSchema method

Future<GetSchemaOutput> getSchema({
  1. required String collaborationIdentifier,
  2. required String name,
})

Retrieves the schema for a relation within a collaboration.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter collaborationIdentifier : A unique identifier for the collaboration that the schema belongs to. Currently accepts a collaboration ID.

Parameter name : The name of the relation to retrieve the schema for.

Implementation

Future<GetSchemaOutput> getSchema({
  required String collaborationIdentifier,
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/schemas/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSchemaOutput.fromJson(response);
}