listAnalysisTemplates method

Future<ListAnalysisTemplatesOutput> listAnalysisTemplates({
  1. required String membershipIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Lists analysis templates that the caller owns.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : The identifier for a membership resource.

Parameter maxResults : The maximum number of results that are returned for an API request call. The service chooses a default number if you don't set one. The service might return a nextToken even if the maxResults value has not been met.

Parameter nextToken : The pagination token that's used to fetch the next set of results.

Implementation

Future<ListAnalysisTemplatesOutput> listAnalysisTemplates({
  required String membershipIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/analysistemplates',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAnalysisTemplatesOutput.fromJson(response);
}