listCollaborationConfiguredAudienceModelAssociations method

Future<ListCollaborationConfiguredAudienceModelAssociationsOutput> listCollaborationConfiguredAudienceModelAssociations({
  1. required String collaborationIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Lists configured audience model associations within a collaboration.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter collaborationIdentifier : A unique identifier for the collaboration that the configured audience model association belongs to. Accepts a collaboration ID.

Parameter maxResults : The maximum number of results that are returned for an API request call. The service chooses a default number if you don't set one. The service might return a nextToken even if the maxResults value has not been met.

Parameter nextToken : The pagination token that's used to fetch the next set of results.

Implementation

Future<ListCollaborationConfiguredAudienceModelAssociationsOutput>
    listCollaborationConfiguredAudienceModelAssociations({
  required String collaborationIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/configuredaudiencemodelassociations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCollaborationConfiguredAudienceModelAssociationsOutput.fromJson(
      response);
}