listConfiguredAudienceModelAssociations method
Lists information about requested configured audience model associations.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
A unique identifier for a membership that contains the configured audience
model associations that you want to retrieve.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
The service chooses a default number if you don't set one. The service
might return a nextToken even if the maxResults value has not been
met.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListConfiguredAudienceModelAssociationsOutput>
listConfiguredAudienceModelAssociations({
required String membershipIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredaudiencemodelassociations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListConfiguredAudienceModelAssociationsOutput.fromJson(response);
}