listIdNamespaceAssociations method

Future<ListIdNamespaceAssociationsOutput> listIdNamespaceAssociations({
  1. required String membershipIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of ID namespace associations.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : The unique identifier of the membership that contains the ID namespace association that you want to view.

Parameter maxResults : The maximum size of the results that is returned per call. Service chooses a default if it has not been set. Service may return a nextToken even if the maximum results has not been met.

Parameter nextToken : The pagination token that's used to fetch the next set of results.

Implementation

Future<ListIdNamespaceAssociationsOutput> listIdNamespaceAssociations({
  required String membershipIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/idnamespaceassociations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListIdNamespaceAssociationsOutput.fromJson(response);
}