populateIdMappingTable method
Defines the information that's necessary to populate an ID mapping table.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter idMappingTableIdentifier :
The unique identifier of the ID mapping table that you want to populate.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the ID mapping table
that you want to populate.
Parameter jobType :
The job type of the rule-based ID mapping job. Valid values include:
INCREMENTAL: Processes only new or changed data since the
last job run. This is the default job type if the ID mapping workflow was
created in Entity Resolution with incrementalRunConfig
specified.
BATCH: Processes all data from the input source, regardless
of previous job runs. This is the default job type if the ID mapping
workflow was created in Entity Resolution but
incrementalRunConfig wasn't specified.
DELETE_ONLY: Processes only deletion requests from
BatchDeleteUniqueId, which is set in Entity Resolution.
For more information about incrementalRunConfig and
BatchDeleteUniqueId, see the Entity
Resolution API Reference.
Implementation
Future<PopulateIdMappingTableOutput> populateIdMappingTable({
required String idMappingTableIdentifier,
required String membershipIdentifier,
JobType? jobType,
}) async {
final $payload = <String, dynamic>{
if (jobType != null) 'jobType': jobType.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/idmappingtables/${Uri.encodeComponent(idMappingTableIdentifier)}/populate',
exceptionFnMap: _exceptionFns,
);
return PopulateIdMappingTableOutput.fromJson(response);
}