previewPrivacyImpact method

Future<PreviewPrivacyImpactOutput> previewPrivacyImpact({
  1. required String membershipIdentifier,
  2. required PreviewPrivacyImpactParametersInput parameters,
})

An estimate of the number of aggregation functions that the member who can query can run given epsilon and noise parameters.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : A unique identifier for one of your memberships for a collaboration. Accepts a membership ID.

Parameter parameters : Specifies the desired epsilon and noise parameters to preview.

Implementation

Future<PreviewPrivacyImpactOutput> previewPrivacyImpact({
  required String membershipIdentifier,
  required PreviewPrivacyImpactParametersInput parameters,
}) async {
  final $payload = <String, dynamic>{
    'parameters': parameters,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/previewprivacyimpact',
    exceptionFnMap: _exceptionFns,
  );
  return PreviewPrivacyImpactOutput.fromJson(response);
}