updateConfiguredAudienceModelAssociation method
Provides the details necessary to update a configured audience model association.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter configuredAudienceModelAssociationIdentifier :
A unique identifier for the configured audience model association that you
want to update.
Parameter membershipIdentifier :
A unique identifier of the membership that contains the configured
audience model association that you want to update.
Parameter description :
A new description for the configured audience model association.
Parameter name :
A new name for the configured audience model association.
Implementation
Future<UpdateConfiguredAudienceModelAssociationOutput>
updateConfiguredAudienceModelAssociation({
required String configuredAudienceModelAssociationIdentifier,
required String membershipIdentifier,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredaudiencemodelassociations/${Uri.encodeComponent(configuredAudienceModelAssociationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateConfiguredAudienceModelAssociationOutput.fromJson(response);
}