updateConfiguredTable method

Future<UpdateConfiguredTableOutput> updateConfiguredTable({
  1. required String configuredTableIdentifier,
  2. List<String>? allowedColumns,
  3. AnalysisMethod? analysisMethod,
  4. String? description,
  5. String? name,
  6. List<SelectedAnalysisMethod>? selectedAnalysisMethods,
  7. TableReference? tableReference,
})

Updates a configured table.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter configuredTableIdentifier : The identifier for the configured table to update. Currently accepts the configured table ID.

Parameter allowedColumns : The columns of the underlying table that can be used by collaborations or analysis rules.

Parameter analysisMethod : The analysis method for the configured table.

DIRECT_QUERY allows SQL queries to be run directly on this table.

DIRECT_JOB allows PySpark jobs to be run directly on this table.

MULTIPLE allows both SQL queries and PySpark jobs to be run directly on this table.

Parameter description : A new description for the configured table.

Parameter name : A new name for the configured table.

Parameter selectedAnalysisMethods : The selected analysis methods for the table configuration update.

Implementation

Future<UpdateConfiguredTableOutput> updateConfiguredTable({
  required String configuredTableIdentifier,
  List<String>? allowedColumns,
  AnalysisMethod? analysisMethod,
  String? description,
  String? name,
  List<SelectedAnalysisMethod>? selectedAnalysisMethods,
  TableReference? tableReference,
}) async {
  final $payload = <String, dynamic>{
    if (allowedColumns != null) 'allowedColumns': allowedColumns,
    if (analysisMethod != null) 'analysisMethod': analysisMethod.value,
    if (description != null) 'description': description,
    if (name != null) 'name': name,
    if (selectedAnalysisMethods != null)
      'selectedAnalysisMethods':
          selectedAnalysisMethods.map((e) => e.value).toList(),
    if (tableReference != null) 'tableReference': tableReference,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/configuredTables/${Uri.encodeComponent(configuredTableIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateConfiguredTableOutput.fromJson(response);
}