updateConfiguredTableAnalysisRule method

Future<UpdateConfiguredTableAnalysisRuleOutput> updateConfiguredTableAnalysisRule({
  1. required ConfiguredTableAnalysisRulePolicy analysisRulePolicy,
  2. required ConfiguredTableAnalysisRuleType analysisRuleType,
  3. required String configuredTableIdentifier,
})

Updates a configured table analysis rule.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRulePolicy : The new analysis rule policy for the configured table analysis rule.

Parameter analysisRuleType : The analysis rule type to be updated. Configured table analysis rules are uniquely identified by their configured table identifier and analysis rule type.

Parameter configuredTableIdentifier : The unique identifier for the configured table that the analysis rule applies to. Currently accepts the configured table ID.

Implementation

Future<UpdateConfiguredTableAnalysisRuleOutput>
    updateConfiguredTableAnalysisRule({
  required ConfiguredTableAnalysisRulePolicy analysisRulePolicy,
  required ConfiguredTableAnalysisRuleType analysisRuleType,
  required String configuredTableIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisRulePolicy': analysisRulePolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/configuredTables/${Uri.encodeComponent(configuredTableIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateConfiguredTableAnalysisRuleOutput.fromJson(response);
}