updateConfiguredTableAssociationAnalysisRule method

Future<UpdateConfiguredTableAssociationAnalysisRuleOutput> updateConfiguredTableAssociationAnalysisRule({
  1. required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy,
  2. required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  3. required String configuredTableAssociationIdentifier,
  4. required String membershipIdentifier,
})

Updates the analysis rule for a configured table association.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRulePolicy : The updated analysis rule policy for the configured table association.

Parameter analysisRuleType : The analysis rule type that you want to update.

Parameter configuredTableAssociationIdentifier : The identifier for the configured table association to update.

Parameter membershipIdentifier : A unique identifier for the membership that the configured table association belongs to. Currently accepts the membership ID.

Implementation

Future<UpdateConfiguredTableAssociationAnalysisRuleOutput>
    updateConfiguredTableAssociationAnalysisRule({
  required ConfiguredTableAssociationAnalysisRulePolicy analysisRulePolicy,
  required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
  required String configuredTableAssociationIdentifier,
  required String membershipIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisRulePolicy': analysisRulePolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredTableAssociations/${Uri.encodeComponent(configuredTableAssociationIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateConfiguredTableAssociationAnalysisRuleOutput.fromJson(
      response);
}