updateIdNamespaceAssociation method

Future<UpdateIdNamespaceAssociationOutput> updateIdNamespaceAssociation({
  1. required String idNamespaceAssociationIdentifier,
  2. required String membershipIdentifier,
  3. String? description,
  4. IdMappingConfig? idMappingConfig,
  5. String? name,
})

Provides the details that are necessary to update an ID namespace association.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter idNamespaceAssociationIdentifier : The unique identifier of the ID namespace association that you want to update.

Parameter membershipIdentifier : The unique identifier of the membership that contains the ID namespace association that you want to update.

Parameter description : A new description for the ID namespace association.

Parameter idMappingConfig : The configuration settings for the ID mapping table.

Parameter name : A new name for the ID namespace association.

Implementation

Future<UpdateIdNamespaceAssociationOutput> updateIdNamespaceAssociation({
  required String idNamespaceAssociationIdentifier,
  required String membershipIdentifier,
  String? description,
  IdMappingConfig? idMappingConfig,
  String? name,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (idMappingConfig != null) 'idMappingConfig': idMappingConfig,
    if (name != null) 'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/idnamespaceassociations/${Uri.encodeComponent(idNamespaceAssociationIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateIdNamespaceAssociationOutput.fromJson(response);
}