updateIntermediateTableAnalysisRule method

Future<UpdateIntermediateTableAnalysisRuleOutput> updateIntermediateTableAnalysisRule({
  1. required IntermediateTableAnalysisRulePolicy analysisRulePolicy,
  2. required IntermediateTableAnalysisRuleType analysisRuleType,
  3. required String intermediateTableIdentifier,
  4. required String membershipIdentifier,
})

Updates the analysis rule policy for an intermediate table. Only the intermediate table owner can call this operation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter analysisRulePolicy : The updated analysis rule policy for the intermediate table.

Parameter analysisRuleType : The type of analysis rule to update. Currently, only CUSTOM is supported.

Parameter intermediateTableIdentifier : The unique identifier of the intermediate table for which to update the analysis rule.

Parameter membershipIdentifier : The unique identifier of the membership that contains the intermediate table.

Implementation

Future<UpdateIntermediateTableAnalysisRuleOutput>
    updateIntermediateTableAnalysisRule({
  required IntermediateTableAnalysisRulePolicy analysisRulePolicy,
  required IntermediateTableAnalysisRuleType analysisRuleType,
  required String intermediateTableIdentifier,
  required String membershipIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'analysisRulePolicy': analysisRulePolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateIntermediateTableAnalysisRuleOutput.fromJson(response);
}