updateMembership method

Future<UpdateMembershipOutput> updateMembership({
  1. required String membershipIdentifier,
  2. MembershipProtectedJobResultConfiguration? defaultJobResultConfiguration,
  3. MembershipProtectedQueryResultConfiguration? defaultResultConfiguration,
  4. MembershipJobLogStatus? jobLogStatus,
  5. UpdateMembershipPaymentConfiguration? membershipPaymentConfiguration,
  6. MembershipQueryLogStatus? queryLogStatus,
})

Updates a membership.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : The unique identifier of the membership.

Parameter defaultJobResultConfiguration : The default job result configuration.

Parameter defaultResultConfiguration : The default protected query result configuration as specified by the member who can receive results.

Parameter jobLogStatus : An indicator as to whether job logging has been enabled or disabled for the collaboration.

When ENABLED, Clean Rooms logs details about jobs run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is DISABLED.

Parameter membershipPaymentConfiguration : The payment configuration to update for the membership.

Parameter queryLogStatus : An indicator as to whether query logging has been enabled or disabled for the membership.

When ENABLED, Clean Rooms logs details about queries run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is DISABLED.

Implementation

Future<UpdateMembershipOutput> updateMembership({
  required String membershipIdentifier,
  MembershipProtectedJobResultConfiguration? defaultJobResultConfiguration,
  MembershipProtectedQueryResultConfiguration? defaultResultConfiguration,
  MembershipJobLogStatus? jobLogStatus,
  UpdateMembershipPaymentConfiguration? membershipPaymentConfiguration,
  MembershipQueryLogStatus? queryLogStatus,
}) async {
  final $payload = <String, dynamic>{
    if (defaultJobResultConfiguration != null)
      'defaultJobResultConfiguration': defaultJobResultConfiguration,
    if (defaultResultConfiguration != null)
      'defaultResultConfiguration': defaultResultConfiguration,
    if (jobLogStatus != null) 'jobLogStatus': jobLogStatus.value,
    if (membershipPaymentConfiguration != null)
      'membershipPaymentConfiguration': membershipPaymentConfiguration,
    if (queryLogStatus != null) 'queryLogStatus': queryLogStatus.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/memberships/${Uri.encodeComponent(membershipIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateMembershipOutput.fromJson(response);
}