updatePrivacyBudgetTemplate method

Future<UpdatePrivacyBudgetTemplateOutput> updatePrivacyBudgetTemplate({
  1. required String membershipIdentifier,
  2. required String privacyBudgetTemplateIdentifier,
  3. required PrivacyBudgetType privacyBudgetType,
  4. PrivacyBudgetTemplateUpdateParameters? parameters,
})

Updates the privacy budget template for the specified collaboration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : A unique identifier for one of your memberships for a collaboration. The privacy budget template is updated in the collaboration that this membership belongs to. Accepts a membership ID.

Parameter privacyBudgetTemplateIdentifier : A unique identifier for your privacy budget template that you want to update.

Parameter privacyBudgetType : Specifies the type of the privacy budget template.

Parameter parameters : Specifies the epsilon and noise parameters for the privacy budget template.

Implementation

Future<UpdatePrivacyBudgetTemplateOutput> updatePrivacyBudgetTemplate({
  required String membershipIdentifier,
  required String privacyBudgetTemplateIdentifier,
  required PrivacyBudgetType privacyBudgetType,
  PrivacyBudgetTemplateUpdateParameters? parameters,
}) async {
  final $payload = <String, dynamic>{
    'privacyBudgetType': privacyBudgetType.value,
    if (parameters != null) 'parameters': parameters,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/privacybudgettemplates/${Uri.encodeComponent(privacyBudgetTemplateIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdatePrivacyBudgetTemplateOutput.fromJson(response);
}