updateProtectedQuery method

Future<UpdateProtectedQueryOutput> updateProtectedQuery({
  1. required String membershipIdentifier,
  2. required String protectedQueryIdentifier,
  3. required TargetProtectedQueryStatus targetStatus,
})

Updates the processing of a currently running query.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : The identifier for a member of a protected query instance.

Parameter protectedQueryIdentifier : The identifier for a protected query instance.

Parameter targetStatus : The target status of a query. Used to update the execution status of a currently running query.

Implementation

Future<UpdateProtectedQueryOutput> updateProtectedQuery({
  required String membershipIdentifier,
  required String protectedQueryIdentifier,
  required TargetProtectedQueryStatus targetStatus,
}) async {
  final $payload = <String, dynamic>{
    'targetStatus': targetStatus.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/protectedQueries/${Uri.encodeComponent(protectedQueryIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateProtectedQueryOutput.fromJson(response);
}