createAudienceModel method
Defines the information necessary to create an audience model. An audience model is a machine learning model that Clean Rooms ML trains to measure similarity between users. Clean Rooms ML manages training and storing the audience model. The audience model can be used in multiple calls to the StartAudienceGenerationJob API.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter name :
The name of the audience model resource.
Parameter trainingDatasetArn :
The Amazon Resource Name (ARN) of the training dataset for this audience
model.
Parameter description :
The description of the audience model.
Parameter kmsKeyArn :
The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt
and decrypt customer-owned data in the trained ML model and the associated
data.
Parameter tags :
The optional metadata that you apply to the resource to help you
categorize and organize them. Each tag consists of a key and an optional
value, both of which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50.
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8.
- Maximum value length - 256 Unicode characters in UTF-8.
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case sensitive.
- Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.
Parameter trainingDataEndTime :
The end date and time of the training window.
Parameter trainingDataStartTime :
The start date and time of the training window.
Implementation
Future<CreateAudienceModelResponse> createAudienceModel({
required String name,
required String trainingDatasetArn,
String? description,
String? kmsKeyArn,
Map<String, String>? tags,
DateTime? trainingDataEndTime,
DateTime? trainingDataStartTime,
}) async {
final $payload = <String, dynamic>{
'name': name,
'trainingDatasetArn': trainingDatasetArn,
if (description != null) 'description': description,
if (kmsKeyArn != null) 'kmsKeyArn': kmsKeyArn,
if (tags != null) 'tags': tags,
if (trainingDataEndTime != null)
'trainingDataEndTime': iso8601ToJson(trainingDataEndTime),
if (trainingDataStartTime != null)
'trainingDataStartTime': iso8601ToJson(trainingDataStartTime),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/audience-model',
exceptionFnMap: _exceptionFns,
);
return CreateAudienceModelResponse.fromJson(response);
}