createConfiguredAudienceModel method
Defines the information necessary to create a configured audience model.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter audienceModelArn :
The Amazon Resource Name (ARN) of the audience model to use for the
configured audience model.
Parameter name :
The name of the configured audience model.
Parameter outputConfig :
Configure the Amazon S3 location and IAM Role for audiences created using
this configured audience model. Each audience will have a unique location.
The IAM Role must have s3:PutObject permission on the
destination Amazon S3 location. If the destination is protected with
Amazon S3 KMS-SSE, then the Role must also have the required KMS
permissions.
Parameter sharedAudienceMetrics :
Whether audience metrics are shared.
Parameter audienceSizeConfig :
Configure the list of output sizes of audiences that can be created using
this configured audience model. A request to
StartAudienceGenerationJob that uses this configured audience model
must have an audienceSize selected from this list. You can
use the ABSOLUTE AudienceSize to configure out
audience sizes using the count of identifiers in the output. You can use
the Percentage AudienceSize to configure sizes in the
range 1-100 percent.
Parameter childResourceTagOnCreatePolicy :
Configure how the service tags audience generation jobs created using this
configured audience model. If you specify NONE, the tags from
the StartAudienceGenerationJob request determine the tags of the
audience generation job. If you specify FROM_PARENT_RESOURCE,
the audience generation job inherits the tags from the configured audience
model, by default. Tags in the StartAudienceGenerationJob will
override the default.
When the client is in a different account than the configured audience model, the tags from the client are never applied to a resource in the caller's account.
Parameter description :
The description of the configured audience model.
Parameter minMatchingSeedSize :
The minimum number of users from the seed audience that must match with
users in the training data of the audience model. The default value is
500.
Parameter tags :
The optional metadata that you apply to the resource to help you
categorize and organize them. Each tag consists of a key and an optional
value, both of which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50.
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8.
- Maximum value length - 256 Unicode characters in UTF-8.
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case sensitive.
- Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.
Implementation
Future<CreateConfiguredAudienceModelResponse> createConfiguredAudienceModel({
required String audienceModelArn,
required String name,
required ConfiguredAudienceModelOutputConfig outputConfig,
required List<SharedAudienceMetrics> sharedAudienceMetrics,
AudienceSizeConfig? audienceSizeConfig,
TagOnCreatePolicy? childResourceTagOnCreatePolicy,
String? description,
int? minMatchingSeedSize,
Map<String, String>? tags,
}) async {
_s.validateNumRange(
'minMatchingSeedSize',
minMatchingSeedSize,
25,
500000,
);
final $payload = <String, dynamic>{
'audienceModelArn': audienceModelArn,
'name': name,
'outputConfig': outputConfig,
'sharedAudienceMetrics':
sharedAudienceMetrics.map((e) => e.value).toList(),
if (audienceSizeConfig != null) 'audienceSizeConfig': audienceSizeConfig,
if (childResourceTagOnCreatePolicy != null)
'childResourceTagOnCreatePolicy': childResourceTagOnCreatePolicy.value,
if (description != null) 'description': description,
if (minMatchingSeedSize != null)
'minMatchingSeedSize': minMatchingSeedSize,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/configured-audience-model',
exceptionFnMap: _exceptionFns,
);
return CreateConfiguredAudienceModelResponse.fromJson(response);
}