deleteAudienceModel method
Specifies an audience model that you want to delete. You can't delete an audience model if there are any configured audience models that depend on the audience model.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter audienceModelArn :
The Amazon Resource Name (ARN) of the audience model that you want to
delete.
Implementation
Future<void> deleteAudienceModel({
required String audienceModelArn,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/audience-model/${Uri.encodeComponent(audienceModelArn)}',
exceptionFnMap: _exceptionFns,
);
}