deleteConfiguredAudienceModel method

Future<void> deleteConfiguredAudienceModel({
  1. required String configuredAudienceModelArn,
})

Deletes the specified configured audience model. You can't delete a configured audience model if there are any lookalike models that use the configured audience model. If you delete a configured audience model, it will be removed from any collaborations that it is associated to.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter configuredAudienceModelArn : The Amazon Resource Name (ARN) of the configured audience model that you want to delete.

Implementation

Future<void> deleteConfiguredAudienceModel({
  required String configuredAudienceModelArn,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/configured-audience-model/${Uri.encodeComponent(configuredAudienceModelArn)}',
    exceptionFnMap: _exceptionFns,
  );
}