deleteConfiguredModelAlgorithmAssociation method

Future<void> deleteConfiguredModelAlgorithmAssociation({
  1. required String configuredModelAlgorithmAssociationArn,
  2. required String membershipIdentifier,
})

Deletes a configured model algorithm association.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter configuredModelAlgorithmAssociationArn : The Amazon Resource Name (ARN) of the configured model algorithm association that you want to delete.

Parameter membershipIdentifier : The membership ID of the member that is deleting the configured model algorithm association.

Implementation

Future<void> deleteConfiguredModelAlgorithmAssociation({
  required String configuredModelAlgorithmAssociationArn,
  required String membershipIdentifier,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/configured-model-algorithm-associations/${Uri.encodeComponent(configuredModelAlgorithmAssociationArn)}',
    exceptionFnMap: _exceptionFns,
  );
}