deleteTrainedModelOutput method

Future<void> deleteTrainedModelOutput({
  1. required String membershipIdentifier,
  2. required String trainedModelArn,
  3. String? versionIdentifier,
})

Deletes the model artifacts stored by the service.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : The membership ID of the member that is deleting the trained model output.

Parameter trainedModelArn : The Amazon Resource Name (ARN) of the trained model whose output you want to delete.

Parameter versionIdentifier : The version identifier of the trained model to delete. If not specified, the operation will delete the base version of the trained model. When specified, only the particular version will be deleted.

Implementation

Future<void> deleteTrainedModelOutput({
  required String membershipIdentifier,
  required String trainedModelArn,
  String? versionIdentifier,
}) async {
  final $query = <String, List<String>>{
    if (versionIdentifier != null) 'versionIdentifier': [versionIdentifier],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-models/${Uri.encodeComponent(trainedModelArn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}