deleteTrainingDataset method

Future<void> deleteTrainingDataset({
  1. required String trainingDatasetArn,
})

Specifies a training dataset that you want to delete. You can't delete a training dataset if there are any audience models that depend on the training dataset. In Clean Rooms ML, the TrainingDataset is metadata that points to a Glue table, which is read only during AudienceModel creation. This action deletes the metadata.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter trainingDatasetArn : The Amazon Resource Name (ARN) of the training dataset that you want to delete.

Implementation

Future<void> deleteTrainingDataset({
  required String trainingDatasetArn,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/training-dataset/${Uri.encodeComponent(trainingDatasetArn)}',
    exceptionFnMap: _exceptionFns,
  );
}