getCollaborationTrainedModel method
Returns information about a trained model in a collaboration.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
The collaboration ID that contains the trained model that you want to
return information about.
Parameter trainedModelArn :
The Amazon Resource Name (ARN) of the trained model that you want to
return information about.
Parameter versionIdentifier :
The version identifier of the trained model to retrieve. If not specified,
the operation returns information about the latest version of the trained
model.
Implementation
Future<GetCollaborationTrainedModelResponse> getCollaborationTrainedModel({
required String collaborationIdentifier,
required String trainedModelArn,
String? versionIdentifier,
}) async {
final $query = <String, List<String>>{
if (versionIdentifier != null) 'versionIdentifier': [versionIdentifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/trained-models/${Uri.encodeComponent(trainedModelArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetCollaborationTrainedModelResponse.fromJson(response);
}