getConfiguredModelAlgorithmAssociation method

Future<GetConfiguredModelAlgorithmAssociationResponse> getConfiguredModelAlgorithmAssociation({
  1. required String configuredModelAlgorithmAssociationArn,
  2. required String membershipIdentifier,
})

Returns information about a configured model algorithm association.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter configuredModelAlgorithmAssociationArn : The Amazon Resource Name (ARN) of the configured model algorithm association that you want to return information about.

Parameter membershipIdentifier : The membership ID of the member that created the configured model algorithm association.

Implementation

Future<GetConfiguredModelAlgorithmAssociationResponse>
    getConfiguredModelAlgorithmAssociation({
  required String configuredModelAlgorithmAssociationArn,
  required String membershipIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/configured-model-algorithm-associations/${Uri.encodeComponent(configuredModelAlgorithmAssociationArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetConfiguredModelAlgorithmAssociationResponse.fromJson(response);
}