getTrainedModelInferenceJob method

Future<GetTrainedModelInferenceJobResponse> getTrainedModelInferenceJob({
  1. required String membershipIdentifier,
  2. required String trainedModelInferenceJobArn,
})

Returns information about a trained model inference job.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter membershipIdentifier : Provides the membership ID of the membership that contains the trained model inference job that you are interested in.

Parameter trainedModelInferenceJobArn : Provides the Amazon Resource Name (ARN) of the trained model inference job that you are interested in.

Implementation

Future<GetTrainedModelInferenceJobResponse> getTrainedModelInferenceJob({
  required String membershipIdentifier,
  required String trainedModelInferenceJobArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-model-inference-jobs/${Uri.encodeComponent(trainedModelInferenceJobArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetTrainedModelInferenceJobResponse.fromJson(response);
}