listCollaborationConfiguredModelAlgorithmAssociations method
Future<ListCollaborationConfiguredModelAlgorithmAssociationsResponse>
listCollaborationConfiguredModelAlgorithmAssociations({})
Returns a list of the configured model algorithm associations in a collaboration.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
The collaboration ID of the collaboration that contains the configured
model algorithm associations that you are interested in.
Parameter maxResults :
The maximum size of the results that is returned per call.
Parameter nextToken :
The token value retrieved from a previous call to access the next page of
results.
Implementation
Future<ListCollaborationConfiguredModelAlgorithmAssociationsResponse>
listCollaborationConfiguredModelAlgorithmAssociations({
required String collaborationIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/configured-model-algorithm-associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCollaborationConfiguredModelAlgorithmAssociationsResponse
.fromJson(response);
}