listCollaborationTrainedModelExportJobs method

Future<ListCollaborationTrainedModelExportJobsResponse> listCollaborationTrainedModelExportJobs({
  1. required String collaborationIdentifier,
  2. required String trainedModelArn,
  3. int? maxResults,
  4. String? nextToken,
  5. String? trainedModelVersionIdentifier,
})

Returns a list of the export jobs for a trained model in a collaboration.

May throw AccessDeniedException. May throw ThrottlingException. May throw ValidationException.

Parameter collaborationIdentifier : The collaboration ID of the collaboration that contains the trained model export jobs that you are interested in.

Parameter trainedModelArn : The Amazon Resource Name (ARN) of the trained model that was used to create the export jobs that you are interested in.

Parameter maxResults : The maximum size of the results that is returned per call.

Parameter nextToken : The token value retrieved from a previous call to access the next page of results.

Parameter trainedModelVersionIdentifier : The version identifier of the trained model to filter export jobs by. When specified, only export jobs for this specific version of the trained model are returned.

Implementation

Future<ListCollaborationTrainedModelExportJobsResponse>
    listCollaborationTrainedModelExportJobs({
  required String collaborationIdentifier,
  required String trainedModelArn,
  int? maxResults,
  String? nextToken,
  String? trainedModelVersionIdentifier,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (trainedModelVersionIdentifier != null)
      'trainedModelVersionIdentifier': [trainedModelVersionIdentifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/trained-models/${Uri.encodeComponent(trainedModelArn)}/export-jobs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCollaborationTrainedModelExportJobsResponse.fromJson(response);
}