listCollaborationTrainedModels method

Future<ListCollaborationTrainedModelsResponse> listCollaborationTrainedModels({
  1. required String collaborationIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of the trained models in a collaboration.

May throw AccessDeniedException. May throw ThrottlingException. May throw ValidationException.

Parameter collaborationIdentifier : The collaboration ID of the collaboration that contains the trained models you are interested in.

Parameter maxResults : The maximum size of the results that is returned per call.

Parameter nextToken : The token value retrieved from a previous call to access the next page of results.

Implementation

Future<ListCollaborationTrainedModelsResponse>
    listCollaborationTrainedModels({
  required String collaborationIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/trained-models',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCollaborationTrainedModelsResponse.fromJson(response);
}