listTrainedModelInferenceJobs method
Returns a list of trained model inference jobs that match the request parameters.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The membership
Parameter maxResults :
The maximum size of the results that is returned per call.
Parameter nextToken :
The token value retrieved from a previous call to access the next page of
results.
Parameter trainedModelArn :
The Amazon Resource Name (ARN) of a trained model that was used to create
the trained model inference jobs that you are interested in.
Parameter trainedModelVersionIdentifier :
The version identifier of the trained model to filter inference jobs by.
When specified, only inference jobs that used this specific version of the
trained model are returned.
Implementation
Future<ListTrainedModelInferenceJobsResponse> listTrainedModelInferenceJobs({
required String membershipIdentifier,
int? maxResults,
String? nextToken,
String? trainedModelArn,
String? trainedModelVersionIdentifier,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (trainedModelArn != null) 'trainedModelArn': [trainedModelArn],
if (trainedModelVersionIdentifier != null)
'trainedModelVersionIdentifier': [trainedModelVersionIdentifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-model-inference-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListTrainedModelInferenceJobsResponse.fromJson(response);
}