startAudienceGenerationJob method

Future<StartAudienceGenerationJobResponse> startAudienceGenerationJob({
  1. required String configuredAudienceModelArn,
  2. required String name,
  3. required AudienceGenerationJobDataSource seedAudience,
  4. String? collaborationId,
  5. String? description,
  6. bool? includeSeedInOutput,
  7. Map<String, String>? tags,
})

Information necessary to start the audience generation job.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter configuredAudienceModelArn : The Amazon Resource Name (ARN) of the configured audience model that is used for this audience generation job.

Parameter name : The name of the audience generation job.

Parameter seedAudience : The seed audience that is used to generate the audience.

Parameter collaborationId : The identifier of the collaboration that contains the audience generation job.

Parameter description : The description of the audience generation job.

Parameter includeSeedInOutput : Whether the seed audience is included in the audience generation output.

Parameter tags : The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.
  • For each resource, each tag key must be unique, and each tag key can have only one value.
  • Maximum key length - 128 Unicode characters in UTF-8.
  • Maximum value length - 256 Unicode characters in UTF-8.
  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
  • Tag keys and values are case sensitive.
  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.

Implementation

Future<StartAudienceGenerationJobResponse> startAudienceGenerationJob({
  required String configuredAudienceModelArn,
  required String name,
  required AudienceGenerationJobDataSource seedAudience,
  String? collaborationId,
  String? description,
  bool? includeSeedInOutput,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'configuredAudienceModelArn': configuredAudienceModelArn,
    'name': name,
    'seedAudience': seedAudience,
    if (collaborationId != null) 'collaborationId': collaborationId,
    if (description != null) 'description': description,
    if (includeSeedInOutput != null)
      'includeSeedInOutput': includeSeedInOutput,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/audience-generation-job',
    exceptionFnMap: _exceptionFns,
  );
  return StartAudienceGenerationJobResponse.fromJson(response);
}