deleteEnvironmentMembership method

Future<void> deleteEnvironmentMembership({
  1. required String environmentId,
  2. required String userArn,
})

Deletes an environment member from a development environment.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw LimitExceededException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter environmentId : The ID of the environment to delete the environment member from.

Parameter userArn : The Amazon Resource Name (ARN) of the environment member to delete from the environment.

Implementation

Future<void> deleteEnvironmentMembership({
  required String environmentId,
  required String userArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSCloud9WorkspaceManagementService.DeleteEnvironmentMembership'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'environmentId': environmentId,
      'userArn': userArn,
    },
  );
}