createResource method

Future<CreateResourceOutput> createResource({
  1. required String desiredState,
  2. required String typeName,
  3. String? clientToken,
  4. String? roleArn,
  5. String? typeVersionId,
})

Creates the specified resource. For more information, see Creating a resource in the Amazon Web Services Cloud Control API User Guide.

After you have initiated a resource creation request, you can monitor the progress of your request by calling GetResourceRequestStatus using the RequestToken of the ProgressEvent type returned by CreateResource.

May throw AlreadyExistsException. May throw ClientTokenConflictException. May throw ConcurrentOperationException. May throw GeneralServiceException. May throw HandlerFailureException. May throw HandlerInternalFailureException. May throw InvalidCredentialsException. May throw InvalidRequestException. May throw NetworkFailureException. May throw NotStabilizedException. May throw NotUpdatableException. May throw PrivateTypeException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceInternalErrorException. May throw ServiceLimitExceededException. May throw ThrottlingException. May throw TypeNotFoundException. May throw UnsupportedActionException.

Parameter desiredState : Structured data format representing the desired state of the resource, consisting of that resource's properties and their desired values. Specify the desired state as one of the following:

  • A JSON blob
  • A local path containing the desired state in JSON data format
For more information, see Composing the desired state of the resource in the Amazon Web Services Cloud Control API User Guide.

For more information about the properties of a specific resource, refer to the related topic for the resource in the Resource and property types reference in the CloudFormation Users Guide.

Parameter typeName : The name of the resource type.

Parameter clientToken : A unique identifier to ensure the idempotency of the resource request. As a best practice, specify this token to ensure idempotency, so that Amazon Web Services Cloud Control API can accurately distinguish between request retries and new resource requests. You might retry a resource request to ensure that it was successfully received.

A client token is valid for 36 hours once used. After that, a resource request with the same client token is treated as a new request.

If you do not specify a client token, one is generated for inclusion in the request.

For more information, see Ensuring resource operation requests are unique in the Amazon Web Services Cloud Control API User Guide.

Parameter roleArn : The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role for Cloud Control API to use when performing this resource operation. The role specified must have the permissions required for this operation. The necessary permissions for each event handler are defined in the handlers section of the resource type definition schema.

If you do not specify a role, Cloud Control API uses a temporary session created using your Amazon Web Services user credentials.

For more information, see Specifying credentials in the Amazon Web Services Cloud Control API User Guide.

Parameter typeVersionId : For private resource types, the type version to use in this resource operation. If you do not specify a resource version, CloudFormation uses the default version.

Implementation

Future<CreateResourceOutput> createResource({
  required String desiredState,
  required String typeName,
  String? clientToken,
  String? roleArn,
  String? typeVersionId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CloudApiService.CreateResource'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DesiredState': desiredState,
      'TypeName': typeName,
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
      if (roleArn != null) 'RoleArn': roleArn,
      if (typeVersionId != null) 'TypeVersionId': typeVersionId,
    },
  );

  return CreateResourceOutput.fromJson(jsonResponse.body);
}