getResource method
Returns information about the current state of the specified resource. For details, see Reading a resource's current state.
You can use this action to return information about an existing resource in your account and Amazon Web Services Region, whether those resources were provisioned using Cloud Control API.
May throw AlreadyExistsException.
May throw GeneralServiceException.
May throw HandlerFailureException.
May throw HandlerInternalFailureException.
May throw InvalidCredentialsException.
May throw InvalidRequestException.
May throw NetworkFailureException.
May throw NotStabilizedException.
May throw NotUpdatableException.
May throw PrivateTypeException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceInternalErrorException.
May throw ServiceLimitExceededException.
May throw ThrottlingException.
May throw TypeNotFoundException.
May throw UnsupportedActionException.
Parameter identifier :
The identifier for the resource.
You can specify the primary identifier, or any secondary identifier defined for the resource type in its resource schema. You can only specify one identifier. Primary identifiers can be specified as a string or JSON; secondary identifiers must be specified as JSON.
For compound primary identifiers (that is, one that consists of multiple
resource properties strung together), to specify the primary identifier as
a string, list the property values in the order they are specified
in the primary identifier definition, separated by |.
For more information, see Identifying resources in the Amazon Web Services Cloud Control API User Guide.
Parameter typeName :
The name of the resource type.
Parameter roleArn :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role for Cloud Control API to use when performing this resource operation.
The role specified must have the permissions required for this operation.
The necessary permissions for each event handler are defined in the
handlers
section of the resource
type definition schema.
If you do not specify a role, Cloud Control API uses a temporary session created using your Amazon Web Services user credentials.
For more information, see Specifying credentials in the Amazon Web Services Cloud Control API User Guide.
Parameter typeVersionId :
For private resource types, the type version to use in this resource
operation. If you do not specify a resource version, CloudFormation uses
the default version.
Implementation
Future<GetResourceOutput> getResource({
required String identifier,
required String typeName,
String? roleArn,
String? typeVersionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CloudApiService.GetResource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Identifier': identifier,
'TypeName': typeName,
if (roleArn != null) 'RoleArn': roleArn,
if (typeVersionId != null) 'TypeVersionId': typeVersionId,
},
);
return GetResourceOutput.fromJson(jsonResponse.body);
}