getResourceRequestStatus method

Future<GetResourceRequestStatusOutput> getResourceRequestStatus({
  1. required String requestToken,
})

Returns the current status of a resource operation request. For more information, see Tracking the progress of resource operation requests in the Amazon Web Services Cloud Control API User Guide.

May throw RequestTokenNotFoundException.

Parameter requestToken : A unique token used to track the progress of the resource operation request.

Request tokens are included in the ProgressEvent type returned by a resource operation request.

Implementation

Future<GetResourceRequestStatusOutput> getResourceRequestStatus({
  required String requestToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CloudApiService.GetResourceRequestStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RequestToken': requestToken,
    },
  );

  return GetResourceRequestStatusOutput.fromJson(jsonResponse.body);
}