listResourceRequests method
Returns existing resource operation requests. This includes requests of all status types. For more information, see Listing active resource operation requests in the Amazon Web Services Cloud Control API User Guide.
Parameter maxResults :
The maximum number of results to be returned with a single call. If the
number of available results exceeds this maximum, the response includes a
NextToken value that you can assign to the
NextToken request parameter to get the next set of results.
The default is 20.
Parameter nextToken :
If the previous paginated request didn't return all of the remaining
results, the response object's NextToken parameter value is
set to a token. To retrieve the next set of results, call this action
again and assign that token to the request object's NextToken
parameter. If there are no remaining results, the previous response
object's NextToken parameter is set to null.
Parameter resourceRequestStatusFilter :
The filter criteria to apply to the requests returned.
Implementation
Future<ListResourceRequestsOutput> listResourceRequests({
int? maxResults,
String? nextToken,
ResourceRequestStatusFilter? resourceRequestStatusFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CloudApiService.ListResourceRequests'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (resourceRequestStatusFilter != null)
'ResourceRequestStatusFilter': resourceRequestStatusFilter,
},
);
return ListResourceRequestsOutput.fromJson(jsonResponse.body);
}