updateResource method
Updates the specified property values in the resource.
You specify your resource property updates as a list of patch operations contained in a JSON patch document that adheres to the RFC 6902 - JavaScript Object Notation (JSON) Patch standard.
For details on how Cloud Control API performs resource update operations, see Updating a resource in the Amazon Web Services Cloud Control API User Guide.
After you have initiated a resource update request, you can monitor the
progress of your request by calling GetResourceRequestStatus
using the RequestToken of the ProgressEvent
returned by UpdateResource.
For more information about the properties of a specific resource, refer to the related topic for the resource in the Resource and property types reference in the CloudFormation Users Guide.
May throw AlreadyExistsException.
May throw ClientTokenConflictException.
May throw ConcurrentOperationException.
May throw GeneralServiceException.
May throw HandlerFailureException.
May throw HandlerInternalFailureException.
May throw InvalidCredentialsException.
May throw InvalidRequestException.
May throw NetworkFailureException.
May throw NotStabilizedException.
May throw NotUpdatableException.
May throw PrivateTypeException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceInternalErrorException.
May throw ServiceLimitExceededException.
May throw ThrottlingException.
May throw TypeNotFoundException.
May throw UnsupportedActionException.
Parameter identifier :
The identifier for the resource.
You can specify the primary identifier, or any secondary identifier defined for the resource type in its resource schema. You can only specify one identifier. Primary identifiers can be specified as a string or JSON; secondary identifiers must be specified as JSON.
For compound primary identifiers (that is, one that consists of multiple
resource properties strung together), to specify the primary identifier as
a string, list the property values in the order they are specified
in the primary identifier definition, separated by |.
For more information, see Identifying resources in the Amazon Web Services Cloud Control API User Guide.
Parameter patchDocument :
A JavaScript Object Notation (JSON) document listing the patch operations
that represent the updates to apply to the current resource properties.
For details, see Composing
the patch document in the Amazon Web Services Cloud Control API
User Guide.
Parameter typeName :
The name of the resource type.
Parameter clientToken :
A unique identifier to ensure the idempotency of the resource request. As
a best practice, specify this token to ensure idempotency, so that Amazon
Web Services Cloud Control API can accurately distinguish between request
retries and new resource requests. You might retry a resource request to
ensure that it was successfully received.
A client token is valid for 36 hours once used. After that, a resource request with the same client token is treated as a new request.
If you do not specify a client token, one is generated for inclusion in the request.
For more information, see Ensuring resource operation requests are unique in the Amazon Web Services Cloud Control API User Guide.
Parameter roleArn :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role for Cloud Control API to use when performing this resource operation.
The role specified must have the permissions required for this operation.
The necessary permissions for each event handler are defined in the
handlers
section of the resource
type definition schema.
If you do not specify a role, Cloud Control API uses a temporary session created using your Amazon Web Services user credentials.
For more information, see Specifying credentials in the Amazon Web Services Cloud Control API User Guide.
Parameter typeVersionId :
For private resource types, the type version to use in this resource
operation. If you do not specify a resource version, CloudFormation uses
the default version.
Implementation
Future<UpdateResourceOutput> updateResource({
required String identifier,
required String patchDocument,
required String typeName,
String? clientToken,
String? roleArn,
String? typeVersionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CloudApiService.UpdateResource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Identifier': identifier,
'PatchDocument': patchDocument,
'TypeName': typeName,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (roleArn != null) 'RoleArn': roleArn,
if (typeVersionId != null) 'TypeVersionId': typeVersionId,
},
);
return UpdateResourceOutput.fromJson(jsonResponse.body);
}