batchRead method
Performs all the read operations in a batch.
May throw AccessDeniedException.
May throw DirectoryNotEnabledException.
May throw InternalServiceException.
May throw InvalidArnException.
May throw LimitExceededException.
May throw RetryableConflictException.
May throw ValidationException.
Parameter directoryArn :
The Amazon Resource Name (ARN) that is associated with the
Directory. For more information, see arns.
Parameter operations :
A list of operations that are part of the batch.
Parameter consistencyLevel :
Represents the manner and timing in which the successful write or update
of an object is reflected in a subsequent read operation of that same
object.
Implementation
Future<BatchReadResponse> batchRead({
required String directoryArn,
required List<BatchReadOperation> operations,
ConsistencyLevel? consistencyLevel,
}) async {
final headers = <String, String>{
'x-amz-data-partition': directoryArn.toString(),
if (consistencyLevel != null)
'x-amz-consistency-level': consistencyLevel.value,
};
final $payload = <String, dynamic>{
'Operations': operations,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/amazonclouddirectory/2017-01-11/batchread',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return BatchReadResponse.fromJson(response);
}