getLinkAttributes method
Retrieves attributes that are associated with a typed link.
May throw AccessDeniedException.
May throw DirectoryNotEnabledException.
May throw FacetValidationException.
May throw InternalServiceException.
May throw InvalidArnException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw RetryableConflictException.
May throw ValidationException.
Parameter attributeNames :
A list of attribute names whose values will be retrieved.
Parameter directoryArn :
The Amazon Resource Name (ARN) that is associated with the Directory where
the typed link resides. For more information, see arns or Typed
Links.
Parameter typedLinkSpecifier :
Allows a typed link specifier to be accepted as input.
Parameter consistencyLevel :
The consistency level at which to retrieve the attributes on a typed link.
Implementation
Future<GetLinkAttributesResponse> getLinkAttributes({
required List<String> attributeNames,
required String directoryArn,
required TypedLinkSpecifier typedLinkSpecifier,
ConsistencyLevel? consistencyLevel,
}) async {
final headers = <String, String>{
'x-amz-data-partition': directoryArn.toString(),
};
final $payload = <String, dynamic>{
'AttributeNames': attributeNames,
'TypedLinkSpecifier': typedLinkSpecifier,
if (consistencyLevel != null) 'ConsistencyLevel': consistencyLevel.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/amazonclouddirectory/2017-01-11/typedlink/attributes/get',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetLinkAttributesResponse.fromJson(response);
}