listObjectAttributes method
Lists all attributes that are associated with an object.
May throw AccessDeniedException.
May throw DirectoryNotEnabledException.
May throw FacetValidationException.
May throw InternalServiceException.
May throw InvalidArnException.
May throw InvalidNextTokenException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw RetryableConflictException.
May throw ValidationException.
Parameter directoryArn :
The Amazon Resource Name (ARN) that is associated with the
Directory where the object resides. For more information, see
arns.
Parameter objectReference :
The reference that identifies the object whose attributes will be listed.
Parameter consistencyLevel :
Represents the manner and timing in which the successful write or update
of an object is reflected in a subsequent read operation of that same
object.
Parameter facetFilter :
Used to filter the list of object attributes that are associated with a
certain facet.
Parameter maxResults :
The maximum number of items to be retrieved in a single call. This is an
approximate number.
Parameter nextToken :
The pagination token.
Implementation
Future<ListObjectAttributesResponse> listObjectAttributes({
required String directoryArn,
required ObjectReference objectReference,
ConsistencyLevel? consistencyLevel,
SchemaFacet? facetFilter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'x-amz-data-partition': directoryArn.toString(),
if (consistencyLevel != null)
'x-amz-consistency-level': consistencyLevel.value,
};
final $payload = <String, dynamic>{
'ObjectReference': objectReference,
if (facetFilter != null) 'FacetFilter': facetFilter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/amazonclouddirectory/2017-01-11/object/attributes',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListObjectAttributesResponse.fromJson(response);
}