listObjectPolicies method
Returns policies attached to an object in pagination fashion.
May throw AccessDeniedException.
May throw DirectoryNotEnabledException.
May throw InternalServiceException.
May throw InvalidArnException.
May throw InvalidNextTokenException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw RetryableConflictException.
May throw ValidationException.
Parameter directoryArn :
The Amazon Resource Name (ARN) that is associated with the
Directory where objects reside. For more information, see
arns.
Parameter objectReference :
Reference that identifies the object for which policies will be listed.
Parameter consistencyLevel :
Represents the manner and timing in which the successful write or update
of an object is reflected in a subsequent read operation of that same
object.
Parameter maxResults :
The maximum number of items to be retrieved in a single call. This is an
approximate number.
Parameter nextToken :
The pagination token.
Implementation
Future<ListObjectPoliciesResponse> listObjectPolicies({
required String directoryArn,
required ObjectReference objectReference,
ConsistencyLevel? consistencyLevel,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'x-amz-data-partition': directoryArn.toString(),
if (consistencyLevel != null)
'x-amz-consistency-level': consistencyLevel.value,
};
final $payload = <String, dynamic>{
'ObjectReference': objectReference,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/amazonclouddirectory/2017-01-11/object/policy',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListObjectPoliciesResponse.fromJson(response);
}