CloudFormation class
CloudFormation allows you to create and manage Amazon Web Services infrastructure deployments predictably and repeatedly. You can use CloudFormation to leverage Amazon Web Services products, such as Amazon Elastic Compute Cloud, Amazon Elastic Block Store, Amazon Simple Notification Service, Elastic Load Balancing, and Amazon EC2 Auto Scaling to build highly reliable, highly scalable, cost-effective applications without creating or configuring the underlying Amazon Web Services infrastructure.
Constructors
- CloudFormation({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateOrganizationsAccess(
) → Future< void> - Activate trusted access with Organizations. With trusted access between StackSets and Organizations activated, the management account has permissions to create and manage StackSets for your organization.
-
activateType(
{bool? autoUpdate, String? executionRoleArn, LoggingConfig? loggingConfig, int? majorVersion, String? publicTypeArn, String? publisherId, ThirdPartyType? type, String? typeName, String? typeNameAlias, VersionBump? versionBump}) → Future< ActivateTypeOutput> - Activates a public third-party extension, such as a resource or module, to make it available for use in stack templates in your current account and Region. It can also create CloudFormation Hooks, which allow you to evaluate resource configurations before CloudFormation provisions them. Hooks integrate with both CloudFormation and Cloud Control API operations.
-
batchDescribeTypeConfigurations(
{required List< TypeConfigurationIdentifier> typeConfigurationIdentifiers}) → Future<BatchDescribeTypeConfigurationsOutput> - Returns configuration data for the specified CloudFormation extensions, from the CloudFormation registry in your current account and Region.
-
cancelUpdateStack(
{required String stackName, String? clientRequestToken}) → Future< void> - Cancels an update on the specified stack. If the call completes successfully, the stack rolls back the update and reverts to the previous stack configuration.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
continueUpdateRollback(
{required String stackName, String? clientRequestToken, List< String> ? resourcesToSkip, String? roleARN}) → Future<void> -
Continues rolling back a stack from
UPDATE_ROLLBACK_FAILEDtoUPDATE_ROLLBACK_COMPLETEstate. Depending on the cause of the failure, you can manually fix the error and continue the rollback. By continuing the rollback, you can return your stack to a working state (theUPDATE_ROLLBACK_COMPLETEstate) and then try to update the stack again. -
createChangeSet(
{required String changeSetName, required String stackName, List< Capability> ? capabilities, ChangeSetType? changeSetType, String? clientToken, DeploymentMode? deploymentMode, String? description, bool? importExistingResources, bool? includeNestedStacks, List<String> ? notificationARNs, OnStackFailure? onStackFailure, List<Parameter> ? parameters, List<String> ? resourceTypes, List<ResourceToImport> ? resourcesToImport, String? roleARN, RollbackConfiguration? rollbackConfiguration, List<Tag> ? tags, String? templateBody, String? templateURL, bool? usePreviousTemplate}) → Future<CreateChangeSetOutput> - Creates a list of changes that will be applied to a stack so that you can review the changes before executing them. You can create a change set for a stack that doesn't exist or an existing stack. If you create a change set for a stack that doesn't exist, the change set shows all of the resources that CloudFormation will create. If you create a change set for an existing stack, CloudFormation compares the stack's information with the information that you submit in the change set and lists the differences. Use change sets to understand which resources CloudFormation will create or change, and how it will change resources in an existing stack, before you create or update a stack.
-
createGeneratedTemplate(
{required String generatedTemplateName, List< ResourceDefinition> ? resources, String? stackName, TemplateConfiguration? templateConfiguration}) → Future<CreateGeneratedTemplateOutput> -
Creates a template from existing resources that are not already managed
with CloudFormation. You can check the status of the template generation
using the
DescribeGeneratedTemplateAPI action. -
createStack(
{required String stackName, List< Capability> ? capabilities, String? clientRequestToken, bool? disableRollback, bool? enableTerminationProtection, List<String> ? notificationARNs, OnFailure? onFailure, List<Parameter> ? parameters, List<String> ? resourceTypes, bool? retainExceptOnCreate, String? roleARN, RollbackConfiguration? rollbackConfiguration, String? stackPolicyBody, String? stackPolicyURL, List<Tag> ? tags, String? templateBody, String? templateURL, int? timeoutInMinutes}) → Future<CreateStackOutput> - Creates a stack as specified in the template. After the call completes successfully, the stack creation starts. You can check the status of the stack through the DescribeStacks operation.
-
createStackInstances(
{required List< String> regions, required String stackSetName, List<String> ? accounts, CallAs? callAs, DeploymentTargets? deploymentTargets, String? operationId, StackSetOperationPreferences? operationPreferences, List<Parameter> ? parameterOverrides}) → Future<CreateStackInstancesOutput> -
Creates stack instances for the specified accounts, within the specified
Amazon Web Services Regions. A stack instance refers to a stack in a
specific account and Region. You must specify at least one value for
either
AccountsorDeploymentTargets, and you must specify at least one value forRegions. -
createStackRefactor(
{required List< StackDefinition> stackDefinitions, String? description, bool? enableStackCreation, List<ResourceMapping> ? resourceMappings}) → Future<CreateStackRefactorOutput> - Creates a refactor across multiple stacks, with the list of stacks and resources that are affected.
-
createStackSet(
{required String stackSetName, String? administrationRoleARN, AutoDeployment? autoDeployment, CallAs? callAs, List< Capability> ? capabilities, String? clientRequestToken, String? description, String? executionRoleName, ManagedExecution? managedExecution, List<Parameter> ? parameters, PermissionModels? permissionModel, String? stackId, List<Tag> ? tags, String? templateBody, String? templateURL}) → Future<CreateStackSetOutput> - Creates a StackSet.
-
deactivateOrganizationsAccess(
) → Future< void> - Deactivates trusted access with Organizations. If trusted access is deactivated, the management account does not have permissions to create and manage service-managed StackSets for your organization.
-
deactivateType(
{String? arn, ThirdPartyType? type, String? typeName}) → Future< void> - Deactivates a public third-party extension, such as a resource or module, or a CloudFormation Hook when you no longer use it.
-
deleteChangeSet(
{required String changeSetName, String? stackName}) → Future< void> - Deletes the specified change set. Deleting change sets ensures that no one executes the wrong change set.
-
deleteGeneratedTemplate(
{required String generatedTemplateName}) → Future< void> - Deleted a generated template.
-
deleteStack(
{required String stackName, String? clientRequestToken, DeletionMode? deletionMode, List< String> ? retainResources, String? roleARN}) → Future<void> - Deletes a specified stack. Once the call completes successfully, stack deletion starts. Deleted stacks don't show up in the DescribeStacks operation if the deletion has been completed successfully.
-
deleteStackInstances(
{required List< String> regions, required bool retainStacks, required String stackSetName, List<String> ? accounts, CallAs? callAs, DeploymentTargets? deploymentTargets, String? operationId, StackSetOperationPreferences? operationPreferences}) → Future<DeleteStackInstancesOutput> - Deletes stack instances for the specified accounts, in the specified Amazon Web Services Regions.
-
deleteStackSet(
{required String stackSetName, CallAs? callAs}) → Future< void> - Deletes a StackSet. Before you can delete a StackSet, all its member stack instances must be deleted. For more information about how to complete this, see DeleteStackInstances.
-
deregisterType(
{String? arn, RegistryType? type, String? typeName, String? versionId}) → Future< void> -
Marks an extension or extension version as
DEPRECATEDin the CloudFormation registry, removing it from active use. Deprecated extensions or extension versions cannot be used in CloudFormation operations. -
describeAccountLimits(
{String? nextToken}) → Future< DescribeAccountLimitsOutput> - Retrieves your account's CloudFormation limits, such as the maximum number of stacks that you can create in your account. For more information about account limits, see Understand CloudFormation quotas in the CloudFormation User Guide.
-
describeChangeSet(
{required String changeSetName, bool? includePropertyValues, String? nextToken, String? stackName}) → Future< DescribeChangeSetOutput> - Returns the inputs for the change set and a list of changes that CloudFormation will make if you execute the change set. For more information, see Update CloudFormation stacks using change sets in the CloudFormation User Guide.
-
describeChangeSetHooks(
{required String changeSetName, String? logicalResourceId, String? nextToken, String? stackName}) → Future< DescribeChangeSetHooksOutput> - Returns Hook-related information for the change set and a list of changes that CloudFormation makes when you run the change set.
-
describeEvents(
{String? changeSetName, EventFilter? filters, String? nextToken, String? operationId, String? stackName}) → Future< DescribeEventsOutput> - Returns CloudFormation events based on flexible query criteria. Groups events by operation ID, enabling you to focus on individual stack operations during deployment.
-
describeGeneratedTemplate(
{required String generatedTemplateName}) → Future< DescribeGeneratedTemplateOutput> -
Describes a generated template. The output includes details about the
progress of the creation of a generated template started by a
CreateGeneratedTemplateAPI action or the update of a generated template started with anUpdateGeneratedTemplateAPI action. -
describeOrganizationsAccess(
{CallAs? callAs}) → Future< DescribeOrganizationsAccessOutput> -
Retrieves information about the account's
OrganizationAccessstatus. This API can be called either by the management account or the delegated administrator by using theCallAsparameter. This API can also be called without theCallAsparameter by the management account. -
describePublisher(
{String? publisherId}) → Future< DescribePublisherOutput> - Returns information about a CloudFormation extension publisher.
-
describeResourceScan(
{required String resourceScanId}) → Future< DescribeResourceScanOutput> - Describes details of a resource scan.
-
describeStackDriftDetectionStatus(
{required String stackDriftDetectionId}) → Future< DescribeStackDriftDetectionStatusOutput> - Returns information about a stack drift detection operation. A stack drift detection operation detects whether a stack's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. A stack is considered to have drifted if one or more of its resources have drifted. For more information about stack and resource drift, see Detect unmanaged configuration changes to stacks and resources with drift detection.
-
describeStackEvents(
{required String stackName, String? nextToken}) → Future< DescribeStackEventsOutput> - Returns all stack related events for a specified stack in reverse chronological order. For more information about a stack's event history, see Understand CloudFormation stack creation events in the CloudFormation User Guide.
-
describeStackInstance(
{required String stackInstanceAccount, required String stackInstanceRegion, required String stackSetName, CallAs? callAs}) → Future< DescribeStackInstanceOutput> - Returns the stack instance that's associated with the specified StackSet, Amazon Web Services account, and Amazon Web Services Region.
-
describeStackRefactor(
{required String stackRefactorId}) → Future< DescribeStackRefactorOutput> - Describes the stack refactor status.
-
describeStackResource(
{required String logicalResourceId, required String stackName}) → Future< DescribeStackResourceOutput> - Returns a description of the specified resource in the specified stack.
-
describeStackResourceDrifts(
{required String stackName, int? maxResults, String? nextToken, List< StackResourceDriftStatus> ? stackResourceDriftStatusFilters}) → Future<DescribeStackResourceDriftsOutput> - Returns drift information for the resources that have been checked for drift in the specified stack. This includes actual and expected configuration values for resources where CloudFormation detects configuration drift.
-
describeStackResources(
{String? logicalResourceId, String? physicalResourceId, String? stackName}) → Future< DescribeStackResourcesOutput> -
Returns Amazon Web Services resource descriptions for running and deleted
stacks. If
StackNameis specified, all the associated resources that are part of the stack are returned. IfPhysicalResourceIdis specified, the associated resources of the stack that the resource belongs to are returned. For deleted stacks,DescribeStackResourcesreturns resource information for up to 90 days after the stack has been deleted. -
describeStacks(
{String? nextToken, String? stackName}) → Future< DescribeStacksOutput> - Returns the description for the specified stack; if no stack name was specified, then it returns the description for all the stacks created. For more information about a stack's event history, see Understand CloudFormation stack creation events in the CloudFormation User Guide.
-
describeStackSet(
{required String stackSetName, CallAs? callAs}) → Future< DescribeStackSetOutput> - Returns the description of the specified StackSet.
-
describeStackSetOperation(
{required String operationId, required String stackSetName, CallAs? callAs}) → Future< DescribeStackSetOperationOutput> - Returns the description of the specified StackSet operation.
-
describeType(
{String? arn, String? publicVersionNumber, String? publisherId, RegistryType? type, String? typeName, String? versionId}) → Future< DescribeTypeOutput> - Returns detailed information about an extension from the CloudFormation registry in your current account and Region.
-
describeTypeRegistration(
{required String registrationToken}) → Future< DescribeTypeRegistrationOutput> - Returns information about an extension's registration, including its current status and type and version identifiers.
-
detectStackDrift(
{required String stackName, List< String> ? logicalResourceIds}) → Future<DetectStackDriftOutput> - Detects whether a stack's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For each resource in the stack that supports drift detection, CloudFormation compares the actual configuration of the resource with its expected template configuration. Only resource properties explicitly defined in the stack template are checked for drift. A stack is considered to have drifted if one or more of its resources differ from their expected template configurations. For more information, see Detect unmanaged configuration changes to stacks and resources with drift detection.
-
detectStackResourceDrift(
{required String logicalResourceId, required String stackName}) → Future< DetectStackResourceDriftOutput> - Returns information about whether a resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. This information includes actual and expected property values for resources in which CloudFormation detects drift. Only resource properties explicitly defined in the stack template are checked for drift. For more information about stack and resource drift, see Detect unmanaged configuration changes to stacks and resources with drift detection.
-
detectStackSetDrift(
{required String stackSetName, CallAs? callAs, String? operationId, StackSetOperationPreferences? operationPreferences}) → Future< DetectStackSetDriftOutput> - Detect drift on a StackSet. When CloudFormation performs drift detection on a StackSet, it performs drift detection on the stack associated with each stack instance in the StackSet. For more information, see Performing drift detection on CloudFormation StackSets.
-
estimateTemplateCost(
{List< Parameter> ? parameters, String? templateBody, String? templateURL}) → Future<EstimateTemplateCostOutput> - Returns the estimated monthly cost of a template. The return value is an Amazon Web Services Simple Monthly Calculator URL with a query string that describes the resources required to run the template.
-
executeChangeSet(
{required String changeSetName, String? clientRequestToken, bool? disableRollback, bool? retainExceptOnCreate, String? stackName}) → Future< void> - Updates a stack using the input information that was provided when the specified change set was created. After the call successfully completes, CloudFormation starts updating the stack. Use the DescribeStacks action to view the status of the update.
-
executeStackRefactor(
{required String stackRefactorId}) → Future< void> - Executes the stack refactor operation.
-
getGeneratedTemplate(
{required String generatedTemplateName, TemplateFormat? format}) → Future< GetGeneratedTemplateOutput> -
Retrieves a generated template. If the template is in an
InProgressorPendingstatus then the template returned will be the template when the template was last in aCompletestatus. If the template has not yet been in aCompletestatus then an empty template will be returned. -
getHookResult(
{String? hookResultId}) → Future< GetHookResultOutput> - Retrieves detailed information and remediation guidance for a Hook invocation result.
-
getStackPolicy(
{required String stackName}) → Future< GetStackPolicyOutput> - Returns the stack policy for a specified stack. If a stack doesn't have a policy, a null value is returned.
-
getTemplate(
{String? changeSetName, String? stackName, TemplateStage? templateStage}) → Future< GetTemplateOutput> - Returns the template body for a specified stack. You can get the template for running or deleted stacks.
-
getTemplateSummary(
{CallAs? callAs, String? stackName, String? stackSetName, String? templateBody, TemplateSummaryConfig? templateSummaryConfig, String? templateURL}) → Future< GetTemplateSummaryOutput> -
Returns information about a new or existing template. The
GetTemplateSummaryaction is useful for viewing parameter information, such as default parameter values and parameter types, before you create or update a stack or StackSet. -
importStacksToStackSet(
{required String stackSetName, CallAs? callAs, String? operationId, StackSetOperationPreferences? operationPreferences, List< String> ? organizationalUnitIds, List<String> ? stackIds, String? stackIdsUrl}) → Future<ImportStacksToStackSetOutput> - Import existing stacks into a new StackSets. Use the stack import operation to import up to 10 stacks into a new StackSet in the same account as the source stack or in a different administrator account and Region, by specifying the stack ID of the stack you intend to import.
-
listChangeSets(
{required String stackName, String? nextToken}) → Future< ListChangeSetsOutput> -
Returns the ID and status of each active change set for a stack. For
example, CloudFormation lists change sets that are in the
CREATE_IN_PROGRESSorCREATE_PENDINGstate. -
listExports(
{String? nextToken}) → Future< ListExportsOutput> - Lists all exported output values in the account and Region in which you call this action. Use this action to see the exported output values that you can import into other stacks. To import values, use the Fn::ImportValue function.
-
listGeneratedTemplates(
{int? maxResults, String? nextToken}) → Future< ListGeneratedTemplatesOutput> - Lists your generated templates in this Region.
-
listHookResults(
{String? nextToken, HookStatus? status, String? targetId, ListHookResultsTargetType? targetType, String? typeArn}) → Future< ListHookResultsOutput> - Returns summaries of invoked Hooks. For more information, see View invocation summaries for CloudFormation Hooks in the CloudFormation Hooks User Guide.
-
listImports(
{required String exportName, String? nextToken}) → Future< ListImportsOutput> - Lists all stacks that are importing an exported output value. To modify or remove an exported output value, first use this action to see which stacks are using it. To see the exported output values in your account, see ListExports.
-
listResourceScanRelatedResources(
{required String resourceScanId, required List< ScannedResourceIdentifier> resources, int? maxResults, String? nextToken}) → Future<ListResourceScanRelatedResourcesOutput> - Lists the related resources for a list of resources from a resource scan. The response indicates whether each returned resource is already managed by CloudFormation.
-
listResourceScanResources(
{required String resourceScanId, int? maxResults, String? nextToken, String? resourceIdentifier, String? resourceTypePrefix, String? tagKey, String? tagValue}) → Future< ListResourceScanResourcesOutput> - Lists the resources from a resource scan. The results can be filtered by resource identifier, resource type prefix, tag key, and tag value. Only resources that match all specified filters are returned. The response indicates whether each returned resource is already managed by CloudFormation.
-
listResourceScans(
{int? maxResults, String? nextToken, ScanType? scanTypeFilter}) → Future< ListResourceScansOutput> - List the resource scans from newest to oldest. By default it will return up to 10 resource scans.
-
listStackInstanceResourceDrifts(
{required String operationId, required String stackInstanceAccount, required String stackInstanceRegion, required String stackSetName, CallAs? callAs, int? maxResults, String? nextToken, List< StackResourceDriftStatus> ? stackInstanceResourceDriftStatuses}) → Future<ListStackInstanceResourceDriftsOutput> - Returns drift information for resources in a stack instance.
-
listStackInstances(
{required String stackSetName, CallAs? callAs, List< StackInstanceFilter> ? filters, int? maxResults, String? nextToken, String? stackInstanceAccount, String? stackInstanceRegion}) → Future<ListStackInstancesOutput> - Returns summary information about stack instances that are associated with the specified StackSet. You can filter for stack instances that are associated with a specific Amazon Web Services account name or Region, or that have a specific status.
-
listStackRefactorActions(
{required String stackRefactorId, int? maxResults, String? nextToken}) → Future< ListStackRefactorActionsOutput> - Lists the stack refactor actions that will be taken after calling the ExecuteStackRefactor action.
-
listStackRefactors(
{List< StackRefactorExecutionStatus> ? executionStatusFilter, int? maxResults, String? nextToken}) → Future<ListStackRefactorsOutput> - Lists all account stack refactor operations and their statuses.
-
listStackResources(
{required String stackName, String? nextToken}) → Future< ListStackResourcesOutput> - Returns descriptions of all resources of the specified stack.
-
listStacks(
{String? nextToken, List< StackStatus> ? stackStatusFilter}) → Future<ListStacksOutput> -
Returns the summary information for stacks whose status matches the
specified
StackStatusFilter. Summary information for stacks that have been deleted is kept for 90 days after the stack is deleted. If noStackStatusFilteris specified, summary information for all stacks is returned (including existing stacks and stacks that have been deleted). -
listStackSetAutoDeploymentTargets(
{required String stackSetName, CallAs? callAs, int? maxResults, String? nextToken}) → Future< ListStackSetAutoDeploymentTargetsOutput> - Returns summary information about deployment targets for a StackSet.
-
listStackSetOperationResults(
{required String operationId, required String stackSetName, CallAs? callAs, List< OperationResultFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListStackSetOperationResultsOutput> - Returns summary information about the results of a StackSet operation.
-
listStackSetOperations(
{required String stackSetName, CallAs? callAs, int? maxResults, String? nextToken}) → Future< ListStackSetOperationsOutput> - Returns summary information about operations performed on a StackSet.
-
listStackSets(
{CallAs? callAs, int? maxResults, String? nextToken, StackSetStatus? status}) → Future< ListStackSetsOutput> - Returns summary information about StackSets that are associated with the user.
-
listTypeRegistrations(
{int? maxResults, String? nextToken, RegistrationStatus? registrationStatusFilter, RegistryType? type, String? typeArn, String? typeName}) → Future< ListTypeRegistrationsOutput> - Returns a list of registration tokens for the specified extension(s).
-
listTypes(
{DeprecatedStatus? deprecatedStatus, TypeFilters? filters, int? maxResults, String? nextToken, ProvisioningType? provisioningType, RegistryType? type, Visibility? visibility}) → Future< ListTypesOutput> - Returns summary information about all extensions, including your private resource types, modules, and Hooks as well as all public extensions from Amazon Web Services and third-party publishers.
-
listTypeVersions(
{String? arn, DeprecatedStatus? deprecatedStatus, int? maxResults, String? nextToken, String? publisherId, RegistryType? type, String? typeName}) → Future< ListTypeVersionsOutput> - Returns summary information about the versions of an extension.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publishType(
{String? arn, String? publicVersionNumber, ThirdPartyType? type, String? typeName}) → Future< PublishTypeOutput> - Publishes the specified extension to the CloudFormation registry as a public extension in this Region. Public extensions are available for use by all CloudFormation users. For more information about publishing extensions, see Publishing extensions to make them available for public use in the CloudFormation Command Line Interface (CLI) User Guide.
-
recordHandlerProgress(
{required String bearerToken, required OperationStatus operationStatus, String? clientRequestToken, OperationStatus? currentOperationStatus, HandlerErrorCode? errorCode, String? resourceModel, String? statusMessage}) → Future< void> - Reports progress of a resource handler to CloudFormation.
-
registerPublisher(
{bool? acceptTermsAndConditions, String? connectionArn}) → Future< RegisterPublisherOutput> - Registers your account as a publisher of public extensions in the CloudFormation registry. Public extensions are available for use by all CloudFormation users. This publisher ID applies to your account in all Amazon Web Services Regions.
-
registerType(
{required String schemaHandlerPackage, required String typeName, String? clientRequestToken, String? executionRoleArn, LoggingConfig? loggingConfig, RegistryType? type}) → Future< RegisterTypeOutput> - Registers an extension with the CloudFormation service. Registering an extension makes it available for use in CloudFormation templates in your Amazon Web Services account, and includes:
-
rollbackStack(
{required String stackName, String? clientRequestToken, bool? retainExceptOnCreate, String? roleARN}) → Future< RollbackStackOutput> -
When specifying
RollbackStack, you preserve the state of previously provisioned resources when an operation fails. You can check the status of the stack through the DescribeStacks operation. -
setStackPolicy(
{required String stackName, String? stackPolicyBody, String? stackPolicyURL}) → Future< void> - Sets a stack policy for a specified stack.
-
setTypeConfiguration(
{required String configuration, String? configurationAlias, ThirdPartyType? type, String? typeArn, String? typeName}) → Future< SetTypeConfigurationOutput> - Specifies the configuration data for a CloudFormation extension, such as a resource or Hook, in the given account and Region.
-
setTypeDefaultVersion(
{String? arn, RegistryType? type, String? typeName, String? versionId}) → Future< void> - Specify the default version of an extension. The default version of an extension will be used in CloudFormation operations.
-
signalResource(
{required String logicalResourceId, required String stackName, required ResourceSignalStatus status, required String uniqueId}) → Future< void> -
Sends a signal to the specified resource with a success or failure status.
You can use the
SignalResourceoperation in conjunction with a creation policy or update policy. CloudFormation doesn't proceed with a stack creation or update until resources receive the required number of signals or the timeout period is exceeded. TheSignalResourceoperation is useful in cases where you want to send signals from anywhere other than an Amazon EC2 instance. -
startResourceScan(
{String? clientRequestToken, List< ScanFilter> ? scanFilters}) → Future<StartResourceScanOutput> -
Starts a scan of the resources in this account in this Region. You can the
status of a scan using the
ListResourceScansAPI action. -
stopStackSetOperation(
{required String operationId, required String stackSetName, CallAs? callAs}) → Future< void> - Stops an in-progress operation on a StackSet and its associated stack instances. StackSets will cancel all the unstarted stack instance deployments and wait for those are in-progress to complete.
-
testType(
{String? arn, String? logDeliveryBucket, ThirdPartyType? type, String? typeName, String? versionId}) → Future< TestTypeOutput> - Tests a registered extension to make sure it meets all necessary requirements for being published in the CloudFormation registry.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateGeneratedTemplate(
{required String generatedTemplateName, List< ResourceDefinition> ? addResources, String? newGeneratedTemplateName, bool? refreshAllResources, List<String> ? removeResources, TemplateConfiguration? templateConfiguration}) → Future<UpdateGeneratedTemplateOutput> -
Updates a generated template. This can be used to change the name, add and
remove resources, refresh resources, and change the
DeletionPolicyandUpdateReplacePolicysettings. You can check the status of the update to the generated template using theDescribeGeneratedTemplateAPI action. -
updateStack(
{required String stackName, List< Capability> ? capabilities, String? clientRequestToken, bool? disableRollback, List<String> ? notificationARNs, List<Parameter> ? parameters, List<String> ? resourceTypes, bool? retainExceptOnCreate, String? roleARN, RollbackConfiguration? rollbackConfiguration, String? stackPolicyBody, String? stackPolicyDuringUpdateBody, String? stackPolicyDuringUpdateURL, String? stackPolicyURL, List<Tag> ? tags, String? templateBody, String? templateURL, bool? usePreviousTemplate}) → Future<UpdateStackOutput> - Updates a stack as specified in the template. After the call completes successfully, the stack update starts. You can check the status of the stack through the DescribeStacks action.
-
updateStackInstances(
{required List< String> regions, required String stackSetName, List<String> ? accounts, CallAs? callAs, DeploymentTargets? deploymentTargets, String? operationId, StackSetOperationPreferences? operationPreferences, List<Parameter> ? parameterOverrides}) → Future<UpdateStackInstancesOutput> - Updates the parameter values for stack instances for the specified accounts, within the specified Amazon Web Services Regions. A stack instance refers to a stack in a specific account and Region.
-
updateStackSet(
{required String stackSetName, List< String> ? accounts, String? administrationRoleARN, AutoDeployment? autoDeployment, CallAs? callAs, List<Capability> ? capabilities, DeploymentTargets? deploymentTargets, String? description, String? executionRoleName, ManagedExecution? managedExecution, String? operationId, StackSetOperationPreferences? operationPreferences, List<Parameter> ? parameters, PermissionModels? permissionModel, List<String> ? regions, List<Tag> ? tags, String? templateBody, String? templateURL, bool? usePreviousTemplate}) → Future<UpdateStackSetOutput> - Updates the StackSet and associated stack instances in the specified accounts and Amazon Web Services Regions.
-
updateTerminationProtection(
{required bool enableTerminationProtection, required String stackName}) → Future< UpdateTerminationProtectionOutput> - Updates termination protection for the specified stack. If a user attempts to delete a stack with termination protection enabled, the operation fails and the stack remains unchanged. For more information, see Protect a CloudFormation stack from being deleted in the CloudFormation User Guide.
-
validateTemplate(
{String? templateBody, String? templateURL}) → Future< ValidateTemplateOutput> - Validates a specified template. CloudFormation first checks if the template is valid JSON. If it isn't, CloudFormation checks if the template is valid YAML. If both these checks fail, CloudFormation returns a template validation error.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited