createChangeSet method
- required String changeSetName,
- required String stackName,
- List<
Capability> ? capabilities, - ChangeSetType? changeSetType,
- String? clientToken,
- DeploymentMode? deploymentMode,
- String? description,
- bool? importExistingResources,
- bool? includeNestedStacks,
- List<
String> ? notificationARNs, - OnStackFailure? onStackFailure,
- List<
Parameter> ? parameters, - List<
String> ? resourceTypes, - List<
ResourceToImport> ? resourcesToImport, - String? roleARN,
- RollbackConfiguration? rollbackConfiguration,
- List<
Tag> ? tags, - String? templateBody,
- String? templateURL,
- bool? usePreviousTemplate,
Creates a list of changes that will be applied to a stack so that you can review the changes before executing them. You can create a change set for a stack that doesn't exist or an existing stack. If you create a change set for a stack that doesn't exist, the change set shows all of the resources that CloudFormation will create. If you create a change set for an existing stack, CloudFormation compares the stack's information with the information that you submit in the change set and lists the differences. Use change sets to understand which resources CloudFormation will create or change, and how it will change resources in an existing stack, before you create or update a stack.
To create a change set for a stack that doesn't exist, for the
ChangeSetType parameter, specify CREATE. To
create a change set for an existing stack, specify UPDATE for
the ChangeSetType parameter. To create a change set for an
import operation, specify IMPORT for the
ChangeSetType parameter. After the
CreateChangeSet call successfully completes, CloudFormation
starts creating the change set. To check the status of the change set or
to review it, use the DescribeChangeSet action.
When you are satisfied with the changes the change set will make, execute the change set by using the ExecuteChangeSet action. CloudFormation doesn't make changes until you execute the change set.
To create a change set for the entire stack hierarchy, set
IncludeNestedStacks to True.
May throw AlreadyExistsException.
May throw InsufficientCapabilitiesException.
May throw LimitExceededException.
Parameter changeSetName :
The name of the change set. The name must be unique among all change sets
that are associated with the specified stack.
A change set name can contain only alphanumeric, case sensitive characters, and hyphens. It must start with an alphabetical character and can't exceed 128 characters.
Parameter stackName :
The name or the unique ID of the stack for which you are creating a change
set. CloudFormation generates the change set by comparing this stack's
information with the information that you submit, such as a modified
template or different parameter input values.
Parameter capabilities :
In some cases, you must explicitly acknowledge that your stack template
contains certain capabilities in order for CloudFormation to create the
stack.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account, for example, by creating new IAM users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability.- If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns
an
InsufficientCapabilitieserror.
- AWS::IAM::AccessKey
- AWS::IAM::Group
- AWS::IAM::InstanceProfile
- AWS::IAM::ManagedPolicy
- AWS::IAM::Policy
- AWS::IAM::Role
- AWS::IAM::User
- AWS::IAM::UserToGroupAddition
-
CAPABILITY_AUTO_EXPANDSome template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually creating the stack. If your stack template contains one or more macros, and you choose to create a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.
If you want to create a stack from a stack template that contains macros and nested stacks, you must create or update the stack directly from the template using the CreateStack or UpdateStack action, and specifying this capability. For more information about macros, see Perform custom processing on CloudFormation templates with template macros.
Parameter changeSetType :
The type of change set operation. To create a change set for a new stack,
specify CREATE. To create a change set for an existing stack,
specify UPDATE. To create a change set for an import
operation, specify IMPORT.
If you create a change set for a new stack, CloudFormation creates a stack
with a unique stack ID, but no template or resources. The stack will be in
the REVIEW_IN_PROGRESS state until you execute the change
set.
By default, CloudFormation specifies UPDATE. You can't use
the UPDATE type to create a change set for a new stack or the
CREATE type to create a change set for an existing stack.
Parameter clientToken :
A unique identifier for this CreateChangeSet request. Specify
this token if you plan to retry requests so that CloudFormation knows that
you're not attempting to create another change set with the same name. You
might retry CreateChangeSet requests to ensure that
CloudFormation successfully received them.
Parameter deploymentMode :
Determines how CloudFormation handles configuration drift during
deployment.
-
REVERT_DRIFT– Creates a drift-aware change set that brings actual resource states in line with template definitions. Provides a three-way comparison between actual state, previous deployment state, and desired state.
Parameter description :
A description to help you identify this change set.
Parameter importExistingResources :
Indicates if the change set auto-imports resources that already exist. For
more information, see Import
Amazon Web Services resources into a CloudFormation stack
automatically in the CloudFormation User Guide.
Parameter includeNestedStacks :
Creates a change set for the all nested stacks specified in the template.
The default behavior of this action is set to False. To
include nested sets in a change set, specify True.
Parameter notificationARNs :
The Amazon Resource Names (ARNs) of Amazon SNS topics that CloudFormation
associates with the stack. To remove all associated notification topics,
specify an empty list.
Parameter onStackFailure :
Determines what action will be taken if stack creation fails. If this
parameter is specified, the DisableRollback parameter to the
ExecuteChangeSet
API operation must not be specified. This must be one of these values:
-
DELETE- Deletes the change set if the stack creation fails. This is only valid when theChangeSetTypeparameter is set toCREATE. If the deletion of the stack fails, the status of the stack isDELETE_FAILED. -
DO_NOTHING- if the stack creation fails, do nothing. This is equivalent to specifyingtruefor theDisableRollbackparameter to the ExecuteChangeSet API operation. -
ROLLBACK- if the stack creation fails, roll back the stack. This is equivalent to specifyingfalsefor theDisableRollbackparameter to the ExecuteChangeSet API operation.
OnStackFailure parameter is set
to DELETE for the change set for the parent stack, any
failure in a child stack will cause the parent stack creation to fail and
all stacks to be deleted.
Parameter parameters :
A list of Parameter structures that specify input parameters
for the change set. For more information, see the Parameter data
type.
Parameter resourceTypes :
Specifies which resource types you can work with, such as
AWS::EC2::Instance or Custom::MyCustomInstance.
If the list of resource types doesn't include a resource type that you're updating, the stack update fails. By default, CloudFormation grants permissions to all resource types. IAM uses this parameter for condition keys in IAM policies for CloudFormation. For more information, see Control CloudFormation access with Identity and Access Management in the CloudFormation User Guide.
Parameter resourcesToImport :
The resources to import into your stack.
Parameter roleARN :
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes
when executing the change set. CloudFormation uses the role's credentials
to make calls on your behalf. CloudFormation uses this role for all future
operations on the stack. Provided that users have permission to operate on
the stack, CloudFormation uses this role even if the users don't have
permission to pass it. Ensure that the role grants least permission.
If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials.
Parameter rollbackConfiguration :
The rollback triggers for CloudFormation to monitor during stack creation
and updating operations, and for the specified monitoring period
afterwards.
Parameter tags :
Key-value pairs to associate with this stack. CloudFormation also
propagates these tags to resources in the stack. You can specify a maximum
of 50 tags.
Parameter templateBody :
A structure that contains the body of the revised template, with a minimum
length of 1 byte and a maximum length of 51,200 bytes. CloudFormation
generates the change set by comparing this template with the template of
the stack that you specified.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Parameter templateURL :
The URL of the file that contains the revised template. The URL must point
to a template (max size: 1 MB) that's located in an Amazon S3 bucket or a
Systems Manager document. CloudFormation generates the change set by
comparing this template with the stack that you specified. The location
for an Amazon S3 bucket must start with https://. URLs from
S3 static websites are not supported.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Parameter usePreviousTemplate :
Whether to reuse the template that's associated with the stack to create
the change set.
When using templates with the AWS::LanguageExtensions
transform, provide the template instead of using
UsePreviousTemplate to ensure new parameter values and
Systems Manager parameter updates are applied correctly. For more
information, see AWS::LanguageExtensions
transform.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Implementation
Future<CreateChangeSetOutput> createChangeSet({
required String changeSetName,
required String stackName,
List<Capability>? capabilities,
ChangeSetType? changeSetType,
String? clientToken,
DeploymentMode? deploymentMode,
String? description,
bool? importExistingResources,
bool? includeNestedStacks,
List<String>? notificationARNs,
OnStackFailure? onStackFailure,
List<Parameter>? parameters,
List<String>? resourceTypes,
List<ResourceToImport>? resourcesToImport,
String? roleARN,
RollbackConfiguration? rollbackConfiguration,
List<Tag>? tags,
String? templateBody,
String? templateURL,
bool? usePreviousTemplate,
}) async {
final $request = <String, String>{
'ChangeSetName': changeSetName,
'StackName': stackName,
if (capabilities != null)
if (capabilities.isEmpty)
'Capabilities': ''
else
for (var i1 = 0; i1 < capabilities.length; i1++)
'Capabilities.member.${i1 + 1}': capabilities[i1].value,
if (changeSetType != null) 'ChangeSetType': changeSetType.value,
if (clientToken != null) 'ClientToken': clientToken,
if (deploymentMode != null) 'DeploymentMode': deploymentMode.value,
if (description != null) 'Description': description,
if (importExistingResources != null)
'ImportExistingResources': importExistingResources.toString(),
if (includeNestedStacks != null)
'IncludeNestedStacks': includeNestedStacks.toString(),
if (notificationARNs != null)
if (notificationARNs.isEmpty)
'NotificationARNs': ''
else
for (var i1 = 0; i1 < notificationARNs.length; i1++)
'NotificationARNs.member.${i1 + 1}': notificationARNs[i1],
if (onStackFailure != null) 'OnStackFailure': onStackFailure.value,
if (parameters != null)
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.member.${i1 + 1}.${e3.key}': e3.value,
if (resourceTypes != null)
if (resourceTypes.isEmpty)
'ResourceTypes': ''
else
for (var i1 = 0; i1 < resourceTypes.length; i1++)
'ResourceTypes.member.${i1 + 1}': resourceTypes[i1],
if (resourcesToImport != null)
if (resourcesToImport.isEmpty)
'ResourcesToImport': ''
else
for (var i1 = 0; i1 < resourcesToImport.length; i1++)
for (var e3 in resourcesToImport[i1].toQueryMap().entries)
'ResourcesToImport.member.${i1 + 1}.${e3.key}': e3.value,
if (roleARN != null) 'RoleARN': roleARN,
if (rollbackConfiguration != null)
for (var e1 in rollbackConfiguration.toQueryMap().entries)
'RollbackConfiguration.${e1.key}': e1.value,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
if (templateBody != null) 'TemplateBody': templateBody,
if (templateURL != null) 'TemplateURL': templateURL,
if (usePreviousTemplate != null)
'UsePreviousTemplate': usePreviousTemplate.toString(),
};
final $result = await _protocol.send(
$request,
action: 'CreateChangeSet',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateChangeSetResult',
);
return CreateChangeSetOutput.fromXml($result);
}