createStack method
- required String stackName,
- List<
Capability> ? capabilities, - String? clientRequestToken,
- bool? disableRollback,
- bool? enableTerminationProtection,
- List<
String> ? notificationARNs, - OnFailure? onFailure,
- List<
Parameter> ? parameters, - List<
String> ? resourceTypes, - bool? retainExceptOnCreate,
- String? roleARN,
- RollbackConfiguration? rollbackConfiguration,
- String? stackPolicyBody,
- String? stackPolicyURL,
- List<
Tag> ? tags, - String? templateBody,
- String? templateURL,
- int? timeoutInMinutes,
Creates a stack as specified in the template. After the call completes successfully, the stack creation starts. You can check the status of the stack through the DescribeStacks operation.
For more information about creating a stack and monitoring stack progress, see Managing Amazon Web Services resources as a single unit with CloudFormation stacks in the CloudFormation User Guide.
May throw AlreadyExistsException.
May throw InsufficientCapabilitiesException.
May throw LimitExceededException.
May throw TokenAlreadyExistsException.
Parameter stackName :
The name that's associated with the stack. The name must be unique in the
Region in which you are creating the stack.
Parameter capabilities :
In some cases, you must explicitly acknowledge that your stack template
contains certain capabilities in order for CloudFormation to create the
stack.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account; for example, by creating new IAM users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability.- If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns
an
InsufficientCapabilitieserror.
- AWS::IAM::AccessKey
- AWS::IAM::Group
- AWS::IAM::InstanceProfile
- AWS::IAM::ManagedPolicy
- AWS::IAM::Policy
- AWS::IAM::Role
- AWS::IAM::User
- AWS::IAM::UserToGroupAddition
-
CAPABILITY_AUTO_EXPANDSome template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually creating the stack. If your stack template contains one or more macros, and you choose to create a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.
If you want to create a stack from a stack template that contains macros and nested stacks, you must create the stack directly from the template using this capability.
Each macro relies on an underlying Lambda service function for processing stack templates. Be aware that the Lambda function owner can update the function operation without CloudFormation being notified. For more information, see Perform custom processing on CloudFormation templates with template macros.
Parameter clientRequestToken :
A unique identifier for this CreateStack request. Specify
this token if you plan to retry requests so that CloudFormation knows that
you're not attempting to create a stack with the same name. You might
retry CreateStack requests to ensure that CloudFormation
successfully received them.
All events initiated by a given stack operation are assigned the same
client request token, which you can use to track operations. For example,
if you execute a CreateStack operation with the token
token1, then all the StackEvents generated by
that operation will have ClientRequestToken set as
token1.
In the console, stack operations display the client request token on the
Events tab. Stack operations that are initiated from the console use the
token format Console-StackOperation-ID, which helps you easily
identify the stack operation . For example, if you create a stack using
the console, each stack event would be assigned the same token in the
following format:
Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002.
Parameter disableRollback :
Set to true to disable rollback of the stack if stack
creation failed. You can specify either DisableRollback or
OnFailure, but not both.
Default: false
Parameter enableTerminationProtection :
Whether to enable termination protection on the specified stack. If a user
attempts to delete a stack with termination protection enabled, the
operation fails and the stack remains unchanged. For more information, see
Protect
CloudFormation stacks from being deleted in the CloudFormation User
Guide. Termination protection is deactivated on stacks by default.
For nested stacks, termination protection is set on the root stack and can't be changed directly on the nested stack.
Parameter notificationARNs :
The Amazon SNS topic ARNs to publish stack related events. You can find
your Amazon SNS topic ARNs using the Amazon SNS console or your Command
Line Interface (CLI).
Parameter onFailure :
Determines what action will be taken if stack creation fails. This must be
one of: DO_NOTHING, ROLLBACK, or
DELETE. You can specify either OnFailure or
DisableRollback, but not both.
Default: ROLLBACK
Parameter parameters :
A list of Parameter structures that specify input parameters
for the stack. For more information, see the Parameter
data type.
Parameter resourceTypes :
Specifies which resource types you can work with, such as
AWS::EC2::Instance or Custom::MyCustomInstance.
If the list of resource types doesn't include a resource that you're creating, the stack creation fails. By default, CloudFormation grants permissions to all resource types. IAM uses this parameter for CloudFormation-specific condition keys in IAM policies. For more information, see Control CloudFormation access with Identity and Access Management.
Parameter retainExceptOnCreate :
When set to true, newly created resources are deleted when
the operation rolls back. This includes newly created resources marked
with a deletion policy of Retain.
Default: false
Parameter roleARN :
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes
to create the stack. CloudFormation uses the role's credentials to make
calls on your behalf. CloudFormation always uses this role for all future
operations on the stack. Provided that users have permission to operate on
the stack, CloudFormation uses this role even if the users don't have
permission to pass it. Ensure that the role grants least privilege.
If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that's generated from your user credentials.
Parameter rollbackConfiguration :
The rollback triggers for CloudFormation to monitor during stack creation
and updating operations, and for the specified monitoring period
afterwards.
Parameter stackPolicyBody :
Structure that contains the stack policy body. For more information, see
Prevent
updates to stack resources in the CloudFormation User Guide.
You can specify either the StackPolicyBody or the
StackPolicyURL parameter, but not both.
Parameter stackPolicyURL :
Location of a file that contains the stack policy. The URL must point to a
policy (maximum size: 16 KB) located in an S3 bucket in the same Region as
the stack. The location for an Amazon S3 bucket must start with
https://. URLs from S3 static websites are not supported.
You can specify either the StackPolicyBody or the
StackPolicyURL parameter, but not both.
Parameter tags :
Key-value pairs to associate with this stack. CloudFormation also
propagates these tags to the resources created in the stack. A maximum
number of 50 tags can be specified.
Parameter templateBody :
Structure that contains the template body with a minimum length of 1 byte
and a maximum length of 51,200 bytes.
Conditional: You must specify either TemplateBody or
TemplateURL, but not both.
Parameter templateURL :
The URL of a file that contains the template body. The URL must point to a
template (max size: 1 MB) that's located in an Amazon S3 bucket or a
Systems Manager document. The location for an Amazon S3 bucket must start
with https://. URLs from S3 static websites are not
supported.
Conditional: You must specify either the TemplateBody or the
TemplateURL parameter, but not both.
Parameter timeoutInMinutes :
The amount of time that can pass before the stack status becomes
CREATE_FAILED; if DisableRollback is not set or
is set to false, the stack will be rolled back.
Implementation
Future<CreateStackOutput> createStack({
required String stackName,
List<Capability>? capabilities,
String? clientRequestToken,
bool? disableRollback,
bool? enableTerminationProtection,
List<String>? notificationARNs,
OnFailure? onFailure,
List<Parameter>? parameters,
List<String>? resourceTypes,
bool? retainExceptOnCreate,
String? roleARN,
RollbackConfiguration? rollbackConfiguration,
String? stackPolicyBody,
String? stackPolicyURL,
List<Tag>? tags,
String? templateBody,
String? templateURL,
int? timeoutInMinutes,
}) async {
_s.validateNumRange(
'timeoutInMinutes',
timeoutInMinutes,
1,
1152921504606846976,
);
final $request = <String, String>{
'StackName': stackName,
if (capabilities != null)
if (capabilities.isEmpty)
'Capabilities': ''
else
for (var i1 = 0; i1 < capabilities.length; i1++)
'Capabilities.member.${i1 + 1}': capabilities[i1].value,
if (clientRequestToken != null) 'ClientRequestToken': clientRequestToken,
if (disableRollback != null)
'DisableRollback': disableRollback.toString(),
if (enableTerminationProtection != null)
'EnableTerminationProtection': enableTerminationProtection.toString(),
if (notificationARNs != null)
if (notificationARNs.isEmpty)
'NotificationARNs': ''
else
for (var i1 = 0; i1 < notificationARNs.length; i1++)
'NotificationARNs.member.${i1 + 1}': notificationARNs[i1],
if (onFailure != null) 'OnFailure': onFailure.value,
if (parameters != null)
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.member.${i1 + 1}.${e3.key}': e3.value,
if (resourceTypes != null)
if (resourceTypes.isEmpty)
'ResourceTypes': ''
else
for (var i1 = 0; i1 < resourceTypes.length; i1++)
'ResourceTypes.member.${i1 + 1}': resourceTypes[i1],
if (retainExceptOnCreate != null)
'RetainExceptOnCreate': retainExceptOnCreate.toString(),
if (roleARN != null) 'RoleARN': roleARN,
if (rollbackConfiguration != null)
for (var e1 in rollbackConfiguration.toQueryMap().entries)
'RollbackConfiguration.${e1.key}': e1.value,
if (stackPolicyBody != null) 'StackPolicyBody': stackPolicyBody,
if (stackPolicyURL != null) 'StackPolicyURL': stackPolicyURL,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
if (templateBody != null) 'TemplateBody': templateBody,
if (templateURL != null) 'TemplateURL': templateURL,
if (timeoutInMinutes != null)
'TimeoutInMinutes': timeoutInMinutes.toString(),
};
final $result = await _protocol.send(
$request,
action: 'CreateStack',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateStackResult',
);
return CreateStackOutput.fromXml($result);
}