createStackSet method
- required String stackSetName,
- String? administrationRoleARN,
- AutoDeployment? autoDeployment,
- CallAs? callAs,
- List<
Capability> ? capabilities, - String? clientRequestToken,
- String? description,
- String? executionRoleName,
- ManagedExecution? managedExecution,
- List<
Parameter> ? parameters, - PermissionModels? permissionModel,
- String? stackId,
- List<
Tag> ? tags, - String? templateBody,
- String? templateURL,
Creates a StackSet.
May throw CreatedButModifiedException.
May throw LimitExceededException.
May throw NameAlreadyExistsException.
Parameter stackSetName :
The name to associate with the StackSet. The name must be unique in the
Region where you create your StackSet.
Parameter administrationRoleARN :
The Amazon Resource Name (ARN) of the IAM role to use to create this
StackSet.
Specify an IAM role only if you are using customized administrator roles to control which users or groups can manage specific StackSets within the same administrator account. For more information, see Grant self-managed permissions in the CloudFormation User Guide.
Valid only if the permissions model is SELF_MANAGED.
Parameter autoDeployment :
Describes whether StackSets automatically deploys to Organizations
accounts that are added to the target organization or organizational unit
(OU). For more information, see Enable
or disable automatic deployments for StackSets in Organizations in the
CloudFormation User Guide.
Required if the permissions model is SERVICE_MANAGED. (Not
used with self-managed permissions.)
Parameter callAs :
Specifies whether you are acting as an account administrator in the
organization's management account or as a delegated administrator in a
member account.
By default, SELF is specified. Use SELF for
StackSets with self-managed permissions.
-
To create a StackSet with service-managed permissions while signed in to
the management account, specify
SELF. -
To create a StackSet with service-managed permissions while signed in to a
delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated admin in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
Valid only if the permissions model is SERVICE_MANAGED.
Parameter capabilities :
In some cases, you must explicitly acknowledge that your StackSet template
contains certain capabilities in order for CloudFormation to create the
StackSet and related stack instances.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account; for example, by creating new IAM users. For those StackSets, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability.- If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns
an
InsufficientCapabilitieserror.
- AWS::IAM::AccessKey
- AWS::IAM::Group
- AWS::IAM::InstanceProfile
- AWS::IAM::Policy
- AWS::IAM::Role
- AWS::IAM::User
- AWS::IAM::UserToGroupAddition
-
CAPABILITY_AUTO_EXPANDSome templates reference macros. If your StackSet template references one or more macros, you must create the StackSet directly from the processed template, without first reviewing the resulting changes in a change set. To create the StackSet directly, you must acknowledge this capability. For more information, see Perform custom processing on CloudFormation templates with template macros.
Parameter clientRequestToken :
A unique identifier for this CreateStackSet request. Specify
this token if you plan to retry requests so that CloudFormation knows that
you're not attempting to create another StackSet with the same name. You
might retry CreateStackSet requests to ensure that
CloudFormation successfully received them.
If you don't specify an operation ID, the SDK generates one automatically.
Parameter description :
A description of the StackSet. You can use the description to identify the
StackSet's purpose or other important information.
Parameter executionRoleName :
The name of the IAM execution role to use to create the StackSet. If you
do not specify an execution role, CloudFormation uses the
AWSCloudFormationStackSetExecutionRole role for the StackSet
operation.
Specify an IAM role only if you are using customized execution roles to control which stack resources users and groups can include in their StackSets.
Valid only if the permissions model is SELF_MANAGED.
Parameter managedExecution :
Describes whether CloudFormation performs non-conflicting operations
concurrently and queues conflicting operations.
Parameter parameters :
The input parameters for the StackSet template.
Parameter permissionModel :
Describes how the IAM roles required for StackSet operations are created.
By default, SELF-MANAGED is specified.
-
With
self-managedpermissions, you must create the administrator and execution roles required to deploy to target accounts. For more information, see Grant self-managed permissions. -
With
service-managedpermissions, StackSets automatically creates the IAM roles required to deploy to accounts managed by Organizations. For more information, see Activate trusted access for StackSets with Organizations.
Parameter stackId :
The stack ID you are importing into a new StackSet. Specify the Amazon
Resource Name (ARN) of the stack.
Parameter tags :
The key-value pairs to associate with this StackSet and the stacks created
from it. CloudFormation also propagates these tags to supported resources
that are created in the stacks. A maximum number of 50 tags can be
specified.
If you specify tags as part of a CreateStackSet action,
CloudFormation checks to see if you have the required IAM permission to
tag resources. If you don't, the entire CreateStackSet action
fails with an access denied error, and the StackSet is not
created.
Parameter templateBody :
The structure that contains the template body, with a minimum length of 1
byte and a maximum length of 51,200 bytes.
Conditional: You must specify either the TemplateBody or the
TemplateURL parameter, but not both.
Parameter templateURL :
The URL of a file that contains the template body. The URL must point to a
template (maximum size: 1 MB) that's located in an Amazon S3 bucket or a
Systems Manager document. The location for an Amazon S3 bucket must start
with https://. S3 static website URLs are not supported.
Conditional: You must specify either the TemplateBody or the
TemplateURL parameter, but not both.
Implementation
Future<CreateStackSetOutput> createStackSet({
required String stackSetName,
String? administrationRoleARN,
AutoDeployment? autoDeployment,
CallAs? callAs,
List<Capability>? capabilities,
String? clientRequestToken,
String? description,
String? executionRoleName,
ManagedExecution? managedExecution,
List<Parameter>? parameters,
PermissionModels? permissionModel,
String? stackId,
List<Tag>? tags,
String? templateBody,
String? templateURL,
}) async {
final $request = <String, String>{
'StackSetName': stackSetName,
if (administrationRoleARN != null)
'AdministrationRoleARN': administrationRoleARN,
if (autoDeployment != null)
for (var e1 in autoDeployment.toQueryMap().entries)
'AutoDeployment.${e1.key}': e1.value,
if (callAs != null) 'CallAs': callAs.value,
if (capabilities != null)
if (capabilities.isEmpty)
'Capabilities': ''
else
for (var i1 = 0; i1 < capabilities.length; i1++)
'Capabilities.member.${i1 + 1}': capabilities[i1].value,
'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (executionRoleName != null) 'ExecutionRoleName': executionRoleName,
if (managedExecution != null)
for (var e1 in managedExecution.toQueryMap().entries)
'ManagedExecution.${e1.key}': e1.value,
if (parameters != null)
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.member.${i1 + 1}.${e3.key}': e3.value,
if (permissionModel != null) 'PermissionModel': permissionModel.value,
if (stackId != null) 'StackId': stackId,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
if (templateBody != null) 'TemplateBody': templateBody,
if (templateURL != null) 'TemplateURL': templateURL,
};
final $result = await _protocol.send(
$request,
action: 'CreateStackSet',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateStackSetResult',
);
return CreateStackSetOutput.fromXml($result);
}