deleteStackInstances method

Future<DeleteStackInstancesOutput> deleteStackInstances({
  1. required List<String> regions,
  2. required bool retainStacks,
  3. required String stackSetName,
  4. List<String>? accounts,
  5. CallAs? callAs,
  6. DeploymentTargets? deploymentTargets,
  7. String? operationId,
  8. StackSetOperationPreferences? operationPreferences,
})

Deletes stack instances for the specified accounts, in the specified Amazon Web Services Regions.

If you need more than 50, consider the following options:

  • Batch processing: If you don't want to expose your OU hierarchy, split up the operations into multiple calls with less than 50 OUs each.
  • Parent OU strategy: If you don't mind exposing the OU hierarchy, target a parent OU that contains all desired child OUs.

May throw InvalidOperationException. May throw OperationIdAlreadyExistsException. May throw OperationInProgressException. May throw StackSetNotFoundException. May throw StaleRequestException.

Parameter regions : The Amazon Web Services Regions where you want to delete StackSet instances.

Parameter retainStacks : Removes the stack instances from the specified StackSet, but doesn't delete the stacks. You can't reassociate a retained stack or add an existing, saved stack to a new stack set.

For more information, see StackSet operation options.

Parameter stackSetName : The name or unique ID of the StackSet that you want to delete stack instances for.

Parameter accounts : [Self-managed permissions] The account IDs of the Amazon Web Services accounts that you want to delete stack instances for.

You can specify Accounts or DeploymentTargets, but not both.

Parameter callAs : [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

  • If you are signed in to the management account, specify SELF.
  • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

    Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

Parameter deploymentTargets : [Service-managed permissions] The Organizations accounts from which to delete stack instances.

You can specify Accounts or DeploymentTargets, but not both.

Parameter operationId : The unique identifier for this StackSet operation.

If you don't specify an operation ID, the SDK generates one automatically.

The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the StackSet operation only once, even if you retry the request multiple times. You can retry StackSet operation requests to ensure that CloudFormation successfully received them.

Repeating this StackSet operation with a new operation ID retries all stack instances whose status is OUTDATED.

Parameter operationPreferences : Preferences for how CloudFormation performs this StackSet operation.

Implementation

Future<DeleteStackInstancesOutput> deleteStackInstances({
  required List<String> regions,
  required bool retainStacks,
  required String stackSetName,
  List<String>? accounts,
  CallAs? callAs,
  DeploymentTargets? deploymentTargets,
  String? operationId,
  StackSetOperationPreferences? operationPreferences,
}) async {
  final $request = <String, String>{
    if (regions.isEmpty)
      'Regions': ''
    else
      for (var i1 = 0; i1 < regions.length; i1++)
        'Regions.member.${i1 + 1}': regions[i1],
    'RetainStacks': retainStacks.toString(),
    'StackSetName': stackSetName,
    if (accounts != null)
      if (accounts.isEmpty)
        'Accounts': ''
      else
        for (var i1 = 0; i1 < accounts.length; i1++)
          'Accounts.member.${i1 + 1}': accounts[i1],
    if (callAs != null) 'CallAs': callAs.value,
    if (deploymentTargets != null)
      for (var e1 in deploymentTargets.toQueryMap().entries)
        'DeploymentTargets.${e1.key}': e1.value,
    'OperationId': operationId ?? _s.generateIdempotencyToken(),
    if (operationPreferences != null)
      for (var e1 in operationPreferences.toQueryMap().entries)
        'OperationPreferences.${e1.key}': e1.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteStackInstances',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteStackInstancesResult',
  );
  return DeleteStackInstancesOutput.fromXml($result);
}