describeChangeSet method

Future<DescribeChangeSetOutput> describeChangeSet({
  1. required String changeSetName,
  2. bool? includePropertyValues,
  3. String? nextToken,
  4. String? stackName,
})

Returns the inputs for the change set and a list of changes that CloudFormation will make if you execute the change set. For more information, see Update CloudFormation stacks using change sets in the CloudFormation User Guide.

May throw ChangeSetNotFoundException.

Parameter changeSetName : The name or Amazon Resource Name (ARN) of the change set that you want to describe.

Parameter includePropertyValues : If true, the returned changes include detailed changes in the property values.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Parameter stackName : If you specified the name of a change set, specify the stack name or ID (ARN) of the change set you want to describe.

Implementation

Future<DescribeChangeSetOutput> describeChangeSet({
  required String changeSetName,
  bool? includePropertyValues,
  String? nextToken,
  String? stackName,
}) async {
  final $request = <String, String>{
    'ChangeSetName': changeSetName,
    if (includePropertyValues != null)
      'IncludePropertyValues': includePropertyValues.toString(),
    if (nextToken != null) 'NextToken': nextToken,
    if (stackName != null) 'StackName': stackName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeChangeSet',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeChangeSetResult',
  );
  return DescribeChangeSetOutput.fromXml($result);
}