describeGeneratedTemplate method

Future<DescribeGeneratedTemplateOutput> describeGeneratedTemplate({
  1. required String generatedTemplateName,
})

Describes a generated template. The output includes details about the progress of the creation of a generated template started by a CreateGeneratedTemplate API action or the update of a generated template started with an UpdateGeneratedTemplate API action.

May throw GeneratedTemplateNotFoundException.

Parameter generatedTemplateName : The name or Amazon Resource Name (ARN) of a generated template.

Implementation

Future<DescribeGeneratedTemplateOutput> describeGeneratedTemplate({
  required String generatedTemplateName,
}) async {
  final $request = <String, String>{
    'GeneratedTemplateName': generatedTemplateName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeGeneratedTemplate',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeGeneratedTemplateResult',
  );
  return DescribeGeneratedTemplateOutput.fromXml($result);
}