describeOrganizationsAccess method
Retrieves information about the account's OrganizationAccess
status. This API can be called either by the management account or the
delegated administrator by using the CallAs parameter. This
API can also be called without the CallAs parameter by the
management account.
May throw InvalidOperationException.
May throw OperationNotFoundException.
Parameter callAs :
[Service-managed permissions] Specifies whether you are acting as an
account administrator in the organization's management account or as a
delegated administrator in a member account.
By default, SELF is specified.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
Implementation
Future<DescribeOrganizationsAccessOutput> describeOrganizationsAccess({
CallAs? callAs,
}) async {
final $request = <String, String>{
if (callAs != null) 'CallAs': callAs.value,
};
final $result = await _protocol.send(
$request,
action: 'DescribeOrganizationsAccess',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeOrganizationsAccessResult',
);
return DescribeOrganizationsAccessOutput.fromXml($result);
}