describePublisher method

Future<DescribePublisherOutput> describePublisher({
  1. String? publisherId,
})

Returns information about a CloudFormation extension publisher.

If you don't supply a PublisherId, and you have registered as an extension publisher, DescribePublisher returns information about your own publisher account.

For more information about registering as a publisher, see:

May throw CFNRegistryException.

Parameter publisherId : The ID of the extension publisher.

If you don't supply a PublisherId, and you have registered as an extension publisher, DescribePublisher returns information about your own publisher account.

Implementation

Future<DescribePublisherOutput> describePublisher({
  String? publisherId,
}) async {
  final $request = <String, String>{
    if (publisherId != null) 'PublisherId': publisherId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribePublisher',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribePublisherResult',
  );
  return DescribePublisherOutput.fromXml($result);
}