describeStackEvents method

Future<DescribeStackEventsOutput> describeStackEvents({
  1. required String stackName,
  2. String? nextToken,
})

Returns all stack related events for a specified stack in reverse chronological order. For more information about a stack's event history, see Understand CloudFormation stack creation events in the CloudFormation User Guide.

Parameter stackName : The name or the unique stack ID that's associated with the stack, which aren't always interchangeable:

  • Running stacks: You can specify either the stack's name or its unique stack ID.
  • Deleted stacks: You must specify the unique stack ID.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<DescribeStackEventsOutput> describeStackEvents({
  required String stackName,
  String? nextToken,
}) async {
  final $request = <String, String>{
    'StackName': stackName,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeStackEvents',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeStackEventsResult',
  );
  return DescribeStackEventsOutput.fromXml($result);
}