detectStackDrift method
Detects whether a stack's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For each resource in the stack that supports drift detection, CloudFormation compares the actual configuration of the resource with its expected template configuration. Only resource properties explicitly defined in the stack template are checked for drift. A stack is considered to have drifted if one or more of its resources differ from their expected template configurations. For more information, see Detect unmanaged configuration changes to stacks and resources with drift detection.
Use DetectStackDrift to detect drift on all supported
resources for a given stack, or DetectStackResourceDrift to detect
drift on individual resources.
For a list of stack resources that currently support drift detection, see Resource type support for imports and drift detection.
DetectStackDrift can take up to several minutes, depending on
the number of resources contained within the stack. Use
DescribeStackDriftDetectionStatus to monitor the progress of a
detect stack drift operation. Once the drift detection operation has
completed, use DescribeStackResourceDrifts to return drift
information about the stack and its resources.
When detecting drift on a stack, CloudFormation doesn't detect drift on
any nested stacks belonging to that stack. Perform
DetectStackDrift directly on the nested stack itself.
Parameter stackName :
The name of the stack for which you want to detect drift.
Parameter logicalResourceIds :
The logical names of any resources you want to use as filters.
Implementation
Future<DetectStackDriftOutput> detectStackDrift({
required String stackName,
List<String>? logicalResourceIds,
}) async {
final $request = <String, String>{
'StackName': stackName,
if (logicalResourceIds != null)
if (logicalResourceIds.isEmpty)
'LogicalResourceIds': ''
else
for (var i1 = 0; i1 < logicalResourceIds.length; i1++)
'LogicalResourceIds.member.${i1 + 1}': logicalResourceIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'DetectStackDrift',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DetectStackDriftResult',
);
return DetectStackDriftOutput.fromXml($result);
}