executeChangeSet method
Updates a stack using the input information that was provided when the specified change set was created. After the call successfully completes, CloudFormation starts updating the stack. Use the DescribeStacks action to view the status of the update.
When you execute a change set, CloudFormation deletes all other change sets associated with the stack because they aren't valid for the updated stack.
If a stack policy is associated with the stack, CloudFormation enforces the policy during the update. You can't specify a temporary stack policy that overrides the current policy.
To create a change set for the entire stack hierarchy,
IncludeNestedStacks must have been set to True.
May throw ChangeSetNotFoundException.
May throw InsufficientCapabilitiesException.
May throw InvalidChangeSetStatusException.
May throw TokenAlreadyExistsException.
Parameter changeSetName :
The name or Amazon Resource Name (ARN) of the change set that you want use
to update the specified stack.
Parameter clientRequestToken :
A unique identifier for this ExecuteChangeSet request.
Specify this token if you plan to retry requests so that CloudFormation
knows that you're not attempting to execute a change set to update a stack
with the same name. You might retry ExecuteChangeSet requests
to ensure that CloudFormation successfully received them.
Parameter disableRollback :
Preserves the state of previously provisioned resources when an operation
fails. This parameter can't be specified when the
OnStackFailure parameter to the CreateChangeSet
API operation was specified.
-
True- if the stack creation fails, do nothing. This is equivalent to specifyingDO_NOTHINGfor theOnStackFailureparameter to the CreateChangeSet API operation. -
False- if the stack creation fails, roll back the stack. This is equivalent to specifyingROLLBACKfor theOnStackFailureparameter to the CreateChangeSet API operation.
True
Parameter retainExceptOnCreate :
When set to true, newly created resources are deleted when
the operation rolls back. This includes newly created resources marked
with a deletion policy of Retain.
Default: false
Parameter stackName :
If you specified the name of a change set, specify the stack name or
Amazon Resource Name (ARN) that's associated with the change set you want
to execute.
Implementation
Future<void> executeChangeSet({
required String changeSetName,
String? clientRequestToken,
bool? disableRollback,
bool? retainExceptOnCreate,
String? stackName,
}) async {
final $request = <String, String>{
'ChangeSetName': changeSetName,
if (clientRequestToken != null) 'ClientRequestToken': clientRequestToken,
if (disableRollback != null)
'DisableRollback': disableRollback.toString(),
if (retainExceptOnCreate != null)
'RetainExceptOnCreate': retainExceptOnCreate.toString(),
if (stackName != null) 'StackName': stackName,
};
await _protocol.send(
$request,
action: 'ExecuteChangeSet',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ExecuteChangeSetResult',
);
}