getHookResult method

Future<GetHookResultOutput> getHookResult({
  1. String? hookResultId,
})

Retrieves detailed information and remediation guidance for a Hook invocation result.

If the Hook uses a KMS key to encrypt annotations, callers of the GetHookResult operation must have kms:Decrypt permissions. For more information, see KMS key policy and permissions for encrypting CloudFormation Hooks results at rest in the CloudFormation Hooks User Guide.

May throw HookResultNotFoundException.

Parameter hookResultId : The unique identifier (ID) of the Hook invocation result that you want details about. You can get the ID from the ListHookResults operation.

Implementation

Future<GetHookResultOutput> getHookResult({
  String? hookResultId,
}) async {
  final $request = <String, String>{
    if (hookResultId != null) 'HookResultId': hookResultId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'GetHookResult',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'GetHookResultResult',
  );
  return GetHookResultOutput.fromXml($result);
}