getTemplate method
Returns the template body for a specified stack. You can get the template for running or deleted stacks.
For deleted stacks, GetTemplate returns the template for up
to 90 days after the stack has been deleted.
May throw ChangeSetNotFoundException.
Parameter changeSetName :
The name or Amazon Resource Name (ARN) of a change set for which
CloudFormation returns the associated template. If you specify a name, you
must also specify the StackName.
Parameter stackName :
The name or the unique stack ID that's associated with the stack, which
aren't always interchangeable:
- Running stacks: You can specify either the stack's name or its unique stack ID.
- Deleted stacks: You must specify the unique stack ID.
Parameter templateStage :
For templates that include transforms, the stage of the template that
CloudFormation returns. To get the user-submitted template, specify
Original. To get the template after CloudFormation has
processed all transforms, specify Processed.
If the template doesn't include transforms, Original and
Processed return the same template. By default,
CloudFormation specifies Processed.
Implementation
Future<GetTemplateOutput> getTemplate({
String? changeSetName,
String? stackName,
TemplateStage? templateStage,
}) async {
final $request = <String, String>{
if (changeSetName != null) 'ChangeSetName': changeSetName,
if (stackName != null) 'StackName': stackName,
if (templateStage != null) 'TemplateStage': templateStage.value,
};
final $result = await _protocol.send(
$request,
action: 'GetTemplate',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetTemplateResult',
);
return GetTemplateOutput.fromXml($result);
}