listStackRefactorActions method

Future<ListStackRefactorActionsOutput> listStackRefactorActions({
  1. required String stackRefactorId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the stack refactor actions that will be taken after calling the ExecuteStackRefactor action.

Parameter stackRefactorId : The ID associated with the stack refactor created from the CreateStackRefactor action.

Parameter maxResults : The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<ListStackRefactorActionsOutput> listStackRefactorActions({
  required String stackRefactorId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $request = <String, String>{
    'StackRefactorId': stackRefactorId,
    if (maxResults != null) 'MaxResults': maxResults.toString(),
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListStackRefactorActions',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListStackRefactorActionsResult',
  );
  return ListStackRefactorActionsOutput.fromXml($result);
}