listStackResources method

Future<ListStackResourcesOutput> listStackResources({
  1. required String stackName,
  2. String? nextToken,
})

Returns descriptions of all resources of the specified stack.

For deleted stacks, ListStackResources returns resource information for up to 90 days after the stack has been deleted.

Parameter stackName : The name or the unique stack ID that is associated with the stack, which aren't always interchangeable:

  • Running stacks: You can specify either the stack's name or its unique stack ID.
  • Deleted stacks: You must specify the unique stack ID.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<ListStackResourcesOutput> listStackResources({
  required String stackName,
  String? nextToken,
}) async {
  final $request = <String, String>{
    'StackName': stackName,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListStackResources',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListStackResourcesResult',
  );
  return ListStackResourcesOutput.fromXml($result);
}