listStackSetAutoDeploymentTargets method

Future<ListStackSetAutoDeploymentTargetsOutput> listStackSetAutoDeploymentTargets({
  1. required String stackSetName,
  2. CallAs? callAs,
  3. int? maxResults,
  4. String? nextToken,
})

Returns summary information about deployment targets for a StackSet.

May throw StackSetNotFoundException.

Parameter stackSetName : The name or unique ID of the StackSet that you want to get automatic deployment targets for.

Parameter callAs : Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

  • If you are signed in to the management account, specify SELF.
  • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

    Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

Parameter maxResults : The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<ListStackSetAutoDeploymentTargetsOutput>
    listStackSetAutoDeploymentTargets({
  required String stackSetName,
  CallAs? callAs,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $request = <String, String>{
    'StackSetName': stackSetName,
    if (callAs != null) 'CallAs': callAs.value,
    if (maxResults != null) 'MaxResults': maxResults.toString(),
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListStackSetAutoDeploymentTargets',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListStackSetAutoDeploymentTargetsResult',
  );
  return ListStackSetAutoDeploymentTargetsOutput.fromXml($result);
}