updateStack method
- required String stackName,
- List<
Capability> ? capabilities, - String? clientRequestToken,
- bool? disableRollback,
- List<
String> ? notificationARNs, - List<
Parameter> ? parameters, - List<
String> ? resourceTypes, - bool? retainExceptOnCreate,
- String? roleARN,
- RollbackConfiguration? rollbackConfiguration,
- String? stackPolicyBody,
- String? stackPolicyDuringUpdateBody,
- String? stackPolicyDuringUpdateURL,
- String? stackPolicyURL,
- List<
Tag> ? tags, - String? templateBody,
- String? templateURL,
- bool? usePreviousTemplate,
Updates a stack as specified in the template. After the call completes successfully, the stack update starts. You can check the status of the stack through the DescribeStacks action.
To get a copy of the template for an existing stack, you can use the GetTemplate action.
For more information about updating a stack and monitoring the progress of the update, see Managing Amazon Web Services resources as a single unit with CloudFormation stacks in the CloudFormation User Guide.
May throw InsufficientCapabilitiesException.
May throw TokenAlreadyExistsException.
Parameter stackName :
The name or unique stack ID of the stack to update.
Parameter capabilities :
In some cases, you must explicitly acknowledge that your stack template
contains certain capabilities in order for CloudFormation to update the
stack.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account, for example, by creating new IAM users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability.- If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns
an
InsufficientCapabilitieserror.
- AWS::IAM::AccessKey
- AWS::IAM::Group
- AWS::IAM::InstanceProfile
- AWS::IAM::ManagedPolicy
- AWS::IAM::Policy
- AWS::IAM::Role
- AWS::IAM::User
- AWS::IAM::UserToGroupAddition
-
CAPABILITY_AUTO_EXPANDSome template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually updating the stack. If your stack template contains one or more macros, and you choose to update a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.
If you want to update a stack from a stack template that contains macros and nested stacks, you must update the stack directly from the template using this capability.
Each macro relies on an underlying Lambda service function for processing stack templates. Be aware that the Lambda function owner can update the function operation without CloudFormation being notified. For more information, see Perform custom processing on CloudFormation templates with template macros.
Parameter clientRequestToken :
A unique identifier for this UpdateStack request. Specify
this token if you plan to retry requests so that CloudFormation knows that
you're not attempting to update a stack with the same name. You might
retry UpdateStack requests to ensure that CloudFormation
successfully received them.
All events triggered by a given stack operation are assigned the same
client request token, which you can use to track operations. For example,
if you execute a CreateStack operation with the token
token1, then all the StackEvents generated by
that operation will have ClientRequestToken set as
token1.
In the console, stack operations display the client request token on the
Events tab. Stack operations that are initiated from the console use the
token format Console-StackOperation-ID, which helps you easily
identify the stack operation . For example, if you create a stack using
the console, each stack event would be assigned the same token in the
following format:
Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002.
Parameter disableRollback :
Preserve the state of previously provisioned resources when an operation
fails.
Default: False
Parameter notificationARNs :
Amazon Simple Notification Service topic Amazon Resource Names (ARNs) that
CloudFormation associates with the stack. Specify an empty list to remove
all notification topics.
Parameter parameters :
A list of Parameter structures that specify input parameters
for the stack. For more information, see the Parameter
data type.
Parameter resourceTypes :
Specifies which resource types you can work with, such as
AWS::EC2::Instance or Custom::MyCustomInstance.
If the list of resource types doesn't include a resource that you're updating, the stack update fails. By default, CloudFormation grants permissions to all resource types. IAM uses this parameter for CloudFormation-specific condition keys in IAM policies. For more information, see Control CloudFormation access with Identity and Access Management.
Parameter retainExceptOnCreate :
When set to true, newly created resources are deleted when
the operation rolls back. This includes newly created resources marked
with a deletion policy of Retain.
Default: false
Parameter roleARN :
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes
to update the stack. CloudFormation uses the role's credentials to make
calls on your behalf. CloudFormation always uses this role for all future
operations on the stack. Provided that users have permission to operate on
the stack, CloudFormation uses this role even if the users don't have
permission to pass it. Ensure that the role grants least privilege.
If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials.
Parameter rollbackConfiguration :
The rollback triggers for CloudFormation to monitor during stack creation
and updating operations, and for the specified monitoring period
afterwards.
Parameter stackPolicyBody :
Structure that contains a new stack policy body. You can specify either
the StackPolicyBody or the StackPolicyURL
parameter, but not both.
You might update the stack policy, for example, in order to protect a new resource that you created during a stack update. If you don't specify a stack policy, the current policy that is associated with the stack is unchanged.
Parameter stackPolicyDuringUpdateBody :
Structure that contains the temporary overriding stack policy body. You
can specify either the StackPolicyDuringUpdateBody or the
StackPolicyDuringUpdateURL parameter, but not both.
If you want to update protected resources, specify a temporary overriding stack policy during this update. If you don't specify a stack policy, the current policy that is associated with the stack will be used.
Parameter stackPolicyDuringUpdateURL :
Location of a file that contains the temporary overriding stack policy.
The URL must point to a policy (max size: 16KB) located in an S3 bucket in
the same Region as the stack. The location for an Amazon S3 bucket must
start with https://. URLs from S3 static websites are not
supported.
You can specify either the StackPolicyDuringUpdateBody or the
StackPolicyDuringUpdateURL parameter, but not both.
If you want to update protected resources, specify a temporary overriding stack policy during this update. If you don't specify a stack policy, the current policy that is associated with the stack will be used.
Parameter stackPolicyURL :
Location of a file that contains the updated stack policy. The URL must
point to a policy (max size: 16KB) located in an S3 bucket in the same
Region as the stack. The location for an Amazon S3 bucket must start with
https://. URLs from S3 static websites are not supported.
You can specify either the StackPolicyBody or the
StackPolicyURL parameter, but not both.
You might update the stack policy, for example, in order to protect a new resource that you created during a stack update. If you don't specify a stack policy, the current policy that is associated with the stack is unchanged.
Parameter tags :
Key-value pairs to associate with this stack. CloudFormation also
propagates these tags to supported resources in the stack. You can specify
a maximum number of 50 tags.
If you don't specify this parameter, CloudFormation doesn't modify the stack's tags. If you specify an empty value, CloudFormation removes all associated tags.
Parameter templateBody :
Structure that contains the template body with a minimum length of 1 byte
and a maximum length of 51,200 bytes.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Parameter templateURL :
The URL of a file that contains the template body. The URL must point to a
template that's located in an Amazon S3 bucket or a Systems Manager
document. The location for an Amazon S3 bucket must start with
https://.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Parameter usePreviousTemplate :
Reuse the existing template that is associated with the stack that you are
updating.
When using templates with the AWS::LanguageExtensions
transform, provide the template instead of using
UsePreviousTemplate to ensure new parameter values and
Systems Manager parameter updates are applied correctly. For more
information, see AWS::LanguageExtensions
transform.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the
UsePreviousTemplate to true.
Implementation
Future<UpdateStackOutput> updateStack({
required String stackName,
List<Capability>? capabilities,
String? clientRequestToken,
bool? disableRollback,
List<String>? notificationARNs,
List<Parameter>? parameters,
List<String>? resourceTypes,
bool? retainExceptOnCreate,
String? roleARN,
RollbackConfiguration? rollbackConfiguration,
String? stackPolicyBody,
String? stackPolicyDuringUpdateBody,
String? stackPolicyDuringUpdateURL,
String? stackPolicyURL,
List<Tag>? tags,
String? templateBody,
String? templateURL,
bool? usePreviousTemplate,
}) async {
final $request = <String, String>{
'StackName': stackName,
if (capabilities != null)
if (capabilities.isEmpty)
'Capabilities': ''
else
for (var i1 = 0; i1 < capabilities.length; i1++)
'Capabilities.member.${i1 + 1}': capabilities[i1].value,
if (clientRequestToken != null) 'ClientRequestToken': clientRequestToken,
if (disableRollback != null)
'DisableRollback': disableRollback.toString(),
if (notificationARNs != null)
if (notificationARNs.isEmpty)
'NotificationARNs': ''
else
for (var i1 = 0; i1 < notificationARNs.length; i1++)
'NotificationARNs.member.${i1 + 1}': notificationARNs[i1],
if (parameters != null)
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.member.${i1 + 1}.${e3.key}': e3.value,
if (resourceTypes != null)
if (resourceTypes.isEmpty)
'ResourceTypes': ''
else
for (var i1 = 0; i1 < resourceTypes.length; i1++)
'ResourceTypes.member.${i1 + 1}': resourceTypes[i1],
if (retainExceptOnCreate != null)
'RetainExceptOnCreate': retainExceptOnCreate.toString(),
if (roleARN != null) 'RoleARN': roleARN,
if (rollbackConfiguration != null)
for (var e1 in rollbackConfiguration.toQueryMap().entries)
'RollbackConfiguration.${e1.key}': e1.value,
if (stackPolicyBody != null) 'StackPolicyBody': stackPolicyBody,
if (stackPolicyDuringUpdateBody != null)
'StackPolicyDuringUpdateBody': stackPolicyDuringUpdateBody,
if (stackPolicyDuringUpdateURL != null)
'StackPolicyDuringUpdateURL': stackPolicyDuringUpdateURL,
if (stackPolicyURL != null) 'StackPolicyURL': stackPolicyURL,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
if (templateBody != null) 'TemplateBody': templateBody,
if (templateURL != null) 'TemplateURL': templateURL,
if (usePreviousTemplate != null)
'UsePreviousTemplate': usePreviousTemplate.toString(),
};
final $result = await _protocol.send(
$request,
action: 'UpdateStack',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdateStackResult',
);
return UpdateStackOutput.fromXml($result);
}