createAnycastIpList method

Future<CreateAnycastIpListResult> createAnycastIpList({
  1. required int ipCount,
  2. required String name,
  3. IpAddressType? ipAddressType,
  4. List<IpamCidrConfig>? ipamCidrConfigs,
  5. Tags? tags,
})

Creates an Anycast static IP list.

May throw AccessDenied. May throw EntityAlreadyExists. May throw EntityLimitExceeded. May throw InvalidArgument. May throw InvalidTagging. May throw UnsupportedOperation.

Parameter ipCount : The number of static IP addresses that are allocated to the Anycast static IP list. Valid values: 21 or 3.

Parameter name : Name of the Anycast static IP list.

Parameter ipAddressType : The IP address type for the Anycast static IP list. You can specify one of the following options:

  • ipv4 only
  • ipv6 only
  • dualstack - Allocate a list of both IPv4 and IPv6 addresses

Parameter ipamCidrConfigs : A list of IPAM CIDR configurations that specify the IP address ranges and IPAM pool settings for creating the Anycast static IP list.

Implementation

Future<CreateAnycastIpListResult> createAnycastIpList({
  required int ipCount,
  required String name,
  IpAddressType? ipAddressType,
  List<IpamCidrConfig>? ipamCidrConfigs,
  Tags? tags,
}) async {
  final $result = await _protocol.sendRaw(
    method: 'POST',
    requestUri: '/2020-05-31/anycast-ip-list',
    payload: CreateAnycastIpListRequest(
            ipCount: ipCount,
            name: name,
            ipAddressType: ipAddressType,
            ipamCidrConfigs: ipamCidrConfigs,
            tags: tags)
        .toXml('CreateAnycastIpListRequest'),
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return CreateAnycastIpListResult(
    anycastIpList: AnycastIpList.fromXml($elem),
    eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
  );
}