createConnectionGroup method

Future<CreateConnectionGroupResult> createConnectionGroup({
  1. required String name,
  2. String? anycastIpListId,
  3. bool? enabled,
  4. bool? ipv6Enabled,
  5. Tags? tags,
})

Creates a connection group.

May throw AccessDenied. May throw EntityAlreadyExists. May throw EntityLimitExceeded. May throw EntityNotFound. May throw InvalidArgument. May throw InvalidTagging.

Parameter name : The name of the connection group. Enter a friendly identifier that is unique within your Amazon Web Services account. This name can't be updated after you create the connection group.

Parameter anycastIpListId : The ID of the Anycast static IP list.

Parameter enabled : Enable the connection group.

Parameter ipv6Enabled : Enable IPv6 for the connection group. The default is true. For more information, see Enable IPv6 in the Amazon CloudFront Developer Guide.

Implementation

Future<CreateConnectionGroupResult> createConnectionGroup({
  required String name,
  String? anycastIpListId,
  bool? enabled,
  bool? ipv6Enabled,
  Tags? tags,
}) async {
  final $result = await _protocol.sendRaw(
    method: 'POST',
    requestUri: '/2020-05-31/connection-group',
    payload: CreateConnectionGroupRequest(
            name: name,
            anycastIpListId: anycastIpListId,
            enabled: enabled,
            ipv6Enabled: ipv6Enabled,
            tags: tags)
        .toXml('CreateConnectionGroupRequest'),
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return CreateConnectionGroupResult(
    connectionGroup: ConnectionGroup.fromXml($elem),
    eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
  );
}