deleteDistributionTenant method

Future<void> deleteDistributionTenant({
  1. required String id,
  2. required String ifMatch,
})

Deletes a distribution tenant. If you use this API operation to delete a distribution tenant that is currently enabled, the request will fail.

To delete a distribution tenant, you must first disable the distribution tenant by using the UpdateDistributionTenant API operation.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidIfMatchVersion. May throw PreconditionFailed. May throw ResourceNotDisabled.

Parameter id : The ID of the distribution tenant to delete.

Parameter ifMatch : The value of the ETag header that you received when retrieving the distribution tenant. This value is returned in the response of the GetDistributionTenant API operation.

Implementation

Future<void> deleteDistributionTenant({
  required String id,
  required String ifMatch,
}) async {
  final headers = <String, String>{
    'If-Match': ifMatch.toString(),
  };
  await _protocol.send(
    method: 'DELETE',
    requestUri: '/2020-05-31/distribution-tenant/${Uri.encodeComponent(id)}',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}