deleteResponseHeadersPolicy method
Deletes a response headers policy.
You cannot delete a response headers policy if it's attached to a cache behavior. First update your distributions to remove the response headers policy from all cache behaviors, then delete the response headers policy.
To delete a response headers policy, you must provide the policy's
identifier and version. To get these values, you can use
ListResponseHeadersPolicies or
GetResponseHeadersPolicy.
May throw AccessDenied.
May throw IllegalDelete.
May throw InvalidIfMatchVersion.
May throw NoSuchResponseHeadersPolicy.
May throw PreconditionFailed.
May throw ResponseHeadersPolicyInUse.
Parameter id :
The identifier for the response headers policy that you are deleting.
To get the identifier, you can use
ListResponseHeadersPolicies.
Parameter ifMatch :
The version of the response headers policy that you are deleting.
The version is the response headers policy's ETag value,
which you can get using ListResponseHeadersPolicies,
GetResponseHeadersPolicy, or
GetResponseHeadersPolicyConfig.
Implementation
Future<void> deleteResponseHeadersPolicy({
required String id,
String? ifMatch,
}) async {
final headers = <String, String>{
if (ifMatch != null) 'If-Match': ifMatch.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri:
'/2020-05-31/response-headers-policy/${Uri.encodeComponent(id)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}