disassociateDistributionTenantWebACL method

Future<DisassociateDistributionTenantWebACLResult> disassociateDistributionTenantWebACL({
  1. required String id,
  2. String? ifMatch,
})

Disassociates a distribution tenant from the WAF web ACL.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidArgument. May throw InvalidIfMatchVersion. May throw PreconditionFailed.

Parameter id : The ID of the distribution tenant.

Parameter ifMatch : The current version of the distribution tenant that you're disassociating from the WAF web ACL. This is the ETag value returned in the response to the GetDistributionTenant API operation.

Implementation

Future<DisassociateDistributionTenantWebACLResult>
    disassociateDistributionTenantWebACL({
  required String id,
  String? ifMatch,
}) async {
  final headers = <String, String>{
    if (ifMatch != null) 'If-Match': ifMatch.toString(),
  };
  final $result = await _protocol.sendRaw(
    method: 'PUT',
    requestUri:
        '/2020-05-31/distribution-tenant/${Uri.encodeComponent(id)}/disassociate-web-acl',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return DisassociateDistributionTenantWebACLResult(
    id: _s.extractXmlStringValue($elem, 'Id'),
    eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
  );
}