listConnectionFunctions method

Future<ListConnectionFunctionsResult> listConnectionFunctions({
  1. String? marker,
  2. int? maxItems,
  3. FunctionStage? stage,
})

Lists connection functions.

May throw AccessDenied. May throw InvalidArgument. May throw UnsupportedOperation.

Parameter marker : Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Parameter maxItems : The maximum number of connection functions that you want returned in the response.

Parameter stage : The connection function's stage.

Implementation

Future<ListConnectionFunctionsResult> listConnectionFunctions({
  String? marker,
  int? maxItems,
  FunctionStage? stage,
}) async {
  final $result = await _protocol.send(
    method: 'POST',
    requestUri: '/2020-05-31/connection-functions',
    payload: ListConnectionFunctionsRequest(
            marker: marker, maxItems: maxItems, stage: stage)
        .toXml('ListConnectionFunctionsRequest'),
    exceptionFnMap: _exceptionFns,
  );
  return ListConnectionFunctionsResult.fromXml($result.body);
}