listDistributionsByAnycastIpListId method

Future<ListDistributionsByAnycastIpListIdResult> listDistributionsByAnycastIpListId({
  1. required String anycastIpListId,
  2. String? marker,
  3. int? maxItems,
})

Lists the distributions in your account that are associated with the specified AnycastIpListId.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidArgument. May throw UnsupportedOperation.

Parameter anycastIpListId : The ID of the Anycast static IP list.

Parameter marker : Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Parameter maxItems : The maximum number of distributions that you want returned in the response.

Implementation

Future<ListDistributionsByAnycastIpListIdResult>
    listDistributionsByAnycastIpListId({
  required String anycastIpListId,
  String? marker,
  int? maxItems,
}) async {
  final $query = <String, List<String>>{
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri:
        '/2020-05-31/distributionsByAnycastIpListId/${Uri.encodeComponent(anycastIpListId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return ListDistributionsByAnycastIpListIdResult(
    distributionList: DistributionList.fromXml($elem),
  );
}