listDistributionsByConnectionFunction method

Future<ListDistributionsByConnectionFunctionResult> listDistributionsByConnectionFunction({
  1. required String connectionFunctionIdentifier,
  2. String? marker,
  3. int? maxItems,
})

Lists distributions by connection function.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidArgument.

Parameter connectionFunctionIdentifier : The distributions by connection function identifier.

Parameter marker : Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Parameter maxItems : The maximum number of distributions that you want returned in the response.

Implementation

Future<ListDistributionsByConnectionFunctionResult>
    listDistributionsByConnectionFunction({
  required String connectionFunctionIdentifier,
  String? marker,
  int? maxItems,
}) async {
  final $query = <String, List<String>>{
    'ConnectionFunctionIdentifier': [connectionFunctionIdentifier],
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri: '/2020-05-31/distributionsByConnectionFunction',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return ListDistributionsByConnectionFunctionResult(
    distributionList: DistributionList.fromXml($elem),
  );
}