listDistributionsByResponseHeadersPolicyId method
Gets a list of distribution IDs for distributions that have a cache behavior that's associated with the specified response headers policy.
You can optionally specify the maximum number of items to receive in the
response. If the total number of items in the list exceeds the maximum
that you specify, or the default maximum, the response is paginated. To
get the next page of items, send a subsequent request that specifies the
NextMarker value from the current response as the
Marker value in the subsequent request.
May throw AccessDenied.
May throw InvalidArgument.
May throw NoSuchResponseHeadersPolicy.
Parameter responseHeadersPolicyId :
The ID of the response headers policy whose associated distribution IDs
you want to list.
Parameter marker :
Use this field when paginating results to indicate where to begin in your
list of distribution IDs. The response includes distribution IDs in the
list that occur after the marker. To get the next page of the list, set
this field's value to the value of NextMarker from the
current page's response.
Parameter maxItems :
The maximum number of distribution IDs that you want to get in the
response.
Implementation
Future<ListDistributionsByResponseHeadersPolicyIdResult>
listDistributionsByResponseHeadersPolicyId({
required String responseHeadersPolicyId,
String? marker,
int? maxItems,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri:
'/2020-05-31/distributionsByResponseHeadersPolicyId/${Uri.encodeComponent(responseHeadersPolicyId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListDistributionsByResponseHeadersPolicyIdResult(
distributionIdList: DistributionIdList.fromXml($elem),
);
}