listDistributionsByTrustStore method

Future<ListDistributionsByTrustStoreResult> listDistributionsByTrustStore({
  1. required String trustStoreIdentifier,
  2. String? marker,
  3. int? maxItems,
})

Lists distributions by trust store.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidArgument.

Parameter trustStoreIdentifier : The distributions by trust store identifier.

Parameter marker : Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Parameter maxItems : The maximum number of distributions that you want returned in the response.

Implementation

Future<ListDistributionsByTrustStoreResult> listDistributionsByTrustStore({
  required String trustStoreIdentifier,
  String? marker,
  int? maxItems,
}) async {
  final $query = <String, List<String>>{
    'TrustStoreIdentifier': [trustStoreIdentifier],
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri: '/2020-05-31/distributionsByTrustStore',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return ListDistributionsByTrustStoreResult(
    distributionList: DistributionList.fromXml($elem),
  );
}