listInvalidationsForDistributionTenant method
Lists the invalidations for a distribution tenant.
May throw AccessDenied.
May throw EntityNotFound.
May throw InvalidArgument.
Parameter id :
The ID of the distribution tenant.
Parameter marker :
Use this parameter when paginating results to indicate where to begin in
your list of invalidation batches. Because the results are returned in
decreasing order from most recent to oldest, the most recent results are
on the first page, the second page will contain earlier results, and so
on. To get the next page of results, set Marker to the value
of the NextMarker from the current page's response. This
value is the same as the ID of the last invalidation batch on that page.
Parameter maxItems :
The maximum number of invalidations to return for the distribution tenant.
Implementation
Future<ListInvalidationsForDistributionTenantResult>
listInvalidationsForDistributionTenant({
required String id,
String? marker,
int? maxItems,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri:
'/2020-05-31/distribution-tenant/${Uri.encodeComponent(id)}/invalidation',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListInvalidationsForDistributionTenantResult(
invalidationList: InvalidationList.fromXml($elem),
);
}