listKeyValueStores method

Future<ListKeyValueStoresResult> listKeyValueStores({
  1. String? marker,
  2. int? maxItems,
  3. String? status,
})

Specifies the key value stores to list.

May throw AccessDenied. May throw InvalidArgument. May throw UnsupportedOperation.

Parameter marker : The marker associated with the key value stores list.

Parameter maxItems : The maximum number of items in the key value stores list.

Parameter status : The status of the request for the key value stores list.

Implementation

Future<ListKeyValueStoresResult> listKeyValueStores({
  String? marker,
  int? maxItems,
  String? status,
}) async {
  final $query = <String, List<String>>{
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
    if (status != null) 'Status': [status],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri: '/2020-05-31/key-value-store',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return ListKeyValueStoresResult(
    keyValueStoreList: KeyValueStoreList.fromXml($elem),
  );
}