listOriginRequestPolicies method
Gets a list of origin request policies.
You can optionally apply a filter to return only the managed policies created by Amazon Web Services, or only the custom policies created in your Amazon Web Services account.
You can optionally specify the maximum number of items to receive in the
response. If the total number of items in the list exceeds the maximum
that you specify, or the default maximum, the response is paginated. To
get the next page of items, send a subsequent request that specifies the
NextMarker value from the current response as the
Marker value in the subsequent request.
May throw AccessDenied.
May throw InvalidArgument.
May throw NoSuchOriginRequestPolicy.
Parameter marker :
Use this field when paginating results to indicate where to begin in your
list of origin request policies. The response includes origin request
policies in the list that occur after the marker. To get the next page of
the list, set this field's value to the value of NextMarker
from the current page's response.
Parameter maxItems :
The maximum number of origin request policies that you want in the
response.
Parameter type :
A filter to return only the specified kinds of origin request policies.
Valid values are:
-
managed– Returns only the managed policies created by Amazon Web Services. -
custom– Returns only the custom policies created in your Amazon Web Services account.
Implementation
Future<ListOriginRequestPoliciesResult> listOriginRequestPolicies({
String? marker,
int? maxItems,
OriginRequestPolicyType? type,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
if (type != null) 'Type': [type.value],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/2020-05-31/origin-request-policy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListOriginRequestPoliciesResult(
originRequestPolicyList: OriginRequestPolicyList.fromXml($elem),
);
}