listResponseHeadersPolicies method
Gets a list of response headers policies.
You can optionally apply a filter to get only the managed policies created by Amazon Web Services, or only the custom policies created in your Amazon Web Services account.
You can optionally specify the maximum number of items to receive in the
response. If the total number of items in the list exceeds the maximum
that you specify, or the default maximum, the response is paginated. To
get the next page of items, send a subsequent request that specifies the
NextMarker value from the current response as the
Marker value in the subsequent request.
May throw AccessDenied.
May throw InvalidArgument.
May throw NoSuchResponseHeadersPolicy.
Parameter marker :
Use this field when paginating results to indicate where to begin in your
list of response headers policies. The response includes response headers
policies in the list that occur after the marker. To get the next page of
the list, set this field's value to the value of NextMarker
from the current page's response.
Parameter maxItems :
The maximum number of response headers policies that you want to get in
the response.
Parameter type :
A filter to get only the specified kind of response headers policies.
Valid values are:
-
managed– Gets only the managed policies created by Amazon Web Services. -
custom– Gets only the custom policies created in your Amazon Web Services account.
Implementation
Future<ListResponseHeadersPoliciesResult> listResponseHeadersPolicies({
String? marker,
int? maxItems,
ResponseHeadersPolicyType? type,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
if (type != null) 'Type': [type.value],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/2020-05-31/response-headers-policy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListResponseHeadersPoliciesResult(
responseHeadersPolicyList: ResponseHeadersPolicyList.fromXml($elem),
);
}