listTrustStores method

Future<ListTrustStoresResult> listTrustStores({
  1. String? marker,
  2. int? maxItems,
})

Lists trust stores.

May throw AccessDenied. May throw EntityNotFound. May throw InvalidArgument.

Parameter marker : Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of NextMarker from the current page's response.

Parameter maxItems : The maximum number of trust stores that you want returned in the response.

Implementation

Future<ListTrustStoresResult> listTrustStores({
  String? marker,
  int? maxItems,
}) async {
  final $result = await _protocol.send(
    method: 'POST',
    requestUri: '/2020-05-31/trust-stores',
    payload: ListTrustStoresRequest(marker: marker, maxItems: maxItems)
        .toXml('ListTrustStoresRequest'),
    exceptionFnMap: _exceptionFns,
  );
  return ListTrustStoresResult.fromXml($result.body);
}