untagResource method
Remove tags from a CloudFront resource. For more information, see Tagging a distribution in the Amazon CloudFront Developer Guide.
May throw AccessDenied.
May throw InvalidArgument.
May throw InvalidTagging.
May throw NoSuchResource.
Parameter resource :
An ARN of a CloudFront resource.
Parameter tagKeys :
A complex type that contains zero or more Tag key elements.
Implementation
Future<void> untagResource({
required String resource,
required TagKeys tagKeys,
}) async {
final $query = <String, List<String>>{
'Resource': [resource],
};
await _protocol.send(
method: 'POST',
requestUri: '/2020-05-31/tagging?Operation=Untag',
queryParams: $query,
payload: tagKeys.toXml('TagKeys'),
exceptionFnMap: _exceptionFns,
);
}