verifyDnsConfiguration method
Verify the DNS configuration for your domain names. This API operation checks whether your domain name points to the correct routing endpoint of the connection group, such as d111111abcdef8.cloudfront.net. You can use this API operation to troubleshoot and resolve DNS configuration issues.
May throw AccessDenied.
May throw EntityNotFound.
May throw InvalidArgument.
Parameter identifier :
The identifier of the distribution tenant. You can specify the ARN, ID, or
name of the distribution tenant.
Parameter domain :
The domain name that you're verifying.
Implementation
Future<VerifyDnsConfigurationResult> verifyDnsConfiguration({
required String identifier,
String? domain,
}) async {
final $result = await _protocol.send(
method: 'POST',
requestUri: '/2020-05-31/verify-dns-configuration',
payload:
VerifyDnsConfigurationRequest(identifier: identifier, domain: domain)
.toXml('VerifyDnsConfigurationRequest'),
exceptionFnMap: _exceptionFns,
);
return VerifyDnsConfigurationResult.fromXml($result.body);
}