CloudFrontKeyValueStore class

Amazon CloudFront KeyValueStore Service to View and Update Data in a KVS Resource

Constructors

CloudFrontKeyValueStore({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteKey({required String ifMatch, required String key, required String kvsARN}) Future<DeleteKeyResponse>
Deletes the key value pair specified by the key.
describeKeyValueStore({required String kvsARN}) Future<DescribeKeyValueStoreResponse>
Returns metadata information about Key Value Store.
getKey({required String key, required String kvsARN}) Future<GetKeyResponse>
Returns a key value pair.
listKeys({required String kvsARN, int? maxResults, String? nextToken}) Future<ListKeysResponse>
Returns a list of key value pairs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putKey({required String ifMatch, required String key, required String kvsARN, required String value}) Future<PutKeyResponse>
Creates a new key value pair or replaces the value of an existing key.
toString() String
A string representation of this object.
inherited
updateKeys({required String ifMatch, required String kvsARN, List<DeleteKeyRequestListItem>? deletes, List<PutKeyRequestListItem>? puts}) Future<UpdateKeysResponse>
Puts or Deletes multiple key value pairs in a single, all-or-nothing operation.

Operators

operator ==(Object other) bool
The equality operator.
inherited