CloudHsmV2 class
For more information about CloudHSM, see CloudHSM and the CloudHSM User Guide.
Constructors
- CloudHsmV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
copyBackupToRegion(
{required String backupId, required String destinationRegion, List< Tag> ? tagList}) → Future<CopyBackupToRegionResponse> - Copy an CloudHSM cluster backup to a different region.
-
createCluster(
{required String hsmType, required List< String> subnetIds, BackupRetentionPolicy? backupRetentionPolicy, ClusterMode? mode, NetworkType? networkType, String? sourceBackupId, List<Tag> ? tagList}) → Future<CreateClusterResponse> - Creates a new CloudHSM cluster.
-
createHsm(
{required String availabilityZone, required String clusterId, String? ipAddress}) → Future< CreateHsmResponse> - Creates a new hardware security module (HSM) in the specified CloudHSM cluster.
-
deleteBackup(
{required String backupId}) → Future< DeleteBackupResponse> - Deletes a specified CloudHSM backup. A backup can be restored up to 7 days after the DeleteBackup request is made. For more information on restoring a backup, see RestoreBackup.
-
deleteCluster(
{required String clusterId}) → Future< DeleteClusterResponse> - Deletes the specified CloudHSM cluster. Before you can delete a cluster, you must delete all HSMs in the cluster. To see if the cluster contains any HSMs, use DescribeClusters. To delete an HSM, use DeleteHsm.
-
deleteHsm(
{required String clusterId, String? eniId, String? eniIp, String? hsmId}) → Future< DeleteHsmResponse> - Deletes the specified HSM. To specify an HSM, you can use its identifier (ID), the IP address of the HSM's elastic network interface (ENI), or the ID of the HSM's ENI. You need to specify only one of these values. To find these values, use DescribeClusters.
-
deleteResourcePolicy(
{String? resourceArn}) → Future< DeleteResourcePolicyResponse> - Deletes an CloudHSM resource policy. Deleting a resource policy will result in the resource being unshared and removed from any RAM resource shares. Deleting the resource policy attached to a backup will not impact any clusters created from that backup.
-
describeBackups(
{Map< String, List< ? filters, int? maxResults, String? nextToken, bool? sortAscending}) → Future<String> >DescribeBackupsResponse> - Gets information about backups of CloudHSM clusters. Lists either the backups you own or the backups shared with you when the Shared parameter is true.
-
describeClusters(
{Map< String, List< ? filters, int? maxResults, String? nextToken}) → Future<String> >DescribeClustersResponse> - Gets information about CloudHSM clusters.
-
getResourcePolicy(
{String? resourceArn}) → Future< GetResourcePolicyResponse> - Retrieves the resource policy document attached to a given resource.
-
initializeCluster(
{required String clusterId, required String signedCert, required String trustAnchor}) → Future< InitializeClusterResponse> - Claims an CloudHSM cluster by submitting the cluster certificate issued by your issuing certificate authority (CA) and the CA's root certificate. Before you can claim a cluster, you must sign the cluster's certificate signing request (CSR) with your issuing CA. To get the cluster's CSR, use DescribeClusters.
-
listTags(
{required String resourceId, int? maxResults, String? nextToken}) → Future< ListTagsResponse> - Gets a list of tags for the specified CloudHSM cluster.
-
modifyBackupAttributes(
{required String backupId, required bool neverExpires}) → Future< ModifyBackupAttributesResponse> - Modifies attributes for CloudHSM backup.
-
modifyCluster(
{required String clusterId, BackupRetentionPolicy? backupRetentionPolicy, String? hsmType}) → Future< ModifyClusterResponse> - Modifies CloudHSM cluster.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putResourcePolicy(
{String? policy, String? resourceArn}) → Future< PutResourcePolicyResponse> - Creates or updates an CloudHSM resource policy. A resource policy helps you to define the IAM entity (for example, an Amazon Web Services account) that can manage your CloudHSM resources. The following resources support CloudHSM resource policies:
-
restoreBackup(
{required String backupId}) → Future< RestoreBackupResponse> -
Restores a specified CloudHSM backup that is in the
PENDING_DELETIONstate. For more information on deleting a backup, see DeleteBackup. -
tagResource(
{required String resourceId, required List< Tag> tagList}) → Future<void> - Adds or overwrites one or more tags for the specified CloudHSM cluster.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceId, required List< String> tagKeyList}) → Future<void> - Removes the specified tag or tags from the specified CloudHSM cluster.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited