describeDomains method

Future<DescribeDomainsResponse> describeDomains({
  1. List<String>? domainNames,
})

Gets information about the search domains owned by this account. Can be limited to specific domains. Shows all domains by default. To get the number of searchable documents in a domain, use the console or submit a matchall request to your domain's search endpoint: q=matchall&q.parser=structured&size=0. For more information, see Getting Information about a Search Domain in the Amazon CloudSearch Developer Guide.

May throw BaseException. May throw InternalException.

Parameter domainNames : The names of the domains you want to include in the response.

Implementation

Future<DescribeDomainsResponse> describeDomains({
  List<String>? domainNames,
}) async {
  final $request = <String, String>{
    if (domainNames != null)
      if (domainNames.isEmpty)
        'DomainNames': ''
      else
        for (var i1 = 0; i1 < domainNames.length; i1++)
          'DomainNames.member.${i1 + 1}': domainNames[i1],
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDomains',
    version: '2013-01-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDomainsResult',
  );
  return DescribeDomainsResponse.fromXml($result);
}