createTrail method

Future<CreateTrailResponse> createTrail({
  1. required String name,
  2. required String s3BucketName,
  3. String? cloudWatchLogsLogGroupArn,
  4. String? cloudWatchLogsRoleArn,
  5. bool? enableLogFileValidation,
  6. bool? includeGlobalServiceEvents,
  7. bool? isMultiRegionTrail,
  8. bool? isOrganizationTrail,
  9. String? kmsKeyId,
  10. String? s3KeyPrefix,
  11. String? snsTopicName,
  12. List<Tag>? tagsList,
})

Creates a trail that specifies the settings for delivery of log data to an Amazon S3 bucket.

May throw CloudTrailAccessNotEnabledException. May throw CloudTrailInvalidClientTokenIdException. May throw CloudWatchLogsDeliveryUnavailableException. May throw ConflictException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InsufficientEncryptionPolicyException. May throw InsufficientS3BucketPolicyException. May throw InsufficientSnsTopicPolicyException. May throw InvalidCloudWatchLogsLogGroupArnException. May throw InvalidCloudWatchLogsRoleArnException. May throw InvalidKmsKeyIdException. May throw InvalidParameterCombinationException. May throw InvalidParameterException. May throw InvalidS3BucketNameException. May throw InvalidS3PrefixException. May throw InvalidSnsTopicNameException. May throw InvalidTagParameterException. May throw InvalidTrailNameException. May throw KmsException. May throw KmsKeyDisabledException. May throw KmsKeyNotFoundException. May throw MaximumNumberOfTrailsExceededException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw OrganizationNotInAllFeaturesModeException. May throw OrganizationsNotInUseException. May throw S3BucketDoesNotExistException. May throw TagsLimitExceededException. May throw ThrottlingException. May throw TrailAlreadyExistsException. May throw TrailNotProvidedException. May throw UnsupportedOperationException.

Parameter name : Specifies the name of the trail. The name must meet the following requirements:

  • Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
  • Start with a letter or number, and end with a letter or number
  • Be between 3 and 128 characters
  • Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are not valid.
  • Not be in IP address format (for example, 192.168.5.4)

Parameter s3BucketName : Specifies the name of the Amazon S3 bucket designated for publishing log files. For information about bucket naming rules, see Bucket naming rules in the Amazon Simple Storage Service User Guide.

Parameter cloudWatchLogsLogGroupArn : Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered. You must use a log group that exists in your account.

Not required unless you specify CloudWatchLogsRoleArn.

Parameter cloudWatchLogsRoleArn : Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group. You must use a role that exists in your account.

Parameter enableLogFileValidation : Specifies whether log file integrity validation is enabled. The default is false.

Parameter includeGlobalServiceEvents : Specifies whether the trail is publishing events from global services such as IAM to the log files.

Parameter isMultiRegionTrail : Specifies whether the trail is created in the current Region or in all Regions. The default is false, which creates a trail only in the Region where you are signed in. As a best practice, consider creating trails that log events in all Regions.

Parameter isOrganizationTrail : Specifies whether the trail is created for all accounts in an organization in Organizations, or only for the current Amazon Web Services account. The default is false, and cannot be true unless the call is made on behalf of an Amazon Web Services account that is the management account or delegated administrator account for an organization in Organizations.

Parameter kmsKeyId : Specifies the KMS key ID to use to encrypt the logs and digest files delivered by CloudTrail. The value can be an alias name prefixed by alias/, a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier.

CloudTrail also supports KMS multi-Region keys. For more information about multi-Region keys, see Using multi-Region keys in the Key Management Service Developer Guide.

Examples:

  • alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012
  • 12345678-1234-1234-1234-123456789012

Parameter s3KeyPrefix : Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files. The maximum length is 200 characters.

Parameter snsTopicName : Specifies the name or ARN of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters.

Implementation

Future<CreateTrailResponse> createTrail({
  required String name,
  required String s3BucketName,
  String? cloudWatchLogsLogGroupArn,
  String? cloudWatchLogsRoleArn,
  bool? enableLogFileValidation,
  bool? includeGlobalServiceEvents,
  bool? isMultiRegionTrail,
  bool? isOrganizationTrail,
  String? kmsKeyId,
  String? s3KeyPrefix,
  String? snsTopicName,
  List<Tag>? tagsList,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.CreateTrail'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      'S3BucketName': s3BucketName,
      if (cloudWatchLogsLogGroupArn != null)
        'CloudWatchLogsLogGroupArn': cloudWatchLogsLogGroupArn,
      if (cloudWatchLogsRoleArn != null)
        'CloudWatchLogsRoleArn': cloudWatchLogsRoleArn,
      if (enableLogFileValidation != null)
        'EnableLogFileValidation': enableLogFileValidation,
      if (includeGlobalServiceEvents != null)
        'IncludeGlobalServiceEvents': includeGlobalServiceEvents,
      if (isMultiRegionTrail != null)
        'IsMultiRegionTrail': isMultiRegionTrail,
      if (isOrganizationTrail != null)
        'IsOrganizationTrail': isOrganizationTrail,
      if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
      if (s3KeyPrefix != null) 'S3KeyPrefix': s3KeyPrefix,
      if (snsTopicName != null) 'SnsTopicName': snsTopicName,
      if (tagsList != null) 'TagsList': tagsList,
    },
  );

  return CreateTrailResponse.fromJson(jsonResponse.body);
}