deleteEventDataStore method

Future<void> deleteEventDataStore({
  1. required String eventDataStore,
})

Disables the event data store specified by EventDataStore, which accepts an event data store ARN. After you run DeleteEventDataStore, the event data store enters a PENDING_DELETION state, and is automatically deleted after a wait period of seven days. TerminationProtectionEnabled must be set to False on the event data store and the FederationStatus must be DISABLED. You cannot delete an event data store if TerminationProtectionEnabled is True or the FederationStatus is ENABLED.

After you run DeleteEventDataStore on an event data store, you cannot run ListQueries, DescribeQuery, or GetQueryResults on queries that are using an event data store in a PENDING_DELETION state. An event data store in the PENDING_DELETION state does not incur costs.

May throw ChannelExistsForEDSException. May throw ConflictException. May throw EventDataStoreARNInvalidException. May throw EventDataStoreFederationEnabledException. May throw EventDataStoreHasOngoingImportException. May throw EventDataStoreNotFoundException. May throw EventDataStoreTerminationProtectedException. May throw InactiveEventDataStoreException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InvalidParameterException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw UnsupportedOperationException.

Parameter eventDataStore : The ARN (or the ID suffix of the ARN) of the event data store to delete.

Implementation

Future<void> deleteEventDataStore({
  required String eventDataStore,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.DeleteEventDataStore'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventDataStore': eventDataStore,
    },
  );
}