disableFederation method

Future<DisableFederationResponse> disableFederation({
  1. required String eventDataStore,
})

Disables Lake query federation on the specified event data store. When you disable federation, CloudTrail disables the integration with Glue, Lake Formation, and Amazon Athena. After disabling Lake query federation, you can no longer query your event data in Amazon Athena.

No CloudTrail Lake data is deleted when you disable federation and you can continue to run queries in CloudTrail Lake.

May throw AccessDeniedException. May throw CloudTrailAccessNotEnabledException. May throw ConcurrentModificationException. May throw EventDataStoreARNInvalidException. May throw EventDataStoreNotFoundException. May throw InactiveEventDataStoreException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InvalidParameterException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw OrganizationNotInAllFeaturesModeException. May throw OrganizationsNotInUseException. May throw UnsupportedOperationException.

Parameter eventDataStore : The ARN (or ID suffix of the ARN) of the event data store for which you want to disable Lake query federation.

Implementation

Future<DisableFederationResponse> disableFederation({
  required String eventDataStore,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.DisableFederation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventDataStore': eventDataStore,
    },
  );

  return DisableFederationResponse.fromJson(jsonResponse.body);
}