getEventConfiguration method
Retrieves the current event configuration settings for the specified event data store or trail. The response includes maximum event size configuration, the context key selectors configured for the event data store, and any aggregation settings configured for the trail.
May throw CloudTrailARNInvalidException.
May throw EventDataStoreARNInvalidException.
May throw EventDataStoreNotFoundException.
May throw InvalidEventDataStoreCategoryException.
May throw InvalidEventDataStoreStatusException.
May throw InvalidParameterCombinationException.
May throw InvalidParameterException.
May throw InvalidTrailNameException.
May throw NoManagementAccountSLRExistsException.
May throw OperationNotPermittedException.
May throw TrailNotFoundException.
May throw UnsupportedOperationException.
Parameter eventDataStore :
The Amazon Resource Name (ARN) or ID suffix of the ARN of the event data
store for which you want to retrieve event configuration settings.
Parameter trailName :
The name of the trail for which you want to retrieve event configuration
settings.
Implementation
Future<GetEventConfigurationResponse> getEventConfiguration({
String? eventDataStore,
String? trailName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CloudTrail_20131101.GetEventConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (eventDataStore != null) 'EventDataStore': eventDataStore,
if (trailName != null) 'TrailName': trailName,
},
);
return GetEventConfigurationResponse.fromJson(jsonResponse.body);
}