restoreEventDataStore method

Future<RestoreEventDataStoreResponse> restoreEventDataStore({
  1. required String eventDataStore,
})

Restores a deleted event data store specified by EventDataStore, which accepts an event data store ARN. You can only restore a deleted event data store within the seven-day wait period after deletion. Restoring an event data store can take several minutes, depending on the size of the event data store.

May throw CloudTrailAccessNotEnabledException. May throw EventDataStoreARNInvalidException. May throw EventDataStoreMaxLimitExceededException. May throw EventDataStoreNotFoundException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InvalidEventDataStoreStatusException. May throw InvalidParameterException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw OrganizationNotInAllFeaturesModeException. May throw OrganizationsNotInUseException. May throw UnsupportedOperationException.

Parameter eventDataStore : The ARN (or the ID suffix of the ARN) of the event data store that you want to restore.

Implementation

Future<RestoreEventDataStoreResponse> restoreEventDataStore({
  required String eventDataStore,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.RestoreEventDataStore'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventDataStore': eventDataStore,
    },
  );

  return RestoreEventDataStoreResponse.fromJson(jsonResponse.body);
}