startLogging method

Future<void> startLogging({
  1. required String name,
})

Starts the recording of Amazon Web Services API calls and log file delivery for a trail. For a trail that is enabled in all Regions, this operation must be called from the Region in which the trail was created. This operation cannot be called on the shadow trails (replicated trails in other Regions) of a trail that is enabled in all Regions.

May throw CloudTrailARNInvalidException. May throw ConflictException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InvalidHomeRegionException. May throw InvalidTrailNameException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw ThrottlingException. May throw TrailNotFoundException. May throw UnsupportedOperationException.

Parameter name : Specifies the name or the CloudTrail ARN of the trail for which CloudTrail logs Amazon Web Services API calls. The following is the format of a trail ARN.

arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail

Implementation

Future<void> startLogging({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.StartLogging'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}