stopEventDataStoreIngestion method

Future<void> stopEventDataStoreIngestion({
  1. required String eventDataStore,
})

Stops the ingestion of live events on an event data store specified as either an ARN or the ID portion of the ARN. To stop ingestion, the event data store Status must be ENABLED and the eventCategory must be Management, Data, NetworkActivity, or ConfigurationItem.

May throw ConflictException. May throw EventDataStoreARNInvalidException. May throw EventDataStoreNotFoundException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InvalidEventDataStoreCategoryException. May throw InvalidEventDataStoreStatusException. May throw InvalidParameterException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw UnsupportedOperationException.

Parameter eventDataStore : The ARN (or ID suffix of the ARN) of the event data store for which you want to stop ingestion.

Implementation

Future<void> stopEventDataStoreIngestion({
  required String eventDataStore,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.StopEventDataStoreIngestion'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventDataStore': eventDataStore,
    },
  );
}