updateEventDataStore method

Future<UpdateEventDataStoreResponse> updateEventDataStore({
  1. required String eventDataStore,
  2. List<AdvancedEventSelector>? advancedEventSelectors,
  3. BillingMode? billingMode,
  4. String? kmsKeyId,
  5. bool? multiRegionEnabled,
  6. String? name,
  7. bool? organizationEnabled,
  8. int? retentionPeriod,
  9. bool? terminationProtectionEnabled,
})

Updates an event data store. The required EventDataStore value is an ARN or the ID portion of the ARN. Other parameters are optional, but at least one optional parameter must be specified, or CloudTrail throws an error. RetentionPeriod is in days, and valid values are integers between 7 and 3653 if the BillingMode is set to EXTENDABLE_RETENTION_PRICING, or between 7 and 2557 if BillingMode is set to FIXED_RETENTION_PRICING. By default, TerminationProtection is enabled.

For event data stores for CloudTrail events, AdvancedEventSelectors includes or excludes management, data, or network activity events in your event data store. For more information about AdvancedEventSelectors, see AdvancedEventSelectors.

For event data stores for CloudTrail Insights events, Config configuration items, Audit Manager evidence, or non-Amazon Web Services events, AdvancedEventSelectors includes events of that type in your event data store.

May throw CloudTrailAccessNotEnabledException. May throw ConflictException. May throw EventDataStoreAlreadyExistsException. May throw EventDataStoreARNInvalidException. May throw EventDataStoreHasOngoingImportException. May throw EventDataStoreNotFoundException. May throw InactiveEventDataStoreException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InsufficientEncryptionPolicyException. May throw InvalidEventSelectorsException. May throw InvalidInsightSelectorsException. May throw InvalidKmsKeyIdException. May throw InvalidParameterException. May throw KmsException. May throw KmsKeyNotFoundException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw OrganizationNotInAllFeaturesModeException. May throw OrganizationsNotInUseException. May throw ThrottlingException. May throw UnsupportedOperationException.

Parameter eventDataStore : The ARN (or the ID suffix of the ARN) of the event data store that you want to update.

Parameter advancedEventSelectors : The advanced event selectors used to select events for the event data store. You can configure up to five advanced event selectors for each event data store.

Parameter billingMode : The billing mode for the event data store determines the cost for ingesting events and the default and maximum retention period for the event data store.

The following are the possible values:

  • EXTENDABLE_RETENTION_PRICING - This billing mode is generally recommended if you want a flexible retention period of up to 3653 days (about 10 years). The default retention period for this billing mode is 366 days.
  • FIXED_RETENTION_PRICING - This billing mode is recommended if you expect to ingest more than 25 TB of event data per month and need a retention period of up to 2557 days (about 7 years). The default retention period for this billing mode is 2557 days.
For more information about CloudTrail pricing, see CloudTrail Pricing and Managing CloudTrail Lake costs.

Parameter kmsKeyId : Specifies the KMS key ID to use to encrypt the events delivered by CloudTrail. The value can be an alias name prefixed by alias/, a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier. CloudTrail also supports KMS multi-Region keys. For more information about multi-Region keys, see Using multi-Region keys in the Key Management Service Developer Guide.

Examples:

  • alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012
  • 12345678-1234-1234-1234-123456789012

Parameter multiRegionEnabled : Specifies whether an event data store collects events from all Regions, or only from the Region in which it was created.

Parameter name : The event data store name.

Parameter organizationEnabled : Specifies whether an event data store collects events logged for an organization in Organizations.

Parameter retentionPeriod : The retention period of the event data store, in days. If BillingMode is set to EXTENDABLE_RETENTION_PRICING, you can set a retention period of up to 3653 days, the equivalent of 10 years. If BillingMode is set to FIXED_RETENTION_PRICING, you can set a retention period of up to 2557 days, the equivalent of seven years.

CloudTrail Lake determines whether to retain an event by checking if the eventTime of the event is within the specified retention period. For example, if you set a retention period of 90 days, CloudTrail will remove events when the eventTime is older than 90 days.

Parameter terminationProtectionEnabled : Indicates that termination protection is enabled and the event data store cannot be automatically deleted.

Implementation

Future<UpdateEventDataStoreResponse> updateEventDataStore({
  required String eventDataStore,
  List<AdvancedEventSelector>? advancedEventSelectors,
  BillingMode? billingMode,
  String? kmsKeyId,
  bool? multiRegionEnabled,
  String? name,
  bool? organizationEnabled,
  int? retentionPeriod,
  bool? terminationProtectionEnabled,
}) async {
  _s.validateNumRange(
    'retentionPeriod',
    retentionPeriod,
    7,
    3653,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.UpdateEventDataStore'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventDataStore': eventDataStore,
      if (advancedEventSelectors != null)
        'AdvancedEventSelectors': advancedEventSelectors,
      if (billingMode != null) 'BillingMode': billingMode.value,
      if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
      if (multiRegionEnabled != null)
        'MultiRegionEnabled': multiRegionEnabled,
      if (name != null) 'Name': name,
      if (organizationEnabled != null)
        'OrganizationEnabled': organizationEnabled,
      if (retentionPeriod != null) 'RetentionPeriod': retentionPeriod,
      if (terminationProtectionEnabled != null)
        'TerminationProtectionEnabled': terminationProtectionEnabled,
    },
  );

  return UpdateEventDataStoreResponse.fromJson(jsonResponse.body);
}