updateTrail method

Future<UpdateTrailResponse> updateTrail({
  1. required String name,
  2. String? cloudWatchLogsLogGroupArn,
  3. String? cloudWatchLogsRoleArn,
  4. bool? enableLogFileValidation,
  5. bool? includeGlobalServiceEvents,
  6. bool? isMultiRegionTrail,
  7. bool? isOrganizationTrail,
  8. String? kmsKeyId,
  9. String? s3BucketName,
  10. String? s3KeyPrefix,
  11. String? snsTopicName,
})

Updates trail settings that control what events you are logging, and how to handle log files. Changes to a trail do not require stopping the CloudTrail service. Use this action to designate an existing bucket for log delivery. If the existing bucket has previously been a target for CloudTrail log files, an IAM policy exists for the bucket. UpdateTrail must be called from the Region in which the trail was created; otherwise, an InvalidHomeRegionException is thrown.

May throw CloudTrailAccessNotEnabledException. May throw CloudTrailARNInvalidException. May throw CloudTrailInvalidClientTokenIdException. May throw CloudWatchLogsDeliveryUnavailableException. May throw ConflictException. May throw InsufficientDependencyServiceAccessPermissionException. May throw InsufficientEncryptionPolicyException. May throw InsufficientS3BucketPolicyException. May throw InsufficientSnsTopicPolicyException. May throw InvalidCloudWatchLogsLogGroupArnException. May throw InvalidCloudWatchLogsRoleArnException. May throw InvalidEventSelectorsException. May throw InvalidHomeRegionException. May throw InvalidKmsKeyIdException. May throw InvalidParameterCombinationException. May throw InvalidParameterException. May throw InvalidS3BucketNameException. May throw InvalidS3PrefixException. May throw InvalidSnsTopicNameException. May throw InvalidTrailNameException. May throw KmsException. May throw KmsKeyDisabledException. May throw KmsKeyNotFoundException. May throw NoManagementAccountSLRExistsException. May throw NotOrganizationMasterAccountException. May throw OperationNotPermittedException. May throw OrganizationNotInAllFeaturesModeException. May throw OrganizationsNotInUseException. May throw S3BucketDoesNotExistException. May throw ThrottlingException. May throw TrailNotFoundException. May throw TrailNotProvidedException. May throw UnsupportedOperationException.

Parameter name : Specifies the name of the trail or trail ARN. If Name is a trail name, the string must meet the following requirements:

  • Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
  • Start with a letter or number, and end with a letter or number
  • Be between 3 and 128 characters
  • Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are not valid.
  • Not be in IP address format (for example, 192.168.5.4)
If Name is a trail ARN, it must be in the following format.

arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail

Parameter cloudWatchLogsLogGroupArn : Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs are delivered. You must use a log group that exists in your account.

Not required unless you specify CloudWatchLogsRoleArn.

Parameter cloudWatchLogsRoleArn : Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group. You must use a role that exists in your account.

Parameter enableLogFileValidation : Specifies whether log file validation is enabled. The default is false.

Parameter includeGlobalServiceEvents : Specifies whether the trail is publishing events from global services such as IAM to the log files.

Parameter isMultiRegionTrail : Specifies whether the trail applies only to the current Region or to all Regions. The default is false. If the trail exists only in the current Region and this value is set to true, shadow trails (replications of the trail) will be created in the other Regions. If the trail exists in all Regions and this value is set to false, the trail will remain in the Region where it was created, and its shadow trails in other Regions will be deleted. As a best practice, consider using trails that log events in all Regions.

Parameter isOrganizationTrail : Specifies whether the trail is applied to all accounts in an organization in Organizations, or only for the current Amazon Web Services account. The default is false, and cannot be true unless the call is made on behalf of an Amazon Web Services account that is the management account for an organization in Organizations. If the trail is not an organization trail and this is set to true, the trail will be created in all Amazon Web Services accounts that belong to the organization. If the trail is an organization trail and this is set to false, the trail will remain in the current Amazon Web Services account but be deleted from all member accounts in the organization.

Parameter kmsKeyId : Specifies the KMS key ID to use to encrypt the logs and digest files delivered by CloudTrail. The value can be an alias name prefixed by "alias/", a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier.

CloudTrail also supports KMS multi-Region keys. For more information about multi-Region keys, see Using multi-Region keys in the Key Management Service Developer Guide.

Examples:

  • alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:alias/MyAliasName
  • arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012
  • 12345678-1234-1234-1234-123456789012

Parameter s3BucketName : Specifies the name of the Amazon S3 bucket designated for publishing log files. See Amazon S3 Bucket naming rules.

Parameter s3KeyPrefix : Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files. The maximum length is 200 characters.

Parameter snsTopicName : Specifies the name or ARN of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters.

Implementation

Future<UpdateTrailResponse> updateTrail({
  required String name,
  String? cloudWatchLogsLogGroupArn,
  String? cloudWatchLogsRoleArn,
  bool? enableLogFileValidation,
  bool? includeGlobalServiceEvents,
  bool? isMultiRegionTrail,
  bool? isOrganizationTrail,
  String? kmsKeyId,
  String? s3BucketName,
  String? s3KeyPrefix,
  String? snsTopicName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CloudTrail_20131101.UpdateTrail'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (cloudWatchLogsLogGroupArn != null)
        'CloudWatchLogsLogGroupArn': cloudWatchLogsLogGroupArn,
      if (cloudWatchLogsRoleArn != null)
        'CloudWatchLogsRoleArn': cloudWatchLogsRoleArn,
      if (enableLogFileValidation != null)
        'EnableLogFileValidation': enableLogFileValidation,
      if (includeGlobalServiceEvents != null)
        'IncludeGlobalServiceEvents': includeGlobalServiceEvents,
      if (isMultiRegionTrail != null)
        'IsMultiRegionTrail': isMultiRegionTrail,
      if (isOrganizationTrail != null)
        'IsOrganizationTrail': isOrganizationTrail,
      if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
      if (s3BucketName != null) 'S3BucketName': s3BucketName,
      if (s3KeyPrefix != null) 'S3KeyPrefix': s3KeyPrefix,
      if (snsTopicName != null) 'SnsTopicName': snsTopicName,
    },
  );

  return UpdateTrailResponse.fromJson(jsonResponse.body);
}