deleteAlarmMuteRule method
Deletes a specific alarm mute rule.
When you delete a mute rule, any alarms that are currently being muted by that rule are immediately unmuted. If those alarms are in an ALARM state, their configured actions will trigger.
This operation is idempotent. If you delete a mute rule that does not exist, the operation succeeds without returning an error.
Permissions
To delete a mute rule, you need the
cloudwatch:DeleteAlarmMuteRule permission on the alarm mute
rule resource.
Parameter alarmMuteRuleName :
The name of the alarm mute rule to delete.
Implementation
Future<void> deleteAlarmMuteRule({
required String alarmMuteRuleName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.DeleteAlarmMuteRule'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AlarmMuteRuleName': alarmMuteRuleName,
},
);
}