deleteDashboards method
Deletes all dashboards that you specify. You can specify up to 100 dashboards to delete. If there is an error during this call, the operation attempts to delete as many dashboards as possible.
May throw ConflictException.
May throw InternalServiceFault.
May throw InvalidParameterValueException.
Parameter dashboardNames :
The dashboards to be deleted. This parameter is required.
Implementation
Future<void> deleteDashboards({
required List<String> dashboardNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.DeleteDashboards'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DashboardNames': dashboardNames,
},
);
}