describeInsightRules method

Future<DescribeInsightRulesOutput> describeInsightRules({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of all the Contributor Insights rules in your account.

For more information about Contributor Insights, see Using Contributor Insights to Analyze High-Cardinality Data.

May throw InvalidNextToken.

Parameter maxResults : The maximum number of results to return in one operation. If you omit this parameter, the default of 500 is used.

Parameter nextToken : Include this value, if it was returned by the previous operation, to get the next set of rules.

Implementation

Future<DescribeInsightRulesOutput> describeInsightRules({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'GraniteServiceVersion20100801.DescribeInsightRules'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeInsightRulesOutput.fromJson(jsonResponse.body);
}