getOTelEnrichment method

Future<GetOTelEnrichmentOutput> getOTelEnrichment()

Returns the current status of vended metric enrichment for the account, including whether CloudWatch vended metrics are enriched with resource ARN and resource tag labels and queryable using PromQL. For the list of supported resources, see Supported Amazon Web Services infrastructure metrics.

Implementation

Future<GetOTelEnrichmentOutput> getOTelEnrichment() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'GraniteServiceVersion20100801.GetOTelEnrichment'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return GetOTelEnrichmentOutput.fromJson(jsonResponse.body);
}