putMetricAlarm method
- required String alarmName,
- bool? actionsEnabled,
- List<
String> ? alarmActions, - String? alarmDescription,
- ComparisonOperator? comparisonOperator,
- int? datapointsToAlarm,
- List<
Dimension> ? dimensions, - String? evaluateLowSampleCountPercentile,
- EvaluationCriteria? evaluationCriteria,
- int? evaluationInterval,
- int? evaluationPeriods,
- String? extendedStatistic,
- List<
String> ? insufficientDataActions, - String? metricName,
- List<
MetricDataQuery> ? metrics, - String? namespace,
- List<
String> ? oKActions, - int? period,
- Statistic? statistic,
- List<
Tag> ? tags, - double? threshold,
- String? thresholdMetricId,
- String? treatMissingData,
- StandardUnit? unit,
Creates or updates an alarm and associates it with the specified metric, metric math expression, anomaly detection model, Metrics Insights query, or PromQL query. For more information about using a Metrics Insights query for an alarm, see Create alarms on Metrics Insights queries.
Alarms based on anomaly detection models cannot have Auto Scaling actions.
When this operation creates an alarm, the alarm state is immediately set
to INSUFFICIENT_DATA. For PromQL alarms, the alarm state is
instead immediately set to OK. The alarm is then evaluated
and its state is set appropriately. Any actions associated with the new
state are then executed.
When you update an existing alarm, its state is left unchanged, but the update completely overwrites the previous configuration of the alarm.
If you are an IAM user, you must have Amazon EC2 permissions for some alarm operations:
-
The
iam:CreateServiceLinkedRolepermission for all alarms with EC2 actions -
The
iam:CreateServiceLinkedRolepermissions to create an alarm with Systems Manager OpsItem or response plan actions.
AWSServiceRoleForCloudWatchEvents and
AWSServiceRoleForCloudWatchAlarms_ActionSSM. For more
information, see Amazon
Web Services service-linked role.
Each PutMetricAlarm action has a maximum uncompressed payload
of 120 KB.
Cross-account alarms
You can set an alarm on metrics in the current account, or in another account. To create a cross-account alarm that watches a metric in a different account, you must have completed the following pre-requisites:
- The account where the metrics are located (the sharing account) must already have a sharing role named CloudWatch-CrossAccountSharingRole. If it does not already have this role, you must create it using the instructions in Set up a sharing account in Cross-account cross-Region CloudWatch console. The policy for that role must grant access to the ID of the account where you are creating the alarm.
- The account where you are creating the alarm (the monitoring account) must already have a service-linked role named AWSServiceRoleForCloudWatchCrossAccount to allow CloudWatch to assume the sharing role in the sharing account. If it does not, you must create it following the directions in Set up a monitoring account in Cross-account cross-Region CloudWatch console.
May throw LimitExceededFault.
Parameter alarmName :
The name for the alarm. This name must be unique within the Region.
The name must contain only UTF-8 characters, and can't contain ASCII control characters
Parameter actionsEnabled :
Indicates whether actions should be executed during any changes to the
alarm state. The default is TRUE.
Parameter alarmActions :
The actions to execute when this alarm transitions to the
ALARM state from any other state. Each action is specified as
an Amazon Resource Name (ARN). Valid values:
EC2 actions:
-
arn:aws:automate:region:ec2:stop -
arn:aws:automate:region:ec2:terminate -
arn:aws:automate:region:ec2:reboot -
arn:aws:automate:region:ec2:recover -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Stop/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Terminate/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Reboot/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Recover/1.0
-
arn:aws:autoscaling:region:account-id:scalingPolicy:policy-id:autoScalingGroupName/group-friendly-name:policyName/policy-friendly-name
-
Invoke the latest version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name -
Invoke a specific version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name:version-number -
Invoke a function by using an alias Lambda function:
arn:aws:lambda:region:account-id:function:function-name:alias-name
-
arn:aws:sns:region:account-id:sns-topic-name
-
arn:aws:ssm:region:account-id:opsitem:severity#CATEGORY=category-name -
arn:aws:ssm-incidents::account-id:responseplan/response-plan-name
arn:aws:aiops:region:account-id:investigation-group:investigation-group-id
Parameter alarmDescription :
The description for the alarm.
Parameter comparisonOperator :
The arithmetic operation to use when comparing the specified statistic and
threshold. The specified statistic value is used as the first operand.
The values LessThanLowerOrGreaterThanUpperThreshold,
LessThanLowerThreshold, and
GreaterThanUpperThreshold are used only for alarms based on
anomaly detection models.
Parameter datapointsToAlarm :
The number of data points that must be breaching to trigger the alarm.
This is used only if you are setting an "M out of N" alarm. In that case,
this value is the M. For more information, see Evaluating
an Alarm in the Amazon CloudWatch User Guide.
Parameter dimensions :
The dimensions for the metric specified in MetricName.
Parameter evaluateLowSampleCountPercentile :
Used only for alarms based on percentiles. If you specify
ignore, the alarm state does not change during periods with
too few data points to be statistically significant. If you specify
evaluate or omit this parameter, the alarm is always
evaluated and possibly changes state no matter how many data points are
available. For more information, see Percentile-Based
CloudWatch Alarms and Low Data Samples.
Valid Values: evaluate | ignore
Parameter evaluationCriteria :
The evaluation criteria for the alarm. For each
PutMetricAlarm operation, you must specify either
MetricName, a Metrics array, or an
EvaluationCriteria.
If you use the EvaluationCriteria parameter, you cannot
include the Namespace, MetricName,
Dimensions, Period, Unit,
Statistic, ExtendedStatistic,
Metrics, Threshold,
ComparisonOperator, ThresholdMetricId,
EvaluationPeriods, or DatapointsToAlarm
parameters of PutMetricAlarm in the same operation. Instead,
all evaluation parameters are defined within this structure.
For an example of how to use this parameter, see the PromQL alarm example on this page.
Parameter evaluationInterval :
The frequency, in seconds, at which the alarm is evaluated. Valid values
are 10, 20, 30, and any multiple of 60.
This parameter is required for alarms that use
EvaluationCriteria, and cannot be specified for alarms
configured with MetricName or Metrics.
Parameter evaluationPeriods :
The number of periods over which data is compared to the specified
threshold. If you are setting an alarm that requires that a number of
consecutive data points be breaching to trigger the alarm, this value
specifies that number. If you are setting an "M out of N" alarm, this
value is the N.
Parameter extendedStatistic :
The extended statistic for the metric specified in
MetricName. When you call PutMetricAlarm and
specify a MetricName, you must specify either
Statistic or ExtendedStatistic but not both.
If you specify ExtendedStatistic, the following are valid
values:
-
p90 -
tm90 -
tc90 -
ts90 -
wm90 -
IQM -
PR(n:m)where n and m are values of the metric -
TC(X%:X%)where X is between 10 and 90 inclusive. -
TM(X%:X%)where X is between 10 and 90 inclusive. -
TS(X%:X%)where X is between 10 and 90 inclusive. -
WM(X%:X%)where X is between 10 and 90 inclusive.
Parameter insufficientDataActions :
The actions to execute when this alarm transitions to the
INSUFFICIENT_DATA state from any other state. Each action is
specified as an Amazon Resource Name (ARN). Valid values:
EC2 actions:
-
arn:aws:automate:region:ec2:stop -
arn:aws:automate:region:ec2:terminate -
arn:aws:automate:region:ec2:reboot -
arn:aws:automate:region:ec2:recover -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Stop/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Terminate/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Reboot/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Recover/1.0
-
arn:aws:autoscaling:region:account-id:scalingPolicy:policy-id:autoScalingGroupName/group-friendly-name:policyName/policy-friendly-name
-
Invoke the latest version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name -
Invoke a specific version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name:version-number -
Invoke a function by using an alias Lambda function:
arn:aws:lambda:region:account-id:function:function-name:alias-name
-
arn:aws:sns:region:account-id:sns-topic-name
-
arn:aws:ssm:region:account-id:opsitem:severity#CATEGORY=category-name -
arn:aws:ssm-incidents::account-id:responseplan/response-plan-name
Parameter metricName :
The name for the metric associated with the alarm. For each
PutMetricAlarm operation, you must specify either
MetricName, a Metrics array, or an
EvaluationCriteria.
If you are creating an alarm based on a math expression, you cannot
specify this parameter, or any of the Namespace,
Dimensions, Period, Unit,
Statistic, or ExtendedStatistic parameters.
Instead, you specify all this information in the Metrics
array.
Parameter metrics :
An array of MetricDataQuery structures that enable you to
create an alarm based on the result of a metric math expression. For each
PutMetricAlarm operation, you must specify either
MetricName, a Metrics array, or an
EvaluationCriteria.
Each item in the Metrics array either retrieves a metric or
performs a math expression.
One item in the Metrics array is the expression that the
alarm watches. You designate this expression by setting
ReturnData to true for this object in the array. For more
information, see MetricDataQuery.
If you use the Metrics parameter, you cannot include the
Namespace, MetricName, Dimensions,
Period, Unit, Statistic, or
ExtendedStatistic parameters of PutMetricAlarm
in the same operation. Instead, you retrieve the metrics you are using in
your math expression as part of the Metrics array.
Parameter namespace :
The namespace for the metric associated specified in
MetricName.
Parameter oKActions :
The actions to execute when this alarm transitions to an OK
state from any other state. Each action is specified as an Amazon Resource
Name (ARN). Valid values:
EC2 actions:
-
arn:aws:automate:region:ec2:stop -
arn:aws:automate:region:ec2:terminate -
arn:aws:automate:region:ec2:reboot -
arn:aws:automate:region:ec2:recover -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Stop/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Terminate/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Reboot/1.0 -
arn:aws:swf:region:account-id:action/actions/AWS_EC2.InstanceId.Recover/1.0
-
arn:aws:autoscaling:region:account-id:scalingPolicy:policy-id:autoScalingGroupName/group-friendly-name:policyName/policy-friendly-name
-
Invoke the latest version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name -
Invoke a specific version of a Lambda function:
arn:aws:lambda:region:account-id:function:function-name:version-number -
Invoke a function by using an alias Lambda function:
arn:aws:lambda:region:account-id:function:function-name:alias-name
-
arn:aws:sns:region:account-id:sns-topic-name
-
arn:aws:ssm:region:account-id:opsitem:severity#CATEGORY=category-name -
arn:aws:ssm-incidents::account-id:responseplan/response-plan-name
Parameter period :
The length, in seconds, used each time the metric specified in
MetricName is evaluated. Valid values are 10, 20, 30, and any
multiple of 60.
Period is required for alarms based on static thresholds. If
you are creating an alarm based on a metric math expression, you specify
the period for each metric within the objects in the Metrics
array.
Be sure to specify 10, 20, or 30 only for metrics that are stored by a
PutMetricData call with a StorageResolution of
- If you specify a period of 10, 20, or 30 for a metric that does not have sub-minute resolution, the alarm still attempts to gather data at the period rate that you specify. In this case, it does not receive data for the attempts that do not correspond to a one-minute data resolution, and the alarm might often lapse into INSUFFICENT_DATA status. Specifying 10, 20, or 30 also sets this alarm as a high-resolution alarm, which has a higher charge than other alarms. For more information about pricing, see Amazon CloudWatch Pricing.
An alarm's total current evaluation period can be no longer than seven
days, so Period multiplied by EvaluationPeriods
can't be more than 604,800 seconds. For alarms with a period of less than
one hour (3,600 seconds), the total evaluation period can't be longer than
one day (86,400 seconds).
Parameter statistic :
The statistic for the metric specified in MetricName, other
than percentile. For percentile statistics, use
ExtendedStatistic. When you call PutMetricAlarm
and specify a MetricName, you must specify either
Statistic or ExtendedStatistic, but not both.
Parameter tags :
A list of key-value pairs to associate with the alarm. You can associate
as many as 50 tags with an alarm. To be able to associate tags with the
alarm when you create the alarm, you must have the
cloudwatch:TagResource permission.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
If you are using this operation to update an existing alarm, any tags you specify in this parameter are ignored. To change the tags of an existing alarm, use TagResource or UntagResource.
To use this field to set tags for an alarm when you create it, you must be
signed on with both the cloudwatch:PutMetricAlarm and
cloudwatch:TagResource permissions.
Parameter threshold :
The value against which the specified statistic is compared.
This parameter is required for alarms based on static thresholds, but should not be used for alarms based on anomaly detection models.
Parameter thresholdMetricId :
If this is an alarm based on an anomaly detection model, make this value
match the ID of the ANOMALY_DETECTION_BAND function.
For an example of how to use this parameter, see the Anomaly Detection Model Alarm example on this page.
If your alarm uses this parameter, it cannot have Auto Scaling actions.
Parameter treatMissingData :
Sets how this alarm is to handle missing data points. If
TreatMissingData is omitted, the default behavior of
missing is used. For more information, see Configuring
How CloudWatch Alarms Treats Missing Data.
Valid Values: breaching | notBreaching | ignore | missing
Parameter unit :
The unit of measure for the statistic. For example, the units for the
Amazon EC2 NetworkIn metric are Bytes because NetworkIn tracks the number
of bytes that an instance receives on all network interfaces. You can also
specify a unit when you create a custom metric. Units help provide
conceptual meaning to your data. Metric data points that specify a unit of
measure, such as Percent, are aggregated separately. If you are creating
an alarm based on a metric math expression, you can specify the unit for
each metric (if needed) within the objects in the Metrics
array.
If you don't specify Unit, CloudWatch retrieves all unit
types that have been published for the metric and attempts to evaluate the
alarm. Usually, metrics are published with only one unit, so the alarm
works as intended.
However, if the metric is published with multiple types of units and you don't specify a unit, the alarm's behavior is not defined and it behaves unpredictably.
We recommend omitting Unit so that you don't inadvertently
specify an incorrect unit that is not published for this metric. Doing so
causes the alarm to be stuck in the INSUFFICIENT DATA state.
Implementation
Future<void> putMetricAlarm({
required String alarmName,
bool? actionsEnabled,
List<String>? alarmActions,
String? alarmDescription,
ComparisonOperator? comparisonOperator,
int? datapointsToAlarm,
List<Dimension>? dimensions,
String? evaluateLowSampleCountPercentile,
EvaluationCriteria? evaluationCriteria,
int? evaluationInterval,
int? evaluationPeriods,
String? extendedStatistic,
List<String>? insufficientDataActions,
String? metricName,
List<MetricDataQuery>? metrics,
String? namespace,
List<String>? oKActions,
int? period,
Statistic? statistic,
List<Tag>? tags,
double? threshold,
String? thresholdMetricId,
String? treatMissingData,
StandardUnit? unit,
}) async {
_s.validateNumRange(
'datapointsToAlarm',
datapointsToAlarm,
1,
1152921504606846976,
);
_s.validateNumRange(
'evaluationInterval',
evaluationInterval,
10,
3600,
);
_s.validateNumRange(
'evaluationPeriods',
evaluationPeriods,
1,
1152921504606846976,
);
_s.validateNumRange(
'period',
period,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.PutMetricAlarm'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AlarmName': alarmName,
if (actionsEnabled != null) 'ActionsEnabled': actionsEnabled,
if (alarmActions != null) 'AlarmActions': alarmActions,
if (alarmDescription != null) 'AlarmDescription': alarmDescription,
if (comparisonOperator != null)
'ComparisonOperator': comparisonOperator.value,
if (datapointsToAlarm != null) 'DatapointsToAlarm': datapointsToAlarm,
if (dimensions != null) 'Dimensions': dimensions,
if (evaluateLowSampleCountPercentile != null)
'EvaluateLowSampleCountPercentile': evaluateLowSampleCountPercentile,
if (evaluationCriteria != null)
'EvaluationCriteria': evaluationCriteria,
if (evaluationInterval != null)
'EvaluationInterval': evaluationInterval,
if (evaluationPeriods != null) 'EvaluationPeriods': evaluationPeriods,
if (extendedStatistic != null) 'ExtendedStatistic': extendedStatistic,
if (insufficientDataActions != null)
'InsufficientDataActions': insufficientDataActions,
if (metricName != null) 'MetricName': metricName,
if (metrics != null) 'Metrics': metrics,
if (namespace != null) 'Namespace': namespace,
if (oKActions != null) 'OKActions': oKActions,
if (period != null) 'Period': period,
if (statistic != null) 'Statistic': statistic.value,
if (tags != null) 'Tags': tags,
if (threshold != null) 'Threshold': threshold,
if (thresholdMetricId != null) 'ThresholdMetricId': thresholdMetricId,
if (treatMissingData != null) 'TreatMissingData': treatMissingData,
if (unit != null) 'Unit': unit.value,
},
);
}