putMetricData method
Publishes metric data to Amazon CloudWatch. CloudWatch associates the data with the specified metric. If the specified metric does not exist, CloudWatch creates the metric. When CloudWatch creates a metric, it can take up to fifteen minutes for the metric to appear in calls to ListMetrics.
You can publish metrics with associated entity data (so that related
telemetry can be found and viewed together), or publish metric data by
itself. To send entity data with your metrics, use the
EntityMetricData parameter. To send metrics without entity
data, use the MetricData parameter. The
EntityMetricData structure includes MetricData
structures for the metric data.
You can publish either individual values in the Value field,
or arrays of values and the number of times each value occurred during the
period by using the Values and Counts fields in
the MetricData structure. Using the Values and
Counts method enables you to publish up to 150 values per
metric with one PutMetricData request, and supports
retrieving percentile statistics on this data.
Each PutMetricData request is limited to 1 MB in size for
HTTP POST requests. You can send a payload compressed by gzip. Each
request is also limited to no more than 1000 different metrics (across
both the MetricData and EntityMetricData
properties).
Although the Value parameter accepts numbers of type
Double, CloudWatch rejects values that are either too small
or too large. Values must be in the range of -2^360 to 2^360. In addition,
special values (for example, NaN, +Infinity, -Infinity) are not supported.
You can use up to 30 dimensions per metric to further clarify what data the metric collects. Each dimension consists of a Name and Value pair. For more information about specifying dimensions, see Publishing Metrics in the Amazon CloudWatch User Guide.
You specify the time stamp to be associated with each data point. You can specify time stamps that are as much as two weeks before the current date, and as much as 2 hours after the current day and time.
Data points with time stamps from 24 hours ago or longer can take at least 48 hours to become available for GetMetricData or GetMetricStatistics from the time they are submitted. Data points with time stamps between 3 and 24 hours ago can take as much as 2 hours to become available for GetMetricData or GetMetricStatistics.
CloudWatch needs raw data points to calculate percentile statistics. If you publish data using a statistic set instead, you can only retrieve percentile statistics for this data if one of the following conditions is true:
-
The
SampleCountvalue of the statistic set is 1 andMin,Max, andSumare all equal. -
The
MinandMaxare equal, andSumis equal toMinmultiplied bySampleCount.
May throw InternalServiceFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw MissingRequiredParameterException.
Parameter namespace :
The namespace for the metric data. You can use ASCII characters for the
namespace, except for control characters which are not supported.
To avoid conflicts with Amazon Web Services service namespaces, you should
not specify a namespace that begins with AWS/
Parameter entityMetricData :
Data for metrics that contain associated entity information. You can
include up to two EntityMetricData objects, each of which can
contain a single Entity and associated metrics.
The limit of metrics allowed, 1000, is the sum of both
EntityMetricData and MetricData metrics.
Parameter metricData :
The data for the metrics. Use this parameter if your metrics do not
contain associated entities. The array can include no more than 1000
metrics per call.
The limit of metrics allowed, 1000, is the sum of both
EntityMetricData and MetricData metrics.
Parameter strictEntityValidation :
Whether to accept valid metric data when an invalid entity is sent.
-
When set to
true: Any validation error (for entity or metric data) will fail the entire request, and no data will be ingested. The failed operation will return a 400 result with the error. -
When set to
false: Validation errors in the entity will not associate the metric with the entity, but the metric data will still be accepted and ingested. Validation errors in the metric data will fail the entire request, and no data will be ingested.In the case of an invalid entity, the operation will return a
200status, but an additional response header will contain information about the validation errors. The new header,X-Amzn-Failure-Messageis an enumeration of the following values:-
InvalidEntity- The provided entity is invalid. -
InvalidKeyAttributes- The providedKeyAttributesof an entity is invalid. -
InvalidAttributes- The providedAttributesof an entity is invalid. -
InvalidTypeValue- The providedTypein theKeyAttributesof an entity is invalid. -
EntitySizeTooLarge- The number ofEntityMetricDataobjects allowed is 2. -
MissingRequiredFields- There are missing required fields in theKeyAttributesfor the providedType.
-
EntityMetricData is
included.
Implementation
Future<void> putMetricData({
required String namespace,
List<EntityMetricData>? entityMetricData,
List<MetricDatum>? metricData,
bool? strictEntityValidation,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.PutMetricData'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Namespace': namespace,
if (entityMetricData != null) 'EntityMetricData': entityMetricData,
if (metricData != null) 'MetricData': metricData,
if (strictEntityValidation != null)
'StrictEntityValidation': strictEntityValidation,
},
);
}