putMetricStream method
- required String firehoseArn,
- required String name,
- required MetricStreamOutputFormat outputFormat,
- required String roleArn,
- List<
MetricStreamFilter> ? excludeFilters, - List<
MetricStreamFilter> ? includeFilters, - bool? includeLinkedAccountsMetrics,
- List<
MetricStreamStatisticsConfiguration> ? statisticsConfigurations, - List<
Tag> ? tags,
Creates or updates a metric stream. Metric streams can automatically stream CloudWatch metrics to Amazon Web Services destinations, including Amazon S3, and to many third-party solutions.
For more information, see Using Metric Streams.
To create a metric stream, you must be signed in to an account that has
the iam:PassRole permission and either the
CloudWatchFullAccess policy or the
cloudwatch:PutMetricStream permission.
When you create or update a metric stream, you choose one of the following:
- Stream metrics from all metric namespaces in the account.
-
Stream metrics from all metric namespaces in the account, except for the
namespaces that you list in
ExcludeFilters. -
Stream metrics from only the metric namespaces that you list in
IncludeFilters.
MAX,
MIN, SUM, and SAMPLECOUNT
statistics for each metric that is streamed. You can use the
StatisticsConfigurations parameter to have the metric stream
send additional statistics in the stream. Streaming additional statistics
incurs additional costs. For more information, see Amazon CloudWatch
Pricing.
When you use PutMetricStream to create a new metric stream,
the stream is created in the running state. If you use it to
update an existing stream, the state of the stream is not changed.
If you are using CloudWatch cross-account observability and you create a metric stream in a monitoring account, you can choose whether to include metrics from source accounts in the stream. For more information, see CloudWatch cross-account observability.
May throw ConcurrentModificationException.
May throw InternalServiceFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw MissingRequiredParameterException.
Parameter firehoseArn :
The ARN of the Amazon Kinesis Data Firehose delivery stream to use for
this metric stream. This Amazon Kinesis Data Firehose delivery stream must
already exist and must be in the same account as the metric stream.
Parameter name :
If you are creating a new metric stream, this is the name for the new
stream. The name must be different than the names of other metric streams
in this account and Region.
If you are updating a metric stream, specify the name of that stream here.
Valid characters are A-Z, a-z, 0-9, "-" and "_".
Parameter outputFormat :
The output format for the stream. Valid values are json,
opentelemetry1.0, and opentelemetry0.7. For more
information about metric stream output formats, see
Metric streams output formats.
Parameter roleArn :
The ARN of an IAM role that this metric stream will use to access Amazon
Kinesis Data Firehose resources. This IAM role must already exist and must
be in the same account as the metric stream. This IAM role must include
the following permissions:
- firehose:PutRecord
- firehose:PutRecordBatch
Parameter excludeFilters :
If you specify this parameter, the stream sends metrics from all metric
namespaces except for the namespaces that you specify here.
You cannot include ExcludeFilters and
IncludeFilters in the same operation.
Parameter includeFilters :
If you specify this parameter, the stream sends only the metrics from the
metric namespaces that you specify here.
You cannot include IncludeFilters and
ExcludeFilters in the same operation.
Parameter includeLinkedAccountsMetrics :
If you are creating a metric stream in a monitoring account, specify
true to include metrics from source accounts in the metric
stream.
Parameter statisticsConfigurations :
By default, a metric stream always sends the MAX,
MIN, SUM, and SAMPLECOUNT
statistics for each metric that is streamed. You can use this parameter to
have the metric stream also send additional statistics in the stream. This
array can have up to 100 members.
For each entry in this array, you specify one or more metrics and the list
of additional statistics to stream for those metrics. The additional
statistics that you can stream depend on the stream's
OutputFormat. If the OutputFormat is
json, you can stream any additional statistic that is
supported by CloudWatch, listed in
CloudWatch statistics definitions. If the OutputFormat is
opentelemetry1.0 or opentelemetry0.7, you can
stream percentile statistics such as p95, p99.9, and so on.
Parameter tags :
A list of key-value pairs to associate with the metric stream. You can
associate as many as 50 tags with a metric stream.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
You can use this parameter only when you are creating a new metric stream. If you are using this operation to update an existing metric stream, any tags you specify in this parameter are ignored. To change the tags of an existing metric stream, use TagResource or UntagResource.
Implementation
Future<PutMetricStreamOutput> putMetricStream({
required String firehoseArn,
required String name,
required MetricStreamOutputFormat outputFormat,
required String roleArn,
List<MetricStreamFilter>? excludeFilters,
List<MetricStreamFilter>? includeFilters,
bool? includeLinkedAccountsMetrics,
List<MetricStreamStatisticsConfiguration>? statisticsConfigurations,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.PutMetricStream'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FirehoseArn': firehoseArn,
'Name': name,
'OutputFormat': outputFormat.value,
'RoleArn': roleArn,
if (excludeFilters != null) 'ExcludeFilters': excludeFilters,
if (includeFilters != null) 'IncludeFilters': includeFilters,
if (includeLinkedAccountsMetrics != null)
'IncludeLinkedAccountsMetrics': includeLinkedAccountsMetrics,
if (statisticsConfigurations != null)
'StatisticsConfigurations': statisticsConfigurations,
if (tags != null) 'Tags': tags,
},
);
return PutMetricStreamOutput.fromJson(jsonResponse.body);
}