startMetricStreams method
Starts the streaming of metrics for one or more of your metric streams.
May throw InternalServiceFault.
May throw InvalidParameterValueException.
May throw MissingRequiredParameterException.
Parameter names :
The array of the names of metric streams to start streaming.
This is an "all or nothing" operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will start streaming.
Implementation
Future<void> startMetricStreams({
required List<String> names,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.StartMetricStreams'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Names': names,
},
);
}