startOTelEnrichment method
Enables enrichment and PromQL access for CloudWatch vended metrics for supported
Amazon Web Services resources in the account. Once enabled, metrics
that contain a resource identifier dimension (for example, EC2
CPUUtilization with an InstanceId dimension) are
enriched with resource ARN and resource tag labels and become queryable
using PromQL.
Before calling this operation, you must enable resource tags on telemetry for your account. For more information, see Enable resource tags on telemetry.
Implementation
Future<void> startOTelEnrichment() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.StartOTelEnrichment'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}