cloud_watch_2010_08_01 library

Classes

AwsClientCredentials
AWS credentials.
CloudWatch
Amazon CloudWatch monitors your Amazon Web Services (Amazon Web Services) resources and the applications you run on Amazon Web Services in real time. You can use CloudWatch to collect and track metrics, which are the variables you want to measure for your resources and applications.