activateEventSource method

Future<void> activateEventSource({
  1. required String name,
})

Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.

May throw ConcurrentModificationException. May throw InternalException. May throw InvalidStateException. May throw OperationDisabledException. May throw ResourceNotFoundException.

Parameter name : The name of the partner event source to activate.

Implementation

Future<void> activateEventSource({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSEvents.ActivateEventSource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}