deletePartnerEventSource method
This operation is used by SaaS partners to delete a partner event source. This operation is not used by Amazon Web Services customers.
When you delete an event source, the status of the corresponding partner event bus in the Amazon Web Services customer account becomes DELETED.
May throw ConcurrentModificationException.
May throw InternalException.
May throw OperationDisabledException.
Parameter account :
The Amazon Web Services account ID of the Amazon Web Services customer
that the event source was created for.
Parameter name :
The name of the event source to delete.
Implementation
Future<void> deletePartnerEventSource({
required String account,
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.DeletePartnerEventSource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Account': account,
'Name': name,
},
);
}