describeEventSource method
This operation lists details about a partner event source that is shared with your account.
May throw InternalException.
May throw OperationDisabledException.
May throw ResourceNotFoundException.
Parameter name :
The name of the partner event source to display the details of.
Implementation
Future<DescribeEventSourceResponse> describeEventSource({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.DescribeEventSource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
return DescribeEventSourceResponse.fromJson(jsonResponse.body);
}