describePartnerEventSource method

Future<DescribePartnerEventSourceResponse> describePartnerEventSource({
  1. required String name,
})

An SaaS partner can use this operation to list details about a partner event source that they have created. Amazon Web Services customers do not use this operation. Instead, Amazon Web Services customers can use DescribeEventSource to see details about a partner event source that is shared with them.

May throw InternalException. May throw OperationDisabledException. May throw ResourceNotFoundException.

Parameter name : The name of the event source to display.

Implementation

Future<DescribePartnerEventSourceResponse> describePartnerEventSource({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSEvents.DescribePartnerEventSource'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );

  return DescribePartnerEventSourceResponse.fromJson(jsonResponse.body);
}