associateSourceToS3TableIntegration method
Future<AssociateSourceToS3TableIntegrationResponse>
associateSourceToS3TableIntegration({
- required DataSource dataSource,
- required String integrationArn,
Associates a data source with an S3 Table Integration for query access in the 'logs' namespace. This enables querying log data using analytics engines that support Iceberg such as Amazon Athena, Amazon Redshift, and Apache Spark.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter dataSource :
The data source to associate with the S3 Table Integration. Contains the
name and type of the data source.
Parameter integrationArn :
The Amazon Resource Name (ARN) of the S3 Table Integration to associate
the data source with.
Implementation
Future<AssociateSourceToS3TableIntegrationResponse>
associateSourceToS3TableIntegration({
required DataSource dataSource,
required String integrationArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.AssociateSourceToS3TableIntegration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'dataSource': dataSource,
'integrationArn': integrationArn,
},
);
return AssociateSourceToS3TableIntegrationResponse.fromJson(
jsonResponse.body);
}