createDelivery method

Future<CreateDeliveryResponse> createDelivery({
  1. required String deliveryDestinationArn,
  2. required String deliverySourceName,
  3. String? fieldDelimiter,
  4. List<String>? recordFields,
  5. S3DeliveryConfiguration? s3DeliveryConfiguration,
  6. Map<String, String>? tags,
})

Creates a delivery. A delivery is a connection between a logical delivery source and a logical delivery destination that you have already created.

Only some Amazon Web Services services support being configured as a delivery source using this operation. These services are listed as Supported [V2 Permissions] in the table at Enabling logging from Amazon Web Services services.

A delivery destination can represent a log group in CloudWatch Logs, an Amazon S3 bucket, a delivery stream in Firehose, or X-Ray.

To configure logs delivery between a supported Amazon Web Services service and a destination, you must do the following:

  • Create a delivery source, which is a logical object that represents the resource that is actually sending the logs. For more information, see PutDeliverySource.
  • Create a delivery destination, which is a logical object that represents the actual delivery destination. For more information, see PutDeliveryDestination.
  • If you are delivering logs cross-account, you must use PutDeliveryDestinationPolicy in the destination account to assign an IAM policy to the destination. This policy allows delivery to that destination.
  • Use CreateDelivery to create a delivery by pairing exactly one delivery source and one delivery destination.
You can configure a single delivery source to send logs to multiple destinations by creating multiple deliveries. You can also create multiple deliveries to configure multiple delivery sources to send logs to the same delivery destination.

To update an existing delivery configuration, use UpdateDeliveryConfiguration.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw ValidationException.

Parameter deliveryDestinationArn : The ARN of the delivery destination to use for this delivery.

Parameter deliverySourceName : The name of the delivery source to use for this delivery.

Parameter fieldDelimiter : The field delimiter to use between record fields when the final output format of a delivery is in Plain, W3C, or Raw format.

Parameter recordFields : The list of record fields to be delivered to the destination, in order. If the delivery's log source has mandatory fields, they must be included in this list.

Parameter s3DeliveryConfiguration : This structure contains parameters that are valid only when the delivery's delivery destination is an S3 bucket.

Parameter tags : An optional list of key-value pairs to associate with the resource.

For more information about tagging, see Tagging Amazon Web Services resources

Implementation

Future<CreateDeliveryResponse> createDelivery({
  required String deliveryDestinationArn,
  required String deliverySourceName,
  String? fieldDelimiter,
  List<String>? recordFields,
  S3DeliveryConfiguration? s3DeliveryConfiguration,
  Map<String, String>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.CreateDelivery'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'deliveryDestinationArn': deliveryDestinationArn,
      'deliverySourceName': deliverySourceName,
      if (fieldDelimiter != null) 'fieldDelimiter': fieldDelimiter,
      if (recordFields != null) 'recordFields': recordFields,
      if (s3DeliveryConfiguration != null)
        's3DeliveryConfiguration': s3DeliveryConfiguration,
      if (tags != null) 'tags': tags,
    },
  );

  return CreateDeliveryResponse.fromJson(jsonResponse.body);
}