createExportTask method

Future<CreateExportTaskResponse> createExportTask({
  1. required String destination,
  2. required int from,
  3. required String logGroupName,
  4. required int to,
  5. String? destinationPrefix,
  6. String? logStreamNamePrefix,
  7. String? taskName,
})

Creates an export task so that you can efficiently export data from a log group to an Amazon S3 bucket. When you perform a CreateExportTask operation, you must use credentials that have permission to write to the S3 bucket that you specify as the destination.

Exporting log data to S3 buckets that are encrypted by KMS is supported. Exporting log data to Amazon S3 buckets that have S3 Object Lock enabled with a retention period is also supported.

Exporting to S3 buckets that are encrypted with AES-256 is supported.

This is an asynchronous call. If all the required information is provided, this operation initiates an export task and responds with the ID of the task. After the task has started, you can use DescribeExportTasks to get the status of the export task. Each account can only have one active (RUNNING or PENDING) export task at a time. To cancel an export task, use CancelExportTask.

You can export logs from multiple log groups or multiple time ranges to the same S3 bucket. To separate log data for each export task, specify a prefix to be used as the Amazon S3 key prefix for all exported objects.

May throw InvalidParameterException. May throw LimitExceededException. May throw OperationAbortedException. May throw ResourceAlreadyExistsException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter destination : The name of S3 bucket for the exported log data. The bucket must be in the same Amazon Web Services Region.

Parameter from : The start time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp earlier than this time are not exported.

Parameter logGroupName : The name of the log group.

Parameter to : The end time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp later than this time are not exported.

You must specify a time that is not earlier than when this log group was created.

Parameter destinationPrefix : The prefix used as the start of the key for every object exported. If you don't specify a value, the default is exportedlogs.

The length of this parameter must comply with the S3 object key name length limits. The object key name is a sequence of Unicode characters with UTF-8 encoding, and can be up to 1,024 bytes.

Parameter logStreamNamePrefix : Export only log streams that match the provided prefix. If you don't specify a value, no prefix filter is applied.

Parameter taskName : The name of the export task.

Implementation

Future<CreateExportTaskResponse> createExportTask({
  required String destination,
  required int from,
  required String logGroupName,
  required int to,
  String? destinationPrefix,
  String? logStreamNamePrefix,
  String? taskName,
}) async {
  _s.validateNumRange(
    'from',
    from,
    0,
    1152921504606846976,
    isRequired: true,
  );
  _s.validateNumRange(
    'to',
    to,
    0,
    1152921504606846976,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.CreateExportTask'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'destination': destination,
      'from': from,
      'logGroupName': logGroupName,
      'to': to,
      if (destinationPrefix != null) 'destinationPrefix': destinationPrefix,
      if (logStreamNamePrefix != null)
        'logStreamNamePrefix': logStreamNamePrefix,
      if (taskName != null) 'taskName': taskName,
    },
  );

  return CreateExportTaskResponse.fromJson(jsonResponse.body);
}