createLogStream method
Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored.
There is no limit on the number of log streams that you can create for a
log group. There is a limit of 50 TPS on CreateLogStream
operations, after which transactions are throttled.
You must use the following guidelines when naming a log stream:
- Log stream names must be unique within the log group.
- Log stream names can be between 1 and 512 characters long.
- Don't use ':' (colon) or '*' (asterisk) characters.
May throw InvalidParameterException.
May throw ResourceAlreadyExistsException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter logGroupName :
The name of the log group.
Parameter logStreamName :
The name of the log stream.
Implementation
Future<void> createLogStream({
required String logGroupName,
required String logStreamName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.CreateLogStream'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupName': logGroupName,
'logStreamName': logStreamName,
},
);
}