deleteAccountPolicy method
Deletes a CloudWatch Logs account policy. This stops the account-wide policy from applying to log groups or data sources in the account. If you delete a data protection policy or subscription filter policy, any log-group level policies of those types remain in effect. This operation supports deletion of data source-based field index policies, including facet configurations, in addition to log group-based policies.
To use this operation, you must be signed on with the correct permissions depending on the type of policy that you are deleting.
-
To delete a data protection policy, you must have the
logs:DeleteDataProtectionPolicyandlogs:DeleteAccountPolicypermissions. -
To delete a subscription filter policy, you must have the
logs:DeleteSubscriptionFilterandlogs:DeleteAccountPolicypermissions. -
To delete a transformer policy, you must have the
logs:DeleteTransformerandlogs:DeleteAccountPolicypermissions. -
To delete a field index policy, you must have the
logs:DeleteIndexPolicyandlogs:DeleteAccountPolicypermissions.If you delete a field index policy that included facet configurations, those facets will no longer be available for interactive exploration in the CloudWatch Logs Insights console. However, facet data is retained for up to 30 days.
May throw InvalidParameterException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter policyName :
The name of the policy to delete.
Parameter policyType :
The type of policy to delete.
Implementation
Future<void> deleteAccountPolicy({
required String policyName,
required PolicyType policyType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteAccountPolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'policyName': policyName,
'policyType': policyType.value,
},
);
}