deleteLogGroup method
Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
May throw InvalidParameterException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ValidationException.
Parameter logGroupName :
The name of the log group.
Implementation
Future<void> deleteLogGroup({
required String logGroupName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteLogGroup'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupName': logGroupName,
},
);
}