deleteLookupTable method
Deletes a lookup table permanently. This operation cannot be undone.
Queries that reference a deleted table will return an error. Before deleting a lookup table, review any saved queries or dashboards that may reference it.
May throw AccessDeniedException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter lookupTableArn :
The ARN of the lookup table to delete.
Implementation
Future<void> deleteLookupTable({
required String lookupTableArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteLookupTable'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'lookupTableArn': lookupTableArn,
},
);
}