deleteScheduledQuery method
Deletes a scheduled query and stops all future executions. This operation also removes any configured actions and associated resources.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The ARN or name of the scheduled query to delete.
Implementation
Future<void> deleteScheduledQuery({
required String identifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteScheduledQuery'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'identifier': identifier,
},
);
}