deleteSyslogConfiguration method

Future<void> deleteSyslogConfiguration({
  1. required String logGroupIdentifier,
  2. String? vpcEndpointId,
})

Deletes a syslog configuration for a log group. After deletion, syslog data is no longer ingested through the specified VPC endpoint.

May throw AccessDeniedException. May throw InvalidOperationException. May throw InvalidParameterException. May throw OperationAbortedException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter logGroupIdentifier : The name or ARN of the log group to remove the syslog configuration from.

Parameter vpcEndpointId : The ID of the VPC endpoint associated with the syslog configuration to delete.

Implementation

Future<void> deleteSyslogConfiguration({
  required String logGroupIdentifier,
  String? vpcEndpointId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.DeleteSyslogConfiguration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'logGroupIdentifier': logGroupIdentifier,
      if (vpcEndpointId != null) 'vpcEndpointId': vpcEndpointId,
    },
  );
}