describeDeliveryDestinations method

Future<DescribeDeliveryDestinationsResponse> describeDeliveryDestinations({
  1. int? limit,
  2. String? nextToken,
})

Retrieves a list of the delivery destinations that have been created in the account.

May throw ServiceQuotaExceededException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw ValidationException.

Parameter limit : Optionally specify the maximum number of delivery destinations to return in the response.

Implementation

Future<DescribeDeliveryDestinationsResponse> describeDeliveryDestinations({
  int? limit,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    50,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.DescribeDeliveryDestinations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (limit != null) 'limit': limit,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return DescribeDeliveryDestinationsResponse.fromJson(jsonResponse.body);
}