describeDeliverySources method
Retrieves a list of the delivery sources that have been created in the account.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter limit :
Optionally specify the maximum number of delivery sources to return in the
response.
Implementation
Future<DescribeDeliverySourcesResponse> describeDeliverySources({
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
50,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DescribeDeliverySources'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (limit != null) 'limit': limit,
if (nextToken != null) 'nextToken': nextToken,
},
);
return DescribeDeliverySourcesResponse.fromJson(jsonResponse.body);
}