describeLookupTables method

Future<DescribeLookupTablesResponse> describeLookupTables({
  1. String? lookupTableNamePrefix,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves metadata about lookup tables in your account. You can optionally filter the results by table name prefix. Results are sorted by table name in ascending order.

May throw AccessDeniedException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter lookupTableNamePrefix : A prefix to filter lookup tables by name. Only tables whose names start with this prefix are returned. If you don't specify a prefix, all tables in the account and Region are returned.

Parameter maxResults : The maximum number of lookup tables to return in the response. The default value is 50 and the maximum value is 100.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<DescribeLookupTablesResponse> describeLookupTables({
  String? lookupTableNamePrefix,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.DescribeLookupTables'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (lookupTableNamePrefix != null)
        'lookupTableNamePrefix': lookupTableNamePrefix,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return DescribeLookupTablesResponse.fromJson(jsonResponse.body);
}