getDataProtectionPolicy method

Future<GetDataProtectionPolicyResponse> getDataProtectionPolicy({
  1. required String logGroupIdentifier,
})

Returns information about a log group data protection policy.

May throw InvalidParameterException. May throw OperationAbortedException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter logGroupIdentifier : The name or ARN of the log group that contains the data protection policy that you want to see.

Implementation

Future<GetDataProtectionPolicyResponse> getDataProtectionPolicy({
  required String logGroupIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.GetDataProtectionPolicy'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'logGroupIdentifier': logGroupIdentifier,
    },
  );

  return GetDataProtectionPolicyResponse.fromJson(jsonResponse.body);
}