getIntegration method

Future<GetIntegrationResponse> getIntegration({
  1. required String integrationName,
})

Returns information about one integration between CloudWatch Logs and OpenSearch Service.

May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter integrationName : The name of the integration that you want to find information about. To find the name of your integration, use ListIntegrations

Implementation

Future<GetIntegrationResponse> getIntegration({
  required String integrationName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.GetIntegration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'integrationName': integrationName,
    },
  );

  return GetIntegrationResponse.fromJson(jsonResponse.body);
}