getScheduledQuery method

Future<GetScheduledQueryResponse> getScheduledQuery({
  1. required String identifier,
})

Retrieves details about a specific scheduled query, including its configuration, execution status, and metadata.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : The ARN or name of the scheduled query to retrieve.

Implementation

Future<GetScheduledQueryResponse> getScheduledQuery({
  required String identifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Logs_20140328.GetScheduledQuery'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'identifier': identifier,
    },
  );

  return GetScheduledQueryResponse.fromJson(jsonResponse.body);
}