getTransformer method
Returns the information about the log transformer associated with this log group.
This operation returns data only for transformers created at the log group level. To get information for an account-level transformer, use DescribeAccountPolicies.
May throw InvalidOperationException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter logGroupIdentifier :
Specify either the name or ARN of the log group to return transformer
information for. If the log group is in a source account and you are using
a monitoring account, you must use the log group ARN.
Implementation
Future<GetTransformerResponse> getTransformer({
required String logGroupIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.GetTransformer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupIdentifier': logGroupIdentifier,
},
);
return GetTransformerResponse.fromJson(jsonResponse.body);
}