listSourcesForS3TableIntegration method
Returns a list of data source associations for a specified S3 Table Integration, showing which data sources are currently associated for query access.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter integrationArn :
The Amazon Resource Name (ARN) of the S3 Table Integration to list
associations for.
Parameter maxResults :
The maximum number of associations to return in a single call. Valid range
is 1 to 100.
Implementation
Future<ListSourcesForS3TableIntegrationResponse>
listSourcesForS3TableIntegration({
required String integrationArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.ListSourcesForS3TableIntegration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'integrationArn': integrationArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListSourcesForS3TableIntegrationResponse.fromJson(jsonResponse.body);
}