putDeliveryDestinationPolicy method
Creates and assigns an IAM policy that grants permissions to CloudWatch Logs to deliver logs cross-account to a specified destination in this account. To configure the delivery of logs from an Amazon Web Services service in another account to a logs delivery destination in the current account, you must do the following:
- Create a delivery source, which is a logical object that represents the resource that is actually sending the logs. For more information, see PutDeliverySource.
- Create a delivery destination, which is a logical object that represents the actual delivery destination. For more information, see PutDeliveryDestination.
- Use this operation in the destination account to assign an IAM policy to the destination. This policy allows delivery to that destination.
- Create a delivery by pairing exactly one delivery source and one delivery destination. For more information, see CreateDelivery.
The contents of the policy must include two statements. One statement enables general logs delivery, and the other allows delivery to the chosen destination. See the examples for the needed policies.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ValidationException.
Parameter deliveryDestinationName :
The name of the delivery destination to assign this policy to.
Parameter deliveryDestinationPolicy :
The contents of the policy.
Implementation
Future<PutDeliveryDestinationPolicyResponse> putDeliveryDestinationPolicy({
required String deliveryDestinationName,
required String deliveryDestinationPolicy,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.PutDeliveryDestinationPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'deliveryDestinationName': deliveryDestinationName,
'deliveryDestinationPolicy': deliveryDestinationPolicy,
},
);
return PutDeliveryDestinationPolicyResponse.fromJson(jsonResponse.body);
}