putIndexPolicy method
Creates or updates a field index policy for the specified log group. Only log groups in the Standard log class support field index policies. For more information about log classes, see Log classes.
You can use field index policies to create field indexes on fields found in log events in the log group. Creating field indexes speeds up and lowers the costs for CloudWatch Logs Insights queries that reference those field indexes, because these queries attempt to skip the processing of log events that are known to not match the indexed field. Good fields to index are fields that you often need to query for and fields or values that match only a small fraction of the total log events. Common examples of indexes include request ID, session ID, userID, and instance IDs. For more information, see Create field indexes to improve query performance and reduce costs.
You can configure indexed fields as facets to enable interactive exploration and filtering of your logs in the CloudWatch Logs Insights console. Facets allow you to view value distributions and counts for indexed fields without running queries. When you create a field index, you can optionally set it as a facet to enable this interactive analysis capability. For more information, see Use facets to group and explore logs.
To find the fields that are in your log group events, use the GetLogGroupFields operation.
For example, suppose you have created a field index for
requestId. Then, any CloudWatch Logs Insights query on that
log group that includes requestId = value or
requestId IN [value, value, ...] will process
fewer log events to reduce costs, and have improved performance.
CloudWatch Logs provides default field indexes for all log groups in the Standard log class. Default field indexes are automatically available for the following fields:
-
@logStream -
@aws.region -
@aws.account -
@source.log -
traceId
Each index policy has the following quotas and restrictions:
- As many as 20 fields can be included in the policy.
- Each field name can include as many as 100 characters.
RequestId won't match a log
event containing requestId.
Log group-level field index policies created with
PutIndexPolicy override account-level field index policies
created with PutAccountPolicy
that apply to log groups. If you use PutIndexPolicy to create
a field index policy for a log group, that log group uses only that policy
for log group-level indexing, including any facet configurations. The log
group ignores any account-wide field index policy that applies to log
groups, but data source-based account policies may still apply.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter logGroupIdentifier :
Specify either the log group name or log group ARN to apply this field
index policy to. If you specify an ARN, use the format
arn:aws:logs:region:account-id:log-group:log_group_name
Don't include an * at the end.
Parameter policyDocument :
The index policy document, in JSON format. The following is an example of
an index policy document that creates indexes with different types.
"policyDocument": "{"Fields": [ "TransactionId" ], "FieldsV2":
{"RequestId": {"type": "FIELD_INDEX"}, "APIName": {"type": "FACET"},
"StatusCode": {"type": "FACET"}}}"
You can use FieldsV2 to specify the type for each field.
Supported types are FIELD_INDEX and FACET. Field
names within Fields and FieldsV2 must be
mutually exclusive.
The policy document must include at least one field index. For more information about the fields that can be included and other restrictions, see Field index syntax and quotas.
Implementation
Future<PutIndexPolicyResponse> putIndexPolicy({
required String logGroupIdentifier,
required String policyDocument,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.PutIndexPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupIdentifier': logGroupIdentifier,
'policyDocument': policyDocument,
},
);
return PutIndexPolicyResponse.fromJson(jsonResponse.body);
}