putQueryDefinition method
Creates or updates a query definition for CloudWatch Logs Insights. For more information, see Analyzing Log Data with CloudWatch Logs Insights.
To update a query definition, specify its queryDefinitionId
in your request. The values of name,
queryString, and logGroupNames are changed to
the values that you specify in your update operation. No current values
are retained from the current query definition. For example, imagine
updating a current query definition that includes log groups. If you don't
specify the logGroupNames parameter in your update operation,
the query definition changes to contain no log groups.
You must have the logs:PutQueryDefinition permission to be
able to perform this operation.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter name :
A name for the query definition. If you are saving numerous query
definitions, we recommend that you name them. This way, you can find the
ones you want by using the first part of the name as a filter in the
queryDefinitionNamePrefix parameter of DescribeQueryDefinitions.
Parameter queryString :
The query string to use for this definition. For more information, see CloudWatch
Logs Insights Query Syntax.
Parameter clientToken :
Used as an idempotency token, to avoid returning an exception if the
service receives the same request twice because of a network error.
Parameter logGroupNames :
Use this parameter to include specific log groups as part of your query
definition. If your query uses the OpenSearch Service query language, you
specify the log group names inside the querystring instead of
here.
If you are updating an existing query definition for the Logs Insights QL or OpenSearch Service PPL and you omit this parameter, then the updated definition will contain no log groups.
Parameter parameters :
Use this parameter to include specific query parameters as part of your
query definition. Query parameters are supported only for Logs Insights QL
queries. Query parameters allow you to use placeholder variables in your
query string that are substituted with values at execution time. Use the
{{parameterName}} syntax in your query string to reference a
parameter.
Parameter queryDefinitionId :
If you are updating a query definition, use this parameter to specify the
ID of the query definition that you want to update. You can use DescribeQueryDefinitions
to retrieve the IDs of your saved query definitions.
If you are creating a query definition, do not specify this parameter. CloudWatch generates a unique ID for the new query definition and include it in the response to this operation.
Parameter queryLanguage :
Specify the query language to use for this query. The options are Logs
Insights QL, OpenSearch PPL, and OpenSearch SQL. For more information
about the query languages that CloudWatch Logs supports, see Supported
query languages.
Implementation
Future<PutQueryDefinitionResponse> putQueryDefinition({
required String name,
required String queryString,
String? clientToken,
List<String>? logGroupNames,
List<QueryParameter>? parameters,
String? queryDefinitionId,
QueryLanguage? queryLanguage,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.PutQueryDefinition'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'name': name,
'queryString': queryString,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (logGroupNames != null) 'logGroupNames': logGroupNames,
if (parameters != null) 'parameters': parameters,
if (queryDefinitionId != null) 'queryDefinitionId': queryDefinitionId,
if (queryLanguage != null) 'queryLanguage': queryLanguage.value,
},
);
return PutQueryDefinitionResponse.fromJson(jsonResponse.body);
}