startQuery method
Starts a query of one or more log groups or data sources using CloudWatch Logs Insights. You specify the log groups or data sources and time range to query and the query string to use. You can query up to 10 data sources in a single query.
For more information, see CloudWatch Logs Insights Query Syntax.
After you run a query using StartQuery, the query results are
stored by CloudWatch Logs. You can use GetQueryResults
to retrieve the results of a query, using the queryId that
StartQuery returns.
Interactive queries started with StartQuery share concurrency
limits with automated scheduled query executions. Both types of queries
count toward the same regional concurrent query quota, so high scheduled
query activity may affect the availability of concurrent slots for
interactive queries.
-
Either exactly one of the following parameters:
logGroupName,logGroupNames, orlogGroupIdentifiers -
Or the
queryStringmust include aSOURCEcommand to select log groups for the query. TheSOURCEcommand can select log groups based on log group name prefix, account ID, and log class, or select data sources using dataSource syntax in LogsQL, PPL, and SQL. In LogsQL, theSOURCEcommand also supports filtering by log group tags.For more information about the
SOURCEcommand, see SOURCE.
Queries time out after 60 minutes of runtime. If your queries are timing out, reduce the time range being searched or partition your query into a number of queries.
If you are using CloudWatch cross-account observability, you can use this
operation in a monitoring account to start a query in a linked source
account. For more information, see CloudWatch
cross-account observability. For a cross-account
StartQuery operation, the query definition must be defined in
the monitoring account.
You can have up to 100 concurrent CloudWatch Logs insights queries, including queries that have been added to dashboards.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw MalformedQueryException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter endTime :
The end of the time range to query. The range is inclusive, so the
specified end time is included in the query. Specified as epoch time, the
number of seconds since January 1, 1970, 00:00:00 UTC.
Parameter queryString :
The query string to use. For more information, see CloudWatch
Logs Insights Query Syntax.
Parameter startTime :
The beginning of the time range to query. The range is inclusive, so the
specified start time is included in the query. Specified as epoch time,
the number of seconds since January 1, 1970, 00:00:00 UTC.
Parameter limit :
The maximum number of log events to return in the query. If the query
string uses the fields command, only the specified fields and
their values are returned. The default is 10,000.
The maximum value is 100,000.
Parameter logGroupIdentifiers :
The list of log groups to query. You can include up to 50 log groups.
You can specify them by the log group name or ARN. If a log group that you're querying is in a source account and you're using a monitoring account, you must specify the ARN of the log group here. The query definition must also be defined in the monitoring account.
If you specify an ARN, use the format arn:aws:logs:region:account-id:log-group:log_group_name Don't include an * at the end.
A StartQuery operation must include exactly one of the
following parameters: logGroupName,
logGroupNames, or logGroupIdentifiers. The
exception is queries using the OpenSearch Service SQL query language,
where you specify the log group names inside the querystring
instead of here.
Parameter logGroupName :
The log group on which to perform the query.
Parameter logGroupNames :
The list of log groups to be queried. You can include up to 50 log groups.
Parameter queryLanguage :
Specify the query language to use for this query. The options are Logs
Insights QL, OpenSearch PPL, and OpenSearch SQL. For more information
about the query languages that CloudWatch Logs supports, see Supported
query languages.
Implementation
Future<StartQueryResponse> startQuery({
required int endTime,
required String queryString,
required int startTime,
int? limit,
List<String>? logGroupIdentifiers,
String? logGroupName,
List<String>? logGroupNames,
QueryLanguage? queryLanguage,
}) async {
_s.validateNumRange(
'endTime',
endTime,
0,
1152921504606846976,
isRequired: true,
);
_s.validateNumRange(
'startTime',
startTime,
0,
1152921504606846976,
isRequired: true,
);
_s.validateNumRange(
'limit',
limit,
1,
100000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.StartQuery'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'endTime': endTime,
'queryString': queryString,
'startTime': startTime,
if (limit != null) 'limit': limit,
if (logGroupIdentifiers != null)
'logGroupIdentifiers': logGroupIdentifiers,
if (logGroupName != null) 'logGroupName': logGroupName,
if (logGroupNames != null) 'logGroupNames': logGroupNames,
if (queryLanguage != null) 'queryLanguage': queryLanguage.value,
},
);
return StartQueryResponse.fromJson(jsonResponse.body);
}