CodeBuild class

CodeBuild is a fully managed build service in the cloud. CodeBuild compiles your source code, runs unit tests, and produces artifacts that are ready to deploy. CodeBuild eliminates the need to provision, manage, and scale your own build servers. It provides prepackaged build environments for the most popular programming languages and build tools, such as Apache Maven, Gradle, and more. You can also fully customize build environments in CodeBuild to use your own build tools. CodeBuild scales automatically to meet peak build requests. You pay only for the build time you consume. For more information about CodeBuild, see the CodeBuild User Guide.

Constructors

CodeBuild({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchDeleteBuilds({required List<String> ids}) Future<BatchDeleteBuildsOutput>
Deletes one or more builds.
batchGetBuildBatches({required List<String> ids}) Future<BatchGetBuildBatchesOutput>
Retrieves information about one or more batch builds.
batchGetBuilds({required List<String> ids}) Future<BatchGetBuildsOutput>
Gets information about one or more builds.
batchGetCommandExecutions({required List<String> commandExecutionIds, required String sandboxId}) Future<BatchGetCommandExecutionsOutput>
Gets information about the command executions.
batchGetFleets({required List<String> names}) Future<BatchGetFleetsOutput>
Gets information about one or more compute fleets.
batchGetProjects({required List<String> names}) Future<BatchGetProjectsOutput>
Gets information about one or more build projects.
batchGetReportGroups({required List<String> reportGroupArns}) Future<BatchGetReportGroupsOutput>
Returns an array of report groups.
batchGetReports({required List<String> reportArns}) Future<BatchGetReportsOutput>
Returns an array of reports.
batchGetSandboxes({required List<String> ids}) Future<BatchGetSandboxesOutput>
Gets information about the sandbox status.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createFleet({required int baseCapacity, required ComputeType computeType, required EnvironmentType environmentType, required String name, ComputeConfiguration? computeConfiguration, String? fleetServiceRole, String? imageId, FleetOverflowBehavior? overflowBehavior, ProxyConfiguration? proxyConfiguration, ScalingConfigurationInput? scalingConfiguration, List<Tag>? tags, VpcConfig? vpcConfig}) Future<CreateFleetOutput>
Creates a compute fleet.
createProject({required ProjectArtifacts artifacts, required ProjectEnvironment environment, required String name, required String serviceRole, required ProjectSource source, int? autoRetryLimit, bool? badgeEnabled, ProjectBuildBatchConfig? buildBatchConfig, ProjectCache? cache, int? concurrentBuildLimit, String? description, String? encryptionKey, List<ProjectFileSystemLocation>? fileSystemLocations, LogsConfig? logsConfig, int? queuedTimeoutInMinutes, List<ProjectArtifacts>? secondaryArtifacts, List<ProjectSourceVersion>? secondarySourceVersions, List<ProjectSource>? secondarySources, String? sourceVersion, List<Tag>? tags, int? timeoutInMinutes, VpcConfig? vpcConfig}) Future<CreateProjectOutput>
Creates a build project.
createReportGroup({required ReportExportConfig exportConfig, required String name, required ReportType type, List<Tag>? tags}) Future<CreateReportGroupOutput>
Creates a report group. A report group contains a collection of reports.
createWebhook({required String projectName, String? branchFilter, WebhookBuildType? buildType, List<List<WebhookFilter>>? filterGroups, bool? manualCreation, PullRequestBuildPolicy? pullRequestBuildPolicy, ScopeConfiguration? scopeConfiguration}) Future<CreateWebhookOutput>
For an existing CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables CodeBuild to start rebuilding the source code every time a code change is pushed to the repository.
deleteBuildBatch({required String id}) Future<DeleteBuildBatchOutput>
Deletes a batch build.
deleteFleet({required String arn}) Future<void>
Deletes a compute fleet. When you delete a compute fleet, its builds are not deleted.
deleteProject({required String name}) Future<void>
Deletes a build project. When you delete a project, its builds are not deleted.
deleteReport({required String arn}) Future<void>
Deletes a report.
deleteReportGroup({required String arn, bool? deleteReports}) Future<void>
Deletes a report group. Before you delete a report group, you must delete its reports.
deleteResourcePolicy({required String resourceArn}) Future<void>
Deletes a resource policy that is identified by its resource ARN.
deleteSourceCredentials({required String arn}) Future<DeleteSourceCredentialsOutput>
Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.
deleteWebhook({required String projectName}) Future<void>
For an existing CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code every time a code change is pushed to the repository.
describeCodeCoverages({required String reportArn, double? maxLineCoveragePercentage, int? maxResults, double? minLineCoveragePercentage, String? nextToken, ReportCodeCoverageSortByType? sortBy, SortOrderType? sortOrder}) Future<DescribeCodeCoveragesOutput>
Retrieves one or more code coverage reports.
describeTestCases({required String reportArn, TestCaseFilter? filter, int? maxResults, String? nextToken}) Future<DescribeTestCasesOutput>
Returns a list of details about test cases for a report.
getReportGroupTrend({required String reportGroupArn, required ReportGroupTrendFieldType trendField, int? numOfReports}) Future<GetReportGroupTrendOutput>
Analyzes and accumulates test report values for the specified test reports.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyOutput>
Gets a resource policy that is identified by its resource ARN.
importSourceCredentials({required AuthType authType, required ServerType serverType, required String token, bool? shouldOverwrite, String? username}) Future<ImportSourceCredentialsOutput>
Imports the source repository credentials for an CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed, or Bitbucket repository.
invalidateProjectCache({required String projectName}) Future<void>
Resets the cache for a project.
listBuildBatches({BuildBatchFilter? filter, int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListBuildBatchesOutput>
Retrieves the identifiers of your build batches in the current region.
listBuildBatchesForProject({BuildBatchFilter? filter, int? maxResults, String? nextToken, String? projectName, SortOrderType? sortOrder}) Future<ListBuildBatchesForProjectOutput>
Retrieves the identifiers of the build batches for a specific project.
listBuilds({String? nextToken, SortOrderType? sortOrder}) Future<ListBuildsOutput>
Gets a list of build IDs, with each build ID representing a single build.
listBuildsForProject({required String projectName, String? nextToken, SortOrderType? sortOrder}) Future<ListBuildsForProjectOutput>
Gets a list of build identifiers for the specified build project, with each build identifier representing a single build.
listCommandExecutionsForSandbox({required String sandboxId, int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListCommandExecutionsForSandboxOutput>
Gets a list of command executions for a sandbox.
listCuratedEnvironmentImages() Future<ListCuratedEnvironmentImagesOutput>
Gets information about Docker images that are managed by CodeBuild.
listFleets({int? maxResults, String? nextToken, FleetSortByType? sortBy, SortOrderType? sortOrder}) Future<ListFleetsOutput>
Gets a list of compute fleet names with each compute fleet name representing a single compute fleet.
listProjects({String? nextToken, ProjectSortByType? sortBy, SortOrderType? sortOrder}) Future<ListProjectsOutput>
Gets a list of build project names, with each build project name representing a single build project.
listReportGroups({int? maxResults, String? nextToken, ReportGroupSortByType? sortBy, SortOrderType? sortOrder}) Future<ListReportGroupsOutput>
Gets a list ARNs for the report groups in the current Amazon Web Services account.
listReports({ReportFilter? filter, int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListReportsOutput>
Returns a list of ARNs for the reports in the current Amazon Web Services account.
listReportsForReportGroup({required String reportGroupArn, ReportFilter? filter, int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListReportsForReportGroupOutput>
Returns a list of ARNs for the reports that belong to a ReportGroup.
listSandboxes({int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListSandboxesOutput>
Gets a list of sandboxes.
listSandboxesForProject({required String projectName, int? maxResults, String? nextToken, SortOrderType? sortOrder}) Future<ListSandboxesForProjectOutput>
Gets a list of sandboxes for a given project.
listSharedProjects({int? maxResults, String? nextToken, SharedResourceSortByType? sortBy, SortOrderType? sortOrder}) Future<ListSharedProjectsOutput>
Gets a list of projects that are shared with other Amazon Web Services accounts or users.
listSharedReportGroups({int? maxResults, String? nextToken, SharedResourceSortByType? sortBy, SortOrderType? sortOrder}) Future<ListSharedReportGroupsOutput>
Gets a list of report groups that are shared with other Amazon Web Services accounts or users.
listSourceCredentials() Future<ListSourceCredentialsOutput>
Returns a list of SourceCredentialsInfo objects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String policy, required String resourceArn}) Future<PutResourcePolicyOutput>
Stores a resource policy for the ARN of a Project or ReportGroup object.
retryBuild({String? id, String? idempotencyToken}) Future<RetryBuildOutput>
Restarts a build.
retryBuildBatch({String? id, String? idempotencyToken, RetryBuildBatchType? retryType}) Future<RetryBuildBatchOutput>
Restarts a failed batch build. Only batch builds that have failed can be retried.
startBuild({required String projectName, ProjectArtifacts? artifactsOverride, int? autoRetryLimitOverride, BuildStatusConfig? buildStatusConfigOverride, String? buildspecOverride, ProjectCache? cacheOverride, String? certificateOverride, ComputeType? computeTypeOverride, bool? debugSessionEnabled, String? encryptionKeyOverride, EnvironmentType? environmentTypeOverride, List<EnvironmentVariable>? environmentVariablesOverride, ProjectFleet? fleetOverride, int? gitCloneDepthOverride, GitSubmodulesConfig? gitSubmodulesConfigOverride, String? idempotencyToken, String? imageOverride, ImagePullCredentialsType? imagePullCredentialsTypeOverride, bool? insecureSslOverride, LogsConfig? logsConfigOverride, bool? privilegedModeOverride, int? queuedTimeoutInMinutesOverride, RegistryCredential? registryCredentialOverride, bool? reportBuildStatusOverride, List<ProjectArtifacts>? secondaryArtifactsOverride, List<ProjectSource>? secondarySourcesOverride, List<ProjectSourceVersion>? secondarySourcesVersionOverride, String? serviceRoleOverride, SourceAuth? sourceAuthOverride, String? sourceLocationOverride, SourceType? sourceTypeOverride, String? sourceVersion, int? timeoutInMinutesOverride}) Future<StartBuildOutput>
Starts running a build with the settings defined in the project. These setting include: how to run a build, where to get the source code, which build environment to use, which build commands to run, and where to store the build output.
startBuildBatch({required String projectName, ProjectArtifacts? artifactsOverride, ProjectBuildBatchConfig? buildBatchConfigOverride, int? buildTimeoutInMinutesOverride, String? buildspecOverride, ProjectCache? cacheOverride, String? certificateOverride, ComputeType? computeTypeOverride, bool? debugSessionEnabled, String? encryptionKeyOverride, EnvironmentType? environmentTypeOverride, List<EnvironmentVariable>? environmentVariablesOverride, int? gitCloneDepthOverride, GitSubmodulesConfig? gitSubmodulesConfigOverride, String? idempotencyToken, String? imageOverride, ImagePullCredentialsType? imagePullCredentialsTypeOverride, bool? insecureSslOverride, LogsConfig? logsConfigOverride, bool? privilegedModeOverride, int? queuedTimeoutInMinutesOverride, RegistryCredential? registryCredentialOverride, bool? reportBuildBatchStatusOverride, List<ProjectArtifacts>? secondaryArtifactsOverride, List<ProjectSource>? secondarySourcesOverride, List<ProjectSourceVersion>? secondarySourcesVersionOverride, String? serviceRoleOverride, SourceAuth? sourceAuthOverride, String? sourceLocationOverride, SourceType? sourceTypeOverride, String? sourceVersion}) Future<StartBuildBatchOutput>
Starts a batch build for a project.
startCommandExecution({required String command, required String sandboxId, CommandType? type}) Future<StartCommandExecutionOutput>
Starts a command execution.
startSandbox({String? idempotencyToken, String? projectName}) Future<StartSandboxOutput>
Starts a sandbox.
startSandboxConnection({required String sandboxId}) Future<StartSandboxConnectionOutput>
Starts a sandbox connection.
stopBuild({required String id}) Future<StopBuildOutput>
Attempts to stop running a build.
stopBuildBatch({required String id}) Future<StopBuildBatchOutput>
Stops a running batch build.
stopSandbox({required String id}) Future<StopSandboxOutput>
Stops a sandbox.
toString() String
A string representation of this object.
inherited
updateFleet({required String arn, int? baseCapacity, ComputeConfiguration? computeConfiguration, ComputeType? computeType, EnvironmentType? environmentType, String? fleetServiceRole, String? imageId, FleetOverflowBehavior? overflowBehavior, ProxyConfiguration? proxyConfiguration, ScalingConfigurationInput? scalingConfiguration, List<Tag>? tags, VpcConfig? vpcConfig}) Future<UpdateFleetOutput>
Updates a compute fleet.
updateProject({required String name, ProjectArtifacts? artifacts, int? autoRetryLimit, bool? badgeEnabled, ProjectBuildBatchConfig? buildBatchConfig, ProjectCache? cache, int? concurrentBuildLimit, String? description, String? encryptionKey, ProjectEnvironment? environment, List<ProjectFileSystemLocation>? fileSystemLocations, LogsConfig? logsConfig, int? queuedTimeoutInMinutes, List<ProjectArtifacts>? secondaryArtifacts, List<ProjectSourceVersion>? secondarySourceVersions, List<ProjectSource>? secondarySources, String? serviceRole, ProjectSource? source, String? sourceVersion, List<Tag>? tags, int? timeoutInMinutes, VpcConfig? vpcConfig}) Future<UpdateProjectOutput>
Changes the settings of a build project.
updateProjectVisibility({required String projectArn, required ProjectVisibilityType projectVisibility, String? resourceAccessRole}) Future<UpdateProjectVisibilityOutput>
Changes the public visibility for a project. The project's build results, logs, and artifacts are available to the general public. For more information, see Public build projects in the CodeBuild User Guide.
updateReportGroup({required String arn, ReportExportConfig? exportConfig, List<Tag>? tags}) Future<UpdateReportGroupOutput>
Updates a report group.
updateWebhook({required String projectName, String? branchFilter, WebhookBuildType? buildType, List<List<WebhookFilter>>? filterGroups, PullRequestBuildPolicy? pullRequestBuildPolicy, bool? rotateSecret}) Future<UpdateWebhookOutput>
Updates the webhook associated with an CodeBuild build project.

Operators

operator ==(Object other) bool
The equality operator.
inherited