deleteResourcePolicy method

Future<void> deleteResourcePolicy({
  1. required String resourceArn,
})

Deletes a resource policy that is identified by its resource ARN.

May throw InvalidInputException.

Parameter resourceArn : The ARN of the resource that is associated with the resource policy.

Implementation

Future<void> deleteResourcePolicy({
  required String resourceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodeBuild_20161006.DeleteResourcePolicy'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'resourceArn': resourceArn,
    },
  );
}