deleteWebhook method

Future<void> deleteWebhook({
  1. required String projectName,
})

For an existing CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code every time a code change is pushed to the repository.

May throw InvalidInputException. May throw OAuthProviderException. May throw ResourceNotFoundException.

Parameter projectName : The name of the CodeBuild project.

Implementation

Future<void> deleteWebhook({
  required String projectName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodeBuild_20161006.DeleteWebhook'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'projectName': projectName,
    },
  );
}