updateFleet method
- required String arn,
- int? baseCapacity,
- ComputeConfiguration? computeConfiguration,
- ComputeType? computeType,
- EnvironmentType? environmentType,
- String? fleetServiceRole,
- String? imageId,
- FleetOverflowBehavior? overflowBehavior,
- ProxyConfiguration? proxyConfiguration,
- ScalingConfigurationInput? scalingConfiguration,
- List<
Tag> ? tags, - VpcConfig? vpcConfig,
Updates a compute fleet.
May throw AccountLimitExceededException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
Parameter arn :
The ARN of the compute fleet.
Parameter baseCapacity :
The initial number of machines allocated to the compute fleet, which defines
the number of builds that can run in parallel.
Parameter computeConfiguration :
The compute configuration of the compute fleet. This is only required if
computeType is set to ATTRIBUTE_BASED_COMPUTE or
CUSTOM_INSTANCE_TYPE.
Parameter computeType :
Information about the compute resources the compute fleet uses. Available
values include:
-
ATTRIBUTE_BASED_COMPUTE: Specify the amount of vCPUs, memory, disk space, and the type of machine. -
CUSTOM_INSTANCE_TYPE: Specify the instance type for your compute fleet. For a list of supported instance types, see Supported instance families in the CodeBuild User Guide. -
BUILD_GENERAL1_SMALL: Use up to 4 GiB memory and 2 vCPUs for builds. -
BUILD_GENERAL1_MEDIUM: Use up to 8 GiB memory and 4 vCPUs for builds. -
BUILD_GENERAL1_LARGE: Use up to 16 GiB memory and 8 vCPUs for builds, depending on your environment type. -
BUILD_GENERAL1_XLARGE: Use up to 72 GiB memory and 36 vCPUs for builds, depending on your environment type. -
BUILD_GENERAL1_2XLARGE: Use up to 144 GiB memory, 72 vCPUs, and 824 GB of SSD storage for builds. This compute type supports Docker images up to 100 GB uncompressed. -
BUILD_LAMBDA_1GB: Use up to 1 GiB memory for builds. Only available for environment typeLINUX_LAMBDA_CONTAINERandARM_LAMBDA_CONTAINER. -
BUILD_LAMBDA_2GB: Use up to 2 GiB memory for builds. Only available for environment typeLINUX_LAMBDA_CONTAINERandARM_LAMBDA_CONTAINER. -
BUILD_LAMBDA_4GB: Use up to 4 GiB memory for builds. Only available for environment typeLINUX_LAMBDA_CONTAINERandARM_LAMBDA_CONTAINER. -
BUILD_LAMBDA_8GB: Use up to 8 GiB memory for builds. Only available for environment typeLINUX_LAMBDA_CONTAINERandARM_LAMBDA_CONTAINER. -
BUILD_LAMBDA_10GB: Use up to 10 GiB memory for builds. Only available for environment typeLINUX_LAMBDA_CONTAINERandARM_LAMBDA_CONTAINER.
BUILD_GENERAL1_SMALL:
-
For environment type
LINUX_CONTAINER, you can use up to 4 GiB memory and 2 vCPUs for builds. -
For environment type
LINUX_GPU_CONTAINER, you can use up to 16 GiB memory, 4 vCPUs, and 1 NVIDIA A10G Tensor Core GPU for builds. -
For environment type
ARM_CONTAINER, you can use up to 4 GiB memory and 2 vCPUs on ARM-based processors for builds.
BUILD_GENERAL1_LARGE:
-
For environment type
LINUX_CONTAINER, you can use up to 16 GiB memory and 8 vCPUs for builds. -
For environment type
LINUX_GPU_CONTAINER, you can use up to 255 GiB memory, 32 vCPUs, and 4 NVIDIA Tesla V100 GPUs for builds. -
For environment type
ARM_CONTAINER, you can use up to 16 GiB memory and 8 vCPUs on ARM-based processors for builds.
Parameter environmentType :
The environment type of the compute fleet.
-
The environment type
ARM_CONTAINERis available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), Asia Pacific (Mumbai), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), EU (Frankfurt), and South America (São Paulo). -
The environment type
ARM_EC2is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), South America (São Paulo), and Asia Pacific (Mumbai). -
The environment type
LINUX_CONTAINERis available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), South America (São Paulo), and Asia Pacific (Mumbai). -
The environment type
LINUX_EC2is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), South America (São Paulo), and Asia Pacific (Mumbai). -
The environment type
LINUX_GPU_CONTAINERis available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), and Asia Pacific (Sydney). -
The environment type
MAC_ARMis available for Medium fleets only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), Asia Pacific (Sydney), and EU (Frankfurt) -
The environment type
MAC_ARMis available for Large fleets only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), and Asia Pacific (Sydney). -
The environment type
WINDOWS_EC2is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), South America (São Paulo), and Asia Pacific (Mumbai). -
The environment type
WINDOWS_SERVER_2019_CONTAINERis available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), Asia Pacific (Sydney), Asia Pacific (Tokyo), Asia Pacific (Mumbai) and EU (Ireland). -
The environment type
WINDOWS_SERVER_2022_CONTAINERis available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Sydney), Asia Pacific (Singapore), Asia Pacific (Tokyo), South America (São Paulo) and Asia Pacific (Mumbai).
Parameter fleetServiceRole :
The service role associated with the compute fleet. For more information,
see
Allow a user to add a permission policy for a fleet service role in
the CodeBuild User Guide.
Parameter imageId :
The Amazon Machine Image (AMI) of the compute fleet.
Parameter overflowBehavior :
The compute fleet overflow behavior.
-
For overflow behavior
QUEUE, your overflow builds need to wait on the existing fleet instance to become available. -
For overflow behavior
ON_DEMAND, your overflow builds run on CodeBuild on-demand.
Parameter proxyConfiguration :
The proxy configuration of the compute fleet.
Parameter scalingConfiguration :
The scaling configuration of the compute fleet.
Parameter tags :
A list of tag key and value pairs associated with this compute fleet.
These tags are available for use by Amazon Web Services services that support CodeBuild build project tags.
Implementation
Future<UpdateFleetOutput> updateFleet({
required String arn,
int? baseCapacity,
ComputeConfiguration? computeConfiguration,
ComputeType? computeType,
EnvironmentType? environmentType,
String? fleetServiceRole,
String? imageId,
FleetOverflowBehavior? overflowBehavior,
ProxyConfiguration? proxyConfiguration,
ScalingConfigurationInput? scalingConfiguration,
List<Tag>? tags,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodeBuild_20161006.UpdateFleet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (baseCapacity != null) 'baseCapacity': baseCapacity,
if (computeConfiguration != null)
'computeConfiguration': computeConfiguration,
if (computeType != null) 'computeType': computeType.value,
if (environmentType != null) 'environmentType': environmentType.value,
if (fleetServiceRole != null) 'fleetServiceRole': fleetServiceRole,
if (imageId != null) 'imageId': imageId,
if (overflowBehavior != null)
'overflowBehavior': overflowBehavior.value,
if (proxyConfiguration != null)
'proxyConfiguration': proxyConfiguration,
if (scalingConfiguration != null)
'scalingConfiguration': scalingConfiguration,
if (tags != null) 'tags': tags,
if (vpcConfig != null) 'vpcConfig': vpcConfig,
},
);
return UpdateFleetOutput.fromJson(jsonResponse.body);
}