updateProject method

Future<UpdateProjectOutput> updateProject({
  1. required String name,
  2. ProjectArtifacts? artifacts,
  3. int? autoRetryLimit,
  4. bool? badgeEnabled,
  5. ProjectBuildBatchConfig? buildBatchConfig,
  6. ProjectCache? cache,
  7. int? concurrentBuildLimit,
  8. String? description,
  9. String? encryptionKey,
  10. ProjectEnvironment? environment,
  11. List<ProjectFileSystemLocation>? fileSystemLocations,
  12. LogsConfig? logsConfig,
  13. int? queuedTimeoutInMinutes,
  14. List<ProjectArtifacts>? secondaryArtifacts,
  15. List<ProjectSourceVersion>? secondarySourceVersions,
  16. List<ProjectSource>? secondarySources,
  17. String? serviceRole,
  18. ProjectSource? source,
  19. String? sourceVersion,
  20. List<Tag>? tags,
  21. int? timeoutInMinutes,
  22. VpcConfig? vpcConfig,
})

Changes the settings of a build project.

May throw InvalidInputException. May throw ResourceNotFoundException.

Parameter name : The name of the build project.

Parameter artifacts : Information to be changed about the build output artifacts for the build project.

Parameter autoRetryLimit : The maximum number of additional automatic retries after a failed build. For example, if the auto-retry limit is set to 2, CodeBuild will call the RetryBuild API to automatically retry your build for up to 2 additional times.

Parameter badgeEnabled : Set this to true to generate a publicly accessible URL for your project's build badge.

Parameter cache : Stores recently used information so that it can be quickly accessed at a later time.

Parameter concurrentBuildLimit : The maximum number of concurrent builds that are allowed for this project.

New builds are only started if the current number of builds is less than or equal to this limit. If the current build count meets this limit, new builds are throttled and are not run.

To remove this limit, set this value to -1.

Parameter description : A new or replacement description of the build project.

Parameter encryptionKey : The Key Management Service customer master key (CMK) to be used for encrypting the build output artifacts. You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the format alias/).

Parameter environment : Information to be changed about the build environment for the build project.

Parameter fileSystemLocations : An array of ProjectFileSystemLocation objects for a CodeBuild build project. A ProjectFileSystemLocation object specifies the identifier, location, mountOptions, mountPoint, and type of a file system created using Amazon Elastic File System.

Parameter logsConfig : Information about logs for the build project. A project can create logs in CloudWatch Logs, logs in an S3 bucket, or both.

Parameter queuedTimeoutInMinutes : The number of minutes a build is allowed to be queued before it times out.

Parameter secondaryArtifacts : An array of ProjectArtifact objects.

Parameter secondarySourceVersions : An array of ProjectSourceVersion objects. If secondarySourceVersions is specified at the build level, then they take over these secondarySourceVersions (at the project level).

Parameter secondarySources : An array of ProjectSource objects.

Parameter serviceRole : The replacement ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.

Parameter source : Information to be changed about the build input source code for the build project.

Parameter sourceVersion : A version of the build input to be built for this project. If not specified, the latest version is used. If specified, it must be one of:

  • For CodeCommit: the commit ID, branch, or Git tag to use.
  • For GitHub: the commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format pr/pull-request-ID (for example pr/25). If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.
  • For GitLab: the commit ID, branch, or Git tag to use.
  • For Bitbucket: the commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.
  • For Amazon S3: the version ID of the object that represents the build input ZIP file to use.
If sourceVersion is specified at the build level, then that version takes precedence over this sourceVersion (at the project level).

For more information, see Source Version Sample with CodeBuild in the CodeBuild User Guide.

Parameter tags : An updated list of tag key and value pairs associated with this build project.

These tags are available for use by Amazon Web Services services that support CodeBuild build project tags.

Parameter timeoutInMinutes : The replacement value in minutes, from 5 to 2160 (36 hours), for CodeBuild to wait before timing out any related build that did not get marked as completed.

Parameter vpcConfig : VpcConfig enables CodeBuild to access resources in an Amazon VPC.

Implementation

Future<UpdateProjectOutput> updateProject({
  required String name,
  ProjectArtifacts? artifacts,
  int? autoRetryLimit,
  bool? badgeEnabled,
  ProjectBuildBatchConfig? buildBatchConfig,
  ProjectCache? cache,
  int? concurrentBuildLimit,
  String? description,
  String? encryptionKey,
  ProjectEnvironment? environment,
  List<ProjectFileSystemLocation>? fileSystemLocations,
  LogsConfig? logsConfig,
  int? queuedTimeoutInMinutes,
  List<ProjectArtifacts>? secondaryArtifacts,
  List<ProjectSourceVersion>? secondarySourceVersions,
  List<ProjectSource>? secondarySources,
  String? serviceRole,
  ProjectSource? source,
  String? sourceVersion,
  List<Tag>? tags,
  int? timeoutInMinutes,
  VpcConfig? vpcConfig,
}) async {
  _s.validateNumRange(
    'queuedTimeoutInMinutes',
    queuedTimeoutInMinutes,
    5,
    480,
  );
  _s.validateNumRange(
    'timeoutInMinutes',
    timeoutInMinutes,
    5,
    2160,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodeBuild_20161006.UpdateProject'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'name': name,
      if (artifacts != null) 'artifacts': artifacts,
      if (autoRetryLimit != null) 'autoRetryLimit': autoRetryLimit,
      if (badgeEnabled != null) 'badgeEnabled': badgeEnabled,
      if (buildBatchConfig != null) 'buildBatchConfig': buildBatchConfig,
      if (cache != null) 'cache': cache,
      if (concurrentBuildLimit != null)
        'concurrentBuildLimit': concurrentBuildLimit,
      if (description != null) 'description': description,
      if (encryptionKey != null) 'encryptionKey': encryptionKey,
      if (environment != null) 'environment': environment,
      if (fileSystemLocations != null)
        'fileSystemLocations': fileSystemLocations,
      if (logsConfig != null) 'logsConfig': logsConfig,
      if (queuedTimeoutInMinutes != null)
        'queuedTimeoutInMinutes': queuedTimeoutInMinutes,
      if (secondaryArtifacts != null)
        'secondaryArtifacts': secondaryArtifacts,
      if (secondarySourceVersions != null)
        'secondarySourceVersions': secondarySourceVersions,
      if (secondarySources != null) 'secondarySources': secondarySources,
      if (serviceRole != null) 'serviceRole': serviceRole,
      if (source != null) 'source': source,
      if (sourceVersion != null) 'sourceVersion': sourceVersion,
      if (tags != null) 'tags': tags,
      if (timeoutInMinutes != null) 'timeoutInMinutes': timeoutInMinutes,
      if (vpcConfig != null) 'vpcConfig': vpcConfig,
    },
  );

  return UpdateProjectOutput.fromJson(jsonResponse.body);
}