deleteAccessToken method

Future<void> deleteAccessToken({
  1. required String id,
})

Deletes a specified personal access token (PAT). A personal access token can only be deleted by the user who created it.

Parameter id : The ID of the personal access token to delete. You can find the IDs of all PATs associated with your Amazon Web Services Builder ID in a space by calling ListAccessTokens.

Implementation

Future<void> deleteAccessToken({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/v1/accessTokens/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}