listAccessTokens method

Future<ListAccessTokensResponse> listAccessTokens({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all personal access tokens (PATs) associated with the user who calls the API. You can only list PATs associated with your Amazon Web Services Builder ID.

Parameter maxResults : The maximum number of results to show in a single call to this API. If the number of results is larger than the number you specified, the response will include a NextToken element, which you can use to obtain additional results.

Parameter nextToken : A token returned from a call to this API to indicate the next batch of results to return, if any.

Implementation

Future<ListAccessTokensResponse> listAccessTokens({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/accessTokens',
    exceptionFnMap: _exceptionFns,
  );
  return ListAccessTokensResponse.fromJson(response);
}