listDevEnvironmentSessions method
Retrieves a list of active sessions for a Dev Environment in a project.
Parameter devEnvironmentId :
The system-generated unique ID of the Dev Environment.
Parameter projectName :
The name of the project in the space.
Parameter spaceName :
The name of the space.
Parameter maxResults :
The maximum number of results to show in a single call to this API. If the
number of results is larger than the number you specified, the response
will include a NextToken element, which you can use to obtain
additional results.
Parameter nextToken :
A token returned from a call to this API to indicate the next batch of
results to return, if any.
Implementation
Future<ListDevEnvironmentSessionsResponse> listDevEnvironmentSessions({
required String devEnvironmentId,
required String projectName,
required String spaceName,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v1/spaces/${Uri.encodeComponent(spaceName)}/projects/${Uri.encodeComponent(projectName)}/devEnvironments/${Uri.encodeComponent(devEnvironmentId)}/sessions',
exceptionFnMap: _exceptionFns,
);
return ListDevEnvironmentSessionsResponse.fromJson(response);
}