listProjects method

Future<ListProjectsResponse> listProjects({
  1. required String spaceName,
  2. List<ProjectListFilter>? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Retrieves a list of projects.

Parameter spaceName : The name of the space.

Parameter filters : Information about filters to apply to narrow the results returned in the list.

Parameter maxResults : The maximum number of results to show in a single call to this API. If the number of results is larger than the number you specified, the response will include a NextToken element, which you can use to obtain additional results.

Parameter nextToken : A token returned from a call to this API to indicate the next batch of results to return, if any.

Implementation

Future<ListProjectsResponse> listProjects({
  required String spaceName,
  List<ProjectListFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/spaces/${Uri.encodeComponent(spaceName)}/projects',
    exceptionFnMap: _exceptionFns,
  );
  return ListProjectsResponse.fromJson(response);
}