listSourceRepositories method

Future<ListSourceRepositoriesResponse> listSourceRepositories({
  1. required String projectName,
  2. required String spaceName,
  3. int? maxResults,
  4. String? nextToken,
})

Retrieves a list of source repositories in a project.

Parameter projectName : The name of the project in the space.

Parameter spaceName : The name of the space.

Parameter maxResults : The maximum number of results to show in a single call to this API. If the number of results is larger than the number you specified, the response will include a NextToken element, which you can use to obtain additional results.

Parameter nextToken : A token returned from a call to this API to indicate the next batch of results to return, if any.

Implementation

Future<ListSourceRepositoriesResponse> listSourceRepositories({
  required String projectName,
  required String spaceName,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/v1/spaces/${Uri.encodeComponent(spaceName)}/projects/${Uri.encodeComponent(projectName)}/sourceRepositories',
    exceptionFnMap: _exceptionFns,
  );
  return ListSourceRepositoriesResponse.fromJson(response);
}