listSourceRepositoryBranches method

Future<ListSourceRepositoryBranchesResponse> listSourceRepositoryBranches({
  1. required String projectName,
  2. required String sourceRepositoryName,
  3. required String spaceName,
  4. int? maxResults,
  5. String? nextToken,
})

Retrieves a list of branches in a specified source repository.

Parameter projectName : The name of the project in the space.

Parameter sourceRepositoryName : The name of the source repository.

Parameter spaceName : The name of the space.

Parameter maxResults : The maximum number of results to show in a single call to this API. If the number of results is larger than the number you specified, the response will include a NextToken element, which you can use to obtain additional results.

Parameter nextToken : A token returned from a call to this API to indicate the next batch of results to return, if any.

Implementation

Future<ListSourceRepositoryBranchesResponse> listSourceRepositoryBranches({
  required String projectName,
  required String sourceRepositoryName,
  required String spaceName,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/v1/spaces/${Uri.encodeComponent(spaceName)}/projects/${Uri.encodeComponent(projectName)}/sourceRepositories/${Uri.encodeComponent(sourceRepositoryName)}/branches',
    exceptionFnMap: _exceptionFns,
  );
  return ListSourceRepositoryBranchesResponse.fromJson(response);
}