listSpaces method

Future<ListSpacesResponse> listSpaces({
  1. String? nextToken,
})

Retrieves a list of spaces.

Parameter nextToken : A token returned from a call to this API to indicate the next batch of results to return, if any.

Implementation

Future<ListSpacesResponse> listSpaces({
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/spaces',
    exceptionFnMap: _exceptionFns,
  );
  return ListSpacesResponse.fromJson(response);
}