untagResource method
Removes tags for a resource in CodeCommit. For a list of valid resources in CodeCommit, see CodeCommit Resources and Operations in the CodeCommit User Guide.
May throw InvalidRepositoryNameException.
May throw InvalidResourceArnException.
May throw InvalidSystemTagUsageException.
May throw InvalidTagKeysListException.
May throw RepositoryDoesNotExistException.
May throw ResourceArnRequiredException.
May throw TagKeysListRequiredException.
May throw TagPolicyException.
May throw TooManyTagsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to which you want to remove
tags.
Parameter tagKeys :
The tag key for each tag that you want to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodeCommit_20150413.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'resourceArn': resourceArn,
'tagKeys': tagKeys,
},
);
}