batchGetApplications method

Future<BatchGetApplicationsOutput> batchGetApplications({
  1. required List<String> applicationNames,
})

Gets information about one or more applications. The maximum number of applications that can be returned is 100.

May throw ApplicationDoesNotExistException. May throw ApplicationNameRequiredException. May throw BatchLimitExceededException. May throw InvalidApplicationNameException.

Parameter applicationNames : A list of application names separated by spaces. The maximum number of application names you can specify is 100.

Implementation

Future<BatchGetApplicationsOutput> batchGetApplications({
  required List<String> applicationNames,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodeDeploy_20141006.BatchGetApplications'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'applicationNames': applicationNames,
    },
  );

  return BatchGetApplicationsOutput.fromJson(jsonResponse.body);
}