createDeployment method

Future<CreateDeploymentOutput> createDeployment({
  1. required String applicationName,
  2. AutoRollbackConfiguration? autoRollbackConfiguration,
  3. String? deploymentConfigName,
  4. String? deploymentGroupName,
  5. String? description,
  6. FileExistsBehavior? fileExistsBehavior,
  7. bool? ignoreApplicationStopFailures,
  8. AlarmConfiguration? overrideAlarmConfiguration,
  9. RevisionLocation? revision,
  10. TargetInstances? targetInstances,
  11. bool? updateOutdatedInstancesOnly,
})

Deploys an application revision through the specified deployment group.

May throw AlarmsLimitExceededException. May throw ApplicationDoesNotExistException. May throw ApplicationNameRequiredException. May throw DeploymentConfigDoesNotExistException. May throw DeploymentGroupDoesNotExistException. May throw DeploymentGroupNameRequiredException. May throw DeploymentLimitExceededException. May throw DescriptionTooLongException. May throw InvalidAlarmConfigException. May throw InvalidApplicationNameException. May throw InvalidAutoRollbackConfigException. May throw InvalidAutoScalingGroupException. May throw InvalidDeploymentConfigNameException. May throw InvalidDeploymentGroupNameException. May throw InvalidFileExistsBehaviorException. May throw InvalidGitHubAccountTokenException. May throw InvalidIgnoreApplicationStopFailuresValueException. May throw InvalidLoadBalancerInfoException. May throw InvalidRevisionException. May throw InvalidRoleException. May throw InvalidTargetInstancesException. May throw InvalidTrafficRoutingConfigurationException. May throw InvalidUpdateOutdatedInstancesOnlyValueException. May throw RevisionDoesNotExistException. May throw RevisionRequiredException. May throw ThrottlingException.

Parameter applicationName : The name of an CodeDeploy application associated with the user or Amazon Web Services account.

Parameter autoRollbackConfiguration : Configuration information for an automatic rollback that is added when a deployment is created.

Parameter deploymentConfigName : The name of a deployment configuration associated with the user or Amazon Web Services account.

If not specified, the value configured in the deployment group is used as the default. If the deployment group does not have a deployment configuration associated with it, CodeDeployDefault.OneAtATime is used by default.

Parameter deploymentGroupName : The name of the deployment group.

Parameter description : A comment about the deployment.

Parameter fileExistsBehavior : Information about how CodeDeploy handles files that already exist in a deployment target location but weren't part of the previous successful deployment.

The fileExistsBehavior parameter takes any of the following values:

  • DISALLOW: The deployment fails. This is also the default behavior if no option is specified.
  • OVERWRITE: The version of the file from the application revision currently being deployed replaces the version already on the instance.
  • RETAIN: The version of the file already on the instance is kept and used as part of the new deployment.

Parameter ignoreApplicationStopFailures : If true, then if an ApplicationStop, BeforeBlockTraffic, or AfterBlockTraffic deployment lifecycle event to an instance fails, then the deployment continues to the next deployment lifecycle event. For example, if ApplicationStop fails, the deployment continues with DownloadBundle. If BeforeBlockTraffic fails, the deployment continues with BlockTraffic. If AfterBlockTraffic fails, the deployment continues with ApplicationStop.

If false or not specified, then if a lifecycle event fails during a deployment to an instance, that deployment fails. If deployment to that instance is part of an overall deployment and the number of healthy hosts is not less than the minimum number of healthy hosts, then a deployment to the next instance is attempted.

During a deployment, the CodeDeploy agent runs the scripts specified for ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic in the AppSpec file from the previous successful deployment. (All other scripts are run from the AppSpec file in the current deployment.) If one of these scripts contains an error and does not run successfully, the deployment can fail.

If the cause of the failure is a script from the last successful deployment that will never run successfully, create a new deployment and use ignoreApplicationStopFailures to specify that the ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic failures should be ignored.

Parameter overrideAlarmConfiguration : Allows you to specify information about alarms associated with a deployment. The alarm configuration that you specify here will override the alarm configuration at the deployment group level. Consider overriding the alarm configuration if you have set up alarms at the deployment group level that are causing deployment failures. In this case, you would call CreateDeployment to create a new deployment that uses a previous application revision that is known to work, and set its alarm configuration to turn off alarm polling. Turning off alarm polling ensures that the new deployment proceeds without being blocked by the alarm that was generated by the previous, failed, deployment.

Parameter revision : The type and location of the revision to deploy.

Parameter targetInstances : Information about the instances that belong to the replacement environment in a blue/green deployment.

Parameter updateOutdatedInstancesOnly : Indicates whether to deploy to all instances or only to instances that are not running the latest application revision.

Implementation

Future<CreateDeploymentOutput> createDeployment({
  required String applicationName,
  AutoRollbackConfiguration? autoRollbackConfiguration,
  String? deploymentConfigName,
  String? deploymentGroupName,
  String? description,
  FileExistsBehavior? fileExistsBehavior,
  bool? ignoreApplicationStopFailures,
  AlarmConfiguration? overrideAlarmConfiguration,
  RevisionLocation? revision,
  TargetInstances? targetInstances,
  bool? updateOutdatedInstancesOnly,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodeDeploy_20141006.CreateDeployment'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'applicationName': applicationName,
      if (autoRollbackConfiguration != null)
        'autoRollbackConfiguration': autoRollbackConfiguration,
      if (deploymentConfigName != null)
        'deploymentConfigName': deploymentConfigName,
      if (deploymentGroupName != null)
        'deploymentGroupName': deploymentGroupName,
      if (description != null) 'description': description,
      if (fileExistsBehavior != null)
        'fileExistsBehavior': fileExistsBehavior.value,
      if (ignoreApplicationStopFailures != null)
        'ignoreApplicationStopFailures': ignoreApplicationStopFailures,
      if (overrideAlarmConfiguration != null)
        'overrideAlarmConfiguration': overrideAlarmConfiguration,
      if (revision != null) 'revision': revision,
      if (targetInstances != null) 'targetInstances': targetInstances,
      if (updateOutdatedInstancesOnly != null)
        'updateOutdatedInstancesOnly': updateOutdatedInstancesOnly,
    },
  );

  return CreateDeploymentOutput.fromJson(jsonResponse.body);
}