getNotificationConfiguration method
Future<GetNotificationConfigurationResponse>
getNotificationConfiguration({
- required String profilingGroupName,
Get the current configuration for anomaly notifications for a profiling group.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter profilingGroupName :
The name of the profiling group we want to get the notification
configuration for.
Implementation
Future<GetNotificationConfigurationResponse> getNotificationConfiguration({
required String profilingGroupName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/profilingGroups/${Uri.encodeComponent(profilingGroupName)}/notificationConfiguration',
exceptionFnMap: _exceptionFns,
);
return GetNotificationConfigurationResponse.fromJson(response);
}