removeNotificationChannel method

Future<RemoveNotificationChannelResponse> removeNotificationChannel({
  1. required String channelId,
  2. required String profilingGroupName,
})

Remove one anomaly notifications channel for a profiling group.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter channelId : The id of the channel that we want to stop receiving notifications.

Parameter profilingGroupName : The name of the profiling group we want to change notification configuration for.

Implementation

Future<RemoveNotificationChannelResponse> removeNotificationChannel({
  required String channelId,
  required String profilingGroupName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/profilingGroups/${Uri.encodeComponent(profilingGroupName)}/notificationConfiguration/${Uri.encodeComponent(channelId)}',
    exceptionFnMap: _exceptionFns,
  );
  return RemoveNotificationChannelResponse.fromJson(response);
}