listRecommendations method
Returns the list of all recommendations for a completed code review.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter codeReviewArn :
The Amazon Resource Name (ARN) of the CodeReview
object.
Parameter maxResults :
The maximum number of results that are returned per call. The default is
100.
Parameter nextToken :
Pagination token.
Implementation
Future<ListRecommendationsResponse> listRecommendations({
required String codeReviewArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
300,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/codereviews/${Uri.encodeComponent(codeReviewArn)}/Recommendations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRecommendationsResponse.fromJson(response);
}