code_guru_reviewer_2019_09_19 library

Classes

AwsClientCredentials
AWS credentials.
CodeGuruReviewer
This section provides documentation for the Amazon CodeGuru Reviewer API operations. CodeGuru Reviewer is a service that uses program analysis and machine learning to detect potential defects that are difficult for developers to find and recommends fixes in your Java and Python code.