CodeGuruSecurity class

This section provides documentation for the Amazon CodeGuru Security API operations. CodeGuru Security is a service that uses program analysis and machine learning to detect security policy violations and vulnerabilities, and recommends ways to address these security risks.

By proactively detecting and providing recommendations for addressing security risks, CodeGuru Security improves the overall security of your application code. For more information about CodeGuru Security, see the Amazon CodeGuru Security User Guide.

Constructors

CodeGuruSecurity({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetFindings({required List<FindingIdentifier> findingIdentifiers}) Future<BatchGetFindingsResponse>
Returns a list of requested findings from standard scans.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createScan({required ResourceId resourceId, required String scanName, AnalysisType? analysisType, String? clientToken, ScanType? scanType, Map<String, String>? tags}) Future<CreateScanResponse>
Use to create a scan using code uploaded to an Amazon S3 bucket.
createUploadUrl({required String scanName}) Future<CreateUploadUrlResponse>
Generates a pre-signed URL, request headers used to upload a code resource, and code artifact identifier for the uploaded resource.
getAccountConfiguration() Future<GetAccountConfigurationResponse>
Use to get the encryption configuration for an account.
getFindings({required String scanName, int? maxResults, String? nextToken, Status? status}) Future<GetFindingsResponse>
Returns a list of all findings generated by a particular scan.
getMetricsSummary({required DateTime date}) Future<GetMetricsSummaryResponse>
Returns a summary of metrics for an account from a specified date, including number of open findings, the categories with most findings, the scans with most open findings, and scans with most open critical findings.
getScan({required String scanName, String? runId}) Future<GetScanResponse>
Returns details about a scan, including whether or not a scan has completed.
listFindingsMetrics({required DateTime endDate, required DateTime startDate, int? maxResults, String? nextToken}) Future<ListFindingsMetricsResponse>
Returns metrics about all findings in an account within a specified time range.
listScans({int? maxResults, String? nextToken}) Future<ListScansResponse>
Returns a list of all scans in an account. Does not return EXPRESS scans.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of all tags associated with a scan.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Use to add one or more tags to an existing scan.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Use to remove one or more tags from an existing scan.
updateAccountConfiguration({required EncryptionConfig encryptionConfig}) Future<UpdateAccountConfigurationResponse>
Use to update the encryption configuration for an account.

Operators

operator ==(Object other) bool
The equality operator.
inherited