createUploadUrl method
Generates a pre-signed URL, request headers used to upload a code resource, and code artifact identifier for the uploaded resource.
You can upload your code resource to the URL with the request headers using any HTTP client.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter scanName :
The name of the scan that will use the uploaded resource. CodeGuru
Security uses the unique scan name to track revisions across multiple
scans of the same resource. Use this scanName when you call
CreateScan on the code resource you upload to this URL.
Implementation
Future<CreateUploadUrlResponse> createUploadUrl({
required String scanName,
}) async {
final $payload = <String, dynamic>{
'scanName': scanName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/uploadUrl',
exceptionFnMap: _exceptionFns,
);
return CreateUploadUrlResponse.fromJson(response);
}