getMetricsSummary method

Future<GetMetricsSummaryResponse> getMetricsSummary({
  1. required DateTime date,
})

Returns a summary of metrics for an account from a specified date, including number of open findings, the categories with most findings, the scans with most open findings, and scans with most open critical findings.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter date : The date you want to retrieve summary metrics from, rounded to the nearest day. The date must be within the past two years.

Implementation

Future<GetMetricsSummaryResponse> getMetricsSummary({
  required DateTime date,
}) async {
  final $query = <String, List<String>>{
    'date': [_s.iso8601ToJson(date).toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/metrics/summary',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetMetricsSummaryResponse.fromJson(response);
}