listScans method
Returns a list of all scans in an account. Does not return
EXPRESS scans.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return in the response. Use this
parameter when paginating results. If additional results exist beyond the
number you specify, the nextToken element is returned in the
response. Use nextToken in a subsequent request to retrieve
additional results. If not specified, returns 100 results.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request. For
subsequent calls, use the nextToken value returned from the
previous request to continue listing results after the first page.
Implementation
Future<ListScansResponse> listScans({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/scans',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListScansResponse.fromJson(response);
}