CodePipeline class
This is the CodePipeline API Reference. This guide provides descriptions of the actions and data types for CodePipeline. Some functionality for your pipeline can only be configured through the API. For more information, see the CodePipeline User Guide.
Constructors
- CodePipeline({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acknowledgeJob(
{required String jobId, required String nonce}) → Future< AcknowledgeJobOutput> - Returns information about a specified job and whether that job has been received by the job worker. Used for custom actions only.
-
acknowledgeThirdPartyJob(
{required String clientToken, required String jobId, required String nonce}) → Future< AcknowledgeThirdPartyJobOutput> - Confirms a job worker has received the specified job. Used for partner actions only.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCustomActionType(
{required ActionCategory category, required ArtifactDetails inputArtifactDetails, required ArtifactDetails outputArtifactDetails, required String provider, required String version, List< ActionConfigurationProperty> ? configurationProperties, ActionTypeSettings? settings, List<Tag> ? tags}) → Future<CreateCustomActionTypeOutput> - Creates a new custom action that can be used in all pipelines associated with the Amazon Web Services account. Only used for custom actions.
-
createPipeline(
{required PipelineDeclaration pipeline, List< Tag> ? tags}) → Future<CreatePipelineOutput> - Creates a pipeline.
-
deleteCustomActionType(
{required ActionCategory category, required String provider, required String version}) → Future< void> -
Marks a custom action as deleted.
PollForJobsfor the custom action fails after the action is marked for deletion. Used for custom actions only. -
deletePipeline(
{required String name}) → Future< void> - Deletes the specified pipeline.
-
deleteWebhook(
{required String name}) → Future< void> - Deletes a previously created webhook by name. Deleting the webhook stops CodePipeline from starting a pipeline every time an external event occurs. The API returns successfully when trying to delete a webhook that is already deleted. If a deleted webhook is re-created by calling PutWebhook with the same name, it will have a different URL.
-
deregisterWebhookWithThirdParty(
{String? webhookName}) → Future< void> - Removes the connection between the webhook that was created by CodePipeline and the external tool with events to be detected. Currently supported only for webhooks that target an action type of GitHub.
-
disableStageTransition(
{required String pipelineName, required String reason, required String stageName, required StageTransitionType transitionType}) → Future< void> - Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline.
-
enableStageTransition(
{required String pipelineName, required String stageName, required StageTransitionType transitionType}) → Future< void> - Enables artifacts in a pipeline to transition to a stage in a pipeline.
-
getActionType(
{required ActionCategory category, required String owner, required String provider, required String version}) → Future< GetActionTypeOutput> - Returns information about an action type created for an external provider, where the action is to be used by customers of the external provider. The action can be created with any supported integration model.
-
getJobDetails(
{required String jobId}) → Future< GetJobDetailsOutput> - Returns information about a job. Used for custom actions only.
-
getPipeline(
{required String name, int? version}) → Future< GetPipelineOutput> - Returns the metadata, structure, stages, and actions of a pipeline. Can be used to return the entire structure of a pipeline in JSON format, which can then be modified and used to update the pipeline structure with UpdatePipeline.
-
getPipelineExecution(
{required String pipelineExecutionId, required String pipelineName}) → Future< GetPipelineExecutionOutput> - Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.
-
getPipelineState(
{required String name}) → Future< GetPipelineStateOutput> - Returns information about the state of a pipeline, including the stages and actions.
-
getThirdPartyJobDetails(
{required String clientToken, required String jobId}) → Future< GetThirdPartyJobDetailsOutput> - Requests the details of a job for a third party action. Used for partner actions only.
-
listActionExecutions(
{required String pipelineName, ActionExecutionFilter? filter, int? maxResults, String? nextToken}) → Future< ListActionExecutionsOutput> - Lists the action executions that have occurred in a pipeline.
-
listActionTypes(
{ActionOwner? actionOwnerFilter, String? nextToken, String? regionFilter}) → Future< ListActionTypesOutput> - Gets a summary of all CodePipeline action types associated with your account.
-
listDeployActionExecutionTargets(
{required String actionExecutionId, List< TargetFilter> ? filters, int? maxResults, String? nextToken, String? pipelineName}) → Future<ListDeployActionExecutionTargetsOutput> - Lists the targets for the deploy action.
-
listPipelineExecutions(
{required String pipelineName, PipelineExecutionFilter? filter, int? maxResults, String? nextToken}) → Future< ListPipelineExecutionsOutput> - Gets a summary of the most recent executions for a pipeline.
-
listPipelines(
{int? maxResults, String? nextToken}) → Future< ListPipelinesOutput> - Gets a summary of all of the pipelines associated with your account.
-
listRuleExecutions(
{required String pipelineName, RuleExecutionFilter? filter, int? maxResults, String? nextToken}) → Future< ListRuleExecutionsOutput> - Lists the rule executions that have occurred in a pipeline configured for conditions with rules.
-
listRuleTypes(
{String? regionFilter, RuleOwner? ruleOwnerFilter}) → Future< ListRuleTypesOutput> - Lists the rules for the condition. For more information about conditions, see Stage conditions and How do stage conditions work?.For more information about rules, see the CodePipeline rule reference.
-
listTagsForResource(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListTagsForResourceOutput> - Gets the set of key-value pairs (metadata) that are used to manage the resource.
-
listWebhooks(
{int? maxResults, String? nextToken}) → Future< ListWebhooksOutput> - Gets a listing of all the webhooks in this Amazon Web Services Region for this account. The output lists all webhooks and includes the webhook URL and ARN and the configuration for each webhook.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overrideStageCondition(
{required ConditionType conditionType, required String pipelineExecutionId, required String pipelineName, required String stageName}) → Future< void> - Used to override a stage condition. For more information about conditions, see Stage conditions and How do stage conditions work?.
-
pollForJobs(
{required ActionTypeId actionTypeId, int? maxBatchSize, Map< String, String> ? queryParam}) → Future<PollForJobsOutput> -
Returns information about any jobs for CodePipeline to act on.
PollForJobsis valid only for action types with "Custom" in the owner field. If the action type containsAWSorThirdPartyin the owner field, thePollForJobsaction returns an error. -
pollForThirdPartyJobs(
{required ActionTypeId actionTypeId, int? maxBatchSize}) → Future< PollForThirdPartyJobsOutput> - Determines whether there are any third party jobs for a job worker to act on. Used for partner actions only.
-
putActionRevision(
{required String actionName, required ActionRevision actionRevision, required String pipelineName, required String stageName}) → Future< PutActionRevisionOutput> - Provides information to CodePipeline about new revisions to a source.
-
putApprovalResult(
{required String actionName, required String pipelineName, required ApprovalResult result, required String stageName, required String token}) → Future< PutApprovalResultOutput> - Provides the response to a manual approval request to CodePipeline. Valid responses include Approved and Rejected.
-
putJobFailureResult(
{required FailureDetails failureDetails, required String jobId}) → Future< void> - Represents the failure of a job as returned to the pipeline by a job worker. Used for custom actions only.
-
putJobSuccessResult(
{required String jobId, String? continuationToken, CurrentRevision? currentRevision, ExecutionDetails? executionDetails, Map< String, String> ? outputVariables}) → Future<void> - Represents the success of a job as returned to the pipeline by a job worker. Used for custom actions only.
-
putThirdPartyJobFailureResult(
{required String clientToken, required FailureDetails failureDetails, required String jobId}) → Future< void> - Represents the failure of a third party job as returned to the pipeline by a job worker. Used for partner actions only.
-
putThirdPartyJobSuccessResult(
{required String clientToken, required String jobId, String? continuationToken, CurrentRevision? currentRevision, ExecutionDetails? executionDetails}) → Future< void> - Represents the success of a third party job as returned to the pipeline by a job worker. Used for partner actions only.
-
putWebhook(
{required WebhookDefinition webhook, List< Tag> ? tags}) → Future<PutWebhookOutput> - Defines a webhook and returns a unique webhook URL generated by CodePipeline. This URL can be supplied to third party source hosting providers to call every time there's a code change. When CodePipeline receives a POST request on this URL, the pipeline defined in the webhook is started as long as the POST request satisfied the authentication and filtering requirements supplied when defining the webhook. RegisterWebhookWithThirdParty and DeregisterWebhookWithThirdParty APIs can be used to automatically configure supported third parties to call the generated webhook URL.
-
registerWebhookWithThirdParty(
{String? webhookName}) → Future< void> - Configures a connection between the webhook that was created and the external tool with events to be detected.
-
retryStageExecution(
{required String pipelineExecutionId, required String pipelineName, required StageRetryMode retryMode, required String stageName}) → Future< RetryStageExecutionOutput> - You can retry a stage that has failed without having to run a pipeline again from the beginning. You do this by either retrying the failed actions in a stage or by retrying all actions in the stage starting from the first action in the stage. When you retry the failed actions in a stage, all actions that are still in progress continue working, and failed actions are triggered again. When you retry a failed stage from the first action in the stage, the stage cannot have any actions in progress. Before a stage can be retried, it must either have all actions failed or some actions failed and some succeeded.
-
rollbackStage(
{required String pipelineName, required String stageName, required String targetPipelineExecutionId}) → Future< RollbackStageOutput> - Rolls back a stage execution.
-
startPipelineExecution(
{required String name, String? clientRequestToken, List< SourceRevisionOverride> ? sourceRevisions, List<PipelineVariable> ? variables}) → Future<StartPipelineExecutionOutput> - Starts the specified pipeline. Specifically, it begins processing the latest commit to the source location specified as part of the pipeline.
-
stopPipelineExecution(
{required String pipelineExecutionId, required String pipelineName, bool? abandon, String? reason}) → Future< StopPipelineExecutionOutput> -
Stops the specified pipeline execution. You choose to either stop the
pipeline execution by completing in-progress actions without starting
subsequent actions, or by abandoning in-progress actions. While completing
or abandoning in-progress actions, the pipeline execution is in a
Stoppingstate. After all in-progress actions are completed or abandoned, the pipeline execution is in aStoppedstate. -
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Adds to or modifies the tags of the given resource. Tags are metadata that can be used to manage a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from an Amazon Web Services resource.
-
updateActionType(
{required ActionTypeDeclaration actionType}) → Future< void> -
Updates an action type that was created with any supported integration
model, where the action type is to be used by customers of the action type
provider. Use a JSON file with the action definition and
UpdateActionTypeto provide the full structure. -
updatePipeline(
{required PipelineDeclaration pipeline}) → Future< UpdatePipelineOutput> -
Updates a specified pipeline with edits or changes to its structure. Use a
JSON file with the pipeline structure and
UpdatePipelineto provide the full structure of the pipeline. Updating the pipeline increases the version number of the pipeline by 1.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited