deleteCustomActionType method

Future<void> deleteCustomActionType({
  1. required ActionCategory category,
  2. required String provider,
  3. required String version,
})

Marks a custom action as deleted. PollForJobs for the custom action fails after the action is marked for deletion. Used for custom actions only.

May throw ConcurrentModificationException. May throw ValidationException.

Parameter category : The category of the custom action that you want to delete, such as source or deploy.

Parameter provider : The provider of the service used in the custom action, such as CodeDeploy.

Parameter version : The version of the custom action to delete.

Implementation

Future<void> deleteCustomActionType({
  required ActionCategory category,
  required String provider,
  required String version,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodePipeline_20150709.DeleteCustomActionType'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'category': category.value,
      'provider': provider,
      'version': version,
    },
  );
}