listDeployActionExecutionTargets method

Future<ListDeployActionExecutionTargetsOutput> listDeployActionExecutionTargets({
  1. required String actionExecutionId,
  2. List<TargetFilter>? filters,
  3. int? maxResults,
  4. String? nextToken,
  5. String? pipelineName,
})

Lists the targets for the deploy action.

May throw ActionExecutionNotFoundException. May throw InvalidNextTokenException. May throw PipelineNotFoundException. May throw ValidationException.

Parameter actionExecutionId : The execution ID for the deploy action.

Parameter filters : Filters the targets for a specified deploy action.

Parameter maxResults : The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : An identifier that was returned from the previous list action types call, which can be used to return the next set of action types in the list.

Parameter pipelineName : The name of the pipeline with the deploy action.

Implementation

Future<ListDeployActionExecutionTargetsOutput>
    listDeployActionExecutionTargets({
  required String actionExecutionId,
  List<TargetFilter>? filters,
  int? maxResults,
  String? nextToken,
  String? pipelineName,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodePipeline_20150709.ListDeployActionExecutionTargets'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'actionExecutionId': actionExecutionId,
      if (filters != null) 'filters': filters,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
      if (pipelineName != null) 'pipelineName': pipelineName,
    },
  );

  return ListDeployActionExecutionTargetsOutput.fromJson(jsonResponse.body);
}