listPipelines method

Future<ListPipelinesOutput> listPipelines({
  1. int? maxResults,
  2. String? nextToken,
})

Gets a summary of all of the pipelines associated with your account.

May throw InvalidNextTokenException. May throw ValidationException.

Parameter maxResults : The maximum number of pipelines to return in a single call. To retrieve the remaining pipelines, make another call with the returned nextToken value. The minimum value you can specify is 1. The maximum accepted value is 1000.

Parameter nextToken : An identifier that was returned from the previous list pipelines call. It can be used to return the next set of pipelines in the list.

Implementation

Future<ListPipelinesOutput> listPipelines({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'CodePipeline_20150709.ListPipelines'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListPipelinesOutput.fromJson(jsonResponse.body);
}