listWebhooks method
Gets a listing of all the webhooks in this Amazon Web Services Region for this account. The output lists all webhooks and includes the webhook URL and ARN and the configuration for each webhook.
May throw InvalidNextTokenException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return in a single call. To retrieve the
remaining results, make another call with the returned nextToken value.
Parameter nextToken :
The token that was returned from the previous ListWebhooks call, which can
be used to return the next set of webhooks in the list.
Implementation
Future<ListWebhooksOutput> listWebhooks({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.ListWebhooks'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListWebhooksOutput.fromJson(jsonResponse.body);
}