putActionRevision method
Provides information to CodePipeline about new revisions to a source.
May throw ActionNotFoundException.
May throw ConcurrentPipelineExecutionsLimitExceededException.
May throw PipelineNotFoundException.
May throw StageNotFoundException.
May throw ValidationException.
Parameter actionName :
The name of the action that processes the revision.
Parameter actionRevision :
Represents information about the version (or revision) of an action.
Parameter pipelineName :
The name of the pipeline that starts processing the revision to the
source.
Parameter stageName :
The name of the stage that contains the action that acts on the revision.
Implementation
Future<PutActionRevisionOutput> putActionRevision({
required String actionName,
required ActionRevision actionRevision,
required String pipelineName,
required String stageName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.PutActionRevision'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'actionName': actionName,
'actionRevision': actionRevision,
'pipelineName': pipelineName,
'stageName': stageName,
},
);
return PutActionRevisionOutput.fromJson(jsonResponse.body);
}