putThirdPartyJobFailureResult method
Represents the failure of a third party job as returned to the pipeline by a job worker. Used for partner actions only.
May throw InvalidClientTokenException.
May throw InvalidJobStateException.
May throw JobNotFoundException.
May throw ValidationException.
Parameter clientToken :
The clientToken portion of the clientId and clientToken pair used to
verify that the calling entity is allowed access to the job and its
details.
Parameter failureDetails :
Represents information about failure details.
Parameter jobId :
The ID of the job that failed. This is the same ID returned from
PollForThirdPartyJobs.
Implementation
Future<void> putThirdPartyJobFailureResult({
required String clientToken,
required FailureDetails failureDetails,
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.PutThirdPartyJobFailureResult'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'clientToken': clientToken,
'failureDetails': failureDetails,
'jobId': jobId,
},
);
}