code_pipeline_2015_07_09 library

Classes

AwsClientCredentials
AWS credentials.
CodePipeline
This is the CodePipeline API Reference. This guide provides descriptions of the actions and data types for CodePipeline. Some functionality for your pipeline can only be configured through the API. For more information, see the CodePipeline User Guide.