CodeStarConnections class

This Amazon Web Services CodeStar Connections API Reference provides descriptions and usage examples of the operations and data types for the Amazon Web Services CodeStar Connections API. You can use the connections API to work with connections and installations.

Constructors

CodeStarConnections({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createConnection({required String connectionName, String? hostArn, ProviderType? providerType, List<Tag>? tags}) Future<CreateConnectionOutput>
Creates a connection that can then be given to other Amazon Web Services services like CodePipeline so that it can access third-party code repositories. The connection is in pending status until the third-party connection handshake is completed from the console.
createHost({required String name, required String providerEndpoint, required ProviderType providerType, List<Tag>? tags, VpcConfiguration? vpcConfiguration}) Future<CreateHostOutput>
Creates a resource that represents the infrastructure where a third-party provider is installed. The host is used when you create connections to an installed third-party provider type, such as GitHub Enterprise Server. You create one host for all connections to that provider.
Creates a link to a specified external Git repository. A repository link allows Git sync to monitor and sync changes to files in a specified Git repository.
createSyncConfiguration({required String branch, required String configFile, required String repositoryLinkId, required String resourceName, required String roleArn, required SyncConfigurationType syncType, PublishDeploymentStatus? publishDeploymentStatus, TriggerResourceUpdateOn? triggerResourceUpdateOn}) Future<CreateSyncConfigurationOutput>
Creates a sync configuration which allows Amazon Web Services to sync content from a Git repository to update a specified Amazon Web Services resource. Parameters for the sync configuration are determined by the sync type.
deleteConnection({required String connectionArn}) Future<void>
The connection to be deleted.
deleteHost({required String hostArn}) Future<void>
The host to be deleted. Before you delete a host, all connections associated to the host must be deleted.
Deletes the association between your connection and a specified external Git repository.
deleteSyncConfiguration({required String resourceName, required SyncConfigurationType syncType}) Future<void>
Deletes the sync configuration for a specified repository and connection.
getConnection({required String connectionArn}) Future<GetConnectionOutput>
Returns the connection ARN and details such as status, owner, and provider type.
getHost({required String hostArn}) Future<GetHostOutput>
Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration.
Returns details about a repository link. A repository link allows Git sync to monitor and sync changes from files in a specified Git repository.
getRepositorySyncStatus({required String branch, required String repositoryLinkId, required SyncConfigurationType syncType}) Future<GetRepositorySyncStatusOutput>
Returns details about the sync status for a repository. A repository sync uses Git sync to push and pull changes from your remote repository.
getResourceSyncStatus({required String resourceName, required SyncConfigurationType syncType}) Future<GetResourceSyncStatusOutput>
Returns the status of the sync with the Git repository for a specific Amazon Web Services resource.
getSyncBlockerSummary({required String resourceName, required SyncConfigurationType syncType}) Future<GetSyncBlockerSummaryOutput>
Returns a list of the most recent sync blockers.
getSyncConfiguration({required String resourceName, required SyncConfigurationType syncType}) Future<GetSyncConfigurationOutput>
Returns details about a sync configuration, including the sync type and resource name. A sync configuration allows the configuration to sync (push and pull) changes from the remote repository for a specified branch in a Git repository.
listConnections({String? hostArnFilter, int? maxResults, String? nextToken, ProviderType? providerTypeFilter}) Future<ListConnectionsOutput>
Lists the connections associated with your account.
listHosts({int? maxResults, String? nextToken}) Future<ListHostsOutput>
Lists the hosts associated with your account.
Lists the repository links created for connections in your account.
listRepositorySyncDefinitions({required String repositoryLinkId, required SyncConfigurationType syncType}) Future<ListRepositorySyncDefinitionsOutput>
Lists the repository sync definitions for repository links in your account.
listSyncConfigurations({required String repositoryLinkId, required SyncConfigurationType syncType, int? maxResults, String? nextToken}) Future<ListSyncConfigurationsOutput>
Returns a list of sync configurations for a specified repository.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Gets the set of key-value pairs (metadata) that are used to manage the resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Adds to or modifies the tags of the given resource. Tags are metadata that can be used to manage a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from an Amazon Web Services resource.
updateHost({required String hostArn, String? providerEndpoint, VpcConfiguration? vpcConfiguration}) Future<void>
Updates a specified host with the provided configurations.
Updates the association between your connection and a specified external Git repository. A repository link allows Git sync to monitor and sync changes to files in a specified Git repository.
updateSyncBlocker({required String id, required String resolvedReason, required String resourceName, required SyncConfigurationType syncType}) Future<UpdateSyncBlockerOutput>
Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue.
updateSyncConfiguration({required String resourceName, required SyncConfigurationType syncType, String? branch, String? configFile, PublishDeploymentStatus? publishDeploymentStatus, String? repositoryLinkId, String? roleArn, TriggerResourceUpdateOn? triggerResourceUpdateOn}) Future<UpdateSyncConfigurationOutput>
Updates the sync configuration for your connection and a specified external Git repository.

Operators

operator ==(Object other) bool
The equality operator.
inherited