deleteSyncConfiguration method

Future<void> deleteSyncConfiguration({
  1. required String resourceName,
  2. required SyncConfigurationType syncType,
})

Deletes the sync configuration for a specified repository and connection.

May throw AccessDeniedException. May throw ConcurrentModificationException. May throw InternalServerException. May throw InvalidInputException. May throw LimitExceededException. May throw ThrottlingException.

Parameter resourceName : The name of the Amazon Web Services resource associated with the sync configuration to be deleted.

Parameter syncType : The type of sync configuration to be deleted.

Implementation

Future<void> deleteSyncConfiguration({
  required String resourceName,
  required SyncConfigurationType syncType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CodeStar_connections_20191201.DeleteSyncConfiguration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceName': resourceName,
      'SyncType': syncType.value,
    },
  );
}