getRepositoryLink method

Future<GetRepositoryLinkOutput> getRepositoryLink({
  1. required String repositoryLinkId,
})

Returns details about a repository link. A repository link allows Git sync to monitor and sync changes from files in a specified Git repository.

May throw AccessDeniedException. May throw ConcurrentModificationException. May throw InternalServerException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter repositoryLinkId : The ID of the repository link to get.

Implementation

Future<GetRepositoryLinkOutput> getRepositoryLink({
  required String repositoryLinkId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CodeStar_connections_20191201.GetRepositoryLink'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RepositoryLinkId': repositoryLinkId,
    },
  );

  return GetRepositoryLinkOutput.fromJson(jsonResponse.body);
}