getRepositorySyncStatus method
Returns details about the sync status for a repository. A repository sync uses Git sync to push and pull changes from your remote repository.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter branch :
The branch of the repository link for the requested repository sync
status.
Parameter repositoryLinkId :
The repository link ID for the requested repository sync status.
Parameter syncType :
The sync type of the requested sync status.
Implementation
Future<GetRepositorySyncStatusOutput> getRepositorySyncStatus({
required String branch,
required String repositoryLinkId,
required SyncConfigurationType syncType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CodeStar_connections_20191201.GetRepositorySyncStatus'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Branch': branch,
'RepositoryLinkId': repositoryLinkId,
'SyncType': syncType.value,
},
);
return GetRepositorySyncStatusOutput.fromJson(jsonResponse.body);
}