getSyncBlockerSummary method

Future<GetSyncBlockerSummaryOutput> getSyncBlockerSummary({
  1. required String resourceName,
  2. required SyncConfigurationType syncType,
})

Returns a list of the most recent sync blockers.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter resourceName : The name of the Amazon Web Services resource currently blocked from automatically being synced from a Git repository.

Parameter syncType : The sync type for the sync blocker summary.

Implementation

Future<GetSyncBlockerSummaryOutput> getSyncBlockerSummary({
  required String resourceName,
  required SyncConfigurationType syncType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CodeStar_connections_20191201.GetSyncBlockerSummary'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceName': resourceName,
      'SyncType': syncType.value,
    },
  );

  return GetSyncBlockerSummaryOutput.fromJson(jsonResponse.body);
}