updateRepositoryLink method
Updates the association between your connection and a specified external Git repository. A repository link allows Git sync to monitor and sync changes to files in a specified Git repository.
May throw AccessDeniedException.
May throw ConditionalCheckFailedException.
May throw InternalServerException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UpdateOutOfSyncException.
Parameter repositoryLinkId :
The ID of the repository link to be updated.
Parameter connectionArn :
The Amazon Resource Name (ARN) of the connection for the repository link
to be updated. The updated connection ARN must have the same providerType
(such as GitHub) as the original connection ARN for the repo link.
Parameter encryptionKeyArn :
The Amazon Resource Name (ARN) of the encryption key for the repository
link to be updated.
Implementation
Future<UpdateRepositoryLinkOutput> updateRepositoryLink({
required String repositoryLinkId,
String? connectionArn,
String? encryptionKeyArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CodeStar_connections_20191201.UpdateRepositoryLink'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RepositoryLinkId': repositoryLinkId,
if (connectionArn != null) 'ConnectionArn': connectionArn,
if (encryptionKeyArn != null) 'EncryptionKeyArn': encryptionKeyArn,
},
);
return UpdateRepositoryLinkOutput.fromJson(jsonResponse.body);
}