updateSyncBlocker method

Future<UpdateSyncBlockerOutput> updateSyncBlocker({
  1. required String id,
  2. required String resolvedReason,
  3. required String resourceName,
  4. required SyncConfigurationType syncType,
})

Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw RetryLatestCommitFailedException. May throw SyncBlockerDoesNotExistException. May throw ThrottlingException.

Parameter id : The ID of the sync blocker to be updated.

Parameter resolvedReason : The reason for resolving the sync blocker.

Parameter resourceName : The name of the resource for the sync blocker to be updated.

Parameter syncType : The sync type of the sync blocker to be updated.

Implementation

Future<UpdateSyncBlockerOutput> updateSyncBlocker({
  required String id,
  required String resolvedReason,
  required String resourceName,
  required SyncConfigurationType syncType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'CodeStar_connections_20191201.UpdateSyncBlocker'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'ResolvedReason': resolvedReason,
      'ResourceName': resourceName,
      'SyncType': syncType.value,
    },
  );

  return UpdateSyncBlockerOutput.fromJson(jsonResponse.body);
}