Codeartifact class
CodeArtifact is a fully managed artifact repository compatible with language-native package managers and build tools such as npm, Apache Maven, pip, and dotnet. You can use CodeArtifact to share packages with development teams and pull packages. Packages can be pulled from both public and CodeArtifact repositories. You can also create an upstream relationship between a CodeArtifact repository and another repository, which effectively merges their contents from the point of view of a package manager client.
CodeArtifact concepts
-
Repository: A CodeArtifact repository contains a set of package
versions, each of which maps to a set of assets, or files. Repositories
are polyglot, so a single repository can contain packages of any supported
type. Each repository exposes endpoints for fetching and publishing packages
using tools such as the
npmCLI or the Maven CLI (mvn). For a list of supported package managers, see the CodeArtifact User Guide. -
Domain: Repositories are aggregated into a higher-level entity known
as a domain. All package assets and metadata are stored in the
domain, but are consumed through repositories. A given package asset, such
as a Maven JAR file, is stored once per domain, no matter how many
repositories it's present in. All of the assets and metadata in a domain are
encrypted with the same customer master key (CMK) stored in Key Management
Service (KMS).
Each repository is a member of a single domain and can't be moved to a different domain.
The domain allows organizational policy to be applied across multiple repositories, such as which accounts can access repositories in the domain, and which public repositories can be used as sources of packages.
Although an organization can have multiple domains, we recommend a single production domain that contains all published artifacts so that teams can find and share packages across their organization.
-
Package: A package is a bundle of software and the metadata
required to resolve dependencies and install the software. CodeArtifact
supports npm, PyPI, Maven, NuGet, Swift, Ruby, Cargo, and generic package
formats. For more information about the supported package formats and how to
use CodeArtifact with them, see the CodeArtifact
User Guide.
In CodeArtifact, a package consists of:
-
A name (for example,
webpackis the name of a popular npm package) -
An optional namespace (for example,
@typesin@types/node) -
A set of versions (for example,
1.0.0,1.0.1,1.0.2, etc.) - Package-level metadata (for example, npm tags)
-
A name (for example,
- Package group: A group of packages that match a specified definition. Package groups can be used to apply configuration to multiple packages that match a defined pattern using package format, package namespace, and package name. You can use package groups to more conveniently configure package origin controls for multiple packages. Package origin controls are used to block or allow ingestion or publishing of new package versions, which protects users from malicious actions known as dependency substitution attacks.
-
Package version: A version of a package, such as
@types/node 12.6.9. The version number format and semantics vary for different package formats. For example, npm package versions must conform to the Semantic Versioning specification. In CodeArtifact, a package version consists of the version identifier, metadata at the package version level, and a set of assets. - Upstream repository: One repository is upstream of another when the package versions in it can be accessed from the repository endpoint of the downstream repository, effectively merging the contents of the two repositories from the point of view of a client. CodeArtifact allows creating an upstream relationship between two repositories.
-
Asset: An individual file stored in CodeArtifact associated with a
package version, such as an npm
.tgzfile or Maven POM and JAR files.
-
AssociateExternalConnection: Adds an existing external connection to a repository. -
CopyPackageVersions: Copies package versions from one repository to another repository in the same domain. -
CreateDomain: Creates a domain. -
CreatePackageGroup: Creates a package group. -
CreateRepository: Creates a CodeArtifact repository in a domain. -
DeleteDomain: Deletes a domain. You cannot delete a domain that contains repositories. -
DeleteDomainPermissionsPolicy: Deletes the resource policy that is set on a domain. -
DeletePackage: Deletes a package and all associated package versions. -
DeletePackageGroup: Deletes a package group. Does not delete packages or package versions that are associated with a package group. -
DeletePackageVersions: Deletes versions of a package. After a package has been deleted, it can be republished, but its assets and metadata cannot be restored because they have been permanently removed from storage. -
DeleteRepository: Deletes a repository. -
DeleteRepositoryPermissionsPolicy: Deletes the resource policy that is set on a repository. -
DescribeDomain: Returns aDomainDescriptionobject that contains information about the requested domain. -
DescribePackage: Returns a PackageDescription object that contains details about a package. -
DescribePackageGroup: Returns a PackageGroup object that contains details about a package group. -
DescribePackageVersion: Returns a PackageVersionDescription object that contains details about a package version. -
DescribeRepository: Returns aRepositoryDescriptionobject that contains detailed information about the requested repository. -
DisposePackageVersions: Disposes versions of a package. A package version with the statusDisposedcannot be restored because they have been permanently removed from storage. -
DisassociateExternalConnection: Removes an existing external connection from a repository. -
GetAssociatedPackageGroup: Returns the most closely associated package group to the specified package. -
GetAuthorizationToken: Generates a temporary authorization token for accessing repositories in the domain. The token expires the authorization period has passed. The default authorization period is 12 hours and can be customized to any length with a maximum of 12 hours. -
GetDomainPermissionsPolicy: Returns the policy of a resource that is attached to the specified domain. -
GetPackageVersionAsset: Returns the contents of an asset that is in a package version. -
GetPackageVersionReadme: Gets the readme file or descriptive text for a package version. -
GetRepositoryEndpoint: Returns the endpoint of a repository for a specific package format. A repository has one endpoint for each package format:-
cargo -
generic -
maven -
npm -
nuget -
pypi -
ruby -
swift
-
-
GetRepositoryPermissionsPolicy: Returns the resource policy that is set on a repository. -
ListAllowedRepositoriesForGroup: Lists the allowed repositories for a package group that has origin configuration set toALLOW_SPECIFIC_REPOSITORIES. -
ListAssociatedPackages: Returns a list of packages associated with the requested package group. -
ListDomains: Returns a list ofDomainSummaryobjects. Each returnedDomainSummaryobject contains information about a domain. -
ListPackages: Lists the packages in a repository. -
ListPackageGroups: Returns a list of package groups in the requested domain. -
ListPackageVersionAssets: Lists the assets for a given package version. -
ListPackageVersionDependencies: Returns a list of the direct dependencies for a package version. -
ListPackageVersions: Returns a list of package versions for a specified package in a repository. -
ListRepositories: Returns a list of repositories owned by the Amazon Web Services account that called this method. -
ListRepositoriesInDomain: Returns a list of the repositories in a domain. -
ListSubPackageGroups: Returns a list of direct children of the specified package group. -
PublishPackageVersion: Creates a new package version containing one or more assets. -
PutDomainPermissionsPolicy: Attaches a resource policy to a domain. -
PutPackageOriginConfiguration: Sets the package origin configuration for a package, which determine how new versions of the package can be added to a specific repository. -
PutRepositoryPermissionsPolicy: Sets the resource policy on a repository that specifies permissions to access it. -
UpdatePackageGroup: Updates a package group. This API cannot be used to update a package group's origin configuration or pattern. -
UpdatePackageGroupOriginConfiguration: Updates the package origin configuration for a package group. -
UpdatePackageVersionsStatus: Updates the status of one or more versions of a package. -
UpdateRepository: Updates the properties of a repository.
Constructors
- Codeartifact({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateExternalConnection(
{required String domain, required String externalConnection, required String repository, String? domainOwner}) → Future< AssociateExternalConnectionResult> - Adds an existing external connection to a repository. One external connection is allowed per repository.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
copyPackageVersions(
{required String destinationRepository, required String domain, required PackageFormat format, required String package, required String sourceRepository, bool? allowOverwrite, String? domainOwner, bool? includeFromUpstream, String? namespace, Map< String, String> ? versionRevisions, List<String> ? versions}) → Future<CopyPackageVersionsResult> - Copies package versions from one repository to another repository in the same domain.
-
createDomain(
{required String domain, String? encryptionKey, List< Tag> ? tags}) → Future<CreateDomainResult> - Creates a domain. CodeArtifact domains make it easier to manage multiple repositories across an organization. You can use a domain to apply permissions across many repositories owned by different Amazon Web Services accounts. An asset is stored only once in a domain, even if it's in multiple repositories.
-
createPackageGroup(
{required String domain, required String packageGroup, String? contactInfo, String? description, String? domainOwner, List< Tag> ? tags}) → Future<CreatePackageGroupResult> - Creates a package group. For more information about creating package groups, including example CLI commands, see Create a package group in the CodeArtifact User Guide.
-
createRepository(
{required String domain, required String repository, String? description, String? domainOwner, List< Tag> ? tags, List<UpstreamRepository> ? upstreams}) → Future<CreateRepositoryResult> - Creates a repository.
-
deleteDomain(
{required String domain, String? domainOwner}) → Future< DeleteDomainResult> - Deletes a domain. You cannot delete a domain that contains repositories. If you want to delete a domain with repositories, first delete its repositories.
-
deleteDomainPermissionsPolicy(
{required String domain, String? domainOwner, String? policyRevision}) → Future< DeleteDomainPermissionsPolicyResult> - Deletes the resource policy set on a domain.
-
deletePackage(
{required String domain, required PackageFormat format, required String package, required String repository, String? domainOwner, String? namespace}) → Future< DeletePackageResult> - Deletes a package and all associated package versions. A deleted package cannot be restored. To delete one or more package versions, use the DeletePackageVersions API.
-
deletePackageGroup(
{required String domain, required String packageGroup, String? domainOwner}) → Future< DeletePackageGroupResult> - Deletes a package group. Deleting a package group does not delete packages or package versions associated with the package group. When a package group is deleted, the direct child package groups will become children of the package group's direct parent package group. Therefore, if any of the child groups are inheriting any settings from the parent, those settings could change.
-
deletePackageVersions(
{required String domain, required PackageFormat format, required String package, required String repository, required List< String> versions, String? domainOwner, PackageVersionStatus? expectedStatus, String? namespace}) → Future<DeletePackageVersionsResult> -
Deletes one or more versions of a package. A deleted package version
cannot be restored in your repository. If you want to remove a package
version from your repository and be able to restore it later, set its
status to
Archived. Archived packages cannot be downloaded from a repository and don't show up with list package APIs (for example, ListPackageVersions), but you can restore them using UpdatePackageVersionsStatus. -
deleteRepository(
{required String domain, required String repository, String? domainOwner}) → Future< DeleteRepositoryResult> - Deletes a repository.
-
deleteRepositoryPermissionsPolicy(
{required String domain, required String repository, String? domainOwner, String? policyRevision}) → Future< DeleteRepositoryPermissionsPolicyResult> - Deletes the resource policy that is set on a repository. After a resource policy is deleted, the permissions allowed and denied by the deleted policy are removed. The effect of deleting a resource policy might not be immediate.
-
describeDomain(
{required String domain, String? domainOwner}) → Future< DescribeDomainResult> - Returns a DomainDescription object that contains information about the requested domain.
-
describePackage(
{required String domain, required PackageFormat format, required String package, required String repository, String? domainOwner, String? namespace}) → Future< DescribePackageResult> - Returns a PackageDescription object that contains information about the requested package.
-
describePackageGroup(
{required String domain, required String packageGroup, String? domainOwner}) → Future< DescribePackageGroupResult> - Returns a PackageGroupDescription object that contains information about the requested package group.
-
describePackageVersion(
{required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, String? namespace}) → Future< DescribePackageVersionResult> - Returns a PackageVersionDescription object that contains information about the requested package version.
-
describeRepository(
{required String domain, required String repository, String? domainOwner}) → Future< DescribeRepositoryResult> -
Returns a
RepositoryDescriptionobject that contains detailed information about the requested repository. -
disassociateExternalConnection(
{required String domain, required String externalConnection, required String repository, String? domainOwner}) → Future< DisassociateExternalConnectionResult> - Removes an existing external connection from a repository.
-
disposePackageVersions(
{required String domain, required PackageFormat format, required String package, required String repository, required List< String> versions, String? domainOwner, PackageVersionStatus? expectedStatus, String? namespace, Map<String, String> ? versionRevisions}) → Future<DisposePackageVersionsResult> -
Deletes the assets in package versions and sets the package versions'
status to
Disposed. A disposed package version cannot be restored in your repository because its assets are deleted. -
getAssociatedPackageGroup(
{required String domain, required PackageFormat format, required String package, String? domainOwner, String? namespace}) → Future< GetAssociatedPackageGroupResult> -
Returns the most closely associated package group to the specified
package. This API does not require that the package exist in any
repository in the domain. As such,
GetAssociatedPackageGroupcan be used to see which package group's origin configuration applies to a package before that package is in a repository. This can be helpful to check if public packages are blocked without ingesting them. -
getAuthorizationToken(
{required String domain, String? domainOwner, int? durationSeconds}) → Future< GetAuthorizationTokenResult> -
Generates a temporary authorization token for accessing repositories in
the domain. This API requires the
codeartifact:GetAuthorizationTokenandsts:GetServiceBearerTokenpermissions. For more information about authorization tokens, see CodeArtifact authentication and tokens. -
getDomainPermissionsPolicy(
{required String domain, String? domainOwner}) → Future< GetDomainPermissionsPolicyResult> - Returns the resource policy attached to the specified domain.
-
getPackageVersionAsset(
{required String asset, required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, String? namespace, String? packageVersionRevision}) → Future< GetPackageVersionAssetResult> -
Returns an asset (or file) that is in a package. For example, for a Maven
package version, use
GetPackageVersionAssetto download aJARfile, aPOMfile, or any other assets in the package version. -
getPackageVersionReadme(
{required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, String? namespace}) → Future< GetPackageVersionReadmeResult> - Gets the readme file or descriptive text for a package version.
-
getRepositoryEndpoint(
{required String domain, required PackageFormat format, required String repository, String? domainOwner, EndpointType? endpointType}) → Future< GetRepositoryEndpointResult> - Returns the endpoint of a repository for a specific package format. A repository has one endpoint for each package format:
-
getRepositoryPermissionsPolicy(
{required String domain, required String repository, String? domainOwner}) → Future< GetRepositoryPermissionsPolicyResult> - Returns the resource policy that is set on a repository.
-
listAllowedRepositoriesForGroup(
{required String domain, required PackageGroupOriginRestrictionType originRestrictionType, required String packageGroup, String? domainOwner, int? maxResults, String? nextToken}) → Future< ListAllowedRepositoriesForGroupResult> - Lists the repositories in the added repositories list of the specified restriction type for a package group. For more information about restriction types and added repository lists, see Package group origin controls in the CodeArtifact User Guide.
-
listAssociatedPackages(
{required String domain, required String packageGroup, String? domainOwner, int? maxResults, String? nextToken, bool? preview}) → Future< ListAssociatedPackagesResult> - Returns a list of packages associated with the requested package group. For information package group association and matching, see Package group definition syntax and matching behavior in the CodeArtifact User Guide.
-
listDomains(
{int? maxResults, String? nextToken}) → Future< ListDomainsResult> -
Returns a list of DomainSummary
objects for all domains owned by the Amazon Web Services account that
makes this call. Each returned
DomainSummaryobject contains information about a domain. -
listPackageGroups(
{required String domain, String? domainOwner, int? maxResults, String? nextToken, String? prefix}) → Future< ListPackageGroupsResult> - Returns a list of package groups in the requested domain.
-
listPackages(
{required String domain, required String repository, String? domainOwner, PackageFormat? format, int? maxResults, String? namespace, String? nextToken, String? packagePrefix, AllowPublish? publish, AllowUpstream? upstream}) → Future< ListPackagesResult> - Returns a list of PackageSummary objects for packages in a repository that match the request parameters.
-
listPackageVersionAssets(
{required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, int? maxResults, String? namespace, String? nextToken}) → Future< ListPackageVersionAssetsResult> - Returns a list of AssetSummary objects for assets in a package version.
-
listPackageVersionDependencies(
{required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, String? namespace, String? nextToken}) → Future< ListPackageVersionDependenciesResult> -
Returns the direct dependencies for a package version. The dependencies
are returned as PackageDependency
objects. CodeArtifact extracts the dependencies for a package version from
the metadata file for the package format (for example, the
package.jsonfile for npm packages and thepom.xmlfile for Maven). Any package version dependencies that are not listed in the configuration file are not returned. -
listPackageVersions(
{required String domain, required PackageFormat format, required String package, required String repository, String? domainOwner, int? maxResults, String? namespace, String? nextToken, PackageVersionOriginType? originType, PackageVersionSortType? sortBy, PackageVersionStatus? status}) → Future< ListPackageVersionsResult> -
Returns a list of PackageVersionSummary
objects for package versions in a repository that match the request
parameters. Package versions of all statuses will be returned by default
when calling
list-package-versionswith no--statusparameter. -
listRepositories(
{int? maxResults, String? nextToken, String? repositoryPrefix}) → Future< ListRepositoriesResult> -
Returns a list of RepositorySummary
objects. Each
RepositorySummarycontains information about a repository in the specified Amazon Web Services account and that matches the input parameters. -
listRepositoriesInDomain(
{required String domain, String? administratorAccount, String? domainOwner, int? maxResults, String? nextToken, String? repositoryPrefix}) → Future< ListRepositoriesInDomainResult> -
Returns a list of RepositorySummary
objects. Each
RepositorySummarycontains information about a repository in the specified domain and that matches the input parameters. -
listSubPackageGroups(
{required String domain, required String packageGroup, String? domainOwner, int? maxResults, String? nextToken}) → Future< ListSubPackageGroupsResult> - Returns a list of direct children of the specified package group.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResult> - Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in CodeArtifact.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publishPackageVersion(
{required Uint8List assetContent, required String assetName, required String assetSHA256, required String domain, required PackageFormat format, required String package, required String packageVersion, required String repository, String? domainOwner, String? namespace, bool? unfinished}) → Future< PublishPackageVersionResult> - Creates a new package version containing one or more assets (or files).
-
putDomainPermissionsPolicy(
{required String domain, required String policyDocument, String? domainOwner, String? policyRevision}) → Future< PutDomainPermissionsPolicyResult> - Sets a resource policy on a domain that specifies permissions to access it.
-
putPackageOriginConfiguration(
{required String domain, required PackageFormat format, required String package, required String repository, required PackageOriginRestrictions restrictions, String? domainOwner, String? namespace}) → Future< PutPackageOriginConfigurationResult> - Sets the package origin configuration for a package.
-
putRepositoryPermissionsPolicy(
{required String domain, required String policyDocument, required String repository, String? domainOwner, String? policyRevision}) → Future< PutRepositoryPermissionsPolicyResult> - Sets the resource policy on a repository that specifies permissions to access it.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Adds or updates tags for a resource in CodeArtifact.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from a resource in CodeArtifact.
-
updatePackageGroup(
{required String domain, required String packageGroup, String? contactInfo, String? description, String? domainOwner}) → Future< UpdatePackageGroupResult> - Updates a package group. This API cannot be used to update a package group's origin configuration or pattern. To update a package group's origin configuration, use UpdatePackageGroupOriginConfiguration.
-
updatePackageGroupOriginConfiguration(
{required String domain, required String packageGroup, List< PackageGroupAllowedRepository> ? addAllowedRepositories, String? domainOwner, List<PackageGroupAllowedRepository> ? removeAllowedRepositories, Map<PackageGroupOriginRestrictionType, PackageGroupOriginRestrictionMode> ? restrictions}) → Future<UpdatePackageGroupOriginConfigurationResult> - Updates the package origin configuration for a package group.
-
updatePackageVersionsStatus(
{required String domain, required PackageFormat format, required String package, required String repository, required PackageVersionStatus targetStatus, required List< String> versions, String? domainOwner, PackageVersionStatus? expectedStatus, String? namespace, Map<String, String> ? versionRevisions}) → Future<UpdatePackageVersionsStatusResult> -
Updates the status of one or more versions of a package. Using
UpdatePackageVersionsStatus, you can update the status of package versions toArchived,Published, orUnlisted. To set the status of a package version toDisposed, use DisposePackageVersions. -
updateRepository(
{required String domain, required String repository, String? description, String? domainOwner, List< UpstreamRepository> ? upstreams}) → Future<UpdateRepositoryResult> - Update the properties of a repository.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited