deleteDomain method

Future<DeleteDomainResult> deleteDomain({
  1. required String domain,
  2. String? domainOwner,
})

Deletes a domain. You cannot delete a domain that contains repositories. If you want to delete a domain with repositories, first delete its repositories.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter domain : The name of the domain to delete.

Parameter domainOwner : The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

Implementation

Future<DeleteDomainResult> deleteDomain({
  required String domain,
  String? domainOwner,
}) async {
  final $query = <String, List<String>>{
    'domain': [domain],
    if (domainOwner != null) 'domain-owner': [domainOwner],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/v1/domain',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDomainResult.fromJson(response);
}