deleteDomainPermissionsPolicy method
Deletes the resource policy set on a domain.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain associated with the resource policy to be deleted.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Parameter policyRevision :
The current revision of the resource policy to be deleted. This revision
is used for optimistic locking, which prevents others from overwriting
your changes to the domain's resource policy.
Implementation
Future<DeleteDomainPermissionsPolicyResult> deleteDomainPermissionsPolicy({
required String domain,
String? domainOwner,
String? policyRevision,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
if (domainOwner != null) 'domain-owner': [domainOwner],
if (policyRevision != null) 'policy-revision': [policyRevision],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/domain/permissions/policy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeleteDomainPermissionsPolicyResult.fromJson(response);
}