deletePackageGroup method
Deletes a package group. Deleting a package group does not delete packages or package versions associated with the package group. When a package group is deleted, the direct child package groups will become children of the package group's direct parent package group. Therefore, if any of the child groups are inheriting any settings from the parent, those settings could change.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The domain that contains the package group to be deleted.
Parameter packageGroup :
The pattern of the package group to be deleted.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DeletePackageGroupResult> deletePackageGroup({
required String domain,
required String packageGroup,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'package-group': [packageGroup],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/package-group',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeletePackageGroupResult.fromJson(response);
}