describeDomain method
Returns a DomainDescription object that contains information about the requested domain.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
A string that specifies the name of the requested domain.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DescribeDomainResult> describeDomain({
required String domain,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/domain',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeDomainResult.fromJson(response);
}