getDomainPermissionsPolicy method

Future<GetDomainPermissionsPolicyResult> getDomainPermissionsPolicy({
  1. required String domain,
  2. String? domainOwner,
})

Returns the resource policy attached to the specified domain.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domain : The name of the domain to which the resource policy is attached.

Parameter domainOwner : The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

Implementation

Future<GetDomainPermissionsPolicyResult> getDomainPermissionsPolicy({
  required String domain,
  String? domainOwner,
}) async {
  final $query = <String, List<String>>{
    'domain': [domain],
    if (domainOwner != null) 'domain-owner': [domainOwner],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/domain/permissions/policy',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetDomainPermissionsPolicyResult.fromJson(response);
}