getRepositoryPermissionsPolicy method
Returns the resource policy that is set on a repository.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain containing the repository whose associated resource
policy is to be retrieved.
Parameter repository :
The name of the repository whose associated resource policy is to be
retrieved.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<GetRepositoryPermissionsPolicyResult> getRepositoryPermissionsPolicy({
required String domain,
required String repository,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'repository': [repository],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/repository/permissions/policy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetRepositoryPermissionsPolicyResult.fromJson(response);
}