listPackageVersionAssets method
Returns a list of AssetSummary objects for assets in a package version.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that contains the repository associated with the
package version assets.
Parameter format :
The format of the package that contains the requested package version
assets.
Parameter package :
The name of the package that contains the requested package version
assets.
Parameter packageVersion :
A string that contains the package version (for example,
3.5.2).
Parameter repository :
The name of the repository that contains the package that contains the
requested package version assets.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Parameter maxResults :
The maximum number of results to return per page.
Parameter namespace :
The namespace of the package version that contains the requested package
version assets. The package component that specifies its namespace depends
on its type. For example:
- Maven
- Swift
- generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. - Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListPackageVersionAssetsResult> listPackageVersionAssets({
required String domain,
required PackageFormat format,
required String package,
required String packageVersion,
required String repository,
String? domainOwner,
int? maxResults,
String? namespace,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
'domain': [domain],
'format': [format.value],
'package': [package],
'version': [packageVersion],
'repository': [repository],
if (domainOwner != null) 'domain-owner': [domainOwner],
if (maxResults != null) 'max-results': [maxResults.toString()],
if (namespace != null) 'namespace': [namespace],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/v1/package/version/assets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListPackageVersionAssetsResult.fromJson(response);
}