listRepositoriesInDomain method

Future<ListRepositoriesInDomainResult> listRepositoriesInDomain({
  1. required String domain,
  2. String? administratorAccount,
  3. String? domainOwner,
  4. int? maxResults,
  5. String? nextToken,
  6. String? repositoryPrefix,
})

Returns a list of RepositorySummary objects. Each RepositorySummary contains information about a repository in the specified domain and that matches the input parameters.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domain : The name of the domain that contains the returned list of repositories.

Parameter administratorAccount : Filter the list of repositories to only include those that are managed by the Amazon Web Services account ID.

Parameter domainOwner : The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Parameter repositoryPrefix : A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned.

Implementation

Future<ListRepositoriesInDomainResult> listRepositoriesInDomain({
  required String domain,
  String? administratorAccount,
  String? domainOwner,
  int? maxResults,
  String? nextToken,
  String? repositoryPrefix,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    'domain': [domain],
    if (administratorAccount != null)
      'administrator-account': [administratorAccount],
    if (domainOwner != null) 'domain-owner': [domainOwner],
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
    if (repositoryPrefix != null) 'repository-prefix': [repositoryPrefix],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/v1/domain/repositories',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRepositoriesInDomainResult.fromJson(response);
}