CodestarNotifications class

This CodeStar Notifications API Reference provides descriptions and usage examples of the operations and data types for the CodeStar Notifications API. You can use the CodeStar Notifications API to work with the following objects:

Notification rules, by calling the following:

Targets, by calling the following:
  • DeleteTarget, which removes a notification rule target from a notification rule.
  • ListTargets, which lists the targets associated with a notification rule.
Events, by calling the following:
  • ListEventTypes, which lists the event types you can include in a notification rule.
Tags, by calling the following:
  • ListTagsForResource, which lists the tags already associated with a notification rule in your account.
  • TagResource, which associates a tag you provide with a notification rule in your account.
  • UntagResource, which removes a tag from a notification rule in your account.
For information about how to use CodeStar Notifications, see the Amazon Web Services Developer Tools Console User Guide.

Constructors

CodestarNotifications({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createNotificationRule({required DetailType detailType, required List<String> eventTypeIds, required String name, required String resource, required List<Target> targets, String? clientRequestToken, NotificationRuleStatus? status, Map<String, String>? tags}) Future<CreateNotificationRuleResult>
Creates a notification rule for a resource. The rule specifies the events you want notifications about and the targets (such as Amazon Q Developer in chat applications topics or Amazon Q Developer in chat applications clients configured for Slack) where you want to receive them.
deleteNotificationRule({required String arn}) Future<DeleteNotificationRuleResult>
Deletes a notification rule for a resource.
deleteTarget({required String targetAddress, bool? forceUnsubscribeAll}) Future<void>
Deletes a specified target for notifications.
describeNotificationRule({required String arn}) Future<DescribeNotificationRuleResult>
Returns information about a specified notification rule.
listEventTypes({List<ListEventTypesFilter>? filters, int? maxResults, String? nextToken}) Future<ListEventTypesResult>
Returns information about the event types available for configuring notifications.
listNotificationRules({List<ListNotificationRulesFilter>? filters, int? maxResults, String? nextToken}) Future<ListNotificationRulesResult>
Returns a list of the notification rules for an Amazon Web Services account.
listTagsForResource({required String arn}) Future<ListTagsForResourceResult>
Returns a list of the tags associated with a notification rule.
listTargets({List<ListTargetsFilter>? filters, int? maxResults, String? nextToken}) Future<ListTargetsResult>
Returns a list of the notification rule targets for an Amazon Web Services account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe({required String arn, required Target target, String? clientRequestToken}) Future<SubscribeResult>
Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered.
tagResource({required String arn, required Map<String, String> tags}) Future<TagResourceResult>
Associates a set of provided tags with a notification rule.
toString() String
A string representation of this object.
inherited
unsubscribe({required String arn, required String targetAddress}) Future<UnsubscribeResult>
Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.
untagResource({required String arn, required List<String> tagKeys}) Future<void>
Removes the association between one or more provided tags and a notification rule.
updateNotificationRule({required String arn, DetailType? detailType, List<String>? eventTypeIds, String? name, NotificationRuleStatus? status, List<Target>? targets}) Future<void>
Updates a notification rule for a resource. You can change the events that trigger the notification rule, the status of the rule, and the targets that receive the notifications.

Operators

operator ==(Object other) bool
The equality operator.
inherited