deleteTarget method
Deletes a specified target for notifications.
May throw ValidationException.
Parameter targetAddress :
The Amazon Resource Name (ARN) of the Amazon Q Developer in chat
applications topic or Amazon Q Developer in chat applications client to
delete.
Parameter forceUnsubscribeAll :
A Boolean value that can be used to delete all associations with this
Amazon Q Developer in chat applications topic. The default value is FALSE.
If set to TRUE, all associations between that target and every
notification rule in your Amazon Web Services account are deleted.
Implementation
Future<void> deleteTarget({
required String targetAddress,
bool? forceUnsubscribeAll,
}) async {
final $payload = <String, dynamic>{
'TargetAddress': targetAddress,
if (forceUnsubscribeAll != null)
'ForceUnsubscribeAll': forceUnsubscribeAll,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/deleteTarget',
exceptionFnMap: _exceptionFns,
);
}