tagResource method

Future<TagResourceResult> tagResource({
  1. required String arn,
  2. required Map<String, String> tags,
})

Associates a set of provided tags with a notification rule.

May throw ConcurrentModificationException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the notification rule to tag.

Parameter tags : The list of tags to associate with the resource. Tag key names cannot start with "aws".

Implementation

Future<TagResourceResult> tagResource({
  required String arn,
  required Map<String, String> tags,
}) async {
  final $payload = <String, dynamic>{
    'Arn': arn,
    'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/tagResource',
    exceptionFnMap: _exceptionFns,
  );
  return TagResourceResult.fromJson(response);
}