unsubscribe method
Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) of the notification rule.
Parameter targetAddress :
The ARN of the Amazon Q Developer in chat applications topic to
unsubscribe from the notification rule.
Implementation
Future<UnsubscribeResult> unsubscribe({
required String arn,
required String targetAddress,
}) async {
final $payload = <String, dynamic>{
'Arn': arn,
'TargetAddress': targetAddress,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/unsubscribe',
exceptionFnMap: _exceptionFns,
);
return UnsubscribeResult.fromJson(response);
}