untagResource method

Future<void> untagResource({
  1. required String arn,
  2. required List<String> tagKeys,
})

Removes the association between one or more provided tags and a notification rule.

May throw ConcurrentModificationException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the notification rule from which to remove the tags.

Parameter tagKeys : The key names of the tags to remove.

Implementation

Future<void> untagResource({
  required String arn,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/untagResource/${Uri.encodeComponent(arn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}