cognito_identity library

Classes

AwsClientCredentials
AWS credentials.
CognitoIdentity
Amazon Cognito Federated Identities is a web service that delivers scoped temporary credentials to mobile devices and other untrusted environments. It uniquely identifies a device and supplies the user with a consistent identity over the lifetime of an application.