deleteIdentityPool method

Future<void> deleteIdentityPool({
  1. required String identityPoolId,
})

Deletes an identity pool. Once a pool is deleted, users will not be able to authenticate with the pool.

You must use Amazon Web Services developer credentials to call this operation.

May throw InternalErrorException. May throw InvalidParameterException. May throw NotAuthorizedException. May throw ResourceNotFoundException. May throw TooManyRequestsException.

Parameter identityPoolId : An identity pool ID in the format REGION:GUID.

Implementation

Future<void> deleteIdentityPool({
  required String identityPoolId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSCognitoIdentityService.DeleteIdentityPool'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'IdentityPoolId': identityPoolId,
    },
  );
}