getPrincipalTagAttributeMap method

Future<GetPrincipalTagAttributeMapResponse> getPrincipalTagAttributeMap({
  1. required String identityPoolId,
  2. required String identityProviderName,
})

Use GetPrincipalTagAttributeMap to list all mappings between PrincipalTags and user attributes.

May throw InternalErrorException. May throw InvalidParameterException. May throw NotAuthorizedException. May throw ResourceNotFoundException. May throw TooManyRequestsException.

Parameter identityPoolId : You can use this operation to get the ID of the Identity Pool you setup attribute mappings for.

Parameter identityProviderName : You can use this operation to get the provider name.

Implementation

Future<GetPrincipalTagAttributeMapResponse> getPrincipalTagAttributeMap({
  required String identityPoolId,
  required String identityProviderName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSCognitoIdentityService.GetPrincipalTagAttributeMap'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'IdentityPoolId': identityPoolId,
      'IdentityProviderName': identityProviderName,
    },
  );

  return GetPrincipalTagAttributeMapResponse.fromJson(jsonResponse.body);
}