Comprehend class

Amazon Comprehend is an Amazon Web Services service for gaining insight into the content of documents. Use these actions to determine the topics contained in your documents, the topics they discuss, the predominant sentiment expressed in them, the predominant language used, and more.

Constructors

Comprehend({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchDetectDominantLanguage({required List<String> textList}) Future<BatchDetectDominantLanguageResponse>
Determines the dominant language of the input text for a batch of documents. For a list of languages that Amazon Comprehend can detect, see Amazon Comprehend Supported Languages.
batchDetectEntities({required LanguageCode languageCode, required List<String> textList}) Future<BatchDetectEntitiesResponse>
Inspects the text of a batch of documents for named entities and returns information about them. For more information about named entities, see Entities in the Comprehend Developer Guide.
batchDetectKeyPhrases({required LanguageCode languageCode, required List<String> textList}) Future<BatchDetectKeyPhrasesResponse>
Detects the key noun phrases found in a batch of documents.
batchDetectSentiment({required LanguageCode languageCode, required List<String> textList}) Future<BatchDetectSentimentResponse>
Inspects a batch of documents and returns an inference of the prevailing sentiment, POSITIVE, NEUTRAL, MIXED, or NEGATIVE, in each one.
batchDetectSyntax({required SyntaxLanguageCode languageCode, required List<String> textList}) Future<BatchDetectSyntaxResponse>
Inspects the text of a batch of documents for the syntax and part of speech of the words in the document and returns information about them. For more information, see Syntax in the Comprehend Developer Guide.
batchDetectTargetedSentiment({required LanguageCode languageCode, required List<String> textList}) Future<BatchDetectTargetedSentimentResponse>
Inspects a batch of documents and returns a sentiment analysis for each entity identified in the documents.
classifyDocument({required String endpointArn, Uint8List? bytes, DocumentReaderConfig? documentReaderConfig, String? text}) Future<ClassifyDocumentResponse>
Creates a classification request to analyze a single document in real-time. ClassifyDocument supports the following model types:
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
containsPiiEntities({required LanguageCode languageCode, required String text}) Future<ContainsPiiEntitiesResponse>
Analyzes input text for the presence of personally identifiable information (PII) and returns the labels of identified PII entity types such as name, address, bank account number, or phone number.
createDataset({required String datasetName, required String flywheelArn, required DatasetInputDataConfig inputDataConfig, String? clientRequestToken, DatasetType? datasetType, String? description, List<Tag>? tags}) Future<CreateDatasetResponse>
Creates a dataset to upload training or test data for a model associated with a flywheel. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
createDocumentClassifier({required String dataAccessRoleArn, required String documentClassifierName, required DocumentClassifierInputDataConfig inputDataConfig, required LanguageCode languageCode, String? clientRequestToken, DocumentClassifierMode? mode, String? modelKmsKeyId, String? modelPolicy, DocumentClassifierOutputDataConfig? outputDataConfig, List<Tag>? tags, String? versionName, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<CreateDocumentClassifierResponse>
Creates a new document classifier that you can use to categorize documents. To create a classifier, you provide a set of training documents that are labeled with the categories that you want to use. For more information, see Training classifier models in the Comprehend Developer Guide.
createEndpoint({required int desiredInferenceUnits, required String endpointName, String? clientRequestToken, String? dataAccessRoleArn, String? flywheelArn, String? modelArn, List<Tag>? tags}) Future<CreateEndpointResponse>
Creates a model-specific endpoint for synchronous inference for a previously trained custom model For information about endpoints, see Managing endpoints.
createEntityRecognizer({required String dataAccessRoleArn, required EntityRecognizerInputDataConfig inputDataConfig, required LanguageCode languageCode, required String recognizerName, String? clientRequestToken, String? modelKmsKeyId, String? modelPolicy, List<Tag>? tags, String? versionName, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<CreateEntityRecognizerResponse>
Creates an entity recognizer using submitted files. After your CreateEntityRecognizer request is submitted, you can check job status using the DescribeEntityRecognizer API.
createFlywheel({required String dataAccessRoleArn, required String dataLakeS3Uri, required String flywheelName, String? activeModelArn, String? clientRequestToken, DataSecurityConfig? dataSecurityConfig, ModelType? modelType, List<Tag>? tags, TaskConfig? taskConfig}) Future<CreateFlywheelResponse>
A flywheel is an Amazon Web Services resource that orchestrates the ongoing training of a model for custom classification or custom entity recognition. You can create a flywheel to start with an existing trained model, or Comprehend can create and train a new model.
deleteDocumentClassifier({required String documentClassifierArn}) Future<void>
Deletes a previously created document classifier
deleteEndpoint({required String endpointArn}) Future<void>
Deletes a model-specific endpoint for a previously-trained custom model. All endpoints must be deleted in order for the model to be deleted. For information about endpoints, see Managing endpoints.
deleteEntityRecognizer({required String entityRecognizerArn}) Future<void>
Deletes an entity recognizer.
deleteFlywheel({required String flywheelArn}) Future<void>
Deletes a flywheel. When you delete the flywheel, Amazon Comprehend does not delete the data lake or the model associated with the flywheel.
deleteResourcePolicy({required String resourceArn, String? policyRevisionId}) Future<void>
Deletes a resource-based policy that is attached to a custom model.
describeDataset({required String datasetArn}) Future<DescribeDatasetResponse>
Returns information about the dataset that you specify. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
describeDocumentClassificationJob({required String jobId}) Future<DescribeDocumentClassificationJobResponse>
Gets the properties associated with a document classification job. Use this operation to get the status of a classification job.
describeDocumentClassifier({required String documentClassifierArn}) Future<DescribeDocumentClassifierResponse>
Gets the properties associated with a document classifier.
describeDominantLanguageDetectionJob({required String jobId}) Future<DescribeDominantLanguageDetectionJobResponse>
Gets the properties associated with a dominant language detection job. Use this operation to get the status of a detection job.
describeEndpoint({required String endpointArn}) Future<DescribeEndpointResponse>
Gets the properties associated with a specific endpoint. Use this operation to get the status of an endpoint. For information about endpoints, see Managing endpoints.
describeEntitiesDetectionJob({required String jobId}) Future<DescribeEntitiesDetectionJobResponse>
Gets the properties associated with an entities detection job. Use this operation to get the status of a detection job.
describeEntityRecognizer({required String entityRecognizerArn}) Future<DescribeEntityRecognizerResponse>
Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.
describeEventsDetectionJob({required String jobId}) Future<DescribeEventsDetectionJobResponse>
Gets the status and details of an events detection job.
describeFlywheel({required String flywheelArn}) Future<DescribeFlywheelResponse>
Provides configuration information about the flywheel. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
describeFlywheelIteration({required String flywheelArn, required String flywheelIterationId}) Future<DescribeFlywheelIterationResponse>
Retrieve the configuration properties of a flywheel iteration. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
describeKeyPhrasesDetectionJob({required String jobId}) Future<DescribeKeyPhrasesDetectionJobResponse>
Gets the properties associated with a key phrases detection job. Use this operation to get the status of a detection job.
describePiiEntitiesDetectionJob({required String jobId}) Future<DescribePiiEntitiesDetectionJobResponse>
Gets the properties associated with a PII entities detection job. For example, you can use this operation to get the job status.
describeResourcePolicy({required String resourceArn}) Future<DescribeResourcePolicyResponse>
Gets the details of a resource-based policy that is attached to a custom model, including the JSON body of the policy.
describeSentimentDetectionJob({required String jobId}) Future<DescribeSentimentDetectionJobResponse>
Gets the properties associated with a sentiment detection job. Use this operation to get the status of a detection job.
describeTargetedSentimentDetectionJob({required String jobId}) Future<DescribeTargetedSentimentDetectionJobResponse>
Gets the properties associated with a targeted sentiment detection job. Use this operation to get the status of the job.
describeTopicsDetectionJob({required String jobId}) Future<DescribeTopicsDetectionJobResponse>
Gets the properties associated with a topic detection job. Use this operation to get the status of a detection job.
detectDominantLanguage({required String text}) Future<DetectDominantLanguageResponse>
Determines the dominant language of the input text. For a list of languages that Amazon Comprehend can detect, see Amazon Comprehend Supported Languages.
detectEntities({Uint8List? bytes, DocumentReaderConfig? documentReaderConfig, String? endpointArn, LanguageCode? languageCode, String? text}) Future<DetectEntitiesResponse>
Detects named entities in input text when you use the pre-trained model. Detects custom entities if you have a custom entity recognition model.
detectKeyPhrases({required LanguageCode languageCode, required String text}) Future<DetectKeyPhrasesResponse>
Detects the key noun phrases found in the text.
detectPiiEntities({required LanguageCode languageCode, required String text}) Future<DetectPiiEntitiesResponse>
Inspects the input text for entities that contain personally identifiable information (PII) and returns information about them.
detectSentiment({required LanguageCode languageCode, required String text}) Future<DetectSentimentResponse>
Inspects text and returns an inference of the prevailing sentiment (POSITIVE, NEUTRAL, MIXED, or NEGATIVE).
detectSyntax({required SyntaxLanguageCode languageCode, required String text}) Future<DetectSyntaxResponse>
Inspects text for syntax and the part of speech of words in the document. For more information, see Syntax in the Comprehend Developer Guide.
detectTargetedSentiment({required LanguageCode languageCode, required String text}) Future<DetectTargetedSentimentResponse>
Inspects the input text and returns a sentiment analysis for each entity identified in the text.
detectToxicContent({required LanguageCode languageCode, required List<TextSegment> textSegments}) Future<DetectToxicContentResponse>
Performs toxicity analysis on the list of text strings that you provide as input. The API response contains a results list that matches the size of the input list. For more information about toxicity detection, see Toxicity detection in the Amazon Comprehend Developer Guide.
importModel({required String sourceModelArn, String? dataAccessRoleArn, String? modelKmsKeyId, String? modelName, List<Tag>? tags, String? versionName}) Future<ImportModelResponse>
Creates a new custom model that replicates a source custom model that you import. The source model can be in your Amazon Web Services account or another one.
listDatasets({DatasetFilter? filter, String? flywheelArn, int? maxResults, String? nextToken}) Future<ListDatasetsResponse>
List the datasets that you have configured in this Region. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
listDocumentClassificationJobs({DocumentClassificationJobFilter? filter, int? maxResults, String? nextToken}) Future<ListDocumentClassificationJobsResponse>
Gets a list of the documentation classification jobs that you have submitted.
listDocumentClassifiers({DocumentClassifierFilter? filter, int? maxResults, String? nextToken}) Future<ListDocumentClassifiersResponse>
Gets a list of the document classifiers that you have created.
listDocumentClassifierSummaries({int? maxResults, String? nextToken}) Future<ListDocumentClassifierSummariesResponse>
Gets a list of summaries of the document classifiers that you have created
listDominantLanguageDetectionJobs({DominantLanguageDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListDominantLanguageDetectionJobsResponse>
Gets a list of the dominant language detection jobs that you have submitted.
listEndpoints({EndpointFilter? filter, int? maxResults, String? nextToken}) Future<ListEndpointsResponse>
Gets a list of all existing endpoints that you've created. For information about endpoints, see Managing endpoints.
listEntitiesDetectionJobs({EntitiesDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListEntitiesDetectionJobsResponse>
Gets a list of the entity detection jobs that you have submitted.
listEntityRecognizers({EntityRecognizerFilter? filter, int? maxResults, String? nextToken}) Future<ListEntityRecognizersResponse>
Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training. Allows you to filter the list of recognizers based on criteria such as status and submission time. This call returns up to 500 entity recognizers in the list, with a default number of 100 recognizers in the list.
listEntityRecognizerSummaries({int? maxResults, String? nextToken}) Future<ListEntityRecognizerSummariesResponse>
Gets a list of summaries for the entity recognizers that you have created.
listEventsDetectionJobs({EventsDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListEventsDetectionJobsResponse>
Gets a list of the events detection jobs that you have submitted.
listFlywheelIterationHistory({required String flywheelArn, FlywheelIterationFilter? filter, int? maxResults, String? nextToken}) Future<ListFlywheelIterationHistoryResponse>
Information about the history of a flywheel iteration. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
listFlywheels({FlywheelFilter? filter, int? maxResults, String? nextToken}) Future<ListFlywheelsResponse>
Gets a list of the flywheels that you have created.
listKeyPhrasesDetectionJobs({KeyPhrasesDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListKeyPhrasesDetectionJobsResponse>
Get a list of key phrase detection jobs that you have submitted.
listPiiEntitiesDetectionJobs({PiiEntitiesDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListPiiEntitiesDetectionJobsResponse>
Gets a list of the PII entity detection jobs that you have submitted.
listSentimentDetectionJobs({SentimentDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListSentimentDetectionJobsResponse>
Gets a list of sentiment detection jobs that you have submitted.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists all tags associated with a given Amazon Comprehend resource.
listTargetedSentimentDetectionJobs({TargetedSentimentDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListTargetedSentimentDetectionJobsResponse>
Gets a list of targeted sentiment detection jobs that you have submitted.
listTopicsDetectionJobs({TopicsDetectionJobFilter? filter, int? maxResults, String? nextToken}) Future<ListTopicsDetectionJobsResponse>
Gets a list of the topic detection jobs that you have submitted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String resourceArn, required String resourcePolicy, String? policyRevisionId}) Future<PutResourcePolicyResponse>
Attaches a resource-based policy to a custom model. You can use this policy to authorize an entity in another Amazon Web Services account to import the custom model, which replicates it in Amazon Comprehend in their account.
startDocumentClassificationJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? documentClassifierArn, String? flywheelArn, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartDocumentClassificationJobResponse>
Starts an asynchronous document classification job using a custom classification model. Use the DescribeDocumentClassificationJob operation to track the progress of the job.
startDominantLanguageDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartDominantLanguageDetectionJobResponse>
Starts an asynchronous dominant language detection job for a collection of documents. Use the operation to track the status of a job.
startEntitiesDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? entityRecognizerArn, String? flywheelArn, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartEntitiesDetectionJobResponse>
Starts an asynchronous entity detection job for a collection of documents. Use the operation to track the status of a job.
startEventsDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required OutputDataConfig outputDataConfig, required List<String> targetEventTypes, String? clientRequestToken, String? jobName, List<Tag>? tags}) Future<StartEventsDetectionJobResponse>
Starts an asynchronous event detection job for a collection of documents.
startFlywheelIteration({required String flywheelArn, String? clientRequestToken}) Future<StartFlywheelIterationResponse>
Start the flywheel iteration.This operation uses any new datasets to train a new model version. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
startKeyPhrasesDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartKeyPhrasesDetectionJobResponse>
Starts an asynchronous key phrase detection job for a collection of documents. Use the operation to track the status of a job.
startPiiEntitiesDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required PiiEntitiesDetectionMode mode, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, RedactionConfig? redactionConfig, List<Tag>? tags}) Future<StartPiiEntitiesDetectionJobResponse>
Starts an asynchronous PII entity detection job for a collection of documents.
startSentimentDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartSentimentDetectionJobResponse>
Starts an asynchronous sentiment detection job for a collection of documents. Use the operation to track the status of a job.
startTargetedSentimentDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required LanguageCode languageCode, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartTargetedSentimentDetectionJobResponse>
Starts an asynchronous targeted sentiment detection job for a collection of documents. Use the DescribeTargetedSentimentDetectionJob operation to track the status of a job.
startTopicsDetectionJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, String? clientRequestToken, String? jobName, int? numberOfTopics, List<Tag>? tags, String? volumeKmsKeyId, VpcConfig? vpcConfig}) Future<StartTopicsDetectionJobResponse>
Starts an asynchronous topic detection job. Use the DescribeTopicDetectionJob operation to track the status of a job.
stopDominantLanguageDetectionJob({required String jobId}) Future<StopDominantLanguageDetectionJobResponse>
Stops a dominant language detection job in progress.
stopEntitiesDetectionJob({required String jobId}) Future<StopEntitiesDetectionJobResponse>
Stops an entities detection job in progress.
stopEventsDetectionJob({required String jobId}) Future<StopEventsDetectionJobResponse>
Stops an events detection job in progress.
stopKeyPhrasesDetectionJob({required String jobId}) Future<StopKeyPhrasesDetectionJobResponse>
Stops a key phrases detection job in progress.
stopPiiEntitiesDetectionJob({required String jobId}) Future<StopPiiEntitiesDetectionJobResponse>
Stops a PII entities detection job in progress.
stopSentimentDetectionJob({required String jobId}) Future<StopSentimentDetectionJobResponse>
Stops a sentiment detection job in progress.
stopTargetedSentimentDetectionJob({required String jobId}) Future<StopTargetedSentimentDetectionJobResponse>
Stops a targeted sentiment detection job in progress.
stopTrainingDocumentClassifier({required String documentClassifierArn}) Future<void>
Stops a document classifier training job while in progress.
stopTrainingEntityRecognizer({required String entityRecognizerArn}) Future<void>
Stops an entity recognizer training job while in progress.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Associates a specific tag with an Amazon Comprehend resource. A tag is a key-value pair that adds as a metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a specific tag associated with an Amazon Comprehend resource.
updateEndpoint({required String endpointArn, String? desiredDataAccessRoleArn, int? desiredInferenceUnits, String? desiredModelArn, String? flywheelArn}) Future<UpdateEndpointResponse>
Updates information about the specified endpoint. For information about endpoints, see Managing endpoints.
updateFlywheel({required String flywheelArn, String? activeModelArn, String? dataAccessRoleArn, UpdateDataSecurityConfig? dataSecurityConfig}) Future<UpdateFlywheelResponse>
Update the configuration information for an existing flywheel.

Operators

operator ==(Object other) bool
The equality operator.
inherited