batchDetectKeyPhrases method

Future<BatchDetectKeyPhrasesResponse> batchDetectKeyPhrases({
  1. required LanguageCode languageCode,
  2. required List<String> textList,
})

Detects the key noun phrases found in a batch of documents.

May throw BatchSizeLimitExceededException. May throw InternalServerException. May throw InvalidRequestException. May throw TextSizeLimitExceededException. May throw UnsupportedLanguageException.

Parameter languageCode : The language of the input documents. You can specify any of the primary languages supported by Amazon Comprehend. All documents must be in the same language.

Parameter textList : A list containing the UTF-8 encoded text of the input documents. The list can contain a maximum of 25 documents. The maximum size of each document is 5 KB.

Implementation

Future<BatchDetectKeyPhrasesResponse> batchDetectKeyPhrases({
  required LanguageCode languageCode,
  required List<String> textList,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Comprehend_20171127.BatchDetectKeyPhrases'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LanguageCode': languageCode.value,
      'TextList': textList,
    },
  );

  return BatchDetectKeyPhrasesResponse.fromJson(jsonResponse.body);
}