classifyDocument method
Creates a classification request to analyze a single document in
real-time. ClassifyDocument supports the following model
types:
- Custom classifier - a custom model that you have created and trained. For input, you can provide plain text, a single-page document (PDF, Word, or image), or Amazon Textract API output. For more information, see Custom classification in the Amazon Comprehend Developer Guide.
-
Prompt safety classifier - Amazon Comprehend provides a pre-trained model
for classifying input prompts for generative AI applications. For input,
you provide English plain text input. For prompt safety classification,
the response includes only the
Classesfield. For more information about prompt safety classifiers, see Prompt safety classification in the Amazon Comprehend Developer Guide.
Errors field that
describes the errors.
If the system detects a document-level error in your input document, the
API returns an InvalidRequestException error response. For
details about this exception, see
Errors in semi-structured documents in the Comprehend Developer Guide.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceUnavailableException.
May throw TextSizeLimitExceededException.
Parameter endpointArn :
The Amazon Resource Number (ARN) of the endpoint.
For prompt safety classification, Amazon Comprehend provides the endpoint ARN. For more information about prompt safety classifiers, see Prompt safety classification in the Amazon Comprehend Developer Guide
For custom classification, you create an endpoint for your custom model. For more information, see Using Amazon Comprehend endpoints.
Parameter bytes :
Use the Bytes parameter to input a text, PDF, Word or image
file.
When you classify a document using a custom model, you can also use the
Bytes parameter to input an Amazon Textract
DetectDocumentText or AnalyzeDocument output
file.
To classify a document using the prompt safety classifier, use the
Text parameter for input.
Provide the input document as a sequence of base64-encoded bytes. If your code uses an Amazon Web Services SDK to classify documents, the SDK may encode the document file bytes for you.
The maximum length of this field depends on the input document type. For details, see Inputs for real-time custom analysis in the Comprehend Developer Guide.
If you use the Bytes parameter, do not use the
Text parameter.
Parameter documentReaderConfig :
Provides configuration parameters to override the default actions for
extracting text from PDF documents and image files.
Parameter text :
The document text to be analyzed. If you enter text using this parameter,
do not use the Bytes parameter.
Implementation
Future<ClassifyDocumentResponse> classifyDocument({
required String endpointArn,
Uint8List? bytes,
DocumentReaderConfig? documentReaderConfig,
String? text,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.ClassifyDocument'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EndpointArn': endpointArn,
if (bytes != null) 'Bytes': base64Encode(bytes),
if (documentReaderConfig != null)
'DocumentReaderConfig': documentReaderConfig,
if (text != null) 'Text': text,
},
);
return ClassifyDocumentResponse.fromJson(jsonResponse.body);
}