createDocumentClassifier method
- required String dataAccessRoleArn,
- required String documentClassifierName,
- required DocumentClassifierInputDataConfig inputDataConfig,
- required LanguageCode languageCode,
- String? clientRequestToken,
- DocumentClassifierMode? mode,
- String? modelKmsKeyId,
- String? modelPolicy,
- DocumentClassifierOutputDataConfig? outputDataConfig,
- List<
Tag> ? tags, - String? versionName,
- String? volumeKmsKeyId,
- VpcConfig? vpcConfig,
Creates a new document classifier that you can use to categorize documents. To create a classifier, you provide a set of training documents that are labeled with the categories that you want to use. For more information, see Training classifier models in the Comprehend Developer Guide.
May throw InternalServerException.
May throw InvalidRequestException.
May throw KmsKeyValidationException.
May throw ResourceInUseException.
May throw ResourceLimitExceededException.
May throw TooManyRequestsException.
May throw TooManyTagsException.
May throw UnsupportedLanguageException.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of the IAM role that grants Amazon
Comprehend read access to your input data.
Parameter documentClassifierName :
The name of the document classifier.
Parameter inputDataConfig :
Specifies the format and location of the input data for the job.
Parameter languageCode :
The language of the input documents. You can specify any of the languages
supported by Amazon Comprehend. All documents must be in the same
language.
Parameter clientRequestToken :
A unique identifier for the request. If you don't set the client request
token, Amazon Comprehend generates one.
Parameter mode :
Indicates the mode in which the classifier will be trained. The classifier
can be trained in multi-class (single-label) mode or multi-label mode.
Multi-class mode identifies a single class label for each document and
multi-label mode identifies one or more class labels for each document.
Multiple labels for an individual document are separated by a delimiter.
The default delimiter between labels is a pipe (|).
Parameter modelKmsKeyId :
ID for the KMS key that Amazon Comprehend uses to encrypt trained custom
models. The ModelKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter modelPolicy :
The resource-based policy to attach to your custom document classifier
model. You can use this policy to allow another Amazon Web Services
account to import your custom model.
Provide your policy as a JSON body that you enter as a UTF-8 encoded string without line breaks. To provide valid JSON, enclose the attribute names and values in double quotes. If the JSON body is also enclosed in double quotes, then you must escape the double quotes that are inside the policy:
"{"attribute": "value", "attribute": ["value"]}"
To avoid escaping quotes, you can use single quotes to enclose the policy and double quotes to enclose the JSON names and values:
'{"attribute": "value", "attribute": ["value"]}'
Parameter outputDataConfig :
Specifies the location for the output files from a custom classifier job.
This parameter is required for a request that creates a native document
model.
Parameter tags :
Tags to associate with the document classifier. A tag is a key-value pair
that adds as a metadata to a resource used by Amazon Comprehend. For
example, a tag with "Sales" as the key might be added to a resource to
indicate its use by the sales department.
Parameter versionName :
The version name given to the newly created classifier. Version names can
have a maximum of 256 characters. Alphanumeric characters, hyphens (-) and
underscores (_) are allowed. The version name must be unique among all
models with the same classifier name in the Amazon Web Services
account/Amazon Web Services Region.
Parameter volumeKmsKeyId :
ID for the Amazon Web Services Key Management Service (KMS) key that
Amazon Comprehend uses to encrypt data on the storage volume attached to
the ML compute instance(s) that process the analysis job. The
VolumeKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter vpcConfig :
Configuration parameters for an optional private Virtual Private Cloud
(VPC) containing the resources you are using for your custom classifier.
For more information, see Amazon
VPC.
Implementation
Future<CreateDocumentClassifierResponse> createDocumentClassifier({
required String dataAccessRoleArn,
required String documentClassifierName,
required DocumentClassifierInputDataConfig inputDataConfig,
required LanguageCode languageCode,
String? clientRequestToken,
DocumentClassifierMode? mode,
String? modelKmsKeyId,
String? modelPolicy,
DocumentClassifierOutputDataConfig? outputDataConfig,
List<Tag>? tags,
String? versionName,
String? volumeKmsKeyId,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.CreateDocumentClassifier'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DataAccessRoleArn': dataAccessRoleArn,
'DocumentClassifierName': documentClassifierName,
'InputDataConfig': inputDataConfig,
'LanguageCode': languageCode.value,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (mode != null) 'Mode': mode.value,
if (modelKmsKeyId != null) 'ModelKmsKeyId': modelKmsKeyId,
if (modelPolicy != null) 'ModelPolicy': modelPolicy,
if (outputDataConfig != null) 'OutputDataConfig': outputDataConfig,
if (tags != null) 'Tags': tags,
if (versionName != null) 'VersionName': versionName,
if (volumeKmsKeyId != null) 'VolumeKmsKeyId': volumeKmsKeyId,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return CreateDocumentClassifierResponse.fromJson(jsonResponse.body);
}