createEntityRecognizer method
- required String dataAccessRoleArn,
- required EntityRecognizerInputDataConfig inputDataConfig,
- required LanguageCode languageCode,
- required String recognizerName,
- String? clientRequestToken,
- String? modelKmsKeyId,
- String? modelPolicy,
- List<
Tag> ? tags, - String? versionName,
- String? volumeKmsKeyId,
- VpcConfig? vpcConfig,
Creates an entity recognizer using submitted files. After your
CreateEntityRecognizer request is submitted, you can check
job status using the DescribeEntityRecognizer API.
May throw InternalServerException.
May throw InvalidRequestException.
May throw KmsKeyValidationException.
May throw ResourceInUseException.
May throw ResourceLimitExceededException.
May throw TooManyRequestsException.
May throw TooManyTagsException.
May throw UnsupportedLanguageException.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of the IAM role that grants Amazon
Comprehend read access to your input data.
Parameter inputDataConfig :
Specifies the format and location of the input data. The S3 bucket
containing the input data must be located in the same Region as the entity
recognizer being created.
Parameter languageCode :
You can specify any of the following languages: English ("en"), Spanish
("es"), French ("fr"), Italian ("it"), German ("de"), or Portuguese
("pt"). If you plan to use this entity recognizer with PDF, Word, or image
input files, you must specify English as the language. All training
documents must be in the same language.
Parameter recognizerName :
The name given to the newly created recognizer. Recognizer names can be a
maximum of 256 characters. Alphanumeric characters, hyphens (-) and
underscores (_) are allowed. The name must be unique in the
account/Region.
Parameter clientRequestToken :
A unique identifier for the request. If you don't set the client request
token, Amazon Comprehend generates one.
Parameter modelKmsKeyId :
ID for the KMS key that Amazon Comprehend uses to encrypt trained custom
models. The ModelKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter modelPolicy :
The JSON resource-based policy to attach to your custom entity recognizer
model. You can use this policy to allow another Amazon Web Services
account to import your custom model.
Provide your JSON as a UTF-8 encoded string without line breaks. To provide valid JSON for your policy, enclose the attribute names and values in double quotes. If the JSON body is also enclosed in double quotes, then you must escape the double quotes that are inside the policy:
"{"attribute": "value", "attribute": ["value"]}"
To avoid escaping quotes, you can use single quotes to enclose the policy and double quotes to enclose the JSON names and values:
'{"attribute": "value", "attribute": ["value"]}'
Parameter tags :
Tags to associate with the entity recognizer. A tag is a key-value pair
that adds as a metadata to a resource used by Amazon Comprehend. For
example, a tag with "Sales" as the key might be added to a resource to
indicate its use by the sales department.
Parameter versionName :
The version name given to the newly created recognizer. Version names can
be a maximum of 256 characters. Alphanumeric characters, hyphens (-) and
underscores (_) are allowed. The version name must be unique among all
models with the same recognizer name in the account/Region.
Parameter volumeKmsKeyId :
ID for the Amazon Web Services Key Management Service (KMS) key that
Amazon Comprehend uses to encrypt data on the storage volume attached to
the ML compute instance(s) that process the analysis job. The
VolumeKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter vpcConfig :
Configuration parameters for an optional private Virtual Private Cloud
(VPC) containing the resources you are using for your custom entity
recognizer. For more information, see Amazon
VPC.
Implementation
Future<CreateEntityRecognizerResponse> createEntityRecognizer({
required String dataAccessRoleArn,
required EntityRecognizerInputDataConfig inputDataConfig,
required LanguageCode languageCode,
required String recognizerName,
String? clientRequestToken,
String? modelKmsKeyId,
String? modelPolicy,
List<Tag>? tags,
String? versionName,
String? volumeKmsKeyId,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.CreateEntityRecognizer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DataAccessRoleArn': dataAccessRoleArn,
'InputDataConfig': inputDataConfig,
'LanguageCode': languageCode.value,
'RecognizerName': recognizerName,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (modelKmsKeyId != null) 'ModelKmsKeyId': modelKmsKeyId,
if (modelPolicy != null) 'ModelPolicy': modelPolicy,
if (tags != null) 'Tags': tags,
if (versionName != null) 'VersionName': versionName,
if (volumeKmsKeyId != null) 'VolumeKmsKeyId': volumeKmsKeyId,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return CreateEntityRecognizerResponse.fromJson(jsonResponse.body);
}