deleteFlywheel method

Future<void> deleteFlywheel({
  1. required String flywheelArn,
})

Deletes a flywheel. When you delete the flywheel, Amazon Comprehend does not delete the data lake or the model associated with the flywheel.

For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.

May throw InternalServerException. May throw InvalidRequestException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw TooManyRequestsException.

Parameter flywheelArn : The Amazon Resource Number (ARN) of the flywheel to delete.

Implementation

Future<void> deleteFlywheel({
  required String flywheelArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Comprehend_20171127.DeleteFlywheel'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'FlywheelArn': flywheelArn,
    },
  );
}