describeEntitiesDetectionJob method
Future<DescribeEntitiesDetectionJobResponse>
describeEntitiesDetectionJob({
- required String jobId,
Gets the properties associated with an entities detection job. Use this operation to get the status of a detection job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw JobNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier that Amazon Comprehend generated for the job. The
StartEntitiesDetectionJob operation returns this identifier
in its response.
Implementation
Future<DescribeEntitiesDetectionJobResponse> describeEntitiesDetectionJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.DescribeEntitiesDetectionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribeEntitiesDetectionJobResponse.fromJson(jsonResponse.body);
}