describeTopicsDetectionJob method
Gets the properties associated with a topic detection job. Use this operation to get the status of a detection job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw JobNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier assigned by the user to the detection job.
Implementation
Future<DescribeTopicsDetectionJobResponse> describeTopicsDetectionJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.DescribeTopicsDetectionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribeTopicsDetectionJobResponse.fromJson(jsonResponse.body);
}