detectEntities method
Detects named entities in input text when you use the pre-trained model. Detects custom entities if you have a custom entity recognition model.
When detecting named entities using the pre-trained model, use plain text as the input. For more information about named entities, see Entities in the Comprehend Developer Guide.
When you use a custom entity recognition model, you can input plain text or you can upload a single-page input document (text, PDF, Word, or image).
If the system detects errors while processing a page in the input
document, the API response includes an entry in Errors for
each error.
If the system detects a document-level error in your input document, the
API returns an InvalidRequestException error response. For
details about this exception, see
Errors in semi-structured documents in the Comprehend Developer Guide.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceUnavailableException.
May throw TextSizeLimitExceededException.
May throw UnsupportedLanguageException.
Parameter bytes :
This field applies only when you use a custom entity recognition model
that was trained with PDF annotations. For other cases, enter your text
input in the Text field.
Use the Bytes parameter to input a text, PDF, Word or image
file. Using a plain-text file in the Bytes parameter is
equivelent to using the Text parameter (the
Entities field in the response is identical).
You can also use the Bytes parameter to input an Amazon
Textract DetectDocumentText or AnalyzeDocument
output file.
Provide the input document as a sequence of base64-encoded bytes. If your code uses an Amazon Web Services SDK to detect entities, the SDK may encode the document file bytes for you.
The maximum length of this field depends on the input document type. For details, see Inputs for real-time custom analysis in the Comprehend Developer Guide.
If you use the Bytes parameter, do not use the
Text parameter.
Parameter documentReaderConfig :
Provides configuration parameters to override the default actions for
extracting text from PDF documents and image files.
Parameter endpointArn :
The Amazon Resource Name of an endpoint that is associated with a custom
entity recognition model. Provide an endpoint if you want to detect
entities by using your own custom model instead of the default model that
is used by Amazon Comprehend.
If you specify an endpoint, Amazon Comprehend uses the language of your custom model, and it ignores any language code that you provide in your request.
For information about endpoints, see Managing endpoints.
Parameter languageCode :
The language of the input documents. You can specify any of the primary
languages supported by Amazon Comprehend. If your request includes the
endpoint for a custom entity recognition model, Amazon Comprehend uses the
language of your custom model, and it ignores any language code that you
specify here.
All input documents must be in the same language.
Parameter text :
A UTF-8 text string. The maximum string size is 100 KB. If you enter text
using this parameter, do not use the Bytes parameter.
Implementation
Future<DetectEntitiesResponse> detectEntities({
Uint8List? bytes,
DocumentReaderConfig? documentReaderConfig,
String? endpointArn,
LanguageCode? languageCode,
String? text,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.DetectEntities'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (bytes != null) 'Bytes': base64Encode(bytes),
if (documentReaderConfig != null)
'DocumentReaderConfig': documentReaderConfig,
if (endpointArn != null) 'EndpointArn': endpointArn,
if (languageCode != null) 'LanguageCode': languageCode.value,
if (text != null) 'Text': text,
},
);
return DetectEntitiesResponse.fromJson(jsonResponse.body);
}