listFlywheels method
Gets a list of the flywheels that you have created.
May throw InternalServerException.
May throw InvalidFilterException.
May throw InvalidRequestException.
May throw TooManyRequestsException.
Parameter filter :
Filters the flywheels that are returned. You can filter flywheels on their
status, or the date and time that they were submitted. You can only set
one filter at a time.
Parameter maxResults :
Maximum number of results to return in a response. The default is 100.
Parameter nextToken :
Identifies the next page of results to return.
Implementation
Future<ListFlywheelsResponse> listFlywheels({
FlywheelFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.ListFlywheels'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListFlywheelsResponse.fromJson(jsonResponse.body);
}