startEntitiesDetectionJob method
- required String dataAccessRoleArn,
- required InputDataConfig inputDataConfig,
- required LanguageCode languageCode,
- required OutputDataConfig outputDataConfig,
- String? clientRequestToken,
- String? entityRecognizerArn,
- String? flywheelArn,
- String? jobName,
- List<
Tag> ? tags, - String? volumeKmsKeyId,
- VpcConfig? vpcConfig,
Starts an asynchronous entity detection job for a collection of documents. Use the operation to track the status of a job.
This API can be used for either standard entity detection or custom entity
recognition. In order to be used for custom entity recognition, the
optional EntityRecognizerArn must be used in order to provide
access to the recognizer being used to detect the custom entity.
May throw InternalServerException.
May throw InvalidRequestException.
May throw KmsKeyValidationException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw TooManyRequestsException.
May throw TooManyTagsException.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of the IAM role that grants Amazon
Comprehend read access to your input data. For more information, see Role-based
permissions.
Parameter inputDataConfig :
Specifies the format and location of the input data for the job.
Parameter languageCode :
The language of the input documents. All documents must be in the same
language. You can specify any of the languages supported by Amazon
Comprehend. If custom entities recognition is used, this parameter is
ignored and the language used for training the model is used instead.
Parameter outputDataConfig :
Specifies where to send the output files.
Parameter clientRequestToken :
A unique identifier for the request. If you don't set the client request
token, Amazon Comprehend generates one.
Parameter entityRecognizerArn :
The Amazon Resource Name (ARN) that identifies the specific entity
recognizer to be used by the StartEntitiesDetectionJob. This
ARN is optional and is only used for a custom entity recognition job.
Parameter flywheelArn :
The Amazon Resource Number (ARN) of the flywheel associated with the model
to use.
Parameter jobName :
The identifier of the job.
Parameter tags :
Tags to associate with the entities detection job. A tag is a key-value
pair that adds metadata to a resource used by Amazon Comprehend. For
example, a tag with "Sales" as the key might be added to a resource to
indicate its use by the sales department.
Parameter volumeKmsKeyId :
ID for the Amazon Web Services Key Management Service (KMS) key that
Amazon Comprehend uses to encrypt data on the storage volume attached to
the ML compute instance(s) that process the analysis job. The
VolumeKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter vpcConfig :
Configuration parameters for an optional private Virtual Private Cloud
(VPC) containing the resources you are using for your entity detection
job. For more information, see Amazon
VPC.
Implementation
Future<StartEntitiesDetectionJobResponse> startEntitiesDetectionJob({
required String dataAccessRoleArn,
required InputDataConfig inputDataConfig,
required LanguageCode languageCode,
required OutputDataConfig outputDataConfig,
String? clientRequestToken,
String? entityRecognizerArn,
String? flywheelArn,
String? jobName,
List<Tag>? tags,
String? volumeKmsKeyId,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.StartEntitiesDetectionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DataAccessRoleArn': dataAccessRoleArn,
'InputDataConfig': inputDataConfig,
'LanguageCode': languageCode.value,
'OutputDataConfig': outputDataConfig,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (entityRecognizerArn != null)
'EntityRecognizerArn': entityRecognizerArn,
if (flywheelArn != null) 'FlywheelArn': flywheelArn,
if (jobName != null) 'JobName': jobName,
if (tags != null) 'Tags': tags,
if (volumeKmsKeyId != null) 'VolumeKmsKeyId': volumeKmsKeyId,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return StartEntitiesDetectionJobResponse.fromJson(jsonResponse.body);
}