startTargetedSentimentDetectionJob method

Future<StartTargetedSentimentDetectionJobResponse> startTargetedSentimentDetectionJob({
  1. required String dataAccessRoleArn,
  2. required InputDataConfig inputDataConfig,
  3. required LanguageCode languageCode,
  4. required OutputDataConfig outputDataConfig,
  5. String? clientRequestToken,
  6. String? jobName,
  7. List<Tag>? tags,
  8. String? volumeKmsKeyId,
  9. VpcConfig? vpcConfig,
})

Starts an asynchronous targeted sentiment detection job for a collection of documents. Use the DescribeTargetedSentimentDetectionJob operation to track the status of a job.

May throw InternalServerException. May throw InvalidRequestException. May throw KmsKeyValidationException. May throw ResourceInUseException. May throw TooManyRequestsException. May throw TooManyTagsException.

Parameter dataAccessRoleArn : The Amazon Resource Name (ARN) of the IAM role that grants Amazon Comprehend read access to your input data. For more information, see Role-based permissions.

Parameter languageCode : The language of the input documents. Currently, English is the only supported language.

Parameter outputDataConfig : Specifies where to send the output files.

Parameter clientRequestToken : A unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one.

Parameter jobName : The identifier of the job.

Parameter tags : Tags to associate with the targeted sentiment detection job. A tag is a key-value pair that adds metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department.

Parameter volumeKmsKeyId : ID for the KMS key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:

  • KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"
  • Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"

Implementation

Future<StartTargetedSentimentDetectionJobResponse>
    startTargetedSentimentDetectionJob({
  required String dataAccessRoleArn,
  required InputDataConfig inputDataConfig,
  required LanguageCode languageCode,
  required OutputDataConfig outputDataConfig,
  String? clientRequestToken,
  String? jobName,
  List<Tag>? tags,
  String? volumeKmsKeyId,
  VpcConfig? vpcConfig,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Comprehend_20171127.StartTargetedSentimentDetectionJob'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DataAccessRoleArn': dataAccessRoleArn,
      'InputDataConfig': inputDataConfig,
      'LanguageCode': languageCode.value,
      'OutputDataConfig': outputDataConfig,
      'ClientRequestToken':
          clientRequestToken ?? _s.generateIdempotencyToken(),
      if (jobName != null) 'JobName': jobName,
      if (tags != null) 'Tags': tags,
      if (volumeKmsKeyId != null) 'VolumeKmsKeyId': volumeKmsKeyId,
      if (vpcConfig != null) 'VpcConfig': vpcConfig,
    },
  );

  return StartTargetedSentimentDetectionJobResponse.fromJson(
      jsonResponse.body);
}