describeEntitiesDetectionV2Job method
Future<DescribeEntitiesDetectionV2JobResponse>
describeEntitiesDetectionV2Job({
- required String jobId,
Gets the properties associated with a medical entities detection job. Use this operation to get the status of a detection job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier that Amazon Comprehend Medical generated for the job. The
StartEntitiesDetectionV2Job operation returns this identifier
in its response.
Implementation
Future<DescribeEntitiesDetectionV2JobResponse>
describeEntitiesDetectionV2Job({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'ComprehendMedical_20181030.DescribeEntitiesDetectionV2Job'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribeEntitiesDetectionV2JobResponse.fromJson(jsonResponse.body);
}