describeSNOMEDCTInferenceJob method
Future<DescribeSNOMEDCTInferenceJobResponse>
describeSNOMEDCTInferenceJob({
- required String jobId,
Gets the properties associated with an InferSNOMEDCT job. Use this operation to get the status of an inference job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier that Amazon Comprehend Medical generated for the job. The
StartSNOMEDCTInferenceJob operation returns this identifier in its
response.
Implementation
Future<DescribeSNOMEDCTInferenceJobResponse> describeSNOMEDCTInferenceJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ComprehendMedical_20181030.DescribeSNOMEDCTInferenceJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribeSNOMEDCTInferenceJobResponse.fromJson(jsonResponse.body);
}