exportEC2InstanceRecommendations method
Exports optimization recommendations for Amazon EC2 instances.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see Exporting Recommendations in the Compute Optimizer User Guide.
You can have only one Amazon EC2 instance export job in progress per Amazon Web Services Region.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw MissingAuthenticationToken.
May throw OptInRequiredException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter s3DestinationConfig :
An object to specify the destination Amazon Simple Storage Service (Amazon
S3) bucket name and key prefix for the export job.
You must create the destination Amazon S3 bucket for your recommendations export before you create the export job. Compute Optimizer does not create the S3 bucket for you. After you create the S3 bucket, ensure that it has the required permissions policy to allow Compute Optimizer to write the export file to it. If you plan to specify an object prefix when you create the export job, you must include the object prefix in the policy that you add to the S3 bucket. For more information, see Amazon S3 Bucket Policy for Compute Optimizer in the Compute Optimizer User Guide.
Parameter accountIds :
The IDs of the Amazon Web Services accounts for which to export instance
recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to export recommendations.
This parameter cannot be specified together with the include member accounts parameter. The parameters are mutually exclusive.
Recommendations for member accounts are not included in the export if this parameter, or the include member accounts parameter, is omitted.
You can specify multiple account IDs per request.
Parameter fieldsToExport :
The recommendations data to include in the export file. For more
information about the fields that can be exported, see Exported
files in the Compute Optimizer User Guide.
Parameter fileFormat :
The format of the export file.
The only export file format currently supported is Csv.
Parameter filters :
An array of objects to specify a filter that exports a more specific set
of instance recommendations.
Parameter includeMemberAccounts :
Indicates whether to include recommendations for resources in all member
accounts of the organization if your account is the management account of
an organization.
The member accounts must also be opted in to Compute Optimizer, and trusted access for Compute Optimizer must be enabled in the organization account. For more information, see Compute Optimizer and Amazon Web Services Organizations trusted access in the Compute Optimizer User Guide.
Recommendations for member accounts of the organization are not included in the export file if this parameter is omitted.
Recommendations for member accounts are not included in the export if this parameter, or the account IDs parameter, is omitted.
Parameter recommendationPreferences :
An object to specify the preferences for the Amazon EC2 instance
recommendations to export.
Implementation
Future<ExportEC2InstanceRecommendationsResponse>
exportEC2InstanceRecommendations({
required S3DestinationConfig s3DestinationConfig,
List<String>? accountIds,
List<ExportableInstanceField>? fieldsToExport,
FileFormat? fileFormat,
List<Filter>? filters,
bool? includeMemberAccounts,
RecommendationPreferences? recommendationPreferences,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ComputeOptimizerService.ExportEC2InstanceRecommendations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
's3DestinationConfig': s3DestinationConfig,
if (accountIds != null) 'accountIds': accountIds,
if (fieldsToExport != null)
'fieldsToExport': fieldsToExport.map((e) => e.value).toList(),
if (fileFormat != null) 'fileFormat': fileFormat.value,
if (filters != null) 'filters': filters,
if (includeMemberAccounts != null)
'includeMemberAccounts': includeMemberAccounts,
if (recommendationPreferences != null)
'recommendationPreferences': recommendationPreferences,
},
);
return ExportEC2InstanceRecommendationsResponse.fromJson(jsonResponse.body);
}