exportLambdaFunctionRecommendations method
Exports optimization recommendations for Lambda functions.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see Exporting Recommendations in the Compute Optimizer User Guide.
You can have only one Lambda function export job in progress per Amazon Web Services Region.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw MissingAuthenticationToken.
May throw OptInRequiredException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter accountIds :
The IDs of the Amazon Web Services accounts for which to export Lambda
function recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to export recommendations.
This parameter cannot be specified together with the include member accounts parameter. The parameters are mutually exclusive.
Recommendations for member accounts are not included in the export if this parameter, or the include member accounts parameter, is omitted.
You can specify multiple account IDs per request.
Parameter fieldsToExport :
The recommendations data to include in the export file. For more
information about the fields that can be exported, see Exported
files in the Compute Optimizer User Guide.
Parameter fileFormat :
The format of the export file.
The only export file format currently supported is Csv.
Parameter filters :
An array of objects to specify a filter that exports a more specific set
of Lambda function recommendations.
Parameter includeMemberAccounts :
Indicates whether to include recommendations for resources in all member
accounts of the organization if your account is the management account of
an organization.
The member accounts must also be opted in to Compute Optimizer, and trusted access for Compute Optimizer must be enabled in the organization account. For more information, see Compute Optimizer and Amazon Web Services Organizations trusted access in the Compute Optimizer User Guide.
Recommendations for member accounts of the organization are not included in the export file if this parameter is omitted.
This parameter cannot be specified together with the account IDs parameter. The parameters are mutually exclusive.
Recommendations for member accounts are not included in the export if this parameter, or the account IDs parameter, is omitted.
Implementation
Future<ExportLambdaFunctionRecommendationsResponse>
exportLambdaFunctionRecommendations({
required S3DestinationConfig s3DestinationConfig,
List<String>? accountIds,
List<ExportableLambdaFunctionField>? fieldsToExport,
FileFormat? fileFormat,
List<LambdaFunctionRecommendationFilter>? filters,
bool? includeMemberAccounts,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'ComputeOptimizerService.ExportLambdaFunctionRecommendations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
's3DestinationConfig': s3DestinationConfig,
if (accountIds != null) 'accountIds': accountIds,
if (fieldsToExport != null)
'fieldsToExport': fieldsToExport.map((e) => e.value).toList(),
if (fileFormat != null) 'fileFormat': fileFormat.value,
if (filters != null) 'filters': filters,
if (includeMemberAccounts != null)
'includeMemberAccounts': includeMemberAccounts,
},
);
return ExportLambdaFunctionRecommendationsResponse.fromJson(
jsonResponse.body);
}