getLambdaFunctionRecommendations method
Returns Lambda function recommendations.
Compute Optimizer generates recommendations for functions that meet a specific set of requirements. For more information, see the Supported resources and requirements in the Compute Optimizer User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw MissingAuthenticationToken.
May throw OptInRequiredException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter accountIds :
The ID of the Amazon Web Services account for which to return function
recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return function recommendations.
Only one account ID can be specified per request.
Parameter filters :
An array of objects to specify a filter that returns a more specific list
of function recommendations.
Parameter functionArns :
The Amazon Resource Name (ARN) of the functions for which to return
recommendations.
You can specify a qualified or unqualified ARN. If you specify an
unqualified ARN without a function version suffix, Compute Optimizer will
return recommendations for the latest ($LATEST) version of
the function. If you specify a qualified ARN with a version suffix,
Compute Optimizer will return recommendations for the specified function
version. For more information about using function versions, see Using
versions in the Lambda Developer Guide.
Parameter maxResults :
The maximum number of function recommendations to return with a single
request.
To retrieve the remaining results, make another request with the returned
nextToken value.
Parameter nextToken :
The token to advance to the next page of function recommendations.
Implementation
Future<GetLambdaFunctionRecommendationsResponse>
getLambdaFunctionRecommendations({
List<String>? accountIds,
List<LambdaFunctionRecommendationFilter>? filters,
List<String>? functionArns,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ComputeOptimizerService.GetLambdaFunctionRecommendations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (accountIds != null) 'accountIds': accountIds,
if (filters != null) 'filters': filters,
if (functionArns != null) 'functionArns': functionArns,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return GetLambdaFunctionRecommendationsResponse.fromJson(jsonResponse.body);
}