getLicenseRecommendations method
Returns license recommendations for Amazon EC2 instances that run on a specific license.
Compute Optimizer generates recommendations for licenses that meet a specific set of requirements. For more information, see the Supported resources and requirements in the Compute Optimizer User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidParameterValueException.
May throw MissingAuthenticationToken.
May throw OptInRequiredException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter accountIds :
The ID of the Amazon Web Services account for which to return license
recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return license recommendations.
Only one account ID can be specified per request.
Parameter filters :
An array of objects to specify a filter that returns a more specific list
of license recommendations.
Parameter maxResults :
The maximum number of license recommendations to return with a single
request.
To retrieve the remaining results, make another request with the returned
nextToken value.
Parameter nextToken :
The token to advance to the next page of license recommendations.
Parameter resourceArns :
The ARN that identifies the Amazon EC2 instance.
The following is the format of the ARN:
arn:aws:ec2:region:aws_account_id:instance/instance-id
Implementation
Future<GetLicenseRecommendationsResponse> getLicenseRecommendations({
List<String>? accountIds,
List<LicenseRecommendationFilter>? filters,
int? maxResults,
String? nextToken,
List<String>? resourceArns,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ComputeOptimizerService.GetLicenseRecommendations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (accountIds != null) 'accountIds': accountIds,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (resourceArns != null) 'resourceArns': resourceArns,
},
);
return GetLicenseRecommendationsResponse.fromJson(jsonResponse.body);
}