putRecommendationPreferences method
- required ResourceType resourceType,
- EnhancedInfrastructureMetrics? enhancedInfrastructureMetrics,
- ExternalMetricsPreference? externalMetricsPreference,
- InferredWorkloadTypesPreference? inferredWorkloadTypes,
- LookBackPeriodPreference? lookBackPeriod,
- List<
PreferredResource> ? preferredResources, - SavingsEstimationMode? savingsEstimationMode,
- Scope? scope,
- List<
UtilizationPreference> ? utilizationPreferences,
Creates a new recommendation preference or updates an existing recommendation preference, such as enhanced infrastructure metrics.
For more information, see Activating enhanced infrastructure metrics in the Compute Optimizer User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidParameterValueException.
May throw MissingAuthenticationToken.
May throw OptInRequiredException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter resourceType :
The target resource type of the recommendation preference to create.
The Ec2Instance option encompasses standalone instances and
instances that are part of Auto Scaling groups. The
AutoScalingGroup option encompasses only instances that are
part of an Auto Scaling group.
Parameter enhancedInfrastructureMetrics :
The status of the enhanced infrastructure metrics recommendation
preference to create or update.
Specify the Active status to activate the preference, or
specify Inactive to deactivate the preference.
For more information, see Enhanced infrastructure metrics in the Compute Optimizer User Guide.
Parameter externalMetricsPreference :
The provider of the external metrics recommendation preference to create
or update.
Specify a valid provider in the source field to activate the
preference. To delete this preference, see the
DeleteRecommendationPreferences action.
This preference can only be set for the Ec2Instance resource
type.
For more information, see External metrics ingestion in the Compute Optimizer User Guide.
Parameter inferredWorkloadTypes :
The status of the inferred workload types recommendation preference to
create or update.
Specify the Inactive status to deactivate the feature, or
specify Active to activate it.
For more information, see Inferred workload types in the Compute Optimizer User Guide.
Parameter lookBackPeriod :
The preference to control the number of days the utilization metrics of
the Amazon Web Services resource are analyzed. When this preference isn't
specified, we use the default value DAYS_14.
You can only set this preference for the Amazon EC2 instance, Auto Scaling group, Amazon EBS volume, Amazon ECS service on Fargate, Amazon RDS DB instance, and Aurora DB cluster storage resource types.
- Lookback period preferences for Amazon EC2 instances, Amazon EBS volumes, Amazon ECS services, Amazon RDS DB instances, and Aurora DB cluster storage resource types can be set at the organization, account, and resource levels.
- Auto Scaling group lookback preferences can only be set at the resource level.
- Amazon EBS volume lookback preferences can be set at the organization, account, and resource levels.
- Amazon ECS service on Fargate lookback preferences can be set at the organization, account, and resource levels.
- Amazon RDS DB instance lookback preferences can be set at the organization, account, and resource levels.
- Aurora DB cluster storage lookback preferences can be set at the organization, account, and resource levels.
- Changing the lookback period for Amazon EBS volumes to 14 days does not affect the 32-day lookback period used to determine whether an Amazon EBS volume is unattached.
Parameter preferredResources :
The preference to control which resource type values are considered when
generating rightsizing recommendations. You can specify this preference as
a combination of include and exclude lists. You must specify either an
includeList or excludeList. If the preference is
an empty set of resource type values, an error occurs.
Parameter savingsEstimationMode :
The status of the savings estimation mode preference to create or update.
Specify the AfterDiscounts status to activate the preference,
or specify BeforeDiscounts to deactivate the preference.
Only the account manager or delegated administrator of your organization can activate this preference.
For more information, see Savings estimation mode in the Compute Optimizer User Guide.
Parameter scope :
An object that describes the scope of the recommendation preference to
create.
You can create recommendation preferences at the organization level (for management accounts of an organization only), account level, and resource level. For more information, see Activating enhanced infrastructure metrics in the Compute Optimizer User Guide.
Parameter utilizationPreferences :
The preference to control the resource’s CPU utilization threshold, CPU
utilization headroom, and memory utilization headroom. When this
preference isn't specified, we use the following default values.
CPU utilization:
-
P99_5for threshold -
PERCENT_20for headroom
-
PERCENT_20for headroom
Implementation
Future<void> putRecommendationPreferences({
required ResourceType resourceType,
EnhancedInfrastructureMetrics? enhancedInfrastructureMetrics,
ExternalMetricsPreference? externalMetricsPreference,
InferredWorkloadTypesPreference? inferredWorkloadTypes,
LookBackPeriodPreference? lookBackPeriod,
List<PreferredResource>? preferredResources,
SavingsEstimationMode? savingsEstimationMode,
Scope? scope,
List<UtilizationPreference>? utilizationPreferences,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ComputeOptimizerService.PutRecommendationPreferences'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'resourceType': resourceType.value,
if (enhancedInfrastructureMetrics != null)
'enhancedInfrastructureMetrics': enhancedInfrastructureMetrics.value,
if (externalMetricsPreference != null)
'externalMetricsPreference': externalMetricsPreference,
if (inferredWorkloadTypes != null)
'inferredWorkloadTypes': inferredWorkloadTypes.value,
if (lookBackPeriod != null) 'lookBackPeriod': lookBackPeriod.value,
if (preferredResources != null)
'preferredResources': preferredResources,
if (savingsEstimationMode != null)
'savingsEstimationMode': savingsEstimationMode.value,
if (scope != null) 'scope': scope,
if (utilizationPreferences != null)
'utilizationPreferences': utilizationPreferences,
},
);
}