updateEnrollmentStatus method

Future<UpdateEnrollmentStatusResponse> updateEnrollmentStatus({
  1. required Status status,
  2. bool? includeMemberAccounts,
})

Updates the enrollment (opt in and opt out) status of an account to the Compute Optimizer service.

If the account is a management account of an organization, this action can also be used to enroll member accounts of the organization.

You must have the appropriate permissions to opt in to Compute Optimizer, to view its recommendations, and to opt out. For more information, see Controlling access with Amazon Web Services Identity and Access Management in the Compute Optimizer User Guide.

When you opt in, Compute Optimizer automatically creates a service-linked role in your account to access its data. For more information, see Using Service-Linked Roles for Compute Optimizer in the Compute Optimizer User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidParameterValueException. May throw MissingAuthenticationToken. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter status : The new enrollment status of the account.

The following status options are available:

  • Active - Opts in your account to the Compute Optimizer service. Compute Optimizer begins analyzing the configuration and utilization metrics of your Amazon Web Services resources after you opt in. For more information, see Metrics analyzed by Compute Optimizer in the Compute Optimizer User Guide.
  • Inactive - Opts out your account from the Compute Optimizer service. Your account's recommendations and related metrics data will be deleted from Compute Optimizer after you opt out.

Parameter includeMemberAccounts : Indicates whether to enroll member accounts of the organization if the account is the management account of an organization.

Implementation

Future<UpdateEnrollmentStatusResponse> updateEnrollmentStatus({
  required Status status,
  bool? includeMemberAccounts,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'ComputeOptimizerService.UpdateEnrollmentStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'status': status.value,
      if (includeMemberAccounts != null)
        'includeMemberAccounts': includeMemberAccounts,
    },
  );

  return UpdateEnrollmentStatusResponse.fromJson(jsonResponse.body);
}