ConfigService class
Config provides a way to keep track of the configurations of all the Amazon Web Services resources associated with your Amazon Web Services account. You can use Config to get the current and historical configurations of each Amazon Web Services resource and also to get information about the relationship between the resources. An Amazon Web Services resource can be an Amazon Compute Cloud (Amazon EC2) instance, an Elastic Block Store (EBS) volume, an elastic network Interface (ENI), or a security group. For a complete list of resources currently supported by Config, see Supported Amazon Web Services resources.
Constructors
- ConfigService({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateResourceTypes(
{required String configurationRecorderArn, required List< ResourceType> resourceTypes}) → Future<AssociateResourceTypesResponse> -
Adds all resource types specified in the
ResourceTypeslist to the RecordingGroup of specified configuration recorder and includes those resource types when recording. -
batchGetAggregateResourceConfig(
{required String configurationAggregatorName, required List< AggregateResourceIdentifier> resourceIdentifiers}) → Future<BatchGetAggregateResourceConfigResponse> -
Returns the current configuration items for resources that are present in
your Config aggregator. The operation also returns a list of resources
that are not processed in the current request. If there are no unprocessed
resources, the operation returns an empty
unprocessedResourceIdentifierslist. -
batchGetResourceConfig(
{required List< ResourceKey> resourceKeys}) → Future<BatchGetResourceConfigResponse> -
Returns the
BaseConfigurationItemfor one or more requested resources. The operation also returns a list of resources that are not processed in the current request. If there are no unprocessed resources, the operation returns an empty unprocessedResourceKeys list. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deleteAggregationAuthorization(
{required String authorizedAccountId, required String authorizedAwsRegion}) → Future< void> - Deletes the authorization granted to the specified configuration aggregator account in a specified region.
-
deleteConfigRule(
{required String configRuleName}) → Future< void> - Deletes the specified Config rule and all of its evaluation results.
-
deleteConfigurationAggregator(
{required String configurationAggregatorName}) → Future< void> - Deletes the specified configuration aggregator and the aggregated data associated with the aggregator.
-
deleteConfigurationRecorder(
{required String configurationRecorderName}) → Future< void> - Deletes the customer managed configuration recorder.
-
deleteConformancePack(
{required String conformancePackName}) → Future< void> - Deletes the specified conformance pack and all the Config rules, remediation actions, and all evaluation results within that conformance pack.
-
deleteDeliveryChannel(
{required String deliveryChannelName}) → Future< void> - Deletes the delivery channel.
-
deleteEvaluationResults(
{required String configRuleName}) → Future< void> - Deletes the evaluation results for the specified Config rule. You can specify one Config rule per request. After you delete the evaluation results, you can call the StartConfigRulesEvaluation API to start evaluating your Amazon Web Services resources against the rule.
-
deleteOrganizationConfigRule(
{required String organizationConfigRuleName}) → Future< void> - Deletes the specified organization Config rule and all of its evaluation results from all member accounts in that organization.
-
deleteOrganizationConformancePack(
{required String organizationConformancePackName}) → Future< void> - Deletes the specified organization conformance pack and all of the Config rules and remediation actions from all member accounts in that organization.
-
deletePendingAggregationRequest(
{required String requesterAccountId, required String requesterAwsRegion}) → Future< void> - Deletes pending authorization requests for a specified aggregator account in a specified region.
-
deleteRemediationConfiguration(
{required String configRuleName, String? resourceType}) → Future< void> - Deletes the remediation configuration.
-
deleteRemediationExceptions(
{required String configRuleName, required List< RemediationExceptionResourceKey> resourceKeys}) → Future<DeleteRemediationExceptionsResponse> - Deletes one or more remediation exceptions mentioned in the resource keys.
-
deleteResourceConfig(
{required String resourceId, required String resourceType}) → Future< void> - Records the configuration state for a custom resource that has been deleted. This API records a new ConfigurationItem with a ResourceDeleted status. You can retrieve the ConfigurationItems recorded for this resource in your Config History.
-
deleteRetentionConfiguration(
{required String retentionConfigurationName}) → Future< void> - Deletes the retention configuration.
-
deleteServiceLinkedConfigurationRecorder(
{required String servicePrincipal}) → Future< DeleteServiceLinkedConfigurationRecorderResponse> - Deletes an existing service-linked configuration recorder.
-
deleteStoredQuery(
{required String queryName}) → Future< void> - Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region.
-
deliverConfigSnapshot(
{required String deliveryChannelName}) → Future< DeliverConfigSnapshotResponse> - Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel. After the delivery has started, Config sends the following notifications using an Amazon SNS topic that you have specified.
-
describeAggregateComplianceByConfigRules(
{required String configurationAggregatorName, ConfigRuleComplianceFilters? filters, int? limit, String? nextToken}) → Future< DescribeAggregateComplianceByConfigRulesResponse> - Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules. Does not display rules that do not have compliance results.
-
describeAggregateComplianceByConformancePacks(
{required String configurationAggregatorName, AggregateConformancePackComplianceFilters? filters, int? limit, String? nextToken}) → Future< DescribeAggregateComplianceByConformancePacksResponse> - Returns a list of the existing and deleted conformance packs and their associated compliance status with the count of compliant and noncompliant Config rules within each conformance pack. Also returns the total rule count which includes compliant rules, noncompliant rules, and rules that cannot be evaluated due to insufficient data.
-
describeAggregationAuthorizations(
{int? limit, String? nextToken}) → Future< DescribeAggregationAuthorizationsResponse> - Returns a list of authorizations granted to various aggregator accounts and regions.
-
describeComplianceByConfigRule(
{List< ComplianceType> ? complianceTypes, List<String> ? configRuleNames, String? nextToken}) → Future<DescribeComplianceByConfigRuleResponse> - Indicates whether the specified Config rules are compliant. If a rule is noncompliant, this operation returns the number of Amazon Web Services resources that do not comply with the rule.
-
describeComplianceByResource(
{List< ComplianceType> ? complianceTypes, int? limit, String? nextToken, String? resourceId, String? resourceType}) → Future<DescribeComplianceByResourceResponse> - Indicates whether the specified Amazon Web Services resources are compliant. If a resource is noncompliant, this operation returns the number of Config rules that the resource does not comply with.
-
describeConfigRuleEvaluationStatus(
{List< String> ? configRuleNames, int? limit, String? nextToken}) → Future<DescribeConfigRuleEvaluationStatusResponse> - Returns status information for each of your Config managed rules. The status includes information such as the last time Config invoked the rule, the last time Config failed to invoke the rule, and the related error for the last failure.
-
describeConfigRules(
{List< String> ? configRuleNames, DescribeConfigRulesFilters? filters, String? nextToken}) → Future<DescribeConfigRulesResponse> - Returns details about your Config rules.
-
describeConfigurationAggregators(
{List< String> ? configurationAggregatorNames, int? limit, String? nextToken}) → Future<DescribeConfigurationAggregatorsResponse> - Returns the details of one or more configuration aggregators. If the configuration aggregator is not specified, this operation returns the details for all the configuration aggregators associated with the account.
-
describeConfigurationAggregatorSourcesStatus(
{required String configurationAggregatorName, int? limit, String? nextToken, List< AggregatedSourceStatusType> ? updateStatus}) → Future<DescribeConfigurationAggregatorSourcesStatusResponse> - Returns status information for sources within an aggregator. The status includes information about the last time Config verified authorization between the source account and an aggregator account. In case of a failure, the status contains the related error code or message.
-
describeConfigurationRecorders(
{String? arn, List< String> ? configurationRecorderNames, String? servicePrincipal}) → Future<DescribeConfigurationRecordersResponse> - Returns details for the configuration recorder you specify.
-
describeConfigurationRecorderStatus(
{String? arn, List< String> ? configurationRecorderNames, String? servicePrincipal}) → Future<DescribeConfigurationRecorderStatusResponse> - Returns the current status of the configuration recorder you specify as well as the status of the last recording event for the configuration recorders.
-
describeConformancePackCompliance(
{required String conformancePackName, ConformancePackComplianceFilters? filters, int? limit, String? nextToken}) → Future< DescribeConformancePackComplianceResponse> - Returns compliance details for each rule in that conformance pack.
-
describeConformancePacks(
{List< String> ? conformancePackNames, int? limit, String? nextToken}) → Future<DescribeConformancePacksResponse> - Returns a list of one or more conformance packs.
-
describeConformancePackStatus(
{List< String> ? conformancePackNames, int? limit, String? nextToken}) → Future<DescribeConformancePackStatusResponse> - Provides one or more conformance packs deployment status.
-
describeDeliveryChannels(
{List< String> ? deliveryChannelNames}) → Future<DescribeDeliveryChannelsResponse> - Returns details about the specified delivery channel. If a delivery channel is not specified, this operation returns the details of all delivery channels associated with the account.
-
describeDeliveryChannelStatus(
{List< String> ? deliveryChannelNames}) → Future<DescribeDeliveryChannelStatusResponse> - Returns the current status of the specified delivery channel. If a delivery channel is not specified, this operation returns the current status of all delivery channels associated with the account.
-
describeOrganizationConfigRules(
{int? limit, String? nextToken, List< String> ? organizationConfigRuleNames}) → Future<DescribeOrganizationConfigRulesResponse> - Returns a list of organization Config rules.
-
describeOrganizationConfigRuleStatuses(
{int? limit, String? nextToken, List< String> ? organizationConfigRuleNames}) → Future<DescribeOrganizationConfigRuleStatusesResponse> - Provides organization Config rule deployment status for an organization.
-
describeOrganizationConformancePacks(
{int? limit, String? nextToken, List< String> ? organizationConformancePackNames}) → Future<DescribeOrganizationConformancePacksResponse> - Returns a list of organization conformance packs.
-
describeOrganizationConformancePackStatuses(
{int? limit, String? nextToken, List< String> ? organizationConformancePackNames}) → Future<DescribeOrganizationConformancePackStatusesResponse> - Provides organization conformance pack deployment status for an organization.
-
describePendingAggregationRequests(
{int? limit, String? nextToken}) → Future< DescribePendingAggregationRequestsResponse> - Returns a list of all pending aggregation requests.
-
describeRemediationConfigurations(
{required List< String> configRuleNames}) → Future<DescribeRemediationConfigurationsResponse> - Returns the details of one or more remediation configurations.
-
describeRemediationExceptions(
{required String configRuleName, int? limit, String? nextToken, List< RemediationExceptionResourceKey> ? resourceKeys}) → Future<DescribeRemediationExceptionsResponse> - Returns the details of one or more remediation exceptions. A detailed view of a remediation exception for a set of resources that includes an explanation of an exception and the time when the exception will be deleted. When you specify the limit and the next token, you receive a paginated response.
-
describeRemediationExecutionStatus(
{required String configRuleName, int? limit, String? nextToken, List< ResourceKey> ? resourceKeys}) → Future<DescribeRemediationExecutionStatusResponse> - Provides a detailed view of a Remediation Execution for a set of resources including state, timestamps for when steps for the remediation execution occur, and any error messages for steps that have failed. When you specify the limit and the next token, you receive a paginated response.
-
describeRetentionConfigurations(
{String? nextToken, List< String> ? retentionConfigurationNames}) → Future<DescribeRetentionConfigurationsResponse> - Returns the details of one or more retention configurations. If the retention configuration name is not specified, this operation returns the details for all the retention configurations for that account.
-
disassociateResourceTypes(
{required String configurationRecorderArn, required List< ResourceType> resourceTypes}) → Future<DisassociateResourceTypesResponse> -
Removes all resource types specified in the
ResourceTypeslist from the RecordingGroup of configuration recorder and excludes these resource types when recording. -
getAggregateComplianceDetailsByConfigRule(
{required String accountId, required String awsRegion, required String configRuleName, required String configurationAggregatorName, ComplianceType? complianceType, int? limit, String? nextToken}) → Future< GetAggregateComplianceDetailsByConfigRuleResponse> - Returns the evaluation results for the specified Config rule for a specific resource in a rule. The results indicate which Amazon Web Services resources were evaluated by the rule, when each resource was last evaluated, and whether each resource complies with the rule.
-
getAggregateConfigRuleComplianceSummary(
{required String configurationAggregatorName, ConfigRuleComplianceSummaryFilters? filters, ConfigRuleComplianceSummaryGroupKey? groupByKey, int? limit, String? nextToken}) → Future< GetAggregateConfigRuleComplianceSummaryResponse> - Returns the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator.
-
getAggregateConformancePackComplianceSummary(
{required String configurationAggregatorName, AggregateConformancePackComplianceSummaryFilters? filters, AggregateConformancePackComplianceSummaryGroupKey? groupByKey, int? limit, String? nextToken}) → Future< GetAggregateConformancePackComplianceSummaryResponse> - Returns the count of compliant and noncompliant conformance packs across all Amazon Web Services accounts and Amazon Web Services Regions in an aggregator. You can filter based on Amazon Web Services account ID or Amazon Web Services Region.
-
getAggregateDiscoveredResourceCounts(
{required String configurationAggregatorName, ResourceCountFilters? filters, ResourceCountGroupKey? groupByKey, int? limit, String? nextToken}) → Future< GetAggregateDiscoveredResourceCountsResponse> - Returns the resource counts across accounts and regions that are present in your Config aggregator. You can request the resource counts by providing filters and GroupByKey.
-
getAggregateResourceConfig(
{required String configurationAggregatorName, required AggregateResourceIdentifier resourceIdentifier}) → Future< GetAggregateResourceConfigResponse> - Returns configuration item that is aggregated for your specific resource in a specific source account and region.
-
getComplianceDetailsByConfigRule(
{required String configRuleName, List< ComplianceType> ? complianceTypes, int? limit, String? nextToken}) → Future<GetComplianceDetailsByConfigRuleResponse> - Returns the evaluation results for the specified Config rule. The results indicate which Amazon Web Services resources were evaluated by the rule, when each resource was last evaluated, and whether each resource complies with the rule.
-
getComplianceDetailsByResource(
{List< ComplianceType> ? complianceTypes, String? nextToken, String? resourceEvaluationId, String? resourceId, String? resourceType}) → Future<GetComplianceDetailsByResourceResponse> - Returns the evaluation results for the specified Amazon Web Services resource. The results indicate which Config rules were used to evaluate the resource, when each rule was last invoked, and whether the resource complies with each rule.
-
getComplianceSummaryByConfigRule(
) → Future< GetComplianceSummaryByConfigRuleResponse> - Returns the number of Config rules that are compliant and noncompliant, up to a maximum of 25 for each.
-
getComplianceSummaryByResourceType(
{List< String> ? resourceTypes}) → Future<GetComplianceSummaryByResourceTypeResponse> - Returns the number of resources that are compliant and the number that are noncompliant. You can specify one or more resource types to get these numbers for each resource type. The maximum number returned is 100.
-
getConformancePackComplianceDetails(
{required String conformancePackName, ConformancePackEvaluationFilters? filters, int? limit, String? nextToken}) → Future< GetConformancePackComplianceDetailsResponse> - Returns compliance details of a conformance pack for all Amazon Web Services resources that are monitered by conformance pack.
-
getConformancePackComplianceSummary(
{required List< String> conformancePackNames, int? limit, String? nextToken}) → Future<GetConformancePackComplianceSummaryResponse> - Returns compliance details for the conformance pack based on the cumulative compliance results of all the rules in that conformance pack.
-
getCustomRulePolicy(
{String? configRuleName}) → Future< GetCustomRulePolicyResponse> - Returns the policy definition containing the logic for your Config Custom Policy rule.
-
getDiscoveredResourceCounts(
{int? limit, String? nextToken, List< String> ? resourceTypes}) → Future<GetDiscoveredResourceCountsResponse> - Returns the resource types, the number of each resource type, and the total number of resources that Config is recording in this region for your Amazon Web Services account.
-
getOrganizationConfigRuleDetailedStatus(
{required String organizationConfigRuleName, StatusDetailFilters? filters, int? limit, String? nextToken}) → Future< GetOrganizationConfigRuleDetailedStatusResponse> - Returns detailed status for each member account within an organization for a given organization Config rule.
-
getOrganizationConformancePackDetailedStatus(
{required String organizationConformancePackName, OrganizationResourceDetailedStatusFilters? filters, int? limit, String? nextToken}) → Future< GetOrganizationConformancePackDetailedStatusResponse> - Returns detailed status for each member account within an organization for a given organization conformance pack.
-
getOrganizationCustomRulePolicy(
{required String organizationConfigRuleName}) → Future< GetOrganizationCustomRulePolicyResponse> - Returns the policy definition containing the logic for your organization Config Custom Policy rule.
-
getResourceConfigHistory(
{required String resourceId, required ResourceType resourceType, ChronologicalOrder? chronologicalOrder, DateTime? earlierTime, DateTime? laterTime, int? limit, String? nextToken}) → Future< GetResourceConfigHistoryResponse> -
getResourceEvaluationSummary(
{required String resourceEvaluationId}) → Future< GetResourceEvaluationSummaryResponse> - Returns a summary of resource evaluation for the specified resource evaluation ID from the proactive rules that were run. The results indicate which evaluation context was used to evaluate the rules, which resource details were evaluated, the evaluation mode that was run, and whether the resource details comply with the configuration of the proactive rules.
-
getStoredQuery(
{required String queryName}) → Future< GetStoredQueryResponse> - Returns the details of a specific stored query.
-
listAggregateDiscoveredResources(
{required String configurationAggregatorName, required ResourceType resourceType, ResourceFilters? filters, int? limit, String? nextToken}) → Future< ListAggregateDiscoveredResourcesResponse> - Accepts a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions. A resource identifier includes the resource type, ID, (if available) the custom resource name, source account, and source region. You can narrow the results to include only resources that have specific resource IDs, or a resource name, or source account ID, or source region.
-
listConfigurationRecorders(
{List< ConfigurationRecorderFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListConfigurationRecordersResponse> - Returns a list of configuration recorders depending on the filters you specify.
-
listConformancePackComplianceScores(
{ConformancePackComplianceScoresFilters? filters, int? limit, String? nextToken, SortBy? sortBy, SortOrder? sortOrder}) → Future< ListConformancePackComplianceScoresResponse> - Returns a list of conformance pack compliance scores. A compliance score is the percentage of the number of compliant rule-resource combinations in a conformance pack compared to the number of total possible rule-resource combinations in the conformance pack. This metric provides you with a high-level view of the compliance state of your conformance packs. You can use it to identify, investigate, and understand the level of compliance in your conformance packs.
-
listDiscoveredResources(
{required ResourceType resourceType, bool? includeDeletedResources, int? limit, String? nextToken, List< String> ? resourceIds, String? resourceName}) → Future<ListDiscoveredResourcesResponse> - Returns a list of resource resource identifiers for the specified resource types for the resources of that type. A resource identifier includes the resource type, ID, and (if available) the custom resource name.
-
listResourceEvaluations(
{ResourceEvaluationFilters? filters, int? limit, String? nextToken}) → Future< ListResourceEvaluationsResponse> - Returns a list of proactive resource evaluations.
-
listStoredQueries(
{int? maxResults, String? nextToken}) → Future< ListStoredQueriesResponse> - Lists the stored queries for a single Amazon Web Services account and a single Amazon Web Services Region. The default is 100.
-
listTagsForResource(
{required String resourceArn, int? limit, String? nextToken}) → Future< ListTagsForResourceResponse> - List the tags for Config resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAggregationAuthorization(
{required String authorizedAccountId, required String authorizedAwsRegion, List< Tag> ? tags}) → Future<PutAggregationAuthorizationResponse> - Authorizes the aggregator account and region to collect data from the source account and region.
-
putConfigRule(
{required ConfigRule configRule, List< Tag> ? tags}) → Future<void> - Adds or updates an Config rule to evaluate if your Amazon Web Services resources comply with your desired configurations. For information on how many Config rules you can have per account, see Service Limits in the Config Developer Guide.
-
putConfigurationAggregator(
{required String configurationAggregatorName, List< AccountAggregationSource> ? accountAggregationSources, AggregatorFilters? aggregatorFilters, OrganizationAggregationSource? organizationAggregationSource, List<Tag> ? tags}) → Future<PutConfigurationAggregatorResponse> - Creates and updates the configuration aggregator with the selected source accounts and regions. The source account can be individual account(s) or an organization.
-
putConfigurationRecorder(
{required ConfigurationRecorder configurationRecorder, List< Tag> ? tags}) → Future<void> - Creates or updates the customer managed configuration recorder.
-
putConformancePack(
{required String conformancePackName, List< ConformancePackInputParameter> ? conformancePackInputParameters, String? deliveryS3Bucket, String? deliveryS3KeyPrefix, List<Tag> ? tags, String? templateBody, String? templateS3Uri, TemplateSSMDocumentDetails? templateSSMDocumentDetails}) → Future<PutConformancePackResponse> - Creates or updates a conformance pack. A conformance pack is a collection of Config rules that can be easily deployed in an account and a region and across an organization. For information on how many conformance packs you can have per account, see Service Limits in the Config Developer Guide.
-
putDeliveryChannel(
{required DeliveryChannel deliveryChannel}) → Future< void> - Creates or updates a delivery channel to deliver configuration information and other compliance information.
-
putEvaluations(
{required String resultToken, List< Evaluation> ? evaluations, bool? testMode}) → Future<PutEvaluationsResponse> - Used by an Lambda function to deliver evaluation results to Config. This operation is required in every Lambda function that is invoked by an Config rule.
-
putExternalEvaluation(
{required String configRuleName, required ExternalEvaluation externalEvaluation}) → Future< void> - Add or updates the evaluations for process checks. This API checks if the rule is a process check when the name of the Config rule is provided.
-
putOrganizationConfigRule(
{required String organizationConfigRuleName, List< String> ? excludedAccounts, OrganizationCustomPolicyRuleMetadata? organizationCustomPolicyRuleMetadata, OrganizationCustomRuleMetadata? organizationCustomRuleMetadata, OrganizationManagedRuleMetadata? organizationManagedRuleMetadata}) → Future<PutOrganizationConfigRuleResponse> - Adds or updates an Config rule for your entire organization to evaluate if your Amazon Web Services resources comply with your desired configurations. For information on how many organization Config rules you can have per account, see Service Limits in the Config Developer Guide.
-
putOrganizationConformancePack(
{required String organizationConformancePackName, List< ConformancePackInputParameter> ? conformancePackInputParameters, String? deliveryS3Bucket, String? deliveryS3KeyPrefix, List<String> ? excludedAccounts, String? templateBody, String? templateS3Uri}) → Future<PutOrganizationConformancePackResponse> - Deploys conformance packs across member accounts in an Amazon Web Services Organization. For information on how many organization conformance packs and how many Config rules you can have per account, see Service Limits in the Config Developer Guide.
-
putRemediationConfigurations(
{required List< RemediationConfiguration> remediationConfigurations}) → Future<PutRemediationConfigurationsResponse> -
Adds or updates the remediation configuration with a specific Config rule
with the selected target or action. The API creates the
RemediationConfigurationobject for the Config rule. The Config rule must already exist for you to add a remediation configuration. The target (SSM document) must exist and have permissions to use the target. -
putRemediationExceptions(
{required String configRuleName, required List< RemediationExceptionResourceKey> resourceKeys, DateTime? expirationTime, String? message}) → Future<PutRemediationExceptionsResponse> - A remediation exception is when a specified resource is no longer considered for auto-remediation. This API adds a new exception or updates an existing exception for a specified resource with a specified Config rule.
-
putResourceConfig(
{required String configuration, required String resourceId, required String resourceType, required String schemaVersionId, String? resourceName, Map< String, String> ? tags}) → Future<void> - Records the configuration state for the resource provided in the request. The configuration state of a resource is represented in Config as Configuration Items. Once this API records the configuration item, you can retrieve the list of configuration items for the custom resource type using existing Config APIs.
-
putRetentionConfiguration(
{required int retentionPeriodInDays}) → Future< PutRetentionConfigurationResponse> -
Creates and updates the retention configuration with details about
retention period (number of days) that Config stores your historical
information. The API creates the
RetentionConfigurationobject and names the object as default. When you have aRetentionConfigurationobject named default, calling the API modifies the default object. -
putServiceLinkedConfigurationRecorder(
{required String servicePrincipal, List< Tag> ? tags}) → Future<PutServiceLinkedConfigurationRecorderResponse> -
Creates a service-linked configuration recorder that is linked to a
specific Amazon Web Services service based on the
ServicePrincipalyou specify. -
putStoredQuery(
{required StoredQuery storedQuery, List< Tag> ? tags}) → Future<PutStoredQueryResponse> -
Saves a new query or updates an existing saved query. The
QueryNamemust be unique for a single Amazon Web Services account and a single Amazon Web Services Region. You can create upto 300 queries in a single Amazon Web Services account and a single Amazon Web Services Region. -
selectAggregateResourceConfig(
{required String configurationAggregatorName, required String expression, int? limit, int? maxResults, String? nextToken}) → Future< SelectAggregateResourceConfigResponse> - Accepts a structured query language (SQL) SELECT command and an aggregator to query configuration state of Amazon Web Services resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties.
-
selectResourceConfig(
{required String expression, int? limit, String? nextToken}) → Future< SelectResourceConfigResponse> -
Accepts a structured query language (SQL)
SELECTcommand, performs the corresponding search, and returns resource configurations matching the properties. -
startConfigRulesEvaluation(
{List< String> ? configRuleNames}) → Future<void> -
Runs an on-demand evaluation for the specified Config rules against the
last known configuration state of the resources. Use
StartConfigRulesEvaluationwhen you want to test that a rule you updated is working as expected.StartConfigRulesEvaluationdoes not re-record the latest configuration state for your resources. It re-runs an evaluation against the last known state of your resources. -
startConfigurationRecorder(
{required String configurationRecorderName}) → Future< void> - Starts the customer managed configuration recorder. The customer managed configuration recorder will begin recording configuration changes for the resource types you specify.
-
startRemediationExecution(
{required String configRuleName, required List< ResourceKey> resourceKeys}) → Future<StartRemediationExecutionResponse> - Runs an on-demand remediation for the specified Config rules against the last known remediation configuration. It runs an execution against the current state of your resources. Remediation execution is asynchronous.
-
startResourceEvaluation(
{required EvaluationMode evaluationMode, required ResourceDetails resourceDetails, String? clientToken, EvaluationContext? evaluationContext, int? evaluationTimeout}) → Future< StartResourceEvaluationResponse> - Runs an on-demand evaluation for the specified resource to determine whether the resource details will comply with configured Config rules. You can also use it for evaluation purposes. Config recommends using an evaluation context. It runs an execution against the resource details with all of the Config rules in your account that match with the specified proactive mode and resource type.
-
stopConfigurationRecorder(
{required String configurationRecorderName}) → Future< void> - Stops the customer managed configuration recorder. The customer managed configuration recorder will stop recording configuration changes for the resource types you have specified.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> -
Associates the specified tags to a resource with the specified
ResourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. If existing tags are specified, however, then their values will be updated. When a resource is deleted, the tags associated with that resource are deleted as well. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Deletes specified tags from a resource.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited