deleteConfigurationRecorder method

Future<void> deleteConfigurationRecorder({
  1. required String configurationRecorderName,
})

Deletes the customer managed configuration recorder.

This operation does not delete the configuration information that was previously recorded. You will be able to access the previously recorded information by using the GetResourceConfigHistory operation, but you will not be able to access this information in the Config console until you have created a new customer managed configuration recorder.

May throw NoSuchConfigurationRecorderException. May throw UnmodifiableEntityException.

Parameter configurationRecorderName : The name of the customer managed configuration recorder that you want to delete. You can retrieve the name of your configuration recorders by using the DescribeConfigurationRecorders operation.

Implementation

Future<void> deleteConfigurationRecorder({
  required String configurationRecorderName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.DeleteConfigurationRecorder'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigurationRecorderName': configurationRecorderName,
    },
  );
}