deleteConformancePack method
Deletes the specified conformance pack and all the Config rules, remediation actions, and all evaluation results within that conformance pack.
Config sets the conformance pack to DELETE_IN_PROGRESS until
the deletion is complete. You cannot update a conformance pack while it is
in this state.
Deleting rules creates configuration items (CIs) for
AWS::Config::ResourceCompliance that can affect your costs
for the configuration recorder. If you are deleting rules which evaluate a
large number of resource types, this can lead to a spike in the number of
CIs recorded.
To avoid the associated costs, you can opt to disable recording for the
AWS::Config::ResourceCompliance resource type before deleting
rules, and re-enable recording after the rules have been deleted.
However, since deleting rules is an asynchronous process, it might take an
hour or more to complete. During the time when recording is disabled for
AWS::Config::ResourceCompliance, rule evaluations will not be
recorded in the associated resource’s history.
May throw NoSuchConformancePackException.
May throw ResourceInUseException.
Parameter conformancePackName :
Name of the conformance pack you want to delete.
Implementation
Future<void> deleteConformancePack({
required String conformancePackName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DeleteConformancePack'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConformancePackName': conformancePackName,
},
);
}