deleteDeliveryChannel method
Deletes the delivery channel.
Before you can delete the delivery channel, you must stop the customer managed configuration recorder. You can use the StopConfigurationRecorder operation to stop the customer managed configuration recorder.
May throw LastDeliveryChannelDeleteFailedException.
May throw NoSuchDeliveryChannelException.
Parameter deliveryChannelName :
The name of the delivery channel that you want to delete.
Implementation
Future<void> deleteDeliveryChannel({
required String deliveryChannelName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DeleteDeliveryChannel'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DeliveryChannelName': deliveryChannelName,
},
);
}