deleteEvaluationResults method

Future<void> deleteEvaluationResults({
  1. required String configRuleName,
})

Deletes the evaluation results for the specified Config rule. You can specify one Config rule per request. After you delete the evaluation results, you can call the StartConfigRulesEvaluation API to start evaluating your Amazon Web Services resources against the rule.

May throw NoSuchConfigRuleException. May throw ResourceInUseException.

Parameter configRuleName : The name of the Config rule for which you want to delete the evaluation results.

Implementation

Future<void> deleteEvaluationResults({
  required String configRuleName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.DeleteEvaluationResults'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigRuleName': configRuleName,
    },
  );
}