deleteRemediationExceptions method
Deletes one or more remediation exceptions mentioned in the resource keys.
May throw NoSuchRemediationExceptionException.
Parameter configRuleName :
The name of the Config rule for which you want to delete remediation
exception configuration.
Parameter resourceKeys :
An exception list of resource exception keys to be processed with the
current request. Config adds exception for each resource key. For example,
Config adds 3 exceptions for 3 resource keys.
Implementation
Future<DeleteRemediationExceptionsResponse> deleteRemediationExceptions({
required String configRuleName,
required List<RemediationExceptionResourceKey> resourceKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DeleteRemediationExceptions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigRuleName': configRuleName,
'ResourceKeys': resourceKeys,
},
);
return DeleteRemediationExceptionsResponse.fromJson(jsonResponse.body);
}