deleteStoredQuery method
Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter queryName :
The name of the query that you want to delete.
Implementation
Future<void> deleteStoredQuery({
required String queryName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DeleteStoredQuery'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'QueryName': queryName,
},
);
}