describeComplianceByConfigRule method
Indicates whether the specified Config rules are compliant. If a rule is noncompliant, this operation returns the number of Amazon Web Services resources that do not comply with the rule.
A rule is compliant if all of the evaluated resources comply with it. It is noncompliant if any of these resources do not comply.
If Config has no current evaluation results for the rule, it returns
INSUFFICIENT_DATA. This result might indicate one of the
following conditions:
-
Config has never invoked an evaluation for the rule. To check whether it
has, use the
DescribeConfigRuleEvaluationStatusaction to get theLastSuccessfulInvocationTimeandLastFailedInvocationTime. -
The rule's Lambda function is failing to send evaluation results to
Config. Verify that the role you assigned to your configuration recorder
includes the
config:PutEvaluationspermission. If the rule is a custom rule, verify that the Lambda execution role includes theconfig:PutEvaluationspermission. -
The rule's Lambda function has returned
NOT_APPLICABLEfor all evaluation results. This can occur if the resources were deleted or removed from the rule's scope.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw NoSuchConfigRuleException.
Parameter complianceTypes :
Filters the results by compliance.
Parameter configRuleNames :
Specify one or more Config rule names to filter the results by rule.
Parameter nextToken :
The nextToken string returned on a previous page that you use
to get the next page of results in a paginated response.
Implementation
Future<DescribeComplianceByConfigRuleResponse>
describeComplianceByConfigRule({
List<ComplianceType>? complianceTypes,
List<String>? configRuleNames,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DescribeComplianceByConfigRule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (complianceTypes != null)
'ComplianceTypes': complianceTypes.map((e) => e.value).toList(),
if (configRuleNames != null) 'ConfigRuleNames': configRuleNames,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeComplianceByConfigRuleResponse.fromJson(jsonResponse.body);
}