describeConfigRules method
Returns details about your Config rules.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw NoSuchConfigRuleException.
Parameter configRuleNames :
The names of the Config rules for which you want details. If you do not
specify any names, Config returns details for all your rules.
Parameter filters :
Returns a list of Detective or Proactive Config rules. By default, this
API returns an unfiltered list. For more information on Detective or
Proactive Config rules, see
Evaluation Mode in the Config Developer Guide.
Parameter nextToken :
The nextToken string returned on a previous page that you use
to get the next page of results in a paginated response.
Implementation
Future<DescribeConfigRulesResponse> describeConfigRules({
List<String>? configRuleNames,
DescribeConfigRulesFilters? filters,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DescribeConfigRules'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (configRuleNames != null) 'ConfigRuleNames': configRuleNames,
if (filters != null) 'Filters': filters,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeConfigRulesResponse.fromJson(jsonResponse.body);
}