describeConfigurationAggregatorSourcesStatus method

Future<DescribeConfigurationAggregatorSourcesStatusResponse> describeConfigurationAggregatorSourcesStatus({
  1. required String configurationAggregatorName,
  2. int? limit,
  3. String? nextToken,
  4. List<AggregatedSourceStatusType>? updateStatus,
})

Returns status information for sources within an aggregator. The status includes information about the last time Config verified authorization between the source account and an aggregator account. In case of a failure, the status contains the related error code or message.

May throw InvalidLimitException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw NoSuchConfigurationAggregatorException.

Parameter configurationAggregatorName : The name of the configuration aggregator.

Parameter limit : The maximum number of AggregatorSourceStatus returned on each page. The default is maximum. If you specify 0, Config uses the default.

Parameter nextToken : The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Parameter updateStatus : Filters the status type.

  • Valid value FAILED indicates errors while moving data.
  • Valid value SUCCEEDED indicates the data was successfully moved.
  • Valid value OUTDATED indicates the data is not the most recent.

Implementation

Future<DescribeConfigurationAggregatorSourcesStatusResponse>
    describeConfigurationAggregatorSourcesStatus({
  required String configurationAggregatorName,
  int? limit,
  String? nextToken,
  List<AggregatedSourceStatusType>? updateStatus,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    0,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'StarlingDoveService.DescribeConfigurationAggregatorSourcesStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigurationAggregatorName': configurationAggregatorName,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
      if (updateStatus != null)
        'UpdateStatus': updateStatus.map((e) => e.value).toList(),
    },
  );

  return DescribeConfigurationAggregatorSourcesStatusResponse.fromJson(
      jsonResponse.body);
}