describeConfigurationAggregators method

Future<DescribeConfigurationAggregatorsResponse> describeConfigurationAggregators({
  1. List<String>? configurationAggregatorNames,
  2. int? limit,
  3. String? nextToken,
})

Returns the details of one or more configuration aggregators. If the configuration aggregator is not specified, this operation returns the details for all the configuration aggregators associated with the account.

May throw InvalidLimitException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw NoSuchConfigurationAggregatorException.

Parameter configurationAggregatorNames : The name of the configuration aggregators.

Parameter limit : The maximum number of configuration aggregators returned on each page. The default is maximum. If you specify 0, Config uses the default.

Parameter nextToken : The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Implementation

Future<DescribeConfigurationAggregatorsResponse>
    describeConfigurationAggregators({
  List<String>? configurationAggregatorNames,
  int? limit,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    0,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.DescribeConfigurationAggregators'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (configurationAggregatorNames != null)
        'ConfigurationAggregatorNames': configurationAggregatorNames,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeConfigurationAggregatorsResponse.fromJson(jsonResponse.body);
}