describeOrganizationConformancePackStatuses method
Provides organization conformance pack deployment status for an organization.
When you specify the limit and the next token, you receive a paginated response. Limit and next token are not applicable if you specify organization conformance pack names. They are only applicable, when you request all the organization conformance packs.
May throw InvalidLimitException.
May throw InvalidNextTokenException.
May throw NoSuchOrganizationConformancePackException.
May throw OrganizationAccessDeniedException.
Parameter limit :
The maximum number of OrganizationConformancePackStatuses returned on each
page. If you do no specify a number, Config uses the default. The default
is 100.
Parameter nextToken :
The nextToken string returned on a previous page that you use to get the
next page of results in a paginated response.
Parameter organizationConformancePackNames :
The names of organization conformance packs for which you want status
details. If you do not specify any names, Config returns details for all
your organization conformance packs.
Implementation
Future<DescribeOrganizationConformancePackStatusesResponse>
describeOrganizationConformancePackStatuses({
int? limit,
String? nextToken,
List<String>? organizationConformancePackNames,
}) async {
_s.validateNumRange(
'limit',
limit,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'StarlingDoveService.DescribeOrganizationConformancePackStatuses'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
if (organizationConformancePackNames != null)
'OrganizationConformancePackNames': organizationConformancePackNames,
},
);
return DescribeOrganizationConformancePackStatusesResponse.fromJson(
jsonResponse.body);
}