getAggregateResourceConfig method

Future<GetAggregateResourceConfigResponse> getAggregateResourceConfig({
  1. required String configurationAggregatorName,
  2. required AggregateResourceIdentifier resourceIdentifier,
})

Returns configuration item that is aggregated for your specific resource in a specific source account and region.

May throw NoSuchConfigurationAggregatorException. May throw OversizedConfigurationItemException. May throw ResourceNotDiscoveredException. May throw ValidationException.

Parameter configurationAggregatorName : The name of the configuration aggregator.

Parameter resourceIdentifier : An object that identifies aggregate resource.

Implementation

Future<GetAggregateResourceConfigResponse> getAggregateResourceConfig({
  required String configurationAggregatorName,
  required AggregateResourceIdentifier resourceIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.GetAggregateResourceConfig'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigurationAggregatorName': configurationAggregatorName,
      'ResourceIdentifier': resourceIdentifier,
    },
  );

  return GetAggregateResourceConfigResponse.fromJson(jsonResponse.body);
}