getOrganizationConformancePackDetailedStatus method
Returns detailed status for each member account within an organization for a given organization conformance pack.
May throw InvalidLimitException.
May throw InvalidNextTokenException.
May throw NoSuchOrganizationConformancePackException.
May throw OrganizationAccessDeniedException.
Parameter organizationConformancePackName :
The name of organization conformance pack for which you want status
details for member accounts.
Parameter filters :
An OrganizationResourceDetailedStatusFilters object.
Parameter limit :
The maximum number of
OrganizationConformancePackDetailedStatuses returned on each
page. If you do not specify a number, Config uses the default. The default
is 100.
Parameter nextToken :
The nextToken string returned on a previous page that you use to get the
next page of results in a paginated response.
Implementation
Future<GetOrganizationConformancePackDetailedStatusResponse>
getOrganizationConformancePackDetailedStatus({
required String organizationConformancePackName,
OrganizationResourceDetailedStatusFilters? filters,
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'StarlingDoveService.GetOrganizationConformancePackDetailedStatus'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OrganizationConformancePackName': organizationConformancePackName,
if (filters != null) 'Filters': filters,
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetOrganizationConformancePackDetailedStatusResponse.fromJson(
jsonResponse.body);
}