getResourceEvaluationSummary method
Future<GetResourceEvaluationSummaryResponse>
getResourceEvaluationSummary({
- required String resourceEvaluationId,
Returns a summary of resource evaluation for the specified resource evaluation ID from the proactive rules that were run. The results indicate which evaluation context was used to evaluate the rules, which resource details were evaluated, the evaluation mode that was run, and whether the resource details comply with the configuration of the proactive rules.
May throw ResourceNotFoundException.
Parameter resourceEvaluationId :
The unique ResourceEvaluationId of Amazon Web Services
resource execution for which you want to retrieve the evaluation summary.
Implementation
Future<GetResourceEvaluationSummaryResponse> getResourceEvaluationSummary({
required String resourceEvaluationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.GetResourceEvaluationSummary'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceEvaluationId': resourceEvaluationId,
},
);
return GetResourceEvaluationSummaryResponse.fromJson(jsonResponse.body);
}