listConfigurationRecorders method

Future<ListConfigurationRecordersResponse> listConfigurationRecorders({
  1. List<ConfigurationRecorderFilter>? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of configuration recorders depending on the filters you specify.

May throw ValidationException.

Parameter filters : Filters the results based on a list of ConfigurationRecorderFilter objects that you specify.

Parameter maxResults : The maximum number of results to include in the response.

Parameter nextToken : The NextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Implementation

Future<ListConfigurationRecordersResponse> listConfigurationRecorders({
  List<ConfigurationRecorderFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    20,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.ListConfigurationRecorders'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListConfigurationRecordersResponse.fromJson(jsonResponse.body);
}