putConfigRule method
Adds or updates an Config rule to evaluate if your Amazon Web Services resources comply with your desired configurations. For information on how many Config rules you can have per account, see Service Limits in the Config Developer Guide.
There are two types of rules: Config Managed Rules and Config
Custom Rules. You can use PutConfigRule to create both
Config Managed Rules and Config Custom Rules.
Config Managed Rules are predefined, customizable rules created by Config.
For a list of managed rules, see List
of Config Managed Rules. If you are adding an Config managed rule, you
must specify the rule's identifier for the SourceIdentifier
key.
Config Custom Rules are rules that you create from scratch. There are two ways to create Config custom rules: with Lambda functions ( Lambda Developer Guide) and with Guard (Guard GitHub Repository), a policy-as-code language. Config custom rules created with Lambda are called Config Custom Lambda Rules and Config custom rules created with Guard are called Config Custom Policy Rules.
If you are adding a new Config Custom Lambda rule, you first need to
create an Lambda function that the rule invokes to evaluate your
resources. When you use PutConfigRule to add a Custom Lambda
rule to Config, you must specify the Amazon Resource Name (ARN) that
Lambda assigns to the function. You specify the ARN in the
SourceIdentifier key. This key is part of the
Source object, which is part of the ConfigRule
object.
For any new Config rule that you add, specify the
ConfigRuleName in the ConfigRule object. Do not
specify the ConfigRuleArn or the ConfigRuleId.
These values are generated by Config for new rules.
If you are updating a rule that you added previously, you can specify the
rule by ConfigRuleName, ConfigRuleId, or
ConfigRuleArn in the ConfigRule data type that
you use in this request.
For more information about developing and using Config rules, see Evaluating Resources with Config Rules in the Config Developer Guide.
PutConfigRule is an idempotent API. Subsequent requests won’t
create a duplicate resource if one was already created. If a following
request has different tags values, Config will ignore these
differences and treat it as an idempotent request of the previous. In this
case, tags will not be updated, even if they are different.
Use TagResource and UntagResource to update tags after creation.
May throw InsufficientPermissionsException.
May throw InvalidParameterValueException.
May throw MaxNumberOfConfigRulesExceededException.
May throw NoAvailableConfigurationRecorderException.
May throw ResourceInUseException.
Parameter configRule :
The rule that you want to add to your account.
Parameter tags :
An array of tag object.
Implementation
Future<void> putConfigRule({
required ConfigRule configRule,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutConfigRule'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigRule': configRule,
if (tags != null) 'Tags': tags,
},
);
}