putDeliveryChannel method
Creates or updates a delivery channel to deliver configuration information and other compliance information.
You can use this operation to create a new delivery channel or to update the Amazon S3 bucket and the Amazon SNS topic of an existing delivery channel.
For more information, see Working with the Delivery Channel in the Config Developer Guide.
You can have only one delivery channel for each account for each Amazon Web Services Region.
May throw InsufficientDeliveryPolicyException.
May throw InvalidDeliveryChannelNameException.
May throw InvalidS3KeyPrefixException.
May throw InvalidS3KmsKeyArnException.
May throw InvalidSNSTopicARNException.
May throw MaxNumberOfDeliveryChannelsExceededException.
May throw NoAvailableConfigurationRecorderException.
May throw NoSuchBucketException.
Parameter deliveryChannel :
An object for the delivery channel. A delivery channel sends notifications
and updated configuration states.
Implementation
Future<void> putDeliveryChannel({
required DeliveryChannel deliveryChannel,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutDeliveryChannel'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DeliveryChannel': deliveryChannel,
},
);
}