putOrganizationConfigRule method
Adds or updates an Config rule for your entire organization to evaluate if your Amazon Web Services resources comply with your desired configurations. For information on how many organization Config rules you can have per account, see Service Limits in the Config Developer Guide.
Only a management account and a delegated administrator can create or
update an organization Config rule. When calling this API with a delegated
administrator, you must ensure Organizations
ListDelegatedAdministrator permissions are added. An
organization can have up to 3 delegated administrators.
This API enables organization service access through the
EnableAWSServiceAccess action and creates a service-linked
role AWSServiceRoleForConfigMultiAccountSetup in the
management or delegated administrator account of your organization. The
service-linked role is created only when the role does not exist in the
caller account. Config verifies the existence of role with
GetRole action.
To use this API with delegated administrator, register a delegated
administrator by calling Amazon Web Services Organization
register-delegated-administrator for
config-multiaccountsetup.amazonaws.com.
There are two types of rules: Config Managed Rules and Config
Custom Rules. You can use PutOrganizationConfigRule to
create both Config Managed Rules and Config Custom Rules.
Config Managed Rules are predefined, customizable rules created by Config.
For a list of managed rules, see List
of Config Managed Rules. If you are adding an Config managed rule, you
must specify the rule's identifier for the RuleIdentifier
key.
Config Custom Rules are rules that you create from scratch. There are two ways to create Config custom rules: with Lambda functions ( Lambda Developer Guide) and with Guard (Guard GitHub Repository), a policy-as-code language. Config custom rules created with Lambda are called Config Custom Lambda Rules and Config custom rules created with Guard are called Config Custom Policy Rules.
If you are adding a new Config Custom Lambda rule, you first need to
create an Lambda function in the management account or a delegated
administrator that the rule invokes to evaluate your resources. You also
need to create an IAM role in the managed account that can be assumed by
the Lambda function. When you use PutOrganizationConfigRule
to add a Custom Lambda rule to Config, you must specify the Amazon
Resource Name (ARN) that Lambda assigns to the function.
Make sure to specify one of either
OrganizationCustomPolicyRuleMetadata for Custom Policy rules,
OrganizationCustomRuleMetadata for Custom Lambda rules, or
OrganizationManagedRuleMetadata for managed rules.
May throw InsufficientPermissionsException.
May throw InvalidParameterValueException.
May throw MaxNumberOfOrganizationConfigRulesExceededException.
May throw NoAvailableOrganizationException.
May throw OrganizationAccessDeniedException.
May throw OrganizationAllFeaturesNotEnabledException.
May throw ResourceInUseException.
May throw ValidationException.
Parameter organizationConfigRuleName :
The name that you assign to an organization Config rule.
Parameter excludedAccounts :
A comma-separated list of accounts that you want to exclude from an
organization Config rule.
Parameter organizationCustomPolicyRuleMetadata :
An OrganizationCustomPolicyRuleMetadata object. This object
specifies metadata for your organization's Config Custom Policy rule. The
metadata includes the runtime system in use, which accounts have debug
logging enabled, and other custom rule metadata, such as resource type,
resource ID of Amazon Web Services resource, and organization trigger
types that initiate Config to evaluate Amazon Web Services resources
against a rule.
Parameter organizationCustomRuleMetadata :
An OrganizationCustomRuleMetadata object. This object
specifies organization custom rule metadata such as resource type,
resource ID of Amazon Web Services resource, Lambda function ARN, and
organization trigger types that trigger Config to evaluate your Amazon Web
Services resources against a rule. It also provides the frequency with
which you want Config to run evaluations for the rule if the trigger type
is periodic.
Parameter organizationManagedRuleMetadata :
An OrganizationManagedRuleMetadata object. This object
specifies organization managed rule metadata such as resource type and ID
of Amazon Web Services resource along with the rule identifier. It also
provides the frequency with which you want Config to run evaluations for
the rule if the trigger type is periodic.
Implementation
Future<PutOrganizationConfigRuleResponse> putOrganizationConfigRule({
required String organizationConfigRuleName,
List<String>? excludedAccounts,
OrganizationCustomPolicyRuleMetadata? organizationCustomPolicyRuleMetadata,
OrganizationCustomRuleMetadata? organizationCustomRuleMetadata,
OrganizationManagedRuleMetadata? organizationManagedRuleMetadata,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutOrganizationConfigRule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OrganizationConfigRuleName': organizationConfigRuleName,
if (excludedAccounts != null) 'ExcludedAccounts': excludedAccounts,
if (organizationCustomPolicyRuleMetadata != null)
'OrganizationCustomPolicyRuleMetadata':
organizationCustomPolicyRuleMetadata,
if (organizationCustomRuleMetadata != null)
'OrganizationCustomRuleMetadata': organizationCustomRuleMetadata,
if (organizationManagedRuleMetadata != null)
'OrganizationManagedRuleMetadata': organizationManagedRuleMetadata,
},
);
return PutOrganizationConfigRuleResponse.fromJson(jsonResponse.body);
}