putRemediationExceptions method
A remediation exception is when a specified resource is no longer considered for auto-remediation. This API adds a new exception or updates an existing exception for a specified resource with a specified Config rule.
Config generates a remediation exception when a problem occurs running a remediation action for a specified resource. Remediation exceptions blocks auto-remediation until the exception is cleared.
When placing an exception on an Amazon Web Services resource, it is
recommended that remediation is set as manual remediation until the given
Config rule for the specified resource evaluates the resource as
NON_COMPLIANT. Once the resource has been evaluated as
NON_COMPLIANT, you can add remediation exceptions and change
the remediation type back from Manual to Auto if you want to use
auto-remediation. Otherwise, using auto-remediation before a
NON_COMPLIANT evaluation result can delete resources before
the exception is applied.
Placing an exception can only be performed on resources that are
NON_COMPLIANT. If you use this API for COMPLIANT
resources or resources that are NOT_APPLICABLE, a remediation
exception will not be generated. For more information on the conditions
that initiate the possible Config evaluation results, see Concepts
| Config Rules in the Config Developer Guide.
You cannot place an exception on service-linked remediation actions, such as remediation actions put by an organizational conformance pack.
If you enable auto remediation for a specific Config rule using the PutRemediationConfigurations API or the Config console, it initiates the remediation process for all non-compliant resources for that specific rule. The auto remediation process relies on the compliance data snapshot which is captured on a periodic basis. Any non-compliant resource that is updated between the snapshot schedule will continue to be remediated based on the last known compliance data snapshot.
This means that in some cases auto remediation can be initiated even for compliant resources, since the bootstrap processor uses a database that can have stale evaluation results based on the last known compliance data snapshot.
May throw InsufficientPermissionsException.
May throw InvalidParameterValueException.
Parameter configRuleName :
The name of the Config rule for which you want to create remediation
exception.
Parameter resourceKeys :
An exception list of resource exception keys to be processed with the
current request. Config adds exception for each resource key. For example,
Config adds 3 exceptions for 3 resource keys.
Parameter expirationTime :
The exception is automatically deleted after the expiration date.
Parameter message :
The message contains an explanation of the exception.
Implementation
Future<PutRemediationExceptionsResponse> putRemediationExceptions({
required String configRuleName,
required List<RemediationExceptionResourceKey> resourceKeys,
DateTime? expirationTime,
String? message,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutRemediationExceptions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigRuleName': configRuleName,
'ResourceKeys': resourceKeys,
if (expirationTime != null)
'ExpirationTime': unixTimestampToJson(expirationTime),
if (message != null) 'Message': message,
},
);
return PutRemediationExceptionsResponse.fromJson(jsonResponse.body);
}