startConfigRulesEvaluation method
Runs an on-demand evaluation for the specified Config rules against the
last known configuration state of the resources. Use
StartConfigRulesEvaluation when you want to test that a rule
you updated is working as expected.
StartConfigRulesEvaluation does not re-record the latest
configuration state for your resources. It re-runs an evaluation against
the last known state of your resources.
You can specify up to 25 Config rules per request.
An existing StartConfigRulesEvaluation call for the specified
rules must complete before you can call the API again. If you chose to
have Config stream to an Amazon SNS topic, you will receive a
ConfigRuleEvaluationStarted notification when the evaluation
starts.
The StartConfigRulesEvaluation API is useful if you want to
run on-demand evaluations, such as the following example:
- You have a custom rule that evaluates your IAM resources every 24 hours.
- You update your Lambda function to add additional conditions to your rule.
-
Instead of waiting for the next periodic evaluation, you call the
StartConfigRulesEvaluationAPI. - Config invokes your Lambda function and evaluates your IAM resources.
- Your custom rule will still run periodic evaluations every 24 hours.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw NoSuchConfigRuleException.
May throw ResourceInUseException.
Parameter configRuleNames :
The list of names of Config rules that you want to run evaluations for.
Implementation
Future<void> startConfigRulesEvaluation({
List<String>? configRuleNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.StartConfigRulesEvaluation'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (configRuleNames != null) 'ConfigRuleNames': configRuleNames,
},
);
}