startConfigurationRecorder method

Future<void> startConfigurationRecorder({
  1. required String configurationRecorderName,
})

Starts the customer managed configuration recorder. The customer managed configuration recorder will begin recording configuration changes for the resource types you specify.

You must have created a delivery channel to successfully start the customer managed configuration recorder. You can use the PutDeliveryChannel operation to create a delivery channel.

May throw NoAvailableDeliveryChannelException. May throw NoSuchConfigurationRecorderException. May throw UnmodifiableEntityException.

Parameter configurationRecorderName : The name of the customer managed configuration recorder that you want to start.

Implementation

Future<void> startConfigurationRecorder({
  required String configurationRecorderName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StarlingDoveService.StartConfigurationRecorder'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigurationRecorderName': configurationRecorderName,
    },
  );
}