activateEvaluationForm method
Activates an evaluation form in the specified Connect Customer instance. After the evaluation form is activated, it is available to start new evaluations based on the form.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter evaluationFormId :
The unique identifier for the evaluation form.
Parameter evaluationFormVersion :
The version of the evaluation form to activate. If the version property is
not provided, the latest version of the evaluation form is activated.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Implementation
Future<ActivateEvaluationFormResponse> activateEvaluationForm({
required String evaluationFormId,
required int evaluationFormVersion,
required String instanceId,
}) async {
final $payload = <String, dynamic>{
'EvaluationFormVersion': evaluationFormVersion,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/evaluation-forms/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(evaluationFormId)}/activate',
exceptionFnMap: _exceptionFns,
);
return ActivateEvaluationFormResponse.fromJson(response);
}