associateHoursOfOperations method
Associates a set of hours of operations with another hours of operation. Refer to Administrator Guide here for more information on inheriting overrides from parent hours of operation(s).
May throw ConditionalOperationFailedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter hoursOfOperationId :
The identifier of the child hours of operation.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter parentHoursOfOperationConfigs :
The Amazon Resource Names (ARNs) of the parent hours of operation
resources to associate with the child hours of operation resource.
Implementation
Future<void> associateHoursOfOperations({
required String hoursOfOperationId,
required String instanceId,
required List<ParentHoursOfOperationConfig> parentHoursOfOperationConfigs,
}) async {
final $payload = <String, dynamic>{
'ParentHoursOfOperationConfigs': parentHoursOfOperationConfigs,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/hours-of-operations/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(hoursOfOperationId)}/associate-hours',
exceptionFnMap: _exceptionFns,
);
}