batchDeleteDataTableValue method

Future<BatchDeleteDataTableValueResponse> batchDeleteDataTableValue({
  1. required String dataTableId,
  2. required String instanceId,
  3. required List<DataTableDeleteValueIdentifier> values,
})

Deletes multiple values from a data table. API users may delete values at any time. When deletion is requested from the admin website, a warning is shown alerting the user of the most recent time the attribute and its values were accessed. System managed values are not deletable by customers.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter dataTableId : The unique identifier for the data table. Must also accept the table ARN with or without a version alias.

Parameter instanceId : The unique identifier for the Amazon Connect instance.

Parameter values : A list of value identifiers to delete, each specifying primary values, attribute name, and lock version information.

Implementation

Future<BatchDeleteDataTableValueResponse> batchDeleteDataTableValue({
  required String dataTableId,
  required String instanceId,
  required List<DataTableDeleteValueIdentifier> values,
}) async {
  final $payload = <String, dynamic>{
    'Values': values,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/values/delete',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeleteDataTableValueResponse.fromJson(response);
}