batchGetAttachedFileMetadata method

Future<BatchGetAttachedFileMetadataResponse> batchGetAttachedFileMetadata({
  1. required String associatedResourceArn,
  2. required List<String> fileIds,
  3. required String instanceId,
})

Allows you to retrieve metadata about multiple attached files on an associated resource. Each attached file provided in the input list must be associated with the input AssociatedResourceArn.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter associatedResourceArn : The resource to which the attached file is (being) uploaded to. The supported resources are Cases and Email.

Parameter fileIds : The unique identifiers of the attached file resource.

Parameter instanceId : The unique identifier of the Connect instance.

Implementation

Future<BatchGetAttachedFileMetadataResponse> batchGetAttachedFileMetadata({
  required String associatedResourceArn,
  required List<String> fileIds,
  required String instanceId,
}) async {
  final $query = <String, List<String>>{
    'associatedResourceArn': [associatedResourceArn],
  };
  final $payload = <String, dynamic>{
    'FileIds': fileIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/attached-files/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetAttachedFileMetadataResponse.fromJson(response);
}