batchGetFlowAssociation method

Future<BatchGetFlowAssociationResponse> batchGetFlowAssociation({
  1. required String instanceId,
  2. required List<String> resourceIds,
  3. ListFlowAssociationResourceType? resourceType,
})

Retrieve the flow associations for the given resources.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter resourceIds : A list of resource identifiers to retrieve flow associations.

  • Amazon Web Services End User Messaging SMS phone number ARN when using SMS_PHONE_NUMBER
  • Amazon Web Services End User Messaging Social phone number ARN when using WHATSAPP_MESSAGING_PHONE_NUMBER

Parameter resourceType : The type of resource association.

Implementation

Future<BatchGetFlowAssociationResponse> batchGetFlowAssociation({
  required String instanceId,
  required List<String> resourceIds,
  ListFlowAssociationResourceType? resourceType,
}) async {
  final $payload = <String, dynamic>{
    'ResourceIds': resourceIds,
    if (resourceType != null) 'ResourceType': resourceType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/flow-associations-batch/${Uri.encodeComponent(instanceId)}',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetFlowAssociationResponse.fromJson(response);
}