batchUpdateDataTableValue method

Future<BatchUpdateDataTableValueResponse> batchUpdateDataTableValue({
  1. required String dataTableId,
  2. required String instanceId,
  3. required List<DataTableValue> values,
})

Updates multiple data table values using all properties from BatchCreateDataTableValue. System managed values are not modifiable by customers. The operation requires proper lock versions to prevent concurrent modification conflicts.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter dataTableId : The unique identifier for the data table. Must also accept the table ARN with or without a version alias.

Parameter instanceId : The unique identifier for the Amazon Connect instance.

Parameter values : A list of values to update, each including the current lock version to ensure optimistic locking.

Implementation

Future<BatchUpdateDataTableValueResponse> batchUpdateDataTableValue({
  required String dataTableId,
  required String instanceId,
  required List<DataTableValue> values,
}) async {
  final $payload = <String, dynamic>{
    'Values': values,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/values/update',
    exceptionFnMap: _exceptionFns,
  );
  return BatchUpdateDataTableValueResponse.fromJson(response);
}