completeAttachedFileUpload method

Future<void> completeAttachedFileUpload({
  1. required String associatedResourceArn,
  2. required String fileId,
  3. required String instanceId,
})

Allows you to confirm that the attached file has been uploaded using the pre-signed URL provided in the StartAttachedFileUpload API.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter associatedResourceArn : The resource to which the attached file is (being) uploaded to. The supported resources are Cases and Email.

Parameter fileId : The unique identifier of the attached file resource.

Parameter instanceId : The unique identifier of the Connect Customer instance.

Implementation

Future<void> completeAttachedFileUpload({
  required String associatedResourceArn,
  required String fileId,
  required String instanceId,
}) async {
  final $query = <String, List<String>>{
    'associatedResourceArn': [associatedResourceArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/attached-files/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(fileId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}