createContactFlowModuleVersion method
Creates an immutable snapshot of a contact flow module, preserving its content and settings at a specific point in time for version control and rollback capabilities.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter contactFlowModuleId :
The identifier of the flow module.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter description :
The description of the flow module version.
Parameter flowModuleContentSha256 :
Indicates the checksum value of the flow module content.
Implementation
Future<CreateContactFlowModuleVersionResponse>
createContactFlowModuleVersion({
required String contactFlowModuleId,
required String instanceId,
String? description,
String? flowModuleContentSha256,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'Description': description,
if (flowModuleContentSha256 != null)
'FlowModuleContentSha256': flowModuleContentSha256,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/contact-flow-modules/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowModuleId)}/version',
exceptionFnMap: _exceptionFns,
);
return CreateContactFlowModuleVersionResponse.fromJson(response);
}