deactivateEvaluationForm method

Future<DeactivateEvaluationFormResponse> deactivateEvaluationForm({
  1. required String evaluationFormId,
  2. required int evaluationFormVersion,
  3. required String instanceId,
})

Deactivates an evaluation form in the specified Connect Customer instance. After a form is deactivated, it is no longer available for users to start new evaluations based on the form.

May throw InternalServiceException. May throw InvalidParameterException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter evaluationFormId : The unique identifier for the evaluation form.

Parameter evaluationFormVersion : A version of the evaluation form. If the version property is not provided, the latest version of the evaluation form is deactivated.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Implementation

Future<DeactivateEvaluationFormResponse> deactivateEvaluationForm({
  required String evaluationFormId,
  required int evaluationFormVersion,
  required String instanceId,
}) async {
  final $payload = <String, dynamic>{
    'EvaluationFormVersion': evaluationFormVersion,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/evaluation-forms/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(evaluationFormId)}/deactivate',
    exceptionFnMap: _exceptionFns,
  );
  return DeactivateEvaluationFormResponse.fromJson(response);
}