deleteAttachedFile method
Deletes an attached file along with the underlying S3 Object.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter associatedResourceArn :
The resource to which the attached file is (being) uploaded to. Cases
are the only current supported resource.
Parameter fileId :
The unique identifier of the attached file resource.
Parameter instanceId :
The unique identifier of the Connect instance.
Implementation
Future<void> deleteAttachedFile({
required String associatedResourceArn,
required String fileId,
required String instanceId,
}) async {
final $query = <String, List<String>>{
'associatedResourceArn': [associatedResourceArn],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/attached-files/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(fileId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}