deleteContactFlowModuleAlias method

Future<void> deleteContactFlowModuleAlias({
  1. required String aliasId,
  2. required String contactFlowModuleId,
  3. required String instanceId,
})

Removes an alias reference, breaking the named connection to the underlying module version without affecting the version itself.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter aliasId : The identifier of the alias.

Parameter contactFlowModuleId : The identifier of the flow module.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Implementation

Future<void> deleteContactFlowModuleAlias({
  required String aliasId,
  required String contactFlowModuleId,
  required String instanceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/contact-flow-modules/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowModuleId)}/alias/${Uri.encodeComponent(aliasId)}',
    exceptionFnMap: _exceptionFns,
  );
}