deleteDataTable method

Future<void> deleteDataTable({
  1. required String dataTableId,
  2. required String instanceId,
})

Deletes a data table and all associated attributes, versions, audits, and values. Does not update any references to the data table, even from other data tables. This includes dynamic values and conditional validations. System managed data tables are not deletable by customers. API users may delete the table at any time. When deletion is requested from the admin website, a warning is shown alerting the user of the most recent time the table and its values were accessed.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter dataTableId : The unique identifier for the data table to delete. Must also accept the table ARN. Fails with an error if the version is provided and is not $LATEST.

Parameter instanceId : The unique identifier for the Amazon Connect instance.

Implementation

Future<void> deleteDataTable({
  required String dataTableId,
  required String instanceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}',
    exceptionFnMap: _exceptionFns,
  );
}