deletePushNotificationRegistration method

Future<void> deletePushNotificationRegistration({
  1. required String contactId,
  2. required String instanceId,
  3. required String registrationId,
})

Deletes registration for a device token and a chat contact.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactId : The identifier of the contact within the Connect Customer instance.

Parameter instanceId : The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter registrationId : The identifier for the registration.

Implementation

Future<void> deletePushNotificationRegistration({
  required String contactId,
  required String instanceId,
  required String registrationId,
}) async {
  final $query = <String, List<String>>{
    'contactId': [contactId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/push-notification/${Uri.encodeComponent(instanceId)}/registrations/${Uri.encodeComponent(registrationId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}