deleteUser method

Future<void> deleteUser({
  1. required String instanceId,
  2. required String userId,
})

Deletes a user account from the specified Connect Customer instance.

For information about what happens to a user's data when their account is deleted, see Delete Users from Your Connect Customer Instance in the Connect Customer Administrator Guide.

  • Avoid dangling resources that impact your service quotas.
  • Remove deleted users so they don't appear to agents as transfer options.
  • Avoid the disruption of other Connect Customer processes, such as instance replication and syncing if you're using Connect Customer Global Resiliency.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter userId : The identifier of the user.

Implementation

Future<void> deleteUser({
  required String instanceId,
  required String userId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}',
    exceptionFnMap: _exceptionFns,
  );
}