deleteWorkspacePage method
Removes the association between a view and a page in a workspace. The page will display the default view after deletion.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter page :
The page identifier.
Parameter workspaceId :
The identifier of the workspace.
Implementation
Future<void> deleteWorkspacePage({
required String instanceId,
required String page,
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/workspaces/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(workspaceId)}/pages/${Uri.encodeComponent(page)}',
exceptionFnMap: _exceptionFns,
);
}