describeAttachedFilesConfiguration method
Future<DescribeAttachedFilesConfigurationResponse>
describeAttachedFilesConfiguration({
- required AttachmentScope attachmentScope,
- required String instanceId,
Describes the attached files configuration for the specified Connect Customer instance and attachment scope.
If a custom configuration exists for the specified attachment scope, the custom configuration is returned. If no custom configuration exists, the default configuration values for that attachment scope are returned.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter attachmentScope :
The scope of the attachment. Valid values are EMAIL,
CHAT, CASE, and TASK.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Implementation
Future<DescribeAttachedFilesConfigurationResponse>
describeAttachedFilesConfiguration({
required AttachmentScope attachmentScope,
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/attached-files-configurations/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(attachmentScope.value)}',
exceptionFnMap: _exceptionFns,
);
return DescribeAttachedFilesConfigurationResponse.fromJson(response);
}