describeContactFlowModule method

Future<DescribeContactFlowModuleResponse> describeContactFlowModule({
  1. required String contactFlowModuleId,
  2. required String instanceId,
})

Describes the specified flow module.

Use the $SAVED alias in the request to describe the SAVED content of a Flow. For example, arn:aws:.../contact-flow/{id}:$SAVED. After a flow is published, $SAVED needs to be supplied to view saved content that has not been published.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactFlowModuleId : The identifier of the flow module.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Implementation

Future<DescribeContactFlowModuleResponse> describeContactFlowModule({
  required String contactFlowModuleId,
  required String instanceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/contact-flow-modules/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowModuleId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeContactFlowModuleResponse.fromJson(response);
}