describeContactFlowModuleAlias method
Retrieves detailed information about a specific alias, including which version it currently points to and its metadata.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter aliasId :
The identifier of the alias.
Parameter contactFlowModuleId :
The identifier of the flow module.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Implementation
Future<DescribeContactFlowModuleAliasResponse>
describeContactFlowModuleAlias({
required String aliasId,
required String contactFlowModuleId,
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/contact-flow-modules/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowModuleId)}/alias/${Uri.encodeComponent(aliasId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeContactFlowModuleAliasResponse.fromJson(response);
}