describeDataTableAttribute method
Returns detailed information for a specific data table attribute including its configuration, validation rules, and metadata. "Describe" is a deprecated term but is allowed to maintain consistency with existing operations.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter attributeName :
The name of the attribute to retrieve detailed information for.
Parameter dataTableId :
The unique identifier for the data table. Must also accept the table ARN
with or without a version alias.
Parameter instanceId :
The unique identifier for the Amazon Connect instance.
Implementation
Future<DescribeDataTableAttributeResponse> describeDataTableAttribute({
required String attributeName,
required String dataTableId,
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/attributes/${Uri.encodeComponent(attributeName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeDataTableAttributeResponse.fromJson(response);
}