describeEvaluationForm method
Describes an evaluation form in the specified Connect Customer instance. If the version property is not provided, the latest version of the evaluation form is described.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter evaluationFormId :
A unique identifier for the contact evaluation.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter evaluationFormVersion :
A version of the evaluation form.
Implementation
Future<DescribeEvaluationFormResponse> describeEvaluationForm({
required String evaluationFormId,
required String instanceId,
int? evaluationFormVersion,
}) async {
final $query = <String, List<String>>{
if (evaluationFormVersion != null)
'version': [evaluationFormVersion.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/evaluation-forms/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(evaluationFormId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeEvaluationFormResponse.fromJson(response);
}