describeInstanceStorageConfig method

Future<DescribeInstanceStorageConfigResponse> describeInstanceStorageConfig({
  1. required String associationId,
  2. required String instanceId,
  3. required InstanceStorageResourceType resourceType,
})

This API is in preview release for Connect Customer and is subject to change.

Retrieves the current storage configurations for the specified resource type, association ID, and instance ID.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter associationId : The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter resourceType : A valid resource type.

Implementation

Future<DescribeInstanceStorageConfigResponse> describeInstanceStorageConfig({
  required String associationId,
  required String instanceId,
  required InstanceStorageResourceType resourceType,
}) async {
  final $query = <String, List<String>>{
    'resourceType': [resourceType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/instance/${Uri.encodeComponent(instanceId)}/storage-config/${Uri.encodeComponent(associationId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeInstanceStorageConfigResponse.fromJson(response);
}