describePredefinedAttribute method

Future<DescribePredefinedAttributeResponse> describePredefinedAttribute({
  1. required String instanceId,
  2. required String name,
})

Describes a predefined attribute for the specified Connect Customer instance. A predefined attribute is made up of a name and a value. You can use predefined attributes for:

For the predefined attributes per instance quota, see Connect Customer quotas.

Endpoints: See Connect Customer endpoints and quotas.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter name : The name of the predefined attribute.

Implementation

Future<DescribePredefinedAttributeResponse> describePredefinedAttribute({
  required String instanceId,
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/predefined-attributes/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribePredefinedAttributeResponse.fromJson(response);
}