describeSecurityProfile method
Gets basic information about the security profile.
For information about security profiles, see Security Profiles in the Connect Customer Administrator Guide. For a mapping of the API name and user interface name of the security profile permissions, see List of security profile permissions.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter securityProfileId :
The identifier for the security profle.
Implementation
Future<DescribeSecurityProfileResponse> describeSecurityProfile({
required String instanceId,
required String securityProfileId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/security-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(securityProfileId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeSecurityProfileResponse.fromJson(response);
}