describeTrafficDistributionGroup method

Future<DescribeTrafficDistributionGroupResponse> describeTrafficDistributionGroup({
  1. required String trafficDistributionGroupId,
})

Gets details and status of a traffic distribution group.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter trafficDistributionGroupId : The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Implementation

Future<DescribeTrafficDistributionGroupResponse>
    describeTrafficDistributionGroup({
  required String trafficDistributionGroupId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/traffic-distribution-group/${Uri.encodeComponent(trafficDistributionGroupId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeTrafficDistributionGroupResponse.fromJson(response);
}