describeView method

Future<DescribeViewResponse> describeView({
  1. required String instanceId,
  2. required String viewId,
})

Retrieves the view for the specified Connect Customer instance and view identifier.

The view identifier can be supplied as a ViewId or ARN.

$SAVED needs to be supplied if a view is unpublished.

The view identifier can contain an optional qualifier, for example, , which is either an actual version number or an Connect Customer managed qualifier $SAVED | $LATEST. If it is not supplied, then $LATEST is assumed for customer managed views and an error is returned if there is no published content available. Version 1 is assumed for Amazon Web Services managed views.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw TooManyRequestsException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.

Parameter viewId : The ViewId of the view. This must be an ARN for Amazon Web Services managed views.

Implementation

Future<DescribeViewResponse> describeView({
  required String instanceId,
  required String viewId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/views/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(viewId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeViewResponse.fromJson(response);
}