disassociateAnalyticsDataSet method
Removes the dataset ID associated with a given Connect Customer instance.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter dataSetId :
The identifier of the dataset to remove.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter targetAccountId :
The identifier of the target account. Use to associate a dataset to a
different account than the one containing the Connect Customer instance.
If not specified, by default this value is the Amazon Web Services account
that has the Connect Customer instance.
Implementation
Future<void> disassociateAnalyticsDataSet({
required String dataSetId,
required String instanceId,
String? targetAccountId,
}) async {
final $payload = <String, dynamic>{
'DataSetId': dataSetId,
if (targetAccountId != null) 'TargetAccountId': targetAccountId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/analytics-data/instance/${Uri.encodeComponent(instanceId)}/association',
exceptionFnMap: _exceptionFns,
);
}