disassociateLambdaFunction method

Future<void> disassociateLambdaFunction({
  1. required String functionArn,
  2. required String instanceId,
  3. String? clientToken,
})

This API is in preview release for Connect Customer and is subject to change.

Remove the Lambda function from the dropdown options available in the relevant flow blocks.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter functionArn : The Amazon Resource Name (ARN) of the Lambda function being disassociated.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance..

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Implementation

Future<void> disassociateLambdaFunction({
  required String functionArn,
  required String instanceId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    'functionArn': [functionArn],
    if (clientToken != null) 'clientToken': [clientToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/instance/${Uri.encodeComponent(instanceId)}/lambda-function',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}