disassociateLexBot method
This API is in preview release for Connect Customer and is subject to change.
Revokes authorization from the specified instance to access the specified Amazon Lex bot.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter botName :
The name of the Amazon Lex bot. Maximum character limit of 50.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter lexRegion :
The Amazon Web Services Region in which the Amazon Lex bot has been
created.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. If not provided, the Amazon Web Services SDK
populates this field. For more information about idempotency, see Making
retries safe with idempotent APIs.
Implementation
Future<void> disassociateLexBot({
required String botName,
required String instanceId,
required String lexRegion,
String? clientToken,
}) async {
final $query = <String, List<String>>{
'botName': [botName],
'lexRegion': [lexRegion],
if (clientToken != null) 'clientToken': [clientToken],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/instance/${Uri.encodeComponent(instanceId)}/lex-bot',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}