dismissUserContact method

Future<void> dismissUserContact({
  1. required String contactId,
  2. required String instanceId,
  3. required String userId,
})

Dismisses contacts from an agent’s CCP and returns the agent to an available state, which allows the agent to receive a new routed contact. Contacts can only be dismissed if they are in a MISSED, ERROR, ENDED, or REJECTED state in the Agent Event Stream.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactId : The identifier of the contact.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.

Parameter userId : The identifier of the user account.

Implementation

Future<void> dismissUserContact({
  required String contactId,
  required String instanceId,
  required String userId,
}) async {
  final $payload = <String, dynamic>{
    'ContactId': contactId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}/contact',
    exceptionFnMap: _exceptionFns,
  );
}