evaluateDataTableValues method
Evaluates values at the time of the request and returns them. It considers the request's timezone or the table's timezone, in that order, when accessing time based tables. When a value is accessed, the accessor's identity and the time of access are saved alongside the value to help identify values that are actively in use. The term "Batch" is not included in the operation name since it does not meet all the criteria for a batch operation as specified in Batch Operations: Amazon Web Services API Standards.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter dataTableId :
The unique identifier for the data table. Must also accept the table ARN
with or without a version alias.
Parameter instanceId :
The unique identifier for the Amazon Connect instance.
Parameter values :
A list of value evaluation sets specifying which primary values and
attributes to evaluate.
Parameter maxResults :
The maximum number of data table values to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter timeZone :
Optional IANA timezone identifier to use when resolving time based dynamic
values. Defaults to the data table time zone if not provided.
Implementation
Future<EvaluateDataTableValuesResponse> evaluateDataTableValues({
required String dataTableId,
required String instanceId,
required List<DataTableValueEvaluationSet> values,
int? maxResults,
String? nextToken,
String? timeZone,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
'Values': values,
if (timeZone != null) 'TimeZone': timeZone,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/values/evaluate',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return EvaluateDataTableValuesResponse.fromJson(response);
}