getEffectiveHoursOfOperations method

Future<GetEffectiveHoursOfOperationsResponse> getEffectiveHoursOfOperations({
  1. required String fromDate,
  2. required String hoursOfOperationId,
  3. required String instanceId,
  4. required String toDate,
})

Get the hours of operations with the effective override applied.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter fromDate : The date from when the hours of operation are listed.

Parameter hoursOfOperationId : The identifier for the hours of operation.

Parameter instanceId : The identifier of the Connect Customer instance.

Parameter toDate : The date until when the hours of operation are listed.

Implementation

Future<GetEffectiveHoursOfOperationsResponse> getEffectiveHoursOfOperations({
  required String fromDate,
  required String hoursOfOperationId,
  required String instanceId,
  required String toDate,
}) async {
  final $query = <String, List<String>>{
    'fromDate': [fromDate],
    'toDate': [toDate],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/effective-hours-of-operations/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(hoursOfOperationId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetEffectiveHoursOfOperationsResponse.fromJson(response);
}