getEvaluationFormValidation method
Retrieves the status and results of a validation process started by StartEvaluationFormValidation.
Returns the current execution status (IN_PROGRESS,
COMPLETED, or FAILED), the validated form
version, and when completed, a list of findings that identify structural
issues and quality improvements for the evaluation form, and may include
suggested fixes. If the validation failed, a reason is provided indicating
the cause of the failure.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter evaluationFormId :
The unique identifier for the evaluation form.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter evaluationFormVersion :
The version of the evaluation form to retrieve validation results for.
Implementation
Future<GetEvaluationFormValidationResponse> getEvaluationFormValidation({
required String evaluationFormId,
required String instanceId,
int? evaluationFormVersion,
}) async {
final $query = <String, List<String>>{
if (evaluationFormVersion != null)
'version': [evaluationFormVersion.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/evaluation-forms/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(evaluationFormId)}/validation-results',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetEvaluationFormValidationResponse.fromJson(response);
}