getMetricData method
Gets historical metric data from the specified Connect Customer instance.
For a description of each historical metric, see Metrics definitions in the Connect Customer Administrator Guide.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter endTime :
The timestamp, in UNIX Epoch time format, at which to end the reporting
interval for the retrieval of historical metrics data. The time must be
specified using an interval of 5 minutes, such as 11:00, 11:05, 11:10, and
must be later than the start time timestamp.
The time range between the start and end time must be less than 24 hours.
Parameter filters :
The queues, up to 100, or channels, to use to filter the metrics returned.
Metric data is retrieved only for the resources associated with the queues
or channels included in the filter. You can include both queue IDs and
queue ARNs in the same request. VOICE, CHAT, and TASK channels are
supported.
RoutingStepExpression is not a valid filter for GetMetricData and we recommend switching to GetMetricDataV2 for more up-to-date features.
Parameter historicalMetrics :
The metrics to retrieve. Specify the name, unit, and statistic for each
metric. The following historical metrics are available. For a description
of each metric, see Metrics
definition in the Connect Customer Administrator Guide.
- ABANDON_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: Average queue abandon time
- AFTER_CONTACT_WORK_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: After contact work time
- API_CONTACTS_HANDLED
-
Unit: COUNT
Statistic: SUM
UI name: API contacts handled
- AVG_HOLD_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: Average customer hold time
- CALLBACK_CONTACTS_HANDLED
-
Unit: COUNT
Statistic: SUM
UI name: Callback contacts handled
- CONTACTS_ABANDONED
-
Unit: COUNT
Statistic: SUM
UI name: Contacts abandoned
- CONTACTS_AGENT_HUNG_UP_FIRST
-
Unit: COUNT
Statistic: SUM
UI name: Contacts agent hung up first
- CONTACTS_CONSULTED
-
Unit: COUNT
Statistic: SUM
UI name: Contacts consulted
- CONTACTS_HANDLED
-
Unit: COUNT
Statistic: SUM
UI name: Contacts handled
- CONTACTS_HANDLED_INCOMING
-
Unit: COUNT
Statistic: SUM
UI name: Contacts handled incoming
- CONTACTS_HANDLED_OUTBOUND
-
Unit: COUNT
Statistic: SUM
UI name: Contacts handled outbound
- CONTACTS_HOLD_ABANDONS
-
Unit: COUNT
Statistic: SUM
UI name: Contacts hold disconnect
- CONTACTS_MISSED
-
Unit: COUNT
Statistic: SUM
UI name: AGENT_NON_RESPONSE
- CONTACTS_QUEUED
-
Unit: COUNT
Statistic: SUM
UI name: Contacts queued
- CONTACTS_TRANSFERRED_IN
-
Unit: COUNT
Statistic: SUM
UI name: Contacts transferred in
- CONTACTS_TRANSFERRED_IN_FROM_QUEUE
-
Unit: COUNT
Statistic: SUM
UI name: Contacts transferred out queue
- CONTACTS_TRANSFERRED_OUT
-
Unit: COUNT
Statistic: SUM
UI name: Contacts transferred out
- CONTACTS_TRANSFERRED_OUT_FROM_QUEUE
-
Unit: COUNT
Statistic: SUM
UI name: Contacts transferred out queue
- HANDLE_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: Average handle time
- INTERACTION_AND_HOLD_TIME
-
Unit: SECONDS
Statistic: AVG
- INTERACTION_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: Average agent interaction time
- OCCUPANCY
-
Unit: PERCENT
Statistic: AVG
UI name: Occupancy
- QUEUE_ANSWER_TIME
-
Unit: SECONDS
Statistic: AVG
UI name: Average queue answer time
- QUEUED_TIME
-
Unit: SECONDS
Statistic: MAX
UI name: Minimum flow time
- SERVICE_LEVEL
-
You can include up to 20 SERVICE_LEVEL metrics in a request.
Unit: PERCENT
Statistic: AVG
Threshold: For
ThresholdValue, enter any whole number from 1 to 604800 (inclusive), in seconds. ForComparison, you must enterLT(for "Less than").UI name: Average queue abandon time
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter startTime :
The timestamp, in UNIX Epoch time format, at which to start the reporting
interval for the retrieval of historical metrics data. The time must be
specified using a multiple of 5 minutes, such as 10:05, 10:10, 10:15.
The start time cannot be earlier than 24 hours before the time of the request. Historical metrics are available only for 24 hours.
Parameter groupings :
The grouping applied to the metrics returned. For example, when results
are grouped by queue, the metrics returned are grouped by queue. The
values returned apply to the metrics for each queue rather than aggregated
for all queues.
If no grouping is specified, a summary of metrics for all queues is returned.
RoutingStepExpression is not a valid filter for GetMetricData and we recommend switching to GetMetricDataV2 for more up-to-date features.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<GetMetricDataResponse> getMetricData({
required DateTime endTime,
required Filters filters,
required List<HistoricalMetric> historicalMetrics,
required String instanceId,
required DateTime startTime,
List<Grouping>? groupings,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'EndTime': unixTimestampToJson(endTime),
'Filters': filters,
'HistoricalMetrics': historicalMetrics,
'StartTime': unixTimestampToJson(startTime),
if (groupings != null)
'Groupings': groupings.map((e) => e.value).toList(),
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/metrics/historical/${Uri.encodeComponent(instanceId)}',
exceptionFnMap: _exceptionFns,
);
return GetMetricDataResponse.fromJson(response);
}