getTaskTemplate method

Future<GetTaskTemplateResponse> getTaskTemplate({
  1. required String instanceId,
  2. required String taskTemplateId,
  3. String? snapshotVersion,
})

Gets details about a specific task template in the specified Connect Customer instance.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter taskTemplateId : A unique identifier for the task template.

Parameter snapshotVersion : The system generated version of a task template that is associated with a task, when the task is created.

Implementation

Future<GetTaskTemplateResponse> getTaskTemplate({
  required String instanceId,
  required String taskTemplateId,
  String? snapshotVersion,
}) async {
  final $query = <String, List<String>>{
    if (snapshotVersion != null) 'snapshotVersion': [snapshotVersion],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/instance/${Uri.encodeComponent(instanceId)}/task/template/${Uri.encodeComponent(taskTemplateId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetTaskTemplateResponse.fromJson(response);
}