getTestCaseExecutionSummary method

Future<GetTestCaseExecutionSummaryResponse> getTestCaseExecutionSummary({
  1. required String instanceId,
  2. required String testCaseExecutionId,
  3. required String testCaseId,
})

Retrieves an overview of a test execution that includes the status of the execution, start and end time, and observation summary.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Amazon Connect instance.

Parameter testCaseExecutionId : The identifier of the test case execution.

Parameter testCaseId : The identifier of the test case.

Implementation

Future<GetTestCaseExecutionSummaryResponse> getTestCaseExecutionSummary({
  required String instanceId,
  required String testCaseExecutionId,
  required String testCaseId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/test-cases/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(testCaseId)}/${Uri.encodeComponent(testCaseExecutionId)}/summary',
    exceptionFnMap: _exceptionFns,
  );
  return GetTestCaseExecutionSummaryResponse.fromJson(response);
}