getTrafficDistribution method

Future<GetTrafficDistributionResponse> getTrafficDistribution({
  1. required String id,
})

Retrieves the current traffic distribution for a given traffic distribution group.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter id : The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Implementation

Future<GetTrafficDistributionResponse> getTrafficDistribution({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/traffic-distribution/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetTrafficDistributionResponse.fromJson(response);
}