listChildHoursOfOperations method
Provides information about the child hours of operations for the specified parent hours of operation.
For more information about child hours of operations, see Link overrides from different hours of operation in the Administrator Guide.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter hoursOfOperationId :
The identifier of the parent hours of operation.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter maxResults :
The maximum number of results to return per page. The default MaxResult
size is 100.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListChildHoursOfOperationsResponse> listChildHoursOfOperations({
required String hoursOfOperationId,
required String instanceId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/hours-of-operations/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(hoursOfOperationId)}/hours',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListChildHoursOfOperationsResponse.fromJson(response);
}