listContactEvaluations method

Future<ListContactEvaluationsResponse> listContactEvaluations({
  1. required String contactId,
  2. required String instanceId,
  3. String? nextToken,
})

Lists contact evaluations in the specified Connect Customer instance.

May throw InternalServiceException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactId : The identifier of the contact in this instance of Connect Customer.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListContactEvaluationsResponse> listContactEvaluations({
  required String contactId,
  required String instanceId,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    'contactId': [contactId],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/contact-evaluations/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListContactEvaluationsResponse.fromJson(response);
}