listContactFlowVersions method

Future<ListContactFlowVersionsResponse> listContactFlowVersions({
  1. required String contactFlowId,
  2. required String instanceId,
  3. int? maxResults,
  4. String? nextToken,
})

Returns all the available versions for the specified Connect Customer instance and flow identifier.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactFlowId : The identifier of the flow.

Parameter instanceId : The identifier of the Connect Customer instance.

Parameter maxResults : The maximum number of results to return per page. The default MaxResult size is 100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListContactFlowVersionsResponse> listContactFlowVersions({
  required String contactFlowId,
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/contact-flows/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListContactFlowVersionsResponse.fromJson(response);
}