listContactFlows method

Future<ListContactFlowsResponse> listContactFlows({
  1. required String instanceId,
  2. List<ContactFlowType>? contactFlowTypes,
  3. int? maxResults,
  4. String? nextToken,
})

Provides information about the flows for the specified Connect Customer instance.

You can also create and update flows using the Connect Customer Flow language.

For more information about flows, see Flows in the Connect Customer Administrator Guide.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter contactFlowTypes : The type of flow.

Parameter maxResults : The maximum number of results to return per page. The default MaxResult size is 100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListContactFlowsResponse> listContactFlows({
  required String instanceId,
  List<ContactFlowType>? contactFlowTypes,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (contactFlowTypes != null)
      'contactFlowTypes': contactFlowTypes.map((e) => e.value).toList(),
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/contact-flows-summary/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListContactFlowsResponse.fromJson(response);
}