listDataTables method

Future<ListDataTablesResponse> listDataTables({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all data tables for the specified Amazon Connect instance. Returns summary information for each table including basic metadata and modification details.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The unique identifier for the Amazon Connect instance whose data tables should be listed.

Parameter maxResults : The maximum number of data tables to return in one page of results.

Parameter nextToken : Specify the pagination token from a previous request to retrieve the next page of results.

Implementation

Future<ListDataTablesResponse> listDataTables({
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/data-tables/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDataTablesResponse.fromJson(response);
}