listHoursOfOperationOverrides method

Future<ListHoursOfOperationOverridesResponse> listHoursOfOperationOverrides({
  1. required String hoursOfOperationId,
  2. required String instanceId,
  3. int? maxResults,
  4. String? nextToken,
})

List the hours of operation overrides.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter hoursOfOperationId : The identifier for the hours of operation.

Parameter instanceId : The identifier of the Connect Customer instance.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListHoursOfOperationOverridesResponse> listHoursOfOperationOverrides({
  required String hoursOfOperationId,
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/hours-of-operations/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(hoursOfOperationId)}/overrides',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListHoursOfOperationOverridesResponse.fromJson(response);
}