listInstanceStorageConfigs method
This API is in preview release for Connect Customer and is subject to change.
Returns a paginated list of storage configs for the identified instance and resource type.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter resourceType :
A valid resource type.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListInstanceStorageConfigsResponse> listInstanceStorageConfigs({
required String instanceId,
required InstanceStorageResourceType resourceType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
10,
);
final $query = <String, List<String>>{
'resourceType': [resourceType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/instance/${Uri.encodeComponent(instanceId)}/storage-configs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListInstanceStorageConfigsResponse.fromJson(response);
}