listIntegrationAssociations method
Provides summary information about the Amazon Web Services resource associations for the specified Connect Customer instance.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter integrationArn :
The Amazon Resource Name (ARN) of the integration.
Parameter integrationType :
The integration type.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListIntegrationAssociationsResponse> listIntegrationAssociations({
required String instanceId,
String? integrationArn,
IntegrationType? integrationType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (integrationArn != null) 'integrationArn': [integrationArn],
if (integrationType != null) 'integrationType': [integrationType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/instance/${Uri.encodeComponent(instanceId)}/integration-associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIntegrationAssociationsResponse.fromJson(response);
}