listLexBots method

Future<ListLexBotsResponse> listLexBots({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
})

This API is in preview release for Connect Customer and is subject to change.

Returns a paginated list of all the Amazon Lex V1 bots currently associated with the instance. To return both Amazon Lex V1 and V2 bots, use the ListBots API.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page. If no value is specified, the default is 10.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListLexBotsResponse> listLexBots({
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/instance/${Uri.encodeComponent(instanceId)}/lex-bots',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListLexBotsResponse.fromJson(response);
}