listNotifications method

Future<ListNotificationsResponse> listNotifications({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves a paginated list of all notifications in the Amazon Connect instance.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page. Valid range is 1-100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.

Implementation

Future<ListNotificationsResponse> listNotifications({
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/notifications/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListNotificationsResponse.fromJson(response);
}