listQueueQuickConnects method

Future<ListQueueQuickConnectsResponse> listQueueQuickConnects({
  1. required String instanceId,
  2. required String queueId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists the quick connects associated with a queue.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter queueId : The identifier for the queue.

Parameter maxResults : The maximum number of results to return per page. The default MaxResult size is 100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListQueueQuickConnectsResponse> listQueueQuickConnects({
  required String instanceId,
  required String queueId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/queues/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(queueId)}/quick-connects',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListQueueQuickConnectsResponse.fromJson(response);
}