listQueues method

Future<ListQueuesResponse> listQueues({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
  4. List<QueueType>? queueTypes,
})

Provides information about the queues for the specified Connect Customer instance.

If you do not specify a QueueTypes parameter, both standard and agent queues are returned. This might cause an unexpected truncation of results if you have more than 1000 agents and you limit the number of results of the API call in code.

For more information about queues, see Queues: Standard and Agent in the Connect Customer Administrator Guide.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page. The default MaxResult size is 100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Parameter queueTypes : The type of queue.

Implementation

Future<ListQueuesResponse> listQueues({
  required String instanceId,
  int? maxResults,
  String? nextToken,
  List<QueueType>? queueTypes,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (queueTypes != null)
      'queueTypes': queueTypes.map((e) => e.value).toList(),
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/queues-summary/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListQueuesResponse.fromJson(response);
}