listQuickConnects method
Provides information about the quick connects for the specified Connect Customer instance.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Both Instance ID and Instance ARN are supported input formats.
Parameter maxResults :
The maximum number of results to return per page. The default MaxResult
size is 100.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter quickConnectTypes :
The type of quick connect. In the Connect Customer admin website, when you
create a quick connect, you are prompted to assign one of the following
types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE).
Implementation
Future<ListQuickConnectsResponse> listQuickConnects({
required String instanceId,
int? maxResults,
String? nextToken,
List<QuickConnectType>? quickConnectTypes,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (quickConnectTypes != null)
'QuickConnectTypes': quickConnectTypes.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/quick-connects/${Uri.encodeComponent(instanceId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListQuickConnectsResponse.fromJson(response);
}