listRoutingProfileManualAssignmentQueues method
Lists the manual assignment queues associated with a routing profile.
Use cases
Following are common uses cases for this API:
-
This API returns list of queues where contacts can be manually assigned or
picked by an agent who has access to the Worklist app. The user can
additionally filter on queues, if they have access to those queues
(otherwise a invalid request exception will be thrown).
For information about how manual contact assignment works in the agent workspace, see the Access the Worklist app in the Connect Customer agent workspace in the Connect Customer Administrator Guide.
- This API only returns the manual assignment queues associated with a routing profile. Use the ListRoutingProfileQueues API to list the auto assignment queues for the routing profile.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter routingProfileId :
The identifier of the routing profile.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListRoutingProfileManualAssignmentQueuesResponse>
listRoutingProfileManualAssignmentQueues({
required String instanceId,
required String routingProfileId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/manual-assignment-queues',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRoutingProfileManualAssignmentQueuesResponse.fromJson(response);
}