listSecurityProfileApplications method

Future<ListSecurityProfileApplicationsResponse> listSecurityProfileApplications({
  1. required String instanceId,
  2. required String securityProfileId,
  3. int? maxResults,
  4. String? nextToken,
})

Returns a list of third-party applications or MCP Servers in a specific security profile.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter securityProfileId : The identifier for the security profle.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListSecurityProfileApplicationsResponse>
    listSecurityProfileApplications({
  required String instanceId,
  required String securityProfileId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/security-profiles-applications/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(securityProfileId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSecurityProfileApplicationsResponse.fromJson(response);
}