listSecurityProfileFlowModules method
A list of Flow Modules an AI Agent can invoke as a tool
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter securityProfileId :
The identifier for the security profile.
Parameter maxResults :
The maximum number of results to return per page. The default MaxResult
size is 100.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListSecurityProfileFlowModulesResponse>
listSecurityProfileFlowModules({
required String instanceId,
required String securityProfileId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/security-profiles-flow-modules/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(securityProfileId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSecurityProfileFlowModulesResponse.fromJson(response);
}