listTrafficDistributionGroupUsers method

Future<ListTrafficDistributionGroupUsersResponse> listTrafficDistributionGroupUsers({
  1. required String trafficDistributionGroupId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists traffic distribution group users.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter trafficDistributionGroupId : The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListTrafficDistributionGroupUsersResponse>
    listTrafficDistributionGroupUsers({
  required String trafficDistributionGroupId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    10,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/traffic-distribution-group/${Uri.encodeComponent(trafficDistributionGroupId)}/user',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTrafficDistributionGroupUsersResponse.fromJson(response);
}