listTrafficDistributionGroups method

Future<ListTrafficDistributionGroupsResponse> listTrafficDistributionGroups({
  1. String? instanceId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists traffic distribution groups.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidRequestException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListTrafficDistributionGroupsResponse> listTrafficDistributionGroups({
  String? instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    10,
  );
  final $query = <String, List<String>>{
    if (instanceId != null) 'instanceId': [instanceId],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/traffic-distribution-groups',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTrafficDistributionGroupsResponse.fromJson(response);
}