listUseCases method

Future<ListUseCasesResponse> listUseCases({
  1. required String instanceId,
  2. required String integrationAssociationId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists the use cases for the integration association.

May throw InternalServiceException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter integrationAssociationId : The identifier for the integration association.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListUseCasesResponse> listUseCases({
  required String instanceId,
  required String integrationAssociationId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/instance/${Uri.encodeComponent(instanceId)}/integration-associations/${Uri.encodeComponent(integrationAssociationId)}/use-cases',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListUseCasesResponse.fromJson(response);
}