listUserHierarchyGroups method

Future<ListUserHierarchyGroupsResponse> listUserHierarchyGroups({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
})

Provides summary information about the hierarchy groups for the specified Connect Customer instance.

For more information about agent hierarchies, see Set Up Agent Hierarchies in the Connect Customer Administrator Guide.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page. The default MaxResult size is 100.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListUserHierarchyGroupsResponse> listUserHierarchyGroups({
  required String instanceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/user-hierarchy-groups-summary/${Uri.encodeComponent(instanceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListUserHierarchyGroupsResponse.fromJson(response);
}