listUserProficiencies method
Lists proficiencies associated with a user.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find the instance
ID in the Amazon Resource Name (ARN) of the instance.
Parameter userId :
The identifier of the user account.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListUserProficienciesResponse> listUserProficiencies({
required String instanceId,
required String userId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}/proficiencies',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListUserProficienciesResponse.fromJson(response);
}