resumeContactRecording method

Future<void> resumeContactRecording({
  1. required String contactId,
  2. required String initialContactId,
  3. required String instanceId,
  4. ContactRecordingType? contactRecordingType,
})

When a contact is being recorded, and the recording has been suspended using SuspendContactRecording, this API resumes recording whatever recording is selected in the flow configuration: call, screen, or both. If only call recording or only screen recording is enabled, then it would resume.

Voice and screen recordings are supported.

May throw InternalServiceException. May throw InvalidActiveRegionException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter contactId : The identifier of the contact.

Parameter initialContactId : The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter contactRecordingType : The type of recording being operated on.

Implementation

Future<void> resumeContactRecording({
  required String contactId,
  required String initialContactId,
  required String instanceId,
  ContactRecordingType? contactRecordingType,
}) async {
  final $payload = <String, dynamic>{
    'ContactId': contactId,
    'InitialContactId': initialContactId,
    'InstanceId': instanceId,
    if (contactRecordingType != null)
      'ContactRecordingType': contactRecordingType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/contact/resume-recording',
    exceptionFnMap: _exceptionFns,
  );
}