searchContactFlowModules method
Searches the flow modules in an Connect Customer instance, with optional filtering.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find the instance
ID in the Amazon Resource Name (ARN) of the instance.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter searchCriteria :
The search criteria to be used to return flow modules.
Parameter searchFilter :
Filters to be applied to search results.
Implementation
Future<SearchContactFlowModulesResponse> searchContactFlowModules({
required String instanceId,
int? maxResults,
String? nextToken,
ContactFlowModuleSearchCriteria? searchCriteria,
ContactFlowModuleSearchFilter? searchFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'InstanceId': instanceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchCriteria != null) 'SearchCriteria': searchCriteria,
if (searchFilter != null) 'SearchFilter': searchFilter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/search-contact-flow-modules',
exceptionFnMap: _exceptionFns,
);
return SearchContactFlowModulesResponse.fromJson(response);
}