searchDataTables method
Searches for data tables based on the table's ID, name, and description. In the future, this operation can support searching on attribute names and possibly primary values. Follows other search operations closely and supports both search criteria and filters.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The unique identifier for the Amazon Connect instance to search within.
Parameter maxResults :
The maximum number of data tables to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter searchCriteria :
Search criteria including string conditions for matching table names,
descriptions, or resource IDs. Supports STARTS_WITH, CONTAINS, and EXACT
comparison types.
Parameter searchFilter :
Optional filters to apply to the search results, such as tag-based
filtering for attribute-based access control.
Implementation
Future<SearchDataTablesResponse> searchDataTables({
required String instanceId,
int? maxResults,
String? nextToken,
DataTableSearchCriteria? searchCriteria,
DataTableSearchFilter? searchFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'InstanceId': instanceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchCriteria != null) 'SearchCriteria': searchCriteria,
if (searchFilter != null) 'SearchFilter': searchFilter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/search-data-tables',
exceptionFnMap: _exceptionFns,
);
return SearchDataTablesResponse.fromJson(response);
}