searchEvaluationForms method

Future<SearchEvaluationFormsResponse> searchEvaluationForms({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
  4. EvaluationFormSearchCriteria? searchCriteria,
  5. EvaluationFormSearchFilter? searchFilter,
})

Searches evaluation forms in an Connect Customer instance, with optional filtering.

Use cases

Following are common uses cases for this API:

  • List all evaluation forms in an instance.
  • Find all evaluation forms that meet specific criteria, such as Title, Description, Status, and more.
  • Find all evaluation forms that are tagged with a specific set of tags.
Important things to know
  • A Search operation, unlike a List operation, takes time to index changes to resource (create, update or delete). If you don't see updated information for recently changed contact evaluations, try calling the API again in a few seconds.
Endpoints: See Connect Customer endpoints and quotas.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Parameter searchCriteria : The search criteria to be used to return evaluation forms.

Parameter searchFilter : Filters to be applied to search results.

Implementation

Future<SearchEvaluationFormsResponse> searchEvaluationForms({
  required String instanceId,
  int? maxResults,
  String? nextToken,
  EvaluationFormSearchCriteria? searchCriteria,
  EvaluationFormSearchFilter? searchFilter,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    'InstanceId': instanceId,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (searchCriteria != null) 'SearchCriteria': searchCriteria,
    if (searchFilter != null) 'SearchFilter': searchFilter,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/search-evaluation-forms',
    exceptionFnMap: _exceptionFns,
  );
  return SearchEvaluationFormsResponse.fromJson(response);
}