searchHoursOfOperationOverrides method
Searches the hours of operation overrides.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter searchCriteria :
The search criteria to be used to return hours of operations overrides.
Implementation
Future<SearchHoursOfOperationOverridesResponse>
searchHoursOfOperationOverrides({
required String instanceId,
int? maxResults,
String? nextToken,
HoursOfOperationOverrideSearchCriteria? searchCriteria,
HoursOfOperationSearchFilter? searchFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'InstanceId': instanceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchCriteria != null) 'SearchCriteria': searchCriteria,
if (searchFilter != null) 'SearchFilter': searchFilter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/search-hours-of-operation-overrides',
exceptionFnMap: _exceptionFns,
);
return SearchHoursOfOperationOverridesResponse.fromJson(response);
}