searchPredefinedAttributes method
Searches predefined attributes that meet certain criteria. A predefined attribute is made up of a name and a value. You can use predefined attributes for:
- Routing proficiency (for example, agent certification) that has predefined values (for example, a list of possible certifications). For more information, see Create predefined attributes for routing contacts to agents.
- Contact information that varies between transfers or conferences, such as the name of the business unit handling the contact. For more information, see Use contact segment attributes.
Endpoints: See Connect Customer endpoints and quotas.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find the instance
ID in the Amazon Resource Name (ARN) of the instance.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter searchCriteria :
The search criteria to be used to return predefined attributes.
Implementation
Future<SearchPredefinedAttributesResponse> searchPredefinedAttributes({
required String instanceId,
int? maxResults,
String? nextToken,
PredefinedAttributeSearchCriteria? searchCriteria,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'InstanceId': instanceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchCriteria != null) 'SearchCriteria': searchCriteria,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/search-predefined-attributes',
exceptionFnMap: _exceptionFns,
);
return SearchPredefinedAttributesResponse.fromJson(response);
}