searchRules method

Future<SearchRulesResponse> searchRules({
  1. required String instanceId,
  2. int? maxResults,
  3. String? nextToken,
  4. RulesSearchCriteria? searchCriteria,
  5. RulesSearchFilter? searchFilter,
})

Searches rules in an Connect Customer instance, with optional filtering.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Parameter searchCriteria : The search criteria to be used to return rules.

Parameter searchFilter : Filters to be applied to search results, such as tag-based filters.

Implementation

Future<SearchRulesResponse> searchRules({
  required String instanceId,
  int? maxResults,
  String? nextToken,
  RulesSearchCriteria? searchCriteria,
  RulesSearchFilter? searchFilter,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    200,
  );
  final $payload = <String, dynamic>{
    'InstanceId': instanceId,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (searchCriteria != null) 'SearchCriteria': searchCriteria,
    if (searchFilter != null) 'SearchFilter': searchFilter,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/search-rules',
    exceptionFnMap: _exceptionFns,
  );
  return SearchRulesResponse.fromJson(response);
}