searchViews method
Searches views based on name, description, or tags.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter searchCriteria :
The search criteria, including field names and comparison types.
Parameter searchFilter :
Filters to apply to the search, such as tag-based filters.
Implementation
Future<SearchViewsResponse> searchViews({
required String instanceId,
int? maxResults,
String? nextToken,
ViewSearchCriteria? searchCriteria,
ViewSearchFilter? searchFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'InstanceId': instanceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchCriteria != null) 'SearchCriteria': searchCriteria,
if (searchFilter != null) 'SearchFilter': searchFilter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/search-views',
exceptionFnMap: _exceptionFns,
);
return SearchViewsResponse.fromJson(response);
}