startTaskContact method
- required String instanceId,
- required String name,
- List<
TaskAttachment> ? attachments, - Map<
String, String> ? attributes, - String? clientToken,
- String? contactFlowId,
- String? description,
- String? previousContactId,
- String? quickConnectId,
- Map<
String, Reference> ? references, - DateTime? scheduledTime,
- Map<
String, SegmentAttributeValue> ? segmentAttributes, - String? taskTemplateId,
Initiates a flow to start a new task contact. For more information about task contacts, see Concepts: Tasks in Connect Customer in the Connect Customer Administrator Guide.
When using PreviousContactId and
RelatedContactId input parameters, note the following:
-
PreviousContactId-
Any updates to user-defined task contact attributes on any contact linked
through the same
PreviousContactIdwill affect every contact in the chain. -
There can be a maximum of 12 linked task contacts in a chain. That is, 12
task contacts can be created that share the same
PreviousContactId.
-
Any updates to user-defined task contact attributes on any contact linked
through the same
-
RelatedContactId- Copies contact attributes from the related task contact to the new contact.
- Any update on attributes in a new task contact does not update attributes on previous contact.
-
There’s no limit on the number of task contacts that can be created that
use the same
RelatedContactId.
ContactFlowID, QuickConnectID, or
TaskTemplateID. Only one parameter is required as long as the
task template has a flow configured to run it. If more than one parameter
is specified, or only the TaskTemplateID is specified but it
does not have a flow configured, the request returns an error because
Connect Customer cannot identify the unique flow to run when the task is
created.
A ServiceQuotaExceededException occurs when the number of
open tasks exceeds the active tasks quota or there are already 12 tasks
referencing the same PreviousContactId. For more information
about service quotas for task contacts, see Connect
Customer service quotas in the Connect Customer Administrator
Guide.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter name :
The name of a task that is shown to an agent in the Contact Control Panel
(CCP).
Parameter attachments :
List of S3 presigned URLs of task attachments and their file name. You can
have a maximum of 5 attachments per task.
Parameter attributes :
A custom key-value pair using an attribute map. The attributes are
standard Connect Customer attributes, and can be accessed in flows just
like any other contact attributes.
There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. If not provided, the Amazon Web Services SDK
populates this field. For more information about idempotency, see Making
retries safe with idempotent APIs.
Parameter contactFlowId :
The identifier of the flow for initiating the tasks. To see the
ContactFlowId in the Connect Customer admin website, on the navigation
menu go to Routing, Flows. Choose the flow. On the flow
page, under the name of the flow, choose Show additional flow
information. The ContactFlowId is the last part of the ARN, shown here
in bold:
arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx
Parameter description :
A description of the task that is shown to an agent in the Contact Control
Panel (CCP).
Parameter previousContactId :
The identifier of the previous chat, voice, or task contact. Any updates
to user-defined attributes to task contacts linked using the same
PreviousContactID will affect every contact in the chain.
There can be a maximum of 12 linked task contacts in a chain.
Parameter quickConnectId :
The identifier for the quick connect. Tasks that are created by using
QuickConnectId will use the flow that is defined on agent or
queue quick connect. For more information about quick connects, see Create
quick connects.
Parameter references :
A formatted URL that is shown to an agent in the Contact Control Panel
(CCP). Tasks can have the following reference types at the time of
creation: URL | NUMBER | STRING |
DATE | EMAIL. ATTACHMENT is not a
supported reference type during task creation.
Parameter relatedContactId :
The contactId that is related
to this contact. Linking tasks together by using
RelatedContactID copies over contact attributes from the
related task contact to the new task contact. All updates to user-defined
attributes in the new task contact are limited to the individual contact
ID, unlike what happens when tasks are linked by using
PreviousContactID. There are no limits to the number of
contacts that can be linked by using RelatedContactId.
Parameter scheduledTime :
The timestamp, in Unix Epoch seconds format, at which to start running the
inbound flow. The scheduled time cannot be in the past. It must be within
up to 6 days in future.
Parameter segmentAttributes :
A set of system defined key-value pairs stored on individual contact
segments (unique contact ID) using an attribute map. The attributes are
standard Connect Customer attributes. They can be accessed in flows.
Attribute keys can include only alphanumeric, -, and _.
This field can be used to set Contact Expiry as a duration in minutes and set a UserId for the User who created a task.
To set the created by user, a valid AgentResourceId must be supplied, with
SegmentAttributes like { "connect:CreatedByUser" {
"ValueString":
"arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/agent/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"}}}.
Parameter taskTemplateId :
A unique identifier for the task template. For more information about task
templates, see Create
task templates in the Connect Customer Administrator Guide.
Implementation
Future<StartTaskContactResponse> startTaskContact({
required String instanceId,
required String name,
List<TaskAttachment>? attachments,
Map<String, String>? attributes,
String? clientToken,
String? contactFlowId,
String? description,
String? previousContactId,
String? quickConnectId,
Map<String, Reference>? references,
String? relatedContactId,
DateTime? scheduledTime,
Map<String, SegmentAttributeValue>? segmentAttributes,
String? taskTemplateId,
}) async {
final $payload = <String, dynamic>{
'InstanceId': instanceId,
'Name': name,
if (attachments != null) 'Attachments': attachments,
if (attributes != null) 'Attributes': attributes,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (contactFlowId != null) 'ContactFlowId': contactFlowId,
if (description != null) 'Description': description,
if (previousContactId != null) 'PreviousContactId': previousContactId,
if (quickConnectId != null) 'QuickConnectId': quickConnectId,
if (references != null) 'References': references,
if (relatedContactId != null) 'RelatedContactId': relatedContactId,
if (scheduledTime != null)
'ScheduledTime': unixTimestampToJson(scheduledTime),
if (segmentAttributes != null) 'SegmentAttributes': segmentAttributes,
if (taskTemplateId != null) 'TaskTemplateId': taskTemplateId,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/contact/task',
exceptionFnMap: _exceptionFns,
);
return StartTaskContactResponse.fromJson(response);
}