startTestCaseExecution method

Future<StartTestCaseExecutionResponse> startTestCaseExecution({
  1. required String instanceId,
  2. required String testCaseId,
  3. String? clientToken,
})

Starts executing a published test case.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Amazon Connect instance.

Parameter testCaseId : The identifier of the test case to execute.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Implementation

Future<StartTestCaseExecutionResponse> startTestCaseExecution({
  required String instanceId,
  required String testCaseId,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/test-cases/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(testCaseId)}/start-execution',
    exceptionFnMap: _exceptionFns,
  );
  return StartTestCaseExecutionResponse.fromJson(response);
}