stopContactStreaming method

Future<void> stopContactStreaming({
  1. required String contactId,
  2. required String instanceId,
  3. required String streamingId,
})

Ends message streaming on a specified contact. To restart message streaming on that contact, call the StartContactStreaming API.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter contactId : The identifier of the contact. This is the identifier of the contact that is associated with the first interaction with the contact center.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter streamingId : The identifier of the streaming configuration enabled.

Implementation

Future<void> stopContactStreaming({
  required String contactId,
  required String instanceId,
  required String streamingId,
}) async {
  final $payload = <String, dynamic>{
    'ContactId': contactId,
    'InstanceId': instanceId,
    'StreamingId': streamingId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/contact/stop-streaming',
    exceptionFnMap: _exceptionFns,
  );
}