stopTestCaseExecution method

Future<void> stopTestCaseExecution({
  1. required String instanceId,
  2. required String testCaseExecutionId,
  3. required String testCaseId,
  4. String? clientToken,
})

Stops a running test execution.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Amazon Connect instance.

Parameter testCaseExecutionId : The identifier of the test case execution to stop.

Parameter testCaseId : The identifier of the test case.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Implementation

Future<void> stopTestCaseExecution({
  required String instanceId,
  required String testCaseExecutionId,
  required String testCaseId,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/test-cases/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(testCaseId)}/${Uri.encodeComponent(testCaseExecutionId)}/stop-execution',
    exceptionFnMap: _exceptionFns,
  );
}