suspendContactRecording method
When a contact is being recorded, this API suspends recording whatever is selected in the flow configuration: call (IVR or agent), screen, or both. If only call recording or only screen recording is enabled, then it would be suspended. For example, you might suspend the screen recording while collecting sensitive information, such as a credit card number. Then use ResumeContactRecording to restart recording the screen.
The period of time that the recording is suspended is filled with silence in the final recording.
Voice (IVR, agent) and screen recordings are supported.
May throw InternalServiceException.
May throw InvalidActiveRegionException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter contactId :
The identifier of the contact.
Parameter initialContactId :
The identifier of the contact. This is the identifier of the contact
associated with the first interaction with the contact center.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter contactRecordingType :
The type of recording being operated on.
Implementation
Future<void> suspendContactRecording({
required String contactId,
required String initialContactId,
required String instanceId,
ContactRecordingType? contactRecordingType,
}) async {
final $payload = <String, dynamic>{
'ContactId': contactId,
'InitialContactId': initialContactId,
'InstanceId': instanceId,
if (contactRecordingType != null)
'ContactRecordingType': contactRecordingType.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/contact/suspend-recording',
exceptionFnMap: _exceptionFns,
);
}