updateContactFlowContent method

Future<void> updateContactFlowContent({
  1. required String contactFlowId,
  2. required String content,
  3. required String instanceId,
})

Updates the specified flow.

You can also create and update flows using the Connect Customer Flow language.

Use the $SAVED alias in the request to describe the SAVED content of a Flow. For example, arn:aws:.../contact-flow/{id}:$SAVED. After a flow is published, $SAVED needs to be supplied to view saved content that has not been published.

May throw InternalServiceException. May throw InvalidContactFlowException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactFlowId : The identifier of the flow.

Parameter content : The JSON string that represents the content of the flow. For an example, see Example flow in Connect Customer Flow language.

Length Constraints: Minimum length of 1. Maximum length of 256000.

Parameter instanceId : The identifier of the Connect Customer instance.

Implementation

Future<void> updateContactFlowContent({
  required String contactFlowId,
  required String content,
  required String instanceId,
}) async {
  final $payload = <String, dynamic>{
    'Content': content,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/contact-flows/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowId)}/content',
    exceptionFnMap: _exceptionFns,
  );
}