updateContactSchedule method

Future<void> updateContactSchedule({
  1. required String contactId,
  2. required String instanceId,
  3. required DateTime scheduledTime,
})

Updates the scheduled time of a task contact that is already scheduled.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter contactId : The identifier of the contact.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter scheduledTime : The timestamp, in Unix Epoch seconds format, at which to start running the inbound flow. The scheduled time cannot be in the past. It must be within up to 6 days in future.

Implementation

Future<void> updateContactSchedule({
  required String contactId,
  required String instanceId,
  required DateTime scheduledTime,
}) async {
  final $payload = <String, dynamic>{
    'ContactId': contactId,
    'InstanceId': instanceId,
    'ScheduledTime': unixTimestampToJson(scheduledTime),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/contact/schedule',
    exceptionFnMap: _exceptionFns,
  );
}