updateParticipantRoleConfig method

Future<void> updateParticipantRoleConfig({
  1. required UpdateParticipantRoleConfigChannelInfo channelConfiguration,
  2. required String contactId,
  3. required String instanceId,
})

Updates timeouts for when human chat participants are to be considered idle, and when agents are automatically disconnected from a chat due to idleness. You can set four timers:

  • Customer idle timeout
  • Customer auto-disconnect timeout
  • Agent idle timeout
  • Agent auto-disconnect timeout
For more information about how chat timeouts work, see Set up chat timeouts for human participants.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter channelConfiguration : The Connect Customer channel you want to configure.

Parameter contactId : The identifier of the contact in this instance of Connect Customer.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Implementation

Future<void> updateParticipantRoleConfig({
  required UpdateParticipantRoleConfigChannelInfo channelConfiguration,
  required String contactId,
  required String instanceId,
}) async {
  final $payload = <String, dynamic>{
    'ChannelConfiguration': channelConfiguration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/contact/participant-role-config/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactId)}',
    exceptionFnMap: _exceptionFns,
  );
}