updateQueueMaxContacts method
Updates the maximum number of contacts allowed in a queue before it is considered full.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter queueId :
The identifier for the queue.
Parameter maxContacts :
The maximum number of contacts that can be in the queue before it is
considered full.
Implementation
Future<void> updateQueueMaxContacts({
required String instanceId,
required String queueId,
int? maxContacts,
}) async {
_s.validateNumRange(
'maxContacts',
maxContacts,
0,
1152921504606846976,
);
final $payload = <String, dynamic>{
if (maxContacts != null) 'MaxContacts': maxContacts,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/queues/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(queueId)}/max-contacts',
exceptionFnMap: _exceptionFns,
);
}