updateQueueOutboundCallerConfig method
Updates the outbound caller ID name, number, and outbound whisper flow for a specified queue.
-
If the phone number is claimed to a traffic distribution group that was
created in the same Region as the Connect Customer instance where you are
calling this API, then you can use a full phone number ARN or a UUID for
OutboundCallerIdNumberId. However, if the phone number is claimed to a traffic distribution group that is in one Region, and you are calling this API from an instance in another Amazon Web Services Region that is associated with the traffic distribution group, you must provide a full phone number ARN. If a UUID is provided in this scenario, you will receive aResourceNotFoundException. -
Only use the phone number ARN format that doesn't contain
instancein the path, for example,arn:aws:connect:us-east-1:1234567890:phone-number/uuid. This is the same ARN format that is returned when you call the ListPhoneNumbersV2 API. - If you plan to use IAM policies to allow/deny access to this API for phone number resources claimed to a traffic distribution group, see Allow or Deny queue API actions for phone numbers in a replica Region.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter outboundCallerConfig :
The outbound caller ID name, number, and outbound whisper flow.
Parameter queueId :
The identifier for the queue.
Implementation
Future<void> updateQueueOutboundCallerConfig({
required String instanceId,
required OutboundCallerConfig outboundCallerConfig,
required String queueId,
}) async {
final $payload = <String, dynamic>{
'OutboundCallerConfig': outboundCallerConfig,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/queues/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(queueId)}/outbound-caller-config',
exceptionFnMap: _exceptionFns,
);
}