updateRoutingProfileAgentAvailabilityTimer method

Future<void> updateRoutingProfileAgentAvailabilityTimer({
  1. required AgentAvailabilityTimer agentAvailabilityTimer,
  2. required String instanceId,
  3. required String routingProfileId,
})

Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter agentAvailabilityTimer : Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter routingProfileId : The identifier of the routing profile.

Implementation

Future<void> updateRoutingProfileAgentAvailabilityTimer({
  required AgentAvailabilityTimer agentAvailabilityTimer,
  required String instanceId,
  required String routingProfileId,
}) async {
  final $payload = <String, dynamic>{
    'AgentAvailabilityTimer': agentAvailabilityTimer.value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/agent-availability-timer',
    exceptionFnMap: _exceptionFns,
  );
}