updateRoutingProfileConcurrency method
Updates the channels that agents can handle in the Contact Control Panel (CCP) for a routing profile.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter mediaConcurrencies :
The channels that agents can handle in the Contact Control Panel (CCP).
Parameter routingProfileId :
The identifier of the routing profile.
Implementation
Future<void> updateRoutingProfileConcurrency({
required String instanceId,
required List<MediaConcurrency> mediaConcurrencies,
required String routingProfileId,
}) async {
final $payload = <String, dynamic>{
'MediaConcurrencies': mediaConcurrencies,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/concurrency',
exceptionFnMap: _exceptionFns,
);
}