updateRoutingProfileQueues method

Future<void> updateRoutingProfileQueues({
  1. required String instanceId,
  2. required List<RoutingProfileQueueConfig> queueConfigs,
  3. required String routingProfileId,
})

Updates the properties associated with a set of queues for a routing profile.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter queueConfigs : The queues to be updated for this routing profile. Queues must first be associated to the routing profile. You can do this using AssociateRoutingProfileQueues.

Parameter routingProfileId : The identifier of the routing profile.

Implementation

Future<void> updateRoutingProfileQueues({
  required String instanceId,
  required List<RoutingProfileQueueConfig> queueConfigs,
  required String routingProfileId,
}) async {
  final $payload = <String, dynamic>{
    'QueueConfigs': queueConfigs,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/queues',
    exceptionFnMap: _exceptionFns,
  );
}