updateUserConfig method
- required String instanceId,
- required String userId,
- List<
AfterContactWorkConfigPerChannel> ? afterContactWorkConfigs, - List<
AutoAcceptConfig> ? autoAcceptConfigs, - List<
PersistentConnectionConfig> ? persistentConnectionConfigs, - List<
PhoneNumberConfig> ? phoneNumberConfigs, - List<
VoiceEnhancementConfig> ? voiceEnhancementConfigs,
Updates the configuration settings for the specified user, including per-channel auto-accept and after contact work (ACW) timeout settings.
May throw ConditionalOperationFailedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter userId :
The identifier of the user account.
Parameter afterContactWorkConfigs :
The list of after contact work (ACW) timeout configuration settings for
each channel. ACW timeout specifies how many seconds agents have for after
contact work, such as entering notes about the contact. The minimum
setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter
0 for an indefinite amount of time, meaning agents must manually choose to
end ACW.
Parameter autoAcceptConfigs :
The list of auto-accept configuration settings for each channel. When
auto-accept is enabled for a channel, available agents are automatically
connected to contacts from that channel without needing to manually
accept. Auto-accept connects agents to contacts in less than one second.
Parameter persistentConnectionConfigs :
The list of persistent connection configuration settings for each channel.
Parameter phoneNumberConfigs :
The list of phone number configuration settings for each channel.
Parameter voiceEnhancementConfigs :
The list of voice enhancement configuration settings for each channel.
Implementation
Future<void> updateUserConfig({
required String instanceId,
required String userId,
List<AfterContactWorkConfigPerChannel>? afterContactWorkConfigs,
List<AutoAcceptConfig>? autoAcceptConfigs,
List<PersistentConnectionConfig>? persistentConnectionConfigs,
List<PhoneNumberConfig>? phoneNumberConfigs,
List<VoiceEnhancementConfig>? voiceEnhancementConfigs,
}) async {
final $payload = <String, dynamic>{
if (afterContactWorkConfigs != null)
'AfterContactWorkConfigs': afterContactWorkConfigs,
if (autoAcceptConfigs != null) 'AutoAcceptConfigs': autoAcceptConfigs,
if (persistentConnectionConfigs != null)
'PersistentConnectionConfigs': persistentConnectionConfigs,
if (phoneNumberConfigs != null) 'PhoneNumberConfigs': phoneNumberConfigs,
if (voiceEnhancementConfigs != null)
'VoiceEnhancementConfigs': voiceEnhancementConfigs,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}/config',
exceptionFnMap: _exceptionFns,
);
}