updateUserSecurityProfiles method

Future<void> updateUserSecurityProfiles({
  1. required String instanceId,
  2. required List<String> securityProfileIds,
  3. required String userId,
})

Assigns the specified security profiles to the specified user.

May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter securityProfileIds : The identifiers of the security profiles for the user.

Parameter userId : The identifier of the user account.

Implementation

Future<void> updateUserSecurityProfiles({
  required String instanceId,
  required List<String> securityProfileIds,
  required String userId,
}) async {
  final $payload = <String, dynamic>{
    'SecurityProfileIds': securityProfileIds,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}/security-profiles',
    exceptionFnMap: _exceptionFns,
  );
}