updateWorkspacePage method
Updates the configuration of a page in a workspace, including the associated view and input data.
May throw AccessDeniedException.
May throw DuplicateResourceException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter page :
The current page identifier.
Parameter workspaceId :
The identifier of the workspace.
Parameter inputData :
A JSON string containing input parameters for the view.
Parameter newPage :
The new page identifier, if changing the page name.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the view to associate with the page.
Parameter slug :
The URL-friendly identifier for the page.
Implementation
Future<void> updateWorkspacePage({
required String instanceId,
required String page,
required String workspaceId,
String? inputData,
String? newPage,
String? resourceArn,
String? slug,
}) async {
final $payload = <String, dynamic>{
if (inputData != null) 'InputData': inputData,
if (newPage != null) 'NewPage': newPage,
if (resourceArn != null) 'ResourceArn': resourceArn,
if (slug != null) 'Slug': slug,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/workspaces/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(workspaceId)}/pages/${Uri.encodeComponent(page)}',
exceptionFnMap: _exceptionFns,
);
}