updateWorkspaceTheme method

Future<void> updateWorkspaceTheme({
  1. required String instanceId,
  2. required String workspaceId,
  3. WorkspaceTheme? theme,
})

Updates the theme configuration for a workspace, including colors and styling.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Parameter workspaceId : The identifier of the workspace.

Parameter theme : The theme configuration, including color schemes and visual styles.

Implementation

Future<void> updateWorkspaceTheme({
  required String instanceId,
  required String workspaceId,
  WorkspaceTheme? theme,
}) async {
  final $payload = <String, dynamic>{
    if (theme != null) 'Theme': theme,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/workspaces/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(workspaceId)}/theme',
    exceptionFnMap: _exceptionFns,
  );
}