updateWorkspaceVisibility method
Updates the visibility setting of a workspace, controlling whether it is available to all users, assigned users only, or none.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter visibility :
The visibility setting for the workspace. Valid values are:
ALL (available to all users), ASSIGNED
(available only to assigned users and routing profiles), and
NONE (not visible to any users).
Parameter workspaceId :
The identifier of the workspace.
Implementation
Future<void> updateWorkspaceVisibility({
required String instanceId,
required Visibility visibility,
required String workspaceId,
}) async {
final $payload = <String, dynamic>{
'Visibility': visibility.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/workspaces/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(workspaceId)}/visibility',
exceptionFnMap: _exceptionFns,
);
}