putProfileOutboundRequestBatch method

Future<PutProfileOutboundRequestBatchResponse> putProfileOutboundRequestBatch({
  1. required String id,
  2. required List<ProfileOutboundRequest> profileOutboundRequests,
})

Takes in a list of profile outbound requests to be placed as part of an outbound campaign. This API is idempotent.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw InvalidCampaignStateException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<PutProfileOutboundRequestBatchResponse>
    putProfileOutboundRequestBatch({
  required String id,
  required List<ProfileOutboundRequest> profileOutboundRequests,
}) async {
  final $payload = <String, dynamic>{
    'profileOutboundRequests': profileOutboundRequests,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v2/campaigns/${Uri.encodeComponent(id)}/profile-outbound-requests',
    exceptionFnMap: _exceptionFns,
  );
  return PutProfileOutboundRequestBatchResponse.fromJson(response);
}