ConnectCases class

With Amazon Connect Cases, your agents can track and manage customer issues that require multiple interactions, follow-up tasks, and teams in your contact center. A case represents a customer issue. It records the issue, the steps and interactions taken to resolve the issue, and the outcome. For more information, see Amazon Connect Cases in the Amazon Connect Administrator Guide.

Constructors

ConnectCases({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetCaseRule({required List<CaseRuleIdentifier> caseRules, required String domainId}) Future<BatchGetCaseRuleResponse>
Gets a batch of case rules. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
batchGetField({required String domainId, required List<FieldIdentifier> fields}) Future<BatchGetFieldResponse>
Returns the description for the list of fields in the request parameters.
batchPutFieldOptions({required String domainId, required String fieldId, required List<FieldOption> options}) Future<BatchPutFieldOptionsResponse>
Creates and updates a set of field options for a single select field in a Cases domain.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCase({required String domainId, required List<FieldValue> fields, required String templateId, String? clientToken, UserUnion? performedBy, Map<String, String>? tags}) Future<CreateCaseResponse>
When creating a case from a template that has tag propagation configurations, the specified tags are automatically applied to the case.
createCaseRule({required String domainId, required String name, required CaseRuleDetails rule, String? description}) Future<CreateCaseRuleResponse>
Creates a new case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
createDomain({required String name}) Future<CreateDomainResponse>
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts. Each Amazon Connect instance can be associated with only one Cases domain.
createField({required String domainId, required String name, required FieldType type, FieldAttributes? attributes, String? description}) Future<CreateFieldResponse>
Creates a field in the Cases domain. This field is used to define the case object model (that is, defines what data can be captured on cases) in a Cases domain.
createLayout({required LayoutContent content, required String domainId, required String name}) Future<CreateLayoutResponse>
Creates a layout in the Cases domain. Layouts define the following configuration in the top section and More Info tab of the Cases user interface:
createRelatedItem({required String caseId, required RelatedItemInputContent content, required String domainId, required RelatedItemType type, UserUnion? performedBy}) Future<CreateRelatedItemResponse>
Creates a related item (comments, tasks, and contacts) and associates it with a case.
createTemplate({required String domainId, required String name, String? description, LayoutConfiguration? layoutConfiguration, List<RequiredField>? requiredFields, List<TemplateRule>? rules, TemplateStatus? status, List<TagPropagationConfiguration>? tagPropagationConfigurations}) Future<CreateTemplateResponse>
Creates a template in the Cases domain. This template is used to define the case object model (that is, to define what data can be captured on cases) in a Cases domain. A template must have a unique name within a domain, and it must reference existing field IDs and layout IDs. Additionally, multiple fields with same IDs are not allowed within the same Template. A template can be either Active or Inactive, as indicated by its status. Inactive templates cannot be used to create cases.
deleteCase({required String caseId, required String domainId}) Future<void>
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store. After a successful deletion, you cannot:
deleteCaseRule({required String caseRuleId, required String domainId}) Future<void>
Deletes a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
deleteDomain({required String domainId}) Future<void>
Deletes a Cases domain.
deleteField({required String domainId, required String fieldId}) Future<void>
Deletes a field from a cases template.
deleteLayout({required String domainId, required String layoutId}) Future<void>
Deletes a layout from a cases template. You can delete up to 100 layouts per domain.
deleteRelatedItem({required String caseId, required String domainId, required String relatedItemId}) Future<void>
Deletes the related item resource under a case.
deleteTemplate({required String domainId, required String templateId}) Future<void>
Deletes a cases template. You can delete up to 100 templates per domain.
getCase({required String caseId, required String domainId, required List<FieldIdentifier> fields, String? nextToken}) Future<GetCaseResponse>
Returns information about a specific case if it exists.
getCaseAuditEvents({required String caseId, required String domainId, int? maxResults, String? nextToken}) Future<GetCaseAuditEventsResponse>
Returns the audit history about a specific case if it exists.
getCaseEventConfiguration({required String domainId}) Future<GetCaseEventConfigurationResponse>
Returns the case event publishing configuration.
getDomain({required String domainId}) Future<GetDomainResponse>
Returns information about a specific domain if it exists.
getLayout({required String domainId, required String layoutId}) Future<GetLayoutResponse>
Returns the details for the requested layout.
getTemplate({required String domainId, required String templateId}) Future<GetTemplateResponse>
Returns the details for the requested template. Other template APIs are:
listCaseRules({required String domainId, int? maxResults, String? nextToken}) Future<ListCaseRulesResponse>
Lists all case rules in a Cases domain. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
listCasesForContact({required String contactArn, required String domainId, int? maxResults, String? nextToken}) Future<ListCasesForContactResponse>
Lists cases for a given contact.
listDomains({int? maxResults, String? nextToken}) Future<ListDomainsResponse>
Lists all cases domains in the Amazon Web Services account. Each list item is a condensed summary object of the domain.
listFieldOptions({required String domainId, required String fieldId, int? maxResults, String? nextToken, List<String>? values}) Future<ListFieldOptionsResponse>
Lists all of the field options for a field identifier in the domain.
listFields({required String domainId, int? maxResults, String? nextToken}) Future<ListFieldsResponse>
Lists all fields in a Cases domain.
listLayouts({required String domainId, int? maxResults, String? nextToken}) Future<ListLayoutsResponse>
Lists all layouts in the given cases domain. Each list item is a condensed summary object of the layout.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Lists tags for a resource.
listTemplates({required String domainId, int? maxResults, String? nextToken, List<TemplateStatus>? status}) Future<ListTemplatesResponse>
Lists all of the templates in a Cases domain. Each list item is a condensed summary object of the template.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putCaseEventConfiguration({required String domainId, required EventBridgeConfiguration eventBridge}) Future<void>
Adds case event publishing configuration. For a complete list of fields you can add to the event message, see Create case fields in the Amazon Connect Administrator Guide
searchAllRelatedItems({required String domainId, List<RelatedItemTypeFilter>? filters, int? maxResults, String? nextToken, List<SearchAllRelatedItemsSort>? sorts}) Future<SearchAllRelatedItemsResponse>
Searches for related items across all cases within a domain. This is a global search operation that returns related items from multiple cases, unlike the case-specific SearchRelatedItems API.
searchCases({required String domainId, List<FieldIdentifier>? fields, CaseFilter? filter, int? maxResults, String? nextToken, String? searchTerm, List<Sort>? sorts}) Future<SearchCasesResponse>
Searches for cases within their associated Cases domain. Search results are returned as a paginated list of abridged case documents.
searchRelatedItems({required String caseId, required String domainId, List<RelatedItemTypeFilter>? filters, int? maxResults, String? nextToken}) Future<SearchRelatedItemsResponse>
Searches for related items that are associated with a case.
tagResource({required String arn, required Map<String, String> tags}) Future<void>
Adds tags to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, required List<String> tagKeys}) Future<void>
Untags a resource.
updateCase({required String caseId, required String domainId, required List<FieldValue> fields, UserUnion? performedBy}) Future<void>
CreateCase
updateCaseRule({required String caseRuleId, required String domainId, String? description, String? name, CaseRuleDetails? rule}) Future<void>
Updates a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
updateField({required String domainId, required String fieldId, FieldAttributes? attributes, String? description, String? name}) Future<void>
Updates the properties of an existing field.
updateLayout({required String domainId, required String layoutId, LayoutContent? content, String? name}) Future<void>
Updates the attributes of an existing layout.
updateRelatedItem({required String caseId, required RelatedItemUpdateContent content, required String domainId, required String relatedItemId, UserUnion? performedBy}) Future<UpdateRelatedItemResponse>
Updates the content of a related item associated with a case. The following related item types are supported:
updateTemplate({required String domainId, required String templateId, String? description, LayoutConfiguration? layoutConfiguration, String? name, List<RequiredField>? requiredFields, List<TemplateRule>? rules, TemplateStatus? status, List<TagPropagationConfiguration>? tagPropagationConfigurations}) Future<void>
Updates the attributes of an existing template. The template attributes that can be modified include name, description, layoutConfiguration, requiredFields, and status. At least one of these attributes must not be null. If a null value is provided for a given attribute, that attribute is ignored and its current value is preserved.

Operators

operator ==(Object other) bool
The equality operator.
inherited