batchPutFieldOptions method

Future<BatchPutFieldOptionsResponse> batchPutFieldOptions({
  1. required String domainId,
  2. required String fieldId,
  3. required List<FieldOption> options,
})

Creates and updates a set of field options for a single select field in a Cases domain.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The unique identifier of the Cases domain.

Parameter fieldId : The unique identifier of a field.

Parameter options : A list of FieldOption objects.

Implementation

Future<BatchPutFieldOptionsResponse> batchPutFieldOptions({
  required String domainId,
  required String fieldId,
  required List<FieldOption> options,
}) async {
  final $payload = <String, dynamic>{
    'options': options,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/domains/${Uri.encodeComponent(domainId)}/fields/${Uri.encodeComponent(fieldId)}/options',
    exceptionFnMap: _exceptionFns,
  );
  return BatchPutFieldOptionsResponse.fromJson(response);
}