deleteField method

Future<void> deleteField({
  1. required String domainId,
  2. required String fieldId,
})

Deletes a field from a cases template.

After a field is deleted:

  • You can still retrieve the field by calling BatchGetField.
  • You cannot update a deleted field by calling UpdateField; it throws a ValidationException.
  • Deleted fields are not included in the ListFields response.
  • Calling CreateCase with a deleted field throws a ValidationException denoting which field identifiers in the request have been deleted.
  • Calling GetCase with a deleted field identifier returns the deleted field's value if one exists.
  • Calling UpdateCase with a deleted field ID throws a ValidationException if the case does not already contain a value for the deleted field. Otherwise it succeeds, allowing you to update or remove (using emptyValue: {}) the field's value from the case.
  • GetTemplate does not return field IDs for deleted fields.
  • GetLayout does not return field IDs for deleted fields.
  • Calling SearchCases with the deleted field ID as a filter returns any cases that have a value for the deleted field that matches the filter criteria.
  • Calling SearchCases with a searchTerm value that matches a deleted field's value on a case returns the case in the response.
  • Calling BatchPutFieldOptions with a deleted field ID throw a ValidationException.
  • Calling GetCaseEventConfiguration does not return field IDs for deleted fields.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The unique identifier of the Cases domain.

Parameter fieldId : Unique identifier of the field.

Implementation

Future<void> deleteField({
  required String domainId,
  required String fieldId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/domains/${Uri.encodeComponent(domainId)}/fields/${Uri.encodeComponent(fieldId)}',
    exceptionFnMap: _exceptionFns,
  );
}