getCaseAuditEvents method

Future<GetCaseAuditEventsResponse> getCaseAuditEvents({
  1. required String caseId,
  2. required String domainId,
  3. int? maxResults,
  4. String? nextToken,
})

Returns the audit history about a specific case if it exists.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter caseId : A unique identifier of the case.

Parameter domainId : The unique identifier of the Cases domain.

Parameter maxResults : The maximum number of audit events to return. When no value is provided, 25 is the default.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<GetCaseAuditEventsResponse> getCaseAuditEvents({
  required String caseId,
  required String domainId,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/domains/${Uri.encodeComponent(domainId)}/cases/${Uri.encodeComponent(caseId)}/audit-history',
    exceptionFnMap: _exceptionFns,
  );
  return GetCaseAuditEventsResponse.fromJson(response);
}