listFields method

Future<ListFieldsResponse> listFields({
  1. required String domainId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all fields in a Cases domain.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The unique identifier of the Cases domain.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListFieldsResponse> listFields({
  required String domainId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/domains/${Uri.encodeComponent(domainId)}/fields-list',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListFieldsResponse.fromJson(response);
}