searchRelatedItems method

Future<SearchRelatedItemsResponse> searchRelatedItems({
  1. required String caseId,
  2. required String domainId,
  3. List<RelatedItemTypeFilter>? filters,
  4. int? maxResults,
  5. String? nextToken,
})

Searches for related items that are associated with a case.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter caseId : A unique identifier of the case.

Parameter domainId : The unique identifier of the Cases domain.

Parameter filters : The list of types of related items and their parameters to use for filtering.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<SearchRelatedItemsResponse> searchRelatedItems({
  required String caseId,
  required String domainId,
  List<RelatedItemTypeFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/domains/${Uri.encodeComponent(domainId)}/cases/${Uri.encodeComponent(caseId)}/related-items-search',
    exceptionFnMap: _exceptionFns,
  );
  return SearchRelatedItemsResponse.fromJson(response);
}