ConnectHealth class
Health Agent for healthcare providers and patient engagement
Constructors
- ConnectHealth({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateSubscription(
{required String domainId, required String subscriptionId}) → Future< ActivateSubscriptionOutput> - Activates a Subscription to enable billing for a user.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createDomain(
{required String name, String? kmsKeyArn, Map< String, String> ? tags, CreateWebAppConfiguration? webAppSetupConfiguration}) → Future<CreateDomainOutput> - Creates a new Domain for managing HealthAgent resources.
-
createSubscription(
{required String domainId}) → Future< CreateSubscriptionOutput> - Creates a new Subscription within a Domain for billing and user management.
-
deactivateSubscription(
{required String domainId, required String subscriptionId}) → Future< DeactivateSubscriptionOutput> - Deactivates a Subscription to stop billing for a user.
-
deleteDomain(
{required String domainId}) → Future< DeleteDomainOutput> - Deletes a Domain and all associated resources.
-
getDomain(
{required String domainId}) → Future< GetDomainOutput> - Retrieves information about a Domain.
-
getMedicalScribeListeningSession(
{required String domainId, required String sessionId, required String subscriptionId}) → Future< GetMedicalScribeListeningSessionOutput> - Retrieves details about an existing Medical Scribe listening session
-
getPatientInsightsJob(
{required String domainId, required String jobId}) → Future< GetPatientInsightsJobResponse> - Get details of a started patient insights job.
-
getSubscription(
{required String domainId, required String subscriptionId}) → Future< GetSubscriptionOutput> - Retrieves information about a Subscription.
-
listDomains(
{int? maxResults, String? nextToken, DomainStatus? status}) → Future< ListDomainsOutput> - Lists Domains for a given account.
-
listSubscriptions(
{required String domainId, int? maxResults, String? nextToken}) → Future< ListSubscriptionsOutput> - Lists all Subscriptions within a Domain.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists the tags associated with the specified resource
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startMedicalScribeListeningSession(
{required String domainId, required MedicalScribeLanguageCode languageCode, required MedicalScribeMediaEncoding mediaEncoding, required int mediaSampleRateHertz, required String sessionId, required String subscriptionId, MedicalScribeInputStream? inputStream}) → Future< StartMedicalScribeListeningSessionOutput> - Starts a new Medical Scribe listening session for real-time audio transcription
-
startPatientInsightsJob(
{required String domainId, required PatientInsightsEncounterContext encounterContext, required InputDataConfig inputDataConfig, required InsightsContext insightsContext, required OutputDataConfig outputDataConfig, required PatientInsightsPatientContext patientContext, required UserContext userContext, String? clientToken}) → Future< StartPatientInsightsJobResponse> - Starts a new patient insights job.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Associates the specified tags with the specified resource
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the specified resource
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited