ConnectParticipant class

Connect Customer is an easy-to-use omnichannel cloud contact center service that enables companies of any size to deliver superior customer service at a lower cost. Connect Customer communications capabilities make it easy for companies to deliver personalized interactions across communication channels, including chat.

Use the Connect Customer Participant Service to manage participants (for example, agents, customers, and managers listening in), and to send messages and events within a chat contact. The APIs in the service enable the following: sending chat messages, attachment sharing, managing a participant's connection state and message events, and retrieving chat transcripts.

Constructors

ConnectParticipant({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelParticipantAuthentication({required String connectionToken, required String sessionId}) Future<void>
Cancels the authentication session. The opted out branch of the Authenticate Customer flow block will be taken. The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
completeAttachmentUpload({required List<String> attachmentIds, required String connectionToken, String? clientToken}) Future<void>
Allows you to confirm that the attachment has been uploaded using the pre-signed URL provided in StartAttachmentUpload API. A conflict exception is thrown when an attachment with that identifier is already being uploaded.
createParticipantConnection({required String participantToken, bool? connectParticipant, List<ConnectionType>? type}) Future<CreateParticipantConnectionResponse>
Creates the participant's connection.
describeView({required String connectionToken, required String viewToken}) Future<DescribeViewResponse>
Retrieves the view for the specified view token.
disconnectParticipant({required String connectionToken, String? clientToken}) Future<void>
Disconnects a participant.
getAttachment({required String attachmentId, required String connectionToken, int? urlExpiryInSeconds}) Future<GetAttachmentResponse>
Provides a pre-signed URL for download of a completed attachment. This is an asynchronous API for use with active contacts.
getAuthenticationUrl({required String connectionToken, required String redirectUri, required String sessionId}) Future<GetAuthenticationUrlResponse>
Retrieves the AuthenticationUrl for the current authentication session for the AuthenticateCustomer flow block.
getTranscript({required String connectionToken, String? contactId, int? maxResults, String? nextToken, ScanDirection? scanDirection, SortKey? sortOrder, StartPosition? startPosition}) Future<GetTranscriptResponse>
Retrieves a transcript of the session, including details about any attachments. For information about accessing past chat contact transcripts for a persistent chat, see Enable persistent chat.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent({required String connectionToken, required String contentType, String? clientToken, String? content}) Future<SendEventResponse>
For security recommendations, see Connect Customer Chat security best practices. The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
sendMessage({required String connectionToken, required String content, required String contentType, String? clientToken}) Future<SendMessageResponse>
Sends a message.
startAttachmentUpload({required String attachmentName, required int attachmentSizeInBytes, required String connectionToken, required String contentType, String? clientToken}) Future<StartAttachmentUploadResponse>
Provides a pre-signed Amazon S3 URL in response for uploading the file directly to S3.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited