control_tower library

Classes

AwsClientCredentials
AWS credentials.
ControlTower
Amazon Web Services Control Tower offers application programming interface (API) operations that support programmatic interaction with these types of resources: