ControlTower class
Amazon Web Services Control Tower offers application programming interface (API) operations that support programmatic interaction with these types of resources:
For more information about these types of resources, see the Amazon Web Services Control Tower User Guide .About control APIs
These interfaces allow you to apply the Amazon Web Services library of pre-defined controls to your organizational units, programmatically. In Amazon Web Services Control Tower, the terms "control" and "guardrail" are synonyms.
To call these APIs, you'll need to know:
-
the
controlIdentifierfor the control--or guardrail--you are targeting. -
the ARN associated with the target organizational unit (OU), which we call
the
targetIdentifier. - the ARN associated with a resource that you wish to tag or untag.
controlIdentifier for your Amazon Web Services
Control Tower control:
The controlIdentifier is an ARN that is specified for each
control. You can view the controlIdentifier in the console on
the Control details page, as well as in the documentation.
About identifiers for Amazon Web Services Control Tower
The Amazon Web Services Control Tower controlIdentifier is
unique in each Amazon Web Services Region for each control. You can find the
controlIdentifier for each Region and control in the Tables
of control metadata or the Control
availability by Region tables in the Amazon Web Services Control
Tower Controls Reference Guide.
A quick-reference list of control identifers for the Amazon Web Services Control Tower legacy Strongly recommended and Elective controls is given in Resource identifiers for APIs and controls in the Amazon Web Services Control Tower Controls Reference Guide . Remember that Mandatory controls cannot be added or removed.
-
ARN format for Amazon Web Services Control Tower:
arn:aws:controltower:{REGION}::control/{CONTROL_TOWER_OPAQUE_ID}Example:
arn:aws:controltower:us-west-2::control/AWS-GR_AUTOSCALING_LAUNCH_CONFIG_PUBLIC_IP_DISABLED -
ARN format for Amazon Web Services Control Catalog:
arn:{PARTITION}:controlcatalog:::control/{CONTROL_CATALOG_OPAQUE_ID}
{CONTROL_CATALOG_OPAQUE_ID} in the
Amazon Web Services Control Tower Controls Reference Guide , or
in the Amazon Web Services Control Tower console, on the Control
details page.
The Amazon Web Services Control Tower APIs for enabled controls, such as
GetEnabledControl and ListEnabledControls always
return an ARN of the same type given when the control was enabled.
To get the targetIdentifier:
The targetIdentifier is the ARN for an OU.
In the Amazon Web Services Organizations console, you can find the ARN for the OU on the Organizational unit details page associated with that OU.
arn:${Partition}:organizations::${MasterAccountId}:ou/o-${OrganizationId}/ou-${OrganizationalUnitId}
About landing zone APIs
You can configure and launch an Amazon Web Services Control Tower landing zone with APIs. For an introduction and steps, see Getting started with Amazon Web Services Control Tower using APIs.
For an overview of landing zone API operations, see Amazon Web Services Control Tower supports landing zone APIs. The individual API operations for landing zones are detailed in this document, the API reference manual, in the "Actions" section.
About baseline APIs
You can apply the AWSControlTowerBaseline baseline to an
organizational unit (OU) as a way to register the OU with Amazon Web
Services Control Tower, programmatically. For a general overview of this
capability, see Amazon
Web Services Control Tower supports APIs for OU registration and
configuration with baselines.
You can call the baseline API operations to view the baselines that Amazon Web Services Control Tower enables for your landing zone, on your behalf, when setting up the landing zone. These baselines are read-only baselines.
The individual API operations for baselines are detailed in this document, the API reference manual, in the "Actions" section. For usage examples, see Baseline API input and output examples with CLI.
About Amazon Web Services Control Catalog identifiers
-
The
EnableControlandDisableControlAPI operations can be called by specifying either the Amazon Web Services Control Tower identifer or the Amazon Web Services Control Catalog identifier. The API response returns the same type of identifier that you specified when calling the API. -
If you use an Amazon Web Services Control Tower identifier to call the
EnableControlAPI, and then callEnableControlagain with an Amazon Web Services Control Catalog identifier, Amazon Web Services Control Tower returns an error message stating that the control is already enabled. Similar behavior applies to theDisableControlAPI operation. - Mandatory controls and the landing-zone-level Region deny control have Amazon Web Services Control Tower identifiers only.
Details and examples
- Control API input and output examples with CLI
- Baseline API input and output examples with CLI
- Enable controls with CloudFormation
- Launch a landing zone with CloudFormation
- Control metadata tables (large page)
- Control availability by Region tables (large page)
- List of identifiers for legacy controls
- Controls reference guide
- Controls library groupings
- Creating Amazon Web Services Control Tower resources with Amazon Web Services CloudFormation
Recording API Requests
Amazon Web Services Control Tower supports Amazon Web Services CloudTrail, a service that records Amazon Web Services API calls for your Amazon Web Services account and delivers log files to an Amazon S3 bucket. By using information collected by CloudTrail, you can determine which requests the Amazon Web Services Control Tower service received, who made the request and when, and so on. For more about Amazon Web Services Control Tower and its support for CloudTrail, see Logging Amazon Web Services Control Tower Actions with Amazon Web Services CloudTrail in the Amazon Web Services Control Tower User Guide. To learn more about CloudTrail, including how to turn it on and find your log files, see the Amazon Web Services CloudTrail User Guide.
Constructors
- ControlTower({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createLandingZone(
{required String version, Object? manifest, List< RemediationType> ? remediationTypes, Map<String, String> ? tags}) → Future<CreateLandingZoneOutput> - Creates a new landing zone. This API call starts an asynchronous operation that creates and configures a landing zone, based on the parameters specified in the manifest JSON file.
-
deleteLandingZone(
{required String landingZoneIdentifier}) → Future< DeleteLandingZoneOutput> - Decommissions a landing zone. This API call starts an asynchronous operation that deletes Amazon Web Services Control Tower resources deployed in accounts managed by Amazon Web Services Control Tower.
-
disableBaseline(
{required String enabledBaselineIdentifier}) → Future< DisableBaselineOutput> -
Disable an
EnabledBaselineresource on the specified Target. This API starts an asynchronous operation to remove all resources deployed as part of the baseline enablement. The resource will vary depending on the enabled baseline. For usage examples, see the Amazon Web Services Control Tower User Guide . -
disableControl(
{String? controlIdentifier, String? enabledControlIdentifier, String? targetIdentifier}) → Future< DisableControlOutput> - This API call turns off a control. It starts an asynchronous operation that deletes Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources will vary according to the control that you specify. For usage examples, see the Controls Reference Guide .
-
enableBaseline(
{required String baselineIdentifier, required String baselineVersion, required String targetIdentifier, List< EnabledBaselineParameter> ? parameters, Map<String, String> ? tags}) → Future<EnableBaselineOutput> -
Enable (apply) a
Baselineto a Target. This API starts an asynchronous operation to deploy resources specified by theBaselineto the specified Target. For usage examples, see the Amazon Web Services Control Tower User Guide . -
enableControl(
{required String controlIdentifier, required String targetIdentifier, List< EnabledControlParameter> ? parameters, Map<String, String> ? tags}) → Future<EnableControlOutput> - This API call activates a control. It starts an asynchronous operation that creates Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources created will vary according to the control that you specify. For usage examples, see the Controls Reference Guide .
-
getBaseline(
{required String baselineIdentifier}) → Future< GetBaselineOutput> -
Retrieve details about an existing
Baselineresource by specifying its identifier. For usage examples, see the Amazon Web Services Control Tower User Guide . -
getBaselineOperation(
{required String operationIdentifier}) → Future< GetBaselineOperationOutput> -
Returns the details of an asynchronous baseline operation, as initiated by
any of these APIs:
EnableBaseline,DisableBaseline,UpdateEnabledBaseline,ResetEnabledBaseline. A status message is displayed in case of operation failure. For usage examples, see the Amazon Web Services Control Tower User Guide . -
getControlOperation(
{required String operationIdentifier}) → Future< GetControlOperationOutput> -
Returns the status of a particular
EnableControlorDisableControloperation. Displays a message in case of error. Details for an operation are available for 90 days. For usage examples, see the Controls Reference Guide . -
getEnabledBaseline(
{required String enabledBaselineIdentifier}) → Future< GetEnabledBaselineOutput> -
Retrieve details of an
EnabledBaselineresource by specifying its identifier. -
getEnabledControl(
{required String enabledControlIdentifier}) → Future< GetEnabledControlOutput> - Retrieves details about an enabled control. For usage examples, see the Controls Reference Guide .
-
getLandingZone(
{required String landingZoneIdentifier}) → Future< GetLandingZoneOutput> - Returns details about the landing zone. Displays a message in case of error.
-
getLandingZoneOperation(
{required String operationIdentifier}) → Future< GetLandingZoneOperationOutput> - Returns the status of the specified landing zone operation. Details for an operation are available for 90 days.
-
listBaselines(
{int? maxResults, String? nextToken}) → Future< ListBaselinesOutput> - Returns a summary list of all available baselines. For usage examples, see the Amazon Web Services Control Tower User Guide .
-
listControlOperations(
{ControlOperationFilter? filter, int? maxResults, String? nextToken}) → Future< ListControlOperationsOutput> - Provides a list of operations in progress or queued. For usage examples, see ListControlOperation examples.
-
listEnabledBaselines(
{EnabledBaselineFilter? filter, bool? includeChildren, int? maxResults, String? nextToken}) → Future< ListEnabledBaselinesOutput> -
Returns a list of summaries describing
EnabledBaselineresources. You can filter the list by the correspondingBaselineorTargetof theEnabledBaselineresources. For usage examples, see the Amazon Web Services Control Tower User Guide . -
listEnabledControls(
{EnabledControlFilter? filter, bool? includeChildren, int? maxResults, String? nextToken, String? targetIdentifier}) → Future< ListEnabledControlsOutput> - Lists the controls enabled by Amazon Web Services Control Tower on the specified organizational unit and the accounts it contains. For usage examples, see the Controls Reference Guide .
-
listLandingZoneOperations(
{LandingZoneOperationFilter? filter, int? maxResults, String? nextToken}) → Future< ListLandingZoneOperationsOutput> - Lists all landing zone operations from the past 90 days. Results are sorted by time, with the most recent operation first.
-
listLandingZones(
{int? maxResults, String? nextToken}) → Future< ListLandingZonesOutput> - Returns the landing zone ARN for the landing zone deployed in your managed account. This API also creates an ARN for existing accounts that do not yet have a landing zone ARN.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Returns a list of tags associated with the resource. For usage examples, see the Controls Reference Guide .
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetEnabledBaseline(
{required String enabledBaselineIdentifier}) → Future< ResetEnabledBaselineOutput> -
Re-enables an
EnabledBaselineresource. For example, this API can re-apply the existingBaselineafter a new member account is moved to the target OU. For usage examples, see the Amazon Web Services Control Tower User Guide . -
resetEnabledControl(
{required String enabledControlIdentifier}) → Future< ResetEnabledControlOutput> - Resets an enabled control. Does not work for controls implemented with SCPs.
-
resetLandingZone(
{required String landingZoneIdentifier}) → Future< ResetLandingZoneOutput> - This API call resets a landing zone. It starts an asynchronous operation that resets the landing zone to the parameters specified in the original configuration, which you specified in the manifest file. Nothing in the manifest file's original landing zone configuration is changed during the reset process, by default. This API is not the same as a rollback of a landing zone version, which is not a supported operation.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Applies tags to a resource. For usage examples, see the Controls Reference Guide .
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from a resource. For usage examples, see the Controls Reference Guide .
-
updateEnabledBaseline(
{required String baselineVersion, required String enabledBaselineIdentifier, List< EnabledBaselineParameter> ? parameters}) → Future<UpdateEnabledBaselineOutput> -
Updates an
EnabledBaselineresource's applied parameters or version. For usage examples, see the Amazon Web Services Control Tower User Guide . -
updateEnabledControl(
{required String enabledControlIdentifier, required List< EnabledControlParameter> parameters}) → Future<UpdateEnabledControlOutput> - Updates the configuration of an already enabled control.
-
updateLandingZone(
{required String landingZoneIdentifier, required String version, Object? manifest, List< RemediationType> ? remediationTypes}) → Future<UpdateLandingZoneOutput> - This API call updates the landing zone. It starts an asynchronous operation that updates the landing zone based on the new landing zone version, or on the changed parameters specified in the updated manifest file.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited