deleteLandingZone method
Decommissions a landing zone. This API call starts an asynchronous operation that deletes Amazon Web Services Control Tower resources deployed in accounts managed by Amazon Web Services Control Tower.
Decommissioning a landing zone is a process with significant consequences, and it cannot be undone. We strongly recommend that you perform this decommissioning process only if you intend to stop using your landing zone.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter landingZoneIdentifier :
The unique identifier of the landing zone.
Implementation
Future<DeleteLandingZoneOutput> deleteLandingZone({
required String landingZoneIdentifier,
}) async {
final $payload = <String, dynamic>{
'landingZoneIdentifier': landingZoneIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/delete-landingzone',
exceptionFnMap: _exceptionFns,
);
return DeleteLandingZoneOutput.fromJson(response);
}