disableBaseline method

Future<DisableBaselineOutput> disableBaseline({
  1. required String enabledBaselineIdentifier,
})

Disable an EnabledBaseline resource on the specified Target. This API starts an asynchronous operation to remove all resources deployed as part of the baseline enablement. The resource will vary depending on the enabled baseline. For usage examples, see the Amazon Web Services Control Tower User Guide .

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter enabledBaselineIdentifier : Identifier of the EnabledBaseline resource to be deactivated, in ARN format.

Implementation

Future<DisableBaselineOutput> disableBaseline({
  required String enabledBaselineIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'enabledBaselineIdentifier': enabledBaselineIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/disable-baseline',
    exceptionFnMap: _exceptionFns,
  );
  return DisableBaselineOutput.fromJson(response);
}