getBaseline method

Future<GetBaselineOutput> getBaseline({
  1. required String baselineIdentifier,
})

Retrieve details about an existing Baseline resource by specifying its identifier. For usage examples, see the Amazon Web Services Control Tower User Guide .

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter baselineIdentifier : The ARN of the Baseline resource to be retrieved.

Implementation

Future<GetBaselineOutput> getBaseline({
  required String baselineIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'baselineIdentifier': baselineIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/get-baseline',
    exceptionFnMap: _exceptionFns,
  );
  return GetBaselineOutput.fromJson(response);
}