getBaselineOperation method

Future<GetBaselineOperationOutput> getBaselineOperation({
  1. required String operationIdentifier,
})

Returns the details of an asynchronous baseline operation, as initiated by any of these APIs: EnableBaseline, DisableBaseline, UpdateEnabledBaseline, ResetEnabledBaseline. A status message is displayed in case of operation failure. For usage examples, see the Amazon Web Services Control Tower User Guide .

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter operationIdentifier : The operation ID returned from mutating asynchronous APIs (Enable, Disable, Update, Reset).

Implementation

Future<GetBaselineOperationOutput> getBaselineOperation({
  required String operationIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'operationIdentifier': operationIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/get-baseline-operation',
    exceptionFnMap: _exceptionFns,
  );
  return GetBaselineOperationOutput.fromJson(response);
}