getControlOperation method

Future<GetControlOperationOutput> getControlOperation({
  1. required String operationIdentifier,
})

Returns the status of a particular EnableControl or DisableControl operation. Displays a message in case of error. Details for an operation are available for 90 days. For usage examples, see the Controls Reference Guide .

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter operationIdentifier : The ID of the asynchronous operation, which is used to track status. The operation is available for 90 days.

Implementation

Future<GetControlOperationOutput> getControlOperation({
  required String operationIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'operationIdentifier': operationIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/get-control-operation',
    exceptionFnMap: _exceptionFns,
  );
  return GetControlOperationOutput.fromJson(response);
}