getLandingZoneOperation method

Future<GetLandingZoneOperationOutput> getLandingZoneOperation({
  1. required String operationIdentifier,
})

Returns the status of the specified landing zone operation. Details for an operation are available for 90 days.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter operationIdentifier : A unique identifier assigned to a landing zone operation.

Implementation

Future<GetLandingZoneOperationOutput> getLandingZoneOperation({
  required String operationIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'operationIdentifier': operationIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/get-landingzone-operation',
    exceptionFnMap: _exceptionFns,
  );
  return GetLandingZoneOperationOutput.fromJson(response);
}