listControlOperations method
Provides a list of operations in progress or queued. For usage examples, see ListControlOperation examples.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
An input filter for the ListControlOperations API that lets
you select the types of control operations to view.
Parameter maxResults :
The maximum number of results to be shown.
Parameter nextToken :
A pagination token.
Implementation
Future<ListControlOperationsOutput> listControlOperations({
ControlOperationFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-control-operations',
exceptionFnMap: _exceptionFns,
);
return ListControlOperationsOutput.fromJson(response);
}