listLandingZoneOperations method

Future<ListLandingZoneOperationsOutput> listLandingZoneOperations({
  1. LandingZoneOperationFilter? filter,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all landing zone operations from the past 90 days. Results are sorted by time, with the most recent operation first.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter filter : An input filter for the ListLandingZoneOperations API that lets you select the types of landing zone operations to view.

Parameter maxResults : How many results to return per API call.

Parameter nextToken : The token to continue the list from a previous API call with the same parameters.

Implementation

Future<ListLandingZoneOperationsOutput> listLandingZoneOperations({
  LandingZoneOperationFilter? filter,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (filter != null) 'filter': filter,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-landingzone-operations',
    exceptionFnMap: _exceptionFns,
  );
  return ListLandingZoneOperationsOutput.fromJson(response);
}