resetEnabledBaseline method

Future<ResetEnabledBaselineOutput> resetEnabledBaseline({
  1. required String enabledBaselineIdentifier,
})

Re-enables an EnabledBaseline resource. For example, this API can re-apply the existing Baseline after a new member account is moved to the target OU. For usage examples, see the Amazon Web Services Control Tower User Guide .

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter enabledBaselineIdentifier : Specifies the ID of the EnabledBaseline resource to be re-enabled, in ARN format.

Implementation

Future<ResetEnabledBaselineOutput> resetEnabledBaseline({
  required String enabledBaselineIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'enabledBaselineIdentifier': enabledBaselineIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/reset-enabled-baseline',
    exceptionFnMap: _exceptionFns,
  );
  return ResetEnabledBaselineOutput.fromJson(response);
}