resetLandingZone method
This API call resets a landing zone. It starts an asynchronous operation that resets the landing zone to the parameters specified in the original configuration, which you specified in the manifest file. Nothing in the manifest file's original landing zone configuration is changed during the reset process, by default. This API is not the same as a rollback of a landing zone version, which is not a supported operation.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter landingZoneIdentifier :
The unique identifier of the landing zone.
Implementation
Future<ResetLandingZoneOutput> resetLandingZone({
required String landingZoneIdentifier,
}) async {
final $payload = <String, dynamic>{
'landingZoneIdentifier': landingZoneIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/reset-landingzone',
exceptionFnMap: _exceptionFns,
);
return ResetLandingZoneOutput.fromJson(response);
}