updateEnabledBaseline method

Future<UpdateEnabledBaselineOutput> updateEnabledBaseline({
  1. required String baselineVersion,
  2. required String enabledBaselineIdentifier,
  3. List<EnabledBaselineParameter>? parameters,
})

Updates an EnabledBaseline resource's applied parameters or version. For usage examples, see the Amazon Web Services Control Tower User Guide .

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter baselineVersion : Specifies the new Baseline version, to which the EnabledBaseline should be updated.

Parameter enabledBaselineIdentifier : Specifies the EnabledBaseline resource to be updated.

Parameter parameters : Parameters to apply when making an update.

Implementation

Future<UpdateEnabledBaselineOutput> updateEnabledBaseline({
  required String baselineVersion,
  required String enabledBaselineIdentifier,
  List<EnabledBaselineParameter>? parameters,
}) async {
  final $payload = <String, dynamic>{
    'baselineVersion': baselineVersion,
    'enabledBaselineIdentifier': enabledBaselineIdentifier,
    if (parameters != null) 'parameters': parameters,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-enabled-baseline',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateEnabledBaselineOutput.fromJson(response);
}