updateLandingZone method

Future<UpdateLandingZoneOutput> updateLandingZone({
  1. required String landingZoneIdentifier,
  2. required String version,
  3. Object? manifest,
  4. List<RemediationType>? remediationTypes,
})

This API call updates the landing zone. It starts an asynchronous operation that updates the landing zone based on the new landing zone version, or on the changed parameters specified in the updated manifest file.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter landingZoneIdentifier : The unique identifier of the landing zone.

Parameter version : The landing zone version, for example, 3.2.

Parameter manifest : The manifest file (JSON) is a text file that describes your Amazon Web Services resources. For an example, review Launch your landing zone. The example manifest file contains each of the available parameters. The schema for the landing zone's JSON manifest file is not published, by design.

Parameter remediationTypes : Specifies the types of remediation actions to apply when updating the landing zone configuration.

Implementation

Future<UpdateLandingZoneOutput> updateLandingZone({
  required String landingZoneIdentifier,
  required String version,
  Object? manifest,
  List<RemediationType>? remediationTypes,
}) async {
  final $payload = <String, dynamic>{
    'landingZoneIdentifier': landingZoneIdentifier,
    'version': version,
    if (manifest != null) 'manifest': manifest,
    if (remediationTypes != null)
      'remediationTypes': remediationTypes.map((e) => e.value).toList(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-landingzone',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateLandingZoneOutput.fromJson(response);
}