control_tower_2018_05_10 library
Classes
- AwsClientCredentials
- AWS credentials.
- ControlTower
- Amazon Web Services Control Tower offers application programming interface (API) operations that support programmatic interaction with these types of resources: