cost_and_usage_report_service library

Classes

AwsClientCredentials
AWS credentials.
CostAndUsageReport
You can use the Amazon Web Services Cost and Usage Report API to programmatically create, query, and delete Amazon Web Services Cost and Usage Report definitions.