CostAndUsageReport class

You can use the Amazon Web Services Cost and Usage Report API to programmatically create, query, and delete Amazon Web Services Cost and Usage Report definitions.

Amazon Web Services Cost and Usage Report track the monthly Amazon Web Services costs and usage associated with your Amazon Web Services account. The report contains line items for each unique combination of Amazon Web Services product, usage type, and operation that your Amazon Web Services account uses. You can configure the Amazon Web Services Cost and Usage Report to show only the data that you want, using the Amazon Web Services Cost and Usage Report API.

Service Endpoint

The Amazon Web Services Cost and Usage Report API provides the following endpoint:

  • cur.us-east-1.amazonaws.com

Constructors

CostAndUsageReport({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteReportDefinition({required String reportName}) Future<DeleteReportDefinitionResponse>
Deletes the specified report. Any tags associated with the report are also deleted.
describeReportDefinitions({int? maxResults, String? nextToken}) Future<DescribeReportDefinitionsResponse>
Lists the Amazon Web Services Cost and Usage Report available to this account.
listTagsForResource({required String reportName}) Future<ListTagsForResourceResponse>
Lists the tags associated with the specified report definition.
modifyReportDefinition({required ReportDefinition reportDefinition, required String reportName}) Future<void>
Allows you to programmatically update your report preferences.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putReportDefinition({required ReportDefinition reportDefinition, List<Tag>? tags}) Future<void>
Creates a new report using the description that you provide.
tagResource({required String reportName, required List<Tag> tags}) Future<void>
Associates a set of tags with a report definition.
toString() String
A string representation of this object.
inherited
untagResource({required String reportName, required List<String> tagKeys}) Future<void>
Disassociates a set of tags from a report definition.

Operators

operator ==(Object other) bool
The equality operator.
inherited