deleteReportDefinition method

Future<DeleteReportDefinitionResponse> deleteReportDefinition({
  1. required String reportName,
})

Deletes the specified report. Any tags associated with the report are also deleted.

May throw InternalErrorException. May throw ValidationException.

Parameter reportName : The name of the report that you want to delete. The name must be unique, is case sensitive, and can't include spaces.

Implementation

Future<DeleteReportDefinitionResponse> deleteReportDefinition({
  required String reportName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSOrigamiServiceGatewayService.DeleteReportDefinition'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ReportName': reportName,
    },
  );

  return DeleteReportDefinitionResponse.fromJson(jsonResponse.body);
}