getCostAndUsage method

Future<GetCostAndUsageResponse> getCostAndUsage({
  1. required Granularity granularity,
  2. required List<String> metrics,
  3. required DateInterval timePeriod,
  4. String? billingViewArn,
  5. Expression? filter,
  6. List<GroupDefinition>? groupBy,
  7. String? nextPageToken,
})

Retrieves cost and usage metrics for your account. You can specify which cost and usage-related metric that you want the request to return. For example, you can specify BlendedCosts or UsageQuantity. You can also filter and group your data by various dimensions, such as SERVICE or AZ, in a specific time range. For a complete list of valid dimensions, see the GetDimensionValues operation. Management account in an organization in Organizations have access to all member accounts.

For information about filter limitations, see Quotas and restrictions in the Billing and Cost Management User Guide.

May throw BillExpirationException. May throw BillingViewHealthStatusException. May throw DataUnavailableException. May throw InvalidNextTokenException. May throw LimitExceededException. May throw RequestChangedException. May throw ResourceNotFoundException.

Parameter granularity : Sets the Amazon Web Services cost granularity to MONTHLY or DAILY, or HOURLY. If Granularity isn't set, the response object doesn't include the Granularity, either MONTHLY or DAILY, or HOURLY.

Parameter metrics : Which metrics are returned in the query. For more information about blended and unblended rates, see Why does the "blended" annotation appear on some line items in my bill?.

Valid values are AmortizedCost, BlendedCost, NetAmortizedCost, NetUnblendedCost, NormalizedUsageAmount, UnblendedCost, and UsageQuantity. Metrics is required for GetCostAndUsage requests.

Parameter timePeriod : Sets the start date and end date for retrieving Amazon Web Services costs. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.

Parameter billingViewArn : The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.

Parameter filter : Filters Amazon Web Services costs by different dimensions. For example, you can specify SERVICE and LINKED_ACCOUNT and get the costs that are associated with that account's usage of that service. You can nest Expression objects to define any combination of dimension filters. For more information, see Expression.

Valid values for MatchOptions for Dimensions are EQUALS and CASE_SENSITIVE.

Valid values for MatchOptions for CostCategories and Tags are EQUALS, ABSENT, and CASE_SENSITIVE. Default values are EQUALS and CASE_SENSITIVE.

Parameter groupBy : You can group Amazon Web Services costs using up to two different groups, either dimensions, tag keys, cost categories, or any two group by types.

Valid values for the DIMENSION type are AZ, INSTANCE_TYPE, LEGAL_ENTITY_NAME, INVOICING_ENTITY, LINKED_ACCOUNT, OPERATION, PLATFORM, PURCHASE_TYPE, SERVICE, TENANCY, RECORD_TYPE, and USAGE_TYPE.

When you group by the TAG type and include a valid tag key, you get all tag values, including empty strings.

Parameter nextPageToken : The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Implementation

Future<GetCostAndUsageResponse> getCostAndUsage({
  required Granularity granularity,
  required List<String> metrics,
  required DateInterval timePeriod,
  String? billingViewArn,
  Expression? filter,
  List<GroupDefinition>? groupBy,
  String? nextPageToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSInsightsIndexService.GetCostAndUsage'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Granularity': granularity.value,
      'Metrics': metrics,
      'TimePeriod': timePeriod,
      if (billingViewArn != null) 'BillingViewArn': billingViewArn,
      if (filter != null) 'Filter': filter,
      if (groupBy != null) 'GroupBy': groupBy,
      if (nextPageToken != null) 'NextPageToken': nextPageToken,
    },
  );

  return GetCostAndUsageResponse.fromJson(jsonResponse.body);
}