getCostAndUsageWithResources method

Future<GetCostAndUsageWithResourcesResponse> getCostAndUsageWithResources({
  1. required Expression filter,
  2. required Granularity granularity,
  3. required DateInterval timePeriod,
  4. String? billingViewArn,
  5. List<GroupDefinition>? groupBy,
  6. List<String>? metrics,
  7. String? nextPageToken,
})

Retrieves cost and usage metrics with resources for your account. You can specify which cost and usage-related metric, such as BlendedCosts or UsageQuantity, that you want the request to return. You can also filter and group your data by various dimensions, such as SERVICE or AZ, in a specific time range. For a complete list of valid dimensions, see the GetDimensionValues operation. Management account in an organization in Organizations have access to all member accounts.

Hourly granularity is only available for EC2-Instances (Elastic Compute Cloud) resource-level data. All other resource-level data is available at daily granularity.

May throw BillExpirationException. May throw BillingViewHealthStatusException. May throw DataUnavailableException. May throw InvalidNextTokenException. May throw LimitExceededException. May throw RequestChangedException. May throw ResourceNotFoundException.

Parameter filter : Filters Amazon Web Services costs by different dimensions. For example, you can specify SERVICE and LINKED_ACCOUNT and get the costs that are associated with that account's usage of that service. You can nest Expression objects to define any combination of dimension filters. For more information, see Expression.

The GetCostAndUsageWithResources operation requires that you either group by or filter by a ResourceId. It requires the Expression "SERVICE = Amazon Elastic Compute Cloud - Compute" in the filter.

Valid values for MatchOptions for Dimensions are EQUALS and CASE_SENSITIVE.

Valid values for MatchOptions for CostCategories and Tags are EQUALS, ABSENT, and CASE_SENSITIVE. Default values are EQUALS and CASE_SENSITIVE.

Parameter granularity : Sets the Amazon Web Services cost granularity to MONTHLY, DAILY, or HOURLY. If Granularity isn't set, the response object doesn't include the Granularity, MONTHLY, DAILY, or HOURLY.

Parameter timePeriod : Sets the start and end dates for retrieving Amazon Web Services costs. The range must be within the last 14 days (the start date cannot be earlier than 14 days ago). The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.

Parameter billingViewArn : The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.

Parameter groupBy : You can group Amazon Web Services costs using up to two different groups: DIMENSION, TAG, COST_CATEGORY.

Parameter metrics : Which metrics are returned in the query. For more information about blended and unblended rates, see Why does the "blended" annotation appear on some line items in my bill?.

Valid values are AmortizedCost, BlendedCost, NetAmortizedCost, NetUnblendedCost, NormalizedUsageAmount, UnblendedCost, and UsageQuantity. Metrics is required for GetCostAndUsageWithResources requests.

Parameter nextPageToken : The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Implementation

Future<GetCostAndUsageWithResourcesResponse> getCostAndUsageWithResources({
  required Expression filter,
  required Granularity granularity,
  required DateInterval timePeriod,
  String? billingViewArn,
  List<GroupDefinition>? groupBy,
  List<String>? metrics,
  String? nextPageToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSInsightsIndexService.GetCostAndUsageWithResources'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Filter': filter,
      'Granularity': granularity.value,
      'TimePeriod': timePeriod,
      if (billingViewArn != null) 'BillingViewArn': billingViewArn,
      if (groupBy != null) 'GroupBy': groupBy,
      if (metrics != null) 'Metrics': metrics,
      if (nextPageToken != null) 'NextPageToken': nextPageToken,
    },
  );

  return GetCostAndUsageWithResourcesResponse.fromJson(jsonResponse.body);
}