listCommitmentPurchaseAnalyses method

Future<ListCommitmentPurchaseAnalysesResponse> listCommitmentPurchaseAnalyses({
  1. List<String>? analysisIds,
  2. AnalysisStatus? analysisStatus,
  3. String? nextPageToken,
  4. int? pageSize,
})

Lists the commitment purchase analyses for your account.

May throw DataUnavailableException. May throw InvalidNextTokenException. May throw LimitExceededException.

Parameter analysisIds : The analysis IDs associated with the commitment purchase analyses.

Parameter analysisStatus : The status of the analysis.

Parameter nextPageToken : The token to retrieve the next set of results.

Parameter pageSize : The number of analyses that you want returned in a single response object.

Implementation

Future<ListCommitmentPurchaseAnalysesResponse>
    listCommitmentPurchaseAnalyses({
  List<String>? analysisIds,
  AnalysisStatus? analysisStatus,
  String? nextPageToken,
  int? pageSize,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    0,
    600,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSInsightsIndexService.ListCommitmentPurchaseAnalyses'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (analysisIds != null) 'AnalysisIds': analysisIds,
      if (analysisStatus != null) 'AnalysisStatus': analysisStatus.value,
      if (nextPageToken != null) 'NextPageToken': nextPageToken,
      if (pageSize != null) 'PageSize': pageSize,
    },
  );

  return ListCommitmentPurchaseAnalysesResponse.fromJson(jsonResponse.body);
}