cost_explorer_2017_10_25 library
Classes
- AwsClientCredentials
- AWS credentials.
- CostExplorer
- You can use the Cost Explorer API to programmatically query your cost and usage data. You can query for aggregated data such as total monthly costs or total daily usage. You can also query for granular data. This might include the number of daily write operations for Amazon DynamoDB database tables in your production environment.