CostOptimizationHub class
You can use the Cost Optimization Hub API to programmatically identify, filter, aggregate, and quantify savings for your cost optimization recommendations across multiple Amazon Web Services Regions and Amazon Web Services accounts in your organization.
The Cost Optimization Hub API provides the following endpoint:
- https://cost-optimization-hub.us-east-1.amazonaws.com
Constructors
- CostOptimizationHub({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getPreferences(
) → Future< GetPreferencesResponse> - Returns a set of preferences for an account in order to add account-specific preferences into the service. These preferences impact how the savings associated with recommendations are presented—estimated savings after discounts or estimated savings before discounts, for example.
-
getRecommendation(
{required String recommendationId}) → Future< GetRecommendationResponse> - Returns both the current and recommended resource configuration and the estimated cost impact for a recommendation.
-
listEfficiencyMetrics(
{required GranularityType granularity, required TimePeriod timePeriod, String? groupBy, int? maxResults, String? nextToken, OrderBy? orderBy}) → Future< ListEfficiencyMetricsResponse> - Returns cost efficiency metrics aggregated over time and optionally grouped by a specified dimension. The metrics provide insights into your cost optimization progress by tracking estimated savings, spending, and measures how effectively you're optimizing your Cloud resources.
-
listEnrollmentStatuses(
{String? accountId, bool? includeOrganizationInfo, int? maxResults, String? nextToken}) → Future< ListEnrollmentStatusesResponse> - Retrieves the enrollment status for an account. It can also return the list of accounts that are enrolled under the organization.
-
listRecommendations(
{Filter? filter, bool? includeAllRecommendations, int? maxResults, String? nextToken, OrderBy? orderBy}) → Future< ListRecommendationsResponse> - Returns a list of recommendations.
-
listRecommendationSummaries(
{required String groupBy, Filter? filter, int? maxResults, List< SummaryMetrics> ? metrics, String? nextToken}) → Future<ListRecommendationSummariesResponse> - Returns a concise representation of savings estimates for resources. Also returns de-duped savings across different types of recommendations.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateEnrollmentStatus(
{required EnrollmentStatus status, bool? includeMemberAccounts}) → Future< UpdateEnrollmentStatusResponse> - Updates the enrollment (opt in and opt out) status of an account to the Cost Optimization Hub service.
-
updatePreferences(
{MemberAccountDiscountVisibility? memberAccountDiscountVisibility, PreferredCommitment? preferredCommitment, SavingsEstimationMode? savingsEstimationMode}) → Future< UpdatePreferencesResponse> - Updates a set of preferences for an account in order to add account-specific preferences into the service. These preferences impact how the savings associated with recommendations are presented.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited