credential_providers library
Classes
- CachedCredentialProvider
- Utility class for caching credentials from a credential provider, with built in support for refreshing when expired.
- ChainedCredentialProvider
- Utility class for chaining multiple providers in a fallback chain Example usage with default chain:
Functions
-
defaultProvider(
{Client? client}) → Future< AwsClientCredentials?> -
fromEnvironment(
{Client? client}) → Future< AwsClientCredentials?> -
Source AWS credentials from known environment variables. If either the
AWS_ACCESS_KEY_IDorAWS_SECRET_ACCESS_KEYenvironment variable is not set in this process, the provider will return null. -
fromIni(
{bool preferStaticCredentials = false, Client? client, String? preferredProfile}) → Future< AwsClientCredentials?> - Creates a credential provider that will read from ini files and supports role assumption and multi-factor authentication.
-
fromInstanceMetaDataService(
{Client? client}) → Future< AwsClientCredentials?> - A credential provider that will source credentials from the EC2 Instance Metadata Service