CustomerProfiles class
Connect Customer Customer Profiles is a unified customer profile for your
contact center that has pre-built connectors powered by AppFlow that make it
easy to combine customer information from third party applications, such as
Salesforce (CRM), ServiceNow (ITSM), and your enterprise resource planning
(ERP), with contact history from your Connect Customer contact center.
Constructors
- CustomerProfiles({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addProfileKey(
{required String domainName, required String keyName, required String profileId, required List< String> values}) → Future<AddProfileKeyResponse> - Associates a new key value with a specific profile, such as a Contact Record ContactId.
-
batchGetCalculatedAttributeForProfile(
{required String calculatedAttributeName, required String domainName, required List< String> profileIds, ConditionOverrides? conditionOverrides}) → Future<BatchGetCalculatedAttributeForProfileResponse> - Fetch the possible attribute values given the attribute name.
-
batchGetProfile(
{required String domainName, required List< String> profileIds}) → Future<BatchGetProfileResponse> - Get a batch of profiles.
-
batchPutProfileObject(
{required String domainName, required List< BatchPutProfileObjectRequestItem> items, required String objectTypeName}) → Future<BatchPutProfileObjectResponse> - Adds multiple profile objects to a domain of a given ObjectType in a single API call.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCalculatedAttributeDefinition(
{required AttributeDetails attributeDetails, required String calculatedAttributeName, required String domainName, required Statistic statistic, Conditions? conditions, String? description, String? displayName, Filter? filter, Map< String, String> ? tags, bool? useHistoricalData}) → Future<CreateCalculatedAttributeDefinitionResponse> -
Creates a new calculated attribute definition. After creation, new object
data ingested into Customer Profiles will be included in the calculated
attribute, which can be retrieved for a profile using the GetCalculatedAttributeForProfile
API. Defining a calculated attribute makes it available for all profiles
within a domain. Each calculated attribute can only reference one
ObjectTypeand at most, two fields from thatObjectType. -
createDomain(
{required int defaultExpirationDays, required String domainName, DataStoreRequest? dataStore, String? deadLetterQueueUrl, String? defaultEncryptionKey, MatchingRequest? matching, RuleBasedMatchingRequest? ruleBasedMatching, Map< String, String> ? tags}) → Future<CreateDomainResponse> - Creates a domain, which is a container for all customer data, such as customer profile attributes, object types, profile keys, and encryption keys. You can create multiple domains, and each domain can have multiple third-party integrations.
-
createDomainLayout(
{required String description, required String displayName, required String domainName, required String layout, required String layoutDefinitionName, required LayoutType layoutType, bool? isDefault, Map< String, String> ? tags}) → Future<CreateDomainLayoutResponse> - Creates the layout to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
-
createEventStream(
{required String domainName, required String eventStreamName, required String uri, Map< String, String> ? tags}) → Future<CreateEventStreamResponse> - Creates an event stream, which is a subscription to real-time events, such as when profiles are created and updated through Connect Customer Customer Profiles.
-
createEventTrigger(
{required String domainName, required List< EventTriggerCondition> eventTriggerConditions, required String eventTriggerName, required String objectTypeName, String? description, EventTriggerLimits? eventTriggerLimits, String? segmentFilter, Map<String, String> ? tags}) → Future<CreateEventTriggerResponse> - Creates an event trigger, which specifies the rules when to perform action based on customer's ingested data.
-
createIntegrationWorkflow(
{required String domainName, required IntegrationConfig integrationConfig, required String objectTypeName, required String roleArn, required WorkflowType workflowType, Map< String, String> ? tags}) → Future<CreateIntegrationWorkflowResponse> - Creates an integration workflow. An integration workflow is an async process which ingests historic data and sets up an integration for ongoing updates. The supported Amazon AppFlow sources are Salesforce, ServiceNow, and Marketo.
-
createProfile(
{required String domainName, String? accountNumber, String? additionalInformation, Address? address, Map< String, String> ? attributes, Address? billingAddress, String? birthDate, String? businessEmailAddress, String? businessName, String? businessPhoneNumber, String? emailAddress, EngagementPreferences? engagementPreferences, String? firstName, Gender? gender, String? genderString, String? homePhoneNumber, String? lastName, Address? mailingAddress, String? middleName, String? mobilePhoneNumber, PartyType? partyType, String? partyTypeString, String? personalEmailAddress, String? phoneNumber, ProfileType? profileType, Address? shippingAddress}) → Future<CreateProfileResponse> - Creates a standard profile.
-
createRecommender(
{required String domainName, required String recommenderName, required RecommenderRecipeName recommenderRecipeName, String? description, RecommenderConfig? recommenderConfig, String? recommenderSchemaName, Map< String, String> ? tags}) → Future<CreateRecommenderResponse> - Creates a recommender
-
createRecommenderFilter(
{required String domainName, required String recommenderFilterExpression, required String recommenderFilterName, String? description, String? recommenderSchemaName, Map< String, String> ? tags}) → Future<CreateRecommenderFilterResponse> - Creates a recommender filter. A recommender filter specifies which items to include or exclude from recommendations.
-
createRecommenderSchema(
{required String domainName, required Map< String, List< fields, required String recommenderSchemaName, Map<RecommenderSchemaField> >String, String> ? tags}) → Future<CreateRecommenderSchemaResponse> - Creates a recommender schema. A recommender schema defines the set of data columns available for training recommenders and filters under a domain.
-
createSegmentDefinition(
{required String displayName, required String domainName, required String segmentDefinitionName, String? description, SegmentGroup? segmentGroups, SegmentSort? segmentSort, String? segmentSqlQuery, Map< String, String> ? tags}) → Future<CreateSegmentDefinitionResponse> - Creates a segment definition associated to the given domain.
-
createSegmentEstimate(
{required String domainName, SegmentGroupStructure? segmentQuery, String? segmentSqlQuery}) → Future< CreateSegmentEstimateResponse> - Creates a segment estimate query.
-
createSegmentSnapshot(
{required DataFormat dataFormat, required String domainName, required String segmentDefinitionName, String? destinationUri, String? encryptionKey, String? roleArn}) → Future< CreateSegmentSnapshotResponse> - Triggers a job to export a segment to a specified destination.
-
createUploadJob(
{required String displayName, required String domainName, required Map< String, ObjectTypeField> fields, required String uniqueKey, int? dataExpiry}) → Future<CreateUploadJobResponse> - Creates an Upload job to ingest data for segment imports. The metadata is created for the job with the provided field mapping and unique key.
-
deleteCalculatedAttributeDefinition(
{required String calculatedAttributeName, required String domainName}) → Future< void> - Deletes an existing calculated attribute definition. Note that deleting a default calculated attribute is possible, however once deleted, you will be unable to undo that action and will need to recreate it on your own using the CreateCalculatedAttributeDefinition API if you want it back.
-
deleteDomain(
{required String domainName}) → Future< DeleteDomainResponse> - Deletes a specific domain and all of its customer data, such as customer profile attributes and their related objects.
-
deleteDomainLayout(
{required String domainName, required String layoutDefinitionName}) → Future< DeleteDomainLayoutResponse> - Deletes the layout used to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
-
deleteDomainObjectType(
{required String domainName, required String objectTypeName}) → Future< void> - Delete a DomainObjectType for the given Domain and ObjectType name.
-
deleteEventStream(
{required String domainName, required String eventStreamName}) → Future< void> - Disables and deletes the specified event stream.
-
deleteEventTrigger(
{required String domainName, required String eventTriggerName}) → Future< DeleteEventTriggerResponse> - Disable and deletes the Event Trigger.
-
deleteIntegration(
{required String domainName, required String uri}) → Future< DeleteIntegrationResponse> - Removes an integration from a specific domain.
-
deleteProfile(
{required String domainName, required String profileId}) → Future< DeleteProfileResponse> - Deletes the standard customer profile and all data pertaining to the profile.
-
deleteProfileKey(
{required String domainName, required String keyName, required String profileId, required List< String> values}) → Future<DeleteProfileKeyResponse> - Removes a searchable key from a customer profile.
-
deleteProfileObject(
{required String domainName, required String objectTypeName, required String profileId, required String profileObjectUniqueKey}) → Future< DeleteProfileObjectResponse> - Removes an object associated with a profile of a given ProfileObjectType.
-
deleteProfileObjectType(
{required String domainName, required String objectTypeName}) → Future< DeleteProfileObjectTypeResponse> - Removes a ProfileObjectType from a specific domain as well as removes all the ProfileObjects of that type. It also disables integrations from this specific ProfileObjectType. In addition, it scrubs all of the fields of the standard profile that were populated from this ProfileObjectType.
-
deleteRecommender(
{required String domainName, required String recommenderName}) → Future< void> - Deletes a recommender.
-
deleteRecommenderFilter(
{required String domainName, required String recommenderFilterName}) → Future< DeleteRecommenderFilterResponse> - Deletes a recommender filter from a domain.
-
deleteRecommenderSchema(
{required String domainName, required String recommenderSchemaName}) → Future< void> - Deletes a recommender schema from a domain.
-
deleteSegmentDefinition(
{required String domainName, required String segmentDefinitionName}) → Future< DeleteSegmentDefinitionResponse> - Deletes a segment definition from the domain.
-
deleteWorkflow(
{required String domainName, required String workflowId}) → Future< void> - Deletes the specified workflow and all its corresponding resources. This is an async process.
-
detectProfileObjectType(
{required String domainName, required List< String> objects}) → Future<DetectProfileObjectTypeResponse> - The process of detecting profile object type mapping by using given objects.
-
getAutoMergingPreview(
{required ConflictResolution conflictResolution, required Consolidation consolidation, required String domainName, double? minAllowedConfidenceScoreForMerging}) → Future< GetAutoMergingPreviewResponse> - Tests the auto-merging settings of your Identity Resolution Job without merging your data. It randomly selects a sample of matching groups from the existing matching results, and applies the automerging settings that you provided. You can then view the number of profiles in the sample, the number of matches, and the number of profiles identified to be merged. This enables you to evaluate the accuracy of the attributes in your matching list.
-
getCalculatedAttributeDefinition(
{required String calculatedAttributeName, required String domainName}) → Future< GetCalculatedAttributeDefinitionResponse> - Provides more information on a calculated attribute definition for Customer Profiles.
-
getCalculatedAttributeForProfile(
{required String calculatedAttributeName, required String domainName, required String profileId}) → Future< GetCalculatedAttributeForProfileResponse> - Retrieve a calculated attribute for a customer profile.
-
getDomain(
{required String domainName}) → Future< GetDomainResponse> - Returns information about a specific domain.
-
getDomainLayout(
{required String domainName, required String layoutDefinitionName}) → Future< GetDomainLayoutResponse> - Gets the layout to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
-
getDomainObjectType(
{required String domainName, required String objectTypeName}) → Future< GetDomainObjectTypeResponse> - Return a DomainObjectType for the input Domain and ObjectType names.
-
getEventStream(
{required String domainName, required String eventStreamName}) → Future< GetEventStreamResponse> - Returns information about the specified event stream in a specific domain.
-
getEventTrigger(
{required String domainName, required String eventTriggerName}) → Future< GetEventTriggerResponse> - Get a specific Event Trigger from the domain.
-
getIdentityResolutionJob(
{required String domainName, required String jobId}) → Future< GetIdentityResolutionJobResponse> - Returns information about an Identity Resolution Job in a specific domain.
-
getIntegration(
{required String domainName, required String uri}) → Future< GetIntegrationResponse> - Returns an integration for a domain.
-
getMatches(
{required String domainName, int? maxResults, String? nextToken}) → Future< GetMatchesResponse> -
Before calling this API, use CreateDomain
or UpdateDomain
to enable identity resolution: set
Matchingto true. -
getObjectTypeAttributeStatistics(
{required String attributeName, required String domainName, required String objectTypeName}) → Future< GetObjectTypeAttributeStatisticsResponse> - The GetObjectTypeAttributeValues API delivers statistical insights about attributes within a specific object type, but is exclusively available for domains with data store enabled. This API performs daily calculations to provide statistical information about your attribute values, helping you understand patterns and trends in your data. The statistical calculations are performed once per day, providing a consistent snapshot of your attribute data characteristics.
-
getProfileHistoryRecord(
{required String domainName, required String id, required String profileId}) → Future< GetProfileHistoryRecordResponse> - Returns a history record for a specific profile, for a specific domain.
-
getProfileObjectType(
{required String domainName, required String objectTypeName}) → Future< GetProfileObjectTypeResponse> - Returns the object types for a specific domain.
-
getProfileObjectTypeTemplate(
{required String templateId}) → Future< GetProfileObjectTypeTemplateResponse> - Returns the template information for a specific object type.
-
getProfileRecommendations(
{required String domainName, required String profileId, required String recommenderName, List< String> ? candidateIds, Map<String, String> ? context, int? maxResults, MetadataConfig? metadataConfig, List<RecommenderFilter> ? recommenderFilters, List<RecommenderPromotionalFilter> ? recommenderPromotionalFilters}) → Future<GetProfileRecommendationsResponse> - Fetches the recommendations for a profile in the input Customer Profiles domain. Fetches all the profile recommendations
-
getRecommender(
{required String domainName, required String recommenderName, int? trainingMetricsCount}) → Future< GetRecommenderResponse> - Retrieves a recommender.
-
getRecommenderFilter(
{required String domainName, required String recommenderFilterName}) → Future< GetRecommenderFilterResponse> - Retrieves information about a specific recommender filter in a domain.
-
getRecommenderSchema(
{required String domainName, required String recommenderSchemaName}) → Future< GetRecommenderSchemaResponse> - Retrieves information about a specific recommender schema in a domain.
-
getSegmentDefinition(
{required String domainName, required String segmentDefinitionName}) → Future< GetSegmentDefinitionResponse> - Gets a segment definition from the domain.
-
getSegmentEstimate(
{required String domainName, required String estimateId}) → Future< GetSegmentEstimateResponse> - Gets the result of a segment estimate query.
-
getSegmentMembership(
{required String domainName, required List< String> profileIds, required String segmentDefinitionName}) → Future<GetSegmentMembershipResponse> - Determines if the given profiles are within a segment.
-
getSegmentSnapshot(
{required String domainName, required String segmentDefinitionName, required String snapshotId}) → Future< GetSegmentSnapshotResponse> - Retrieve the latest status of a segment snapshot.
-
getSimilarProfiles(
{required String domainName, required MatchType matchType, required String searchKey, required String searchValue, int? maxResults, String? nextToken}) → Future< GetSimilarProfilesResponse> -
Returns a set of profiles that belong to the same matching group using the
matchIdorprofileId. You can also specify the type of matching that you want for finding similar profiles using eitherRULE_BASED_MATCHINGorML_BASED_MATCHING. -
getUploadJob(
{required String domainName, required String jobId}) → Future< GetUploadJobResponse> - This API retrieves the details of a specific upload job.
-
getUploadJobPath(
{required String domainName, required String jobId}) → Future< GetUploadJobPathResponse> - This API retrieves the pre-signed URL and client token for uploading the file associated with the upload job.
-
getWorkflow(
{required String domainName, required String workflowId}) → Future< GetWorkflowResponse> - Get details of specified workflow.
-
getWorkflowSteps(
{required String domainName, required String workflowId, int? maxResults, String? nextToken}) → Future< GetWorkflowStepsResponse> - Get granular list of steps in workflow.
-
listAccountIntegrations(
{required String uri, bool? includeHidden, int? maxResults, String? nextToken}) → Future< ListAccountIntegrationsResponse> - Lists all of the integrations associated to a specific URI in the AWS account.
-
listCalculatedAttributeDefinitions(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListCalculatedAttributeDefinitionsResponse> - Lists calculated attribute definitions for Customer Profiles
-
listCalculatedAttributesForProfile(
{required String domainName, required String profileId, int? maxResults, String? nextToken}) → Future< ListCalculatedAttributesForProfileResponse> - Retrieve a list of calculated attributes for a customer profile.
-
listDomainLayouts(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListDomainLayoutsResponse> - Lists the existing layouts that can be used to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
-
listDomainObjectTypes(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListDomainObjectTypesResponse> - List all DomainObjectType(s) in a Customer Profiles domain.
-
listDomains(
{int? maxResults, String? nextToken}) → Future< ListDomainsResponse> - Returns a list of all the domains for an AWS account that have been created.
-
listEventStreams(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListEventStreamsResponse> - Returns a list of all the event streams in a specific domain.
-
listEventTriggers(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListEventTriggersResponse> - List all Event Triggers under a domain.
-
listIdentityResolutionJobs(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListIdentityResolutionJobsResponse> -
Lists all of the Identity Resolution Jobs in your domain. The response
sorts the list by
JobStartTime. -
listIntegrations(
{required String domainName, bool? includeHidden, int? maxResults, String? nextToken}) → Future< ListIntegrationsResponse> - Lists all of the integrations in your domain.
-
listObjectTypeAttributes(
{required String domainName, required String objectTypeName, int? maxResults, String? nextToken}) → Future< ListObjectTypeAttributesResponse> - Fetch the possible attribute values given the attribute name.
-
listObjectTypeAttributeValues(
{required String attributeName, required String domainName, required String objectTypeName, int? maxResults, String? nextToken}) → Future< ListObjectTypeAttributeValuesResponse> - The ListObjectTypeAttributeValues API provides access to the most recent distinct values for any specified attribute, making it valuable for real-time data validation and consistency checks within your object types. This API works across domain, supporting both custom and standard object types. The API accepts the object type name, attribute name, and domain name as input parameters and returns values up to the storage limit of approximately 350KB.
-
listProfileAttributeValues(
{required String attributeName, required String domainName}) → Future< ProfileAttributeValuesResponse> - Fetch the possible attribute values given the attribute name.
-
listProfileHistoryRecords(
{required String domainName, required String profileId, ActionType? actionType, int? maxResults, String? nextToken, String? objectTypeName, String? performedBy}) → Future< ListProfileHistoryRecordsResponse> - Returns a list of history records for a specific profile, for a specific domain.
-
listProfileObjects(
{required String domainName, required String objectTypeName, required String profileId, int? maxResults, String? nextToken, ObjectFilter? objectFilter}) → Future< ListProfileObjectsResponse> - Returns a list of objects associated with a profile of a given ProfileObjectType.
-
listProfileObjectTypes(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListProfileObjectTypesResponse> - Lists all of the templates available within the service.
-
listProfileObjectTypeTemplates(
{int? maxResults, String? nextToken}) → Future< ListProfileObjectTypeTemplatesResponse> - Lists all of the template information for object types.
-
listRecommenderFilters(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListRecommenderFiltersResponse> - Returns a list of recommender filters in the specified domain.
-
listRecommenderRecipes(
{int? maxResults, String? nextToken}) → Future< ListRecommenderRecipesResponse> - Returns a list of available recommender recipes that can be used to create recommenders.
-
listRecommenders(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListRecommendersResponse> - Returns a list of recommenders in the specified domain.
-
listRecommenderSchemas(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListRecommenderSchemasResponse> - Returns a list of recommender schemas in the specified domain.
-
listRuleBasedMatches(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListRuleBasedMatchesResponse> -
Returns a set of
MatchIdsthat belong to the given domain. -
listSegmentDefinitions(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListSegmentDefinitionsResponse> - Lists all segment definitions under a domain.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Displays the tags associated with an Amazon Connect Customer Profiles resource. In Connect Customer Profiles, domains, profile object types, and integrations can be tagged.
-
listUploadJobs(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListUploadJobsResponse> - This API retrieves a list of upload jobs for the specified domain.
-
listWorkflows(
{required String domainName, int? maxResults, String? nextToken, DateTime? queryEndDate, DateTime? queryStartDate, Status? status, WorkflowType? workflowType}) → Future< ListWorkflowsResponse> - Query to list all workflows.
-
mergeProfiles(
{required String domainName, required String mainProfileId, required List< String> profileIdsToBeMerged, FieldSourceProfileIds? fieldSourceProfileIds}) → Future<MergeProfilesResponse> - Runs an AWS Lambda job that does the following:
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putDomainObjectType(
{required String domainName, required Map< String, DomainObjectTypeField> fields, required String objectTypeName, String? description, String? encryptionKey, Map<String, String> ? tags}) → Future<PutDomainObjectTypeResponse> - Create/Update a DomainObjectType in a Customer Profiles domain. To create a new DomainObjectType, Data Store needs to be enabled on the Domain.
-
putIntegration(
{required String domainName, List< String> ? eventTriggerNames, FlowDefinition? flowDefinition, String? objectTypeName, Map<String, String> ? objectTypeNames, String? roleArn, Scope? scope, Map<String, String> ? tags, String? uri}) → Future<PutIntegrationResponse> - Adds an integration between the service and a third-party service, which includes Amazon AppFlow and Amazon Connect.
-
putProfileObject(
{required String domainName, required String object, required String objectTypeName}) → Future< PutProfileObjectResponse> - Adds additional objects to customer profiles of a given ObjectType.
-
putProfileObjectType(
{required String description, required String domainName, required String objectTypeName, bool? allowProfileCreation, String? encryptionKey, int? expirationDays, Map< String, ObjectTypeField> ? fields, Map<String, List< ? keys, int? maxProfileObjectCount, String? sourceLastUpdatedTimestampFormat, int? sourcePriority, Map<ObjectTypeKey> >String, String> ? tags, String? templateId}) → Future<PutProfileObjectTypeResponse> - Defines a ProfileObjectType.
-
searchProfiles(
{required String domainName, required String keyName, required List< String> values, List<AdditionalSearchKey> ? additionalSearchKeys, LogicalOperator? logicalOperator, int? maxResults, String? nextToken}) → Future<SearchProfilesResponse> -
Searches for profiles within a specific domain using one or more
predefined search keys (e.g., _fullName, _phone, _email, _account, etc.)
and/or custom-defined search keys. A search key is a data type pair that
consists of a
KeyNameandValueslist. -
startRecommender(
{required String domainName, required String recommenderName}) → Future< void> - Starts a recommender that was previously stopped. Starting a recommender resumes its ability to generate recommendations.
-
startUploadJob(
{required String domainName, required String jobId}) → Future< void> - This API starts the processing of an upload job to ingest profile data.
-
stopRecommender(
{required String domainName, required String recommenderName}) → Future< void> - Stops a recommender, suspending its ability to generate recommendations. The recommender can be restarted later using StartRecommender.
-
stopUploadJob(
{required String domainName, required String jobId}) → Future< void> - This API stops the processing of an upload job.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified Amazon Connect Customer Profiles resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Connect Customer Profiles, domains, profile object types, and integrations can be tagged.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from the specified Amazon Connect Customer Profiles resource. In Connect Customer Profiles, domains, profile object types, and integrations can be tagged.
-
updateCalculatedAttributeDefinition(
{required String calculatedAttributeName, required String domainName, Conditions? conditions, String? description, String? displayName}) → Future< UpdateCalculatedAttributeDefinitionResponse> - Updates an existing calculated attribute definition. When updating the Conditions, note that increasing the date range of a calculated attribute will not trigger inclusion of historical data greater than the current date range.
-
updateDomain(
{required String domainName, DataStoreRequest? dataStore, String? deadLetterQueueUrl, String? defaultEncryptionKey, int? defaultExpirationDays, MatchingRequest? matching, RuleBasedMatchingRequest? ruleBasedMatching, Map< String, String> ? tags}) → Future<UpdateDomainResponse> - Updates the properties of a domain, including creating or selecting a dead letter queue or an encryption key.
-
updateDomainLayout(
{required String domainName, required String layoutDefinitionName, String? description, String? displayName, bool? isDefault, String? layout, LayoutType? layoutType}) → Future< UpdateDomainLayoutResponse> - Updates the layout used to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
-
updateEventTrigger(
{required String domainName, required String eventTriggerName, String? description, List< EventTriggerCondition> ? eventTriggerConditions, EventTriggerLimits? eventTriggerLimits, String? objectTypeName, String? segmentFilter}) → Future<UpdateEventTriggerResponse> - Update the properties of an Event Trigger.
-
updateProfile(
{required String domainName, required String profileId, String? accountNumber, String? additionalInformation, UpdateAddress? address, Map< String, String> ? attributes, UpdateAddress? billingAddress, String? birthDate, String? businessEmailAddress, String? businessName, String? businessPhoneNumber, String? emailAddress, EngagementPreferences? engagementPreferences, String? firstName, Gender? gender, String? genderString, String? homePhoneNumber, String? lastName, UpdateAddress? mailingAddress, String? middleName, String? mobilePhoneNumber, PartyType? partyType, String? partyTypeString, String? personalEmailAddress, String? phoneNumber, ProfileType? profileType, UpdateAddress? shippingAddress}) → Future<UpdateProfileResponse> - Updates the properties of a profile. The ProfileId is required for updating a customer profile.
-
updateRecommender(
{required String domainName, required String recommenderName, String? description, RecommenderConfig? recommenderConfig}) → Future< UpdateRecommenderResponse> - Updates the properties of an existing recommender, allowing you to modify its configuration and description.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited