createIntegrationWorkflow method
Creates an integration workflow. An integration workflow is an async process which ingests historic data and sets up an integration for ongoing updates. The supported Amazon AppFlow sources are Salesforce, ServiceNow, and Marketo.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter integrationConfig :
Configuration data for integration workflow.
Parameter objectTypeName :
The name of the profile object type.
Parameter roleArn :
The Amazon Resource Name (ARN) of the IAM role. Customer Profiles assumes
this role to create resources on your behalf as part of workflow
execution.
Parameter workflowType :
The type of workflow. The only supported value is APPFLOW_INTEGRATION.
Parameter tags :
The tags used to organize, track, or control access for this resource.
Implementation
Future<CreateIntegrationWorkflowResponse> createIntegrationWorkflow({
required String domainName,
required IntegrationConfig integrationConfig,
required String objectTypeName,
required String roleArn,
required WorkflowType workflowType,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'IntegrationConfig': integrationConfig,
'ObjectTypeName': objectTypeName,
'RoleArn': roleArn,
'WorkflowType': workflowType.value,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/workflows/integrations',
exceptionFnMap: _exceptionFns,
);
return CreateIntegrationWorkflowResponse.fromJson(response);
}