deleteCalculatedAttributeDefinition method

Future<void> deleteCalculatedAttributeDefinition({
  1. required String calculatedAttributeName,
  2. required String domainName,
})

Deletes an existing calculated attribute definition. Note that deleting a default calculated attribute is possible, however once deleted, you will be unable to undo that action and will need to recreate it on your own using the CreateCalculatedAttributeDefinition API if you want it back.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter calculatedAttributeName : The unique name of the calculated attribute.

Parameter domainName : The unique name of the domain.

Implementation

Future<void> deleteCalculatedAttributeDefinition({
  required String calculatedAttributeName,
  required String domainName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/calculated-attributes/${Uri.encodeComponent(calculatedAttributeName)}',
    exceptionFnMap: _exceptionFns,
  );
}