deleteDomain method

Future<DeleteDomainResponse> deleteDomain({
  1. required String domainName,
})

Deletes a specific domain and all of its customer data, such as customer profile attributes and their related objects.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain.

Implementation

Future<DeleteDomainResponse> deleteDomain({
  required String domainName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/domains/${Uri.encodeComponent(domainName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDomainResponse.fromJson(response);
}