deleteProfileObject method

Future<DeleteProfileObjectResponse> deleteProfileObject({
  1. required String domainName,
  2. required String objectTypeName,
  3. required String profileId,
  4. required String profileObjectUniqueKey,
})

Removes an object associated with a profile of a given ProfileObjectType.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain.

Parameter objectTypeName : The name of the profile object type.

Parameter profileId : The unique identifier of a customer profile.

Parameter profileObjectUniqueKey : The unique identifier of the profile object generated by the service.

Implementation

Future<DeleteProfileObjectResponse> deleteProfileObject({
  required String domainName,
  required String objectTypeName,
  required String profileId,
  required String profileObjectUniqueKey,
}) async {
  final $payload = <String, dynamic>{
    'ObjectTypeName': objectTypeName,
    'ProfileId': profileId,
    'ProfileObjectUniqueKey': profileObjectUniqueKey,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/profiles/objects/delete',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteProfileObjectResponse.fromJson(response);
}