deleteProfileObjectType method

Future<DeleteProfileObjectTypeResponse> deleteProfileObjectType({
  1. required String domainName,
  2. required String objectTypeName,
})

Removes a ProfileObjectType from a specific domain as well as removes all the ProfileObjects of that type. It also disables integrations from this specific ProfileObjectType. In addition, it scrubs all of the fields of the standard profile that were populated from this ProfileObjectType.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain.

Parameter objectTypeName : The name of the profile object type.

Implementation

Future<DeleteProfileObjectTypeResponse> deleteProfileObjectType({
  required String domainName,
  required String objectTypeName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/object-types/${Uri.encodeComponent(objectTypeName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteProfileObjectTypeResponse.fromJson(response);
}