getAutoMergingPreview method
Tests the auto-merging settings of your Identity Resolution Job without merging your data. It randomly selects a sample of matching groups from the existing matching results, and applies the automerging settings that you provided. You can then view the number of profiles in the sample, the number of matches, and the number of profiles identified to be merged. This enables you to evaluate the accuracy of the attributes in your matching list.
You can't view which profiles are matched and would be merged.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter conflictResolution :
How the auto-merging process should resolve conflicts between different
profiles.
Parameter consolidation :
A list of matching attributes that represent matching criteria.
Parameter domainName :
The unique name of the domain.
Parameter minAllowedConfidenceScoreForMerging :
Minimum confidence score required for profiles within a matching group to
be merged during the auto-merge process.
Implementation
Future<GetAutoMergingPreviewResponse> getAutoMergingPreview({
required ConflictResolution conflictResolution,
required Consolidation consolidation,
required String domainName,
double? minAllowedConfidenceScoreForMerging,
}) async {
_s.validateNumRange(
'minAllowedConfidenceScoreForMerging',
minAllowedConfidenceScoreForMerging,
0.0,
1.0,
);
final $payload = <String, dynamic>{
'ConflictResolution': conflictResolution,
'Consolidation': consolidation,
if (minAllowedConfidenceScoreForMerging != null)
'MinAllowedConfidenceScoreForMerging':
minAllowedConfidenceScoreForMerging,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/identity-resolution-jobs/auto-merging-preview',
exceptionFnMap: _exceptionFns,
);
return GetAutoMergingPreviewResponse.fromJson(response);
}