getDomainLayout method

Future<GetDomainLayoutResponse> getDomainLayout({
  1. required String domainName,
  2. required String layoutDefinitionName,
})

Gets the layout to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain.

Parameter layoutDefinitionName : The unique name of the layout.

Implementation

Future<GetDomainLayoutResponse> getDomainLayout({
  required String domainName,
  required String layoutDefinitionName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/layouts/${Uri.encodeComponent(layoutDefinitionName)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDomainLayoutResponse.fromJson(response);
}