getIdentityResolutionJob method

Future<GetIdentityResolutionJobResponse> getIdentityResolutionJob({
  1. required String domainName,
  2. required String jobId,
})

Returns information about an Identity Resolution Job in a specific domain.

Identity Resolution Jobs are set up using the Amazon Connect admin console. For more information, see Use Identity Resolution to consolidate similar profiles.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain.

Parameter jobId : The unique identifier of the Identity Resolution Job.

Implementation

Future<GetIdentityResolutionJobResponse> getIdentityResolutionJob({
  required String domainName,
  required String jobId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/identity-resolution-jobs/${Uri.encodeComponent(jobId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetIdentityResolutionJobResponse.fromJson(response);
}