getObjectTypeAttributeStatistics method

Future<GetObjectTypeAttributeStatisticsResponse> getObjectTypeAttributeStatistics({
  1. required String attributeName,
  2. required String domainName,
  3. required String objectTypeName,
})

The GetObjectTypeAttributeValues API delivers statistical insights about attributes within a specific object type, but is exclusively available for domains with data store enabled. This API performs daily calculations to provide statistical information about your attribute values, helping you understand patterns and trends in your data. The statistical calculations are performed once per day, providing a consistent snapshot of your attribute data characteristics.

During the first period after enabling data vault (unless a calculation cycle occurs, which happens once daily).

For attributes that don't contain numeric values.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter attributeName : The attribute name.

Parameter domainName : The unique name of the domain.

Parameter objectTypeName : The unique name of the domain object type.

Implementation

Future<GetObjectTypeAttributeStatisticsResponse>
    getObjectTypeAttributeStatistics({
  required String attributeName,
  required String domainName,
  required String objectTypeName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/object-types/${Uri.encodeComponent(objectTypeName)}/attributes/${Uri.encodeComponent(attributeName)}/statistics',
    exceptionFnMap: _exceptionFns,
  );
  return GetObjectTypeAttributeStatisticsResponse.fromJson(response);
}