getUploadJob method

Future<GetUploadJobResponse> getUploadJob({
  1. required String domainName,
  2. required String jobId,
})

This API retrieves the details of a specific upload job.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain containing the upload job.

Parameter jobId : The unique identifier of the upload job to retrieve.

Implementation

Future<GetUploadJobResponse> getUploadJob({
  required String domainName,
  required String jobId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/upload-jobs/${Uri.encodeComponent(jobId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetUploadJobResponse.fromJson(response);
}