getUploadJobPath method
This API retrieves the pre-signed URL and client token for uploading the file associated with the upload job.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain containing the upload job.
Parameter jobId :
The unique identifier of the upload job to retrieve the upload path for.
This is generated from the CreateUploadJob API.
Implementation
Future<GetUploadJobPathResponse> getUploadJobPath({
required String domainName,
required String jobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/upload-jobs/${Uri.encodeComponent(jobId)}/path',
exceptionFnMap: _exceptionFns,
);
return GetUploadJobPathResponse.fromJson(response);
}