listDomainLayouts method
Lists the existing layouts that can be used to view data for a specific domain. This API can only be invoked from the Amazon Connect admin website.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter maxResults :
The maximum number of objects returned per page.
Parameter nextToken :
Identifies the next page of results to return.
Implementation
Future<ListDomainLayoutsResponse> listDomainLayouts({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domains/${Uri.encodeComponent(domainName)}/layouts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDomainLayoutsResponse.fromJson(response);
}