listIdentityResolutionJobs method
Lists all of the Identity Resolution Jobs in your domain. The response
sorts the list by JobStartTime.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListIdentityResolutionJobsResponse> listIdentityResolutionJobs({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/identity-resolution-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIdentityResolutionJobsResponse.fromJson(response);
}