listRecommenderRecipes method

Future<ListRecommenderRecipesResponse> listRecommenderRecipes({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of available recommender recipes that can be used to create recommenders.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ThrottlingException.

Parameter maxResults : The maximum number of recommender recipes to return in the response. The default value is 100.

Parameter nextToken : A token received from a previous ListRecommenderRecipes call to retrieve the next page of results.

Implementation

Future<ListRecommenderRecipesResponse> listRecommenderRecipes({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    10,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/recommender-recipes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRecommenderRecipesResponse.fromJson(response);
}