listRecommenders method
Returns a list of recommenders in the specified domain.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter maxResults :
The maximum number of recommenders to return in the response. The default
value is 100.
Parameter nextToken :
A token received from a previous ListRecommenders call to retrieve the
next page of results.
Implementation
Future<ListRecommendersResponse> listRecommenders({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domains/${Uri.encodeComponent(domainName)}/recommenders',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRecommendersResponse.fromJson(response);
}