listUploadJobs method
This API retrieves a list of upload jobs for the specified domain.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain to list upload jobs for.
Parameter maxResults :
The maximum number of upload jobs to return per page.
Parameter nextToken :
The pagination token from the previous call to retrieve the next page of
results.
Implementation
Future<ListUploadJobsResponse> listUploadJobs({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domains/${Uri.encodeComponent(domainName)}/upload-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListUploadJobsResponse.fromJson(response);
}