startUploadJob method

Future<void> startUploadJob({
  1. required String domainName,
  2. required String jobId,
})

This API starts the processing of an upload job to ingest profile data.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter domainName : The unique name of the domain containing the upload job to start.

Parameter jobId : The unique identifier of the upload job to start.

Implementation

Future<void> startUploadJob({
  required String domainName,
  required String jobId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/domains/${Uri.encodeComponent(domainName)}/upload-jobs/${Uri.encodeComponent(jobId)}',
    exceptionFnMap: _exceptionFns,
  );
}