updateRecommender method
Updates the properties of an existing recommender, allowing you to modify its configuration and description.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter recommenderName :
The name of the recommender to update.
Parameter description :
The new description to assign to the recommender.
Parameter recommenderConfig :
The new configuration settings to apply to the recommender, including
updated parameters and settings that define its behavior.
Implementation
Future<UpdateRecommenderResponse> updateRecommender({
required String domainName,
required String recommenderName,
String? description,
RecommenderConfig? recommenderConfig,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'Description': description,
if (recommenderConfig != null) 'RecommenderConfig': recommenderConfig,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/recommenders/${Uri.encodeComponent(recommenderName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateRecommenderResponse.fromJson(response);
}