listJobRuns method

Future<ListJobRunsResponse> listJobRuns({
  1. required String name,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all of the previous runs of a particular DataBrew job.

May throw ResourceNotFoundException. May throw ValidationException.

Parameter name : The name of the job.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : The token returned by a previous call to retrieve the next set of results.

Implementation

Future<ListJobRunsResponse> listJobRuns({
  required String name,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/jobs/${Uri.encodeComponent(name)}/jobRuns',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListJobRunsResponse.fromJson(response);
}