listProjects method

Future<ListProjectsResponse> listProjects({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all of the DataBrew projects that are defined.

May throw ValidationException.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : The token returned by a previous call to retrieve the next set of results.

Implementation

Future<ListProjectsResponse> listProjects({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/projects',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListProjectsResponse.fromJson(response);
}