listRecipeVersions method

Future<ListRecipeVersionsResponse> listRecipeVersions({
  1. required String name,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the versions of a particular DataBrew recipe, except for LATEST_WORKING.

May throw ValidationException.

Parameter name : The name of the recipe for which to return version information.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : The token returned by a previous call to retrieve the next set of results.

Implementation

Future<ListRecipeVersionsResponse> listRecipeVersions({
  required String name,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    'name': [name],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/recipeVersions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRecipeVersionsResponse.fromJson(response);
}