listRecipes method

Future<ListRecipesResponse> listRecipes({
  1. int? maxResults,
  2. String? nextToken,
  3. String? recipeVersion,
})

Lists all of the DataBrew recipes that are defined.

May throw ValidationException.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : The token returned by a previous call to retrieve the next set of results.

Parameter recipeVersion : Return only those recipes with a version identifier of LATEST_WORKING or LATEST_PUBLISHED. If RecipeVersion is omitted, ListRecipes returns all of the LATEST_PUBLISHED recipe versions.

Valid values: LATEST_WORKING | LATEST_PUBLISHED

Implementation

Future<ListRecipesResponse> listRecipes({
  int? maxResults,
  String? nextToken,
  String? recipeVersion,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (recipeVersion != null) 'recipeVersion': [recipeVersion],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/recipes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRecipesResponse.fromJson(response);
}