listSchedules method
Lists the DataBrew schedules that are defined.
May throw ValidationException.
Parameter jobName :
The name of the job that these schedules apply to.
Parameter maxResults :
The maximum number of results to return in this request.
Parameter nextToken :
The token returned by a previous call to retrieve the next set of results.
Implementation
Future<ListSchedulesResponse> listSchedules({
String? jobName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (jobName != null) 'jobName': [jobName],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/schedules',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSchedulesResponse.fromJson(response);
}