updateRecipe method

Future<UpdateRecipeResponse> updateRecipe({
  1. required String name,
  2. String? description,
  3. List<RecipeStep>? steps,
})

Modifies the definition of the LATEST_WORKING version of a DataBrew recipe.

May throw ResourceNotFoundException. May throw ValidationException.

Parameter name : The name of the recipe to be updated.

Parameter description : A description of the recipe.

Parameter steps : One or more steps to be performed by the recipe. Each step consists of an action, and the conditions under which the action should succeed.

Implementation

Future<UpdateRecipeResponse> updateRecipe({
  required String name,
  String? description,
  List<RecipeStep>? steps,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'Description': description,
    if (steps != null) 'Steps': steps,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/recipes/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRecipeResponse.fromJson(response);
}