updateSchedule method

Future<UpdateScheduleResponse> updateSchedule({
  1. required String cronExpression,
  2. required String name,
  3. List<String>? jobNames,
})

Modifies the definition of an existing DataBrew schedule.

May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ValidationException.

Parameter cronExpression : The date or dates and time or times when the jobs are to be run. For more information, see Cron expressions in the Glue DataBrew Developer Guide.

Parameter name : The name of the schedule to update.

Parameter jobNames : The name or names of one or more jobs to be run for this schedule.

Implementation

Future<UpdateScheduleResponse> updateSchedule({
  required String cronExpression,
  required String name,
  List<String>? jobNames,
}) async {
  final $payload = <String, dynamic>{
    'CronExpression': cronExpression,
    if (jobNames != null) 'JobNames': jobNames,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/schedules/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateScheduleResponse.fromJson(response);
}