data_brew_2017_07_25 library
Classes
- AwsClientCredentials
- AWS credentials.
- DataBrew
- Glue DataBrew is a visual, cloud-scale data-preparation service. DataBrew simplifies data preparation tasks, targeting data issues that are hard to spot and time-consuming to fix. DataBrew empowers users of all technical levels to visualize the data and perform one-click data transformations, with no coding required.