DataExchange class

AWS Data Exchange is a service that makes it easy for AWS customers to exchange data in the cloud. You can use the AWS Data Exchange APIs to create, update, manage, and access file-based data set in the AWS Cloud.

As a subscriber, you can view and access the data sets that you have an entitlement to through a subscription. You can use the APIs to download or copy your entitled data sets to Amazon Simple Storage Service (Amazon S3) for use across a variety of AWS analytics and machine learning services.

As a provider, you can create and manage your data sets that you would like to publish to a product. Being able to package and provide your data sets into products requires a few steps to determine eligibility. For more information, visit the AWS Data Exchange User Guide.

A data set is a collection of data that can be changed or updated over time. Data sets can be updated using revisions, which represent a new version or incremental change to a data set. A revision contains one or more assets. An asset in AWS Data Exchange is a piece of data that can be stored as an Amazon S3 object, Redshift datashare, API Gateway API, AWS Lake Formation data permission, or Amazon S3 data access. The asset can be a structured data file, an image file, or some other data file. Jobs are asynchronous import or export operations used to create or copy assets.

Constructors

DataExchange({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptDataGrant({required String dataGrantArn}) Future<AcceptDataGrantResponse>
This operation accepts a data grant.
cancelJob({required String jobId}) Future<void>
This operation cancels a job. Jobs can be cancelled only when they are in the WAITING state.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createDataGrant({required GrantDistributionScope grantDistributionScope, required String name, required String receiverPrincipal, required String sourceDataSetId, String? description, DateTime? endsAt, Map<String, String>? tags}) Future<CreateDataGrantResponse>
This operation creates a data grant.
createDataSet({required AssetType assetType, required String description, required String name, Map<String, String>? tags}) Future<CreateDataSetResponse>
This operation creates a data set.
createEventAction({required Action action, required Event event, Map<String, String>? tags}) Future<CreateEventActionResponse>
This operation creates an event action.
createJob({required RequestDetails details, required Type type, AssetConfiguration? assetConfiguration}) Future<CreateJobResponse>
This operation creates a job.
createRevision({required String dataSetId, String? comment, Map<String, String>? tags}) Future<CreateRevisionResponse>
This operation creates a revision for a data set.
deleteAsset({required String assetId, required String dataSetId, required String revisionId}) Future<void>
This operation deletes an asset.
deleteDataGrant({required String dataGrantId}) Future<void>
This operation deletes a data grant.
deleteDataSet({required String dataSetId}) Future<void>
This operation deletes a data set.
deleteEventAction({required String eventActionId}) Future<void>
This operation deletes the event action.
deleteRevision({required String dataSetId, required String revisionId}) Future<void>
This operation deletes a revision.
getAsset({required String assetId, required String dataSetId, required String revisionId}) Future<GetAssetResponse>
This operation returns information about an asset.
getDataGrant({required String dataGrantId}) Future<GetDataGrantResponse>
This operation returns information about a data grant.
getDataSet({required String dataSetId}) Future<GetDataSetResponse>
This operation returns information about a data set.
getEventAction({required String eventActionId}) Future<GetEventActionResponse>
This operation retrieves information about an event action.
getJob({required String jobId}) Future<GetJobResponse>
This operation returns information about a job.
getReceivedDataGrant({required String dataGrantArn}) Future<GetReceivedDataGrantResponse>
This operation returns information about a received data grant.
getRevision({required String dataSetId, required String revisionId}) Future<GetRevisionResponse>
This operation returns information about a revision.
listDataGrants({int? maxResults, String? nextToken}) Future<ListDataGrantsResponse>
This operation returns information about all data grants.
listDataSetRevisions({required String dataSetId, int? maxResults, String? nextToken}) Future<ListDataSetRevisionsResponse>
This operation lists a data set's revisions sorted by CreatedAt in descending order.
listDataSets({int? maxResults, String? nextToken, String? origin}) Future<ListDataSetsResponse>
This operation lists your data sets. When listing by origin OWNED, results are sorted by CreatedAt in descending order. When listing by origin ENTITLED, there is no order.
listEventActions({String? eventSourceId, int? maxResults, String? nextToken}) Future<ListEventActionsResponse>
This operation lists your event actions.
listJobs({String? dataSetId, int? maxResults, String? nextToken, String? revisionId}) Future<ListJobsResponse>
This operation lists your jobs sorted by CreatedAt in descending order.
listReceivedDataGrants({List<AcceptanceStateFilterValue>? acceptanceState, int? maxResults, String? nextToken}) Future<ListReceivedDataGrantsResponse>
This operation returns information about all received data grants.
listRevisionAssets({required String dataSetId, required String revisionId, int? maxResults, String? nextToken}) Future<ListRevisionAssetsResponse>
This operation lists a revision's assets sorted alphabetically in descending order.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
This operation lists the tags on the resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revokeRevision({required String dataSetId, required String revisionId, required String revocationComment}) Future<RevokeRevisionResponse>
This operation revokes subscribers' access to a revision.
sendApiAsset({required String assetId, required String dataSetId, required String revisionId, String? body, String? method, String? path, Map<String, String>? queryStringParameters, Map<String, String>? requestHeaders}) Future<SendApiAssetResponse>
This operation invokes an API Gateway API asset. The request is proxied to the provider’s API Gateway API.
sendDataSetNotification({required String dataSetId, required NotificationType type, String? clientToken, String? comment, NotificationDetails? details, ScopeDetails? scope}) Future<void>
The type of event associated with the data set.
startJob({required String jobId}) Future<void>
This operation starts a job.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
This operation tags a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
This operation removes one or more tags from a resource.
updateAsset({required String assetId, required String dataSetId, required String name, required String revisionId}) Future<UpdateAssetResponse>
This operation updates an asset.
updateDataSet({required String dataSetId, String? description, String? name}) Future<UpdateDataSetResponse>
This operation updates a data set.
updateEventAction({required String eventActionId, Action? action}) Future<UpdateEventActionResponse>
This operation updates the event action.
updateRevision({required String dataSetId, required String revisionId, String? comment, bool? finalized}) Future<UpdateRevisionResponse>
This operation updates a revision.

Operators

operator ==(Object other) bool
The equality operator.
inherited