data_pipeline library

Classes

AwsClientCredentials
AWS credentials.
DataPipeline
AWS Data Pipeline configures and manages a data-driven workflow called a pipeline. AWS Data Pipeline handles the details of scheduling and ensuring that data dependencies are met so that your application can focus on processing the data.