DataSync class
DataSync is an online data movement service that simplifies data migration and helps you quickly, easily, and securely transfer your file or object data to, from, and between Amazon Web Services storage services.
Constructors
- DataSync({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelTaskExecution(
{required String taskExecutionArn}) → Future< void> - Stops an DataSync task execution that's in progress. The transfer of some files are abruptly interrupted. File contents that're transferred to the destination might be incomplete or inconsistent with the source files.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAgent(
{required String activationKey, String? agentName, List< String> ? securityGroupArns, List<String> ? subnetArns, List<TagListEntry> ? tags, String? vpcEndpointId}) → Future<CreateAgentResponse> - Activates an DataSync agent that you deploy in your storage environment. The activation process associates the agent with your Amazon Web Services account.
-
createLocationAzureBlob(
{required AzureBlobAuthenticationType authenticationType, required String containerUrl, AzureAccessTier? accessTier, List< String> ? agentArns, AzureBlobType? blobType, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, AzureBlobSasConfiguration? sasConfiguration, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationAzureBlobResponse> - Creates a transfer location for a Microsoft Azure Blob Storage container. DataSync can use this location as a transfer source or destination. You can make transfers with or without a DataSync agent that connects to your container.
-
createLocationEfs(
{required Ec2Config ec2Config, required String efsFilesystemArn, String? accessPointArn, String? fileSystemAccessRoleArn, EfsInTransitEncryption? inTransitEncryption, String? subdirectory, List< TagListEntry> ? tags}) → Future<CreateLocationEfsResponse> - Creates a transfer location for an Amazon EFS file system. DataSync can use this location as a source or destination for transferring data.
-
createLocationFsxLustre(
{required String fsxFilesystemArn, required List< String> securityGroupArns, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationFsxLustreResponse> - Creates a transfer location for an Amazon FSx for Lustre file system. DataSync can use this location as a source or destination for transferring data.
-
createLocationFsxOntap(
{required FsxProtocol protocol, required List< String> securityGroupArns, required String storageVirtualMachineArn, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationFsxOntapResponse> - Creates a transfer location for an Amazon FSx for NetApp ONTAP file system. DataSync can use this location as a source or destination for transferring data.
-
createLocationFsxOpenZfs(
{required String fsxFilesystemArn, required FsxProtocol protocol, required List< String> securityGroupArns, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationFsxOpenZfsResponse> - Creates a transfer location for an Amazon FSx for OpenZFS file system. DataSync can use this location as a source or destination for transferring data.
-
createLocationFsxWindows(
{required String fsxFilesystemArn, required List< String> securityGroupArns, required String user, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, String? domain, String? password, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationFsxWindowsResponse> - Creates a transfer location for an Amazon FSx for Windows File Server file system. DataSync can use this location as a source or destination for transferring data.
-
createLocationHdfs(
{required List< String> agentArns, required HdfsAuthenticationType authenticationType, required List<HdfsNameNode> nameNodes, int? blockSize, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, Uint8List? kerberosKeytab, Uint8List? kerberosKrb5Conf, String? kerberosPrincipal, String? kmsKeyProviderUri, QopConfiguration? qopConfiguration, int? replicationFactor, String? simpleUser, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationHdfsResponse> - Creates a transfer location for a Hadoop Distributed File System (HDFS). DataSync can use this location as a source or destination for transferring data.
-
createLocationNfs(
{required OnPremConfig onPremConfig, required String serverHostname, required String subdirectory, NfsMountOptions? mountOptions, List< TagListEntry> ? tags}) → Future<CreateLocationNfsResponse> - Creates a transfer location for a Network File System (NFS) file server. DataSync can use this location as a source or destination for transferring data.
-
createLocationObjectStorage(
{required String bucketName, required String serverHostname, String? accessKey, List< String> ? agentArns, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, String? secretKey, Uint8List? serverCertificate, int? serverPort, ObjectStorageServerProtocol? serverProtocol, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationObjectStorageResponse> - Creates a transfer location for an object storage system. DataSync can use this location as a source or destination for transferring data. You can make transfers with or without a DataSync agent.
-
createLocationS3(
{required String s3BucketArn, required S3Config s3Config, List< String> ? agentArns, S3StorageClass? s3StorageClass, String? subdirectory, List<TagListEntry> ? tags}) → Future<CreateLocationS3Response> - Creates a transfer location for an Amazon S3 bucket. DataSync can use this location as a source or destination for transferring data.
-
createLocationSmb(
{required List< String> agentArns, required String serverHostname, required String subdirectory, SmbAuthenticationType? authenticationType, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, List<String> ? dnsIpAddresses, String? domain, Uint8List? kerberosKeytab, Uint8List? kerberosKrb5Conf, String? kerberosPrincipal, SmbMountOptions? mountOptions, String? password, List<TagListEntry> ? tags, String? user}) → Future<CreateLocationSmbResponse> - Creates a transfer location for a Server Message Block (SMB) file server. DataSync can use this location as a source or destination for transferring data.
-
createTask(
{required String destinationLocationArn, required String sourceLocationArn, String? cloudWatchLogGroupArn, List< FilterRule> ? excludes, List<FilterRule> ? includes, ManifestConfig? manifestConfig, String? name, Options? options, TaskSchedule? schedule, List<TagListEntry> ? tags, TaskMode? taskMode, TaskReportConfig? taskReportConfig}) → Future<CreateTaskResponse> - Configures a task, which defines where and how DataSync transfers your data.
-
deleteAgent(
{required String agentArn}) → Future< void> - Removes an DataSync agent resource from your Amazon Web Services account.
-
deleteLocation(
{required String locationArn}) → Future< void> - Deletes a transfer location resource from DataSync.
-
deleteTask(
{required String taskArn}) → Future< void> - Deletes a transfer task resource from DataSync.
-
describeAgent(
{required String agentArn}) → Future< DescribeAgentResponse> - Returns information about an DataSync agent, such as its name, service endpoint type, and status.
-
describeLocationAzureBlob(
{required String locationArn}) → Future< DescribeLocationAzureBlobResponse> - Provides details about how an DataSync transfer location for Microsoft Azure Blob Storage is configured.
-
describeLocationEfs(
{required String locationArn}) → Future< DescribeLocationEfsResponse> - Provides details about how an DataSync transfer location for an Amazon EFS file system is configured.
-
describeLocationFsxLustre(
{required String locationArn}) → Future< DescribeLocationFsxLustreResponse> - Provides details about how an DataSync transfer location for an Amazon FSx for Lustre file system is configured.
-
describeLocationFsxOntap(
{required String locationArn}) → Future< DescribeLocationFsxOntapResponse> - Provides details about how an DataSync transfer location for an Amazon FSx for NetApp ONTAP file system is configured.
-
describeLocationFsxOpenZfs(
{required String locationArn}) → Future< DescribeLocationFsxOpenZfsResponse> - Provides details about how an DataSync transfer location for an Amazon FSx for OpenZFS file system is configured.
-
describeLocationFsxWindows(
{required String locationArn}) → Future< DescribeLocationFsxWindowsResponse> - Provides details about how an DataSync transfer location for an Amazon FSx for Windows File Server file system is configured.
-
describeLocationHdfs(
{required String locationArn}) → Future< DescribeLocationHdfsResponse> - Provides details about how an DataSync transfer location for a Hadoop Distributed File System (HDFS) is configured.
-
describeLocationNfs(
{required String locationArn}) → Future< DescribeLocationNfsResponse> - Provides details about how an DataSync transfer location for a Network File System (NFS) file server is configured.
-
describeLocationObjectStorage(
{required String locationArn}) → Future< DescribeLocationObjectStorageResponse> - Provides details about how an DataSync transfer location for an object storage system is configured.
-
describeLocationS3(
{required String locationArn}) → Future< DescribeLocationS3Response> - Provides details about how an DataSync transfer location for an S3 bucket is configured.
-
describeLocationSmb(
{required String locationArn}) → Future< DescribeLocationSmbResponse> - Provides details about how an DataSync transfer location for a Server Message Block (SMB) file server is configured.
-
describeTask(
{required String taskArn}) → Future< DescribeTaskResponse> - Provides information about a task, which defines where and how DataSync transfers your data.
-
describeTaskExecution(
{required String taskExecutionArn}) → Future< DescribeTaskExecutionResponse> - Provides information about an execution of your DataSync task. You can use this operation to help monitor the progress of an ongoing data transfer or check the results of the transfer.
-
listAgents(
{int? maxResults, String? nextToken}) → Future< ListAgentsResponse> - Returns a list of DataSync agents that belong to an Amazon Web Services account in the Amazon Web Services Region specified in the request.
-
listLocations(
{List< LocationFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListLocationsResponse> - Returns a list of source and destination locations.
-
listTagsForResource(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListTagsForResourceResponse> - Returns all the tags associated with an Amazon Web Services resource.
-
listTaskExecutions(
{int? maxResults, String? nextToken, String? taskArn}) → Future< ListTaskExecutionsResponse> - Returns a list of executions for an DataSync transfer task.
-
listTasks(
{List< TaskFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListTasksResponse> - Returns a list of the DataSync tasks you created.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startTaskExecution(
{required String taskArn, List< FilterRule> ? excludes, List<FilterRule> ? includes, ManifestConfig? manifestConfig, Options? overrideOptions, List<TagListEntry> ? tags, TaskReportConfig? taskReportConfig}) → Future<StartTaskExecutionResponse> - Starts an DataSync transfer task. For each task, you can only run one task execution at a time.
-
tagResource(
{required String resourceArn, required List< TagListEntry> tags}) → Future<void> - Applies a tag to an Amazon Web Services resource. Tags are key-value pairs that can help you manage, filter, and search for your resources.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required List< String> keys, required String resourceArn}) → Future<void> - Removes tags from an Amazon Web Services resource.
-
updateAgent(
{required String agentArn, String? name}) → Future< void> - Updates the name of an DataSync agent.
-
updateLocationAzureBlob(
{required String locationArn, AzureAccessTier? accessTier, List< String> ? agentArns, AzureBlobAuthenticationType? authenticationType, AzureBlobType? blobType, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, AzureBlobSasConfiguration? sasConfiguration, String? subdirectory}) → Future<void> - Modifies the following configurations of the Microsoft Azure Blob Storage transfer location that you're using with DataSync.
-
updateLocationEfs(
{required String locationArn, String? accessPointArn, String? fileSystemAccessRoleArn, EfsInTransitEncryption? inTransitEncryption, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Amazon EFS transfer location that you're using with DataSync.
-
updateLocationFsxLustre(
{required String locationArn, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you're using with DataSync.
-
updateLocationFsxOntap(
{required String locationArn, FsxUpdateProtocol? protocol, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you're using with DataSync.
-
updateLocationFsxOpenZfs(
{required String locationArn, FsxProtocol? protocol, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Amazon FSx for OpenZFS transfer location that you're using with DataSync.
-
updateLocationFsxWindows(
{required String locationArn, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, String? domain, String? password, String? subdirectory, String? user}) → Future< void> - Modifies the following configuration parameters of the Amazon FSx for Windows File Server transfer location that you're using with DataSync.
-
updateLocationHdfs(
{required String locationArn, List< String> ? agentArns, HdfsAuthenticationType? authenticationType, int? blockSize, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, Uint8List? kerberosKeytab, Uint8List? kerberosKrb5Conf, String? kerberosPrincipal, String? kmsKeyProviderUri, List<HdfsNameNode> ? nameNodes, QopConfiguration? qopConfiguration, int? replicationFactor, String? simpleUser, String? subdirectory}) → Future<void> - Modifies the following configuration parameters of the Hadoop Distributed File System (HDFS) transfer location that you're using with DataSync.
-
updateLocationNfs(
{required String locationArn, NfsMountOptions? mountOptions, OnPremConfig? onPremConfig, String? serverHostname, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Network File System (NFS) transfer location that you're using with DataSync.
-
updateLocationObjectStorage(
{required String locationArn, String? accessKey, List< String> ? agentArns, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, String? secretKey, Uint8List? serverCertificate, String? serverHostname, int? serverPort, ObjectStorageServerProtocol? serverProtocol, String? subdirectory}) → Future<void> - Modifies the following configuration parameters of the object storage transfer location that you're using with DataSync.
-
updateLocationS3(
{required String locationArn, S3Config? s3Config, S3StorageClass? s3StorageClass, String? subdirectory}) → Future< void> - Modifies the following configuration parameters of the Amazon S3 transfer location that you're using with DataSync.
-
updateLocationSmb(
{required String locationArn, List< String> ? agentArns, SmbAuthenticationType? authenticationType, CmkSecretConfig? cmkSecretConfig, CustomSecretConfig? customSecretConfig, List<String> ? dnsIpAddresses, String? domain, Uint8List? kerberosKeytab, Uint8List? kerberosKrb5Conf, String? kerberosPrincipal, SmbMountOptions? mountOptions, String? password, String? serverHostname, String? subdirectory, String? user}) → Future<void> - Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you're using with DataSync.
-
updateTask(
{required String taskArn, String? cloudWatchLogGroupArn, List< FilterRule> ? excludes, List<FilterRule> ? includes, ManifestConfig? manifestConfig, String? name, Options? options, TaskSchedule? schedule, TaskReportConfig? taskReportConfig}) → Future<void> - Updates the configuration of a task, which defines where and how DataSync transfers your data.
-
updateTaskExecution(
{required Options options, required String taskExecutionArn}) → Future< void> - Updates the configuration of a running DataSync task execution.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited