listTaskExecutions method

Future<ListTaskExecutionsResponse> listTaskExecutions({
  1. int? maxResults,
  2. String? nextToken,
  3. String? taskArn,
})

Returns a list of executions for an DataSync transfer task.

May throw InternalException. May throw InvalidRequestException.

Parameter maxResults : Specifies how many results you want in the response.

Parameter nextToken : Specifies an opaque string that indicates the position at which to begin the next list of results in the response.

Parameter taskArn : Specifies the Amazon Resource Name (ARN) of the task that you want execution information about.

Implementation

Future<ListTaskExecutionsResponse> listTaskExecutions({
  int? maxResults,
  String? nextToken,
  String? taskArn,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'FmrsService.ListTaskExecutions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (taskArn != null) 'TaskArn': taskArn,
    },
  );

  return ListTaskExecutionsResponse.fromJson(jsonResponse.body);
}