updateLocationFsxOntap method
Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with FSx for ONTAP.
May throw InternalException.
May throw InvalidRequestException.
Parameter locationArn :
Specifies the Amazon Resource Name (ARN) of the FSx for ONTAP transfer
location that you're updating.
Parameter protocol :
Specifies the data transfer protocol that DataSync uses to access your
Amazon FSx file system.
Parameter subdirectory :
Specifies a path to the file share in the storage virtual machine (SVM)
where you want to transfer data to or from.
You can specify a junction path (also known as a mount point), qtree path
(for NFS file shares), or share name (for SMB file shares). For example,
your mount path might be /vol1, /vol1/tree1, or
/share1.
Implementation
Future<void> updateLocationFsxOntap({
required String locationArn,
FsxUpdateProtocol? protocol,
String? subdirectory,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'FmrsService.UpdateLocationFsxOntap'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'LocationArn': locationArn,
if (protocol != null) 'Protocol': protocol,
if (subdirectory != null) 'Subdirectory': subdirectory,
},
);
}