updateLocationSmb method

Future<void> updateLocationSmb({
  1. required String locationArn,
  2. List<String>? agentArns,
  3. SmbAuthenticationType? authenticationType,
  4. CmkSecretConfig? cmkSecretConfig,
  5. CustomSecretConfig? customSecretConfig,
  6. List<String>? dnsIpAddresses,
  7. String? domain,
  8. Uint8List? kerberosKeytab,
  9. Uint8List? kerberosKrb5Conf,
  10. String? kerberosPrincipal,
  11. SmbMountOptions? mountOptions,
  12. String? password,
  13. String? serverHostname,
  14. String? subdirectory,
  15. String? user,
})

Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you're using with DataSync.

For more information, see Configuring DataSync transfers with an SMB file server.

May throw InternalException. May throw InvalidRequestException.

Parameter locationArn : Specifies the ARN of the SMB location that you want to update.

Parameter agentArns : Specifies the DataSync agent (or agents) that can connect to your SMB file server. You specify an agent by using its Amazon Resource Name (ARN).

Parameter authenticationType : Specifies the authentication protocol that DataSync uses to connect to your SMB file server. DataSync supports NTLM (default) and KERBEROS authentication.

For more information, see Providing DataSync access to SMB file servers.

Parameter cmkSecretConfig : Specifies configuration information for a DataSync-managed secret, such as a Password or KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.

Parameter customSecretConfig : Specifies configuration information for a customer-managed secret, such as a Password or KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.

Parameter dnsIpAddresses : Specifies the IP addresses (IPv4 or IPv6) for the DNS servers that your SMB file server belongs to. This parameter applies only if AuthenticationType is set to KERBEROS.

If you have multiple domains in your environment, configuring this parameter makes sure that DataSync connects to the right SMB file server.

Parameter domain : Specifies the Windows domain name that your SMB file server belongs to. This parameter applies only if AuthenticationType is set to NTLM.

If you have multiple domains in your environment, configuring this parameter makes sure that DataSync connects to the right file server.

Parameter kerberosKeytab : Specifies your Kerberos key table (keytab) file, which includes mappings between your Kerberos principal and encryption keys.

To avoid task execution errors, make sure that the Kerberos principal that you use to create the keytab file matches exactly what you specify for KerberosPrincipal.

Parameter kerberosKrb5Conf : Specifies a Kerberos configuration file (krb5.conf) that defines your Kerberos realm configuration.

The file must be base64 encoded. If you're using the CLI, the encoding is done for you.

Parameter kerberosPrincipal : Specifies a Kerberos prinicpal, which is an identity in your Kerberos realm that has permission to access the files, folders, and file metadata in your SMB file server.

A Kerberos principal might look like HOST/kerberosuser@MYDOMAIN.ORG.

Principal names are case sensitive. Your DataSync task execution will fail if the principal that you specify for this parameter doesn’t exactly match the principal that you use to create the keytab file.

Parameter password : Specifies the password of the user who can mount your SMB file server and has permission to access the files and folders involved in your transfer. This parameter applies only if AuthenticationType is set to NTLM.

Parameter serverHostname : Specifies the domain name or IP address (IPv4 or IPv6) of the SMB file server that your DataSync agent connects to.

Parameter subdirectory : Specifies the name of the share exported by your SMB file server where DataSync will read or write data. You can include a subdirectory in the share path (for example, /path/to/subdirectory). Make sure that other SMB clients in your network can also mount this path.

To copy all data in the specified subdirectory, DataSync must be able to mount the SMB share and access all of its data. For more information, see Providing DataSync access to SMB file servers.

Parameter user : Specifies the user name that can mount your SMB file server and has permission to access the files and folders involved in your transfer. This parameter applies only if AuthenticationType is set to NTLM.

For information about choosing a user with the right level of access for your transfer, see Providing DataSync access to SMB file servers.

Implementation

Future<void> updateLocationSmb({
  required String locationArn,
  List<String>? agentArns,
  SmbAuthenticationType? authenticationType,
  CmkSecretConfig? cmkSecretConfig,
  CustomSecretConfig? customSecretConfig,
  List<String>? dnsIpAddresses,
  String? domain,
  Uint8List? kerberosKeytab,
  Uint8List? kerberosKrb5Conf,
  String? kerberosPrincipal,
  SmbMountOptions? mountOptions,
  String? password,
  String? serverHostname,
  String? subdirectory,
  String? user,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'FmrsService.UpdateLocationSmb'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LocationArn': locationArn,
      if (agentArns != null) 'AgentArns': agentArns,
      if (authenticationType != null)
        'AuthenticationType': authenticationType.value,
      if (cmkSecretConfig != null) 'CmkSecretConfig': cmkSecretConfig,
      if (customSecretConfig != null)
        'CustomSecretConfig': customSecretConfig,
      if (dnsIpAddresses != null) 'DnsIpAddresses': dnsIpAddresses,
      if (domain != null) 'Domain': domain,
      if (kerberosKeytab != null)
        'KerberosKeytab': base64Encode(kerberosKeytab),
      if (kerberosKrb5Conf != null)
        'KerberosKrb5Conf': base64Encode(kerberosKrb5Conf),
      if (kerberosPrincipal != null) 'KerberosPrincipal': kerberosPrincipal,
      if (mountOptions != null) 'MountOptions': mountOptions,
      if (password != null) 'Password': password,
      if (serverHostname != null) 'ServerHostname': serverHostname,
      if (subdirectory != null) 'Subdirectory': subdirectory,
      if (user != null) 'User': user,
    },
  );
}