associateGovernedTerms method
Associates governed terms with an asset.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where governed terms are to be associated with an
asset.
Parameter entityIdentifier :
The ID of the asset with which you want to associate a governed term.
Parameter entityType :
The type of the asset with which you want to associate a governed term.
Parameter governedGlossaryTerms :
The glossary terms in a restricted glossary.
Implementation
Future<void> associateGovernedTerms({
required String domainIdentifier,
required String entityIdentifier,
required GovernedEntityType entityType,
required List<String> governedGlossaryTerms,
}) async {
final $payload = <String, dynamic>{
'governedGlossaryTerms': governedGlossaryTerms,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/associate-governed-terms',
exceptionFnMap: _exceptionFns,
);
}