cancelMetadataGenerationRun method

Future<void> cancelMetadataGenerationRun({
  1. required String domainIdentifier,
  2. required String identifier,
})

Cancels the metadata generation run.

Prerequisites:

  • The run must exist and be in a cancelable status (e.g., SUBMITTED, IN_PROGRESS).
  • Runs in SUCCEEDED status cannot be cancelled.
  • User must have access to the run and cancel permissions.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the metadata generation run is to be cancelled.

Parameter identifier : The ID of the metadata generation run.

Implementation

Future<void> cancelMetadataGenerationRun({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/metadata-generation-runs/${Uri.encodeComponent(identifier)}/cancel',
    exceptionFnMap: _exceptionFns,
  );
}