cancelSubscription method

Future<CancelSubscriptionOutput> cancelSubscription({
  1. required String domainIdentifier,
  2. required String identifier,
})

Cancels the subscription to the specified asset.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The unique identifier of the Amazon DataZone domain where the subscription request is being cancelled.

Parameter identifier : The unique identifier of the subscription that is being cancelled.

Implementation

Future<CancelSubscriptionOutput> cancelSubscription({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscriptions/${Uri.encodeComponent(identifier)}/cancel',
    exceptionFnMap: _exceptionFns,
  );
  return CancelSubscriptionOutput.fromJson(response);
}