deleteAssetFilter method
Deletes an asset filter.
Prerequisites:
- The asset filter must exist.
- The domain and asset must not have been deleted.
- Ensure the --identifier refers to a valid filter ID.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter assetIdentifier :
The ID of the data asset.
Parameter domainIdentifier :
The ID of the domain where you want to delete an asset filter.
Parameter identifier :
The ID of the asset filter that you want to delete.
Implementation
Future<void> deleteAssetFilter({
required String assetIdentifier,
required String domainIdentifier,
required String identifier,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/assets/${Uri.encodeComponent(assetIdentifier)}/filters/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}