deleteConnection method

Future<DeleteConnectionOutput> deleteConnection({
  1. required String domainIdentifier,
  2. required String identifier,
})

Deletes and connection. In Amazon DataZone, a connection enables you to connect your resources (domains, projects, and environments) to external resources and services.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the domain where the connection is deleted.

Parameter identifier : The ID of the connection that is deleted.

Implementation

Future<DeleteConnectionOutput> deleteConnection({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/connections/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteConnectionOutput.fromJson(response);
}