deleteDataExportConfiguration method

Future<void> deleteDataExportConfiguration({
  1. required String domainIdentifier,
})

Deletes data export configuration for a domain.

This operation does not delete the S3 table created by the PutDataExportConfiguration operation.

To temporarily disable export without deleting the configuration, use the PutDataExportConfiguration operation with the --no-enable-export flag instead. This allows you to re-enable export for the same domain using the --enable-export flag without deleting S3 table.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The domain ID for which you want to delete the data export configuration.

Implementation

Future<void> deleteDataExportConfiguration({
  required String domainIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-export-configuration',
    exceptionFnMap: _exceptionFns,
  );
}