deleteDataProduct method

Future<void> deleteDataProduct({
  1. required String domainIdentifier,
  2. required String identifier,
})

Deletes a data product in Amazon DataZone.

Prerequisites:

  • The data product must exist and not be deleted or archived.
  • The user must have delete permissions for the data product.
  • Domain and project must be active.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the data product is deleted.

Parameter identifier : The identifier of the data product that is deleted.

Implementation

Future<void> deleteDataProduct({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-products/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}