deleteEnvironmentAction method
Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain in which an environment action is
deleted.
Parameter environmentIdentifier :
The ID of the environment where an environment action is deleted.
Parameter identifier :
The ID of the environment action that is deleted.
Implementation
Future<void> deleteEnvironmentAction({
required String domainIdentifier,
required String environmentIdentifier,
required String identifier,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environments/${Uri.encodeComponent(environmentIdentifier)}/actions/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}