deleteGlossary method

Future<void> deleteGlossary({
  1. required String domainIdentifier,
  2. required String identifier,
})

Deletes a business glossary in Amazon DataZone.

Prerequisites:

  • The glossary must be in DISABLED state.
  • The glossary must not have any glossary terms associated with it.
  • The glossary must exist in the specified domain.
  • The caller must have the datazone:DeleteGlossary permission in the domain and glossary.
  • Glossary should not be linked to any active metadata forms.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the business glossary is deleted.

Parameter identifier : The ID of the business glossary that is deleted.

Implementation

Future<void> deleteGlossary({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/glossaries/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}