deleteGlossaryTerm method

Future<void> deleteGlossaryTerm({
  1. required String domainIdentifier,
  2. required String identifier,
})

Deletes a business glossary term in Amazon DataZone.

Prerequisites:

  • Glossary term must exist and be active.
  • The term must not be linked to other assets or child terms.
  • Caller must have delete permissions in the domain/glossary.
  • Ensure all associations (such as to assets or parent terms) are removed before deletion.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the business glossary term is deleted.

Parameter identifier : The ID of the business glossary term that is deleted.

Implementation

Future<void> deleteGlossaryTerm({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/glossary-terms/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}