deleteProject method

Future<void> deleteProject({
  1. required String domainIdentifier,
  2. required String identifier,
  3. bool? skipDeletionCheck,
})

Deletes a project in Amazon DataZone.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the project is deleted.

Parameter identifier : The identifier of the project that is to be deleted.

Parameter skipDeletionCheck : Specifies the optional flag to delete all child entities within the project.

Implementation

Future<void> deleteProject({
  required String domainIdentifier,
  required String identifier,
  bool? skipDeletionCheck,
}) async {
  final $query = <String, List<String>>{
    if (skipDeletionCheck != null)
      'skipDeletionCheck': [skipDeletionCheck.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/projects/${Uri.encodeComponent(identifier)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}