deleteSubscriptionTarget method

Future<void> deleteSubscriptionTarget({
  1. required String domainIdentifier,
  2. required String environmentIdentifier,
  3. required String identifier,
})

Deletes a subscription target in Amazon DataZone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which the subscription target is deleted.

Parameter environmentIdentifier : The ID of the Amazon DataZone environment in which the subscription target is deleted.

Parameter identifier : The ID of the subscription target that is deleted.

Implementation

Future<void> deleteSubscriptionTarget({
  required String domainIdentifier,
  required String environmentIdentifier,
  required String identifier,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environments/${Uri.encodeComponent(environmentIdentifier)}/subscription-targets/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}