deleteTimeSeriesDataPoints method

Future<void> deleteTimeSeriesDataPoints({
  1. required String domainIdentifier,
  2. required String entityIdentifier,
  3. required TimeSeriesEntityType entityType,
  4. required String formName,
  5. String? clientToken,
})

Deletes the specified time series form for the specified asset.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain that houses the asset for which you want to delete a time series form.

Parameter entityIdentifier : The ID of the asset for which you want to delete a time series form.

Parameter entityType : The type of the asset for which you want to delete a time series form.

Parameter formName : The name of the time series form that you want to delete.

Parameter clientToken : A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

Implementation

Future<void> deleteTimeSeriesDataPoints({
  required String domainIdentifier,
  required String entityIdentifier,
  required TimeSeriesEntityType entityType,
  required String formName,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    'formName': [formName],
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/time-series-data-points',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}