getAccountPool method

Future<GetAccountPoolOutput> getAccountPool({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of the account pool.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the domain in which the account pool lives whose details are to be displayed.

Parameter identifier : The ID of the account pool whose details are to be displayed.

Implementation

Future<GetAccountPoolOutput> getAccountPool({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/account-pools/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetAccountPoolOutput.fromJson(response);
}