getDomainUnit method

Future<GetDomainUnitOutput> getDomainUnit({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of the specified domain unit.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the domain where you want to get a domain unit.

Parameter identifier : The identifier of the domain unit that you want to get.

Implementation

Future<GetDomainUnitOutput> getDomainUnit({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/domain-units/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDomainUnitOutput.fromJson(response);
}