getGlossaryTerm method

Future<GetGlossaryTermOutput> getGlossaryTerm({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets a business glossary term in Amazon DataZone.

Prerequisites:

  • Glossary term with identifier must exist in the domain.
  • User must have permission on the glossary term.
  • Domain must be accessible and active.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain in which this business glossary term exists.

Parameter identifier : The ID of the business glossary term.

Implementation

Future<GetGlossaryTermOutput> getGlossaryTerm({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/glossary-terms/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetGlossaryTermOutput.fromJson(response);
}