getLineageNode method
Gets the data lineage node.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain in which you want to get the data lineage node.
Parameter identifier :
The ID of the data lineage node that you want to get.
Both, a lineage node identifier generated by Amazon DataZone and a
sourceIdentifier of the lineage node are supported. If
sourceIdentifier is greater than 1800 characters, you can use
lineage node identifier generated by Amazon DataZone to get the node
details.
Parameter eventTimestamp :
The event time stamp for which you want to get the data lineage node.
Implementation
Future<GetLineageNodeOutput> getLineageNode({
required String domainIdentifier,
required String identifier,
DateTime? eventTimestamp,
}) async {
final $query = <String, List<String>>{
if (eventTimestamp != null)
'timestamp': [_s.iso8601ToJson(eventTimestamp).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/lineage/nodes/${Uri.encodeComponent(identifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetLineageNodeOutput.fromJson(response);
}