getMetadataGenerationRun method

Future<GetMetadataGenerationRunOutput> getMetadataGenerationRun({
  1. required String domainIdentifier,
  2. required String identifier,
  3. MetadataGenerationRunType? type,
})

Gets a metadata generation run in Amazon DataZone.

Prerequisites:

  • Valid domain and run identifier.
  • The metadata generation run must exist.
  • User must have read access to the metadata run.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain the metadata generation run of which you want to get.

Parameter identifier : The identifier of the metadata generation run.

Parameter type : The type of the metadata generation run.

Implementation

Future<GetMetadataGenerationRunOutput> getMetadataGenerationRun({
  required String domainIdentifier,
  required String identifier,
  MetadataGenerationRunType? type,
}) async {
  final $query = <String, List<String>>{
    if (type != null) 'type': [type.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/metadata-generation-runs/${Uri.encodeComponent(identifier)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetMetadataGenerationRunOutput.fromJson(response);
}