getNotebook method

Future<GetNotebookOutput> getNotebook({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of a notebook in Amazon SageMaker Unified Studio.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.

Parameter identifier : The identifier of the notebook.

Implementation

Future<GetNotebookOutput> getNotebook({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/notebooks/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetNotebookOutput.fromJson(response);
}