getNotebookExport method

Future<GetNotebookExportOutput> getNotebookExport({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of a notebook export in Amazon SageMaker Unified Studio.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon SageMaker Unified Studio domain in which the notebook export exists.

Parameter identifier : The identifier of the notebook export.

Implementation

Future<GetNotebookExportOutput> getNotebookExport({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/notebook-exports/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetNotebookExportOutput.fromJson(response);
}