getNotebookRun method

Future<GetNotebookRunOutput> getNotebookRun({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of a notebook run in Amazon SageMaker Unified Studio.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run exists.

Parameter identifier : The identifier of the notebook run.

Implementation

Future<GetNotebookRunOutput> getNotebookRun({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/notebook-runs/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetNotebookRunOutput.fromJson(response);
}