getSubscriptionRequestDetails method

Future<GetSubscriptionRequestDetailsOutput> getSubscriptionRequestDetails({
  1. required String domainIdentifier,
  2. required String identifier,
})

Gets the details of the specified subscription request.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which to get the subscription request details.

Parameter identifier : The identifier of the subscription request the details of which to get.

Implementation

Future<GetSubscriptionRequestDetailsOutput> getSubscriptionRequestDetails({
  required String domainIdentifier,
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscription-requests/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSubscriptionRequestDetailsOutput.fromJson(response);
}