listDataProductRevisions method

Future<ListDataProductRevisionsOutput> listDataProductRevisions({
  1. required String domainIdentifier,
  2. required String identifier,
  3. int? maxResults,
  4. String? nextToken,
})

Lists data product revisions.

Prerequisites:

  • The data product ID must exist within the domain.
  • User must have view permissions on the data product.
  • The domain must be in a valid and accessible state.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the domain of the data product revisions that you want to list.

Parameter identifier : The ID of the data product revision.

Parameter maxResults : The maximum number of asset filters to return in a single call to ListDataProductRevisions. When the number of data product revisions to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListDataProductRevisions to list the next set of data product revisions.

Parameter nextToken : When the number of data product revisions is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of data product revisions, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListDataProductRevisions to list the next set of data product revisions.

Implementation

Future<ListDataProductRevisionsOutput> listDataProductRevisions({
  required String domainIdentifier,
  required String identifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-products/${Uri.encodeComponent(identifier)}/revisions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDataProductRevisionsOutput.fromJson(response);
}