listDataSourceRunActivities method
Lists data source run activities.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which to list data source
run activities.
Parameter identifier :
The identifier of the data source run.
Parameter maxResults :
The maximum number of activities to return in a single call to
ListDataSourceRunActivities. When the number of activities to
be listed is greater than the value of MaxResults, the
response contains a NextToken value that you can use in a
subsequent call to ListDataSourceRunActivities to list the
next set of activities.
Parameter nextToken :
When the number of activities is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value
for MaxResults that is less than the number of activities,
the response includes a pagination token named NextToken. You
can specify this NextToken value in a subsequent call to
ListDataSourceRunActivities to list the next set of
activities.
Parameter status :
The status of the data source run.
Implementation
Future<ListDataSourceRunActivitiesOutput> listDataSourceRunActivities({
required String domainIdentifier,
required String identifier,
int? maxResults,
String? nextToken,
DataAssetActivityStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-source-runs/${Uri.encodeComponent(identifier)}/activities',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataSourceRunActivitiesOutput.fromJson(response);
}