listDataSourceRuns method
Lists data source runs in Amazon DataZone.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter dataSourceIdentifier :
The identifier of the data source.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which to invoke the
ListDataSourceRuns action.
Parameter maxResults :
The maximum number of runs to return in a single call to
ListDataSourceRuns. When the number of runs to be listed is
greater than the value of MaxResults, the response contains a
NextToken value that you can use in a subsequent call to
ListDataSourceRuns to list the next set of runs.
Parameter nextToken :
When the number of runs is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value
for MaxResults that is less than the number of runs, the
response includes a pagination token named NextToken. You can
specify this NextToken value in a subsequent call to
ListDataSourceRuns to list the next set of runs.
Parameter status :
The status of the data source.
Implementation
Future<ListDataSourceRunsOutput> listDataSourceRuns({
required String dataSourceIdentifier,
required String domainIdentifier,
int? maxResults,
String? nextToken,
DataSourceRunStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-sources/${Uri.encodeComponent(dataSourceIdentifier)}/runs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataSourceRunsOutput.fromJson(response);
}