listDomains method

Future<ListDomainsOutput> listDomains({
  1. int? maxResults,
  2. String? nextToken,
  3. DomainStatus? status,
})

Lists Amazon DataZone domains.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of domains to return in a single call to ListDomains. When the number of domains to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListDomains to list the next set of domains.

Parameter nextToken : When the number of domains is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of domains, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListDomains to list the next set of domains.

Parameter status : The status of the data source.

Implementation

Future<ListDomainsOutput> listDomains({
  int? maxResults,
  String? nextToken,
  DomainStatus? status,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (status != null) 'status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v2/domains',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDomainsOutput.fromJson(response);
}