listLineageNodeHistory method
Lists the history of the specified data lineage node.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where you want to list the history of the specified
data lineage node.
Parameter identifier :
The ID of the data lineage node whose history you want to list.
Parameter direction :
The direction of the data lineage node refers to the lineage node having
neighbors in that direction. For example, if direction is
UPSTREAM, the ListLineageNodeHistory API
responds with historical versions with upstream neighbors only.
Parameter eventTimestampGTE :
Specifies whether the action is to return data lineage node history from
the time after the event timestamp.
Parameter eventTimestampLTE :
Specifies whether the action is to return data lineage node history from
the time prior of the event timestamp.
Parameter maxResults :
The maximum number of history items to return in a single call to
ListLineageNodeHistory. When the number of memberships to be listed is
greater than the value of MaxResults, the response contains a NextToken
value that you can use in a subsequent call to ListLineageNodeHistory to
list the next set of items.
Parameter nextToken :
When the number of history items is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value for MaxResults
that is less than the number of items, the response includes a pagination
token named NextToken. You can specify this NextToken value in a
subsequent call to ListLineageNodeHistory to list the next set of items.
Parameter sortOrder :
The order by which you want data lineage node history to be sorted.
Implementation
Future<ListLineageNodeHistoryOutput> listLineageNodeHistory({
required String domainIdentifier,
required String identifier,
EdgeDirection? direction,
DateTime? eventTimestampGTE,
DateTime? eventTimestampLTE,
int? maxResults,
String? nextToken,
SortOrder? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (direction != null) 'direction': [direction.value],
if (eventTimestampGTE != null)
'timestampGTE': [_s.iso8601ToJson(eventTimestampGTE).toString()],
if (eventTimestampLTE != null)
'timestampLTE': [_s.iso8601ToJson(eventTimestampLTE).toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/lineage/nodes/${Uri.encodeComponent(identifier)}/history',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListLineageNodeHistoryOutput.fromJson(response);
}