listProjectMemberships method

Future<ListProjectMembershipsOutput> listProjectMemberships({
  1. required String domainIdentifier,
  2. required String projectIdentifier,
  3. int? maxResults,
  4. String? nextToken,
  5. SortFieldProject? sortBy,
  6. SortOrder? sortOrder,
})

Lists all members of the specified project.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which you want to list project memberships.

Parameter projectIdentifier : The identifier of the project whose memberships you want to list.

Parameter maxResults : The maximum number of memberships to return in a single call to ListProjectMemberships. When the number of memberships to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListProjectMemberships to list the next set of memberships.

Parameter nextToken : When the number of memberships is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of memberships, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListProjectMemberships to list the next set of memberships.

Parameter sortBy : The method by which you want to sort the project memberships.

Parameter sortOrder : The sort order of the project memberships.

Implementation

Future<ListProjectMembershipsOutput> listProjectMemberships({
  required String domainIdentifier,
  required String projectIdentifier,
  int? maxResults,
  String? nextToken,
  SortFieldProject? sortBy,
  SortOrder? sortOrder,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (sortBy != null) 'sortBy': [sortBy.value],
    if (sortOrder != null) 'sortOrder': [sortOrder.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/projects/${Uri.encodeComponent(projectIdentifier)}/memberships',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListProjectMembershipsOutput.fromJson(response);
}