rejectSubscriptionRequest method

Future<RejectSubscriptionRequestOutput> rejectSubscriptionRequest({
  1. required String domainIdentifier,
  2. required String identifier,
  3. String? decisionComment,
})

Rejects the specified subscription request.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which the subscription request was rejected.

Parameter identifier : The identifier of the subscription request that was rejected.

Parameter decisionComment : The decision comment of the rejected subscription request.

Implementation

Future<RejectSubscriptionRequestOutput> rejectSubscriptionRequest({
  required String domainIdentifier,
  required String identifier,
  String? decisionComment,
}) async {
  final $payload = <String, dynamic>{
    if (decisionComment != null) 'decisionComment': decisionComment,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscription-requests/${Uri.encodeComponent(identifier)}/reject',
    exceptionFnMap: _exceptionFns,
  );
  return RejectSubscriptionRequestOutput.fromJson(response);
}