startDataSourceRun method

Future<StartDataSourceRunOutput> startDataSourceRun({
  1. required String dataSourceIdentifier,
  2. required String domainIdentifier,
  3. String? clientToken,
})

Start the run of the specified data source in Amazon DataZone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter dataSourceIdentifier : The identifier of the data source.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which to start a data source run.

Parameter clientToken : A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

Implementation

Future<StartDataSourceRunOutput> startDataSourceRun({
  required String dataSourceIdentifier,
  required String domainIdentifier,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/data-sources/${Uri.encodeComponent(dataSourceIdentifier)}/runs',
    exceptionFnMap: _exceptionFns,
  );
  return StartDataSourceRunOutput.fromJson(response);
}