updateAssetFilter method
Updates an asset filter.
Prerequisites:
- The domain, asset, and asset filter identifier must all exist.
- The asset must contain the columns being referenced in the update.
- If applying a row filter, ensure the column referenced in the expression exists in the asset schema.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter assetIdentifier :
The ID of the data asset.
Parameter domainIdentifier :
The ID of the domain where you want to update an asset filter.
Parameter identifier :
The ID of the asset filter.
Parameter configuration :
The configuration of the asset filter.
Parameter description :
The description of the asset filter.
Parameter name :
The name of the asset filter.
Implementation
Future<UpdateAssetFilterOutput> updateAssetFilter({
required String assetIdentifier,
required String domainIdentifier,
required String identifier,
AssetFilterConfiguration? configuration,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (configuration != null) 'configuration': configuration,
if (description != null) 'description': description,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/assets/${Uri.encodeComponent(assetIdentifier)}/filters/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateAssetFilterOutput.fromJson(response);
}