updateConnection method
Updates a connection. In Amazon DataZone, a connection enables you to connect your resources (domains, projects, and environments) to external resources and services.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where a connection is to be updated.
Parameter identifier :
The ID of the connection to be updated.
Parameter awsLocation :
The location where a connection is to be updated.
Parameter configurations :
The configurations of the connection.
Parameter description :
The description of a connection.
Parameter props :
The connection props.
Implementation
Future<UpdateConnectionOutput> updateConnection({
required String domainIdentifier,
required String identifier,
AwsLocation? awsLocation,
List<Configuration>? configurations,
String? description,
ConnectionPropertiesPatch? props,
}) async {
final $payload = <String, dynamic>{
if (awsLocation != null) 'awsLocation': awsLocation,
if (configurations != null) 'configurations': configurations,
if (description != null) 'description': description,
if (props != null) 'props': props,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/connections/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateConnectionOutput.fromJson(response);
}