updateEnvironmentBlueprint method

Future<UpdateEnvironmentBlueprintOutput> updateEnvironmentBlueprint({
  1. required String domainIdentifier,
  2. required String identifier,
  3. String? description,
  4. ProvisioningProperties? provisioningProperties,
  5. List<CustomParameter>? userParameters,
})

Updates an environment blueprint in Amazon DataZone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.

Parameter identifier : The identifier of the environment blueprint to be updated.

Parameter description : The description to be updated as part of the UpdateEnvironmentBlueprint action.

Parameter provisioningProperties : The provisioning properties to be updated as part of the UpdateEnvironmentBlueprint action.

Parameter userParameters : The user parameters to be updated as part of the UpdateEnvironmentBlueprint action.

Implementation

Future<UpdateEnvironmentBlueprintOutput> updateEnvironmentBlueprint({
  required String domainIdentifier,
  required String identifier,
  String? description,
  ProvisioningProperties? provisioningProperties,
  List<CustomParameter>? userParameters,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (provisioningProperties != null)
      'provisioningProperties': provisioningProperties,
    if (userParameters != null) 'userParameters': userParameters,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environment-blueprints/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateEnvironmentBlueprintOutput.fromJson(response);
}