updateEnvironmentProfile method
Updates the specified environment profile in Amazon DataZone.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which an environment
profile is to be updated.
Parameter identifier :
The identifier of the environment profile that is to be updated.
Parameter awsAccountId :
The Amazon Web Services account in which a specified environment profile
is to be udpated.
Parameter awsAccountRegion :
The Amazon Web Services Region in which a specified environment profile is
to be updated.
Parameter description :
The description to be updated as part of the
UpdateEnvironmentProfile action.
Parameter name :
The name to be updated as part of the
UpdateEnvironmentProfile action.
Parameter userParameters :
The user parameters to be updated as part of the
UpdateEnvironmentProfile action.
Implementation
Future<UpdateEnvironmentProfileOutput> updateEnvironmentProfile({
required String domainIdentifier,
required String identifier,
String? awsAccountId,
String? awsAccountRegion,
String? description,
String? name,
List<EnvironmentParameter>? userParameters,
}) async {
final $payload = <String, dynamic>{
if (awsAccountId != null) 'awsAccountId': awsAccountId,
if (awsAccountRegion != null) 'awsAccountRegion': awsAccountRegion,
if (description != null) 'description': description,
if (name != null) 'name': name,
if (userParameters != null) 'userParameters': userParameters,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environment-profiles/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateEnvironmentProfileOutput.fromJson(response);
}