updateProject method

Future<UpdateProjectOutput> updateProject({
  1. required String domainIdentifier,
  2. required String identifier,
  3. String? description,
  4. String? domainUnitId,
  5. EnvironmentDeploymentDetails? environmentDeploymentDetails,
  6. List<String>? glossaryTerms,
  7. String? name,
  8. String? projectProfileVersion,
  9. Map<String, String>? resourceTags,
  10. List<EnvironmentConfigurationUserParameter>? userParameters,
})

Updates the specified project in Amazon DataZone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The ID of the Amazon DataZone domain where a project is being updated.

Parameter identifier : The identifier of the project that is to be updated.

Parameter description : The description to be updated as part of the UpdateProject action.

Parameter domainUnitId : The ID of the domain unit.

Parameter environmentDeploymentDetails : The environment deployment details of the project.

Parameter glossaryTerms : The glossary terms to be updated as part of the UpdateProject action.

Parameter name : The name to be updated as part of the UpdateProject action.

Parameter projectProfileVersion : The project profile version to which the project should be updated. You can only specify the following string for this parameter: latest.

Parameter resourceTags : The resource tags of the project.

Parameter userParameters : The user parameters of the project.

Implementation

Future<UpdateProjectOutput> updateProject({
  required String domainIdentifier,
  required String identifier,
  String? description,
  String? domainUnitId,
  EnvironmentDeploymentDetails? environmentDeploymentDetails,
  List<String>? glossaryTerms,
  String? name,
  String? projectProfileVersion,
  Map<String, String>? resourceTags,
  List<EnvironmentConfigurationUserParameter>? userParameters,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (domainUnitId != null) 'domainUnitId': domainUnitId,
    if (environmentDeploymentDetails != null)
      'environmentDeploymentDetails': environmentDeploymentDetails,
    if (glossaryTerms != null) 'glossaryTerms': glossaryTerms,
    if (name != null) 'name': name,
    if (projectProfileVersion != null)
      'projectProfileVersion': projectProfileVersion,
    if (resourceTags != null) 'resourceTags': resourceTags,
    if (userParameters != null) 'userParameters': userParameters,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/projects/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateProjectOutput.fromJson(response);
}