updateSubscriptionRequest method

Future<UpdateSubscriptionRequestOutput> updateSubscriptionRequest({
  1. required String domainIdentifier,
  2. required String identifier,
  3. required String requestReason,
})

Updates a specified subscription request in Amazon DataZone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainIdentifier : The identifier of the Amazon DataZone domain in which a subscription request is to be updated.

Parameter identifier : The identifier of the subscription request that is to be updated.

Parameter requestReason : The reason for the UpdateSubscriptionRequest action.

Implementation

Future<UpdateSubscriptionRequestOutput> updateSubscriptionRequest({
  required String domainIdentifier,
  required String identifier,
  required String requestReason,
}) async {
  final $payload = <String, dynamic>{
    'requestReason': requestReason,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscription-requests/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSubscriptionRequestOutput.fromJson(response);
}