batchStartRecommendations method

Future<BatchStartRecommendationsResponse> batchStartRecommendations({
  1. List<StartRecommendationsRequestEntry>? data,
})
Starts the analysis of up to 20 source databases to recommend target engines for each source database. This is a batch version of StartRecommendations.

The result of analysis of each source database is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.

May throw AccessDeniedFault. May throw InvalidResourceStateFault. May throw ResourceNotFoundFault.

Parameter data : Provides information about source databases to analyze. After this analysis, Fleet Advisor recommends target engines for each source database.

Implementation

Future<BatchStartRecommendationsResponse> batchStartRecommendations({
  List<StartRecommendationsRequestEntry>? data,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.BatchStartRecommendations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (data != null) 'Data': data,
    },
  );

  return BatchStartRecommendationsResponse.fromJson(jsonResponse.body);
}