deleteReplicationConfig method
Future<DeleteReplicationConfigResponse>
deleteReplicationConfig({
- required String replicationConfigArn,
Deletes an DMS Serverless replication configuration. This effectively deprovisions any and all replications that use this configuration. You can't delete the configuration for an DMS Serverless replication that is ongoing. You can delete the configuration when the replication is in a non-RUNNING and non-STARTING state.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter replicationConfigArn :
The replication config to delete.
Implementation
Future<DeleteReplicationConfigResponse> deleteReplicationConfig({
required String replicationConfigArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.DeleteReplicationConfig'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReplicationConfigArn': replicationConfigArn,
},
);
return DeleteReplicationConfigResponse.fromJson(jsonResponse.body);
}