deleteReplicationTaskAssessmentRun method
Future<DeleteReplicationTaskAssessmentRunResponse>
deleteReplicationTaskAssessmentRun({
- required String replicationTaskAssessmentRunArn,
Deletes the record of a single premigration assessment run.
This operation removes all metadata that DMS maintains about this assessment run. However, the operation leaves untouched all information about this assessment run that is stored in your Amazon S3 bucket.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter replicationTaskAssessmentRunArn :
Amazon Resource Name (ARN) of the premigration assessment run to be
deleted.
Implementation
Future<DeleteReplicationTaskAssessmentRunResponse>
deleteReplicationTaskAssessmentRun({
required String replicationTaskAssessmentRunArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.DeleteReplicationTaskAssessmentRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReplicationTaskAssessmentRunArn': replicationTaskAssessmentRunArn,
},
);
return DeleteReplicationTaskAssessmentRunResponse.fromJson(
jsonResponse.body);
}