describeDataMigrations method

Future<DescribeDataMigrationsResponse> describeDataMigrations({
  1. List<Filter>? filters,
  2. String? marker,
  3. int? maxRecords,
  4. bool? withoutSettings,
  5. bool? withoutStatistics,
})

Returns information about data migrations.

May throw FailedDependencyFault. May throw InvalidResourceStateFault. May throw ResourceNotFoundFault.

Parameter filters : Filters applied to the data migrations.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Parameter withoutSettings : An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose true; otherwise, choose false (the default).

Parameter withoutStatistics : An option to set to avoid returning information about statistics. Use this to reduce overhead when statistics information is too large. To use this option, choose true; otherwise, choose false (the default).

Implementation

Future<DescribeDataMigrationsResponse> describeDataMigrations({
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
  bool? withoutSettings,
  bool? withoutStatistics,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeDataMigrations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (withoutSettings != null) 'WithoutSettings': withoutSettings,
      if (withoutStatistics != null) 'WithoutStatistics': withoutStatistics,
    },
  );

  return DescribeDataMigrationsResponse.fromJson(jsonResponse.body);
}