describeEndpointSettings method

Future<DescribeEndpointSettingsResponse> describeEndpointSettings({
  1. required String engineName,
  2. String? marker,
  3. int? maxRecords,
})

Returns information about the possible endpoint settings available when you create an endpoint for a specific database engine.

Parameter engineName : The database engine used for your source or target endpoint.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Implementation

Future<DescribeEndpointSettingsResponse> describeEndpointSettings({
  required String engineName,
  String? marker,
  int? maxRecords,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeEndpointSettings'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EngineName': engineName,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
    },
  );

  return DescribeEndpointSettingsResponse.fromJson(jsonResponse.body);
}