describeFleetAdvisorDatabases method

Future<DescribeFleetAdvisorDatabasesResponse> describeFleetAdvisorDatabases({
  1. List<Filter>? filters,
  2. int? maxRecords,
  3. String? nextToken,
})
Returns a list of Fleet Advisor databases in your account.

May throw InvalidResourceStateFault.

Parameter filters : If you specify any of the following filters, the output includes information for only those databases that meet the filter criteria:

  • database-id – The ID of the database.
  • database-name – The name of the database.
  • database-engine – The name of the database engine.
  • server-ip-address – The IP address of the database server.
  • database-ip-address – The IP address of the database.
  • collector-name – The name of the associated Fleet Advisor collector.
An example is: describe-fleet-advisor-databases --filter Name="database-id",Values="45"

Parameter maxRecords : Sets the maximum number of records returned in the response.

Parameter nextToken : If NextToken is returned by a previous response, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Implementation

Future<DescribeFleetAdvisorDatabasesResponse> describeFleetAdvisorDatabases({
  List<Filter>? filters,
  int? maxRecords,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeFleetAdvisorDatabases'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeFleetAdvisorDatabasesResponse.fromJson(jsonResponse.body);
}