describeFleetAdvisorLsaAnalysis method

Future<DescribeFleetAdvisorLsaAnalysisResponse> describeFleetAdvisorLsaAnalysis({
  1. int? maxRecords,
  2. String? nextToken,
})
Provides descriptions of large-scale assessment (LSA) analyses produced by your Fleet Advisor collectors.

May throw InvalidResourceStateFault.

Parameter maxRecords : Sets the maximum number of records returned in the response.

Parameter nextToken : If NextToken is returned by a previous response, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Implementation

Future<DescribeFleetAdvisorLsaAnalysisResponse>
    describeFleetAdvisorLsaAnalysis({
  int? maxRecords,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeFleetAdvisorLsaAnalysis'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeFleetAdvisorLsaAnalysisResponse.fromJson(jsonResponse.body);
}