describeFleetAdvisorSchemaObjectSummary method

Future<DescribeFleetAdvisorSchemaObjectSummaryResponse> describeFleetAdvisorSchemaObjectSummary({
  1. List<Filter>? filters,
  2. int? maxRecords,
  3. String? nextToken,
})
Provides descriptions of the schemas discovered by your Fleet Advisor collectors.

May throw InvalidResourceStateFault.

Parameter filters : If you specify any of the following filters, the output includes information for only those schema objects that meet the filter criteria:

  • schema-id – The ID of the schema, for example d4610ac5-e323-4ad9-bc50-eaf7249dfe9d.
Example: describe-fleet-advisor-schema-object-summary --filter Name="schema-id",Values="50"

Parameter maxRecords : Sets the maximum number of records returned in the response.

Parameter nextToken : If NextToken is returned by a previous response, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Implementation

Future<DescribeFleetAdvisorSchemaObjectSummaryResponse>
    describeFleetAdvisorSchemaObjectSummary({
  List<Filter>? filters,
  int? maxRecords,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonDMSv20160101.DescribeFleetAdvisorSchemaObjectSummary'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeFleetAdvisorSchemaObjectSummaryResponse.fromJson(
      jsonResponse.body);
}