describeFleetAdvisorSchemas method

Future<DescribeFleetAdvisorSchemasResponse> describeFleetAdvisorSchemas({
  1. List<Filter>? filters,
  2. int? maxRecords,
  3. String? nextToken,
})
Returns a list of schemas detected by Fleet Advisor Collectors in your account.

May throw InvalidResourceStateFault.

Parameter filters : If you specify any of the following filters, the output includes information for only those schemas that meet the filter criteria:

  • complexity – The schema's complexity, for example Simple.
  • database-id – The ID of the schema's database.
  • database-ip-address – The IP address of the schema's database.
  • database-name – The name of the schema's database.
  • database-engine – The name of the schema database's engine.
  • original-schema-name – The name of the schema's database's main schema.
  • schema-id – The ID of the schema, for example 15.
  • schema-name – The name of the schema.
  • server-ip-address – The IP address of the schema database's server.
An example is: describe-fleet-advisor-schemas --filter Name="schema-id",Values="50"

Parameter maxRecords : Sets the maximum number of records returned in the response.

Parameter nextToken : If NextToken is returned by a previous response, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Implementation

Future<DescribeFleetAdvisorSchemasResponse> describeFleetAdvisorSchemas({
  List<Filter>? filters,
  int? maxRecords,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeFleetAdvisorSchemas'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeFleetAdvisorSchemasResponse.fromJson(jsonResponse.body);
}