describeMetadataModelChildren method

Future<DescribeMetadataModelChildrenResponse> describeMetadataModelChildren({
  1. required String migrationProjectIdentifier,
  2. required OriginTypeValue origin,
  3. required String selectionRules,
  4. String? marker,
  5. int? maxRecords,
})

Gets a list of child metadata models for the specified metadata model in the database hierarchy.

May throw AccessDeniedFault. May throw ResourceNotFoundFault.

Parameter migrationProjectIdentifier : The migration project name or Amazon Resource Name (ARN).

Parameter origin : Specifies whether to retrieve metadata from the source or target tree. Valid values: SOURCE | TARGET

Parameter selectionRules : The JSON string that specifies which metadata model's children to retrieve. Only one selection rule with "rule-action": "explicit" can be provided. For more information, see Selection Rules in the DMS User Guide.

Parameter marker : Specifies the unique pagination token that indicates where the next page should start. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of metadata model children to include in the response. If more items exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Implementation

Future<DescribeMetadataModelChildrenResponse> describeMetadataModelChildren({
  required String migrationProjectIdentifier,
  required OriginTypeValue origin,
  required String selectionRules,
  String? marker,
  int? maxRecords,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeMetadataModelChildren'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MigrationProjectIdentifier': migrationProjectIdentifier,
      'Origin': origin.value,
      'SelectionRules': selectionRules,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
    },
  );

  return DescribeMetadataModelChildrenResponse.fromJson(jsonResponse.body);
}