describeMetadataModelCreations method

Future<DescribeMetadataModelCreationsResponse> describeMetadataModelCreations({
  1. required String migrationProjectIdentifier,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
})

Returns a paginated list of metadata model creation requests for a migration project.

May throw AccessDeniedFault. May throw ResourceNotFoundFault.

Parameter migrationProjectIdentifier : The migration project name or Amazon Resource Name (ARN).

Parameter filters : Filters applied to the metadata model creation requests described in the form of key-value pairs. The supported filters are request-id and status.

Parameter marker : Specifies the unique pagination token that makes it possible to display the next page of metadata model creation requests. If Marker is returned by a previous response, there are more metadata model creation requests available.

Parameter maxRecords : The maximum number of metadata model creation requests to include in the response. If more requests exist than the specified MaxRecords value, a pagination token is provided in the response so that you can retrieve the remaining results.

Implementation

Future<DescribeMetadataModelCreationsResponse>
    describeMetadataModelCreations({
  required String migrationProjectIdentifier,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.DescribeMetadataModelCreations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MigrationProjectIdentifier': migrationProjectIdentifier,
      if (filters != null) 'Filters': filters,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
    },
  );

  return DescribeMetadataModelCreationsResponse.fromJson(jsonResponse.body);
}