describeRecommendations method
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
Parameter filters :
Filters applied to the target engine recommendations described in the form
of key-value pairs.
Valid filter names: database-id | engine-name
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, Fleet Advisor
includes a pagination token in the response so that you can retrieve the
remaining results.
Parameter nextToken :
Specifies the unique pagination token that makes it possible to display
the next page of results. If this parameter is specified, the response
includes only records beyond the marker, up to the value specified by
MaxRecords.
If NextToken is returned by a previous response, there are
more results available. The value of NextToken is a unique
pagination token for each page. Make the call again using the returned
token to retrieve the next page. Keep all other arguments unchanged.
Implementation
Future<DescribeRecommendationsResponse> describeRecommendations({
List<Filter>? filters,
int? maxRecords,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.DescribeRecommendations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxRecords != null) 'MaxRecords': maxRecords,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeRecommendationsResponse.fromJson(jsonResponse.body);
}