describeReplicationTaskAssessmentResults method

Future<DescribeReplicationTaskAssessmentResultsResponse> describeReplicationTaskAssessmentResults({
  1. String? marker,
  2. int? maxRecords,
  3. String? replicationTaskArn,
})

Returns the task assessment results from the Amazon S3 bucket that DMS creates in your Amazon Web Services account. This action always returns the latest results.

For more information about DMS task assessments, see Creating a task assessment report in the Database Migration Service User Guide.

May throw ResourceNotFoundFault.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Parameter replicationTaskArn : The Amazon Resource Name (ARN) string that uniquely identifies the task. When this input parameter is specified, the API returns only one result and ignore the values of the MaxRecords and Marker parameters.

Implementation

Future<DescribeReplicationTaskAssessmentResultsResponse>
    describeReplicationTaskAssessmentResults({
  String? marker,
  int? maxRecords,
  String? replicationTaskArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonDMSv20160101.DescribeReplicationTaskAssessmentResults'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (replicationTaskArn != null)
        'ReplicationTaskArn': replicationTaskArn,
    },
  );

  return DescribeReplicationTaskAssessmentResultsResponse.fromJson(
      jsonResponse.body);
}