getTargetSelectionRules method
Converts source selection rules into their target counterparts for schema conversion operations.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter migrationProjectIdentifier :
The migration project name or Amazon Resource Name (ARN).
Parameter selectionRules :
The JSON string representing the source selection rules for conversion.
Selection rules must contain only supported metadata model types. For more
information, see Selection Rules in the DMS User Guide.
Implementation
Future<GetTargetSelectionRulesResponse> getTargetSelectionRules({
required String migrationProjectIdentifier,
required String selectionRules,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.GetTargetSelectionRules'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MigrationProjectIdentifier': migrationProjectIdentifier,
'SelectionRules': selectionRules,
},
);
return GetTargetSelectionRulesResponse.fromJson(jsonResponse.body);
}