reloadReplicationTables method

Future<ReloadReplicationTablesResponse> reloadReplicationTables({
  1. required String replicationConfigArn,
  2. required List<TableToReload> tablesToReload,
  3. ReloadOptionValue? reloadOption,
})

Reloads the target database table with the source data for a given DMS Serverless replication configuration.

You can only use this operation with a task in the RUNNING state, otherwise the service will throw an InvalidResourceStateFault exception.

May throw InvalidResourceStateFault. May throw ResourceNotFoundFault.

Parameter replicationConfigArn : The Amazon Resource Name of the replication config for which to reload tables.

Parameter tablesToReload : The list of tables to reload.

Parameter reloadOption : Options for reload. Specify data-reload to reload the data and re-validate it if validation is enabled. Specify validate-only to re-validate the table. This option applies only when validation is enabled for the replication.

Implementation

Future<ReloadReplicationTablesResponse> reloadReplicationTables({
  required String replicationConfigArn,
  required List<TableToReload> tablesToReload,
  ReloadOptionValue? reloadOption,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.ReloadReplicationTables'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ReplicationConfigArn': replicationConfigArn,
      'TablesToReload': tablesToReload,
      if (reloadOption != null) 'ReloadOption': reloadOption.value,
    },
  );

  return ReloadReplicationTablesResponse.fromJson(jsonResponse.body);
}