startMetadataModelImport method
Loads the metadata for all the dependent database objects of the parent object.
This operation uses your project's Amazon S3 bucket as a metadata cache to improve performance.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw KMSKeyNotAccessibleFault.
May throw ResourceAlreadyExistsFault.
May throw ResourceNotFoundFault.
May throw ResourceQuotaExceededFault.
May throw S3AccessDeniedFault.
May throw S3ResourceNotFoundFault.
Parameter migrationProjectIdentifier :
The migration project name or Amazon Resource Name (ARN).
Parameter origin :
Whether to load metadata to the source or target database.
Parameter selectionRules :
A value that specifies the database objects to import.
Parameter refresh :
If true, DMS loads metadata for the specified objects from
the source database.
Implementation
Future<StartMetadataModelImportResponse> startMetadataModelImport({
required String migrationProjectIdentifier,
required OriginTypeValue origin,
required String selectionRules,
bool? refresh,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.StartMetadataModelImport'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MigrationProjectIdentifier': migrationProjectIdentifier,
'Origin': origin.value,
'SelectionRules': selectionRules,
if (refresh != null) 'Refresh': refresh,
},
);
return StartMetadataModelImportResponse.fromJson(jsonResponse.body);
}