startReplicationTaskAssessment method

Future<StartReplicationTaskAssessmentResponse> startReplicationTaskAssessment({
  1. required String replicationTaskArn,
})

Starts the replication task assessment for unsupported data types in the source database.

You can only use this operation for a task if the following conditions are true:

  • The task must be in the stopped state.
  • The task must have successful connections to the source and target.
If either of these conditions are not met, an InvalidResourceStateFault error will result.

For information about DMS task assessments, see Creating a task assessment report in the Database Migration Service User Guide.

May throw InvalidResourceStateFault. May throw ResourceNotFoundFault.

Parameter replicationTaskArn : The Amazon Resource Name (ARN) of the replication task.

Implementation

Future<StartReplicationTaskAssessmentResponse>
    startReplicationTaskAssessment({
  required String replicationTaskArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.StartReplicationTaskAssessment'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ReplicationTaskArn': replicationTaskArn,
    },
  );

  return StartReplicationTaskAssessmentResponse.fromJson(jsonResponse.body);
}