updateSubscriptionsToEventBridge method

Future<UpdateSubscriptionsToEventBridgeResponse> updateSubscriptionsToEventBridge({
  1. bool? forceMove,
})

Migrates 10 active and enabled Amazon SNS subscriptions at a time and converts them to corresponding Amazon EventBridge rules. By default, this operation migrates subscriptions only when all your replication instance versions are 3.4.5 or higher. If any replication instances are from versions earlier than 3.4.5, the operation raises an error and tells you to upgrade these instances to version 3.4.5 or higher. To enable migration regardless of version, set the Force option to true. However, if you don't upgrade instances earlier than version 3.4.5, some types of events might not be available when you use Amazon EventBridge.

To call this operation, make sure that you have certain permissions added to your user account. For more information, see Migrating event subscriptions to Amazon EventBridge in the Amazon Web Services Database Migration Service User Guide.

May throw AccessDeniedFault. May throw InvalidResourceStateFault.

Parameter forceMove : When set to true, this operation migrates DMS subscriptions for Amazon SNS notifications no matter what your replication instance version is. If not set or set to false, this operation runs only when all your replication instances are from DMS version 3.4.5 or higher.

Implementation

Future<UpdateSubscriptionsToEventBridgeResponse>
    updateSubscriptionsToEventBridge({
  bool? forceMove,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonDMSv20160101.UpdateSubscriptionsToEventBridge'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (forceMove != null) 'ForceMove': forceMove,
    },
  );

  return UpdateSubscriptionsToEventBridgeResponse.fromJson(jsonResponse.body);
}