assumeFleetRoleForRead method

Future<AssumeFleetRoleForReadResponse> assumeFleetRoleForRead({
  1. required String farmId,
  2. required String fleetId,
})

Get Amazon Web Services credentials from the fleet role. The IAM permissions of the credentials are scoped down to have read-only access.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID for the fleet's farm.

Parameter fleetId : The fleet ID.

Implementation

Future<AssumeFleetRoleForReadResponse> assumeFleetRoleForRead({
  required String farmId,
  required String fleetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets/${Uri.encodeComponent(fleetId)}/read-roles',
    exceptionFnMap: _exceptionFns,
  );
  return AssumeFleetRoleForReadResponse.fromJson(response);
}