assumeQueueRoleForRead method

Future<AssumeQueueRoleForReadResponse> assumeQueueRoleForRead({
  1. required String farmId,
  2. required String queueId,
})

Gets Amazon Web Services credentials from the queue role. The IAM permissions of the credentials are scoped down to have read-only access.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID of the farm containing the queue.

Parameter queueId : The queue ID.

Implementation

Future<AssumeQueueRoleForReadResponse> assumeQueueRoleForRead({
  required String farmId,
  required String queueId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queues/${Uri.encodeComponent(queueId)}/read-roles',
    exceptionFnMap: _exceptionFns,
  );
  return AssumeQueueRoleForReadResponse.fromJson(response);
}