assumeQueueRoleForUser method

Future<AssumeQueueRoleForUserResponse> assumeQueueRoleForUser({
  1. required String farmId,
  2. required String queueId,
})

Allows a user to assume a role for a queue.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID of the queue that the user assumes the role for.

Parameter queueId : The queue ID of the queue that the user assumes the role for.

Implementation

Future<AssumeQueueRoleForUserResponse> assumeQueueRoleForUser({
  required String farmId,
  required String queueId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queues/${Uri.encodeComponent(queueId)}/user-roles',
    exceptionFnMap: _exceptionFns,
  );
  return AssumeQueueRoleForUserResponse.fromJson(response);
}