batchGetJobEntity method

Future<BatchGetJobEntityResponse> batchGetJobEntity({
  1. required String farmId,
  2. required String fleetId,
  3. required List<JobEntityIdentifiersUnion> identifiers,
  4. required String workerId,
})

Get batched job details for a worker.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID of the worker that's fetching job details. The worker must have an assignment on a job to fetch job details.

Parameter fleetId : The fleet ID of the worker that's fetching job details. The worker must have an assignment on a job to fetch job details.

Parameter identifiers : The job identifiers to include within the job entity batch details.

Parameter workerId : The worker ID of the worker containing the job details to get.

Implementation

Future<BatchGetJobEntityResponse> batchGetJobEntity({
  required String farmId,
  required String fleetId,
  required List<JobEntityIdentifiersUnion> identifiers,
  required String workerId,
}) async {
  final $payload = <String, dynamic>{
    'identifiers': identifiers,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets/${Uri.encodeComponent(fleetId)}/workers/${Uri.encodeComponent(workerId)}/batchGetJobEntity',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetJobEntityResponse.fromJson(response);
}