createLicenseEndpoint method

Future<CreateLicenseEndpointResponse> createLicenseEndpoint({
  1. required List<String> securityGroupIds,
  2. required List<String> subnetIds,
  3. required String vpcId,
  4. String? clientToken,
  5. Map<String, String>? tags,
})

Creates a license endpoint to integrate your various licensed software used for rendering on Deadline Cloud.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter securityGroupIds : The security group IDs.

Parameter subnetIds : The subnet IDs.

Parameter vpcId : The VPC (virtual private cloud) ID to use with the license endpoint.

Parameter clientToken : The unique token which the server uses to recognize retries of the same request.

Parameter tags : Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.

Implementation

Future<CreateLicenseEndpointResponse> createLicenseEndpoint({
  required List<String> securityGroupIds,
  required List<String> subnetIds,
  required String vpcId,
  String? clientToken,
  Map<String, String>? tags,
}) async {
  final headers = <String, String>{
    if (clientToken != null) 'X-Amz-Client-Token': clientToken.toString(),
  };
  final $payload = <String, dynamic>{
    'securityGroupIds': securityGroupIds,
    'subnetIds': subnetIds,
    'vpcId': vpcId,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2023-10-12/license-endpoints',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return CreateLicenseEndpointResponse.fromJson(response);
}