createQueueFleetAssociation method

Future<void> createQueueFleetAssociation({
  1. required String farmId,
  2. required String fleetId,
  3. required String queueId,
})

Creates an association between a queue and a fleet.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The ID of the farm that the queue and fleet belong to.

Parameter fleetId : The fleet ID.

Parameter queueId : The queue ID.

Implementation

Future<void> createQueueFleetAssociation({
  required String farmId,
  required String fleetId,
  required String queueId,
}) async {
  final $payload = <String, dynamic>{
    'fleetId': fleetId,
    'queueId': queueId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queue-fleet-associations',
    exceptionFnMap: _exceptionFns,
  );
}