deleteMonitor method

Future<void> deleteMonitor({
  1. required String monitorId,
})

Removes a Deadline Cloud monitor. After you delete a monitor, you can create a new one and attach farms to the monitor.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter monitorId : The unique identifier of the monitor to delete. This ID is returned by the CreateMonitor operation, and is included in the response to the GetMonitor operation.

Implementation

Future<void> deleteMonitor({
  required String monitorId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/2023-10-12/monitors/${Uri.encodeComponent(monitorId)}',
    exceptionFnMap: _exceptionFns,
  );
}