deleteQueueLimitAssociation method

Future<void> deleteQueueLimitAssociation({
  1. required String farmId,
  2. required String limitId,
  3. required String queueId,
})

Removes the association between a queue and a limit. You must use the UpdateQueueLimitAssociation operation to set the status to STOP_LIMIT_USAGE_AND_COMPLETE_TASKS or STOP_LIMIT_USAGE_AND_CANCEL_TASKS. The status does not change immediately. Use the GetQueueLimitAssociation operation to see if the status changed to STOPPED before deleting the association.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The unique identifier of the farm that contains the queue and limit to disassociate.

Parameter limitId : The unique identifier of the limit to disassociate.

Parameter queueId : The unique identifier of the queue to disassociate.

Implementation

Future<void> deleteQueueLimitAssociation({
  required String farmId,
  required String limitId,
  required String queueId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queue-limit-associations/${Uri.encodeComponent(queueId)}/${Uri.encodeComponent(limitId)}',
    exceptionFnMap: _exceptionFns,
  );
}