getQueueLimitAssociation method

Future<GetQueueLimitAssociationResponse> getQueueLimitAssociation({
  1. required String farmId,
  2. required String limitId,
  3. required String queueId,
})

Gets information about a specific association between a queue and a limit.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The unique identifier of the farm that contains the associated queue and limit.

Parameter limitId : The unique identifier of the limit associated with the queue.

Parameter queueId : The unique identifier of the queue associated with the limit.

Implementation

Future<GetQueueLimitAssociationResponse> getQueueLimitAssociation({
  required String farmId,
  required String limitId,
  required String queueId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queue-limit-associations/${Uri.encodeComponent(queueId)}/${Uri.encodeComponent(limitId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetQueueLimitAssociationResponse.fromJson(response);
}