listBudgets method

Future<ListBudgetsResponse> listBudgets({
  1. required String farmId,
  2. int? maxResults,
  3. String? nextToken,
  4. BudgetStatus? status,
})

A list of budgets in a farm.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID associated with the budgets.

Parameter maxResults : The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Parameter nextToken : The token for the next set of results, or null to start from the beginning.

Parameter status : The status to list for the budgets.

Implementation

Future<ListBudgetsResponse> listBudgets({
  required String farmId,
  int? maxResults,
  String? nextToken,
  BudgetStatus? status,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (status != null) 'status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/budgets',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListBudgetsResponse.fromJson(response);
}