listJobs method
Lists jobs.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The farm ID for the jobs.
Parameter queueId :
The queue ID for the job.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Parameter principalId :
The principal ID of the members on the jobs.
Implementation
Future<ListJobsResponse> listJobs({
required String farmId,
required String queueId,
int? maxResults,
String? nextToken,
String? principalId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (principalId != null) 'principalId': [principalId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queues/${Uri.encodeComponent(queueId)}/jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListJobsResponse.fromJson(response);
}