listLimits method

Future<ListLimitsResponse> listLimits({
  1. required String farmId,
  2. int? maxResults,
  3. String? nextToken,
})

Gets a list of limits defined in the specified farm.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The unique identifier of the farm that contains the limits.

Parameter maxResults : The maximum number of limits to return in each page of results.

Parameter nextToken : The token for the next set of results, or null to start from the beginning.

Implementation

Future<ListLimitsResponse> listLimits({
  required String farmId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/limits',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListLimitsResponse.fromJson(response);
}