listMeteredProducts method
Lists metered products.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter licenseEndpointId :
The license endpoint ID to include on the list of metered products.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Implementation
Future<ListMeteredProductsResponse> listMeteredProducts({
required String licenseEndpointId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2023-10-12/license-endpoints/${Uri.encodeComponent(licenseEndpointId)}/metered-products',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMeteredProductsResponse.fromJson(response);
}