listQueues method

Future<ListQueuesResponse> listQueues({
  1. required String farmId,
  2. int? maxResults,
  3. String? nextToken,
  4. String? principalId,
  5. QueueStatus? status,
})

Lists queues.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID of the queue.

Parameter maxResults : The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Parameter nextToken : The token for the next set of results, or null to start from the beginning.

Parameter principalId : The principal IDs to include in the list of queues.

Parameter status : The status of the queues listed.

  • ACTIVE–The queues are active.
  • SCHEDULING–The queues are scheduling.
  • SCHEDULING_BLOCKED–The queue scheduling is blocked for these queues.

Implementation

Future<ListQueuesResponse> listQueues({
  required String farmId,
  int? maxResults,
  String? nextToken,
  String? principalId,
  QueueStatus? status,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (principalId != null) 'principalId': [principalId],
    if (status != null) 'status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queues',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListQueuesResponse.fromJson(response);
}