listSessionActions method
Lists session actions.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The farm ID for the session actions list.
Parameter jobId :
The job ID for the session actions list.
Parameter queueId :
The queue ID for the session actions list.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Parameter sessionId :
The session ID to include on the sessions action list.
Parameter taskId :
The task ID for the session actions list.
Implementation
Future<ListSessionActionsResponse> listSessionActions({
required String farmId,
required String jobId,
required String queueId,
int? maxResults,
String? nextToken,
String? sessionId,
String? taskId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (sessionId != null) 'sessionId': [sessionId],
if (taskId != null) 'taskId': [taskId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queues/${Uri.encodeComponent(queueId)}/jobs/${Uri.encodeComponent(jobId)}/session-actions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSessionActionsResponse.fromJson(response);
}