listWorkers method

Future<ListWorkersResponse> listWorkers({
  1. required String farmId,
  2. required String fleetId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists workers.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter farmId : The farm ID connected to the workers.

Parameter fleetId : The fleet ID of the workers.

Parameter maxResults : The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Parameter nextToken : The token for the next set of results, or null to start from the beginning.

Implementation

Future<ListWorkersResponse> listWorkers({
  required String farmId,
  required String fleetId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets/${Uri.encodeComponent(fleetId)}/workers',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListWorkersResponse.fromJson(response);
}