Detective class

Detective uses machine learning and purpose-built visualizations to help you to analyze and investigate security issues across your Amazon Web Services (Amazon Web Services) workloads. Detective automatically extracts time-based events such as login attempts, API calls, and network traffic from CloudTrail and Amazon Virtual Private Cloud (Amazon VPC) flow logs. It also extracts findings detected by Amazon GuardDuty.

The Detective API primarily supports the creation and management of behavior graphs. A behavior graph contains the extracted data from a set of member accounts, and is created and managed by an administrator account.

To add a member account to the behavior graph, the administrator account sends an invitation to the account. When the account accepts the invitation, it becomes a member account in the behavior graph.

Detective is also integrated with Organizations. The organization management account designates the Detective administrator account for the organization. That account becomes the administrator account for the organization behavior graph. The Detective administrator account is also the delegated administrator account for Detective in Organizations.

The Detective administrator account can enable any organization account as a member account in the organization behavior graph. The organization accounts do not receive invitations. The Detective administrator account can also invite other accounts to the organization behavior graph.

Every behavior graph is specific to a Region. You can only use the API to manage behavior graphs that belong to the Region that is associated with the currently selected endpoint.

The administrator account for a behavior graph can use the Detective API to do the following:

  • Enable and disable Detective. Enabling Detective creates a new behavior graph.
  • View the list of member accounts in a behavior graph.
  • Add member accounts to a behavior graph.
  • Remove member accounts from a behavior graph.
  • Apply tags to a behavior graph.
The organization management account can use the Detective API to select the delegated administrator for Detective.

The Detective administrator account for an organization can use the Detective API to do the following:

  • Perform all of the functions of an administrator account.
  • Determine whether to automatically enable new organization accounts as member accounts in the organization behavior graph.
An invited member account can use the Detective API to do the following:
  • View the list of behavior graphs that they are invited to.
  • Accept an invitation to contribute to a behavior graph.
  • Decline an invitation to contribute to a behavior graph.
  • Remove their account from a behavior graph.
All API actions are logged as CloudTrail events. See Logging Detective API Calls with CloudTrail.

Constructors

Detective({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation({required String graphArn}) Future<void>
Accepts an invitation for the member account to contribute data to a behavior graph. This operation can only be called by an invited member account.
batchGetGraphMemberDatasources({required List<String> accountIds, required String graphArn}) Future<BatchGetGraphMemberDatasourcesResponse>
Gets data source package information for the behavior graph.
batchGetMembershipDatasources({required List<String> graphArns}) Future<BatchGetMembershipDatasourcesResponse>
Gets information on the data source package history for an account.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createGraph({Map<String, String>? tags}) Future<CreateGraphResponse>
Creates a new behavior graph for the calling account, and sets that account as the administrator account. This operation is called by the account that is enabling Detective.
createMembers({required List<Account> accounts, required String graphArn, bool? disableEmailNotification, String? message}) Future<CreateMembersResponse>
CreateMembers is used to send invitations to accounts. For the organization behavior graph, the Detective administrator account uses CreateMembers to enable organization accounts as member accounts.
deleteGraph({required String graphArn}) Future<void>
Disables the specified behavior graph and queues it to be deleted. This operation removes the behavior graph from each member account's list of behavior graphs.
deleteMembers({required List<String> accountIds, required String graphArn}) Future<DeleteMembersResponse>
Removes the specified member accounts from the behavior graph. The removed accounts no longer contribute data to the behavior graph. This operation can only be called by the administrator account for the behavior graph.
describeOrganizationConfiguration({required String graphArn}) Future<DescribeOrganizationConfigurationResponse>
Returns information about the configuration for the organization behavior graph. Currently indicates whether to automatically enable new organization accounts as member accounts.
disableOrganizationAdminAccount() Future<void>
Removes the Detective administrator account in the current Region. Deletes the organization behavior graph.
disassociateMembership({required String graphArn}) Future<void>
Removes the member account from the specified behavior graph. This operation can only be called by an invited member account that has the ENABLED status.
enableOrganizationAdminAccount({required String accountId}) Future<void>
Designates the Detective administrator account for the organization in the current Region.
getInvestigation({required String graphArn, required String investigationId}) Future<GetInvestigationResponse>
Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise. An indicator of compromise (IOC) is an artifact observed in or on a network, system, or environment that can (with a high level of confidence) identify malicious activity or a security incident. GetInvestigation returns the investigation results of an investigation for a behavior graph.
getMembers({required List<String> accountIds, required String graphArn}) Future<GetMembersResponse>
Returns the membership details for specified member accounts for a behavior graph.
listDatasourcePackages({required String graphArn, int? maxResults, String? nextToken}) Future<ListDatasourcePackagesResponse>
Lists data source packages in the behavior graph.
listGraphs({int? maxResults, String? nextToken}) Future<ListGraphsResponse>
Returns the list of behavior graphs that the calling account is an administrator account of. This operation can only be called by an administrator account.
listIndicators({required String graphArn, required String investigationId, IndicatorType? indicatorType, int? maxResults, String? nextToken}) Future<ListIndicatorsResponse>
Gets the indicators from an investigation. You can use the information from the indicators to determine if an IAM user and/or IAM role is involved in an unusual activity that could indicate malicious behavior and its impact.
listInvestigations({required String graphArn, FilterCriteria? filterCriteria, int? maxResults, String? nextToken, SortCriteria? sortCriteria}) Future<ListInvestigationsResponse>
Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise. An indicator of compromise (IOC) is an artifact observed in or on a network, system, or environment that can (with a high level of confidence) identify malicious activity or a security incident. ListInvestigations lists all active Detective investigations.
listInvitations({int? maxResults, String? nextToken}) Future<ListInvitationsResponse>
Retrieves the list of open and accepted behavior graph invitations for the member account. This operation can only be called by an invited member account.
listMembers({required String graphArn, int? maxResults, String? nextToken}) Future<ListMembersResponse>
Retrieves the list of member accounts for a behavior graph.
listOrganizationAdminAccounts({int? maxResults, String? nextToken}) Future<ListOrganizationAdminAccountsResponse>
Returns information about the Detective administrator account for an organization. Can only be called by the organization management account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns the tag values that are assigned to a behavior graph.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectInvitation({required String graphArn}) Future<void>
Rejects an invitation to contribute the account data to a behavior graph. This operation must be called by an invited member account that has the INVITED status.
startInvestigation({required String entityArn, required String graphArn, required DateTime scopeEndTime, required DateTime scopeStartTime}) Future<StartInvestigationResponse>
Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise. An indicator of compromise (IOC) is an artifact observed in or on a network, system, or environment that can (with a high level of confidence) identify malicious activity or a security incident. StartInvestigation initiates an investigation on an entity in a behavior graph.
startMonitoringMember({required String accountId, required String graphArn}) Future<void>
Sends a request to enable data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Applies tag values to a behavior graph.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a behavior graph.
updateDatasourcePackages({required List<DatasourcePackage> datasourcePackages, required String graphArn}) Future<void>
Starts a data source package for the Detective behavior graph.
updateInvestigationState({required String graphArn, required String investigationId, required State state}) Future<void>
Updates the state of an investigation.
updateOrganizationConfiguration({required String graphArn, bool? autoEnable}) Future<void>
Updates the configuration for the Organizations integration in the current Region. Can only be called by the Detective administrator account for the organization.

Operators

operator ==(Object other) bool
The equality operator.
inherited