acceptInvitation method
Accepts an invitation for the member account to contribute data to a behavior graph. This operation can only be called by an invited member account.
The request provides the ARN of behavior graph.
The member account status in the graph must be INVITED.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter graphArn :
The ARN of the behavior graph that the member account is accepting the
invitation for.
The member account status in the behavior graph must be
INVITED.
Implementation
Future<void> acceptInvitation({
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'GraphArn': graphArn,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/invitation',
exceptionFnMap: _exceptionFns,
);
}