batchGetGraphMemberDatasources method

Future<BatchGetGraphMemberDatasourcesResponse> batchGetGraphMemberDatasources({
  1. required List<String> accountIds,
  2. required String graphArn,
})

Gets data source package information for the behavior graph.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter accountIds : The list of Amazon Web Services accounts to get data source package information on.

Parameter graphArn : The ARN of the behavior graph.

Implementation

Future<BatchGetGraphMemberDatasourcesResponse>
    batchGetGraphMemberDatasources({
  required List<String> accountIds,
  required String graphArn,
}) async {
  final $payload = <String, dynamic>{
    'AccountIds': accountIds,
    'GraphArn': graphArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/graph/datasources/get',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetGraphMemberDatasourcesResponse.fromJson(response);
}