createMembers method
CreateMembers is used to send invitations to accounts. For
the organization behavior graph, the Detective administrator account uses
CreateMembers to enable organization accounts as member
accounts.
For invited accounts, CreateMembers sends a request to invite
the specified Amazon Web Services accounts to be member accounts in the
behavior graph. This operation can only be called by the administrator
account for a behavior graph.
CreateMembers verifies the accounts and then invites the
verified accounts. The administrator can optionally specify to not send
invitation emails to the member accounts. This would be used when the
administrator manages their member accounts centrally.
For organization accounts in the organization behavior graph,
CreateMembers attempts to enable the accounts. The
organization accounts do not receive invitations.
The request provides the behavior graph ARN and the list of accounts to invite or to enable.
The response separates the requested accounts into two lists:
-
The accounts that
CreateMemberswas able to process. For invited accounts, includes member accounts that are being verified, that have passed verification and are to be invited, and that have failed verification. For organization accounts in the organization behavior graph, includes accounts that can be enabled and that cannot be enabled. -
The accounts that
CreateMemberswas unable to process. This list includes accounts that were already invited to be member accounts in the behavior graph.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter accounts :
The list of Amazon Web Services accounts to invite or to enable. You can
invite or enable up to 50 accounts at a time. For each invited account,
the account list contains the account identifier and the Amazon Web
Services account root user email address. For organization accounts in the
organization behavior graph, the email address is not required.
Parameter graphArn :
The ARN of the behavior graph.
Parameter disableEmailNotification :
if set to true, then the invited accounts do not receive
email notifications. By default, this is set to false, and
the invited accounts receive email notifications.
Organization accounts in the organization behavior graph do not receive email notifications.
Parameter message :
Customized message text to include in the invitation email message to the
invited member accounts.
Implementation
Future<CreateMembersResponse> createMembers({
required List<Account> accounts,
required String graphArn,
bool? disableEmailNotification,
String? message,
}) async {
final $payload = <String, dynamic>{
'Accounts': accounts,
'GraphArn': graphArn,
if (disableEmailNotification != null)
'DisableEmailNotification': disableEmailNotification,
if (message != null) 'Message': message,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/graph/members',
exceptionFnMap: _exceptionFns,
);
return CreateMembersResponse.fromJson(response);
}