deleteGraph method

Future<void> deleteGraph({
  1. required String graphArn,
})

Disables the specified behavior graph and queues it to be deleted. This operation removes the behavior graph from each member account's list of behavior graphs.

DeleteGraph can only be called by the administrator account for a behavior graph.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter graphArn : The ARN of the behavior graph to disable.

Implementation

Future<void> deleteGraph({
  required String graphArn,
}) async {
  final $payload = <String, dynamic>{
    'GraphArn': graphArn,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/graph/removal',
    exceptionFnMap: _exceptionFns,
  );
}