describeOrganizationConfiguration method
Future<DescribeOrganizationConfigurationResponse>
describeOrganizationConfiguration({
- required String graphArn,
Returns information about the configuration for the organization behavior graph. Currently indicates whether to automatically enable new organization accounts as member accounts.
Can only be called by the Detective administrator account for the organization.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter graphArn :
The ARN of the organization behavior graph.
Implementation
Future<DescribeOrganizationConfigurationResponse>
describeOrganizationConfiguration({
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'GraphArn': graphArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/orgs/describeOrganizationConfiguration',
exceptionFnMap: _exceptionFns,
);
return DescribeOrganizationConfigurationResponse.fromJson(response);
}