getInvestigation method

Future<GetInvestigationResponse> getInvestigation({
  1. required String graphArn,
  2. required String investigationId,
})

Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise. An indicator of compromise (IOC) is an artifact observed in or on a network, system, or environment that can (with a high level of confidence) identify malicious activity or a security incident. GetInvestigation returns the investigation results of an investigation for a behavior graph.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter graphArn : The Amazon Resource Name (ARN) of the behavior graph.

Parameter investigationId : The investigation ID of the investigation report.

Implementation

Future<GetInvestigationResponse> getInvestigation({
  required String graphArn,
  required String investigationId,
}) async {
  final $payload = <String, dynamic>{
    'GraphArn': graphArn,
    'InvestigationId': investigationId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/investigations/getInvestigation',
    exceptionFnMap: _exceptionFns,
  );
  return GetInvestigationResponse.fromJson(response);
}