listIndicators method
Gets the indicators from an investigation. You can use the information from the indicators to determine if an IAM user and/or IAM role is involved in an unusual activity that could indicate malicious behavior and its impact.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter graphArn :
The Amazon Resource Name (ARN) of the behavior graph.
Parameter investigationId :
The investigation ID of the investigation report.
Parameter indicatorType :
For the list of indicators of compromise that are generated by Detective
investigations, see Detective
investigations.
Parameter maxResults :
Lists the maximum number of indicators in a page.
Parameter nextToken :
Lists if there are more results available. The value of nextToken is a
unique pagination token for each page. Repeat the call using the returned
token to retrieve the next page. Keep all other arguments unchanged.
Each pagination token expires after 24 hours. Using an expired pagination token will return a Validation Exception error.
Implementation
Future<ListIndicatorsResponse> listIndicators({
required String graphArn,
required String investigationId,
IndicatorType? indicatorType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'GraphArn': graphArn,
'InvestigationId': investigationId,
if (indicatorType != null) 'IndicatorType': indicatorType.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/investigations/listIndicators',
exceptionFnMap: _exceptionFns,
);
return ListIndicatorsResponse.fromJson(response);
}