listInvestigations method
Detective investigations lets you investigate IAM users and IAM roles
using indicators of compromise. An indicator of compromise (IOC) is an
artifact observed in or on a network, system, or environment that can
(with a high level of confidence) identify malicious activity or a
security incident. ListInvestigations lists all active
Detective investigations.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter graphArn :
The Amazon Resource Name (ARN) of the behavior graph.
Parameter filterCriteria :
Filters the investigation results based on a criteria.
Parameter maxResults :
Lists the maximum number of investigations in a page.
Parameter nextToken :
Lists if there are more results available. The value of nextToken is a
unique pagination token for each page. Repeat the call using the returned
token to retrieve the next page. Keep all other arguments unchanged.
Each pagination token expires after 24 hours. Using an expired pagination token will return a Validation Exception error.
Parameter sortCriteria :
Sorts the investigation results based on a criteria.
Implementation
Future<ListInvestigationsResponse> listInvestigations({
required String graphArn,
FilterCriteria? filterCriteria,
int? maxResults,
String? nextToken,
SortCriteria? sortCriteria,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'GraphArn': graphArn,
if (filterCriteria != null) 'FilterCriteria': filterCriteria,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sortCriteria != null) 'SortCriteria': sortCriteria,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/investigations/listInvestigations',
exceptionFnMap: _exceptionFns,
);
return ListInvestigationsResponse.fromJson(response);
}