listInvitations method
Retrieves the list of open and accepted behavior graph invitations for the member account. This operation can only be called by an invited member account.
Open invitations are invitations that the member account has not responded to.
The results do not include behavior graphs for which the member account declined the invitation. The results also do not include behavior graphs that the member account resigned from or was removed from.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
The maximum number of behavior graph invitations to return in the
response. The total must be less than the overall limit on the number of
results to return, which is currently 200.
Parameter nextToken :
For requests to retrieve the next page of results, the pagination token
that was returned with the previous page of results. The initial request
does not include a pagination token.
Implementation
Future<ListInvitationsResponse> listInvitations({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
200,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/invitations/list',
exceptionFnMap: _exceptionFns,
);
return ListInvitationsResponse.fromJson(response);
}