listMembers method
Retrieves the list of member accounts for a behavior graph.
For invited accounts, the results do not include member accounts that were removed from the behavior graph.
For the organization behavior graph, the results do not include organization accounts that the Detective administrator account has not enabled as member accounts.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter graphArn :
The ARN of the behavior graph for which to retrieve the list of member
accounts.
Parameter maxResults :
The maximum number of member accounts to include in the response. The
total must be less than the overall limit on the number of results to
return, which is currently 200.
Parameter nextToken :
For requests to retrieve the next page of member account results, the
pagination token that was returned with the previous page of results. The
initial request does not include a pagination token.
Implementation
Future<ListMembersResponse> listMembers({
required String graphArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
200,
);
final $payload = <String, dynamic>{
'GraphArn': graphArn,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/graph/members/list',
exceptionFnMap: _exceptionFns,
);
return ListMembersResponse.fromJson(response);
}