rejectInvitation method

Future<void> rejectInvitation({
  1. required String graphArn,
})

Rejects an invitation to contribute the account data to a behavior graph. This operation must be called by an invited member account that has the INVITED status.

RejectInvitation cannot be called by an organization account in the organization behavior graph. In the organization behavior graph, organization accounts do not receive an invitation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter graphArn : The ARN of the behavior graph to reject the invitation to.

The member account's current member status in the behavior graph must be INVITED.

Implementation

Future<void> rejectInvitation({
  required String graphArn,
}) async {
  final $payload = <String, dynamic>{
    'GraphArn': graphArn,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/invitation/removal',
    exceptionFnMap: _exceptionFns,
  );
}