updateOrganizationConfiguration method

Future<void> updateOrganizationConfiguration({
  1. required String graphArn,
  2. bool? autoEnable,
})

Updates the configuration for the Organizations integration in the current Region. Can only be called by the Detective administrator account for the organization.

May throw AccessDeniedException. May throw InternalServerException. May throw TooManyRequestsException. May throw ValidationException.

Parameter graphArn : The ARN of the organization behavior graph.

Parameter autoEnable : Indicates whether to automatically enable new organization accounts as member accounts in the organization behavior graph.

Implementation

Future<void> updateOrganizationConfiguration({
  required String graphArn,
  bool? autoEnable,
}) async {
  final $payload = <String, dynamic>{
    'GraphArn': graphArn,
    if (autoEnable != null) 'AutoEnable': autoEnable,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/orgs/updateOrganizationConfiguration',
    exceptionFnMap: _exceptionFns,
  );
}