DevOpsAgent class

AWS DevOps Agent is your always-available operations teammate. It resolves and proactively prevents incidents, optimizes application reliability and performance, and handles on-demand SRE tasks across AWS, multicloud, and on-premises environments. AWS DevOps Agent investigates incidents as an experienced DevOps engineer would. It learns your applications and their relationships. It works with your observability tools, runbooks, code repositories, and CI/CD pipelines. The agent correlates telemetry, code, and deployment data across all of them.

Constructors

DevOpsAgent({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false, bool disableHostPrefix = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateService({required String agentSpaceId, required ServiceConfiguration configuration, required String serviceId}) Future<AssociateServiceOutput>
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAgentSpace({required String name, String? clientToken, String? description, String? kmsKeyArn, String? locale, Map<String, String>? tags}) Future<CreateAgentSpaceOutput>
Creates a new AgentSpace with the specified name and description. Duplicate space names are allowed.
createBacklogTask({required String agentSpaceId, required Priority priority, required TaskType taskType, required String title, String? clientToken, String? description, ReferenceInput? reference}) Future<CreateBacklogTaskResponse>
Creates a new backlog task in the specified agent space
createChat({required String agentSpaceId, String? userId, UserType? userType}) Future<CreateChatResponse>
Creates a new chat execution in the specified agent space
createPrivateConnection({required PrivateConnectionMode mode, required String name, Map<String, String>? tags}) Future<CreatePrivateConnectionOutput>
Creates a Private Connection to a target resource.
deleteAgentSpace({required String agentSpaceId}) Future<void>
Deletes an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
deletePrivateConnection({required String name}) Future<DeletePrivateConnectionOutput>
Deletes a Private Connection. The deletion is asynchronous and returns DELETE_IN_PROGRESS status.
deregisterService({required String serviceId}) Future<void>
Deregister a service
describePrivateConnection({required String name}) Future<DescribePrivateConnectionOutput>
Retrieves details of an existing Private Connection.
disableOperatorApp({required String agentSpaceId, AuthFlow? authFlow}) Future<void>
Disable the Operator App for the specified AgentSpace
disassociateService({required String agentSpaceId, required String associationId}) Future<void>
Deletes a specific service association from an AgentSpace. This operation is idempotent and returns a 204 No Content response on success.
enableOperatorApp({required String agentSpaceId, required AuthFlow authFlow, required String operatorAppRoleArn, String? idcInstanceArn, String? idpClientId, String? idpClientSecret, String? issuerUrl, String? provider}) Future<EnableOperatorAppOutput>
Enable the Operator App to access the given AgentSpace
getAccountUsage() Future<GetAccountUsageOutput>
Retrieves monthly account usage metrics and limits for the AWS account.
getAgentSpace({required String agentSpaceId}) Future<GetAgentSpaceOutput>
Retrieves detailed information about a specific AgentSpace.
getAssociation({required String agentSpaceId, required String associationId}) Future<GetAssociationOutput>
Retrieves given associations configured for a specific AgentSpace.
getBacklogTask({required String agentSpaceId, required String taskId}) Future<GetBacklogTaskResponse>
Gets a backlog task for the specified agent space and task id
getOperatorApp({required String agentSpaceId}) Future<GetOperatorAppOutput>
Get the full auth configuration of operator including any enabled auth flow
getRecommendation({required String agentSpaceId, required String recommendationId, int? recommendationVersion}) Future<GetRecommendationResponse>
Retrieves a specific recommendation by its ID
getService({required String serviceId}) Future<GetServiceOutput>
Retrieves given service by it's unique identifier
listAgentSpaces({int? maxResults, String? nextToken}) Future<ListAgentSpacesOutput>
Lists all AgentSpaces with optional pagination.
listAssociations({required String agentSpaceId, String? filterServiceTypes, int? maxResults, String? nextToken}) Future<ListAssociationsOutput>
List all associations for given AgentSpace
listBacklogTasks({required String agentSpaceId, TaskFilter? filter, int? limit, String? nextToken, TaskSortOrder? order, TaskSortField? sortField}) Future<ListBacklogTasksResponse>
Lists backlog tasks in the specified agent space with optional filtering and sorting
listChats({required String agentSpaceId, int? maxResults, String? nextToken, String? userId}) Future<ListChatsResponse>
Retrieves a paginated list of the user's recent chat executions
listExecutions({required String agentSpaceId, required String taskId, int? limit, String? nextToken}) Future<ListExecutionsResponse>
List executions
listGoals({required String agentSpaceId, GoalType? goalType, int? limit, String? nextToken, GoalStatus? status}) Future<ListGoalsResponse>
Lists goals in the specified agent space with optional filtering
listJournalRecords({required String agentSpaceId, required String executionId, int? limit, String? nextToken, OrderType? order, String? recordType}) Future<ListJournalRecordsResponse>
List journal records for a specific execution
listPendingMessages({required String agentSpaceId, required String executionId}) Future<ListPendingMessagesResponse>
List pending messages for a specific execution.
listPrivateConnections() Future<ListPrivateConnectionsOutput>
Lists all Private Connections in the caller's account.
listRecommendations({required String agentSpaceId, String? goalId, int? limit, String? nextToken, RecommendationPriority? priority, RecommendationStatus? status, String? taskId}) Future<ListRecommendationsResponse>
Lists recommendations for the specified agent space
listServices({Service? filterServiceType, int? maxResults, String? nextToken}) Future<ListServicesOutput>
List a list of registered service on the account level.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists tags for the specified AWS DevOps Agent resource.
listWebhooks({required String agentSpaceId, required String associationId}) Future<ListWebhooksOutput>
List all webhooks for given Association
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerService({required PostRegisterServiceSupportedService service, required ServiceDetails serviceDetails, String? kmsKeyArn, String? name, String? privateConnectionName, Map<String, String>? tags}) Future<RegisterServiceOutput>
This operation registers the specified service
sendMessage({required String agentSpaceId, required String content, required String executionId, SendMessageContext? context, String? userId}) Future<SendMessageResponse>
Sends a chat message and streams the response for the specified agent space execution
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or overwrites tags for the specified AWS DevOps Agent resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from the specified AWS DevOps Agent resource.
updateAgentSpace({required String agentSpaceId, String? description, String? locale, String? name}) Future<UpdateAgentSpaceOutput>
Updates the information of an existing AgentSpace.
updateAssociation({required String agentSpaceId, required String associationId, required ServiceConfiguration configuration}) Future<UpdateAssociationOutput>
Partially updates the configuration of an existing service association for an AgentSpace. Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.
updateBacklogTask({required String agentSpaceId, required String taskId, String? clientToken, TaskStatus? taskStatus}) Future<UpdateBacklogTaskResponse>
Update an existing backlog task.
updateGoal({required String agentSpaceId, required String goalId, String? clientToken, GoalScheduleInput? evaluationSchedule}) Future<UpdateGoalResponse>
Update an existing goal
updateOperatorAppIdpConfig({required String agentSpaceId, String? idpClientSecret}) Future<UpdateOperatorAppIdpConfigOutput>
Update the external Identity Provider configuration for the Operator App
updatePrivateConnectionCertificate({required String certificate, required String name}) Future<UpdatePrivateConnectionCertificateOutput>
Updates the certificate associated with a Private Connection.
updateRecommendation({required String agentSpaceId, required String recommendationId, String? additionalContext, String? clientToken, RecommendationStatus? status}) Future<UpdateRecommendationResponse>
Updates an existing recommendation with new content, status, or metadata
validateAwsAssociations({required String agentSpaceId}) Future<void>
Validates an aws association and set status and returns a 204 No Content response on success.

Operators

operator ==(Object other) bool
The equality operator.
inherited