describeAccountHealth method
Returns the number of open reactive insights, the number of open proactive insights, and the number of metrics analyzed in your Amazon Web Services account. Use these numbers to gauge the health of operations in your Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Implementation
Future<DescribeAccountHealthResponse> describeAccountHealth() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts/health',
exceptionFnMap: _exceptionFns,
);
return DescribeAccountHealthResponse.fromJson(response);
}