describeAccountOverview method

Future<DescribeAccountOverviewResponse> describeAccountOverview({
  1. required DateTime fromTime,
  2. DateTime? toTime,
})

For the time range passed in, returns the number of open reactive insight that were created, the number of open proactive insights that were created, and the Mean Time to Recover (MTTR) for all closed reactive insights.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter fromTime : The start of the time range passed in. The start time granularity is at the day level. The floor of the start time is used. Returned information occurred after this day.

Parameter toTime : The end of the time range passed in. The start time granularity is at the day level. The floor of the start time is used. Returned information occurred before this day. If this is not specified, then the current day is used.

Implementation

Future<DescribeAccountOverviewResponse> describeAccountOverview({
  required DateTime fromTime,
  DateTime? toTime,
}) async {
  final $payload = <String, dynamic>{
    'FromTime': unixTimestampToJson(fromTime),
    if (toTime != null) 'ToTime': unixTimestampToJson(toTime),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/accounts/overview',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAccountOverviewResponse.fromJson(response);
}