describeEventSourcesConfig method

Future<DescribeEventSourcesConfigResponse> describeEventSourcesConfig()

Returns the integration status of services that are integrated with DevOps Guru as Consumer via EventBridge. The one service that can be integrated with DevOps Guru is Amazon CodeGuru Profiler, which can produce proactive recommendations which can be stored and viewed in DevOps Guru.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<DescribeEventSourcesConfigResponse>
    describeEventSourcesConfig() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/event-sources',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeEventSourcesConfigResponse.fromJson(response);
}