describeFeedback method

Future<DescribeFeedbackResponse> describeFeedback({
  1. String? insightId,
})

Returns the most recent feedback submitted in the current Amazon Web Services account and Region.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter insightId : The ID of the insight for which the feedback was provided.

Implementation

Future<DescribeFeedbackResponse> describeFeedback({
  String? insightId,
}) async {
  final $payload = <String, dynamic>{
    if (insightId != null) 'InsightId': insightId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/feedback',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeFeedbackResponse.fromJson(response);
}