describeOrganizationResourceCollectionHealth method

Future<DescribeOrganizationResourceCollectionHealthResponse> describeOrganizationResourceCollectionHealth({
  1. required OrganizationResourceCollectionType organizationResourceCollectionType,
  2. List<String>? accountIds,
  3. int? maxResults,
  4. String? nextToken,
  5. List<String>? organizationalUnitIds,
})

Provides an overview of your system's health. If additional member accounts are part of your organization, you can filter those accounts using the AccountIds field.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter organizationResourceCollectionType : An Amazon Web Services resource collection type. This type specifies how analyzed Amazon Web Services resources are defined. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks.

Parameter accountIds : The ID of the Amazon Web Services account.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

Parameter organizationalUnitIds : The ID of the organizational unit.

Implementation

Future<DescribeOrganizationResourceCollectionHealthResponse>
    describeOrganizationResourceCollectionHealth({
  required OrganizationResourceCollectionType
      organizationResourceCollectionType,
  List<String>? accountIds,
  int? maxResults,
  String? nextToken,
  List<String>? organizationalUnitIds,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $payload = <String, dynamic>{
    'OrganizationResourceCollectionType':
        organizationResourceCollectionType.value,
    if (accountIds != null) 'AccountIds': accountIds,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (organizationalUnitIds != null)
      'OrganizationalUnitIds': organizationalUnitIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/organization/health/resource-collection',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeOrganizationResourceCollectionHealthResponse.fromJson(
      response);
}