describeResourceCollectionHealth method
- required ResourceCollectionType resourceCollectionType,
- String? nextToken,
Returns the number of open proactive insights, open reactive insights, and the Mean Time to Recover (MTTR) for all closed insights in resource collections in your account. You specify the type of Amazon Web Services resources collection. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceCollectionType :
An Amazon Web Services resource collection type. This type specifies how
analyzed Amazon Web Services resources are defined. The two types of
Amazon Web Services resource collections supported are Amazon Web Services
CloudFormation stacks and Amazon Web Services resources that contain the
same Amazon Web Services tag. DevOps Guru can be configured to analyze the
Amazon Web Services resources that are defined in the stacks or that are
tagged using the same tag key. You can specify up to 500 Amazon Web
Services CloudFormation stacks.
Parameter nextToken :
The pagination token to use to retrieve the next page of results for this
operation. If this value is null, it retrieves the first page.
Implementation
Future<DescribeResourceCollectionHealthResponse>
describeResourceCollectionHealth({
required ResourceCollectionType resourceCollectionType,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/health/resource-collection/${Uri.encodeComponent(resourceCollectionType.value)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeResourceCollectionHealthResponse.fromJson(response);
}