getCostEstimation method

Future<GetCostEstimationResponse> getCostEstimation({
  1. String? nextToken,
})

Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon Web Services resources. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nextToken : The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

Implementation

Future<GetCostEstimationResponse> getCostEstimation({
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (nextToken != null) 'NextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cost-estimation',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetCostEstimationResponse.fromJson(response);
}