removeNotificationChannel method
Removes a notification channel from DevOps Guru. A notification channel is used to notify you when DevOps Guru generates an insight that contains information about how to improve your operations.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The ID of the notification channel to be removed.
Implementation
Future<void> removeNotificationChannel({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/channels/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}