updateEventSourcesConfig method
Enables or disables integration with a service that can be integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is Amazon CodeGuru Profiler, which can produce proactive recommendations which can be stored and viewed in DevOps Guru.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter eventSources :
Configuration information about the integration of DevOps Guru as the
Consumer via EventBridge with another AWS Service.
Implementation
Future<void> updateEventSourcesConfig({
EventSourcesConfig? eventSources,
}) async {
final $payload = <String, dynamic>{
if (eventSources != null) 'EventSources': eventSources,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/event-sources',
exceptionFnMap: _exceptionFns,
);
}