updateResourceCollection method
- required UpdateResourceCollectionAction action,
- required UpdateResourceCollectionFilter resourceCollection,
Updates the collection of resources that DevOps Guru analyzes. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks. This method also creates the IAM role required for you to use DevOps Guru.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter action :
Specifies if the resource collection in the request is added or deleted to
the resource collection.
Implementation
Future<void> updateResourceCollection({
required UpdateResourceCollectionAction action,
required UpdateResourceCollectionFilter resourceCollection,
}) async {
final $payload = <String, dynamic>{
'Action': action.value,
'ResourceCollection': resourceCollection,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/resource-collections',
exceptionFnMap: _exceptionFns,
);
}