deleteRemoteAccessSession method

Future<void> deleteRemoteAccessSession({
  1. required String arn,
})

Deletes a completed remote access session and its results. You cannot delete a remote access session if it is still active.

May throw ArgumentException. May throw LimitExceededException. May throw NotFoundException. May throw ServiceAccountException.

Parameter arn : The Amazon Resource Name (ARN) of the session for which you want to delete remote access.

Implementation

Future<void> deleteRemoteAccessSession({
  required String arn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DeviceFarm_20150623.DeleteRemoteAccessSession'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
    },
  );
}