listDevicePools method
Gets information about device pools.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter arn :
The project ARN.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which can be used to return the next set of items in the list.
Parameter type :
The device pools' type.
Allowed values include:
- CURATED: A device pool that is created and managed by AWS Device Farm.
- PRIVATE: A device pool that is created and managed by the device pool developer.
Implementation
Future<ListDevicePoolsResult> listDevicePools({
required String arn,
String? nextToken,
DevicePoolType? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.ListDevicePools'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (nextToken != null) 'nextToken': nextToken,
if (type != null) 'type': type.value,
},
);
return ListDevicePoolsResult.fromJson(jsonResponse.body);
}