listNetworkProfiles method
Returns the list of available network profiles.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter arn :
The Amazon Resource Name (ARN) of the project for which you want to list
network profiles.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which can be used to return the next set of items in the list.
Parameter type :
The type of network profile to return information about. Valid values are
listed here.
Implementation
Future<ListNetworkProfilesResult> listNetworkProfiles({
required String arn,
String? nextToken,
NetworkProfileType? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.ListNetworkProfiles'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (nextToken != null) 'nextToken': nextToken,
if (type != null) 'type': type.value,
},
);
return ListNetworkProfilesResult.fromJson(jsonResponse.body);
}