listOfferingTransactions method
Returns a list of all historical purchases, renewals, and system renewal
transactions for an AWS account. The list is paginated and ordered by a
descending timestamp (most recent transactions are first). The API returns
a NotEligible error if the user is not permitted to invoke
the operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotEligibleException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which can be used to return the next set of items in the list.
Implementation
Future<ListOfferingTransactionsResult> listOfferingTransactions({
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.ListOfferingTransactions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListOfferingTransactionsResult.fromJson(jsonResponse.body);
}