listRemoteAccessSessions method
Returns a list of all currently running remote access sessions.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter arn :
The Amazon Resource Name (ARN) of the project about which you are
requesting information.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which can be used to return the next set of items in the list.
Implementation
Future<ListRemoteAccessSessionsResult> listRemoteAccessSessions({
required String arn,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.ListRemoteAccessSessions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListRemoteAccessSessionsResult.fromJson(jsonResponse.body);
}