updateDeviceInstance method
Updates information about a private device instance.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter arn :
The Amazon Resource Name (ARN) of the device instance.
Parameter labels :
An array of strings that you want to associate with the device instance.
Parameter profileArn :
The ARN of the profile that you want to associate with the device
instance.
Implementation
Future<UpdateDeviceInstanceResult> updateDeviceInstance({
required String arn,
List<String>? labels,
String? profileArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.UpdateDeviceInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (labels != null) 'labels': labels,
if (profileArn != null) 'profileArn': profileArn,
},
);
return UpdateDeviceInstanceResult.fromJson(jsonResponse.body);
}