confirmConnection method
Confirms the creation of the specified hosted connection on an interconnect.
Upon creation, the hosted connection is initially in the
Ordering state, and remains in this state until the owner
confirms creation of the hosted connection.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter connectionId :
The ID of the hosted connection.
Implementation
Future<ConfirmConnectionResponse> confirmConnection({
required String connectionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.ConfirmConnection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'connectionId': connectionId,
},
);
return ConfirmConnectionResponse.fromJson(jsonResponse.body);
}