confirmPublicVirtualInterface method
Future<ConfirmPublicVirtualInterfaceResponse>
confirmPublicVirtualInterface({
- required String virtualInterfaceId,
Accepts ownership of a public virtual interface created by another Amazon Web Services account.
After the virtual interface owner makes this call, the specified virtual interface is created and made available to handle traffic.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter virtualInterfaceId :
The ID of the virtual interface.
Implementation
Future<ConfirmPublicVirtualInterfaceResponse> confirmPublicVirtualInterface({
required String virtualInterfaceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.ConfirmPublicVirtualInterface'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'virtualInterfaceId': virtualInterfaceId,
},
);
return ConfirmPublicVirtualInterfaceResponse.fromJson(jsonResponse.body);
}