confirmTransitVirtualInterface method
Accepts ownership of a transit virtual interface created by another Amazon Web Services account.
After the owner of the transit virtual interface makes this call, the specified transit virtual interface is created and made available to handle traffic.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter directConnectGatewayId :
The ID of the Direct Connect gateway.
Parameter virtualInterfaceId :
The ID of the virtual interface.
Implementation
Future<ConfirmTransitVirtualInterfaceResponse>
confirmTransitVirtualInterface({
required String directConnectGatewayId,
required String virtualInterfaceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.ConfirmTransitVirtualInterface'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'directConnectGatewayId': directConnectGatewayId,
'virtualInterfaceId': virtualInterfaceId,
},
);
return ConfirmTransitVirtualInterfaceResponse.fromJson(jsonResponse.body);
}