describeConnectionLoa method
The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that your APN partner or service provider uses when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see Requesting Cross Connects at Direct Connect Locations in the Direct Connect User Guide.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter connectionId :
The ID of the connection.
Parameter loaContentType :
The standard media type for the LOA-CFA document. The only supported value
is application/pdf.
Parameter providerName :
The name of the APN partner or service provider who establishes
connectivity on your behalf. If you specify this parameter, the LOA-CFA
lists the provider name alongside your company name as the requester of
the cross connect.
Implementation
Future<DescribeConnectionLoaResponse> describeConnectionLoa({
required String connectionId,
LoaContentType? loaContentType,
String? providerName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.DescribeConnectionLoa'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'connectionId': connectionId,
if (loaContentType != null) 'loaContentType': loaContentType.value,
if (providerName != null) 'providerName': providerName,
},
);
return DescribeConnectionLoaResponse.fromJson(jsonResponse.body);
}