describeCustomerMetadata method

Future<DescribeCustomerMetadataResponse> describeCustomerMetadata()

Get and view a list of customer agreements, along with their signed status and whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.

May throw DirectConnectClientException. May throw DirectConnectServerException.

Implementation

Future<DescribeCustomerMetadataResponse> describeCustomerMetadata() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'OvertureService.DescribeCustomerMetadata'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return DescribeCustomerMetadataResponse.fromJson(jsonResponse.body);
}