describeInterconnectLoa method

Future<DescribeInterconnectLoaResponse> describeInterconnectLoa({
  1. required String interconnectId,
  2. LoaContentType? loaContentType,
  3. String? providerName,
})
Gets the LOA-CFA for the specified interconnect.

The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that is used when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see Requesting Cross Connects at Direct Connect Locations in the Direct Connect User Guide.

May throw DirectConnectClientException. May throw DirectConnectServerException.

Parameter interconnectId : The ID of the interconnect.

Parameter loaContentType : The standard media type for the LOA-CFA document. The only supported value is application/pdf.

Parameter providerName : The name of the service provider who establishes connectivity on your behalf. If you supply this parameter, the LOA-CFA lists the provider name alongside your company name as the requester of the cross connect.

Implementation

Future<DescribeInterconnectLoaResponse> describeInterconnectLoa({
  required String interconnectId,
  LoaContentType? loaContentType,
  String? providerName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'OvertureService.DescribeInterconnectLoa'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'interconnectId': interconnectId,
      if (loaContentType != null) 'loaContentType': loaContentType.value,
      if (providerName != null) 'providerName': providerName,
    },
  );

  return DescribeInterconnectLoaResponse.fromJson(jsonResponse.body);
}