describeLoa method

Future<Loa> describeLoa({
  1. required String connectionId,
  2. LoaContentType? loaContentType,
  3. String? providerName,
})

Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG).

The Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a document that is used when establishing your cross connect to Amazon Web Services at the colocation facility. For more information, see Requesting Cross Connects at Direct Connect Locations in the Direct Connect User Guide.

May throw DirectConnectClientException. May throw DirectConnectServerException.

Parameter connectionId : The ID of a connection, LAG, or interconnect.

Parameter loaContentType : The standard media type for the LOA-CFA document. The only supported value is application/pdf.

Parameter providerName : The name of the service provider who establishes connectivity on your behalf. If you specify this parameter, the LOA-CFA lists the provider name alongside your company name as the requester of the cross connect.

Implementation

Future<Loa> describeLoa({
  required String connectionId,
  LoaContentType? loaContentType,
  String? providerName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'OvertureService.DescribeLoa'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'connectionId': connectionId,
      if (loaContentType != null) 'loaContentType': loaContentType.value,
      if (providerName != null) 'providerName': providerName,
    },
  );

  return Loa.fromJson(jsonResponse.body);
}