Directory class

Directory Service is a web service that makes it easy for you to setup and run directories in the Amazon Web Services cloud, or connect your Amazon Web Services resources with an existing self-managed Microsoft Active Directory. This guide provides detailed information about Directory Service operations, data types, parameters, and errors. For information about Directory Services features, see Directory Service and the Directory Service Administration Guide.

Constructors

Directory({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptSharedDirectory({required String sharedDirectoryId}) Future<AcceptSharedDirectoryResult>
Accepts a directory sharing request that was sent from the directory owner account.
addIpRoutes({required String directoryId, required List<IpRoute> ipRoutes, bool? updateSecurityGroupForDirectoryControllers}) Future<void>
If the DNS server for your self-managed domain uses a publicly addressable IP address, you must add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services. AddIpRoutes adds this address block. You can also use AddIpRoutes to facilitate routing traffic that uses public IP ranges from your Microsoft AD on Amazon Web Services to a peer VPC.
addRegion({required String directoryId, required String regionName, required DirectoryVpcSettings vPCSettings}) Future<void>
Adds two domain controllers in the specified Region for the specified directory.
addTagsToResource({required String resourceId, required List<Tag> tags}) Future<void>
Adds or overwrites one or more tags for the specified directory. Each directory can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique to each resource.
cancelSchemaExtension({required String directoryId, required String schemaExtensionId}) Future<void>
Cancels an in-progress schema extension to a Microsoft AD directory. Once a schema extension has started replicating to all domain controllers, the task can no longer be canceled. A schema extension can be canceled during any of the following states; Initializing, CreatingSnapshot, and UpdatingSchema.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
connectDirectory({required DirectoryConnectSettings connectSettings, required String name, required String password, required DirectorySize size, String? description, NetworkType? networkType, String? shortName, List<Tag>? tags}) Future<ConnectDirectoryResult>
Creates an AD Connector to connect to a self-managed directory.
createAlias({required String alias, required String directoryId}) Future<CreateAliasResult>
Creates an alias for a directory and assigns the alias to the directory. The alias is used to construct the access URL for the directory, such as http://.
createComputer({required String computerName, required String directoryId, required String password, List<Attribute>? computerAttributes, String? organizationalUnitDistinguishedName}) Future<CreateComputerResult>
Creates an Active Directory computer object in the specified directory.
createConditionalForwarder({required String directoryId, required String remoteDomainName, List<String>? dnsIpAddrs, List<String>? dnsIpv6Addrs}) Future<void>
Creates a conditional forwarder associated with your Amazon Web Services directory. Conditional forwarders are required in order to set up a trust relationship with another domain. The conditional forwarder points to the trusted domain.
createDirectory({required String name, required String password, required DirectorySize size, String? description, NetworkType? networkType, String? shortName, List<Tag>? tags, DirectoryVpcSettings? vpcSettings}) Future<CreateDirectoryResult>
Creates a Simple AD directory. For more information, see Simple Active Directory in the Directory Service Admin Guide.
createHybridAD({required String assessmentId, required String secretArn, List<Tag>? tags}) Future<CreateHybridADResult>
Creates a hybrid directory that connects your self-managed Active Directory (AD) infrastructure and Amazon Web Services.
createLogSubscription({required String directoryId, required String logGroupName}) Future<void>
Creates a subscription to forward real-time Directory Service domain controller security logs to the specified Amazon CloudWatch log group in your Amazon Web Services account.
createMicrosoftAD({required String name, required String password, required DirectoryVpcSettings vpcSettings, String? description, DirectoryEdition? edition, NetworkType? networkType, String? shortName, List<Tag>? tags}) Future<CreateMicrosoftADResult>
Creates a Microsoft AD directory in the Amazon Web Services Cloud. For more information, see Managed Microsoft AD in the Directory Service Admin Guide.
createSnapshot({required String directoryId, String? name}) Future<CreateSnapshotResult>
Creates a snapshot of a Simple AD or Microsoft AD directory in the Amazon Web Services cloud.
createTrust({required String directoryId, required String remoteDomainName, required TrustDirection trustDirection, required String trustPassword, List<String>? conditionalForwarderIpAddrs, List<String>? conditionalForwarderIpv6Addrs, SelectiveAuth? selectiveAuth, TrustType? trustType}) Future<CreateTrustResult>
Directory Service for Microsoft Active Directory allows you to configure trust relationships. For example, you can establish a trust between your Managed Microsoft AD directory, and your existing self-managed Microsoft Active Directory. This would allow you to provide users and groups access to resources in either domain, with a single set of credentials.
deleteADAssessment({required String assessmentId}) Future<DeleteADAssessmentResult>
Deletes a directory assessment and all associated data. This operation permanently removes the assessment results, validation reports, and configuration information.
deleteConditionalForwarder({required String directoryId, required String remoteDomainName}) Future<void>
Deletes a conditional forwarder that has been set up for your Amazon Web Services directory.
deleteDirectory({required String directoryId}) Future<DeleteDirectoryResult>
Deletes an Directory Service directory.
deleteLogSubscription({required String directoryId}) Future<void>
Deletes the specified log subscription.
deleteSnapshot({required String snapshotId}) Future<DeleteSnapshotResult>
Deletes a directory snapshot.
deleteTrust({required String trustId, bool? deleteAssociatedConditionalForwarder}) Future<DeleteTrustResult>
Deletes an existing trust relationship between your Managed Microsoft AD directory and an external domain.
deregisterCertificate({required String certificateId, required String directoryId}) Future<void>
Deletes from the system the certificate that was registered for secure LDAP or client certificate authentication.
deregisterEventTopic({required String directoryId, required String topicName}) Future<void>
Removes the specified directory as a publisher to the specified Amazon SNS topic.
describeADAssessment({required String assessmentId}) Future<DescribeADAssessmentResult>
Retrieves detailed information about a directory assessment, including its current status, validation results, and configuration details. Use this operation to monitor assessment progress and review results.
describeCAEnrollmentPolicy({required String directoryId}) Future<DescribeCAEnrollmentPolicyResult>
Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory. This policy determines how client certificates are automatically enrolled and managed through Amazon Web Services Private Certificate Authority.
describeCertificate({required String certificateId, required String directoryId}) Future<DescribeCertificateResult>
Displays information about the certificate registered for secure LDAP or client certificate authentication.
describeClientAuthenticationSettings({required String directoryId, int? limit, String? nextToken, ClientAuthenticationType? type}) Future<DescribeClientAuthenticationSettingsResult>
Retrieves information about the type of client authentication for the specified directory, if the type is specified. If no type is specified, information about all client authentication types that are supported for the specified directory is retrieved. Currently, only SmartCard is supported.
describeConditionalForwarders({required String directoryId, List<String>? remoteDomainNames}) Future<DescribeConditionalForwardersResult>
Obtains information about the conditional forwarders for this account.
describeDirectories({List<String>? directoryIds, int? limit, String? nextToken}) Future<DescribeDirectoriesResult>
Obtains information about the directories that belong to this account.
describeDirectoryDataAccess({required String directoryId}) Future<DescribeDirectoryDataAccessResult>
Obtains status of directory data access enablement through the Directory Service Data API for the specified directory.
describeDomainControllers({required String directoryId, List<String>? domainControllerIds, int? limit, String? nextToken}) Future<DescribeDomainControllersResult>
Provides information about any domain controllers in your directory.
describeEventTopics({String? directoryId, List<String>? topicNames}) Future<DescribeEventTopicsResult>
Obtains information about which Amazon SNS topics receive status messages from the specified directory.
describeHybridADUpdate({required String directoryId, String? nextToken, HybridUpdateType? updateType}) Future<DescribeHybridADUpdateResult>
Retrieves information about update activities for a hybrid directory. This operation provides details about configuration changes, administrator account updates, and self-managed instance settings (IDs and DNS IPs).
describeLDAPSSettings({required String directoryId, int? limit, String? nextToken, LDAPSType? type}) Future<DescribeLDAPSSettingsResult>
Describes the status of LDAP security for the specified directory.
describeRegions({required String directoryId, String? nextToken, String? regionName}) Future<DescribeRegionsResult>
Provides information about the Regions that are configured for multi-Region replication.
describeSettings({required String directoryId, String? nextToken, DirectoryConfigurationStatus? status}) Future<DescribeSettingsResult>
Retrieves information about the configurable settings for the specified directory.
describeSharedDirectories({required String ownerDirectoryId, int? limit, String? nextToken, List<String>? sharedDirectoryIds}) Future<DescribeSharedDirectoriesResult>
Returns the shared directories in your account.
describeSnapshots({String? directoryId, int? limit, String? nextToken, List<String>? snapshotIds}) Future<DescribeSnapshotsResult>
Obtains information about the directory snapshots that belong to this account.
describeTrusts({String? directoryId, int? limit, String? nextToken, List<String>? trustIds}) Future<DescribeTrustsResult>
Obtains information about the trust relationships for this account.
describeUpdateDirectory({required String directoryId, required UpdateType updateType, String? nextToken, String? regionName}) Future<DescribeUpdateDirectoryResult>
Describes the updates of a directory for a particular update type.
disableCAEnrollmentPolicy({required String directoryId}) Future<void>
Disables the certificate authority (CA) enrollment policy for the specified directory. This stops automatic certificate enrollment and management for domain-joined clients, but does not affect existing certificates.
disableClientAuthentication({required String directoryId, required ClientAuthenticationType type}) Future<void>
Disables alternative client authentication methods for the specified directory.
disableDirectoryDataAccess({required String directoryId}) Future<void>
Deactivates access to directory data via the Directory Service Data API for the specified directory. For more information, see Directory Service Data API Reference.
disableLDAPS({required String directoryId, required LDAPSType type}) Future<void>
Deactivates LDAP secure calls for the specified directory.
disableRadius({required String directoryId}) Future<void>
Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
disableSso({required String directoryId, String? password, String? userName}) Future<void>
Disables single-sign on for a directory.
enableCAEnrollmentPolicy({required String directoryId, required String pcaConnectorArn}) Future<void>
Enables certificate authority (CA) enrollment policy for the specified directory. This allows domain-joined clients to automatically request and receive certificates from the specified Amazon Web Services Private Certificate Authority.
enableClientAuthentication({required String directoryId, required ClientAuthenticationType type}) Future<void>
Enables alternative client authentication methods for the specified directory.
enableDirectoryDataAccess({required String directoryId}) Future<void>
Enables access to directory data via the Directory Service Data API for the specified directory. For more information, see Directory Service Data API Reference.
enableLDAPS({required String directoryId, required LDAPSType type}) Future<void>
Activates the switch for the specific directory to always use LDAP secure calls.
enableRadius({required String directoryId, required RadiusSettings radiusSettings}) Future<void>
Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
enableSso({required String directoryId, String? password, String? userName}) Future<void>
Enables single sign-on for a directory. Single sign-on allows users in your directory to access certain Amazon Web Services services from a computer joined to the directory without having to enter their credentials separately.
getDirectoryLimits() Future<GetDirectoryLimitsResult>
Obtains directory limit information for the current Region.
getSnapshotLimits({required String directoryId}) Future<GetSnapshotLimitsResult>
Obtains the manual snapshot limits for a directory.
listADAssessments({String? directoryId, int? limit, String? nextToken}) Future<ListADAssessmentsResult>
Retrieves a list of directory assessments for the specified directory or all assessments in your account. Use this operation to monitor assessment status and manage multiple assessments.
listCertificates({required String directoryId, int? limit, String? nextToken}) Future<ListCertificatesResult>
For the specified directory, lists all the certificates registered for a secure LDAP or client certificate authentication.
listIpRoutes({required String directoryId, int? limit, String? nextToken}) Future<ListIpRoutesResult>
Lists the address blocks that you have added to a directory.
listLogSubscriptions({String? directoryId, int? limit, String? nextToken}) Future<ListLogSubscriptionsResult>
Lists the active log subscriptions for the Amazon Web Services account.
listSchemaExtensions({required String directoryId, int? limit, String? nextToken}) Future<ListSchemaExtensionsResult>
Lists all schema extensions applied to a Microsoft AD Directory.
listTagsForResource({required String resourceId, int? limit, String? nextToken}) Future<ListTagsForResourceResult>
Lists all tags on a directory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCertificate({required String certificateData, required String directoryId, ClientCertAuthSettings? clientCertAuthSettings, CertificateType? type}) Future<RegisterCertificateResult>
Registers a certificate for a secure LDAP or client certificate authentication.
registerEventTopic({required String directoryId, required String topicName}) Future<void>
Associates a directory with an Amazon SNS topic. This establishes the directory as a publisher to the specified Amazon SNS topic. You can then receive email or text (SMS) messages when the status of your directory changes. You get notified if your directory goes from an Active status to an Impaired or Inoperable status. You also receive a notification when the directory returns to an Active status.
rejectSharedDirectory({required String sharedDirectoryId}) Future<RejectSharedDirectoryResult>
Rejects a directory sharing request that was sent from the directory owner account.
removeIpRoutes({required String directoryId, List<String>? cidrIps, List<String>? cidrIpv6s}) Future<void>
Removes IP address blocks from a directory.
removeRegion({required String directoryId}) Future<void>
Stops all replication and removes the domain controllers from the specified Region. You cannot remove the primary Region with this operation. Instead, use the DeleteDirectory API.
removeTagsFromResource({required String resourceId, required List<String> tagKeys}) Future<void>
Removes tags from a directory.
resetUserPassword({required String directoryId, required String newPassword, required String userName}) Future<void>
Resets the password for any user in your Managed Microsoft AD or Simple AD directory. Disabled users will become enabled and can be authenticated following the API call.
restoreFromSnapshot({required String snapshotId}) Future<void>
Restores a directory using an existing directory snapshot.
shareDirectory({required String directoryId, required ShareMethod shareMethod, required ShareTarget shareTarget, String? shareNotes}) Future<ShareDirectoryResult>
Shares a specified directory (DirectoryId) in your Amazon Web Services account (directory owner) with another Amazon Web Services account (directory consumer). With this operation you can use your directory from any Amazon Web Services account and from any Amazon VPC within an Amazon Web Services Region.
startADAssessment({AssessmentConfiguration? assessmentConfiguration, String? directoryId}) Future<StartADAssessmentResult>
Initiates a directory assessment to validate your self-managed AD environment for hybrid domain join. The assessment checks compatibility and connectivity of the self-managed AD environment.
startSchemaExtension({required bool createSnapshotBeforeSchemaExtension, required String description, required String directoryId, required String ldifContent}) Future<StartSchemaExtensionResult>
Applies a schema extension to a Microsoft AD directory.
toString() String
A string representation of this object.
inherited
unshareDirectory({required String directoryId, required UnshareTarget unshareTarget}) Future<UnshareDirectoryResult>
Stops the directory sharing between the directory owner and consumer accounts.
updateConditionalForwarder({required String directoryId, required String remoteDomainName, List<String>? dnsIpAddrs, List<String>? dnsIpv6Addrs}) Future<void>
Updates a conditional forwarder that has been set up for your Amazon Web Services directory.
updateDirectorySetup({required String directoryId, required UpdateType updateType, bool? createSnapshotBeforeUpdate, DirectorySizeUpdateSettings? directorySizeUpdateSettings, NetworkUpdateSettings? networkUpdateSettings, OSUpdateSettings? oSUpdateSettings}) Future<void>
Updates directory configuration for the specified update type.
updateHybridAD({required String directoryId, HybridAdministratorAccountUpdate? hybridAdministratorAccountUpdate, HybridCustomerInstancesSettings? selfManagedInstancesSettings}) Future<UpdateHybridADResult>
Updates the configuration of an existing hybrid directory. You can recover hybrid directory administrator account or modify self-managed instance settings.
updateNumberOfDomainControllers({required int desiredNumber, required String directoryId}) Future<void>
Adds or removes domain controllers to or from the directory. Based on the difference between current value and new value (provided through this API call), domain controllers will be added or removed. It may take up to 45 minutes for any new domain controllers to become fully active once the requested number of domain controllers is updated. During this time, you cannot make another update request.
updateRadius({required String directoryId, required RadiusSettings radiusSettings}) Future<void>
Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector or Microsoft AD directory.
updateSettings({required String directoryId, required List<Setting> settings}) Future<UpdateSettingsResult>
Updates the configurable settings for the specified directory.
updateTrust({required String trustId, SelectiveAuth? selectiveAuth}) Future<UpdateTrustResult>
Updates the trust that has been set up between your Managed Microsoft AD directory and an self-managed Active Directory.
verifyTrust({required String trustId}) Future<VerifyTrustResult>
Directory Service for Microsoft Active Directory allows you to configure and verify trust relationships.

Operators

operator ==(Object other) bool
The equality operator.
inherited