deleteConditionalForwarder method

Future<void> deleteConditionalForwarder({
  1. required String directoryId,
  2. required String remoteDomainName,
})

Deletes a conditional forwarder that has been set up for your Amazon Web Services directory.

May throw ClientException. May throw DirectoryUnavailableException. May throw EntityDoesNotExistException. May throw InvalidParameterException. May throw ServiceException. May throw UnsupportedOperationException.

Parameter directoryId : The directory ID for which you are deleting the conditional forwarder.

Parameter remoteDomainName : The fully qualified domain name (FQDN) of the remote domain with which you are deleting the conditional forwarder.

Implementation

Future<void> deleteConditionalForwarder({
  required String directoryId,
  required String remoteDomainName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DirectoryService_20150416.DeleteConditionalForwarder'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DirectoryId': directoryId,
      'RemoteDomainName': remoteDomainName,
    },
  );
}