describeADAssessment method

Future<DescribeADAssessmentResult> describeADAssessment({
  1. required String assessmentId,
})

Retrieves detailed information about a directory assessment, including its current status, validation results, and configuration details. Use this operation to monitor assessment progress and review results.

May throw ClientException. May throw EntityDoesNotExistException. May throw InvalidParameterException. May throw ServiceException. May throw UnsupportedOperationException.

Parameter assessmentId : The identifier of the directory assessment to describe.

Implementation

Future<DescribeADAssessmentResult> describeADAssessment({
  required String assessmentId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DirectoryService_20150416.DescribeADAssessment'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AssessmentId': assessmentId,
    },
  );

  return DescribeADAssessmentResult.fromJson(jsonResponse.body);
}