describeHybridADUpdate method

Future<DescribeHybridADUpdateResult> describeHybridADUpdate({
  1. required String directoryId,
  2. String? nextToken,
  3. HybridUpdateType? updateType,
})

Retrieves information about update activities for a hybrid directory. This operation provides details about configuration changes, administrator account updates, and self-managed instance settings (IDs and DNS IPs).

May throw ClientException. May throw DirectoryDoesNotExistException. May throw InvalidNextTokenException. May throw InvalidParameterException. May throw ServiceException. May throw UnsupportedOperationException.

Parameter directoryId : The identifier of the hybrid directory for which to retrieve update information.

Parameter nextToken : The pagination token from a previous request to DescribeHybridADUpdate. Pass null if this is the first request.

Parameter updateType : The type of update activities to retrieve. Valid values include SelfManagedInstances and HybridAdministratorAccount.

Implementation

Future<DescribeHybridADUpdateResult> describeHybridADUpdate({
  required String directoryId,
  String? nextToken,
  HybridUpdateType? updateType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DirectoryService_20150416.DescribeHybridADUpdate'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DirectoryId': directoryId,
      if (nextToken != null) 'NextToken': nextToken,
      if (updateType != null) 'UpdateType': updateType.value,
    },
  );

  return DescribeHybridADUpdateResult.fromJson(jsonResponse.body);
}