describeSettings method
Retrieves information about the configurable settings for the specified directory.
May throw ClientException.
May throw DirectoryDoesNotExistException.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw ServiceException.
May throw UnsupportedOperationException.
Parameter directoryId :
The identifier of the directory for which to retrieve information.
Parameter nextToken :
The DescribeSettingsResult.NextToken value from a previous
call to DescribeSettings. Pass null if this is the first call.
Parameter status :
The status of the directory settings for which to retrieve information.
Implementation
Future<DescribeSettingsResult> describeSettings({
required String directoryId,
String? nextToken,
DirectoryConfigurationStatus? status,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DirectoryService_20150416.DescribeSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DirectoryId': directoryId,
if (nextToken != null) 'NextToken': nextToken,
if (status != null) 'Status': status.value,
},
);
return DescribeSettingsResult.fromJson(jsonResponse.body);
}