describeUpdateDirectory method

Future<DescribeUpdateDirectoryResult> describeUpdateDirectory({
  1. required String directoryId,
  2. required UpdateType updateType,
  3. String? nextToken,
  4. String? regionName,
})

Describes the updates of a directory for a particular update type.

May throw AccessDeniedException. May throw ClientException. May throw DirectoryDoesNotExistException. May throw InvalidNextTokenException. May throw InvalidParameterException. May throw ServiceException.

Parameter directoryId : The unique identifier of the directory.

Parameter updateType : The type of updates you want to describe for the directory.

Parameter nextToken : The DescribeUpdateDirectoryResult. NextToken value from a previous call to DescribeUpdateDirectory. Pass null if this is the first call.

Parameter regionName : The name of the Region.

Implementation

Future<DescribeUpdateDirectoryResult> describeUpdateDirectory({
  required String directoryId,
  required UpdateType updateType,
  String? nextToken,
  String? regionName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DirectoryService_20150416.DescribeUpdateDirectory'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DirectoryId': directoryId,
      'UpdateType': updateType.value,
      if (nextToken != null) 'NextToken': nextToken,
      if (regionName != null) 'RegionName': regionName,
    },
  );

  return DescribeUpdateDirectoryResult.fromJson(jsonResponse.body);
}