disableCAEnrollmentPolicy method

Future<void> disableCAEnrollmentPolicy({
  1. required String directoryId,
})

Disables the certificate authority (CA) enrollment policy for the specified directory. This stops automatic certificate enrollment and management for domain-joined clients, but does not affect existing certificates.

May throw AccessDeniedException. May throw ClientException. May throw DirectoryDoesNotExistException. May throw DirectoryUnavailableException. May throw DisableAlreadyInProgressException. May throw EntityDoesNotExistException. May throw InvalidParameterException. May throw ServiceException.

Parameter directoryId : The identifier of the directory for which to disable the CA enrollment policy.

Implementation

Future<void> disableCAEnrollmentPolicy({
  required String directoryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'DirectoryService_20150416.DisableCAEnrollmentPolicy'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DirectoryId': directoryId,
    },
  );
}