startADAssessment method
- AssessmentConfiguration? assessmentConfiguration,
- String? directoryId,
Initiates a directory assessment to validate your self-managed AD environment for hybrid domain join. The assessment checks compatibility and connectivity of the self-managed AD environment.
A directory assessment is automatically created when you create a hybrid
directory. There are two types of assessments: CUSTOMER and
SYSTEM. Your Amazon Web Services account has a limit of 100
CUSTOMER directory assessments.
The assessment process typically takes 30 minutes or more to complete. The
assessment process is asynchronous and you can monitor it with
DescribeADAssessment.
The InstanceIds must have a one-to-one correspondence with
CustomerDnsIps, meaning that if the IP address for instance
i-10243410 is 10.24.34.100 and the IP address for instance i-10243420 is
10.24.34.200, then the input arrays must maintain the same order
relationship, either [10.24.34.100, 10.24.34.200] paired with
[i-10243410, i-10243420] or [10.24.34.200, 10.24.34.100] paired with
[i-10243420, i-10243410].
Note: You must provide exactly one DirectoryId or
AssessmentConfiguration.
May throw ADAssessmentLimitExceededException.
May throw ClientException.
May throw DirectoryDoesNotExistException.
May throw InvalidParameterException.
May throw ServiceException.
May throw UnsupportedOperationException.
Parameter assessmentConfiguration :
Configuration parameters for the directory assessment, including DNS
server information, domain name, Amazon VPC subnet, and Amazon Web
Services System Manager managed node details.
Parameter directoryId :
The identifier of the directory for which to perform the assessment. This
should be an existing directory. If the assessment is not for an existing
directory, this parameter should be omitted.
Implementation
Future<StartADAssessmentResult> startADAssessment({
AssessmentConfiguration? assessmentConfiguration,
String? directoryId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DirectoryService_20150416.StartADAssessment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (assessmentConfiguration != null)
'AssessmentConfiguration': assessmentConfiguration,
if (directoryId != null) 'DirectoryId': directoryId,
},
);
return StartADAssessmentResult.fromJson(jsonResponse.body);
}