updateHybridAD method
- required String directoryId,
- HybridAdministratorAccountUpdate? hybridAdministratorAccountUpdate,
- HybridCustomerInstancesSettings? selfManagedInstancesSettings,
Updates the configuration of an existing hybrid directory. You can recover hybrid directory administrator account or modify self-managed instance settings.
Updates are applied asynchronously. Use DescribeHybridADUpdate to monitor the progress of configuration changes.
The InstanceIds must have a one-to-one correspondence with
CustomerDnsIps, meaning that if the IP address for instance
i-10243410 is 10.24.34.100 and the IP address for instance i-10243420 is
10.24.34.200, then the input arrays must maintain the same order
relationship, either [10.24.34.100, 10.24.34.200] paired with
[i-10243410, i-10243420] or [10.24.34.200, 10.24.34.100] paired with
[i-10243420, i-10243410].
May throw ADAssessmentLimitExceededException.
May throw ClientException.
May throw DirectoryDoesNotExistException.
May throw InvalidParameterException.
May throw ServiceException.
May throw UnsupportedOperationException.
Parameter directoryId :
The identifier of the hybrid directory to update.
Parameter hybridAdministratorAccountUpdate :
We create a hybrid directory administrator account when we create a hybrid
directory. Use HybridAdministratorAccountUpdate to recover
the hybrid directory administrator account if you have deleted it.
To recover your hybrid directory administrator account, we need temporary access to a user in your self-managed AD with administrator permissions in the form of a secret from Amazon Web Services Secrets Manager. We use these credentials once during recovery and don't store them.
If your hybrid directory administrator account exists, then you don’t need
to use HybridAdministratorAccountUpdate, even if you have
updated your self-managed AD administrator user.
Parameter selfManagedInstancesSettings :
Updates to the self-managed AD configuration, including DNS server IP
addresses and Amazon Web Services System Manager managed node identifiers.
Implementation
Future<UpdateHybridADResult> updateHybridAD({
required String directoryId,
HybridAdministratorAccountUpdate? hybridAdministratorAccountUpdate,
HybridCustomerInstancesSettings? selfManagedInstancesSettings,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DirectoryService_20150416.UpdateHybridAD'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DirectoryId': directoryId,
if (hybridAdministratorAccountUpdate != null)
'HybridAdministratorAccountUpdate': hybridAdministratorAccountUpdate,
if (selfManagedInstancesSettings != null)
'SelfManagedInstancesSettings': selfManagedInstancesSettings,
},
);
return UpdateHybridADResult.fromJson(jsonResponse.body);
}