DirectoryServiceData class

Amazon Web Services Directory Service Data is an extension of Directory Service. This API reference provides detailed information about Directory Service Data operations and object types.

With Directory Service Data, you can create, read, update, and delete users, groups, and memberships from your Managed Microsoft AD without additional costs and without deploying dedicated management instances. You can also perform built-in object management tasks across directories without direct network connectivity, which simplifies provisioning and access management to achieve fully automated deployments. Directory Service Data supports user and group write operations, such as CreateUser and CreateGroup, within the organizational unit (OU) of your Managed Microsoft AD. Directory Service Data supports read operations, such as ListUsers and ListGroups, on all users, groups, and group memberships within your Managed Microsoft AD and across trusted realms. Directory Service Data supports adding and removing group members in your OU and the Amazon Web Services Delegated Groups OU, so you can grant and deny access to specific roles and permissions. For more information, see Manage users and groups in the Directory Service Administration Guide. Directory Service Data connects to your Managed Microsoft AD domain controllers and performs operations on underlying directory objects. When you create your Managed Microsoft AD, you choose subnets for domain controllers that Directory Service creates on your behalf. If a domain controller is unavailable, Directory Service Data uses an available domain controller. As a result, you might notice eventual consistency while objects replicate from one domain controller to another domain controller. For more information, see What gets created in the Directory Service Administration Guide. Directory limits vary by Managed Microsoft AD edition:

  • Standard edition – Supports 8 transactions per second (TPS) for read operations and 4 TPS for write operations per directory. There's a concurrency limit of 10 concurrent requests.
  • Enterprise edition – Supports 16 transactions per second (TPS) for read operations and 8 TPS for write operations per directory. There's a concurrency limit of 10 concurrent requests.
  • Amazon Web Services Account - Supports a total of 100 TPS for Directory Service Data operations across all directories.
Directory Service Data only supports the Managed Microsoft AD directory type and is only available in the primary Amazon Web Services Region. For more information, see Managed Microsoft AD and Primary vs additional Regions in the Directory Service Administration Guide.

Constructors

DirectoryServiceData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addGroupMember({required String directoryId, required String groupName, required String memberName, String? clientToken, String? memberRealm}) Future<void>
Adds an existing user, group, or computer as a group member.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createGroup({required String directoryId, required String sAMAccountName, String? clientToken, GroupScope? groupScope, GroupType? groupType, Map<String, AttributeValue>? otherAttributes}) Future<CreateGroupResult>
Creates a new group.
createUser({required String directoryId, required String sAMAccountName, String? clientToken, String? emailAddress, String? givenName, Map<String, AttributeValue>? otherAttributes, String? surname}) Future<CreateUserResult>
Creates a new user.
deleteGroup({required String directoryId, required String sAMAccountName, String? clientToken}) Future<void>
Deletes a group.
deleteUser({required String directoryId, required String sAMAccountName, String? clientToken}) Future<void>
Deletes a user.
describeGroup({required String directoryId, required String sAMAccountName, List<String>? otherAttributes, String? realm}) Future<DescribeGroupResult>
Returns information about a specific group.
describeUser({required String directoryId, required String sAMAccountName, List<String>? otherAttributes, String? realm}) Future<DescribeUserResult>
Returns information about a specific user.
disableUser({required String directoryId, required String sAMAccountName, String? clientToken}) Future<void>
Deactivates an active user account. For information about how to enable an inactive user account, see ResetUserPassword in the Directory Service API Reference.
listGroupMembers({required String directoryId, required String sAMAccountName, int? maxResults, String? memberRealm, String? nextToken, String? realm}) Future<ListGroupMembersResult>
Returns member information for the specified group.
listGroups({required String directoryId, int? maxResults, String? nextToken, String? realm}) Future<ListGroupsResult>
Returns group information for the specified directory.
listGroupsForMember({required String directoryId, required String sAMAccountName, int? maxResults, String? memberRealm, String? nextToken, String? realm}) Future<ListGroupsForMemberResult>
Returns group information for the specified member.
listUsers({required String directoryId, int? maxResults, String? nextToken, String? realm}) Future<ListUsersResult>
Returns user information for the specified directory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeGroupMember({required String directoryId, required String groupName, required String memberName, String? clientToken, String? memberRealm}) Future<void>
Removes a member from a group.
searchGroups({required String directoryId, required List<String> searchAttributes, required String searchString, int? maxResults, String? nextToken, String? realm}) Future<SearchGroupsResult>
Searches the specified directory for a group. You can find groups that match the SearchString parameter with the value of their attributes included in the SearchString parameter.
searchUsers({required String directoryId, required List<String> searchAttributes, required String searchString, int? maxResults, String? nextToken, String? realm}) Future<SearchUsersResult>
Searches the specified directory for a user. You can find users that match the SearchString parameter with the value of their attributes included in the SearchString parameter.
toString() String
A string representation of this object.
inherited
updateGroup({required String directoryId, required String sAMAccountName, String? clientToken, GroupScope? groupScope, GroupType? groupType, Map<String, AttributeValue>? otherAttributes, UpdateType? updateType}) Future<void>
Updates group information.
updateUser({required String directoryId, required String sAMAccountName, String? clientToken, String? emailAddress, String? givenName, Map<String, AttributeValue>? otherAttributes, String? surname, UpdateType? updateType}) Future<void>
Updates user information.

Operators

operator ==(Object other) bool
The equality operator.
inherited