describeGroup method

Future<DescribeGroupResult> describeGroup({
  1. required String directoryId,
  2. required String sAMAccountName,
  3. List<String>? otherAttributes,
  4. String? realm,
})

Returns information about a specific group.

May throw AccessDeniedException. May throw DirectoryUnavailableException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter directoryId : The Identifier (ID) of the directory associated with the group.

Parameter sAMAccountName : The name of the group.

Parameter otherAttributes : One or more attributes to be returned for the group. For a list of supported attributes, see Directory Service Data Attributes.

Parameter realm : The domain name that's associated with the group.

This value is case insensitive.

Implementation

Future<DescribeGroupResult> describeGroup({
  required String directoryId,
  required String sAMAccountName,
  List<String>? otherAttributes,
  String? realm,
}) async {
  final $query = <String, List<String>>{
    'DirectoryId': [directoryId],
  };
  final $payload = <String, dynamic>{
    'SAMAccountName': sAMAccountName,
    if (otherAttributes != null) 'OtherAttributes': otherAttributes,
    if (realm != null) 'Realm': realm,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/Groups/DescribeGroup',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeGroupResult.fromJson(response);
}