listGroups method
Returns group information for the specified directory.
This operation supports pagination with the use of the
NextToken request and response parameters. If more results
are available, the ListGroups.NextToken member contains a
token that you pass in the next call to ListGroups. This
retrieves the next set of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
May throw AccessDeniedException.
May throw DirectoryUnavailableException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter directoryId :
The identifier (ID) of the directory that's associated with the group.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter nextToken :
An encoded paging token for paginated calls that can be passed back to
retrieve the next page.
Parameter realm :
The domain name associated with the directory.
This value is case insensitive.
Implementation
Future<ListGroupsResult> listGroups({
required String directoryId,
int? maxResults,
String? nextToken,
String? realm,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
'DirectoryId': [directoryId],
};
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (realm != null) 'Realm': realm,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/Groups/ListGroups',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListGroupsResult.fromJson(response);
}