createLifecyclePolicy method
- required String description,
- required String executionRoleArn,
- required SettablePolicyStateValues state,
- bool? copyTags,
- int? createInterval,
- List<
CrossRegionCopyTarget> ? crossRegionCopyTargets, - DefaultPolicyTypeValues? defaultPolicy,
- Exclusions? exclusions,
- bool? extendDeletion,
- PolicyDetails? policyDetails,
- int? retainInterval,
- Map<
String, String> ? tags,
Creates an Amazon Data Lifecycle Manager lifecycle policy. Amazon Data Lifecycle Manager supports the following policy types:
- Custom EBS snapshot policy
- Custom EBS-backed AMI policy
- Cross-account copy event policy
- Default policy for EBS snapshots
- Default policy for EBS-backed AMIs
May throw InternalServerException.
May throw InvalidRequestException.
May throw LimitExceededException.
Parameter description :
A description of the lifecycle policy. The characters ^[0-9A-Za-z _-]+$
are supported.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the IAM role used to run the operations
specified by the lifecycle policy.
Parameter state :
The activation state of the lifecycle policy after creation.
Parameter copyTags :
[Default policies only] Indicates whether the policy should copy
tags from the source resource to the snapshot or AMI. If you do not
specify a value, the default is false.
Default: false
Parameter createInterval :
[Default policies only] Specifies how often the policy should run
and create snapshots or AMIs. The creation frequency can range from 1 to 7
days. If you do not specify a value, the default is 1.
Default: 1
Parameter crossRegionCopyTargets :
[Default policies only] Specifies destination Regions for
snapshot or AMI copies. You can specify up to 3 destination Regions. If
you do not want to create cross-Region copies, omit this parameter.
Parameter defaultPolicy :
[Default policies only] Specify the type of default policy to
create.
-
To create a default policy for EBS snapshots, that creates snapshots of
all volumes in the Region that do not have recent backups, specify
VOLUME. -
To create a default policy for EBS-backed AMIs, that creates EBS-backed
AMIs from all instances in the Region that do not have recent backups,
specify
INSTANCE.
Parameter exclusions :
[Default policies only] Specifies exclusion parameters for
volumes or instances for which you do not want to create snapshots or
AMIs. The policy will not create snapshots or AMIs for target resources
that match any of the specified exclusion parameters.
Parameter extendDeletion :
[Default policies only] Defines the snapshot or AMI retention
behavior for the policy if the source volume or instance is deleted, or if
the policy enters the error, disabled, or deleted state.
By default (ExtendDeletion=false):
-
If a source resource is deleted, Amazon Data Lifecycle Manager will
continue to delete previously created snapshots or AMIs, up to but not
including the last one, based on the specified retention period. If you
want Amazon Data Lifecycle Manager to delete all snapshots or AMIs,
including the last one, specify
true. -
If a policy enters the error, disabled, or deleted state, Amazon Data
Lifecycle Manager stops deleting snapshots and AMIs. If you want Amazon
Data Lifecycle Manager to continue deleting snapshots or AMIs, including
the last one, if the policy enters one of these states, specify
true.
If you do not specify a value, the default is false.
Default: false
Parameter policyDetails :
The configuration details of the lifecycle policy.
Parameter retainInterval :
[Default policies only] Specifies how long the policy should
retain snapshots or AMIs before deleting them. The retention period can
range from 2 to 14 days, but it must be greater than the creation
frequency to ensure that the policy retains at least 1 snapshot or AMI at
any given time. If you do not specify a value, the default is 7.
Default: 7
Parameter tags :
The tags to apply to the lifecycle policy during creation.
Implementation
Future<CreateLifecyclePolicyResponse> createLifecyclePolicy({
required String description,
required String executionRoleArn,
required SettablePolicyStateValues state,
bool? copyTags,
int? createInterval,
List<CrossRegionCopyTarget>? crossRegionCopyTargets,
DefaultPolicyTypeValues? defaultPolicy,
Exclusions? exclusions,
bool? extendDeletion,
PolicyDetails? policyDetails,
int? retainInterval,
Map<String, String>? tags,
}) async {
_s.validateNumRange(
'createInterval',
createInterval,
1,
1152921504606846976,
);
_s.validateNumRange(
'retainInterval',
retainInterval,
1,
1152921504606846976,
);
final $payload = <String, dynamic>{
'Description': description,
'ExecutionRoleArn': executionRoleArn,
'State': state.value,
if (copyTags != null) 'CopyTags': copyTags,
if (createInterval != null) 'CreateInterval': createInterval,
if (crossRegionCopyTargets != null)
'CrossRegionCopyTargets': crossRegionCopyTargets,
if (defaultPolicy != null) 'DefaultPolicy': defaultPolicy.value,
if (exclusions != null) 'Exclusions': exclusions,
if (extendDeletion != null) 'ExtendDeletion': extendDeletion,
if (policyDetails != null) 'PolicyDetails': policyDetails,
if (retainInterval != null) 'RetainInterval': retainInterval,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/policies',
exceptionFnMap: _exceptionFns,
);
return CreateLifecyclePolicyResponse.fromJson(response);
}