updateLifecyclePolicy method
Updates the specified lifecycle policy.
For more information about updating a policy, see Modify lifecycle policies.
May throw InternalServerException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter policyId :
The identifier of the lifecycle policy.
Parameter copyTags :
[Default policies only] Indicates whether the policy should copy
tags from the source resource to the snapshot or AMI.
Parameter createInterval :
[Default policies only] Specifies how often the policy should run
and create snapshots or AMIs. The creation frequency can range from 1 to 7
days.
Parameter crossRegionCopyTargets :
[Default policies only] Specifies destination Regions for
snapshot or AMI copies. You can specify up to 3 destination Regions. If
you do not want to create cross-Region copies, omit this parameter.
Parameter description :
A description of the lifecycle policy.
Parameter exclusions :
[Default policies only] Specifies exclusion parameters for
volumes or instances for which you do not want to create snapshots or
AMIs. The policy will not create snapshots or AMIs for target resources
that match any of the specified exclusion parameters.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the IAM role used to run the operations
specified by the lifecycle policy.
Parameter extendDeletion :
[Default policies only] Defines the snapshot or AMI retention
behavior for the policy if the source volume or instance is deleted, or if
the policy enters the error, disabled, or deleted state.
By default (ExtendDeletion=false):
-
If a source resource is deleted, Amazon Data Lifecycle Manager will
continue to delete previously created snapshots or AMIs, up to but not
including the last one, based on the specified retention period. If you
want Amazon Data Lifecycle Manager to delete all snapshots or AMIs,
including the last one, specify
true. -
If a policy enters the error, disabled, or deleted state, Amazon Data
Lifecycle Manager stops deleting snapshots and AMIs. If you want Amazon
Data Lifecycle Manager to continue deleting snapshots or AMIs, including
the last one, if the policy enters one of these states, specify
true.
Default: false
Parameter policyDetails :
The configuration of the lifecycle policy. You cannot update the policy
type or the resource type.
Parameter retainInterval :
[Default policies only] Specifies how long the policy should
retain snapshots or AMIs before deleting them. The retention period can
range from 2 to 14 days, but it must be greater than the creation
frequency to ensure that the policy retains at least 1 snapshot or AMI at
any given time.
Parameter state :
The desired activation state of the lifecycle policy after creation.
Implementation
Future<void> updateLifecyclePolicy({
required String policyId,
bool? copyTags,
int? createInterval,
List<CrossRegionCopyTarget>? crossRegionCopyTargets,
String? description,
Exclusions? exclusions,
String? executionRoleArn,
bool? extendDeletion,
PolicyDetails? policyDetails,
int? retainInterval,
SettablePolicyStateValues? state,
}) async {
_s.validateNumRange(
'createInterval',
createInterval,
1,
1152921504606846976,
);
_s.validateNumRange(
'retainInterval',
retainInterval,
1,
1152921504606846976,
);
final $payload = <String, dynamic>{
if (copyTags != null) 'CopyTags': copyTags,
if (createInterval != null) 'CreateInterval': createInterval,
if (crossRegionCopyTargets != null)
'CrossRegionCopyTargets': crossRegionCopyTargets,
if (description != null) 'Description': description,
if (exclusions != null) 'Exclusions': exclusions,
if (executionRoleArn != null) 'ExecutionRoleArn': executionRoleArn,
if (extendDeletion != null) 'ExtendDeletion': extendDeletion,
if (policyDetails != null) 'PolicyDetails': policyDetails,
if (retainInterval != null) 'RetainInterval': retainInterval,
if (state != null) 'State': state.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/policies/${Uri.encodeComponent(policyId)}',
exceptionFnMap: _exceptionFns,
);
}