createEventSubscription method

Future<CreateEventSubscriptionResult> createEventSubscription({
  1. required String snsTopicArn,
  2. required String subscriptionName,
  3. bool? enabled,
  4. List<String>? eventCategories,
  5. List<String>? sourceIds,
  6. String? sourceType,
  7. List<Tag>? tags,
})

Creates an Amazon DocumentDB event notification subscription. This action requires a topic Amazon Resource Name (ARN) created by using the Amazon DocumentDB console, the Amazon SNS console, or the Amazon SNS API. To obtain an ARN with Amazon SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the Amazon SNS console.

You can specify the type of source (SourceType) that you want to be notified of. You can also provide a list of Amazon DocumentDB sources (SourceIds) that trigger the events, and you can provide a list of event categories (EventCategories) for events that you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup.

If you specify both the SourceType and SourceIds (such as SourceType = db-instance and SourceIdentifier = myDBInstance1), you are notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you receive notice of the events for that source type for all your Amazon DocumentDB sources. If you do not specify either the SourceType or the SourceIdentifier, you are notified of events generated from all Amazon DocumentDB sources belonging to your customer account.

May throw EventSubscriptionQuotaExceededFault. May throw SNSInvalidTopicFault. May throw SNSNoAuthorizationFault. May throw SNSTopicArnNotFoundFault. May throw SourceNotFoundFault. May throw SubscriptionAlreadyExistFault. May throw SubscriptionCategoryNotFoundFault.

Parameter snsTopicArn : The Amazon Resource Name (ARN) of the SNS topic created for event notification. Amazon SNS creates the ARN when you create a topic and subscribe to it.

Parameter subscriptionName : The name of the subscription.

Constraints: The name must be fewer than 255 characters.

Parameter enabled : A Boolean value; set to true to activate the subscription, set to false to create the subscription but not active it.

Parameter eventCategories : A list of event categories for a SourceType that you want to subscribe to.

Parameter sourceIds : The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens.

Constraints:

  • If SourceIds are provided, SourceType must also be provided.
  • If the source type is an instance, a DBInstanceIdentifier must be provided.
  • If the source type is a security group, a DBSecurityGroupName must be provided.
  • If the source type is a parameter group, a DBParameterGroupName must be provided.
  • If the source type is a snapshot, a DBSnapshotIdentifier must be provided.

Parameter sourceType : The type of source that is generating the events. For example, if you want to be notified of events generated by an instance, you would set this parameter to db-instance. If this value is not specified, all events are returned.

Valid values: db-instance, db-cluster, db-parameter-group, db-security-group, db-cluster-snapshot

Parameter tags : The tags to be assigned to the event subscription.

Implementation

Future<CreateEventSubscriptionResult> createEventSubscription({
  required String snsTopicArn,
  required String subscriptionName,
  bool? enabled,
  List<String>? eventCategories,
  List<String>? sourceIds,
  String? sourceType,
  List<Tag>? tags,
}) async {
  final $request = <String, String>{
    'SnsTopicArn': snsTopicArn,
    'SubscriptionName': subscriptionName,
    if (enabled != null) 'Enabled': enabled.toString(),
    if (eventCategories != null)
      if (eventCategories.isEmpty)
        'EventCategories': ''
      else
        for (var i1 = 0; i1 < eventCategories.length; i1++)
          'EventCategories.EventCategory.${i1 + 1}': eventCategories[i1],
    if (sourceIds != null)
      if (sourceIds.isEmpty)
        'SourceIds': ''
      else
        for (var i1 = 0; i1 < sourceIds.length; i1++)
          'SourceIds.SourceId.${i1 + 1}': sourceIds[i1],
    if (sourceType != null) 'SourceType': sourceType,
    if (tags != null)
      if (tags.isEmpty)
        'Tags': ''
      else
        for (var i1 = 0; i1 < tags.length; i1++)
          for (var e3 in tags[i1].toQueryMap().entries)
            'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateEventSubscription',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateEventSubscriptionResult',
  );
  return CreateEventSubscriptionResult.fromXml($result);
}