deleteDBClusterSnapshot method

Future<DeleteDBClusterSnapshotResult> deleteDBClusterSnapshot({
  1. required String dBClusterSnapshotIdentifier,
})

Deletes a cluster snapshot. If the snapshot is being copied, the copy operation is terminated.

May throw DBClusterSnapshotNotFoundFault. May throw InvalidDBClusterSnapshotStateFault.

Parameter dBClusterSnapshotIdentifier : The identifier of the cluster snapshot to delete.

Constraints: Must be the name of an existing cluster snapshot in the available state.

Implementation

Future<DeleteDBClusterSnapshotResult> deleteDBClusterSnapshot({
  required String dBClusterSnapshotIdentifier,
}) async {
  final $request = <String, String>{
    'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteDBClusterSnapshot',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteDBClusterSnapshotResult',
  );
  return DeleteDBClusterSnapshotResult.fromXml($result);
}