describeDBClusterSnapshotAttributes method
Future<DescribeDBClusterSnapshotAttributesResult>
describeDBClusterSnapshotAttributes({
- required String dBClusterSnapshotIdentifier,
Returns a list of cluster snapshot attribute names and values for a manual DB cluster snapshot.
When you share snapshots with other Amazon Web Services accounts,
DescribeDBClusterSnapshotAttributes returns the
restore attribute and a list of IDs for the Amazon Web
Services accounts that are authorized to copy or restore the manual
cluster snapshot. If all is included in the list of values
for the restore attribute, then the manual cluster snapshot
is public and can be copied or restored by all Amazon Web Services
accounts.
May throw DBClusterSnapshotNotFoundFault.
Parameter dBClusterSnapshotIdentifier :
The identifier for the cluster snapshot to describe the attributes for.
Implementation
Future<DescribeDBClusterSnapshotAttributesResult>
describeDBClusterSnapshotAttributes({
required String dBClusterSnapshotIdentifier,
}) async {
final $request = <String, String>{
'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterSnapshotAttributes',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterSnapshotAttributesResult',
);
return DescribeDBClusterSnapshotAttributesResult.fromXml($result);
}