describeDBClusterSnapshots method
Returns information about cluster snapshots. This API operation supports pagination.
May throw DBClusterSnapshotNotFoundFault.
Parameter dBClusterIdentifier :
The ID of the cluster to retrieve the list of cluster snapshots for. This
parameter can't be used with the DBClusterSnapshotIdentifier
parameter. This parameter is not case sensitive.
Constraints:
-
If provided, must match the identifier of an existing
DBCluster.
Parameter dBClusterSnapshotIdentifier :
A specific cluster snapshot identifier to describe. This parameter can't
be used with the DBClusterIdentifier parameter. This value is
stored as a lowercase string.
Constraints:
-
If provided, must match the identifier of an existing
DBClusterSnapshot. -
If this identifier is for an automated snapshot, the
SnapshotTypeparameter must also be specified.
Parameter filters :
This parameter is not currently supported.
Parameter includePublic :
Set to true to include manual cluster snapshots that are
public and can be copied or restored by any Amazon Web Services account,
and otherwise false. The default is false.
Parameter includeShared :
Set to true to include shared manual cluster snapshots from
other Amazon Web Services accounts that this Amazon Web Services account
has been given permission to copy or restore, and otherwise
false. The default is false.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
(marker) is included in the response so that the remaining results can be
retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
Parameter snapshotType :
The type of cluster snapshots to be returned. You can specify one of the
following values:
-
automated- Return all cluster snapshots that Amazon DocumentDB has automatically created for your Amazon Web Services account. -
manual- Return all cluster snapshots that you have manually created for your Amazon Web Services account. -
shared- Return all manual cluster snapshots that have been shared to your Amazon Web Services account. -
public- Return all cluster snapshots that have been marked as public.
SnapshotType value, then both
automated and manual cluster snapshots are returned. You can include
shared cluster snapshots with these results by setting the
IncludeShared parameter to true. You can include
public cluster snapshots with these results by setting
theIncludePublic parameter to true.
The IncludeShared and IncludePublic parameters
don't apply for SnapshotType values of manual or
automated. The IncludePublic parameter doesn't
apply when SnapshotType is set to shared. The
IncludeShared parameter doesn't apply when
SnapshotType is set to public.
Implementation
Future<DBClusterSnapshotMessage> describeDBClusterSnapshots({
String? dBClusterIdentifier,
String? dBClusterSnapshotIdentifier,
List<Filter>? filters,
bool? includePublic,
bool? includeShared,
String? marker,
int? maxRecords,
String? snapshotType,
}) async {
final $request = <String, String>{
if (dBClusterIdentifier != null)
'DBClusterIdentifier': dBClusterIdentifier,
if (dBClusterSnapshotIdentifier != null)
'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (includePublic != null) 'IncludePublic': includePublic.toString(),
if (includeShared != null) 'IncludeShared': includeShared.toString(),
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (snapshotType != null) 'SnapshotType': snapshotType,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterSnapshots',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterSnapshotsResult',
);
return DBClusterSnapshotMessage.fromXml($result);
}