describeGlobalClusters method

Future<GlobalClustersMessage> describeGlobalClusters({
  1. List<Filter>? filters,
  2. String? globalClusterIdentifier,
  3. String? marker,
  4. int? maxRecords,
})

Returns information about Amazon DocumentDB global clusters. This API supports pagination.

May throw GlobalClusterNotFoundFault.

Parameter filters : A filter that specifies one or more global DB clusters to describe.

Supported filters: db-cluster-id accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list will only include information about the clusters identified by these ARNs.

Parameter globalClusterIdentifier : The user-supplied cluster identifier. If this parameter is specified, information from only the specific cluster is returned. This parameter isn't case-sensitive.

Parameter marker : An optional pagination token provided by a previous DescribeGlobalClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Implementation

Future<GlobalClustersMessage> describeGlobalClusters({
  List<Filter>? filters,
  String? globalClusterIdentifier,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (globalClusterIdentifier != null)
      'GlobalClusterIdentifier': globalClusterIdentifier,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeGlobalClusters',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeGlobalClustersResult',
  );
  return GlobalClustersMessage.fromXml($result);
}