describeOrderableDBInstanceOptions method
Returns a list of orderable instance options for the specified engine.
Parameter engine :
The name of the engine to retrieve instance options for.
Parameter dBInstanceClass :
The instance class filter value. Specify this parameter to show only the
available offerings that match the specified instance class.
Parameter engineVersion :
The engine version filter value. Specify this parameter to show only the
available offerings that match the specified engine version.
Parameter filters :
This parameter is not currently supported.
Parameter licenseModel :
The license model filter value. Specify this parameter to show only the
available offerings that match the specified license model.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
(marker) is included in the response so that the remaining results can be
retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
Parameter vpc :
The virtual private cloud (VPC) filter value. Specify this parameter to
show only the available VPC or non-VPC offerings.
Implementation
Future<OrderableDBInstanceOptionsMessage> describeOrderableDBInstanceOptions({
required String engine,
String? dBInstanceClass,
String? engineVersion,
List<Filter>? filters,
String? licenseModel,
String? marker,
int? maxRecords,
bool? vpc,
}) async {
final $request = <String, String>{
'Engine': engine,
if (dBInstanceClass != null) 'DBInstanceClass': dBInstanceClass,
if (engineVersion != null) 'EngineVersion': engineVersion,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (licenseModel != null) 'LicenseModel': licenseModel,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (vpc != null) 'Vpc': vpc.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeOrderableDBInstanceOptions',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeOrderableDBInstanceOptionsResult',
);
return OrderableDBInstanceOptionsMessage.fromXml($result);
}