modifyDBCluster method
- required String dBClusterIdentifier,
- bool? allowMajorVersionUpgrade,
- bool? applyImmediately,
- int? backupRetentionPeriod,
- CloudwatchLogsExportConfiguration? cloudwatchLogsExportConfiguration,
- String? dBClusterParameterGroupName,
- bool? deletionProtection,
- String? engineVersion,
- bool? manageMasterUserPassword,
- String? masterUserPassword,
- String? masterUserSecretKmsKeyId,
- String? networkType,
- String? newDBClusterIdentifier,
- int? port,
- String? preferredBackupWindow,
- String? preferredMaintenanceWindow,
- bool? rotateMasterUserPassword,
- ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
- String? storageType,
- List<
String> ? vpcSecurityGroupIds,
Modifies a setting for an Amazon DocumentDB cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.
May throw DBClusterAlreadyExistsFault.
May throw DBClusterNotFoundFault.
May throw DBClusterParameterGroupNotFoundFault.
May throw DBSubnetGroupNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidDBSecurityGroupStateFault.
May throw InvalidDBSubnetGroupStateFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw NetworkTypeNotSupported.
May throw StorageQuotaExceededFault.
Parameter dBClusterIdentifier :
The cluster identifier for the cluster that is being modified. This
parameter is not case sensitive.
Constraints:
-
Must match the identifier of an existing
DBCluster.
Parameter allowMajorVersionUpgrade :
A value that indicates whether major version upgrades are allowed.
Constraints:
-
You must allow major version upgrades when specifying a value for the
EngineVersionparameter that is a different major version than the cluster's current version. -
Since some parameters are version specific, changing them requires
executing a new
ModifyDBClusterAPI call after the in-place MVU completes.
Parameter applyImmediately :
A value that specifies whether the changes in this request and any pending
changes are asynchronously applied as soon as possible, regardless of the
PreferredMaintenanceWindow setting for the cluster. If this
parameter is set to false, changes to the cluster are applied
during the next maintenance window.
The ApplyImmediately parameter affects only the
NewDBClusterIdentifier and MasterUserPassword
values. If you set this parameter value to false, the changes
to the NewDBClusterIdentifier and
MasterUserPassword values are applied during the next
maintenance window. All other changes are applied immediately, regardless
of the value of the ApplyImmediately parameter.
Default: false
Parameter backupRetentionPeriod :
The number of days for which automated backups are retained. You must
specify a minimum value of 1.
Default: 1
Constraints:
- Must be a value from 1 to 35.
Parameter cloudwatchLogsExportConfiguration :
The configuration setting for the log types to be enabled for export to
Amazon CloudWatch Logs for a specific instance or cluster. The
EnableLogTypes and DisableLogTypes arrays
determine which logs are exported (or not exported) to CloudWatch Logs.
Parameter dBClusterParameterGroupName :
The name of the cluster parameter group to use for the cluster.
Parameter deletionProtection :
Specifies whether this cluster can be deleted. If
DeletionProtection is enabled, the cluster cannot be deleted
unless it is modified and DeletionProtection is disabled.
DeletionProtection protects clusters from being accidentally
deleted.
Parameter engineVersion :
The version number of the database engine to which you want to upgrade.
Changing this parameter results in an outage. The change is applied during
the next maintenance window unless ApplyImmediately is
enabled.
To list all of the available engine versions for Amazon DocumentDB use the following command:
aws docdb describe-db-engine-versions --engine docdb --query
"DBEngineVersions[].EngineVersion"
Parameter manageMasterUserPassword :
Specifies whether to manage the master user password with Amazon Web
Services Secrets Manager. If the cluster doesn't manage the master user
password with Amazon Web Services Secrets Manager, you can turn on this
management. In this case, you can't specify
MasterUserPassword. If the cluster already manages the master
user password with Amazon Web Services Secrets Manager, and you specify
that the master user password is not managed with Amazon Web Services
Secrets Manager, then you must specify MasterUserPassword. In
this case, Amazon DocumentDB deletes the secret and uses the new password
for the master user specified by MasterUserPassword.
Parameter masterUserPassword :
The password for the master database user. This password can contain any
printable ASCII character except forward slash (/), double quote ("), or
the "at" symbol (@).
Constraints: Must contain from 8 to 100 characters.
Parameter masterUserSecretKmsKeyId :
The Amazon Web Services KMS key identifier to encrypt a secret that is
automatically generated and managed in Amazon Web Services Secrets
Manager.
This setting is valid only if both of the following conditions are met:
- The cluster doesn't manage the master user password in Amazon Web Services Secrets Manager. If the cluster already manages the master user password in Amazon Web Services Secrets Manager, you can't change the KMS key that is used to encrypt the secret.
-
You are enabling
ManageMasterUserPasswordto manage the master user password in Amazon Web Services Secrets Manager. If you are turning onManageMasterUserPasswordand don't specifyMasterUserSecretKmsKeyId, then theaws/secretsmanagerKMS key is used to encrypt the secret. If the secret is in a different Amazon Web Services account, then you can't use theaws/secretsmanagerKMS key to encrypt the secret, and you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Parameter networkType :
The network type of the cluster.
The network type is determined by the DBSubnetGroup specified
for the cluster. A DBSubnetGroup can support only the IPv4
protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see DocumentDB clusters in a VPC in the Amazon DocumentDB Developer Guide.
Valid Values: IPV4 | DUAL
Parameter newDBClusterIdentifier :
The new cluster identifier for the cluster when renaming a cluster. This
value is stored as a lowercase string.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- The first character must be a letter.
- Cannot end with a hyphen or contain two consecutive hyphens.
my-cluster2
Parameter port :
The port number on which the cluster accepts connections.
Constraints: Must be a value from 1150 to 65535.
Default: The same port as the original cluster.
Parameter preferredBackupWindow :
The daily time range during which automated backups are created if
automated backups are enabled, using the
BackupRetentionPeriod parameter.
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
Parameter preferredMaintenanceWindow :
The weekly time range during which system maintenance can occur, in
Universal Coordinated Time (UTC).
Format: ddd:hh24:mi-ddd:hh24:mi
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region, occurring on a random day of the week.
Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Minimum 30-minute window.
Parameter rotateMasterUserPassword :
Specifies whether to rotate the secret managed by Amazon Web Services
Secrets Manager for the master user password.
This setting is valid only if the master user password is managed by Amazon DocumentDB in Amazon Web Services Secrets Manager for the cluster. The secret value contains the updated password.
Constraint: You must apply the change immediately when rotating the master user password.
Parameter serverlessV2ScalingConfiguration :
Contains the scaling configuration of an Amazon DocumentDB Serverless
cluster.
Parameter storageType :
The storage type to associate with the DB cluster.
For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.
Valid values for storage type - standard | iopt1
Default value is standard
Parameter vpcSecurityGroupIds :
A list of virtual private cloud (VPC) security groups that the cluster
will belong to.
Implementation
Future<ModifyDBClusterResult> modifyDBCluster({
required String dBClusterIdentifier,
bool? allowMajorVersionUpgrade,
bool? applyImmediately,
int? backupRetentionPeriod,
CloudwatchLogsExportConfiguration? cloudwatchLogsExportConfiguration,
String? dBClusterParameterGroupName,
bool? deletionProtection,
String? engineVersion,
bool? manageMasterUserPassword,
String? masterUserPassword,
String? masterUserSecretKmsKeyId,
String? networkType,
String? newDBClusterIdentifier,
int? port,
String? preferredBackupWindow,
String? preferredMaintenanceWindow,
bool? rotateMasterUserPassword,
ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
String? storageType,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
if (allowMajorVersionUpgrade != null)
'AllowMajorVersionUpgrade': allowMajorVersionUpgrade.toString(),
if (applyImmediately != null)
'ApplyImmediately': applyImmediately.toString(),
if (backupRetentionPeriod != null)
'BackupRetentionPeriod': backupRetentionPeriod.toString(),
if (cloudwatchLogsExportConfiguration != null)
for (var e1 in cloudwatchLogsExportConfiguration.toQueryMap().entries)
'CloudwatchLogsExportConfiguration.${e1.key}': e1.value,
if (dBClusterParameterGroupName != null)
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (engineVersion != null) 'EngineVersion': engineVersion,
if (manageMasterUserPassword != null)
'ManageMasterUserPassword': manageMasterUserPassword.toString(),
if (masterUserPassword != null) 'MasterUserPassword': masterUserPassword,
if (masterUserSecretKmsKeyId != null)
'MasterUserSecretKmsKeyId': masterUserSecretKmsKeyId,
if (networkType != null) 'NetworkType': networkType,
if (newDBClusterIdentifier != null)
'NewDBClusterIdentifier': newDBClusterIdentifier,
if (port != null) 'Port': port.toString(),
if (preferredBackupWindow != null)
'PreferredBackupWindow': preferredBackupWindow,
if (preferredMaintenanceWindow != null)
'PreferredMaintenanceWindow': preferredMaintenanceWindow,
if (rotateMasterUserPassword != null)
'RotateMasterUserPassword': rotateMasterUserPassword.toString(),
if (serverlessV2ScalingConfiguration != null)
for (var e1 in serverlessV2ScalingConfiguration.toQueryMap().entries)
'ServerlessV2ScalingConfiguration.${e1.key}': e1.value,
if (storageType != null) 'StorageType': storageType,
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'ModifyDBCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyDBClusterResult',
);
return ModifyDBClusterResult.fromXml($result);
}