modifyGlobalCluster method

Future<ModifyGlobalClusterResult> modifyGlobalCluster({
  1. required String globalClusterIdentifier,
  2. bool? deletionProtection,
  3. String? newGlobalClusterIdentifier,
})

Modify a setting for an Amazon DocumentDB global cluster. You can change one or more configuration parameters (for example: deletion protection), or the global cluster identifier by specifying these parameters and the new values in the request.

May throw GlobalClusterNotFoundFault. May throw InvalidGlobalClusterStateFault.

Parameter globalClusterIdentifier : The identifier for the global cluster being modified. This parameter isn't case-sensitive.

Constraints:

  • Must match the identifier of an existing global cluster.

Parameter deletionProtection : Indicates if the global cluster has deletion protection enabled. The global cluster can't be deleted when deletion protection is enabled.

Parameter newGlobalClusterIdentifier : The new identifier for a global cluster when you modify a global cluster. This value is stored as a lowercase string.

  • Must contain from 1 to 63 letters, numbers, or hyphens

    The first character must be a letter

    Can't end with a hyphen or contain two consecutive hyphens

Example: my-cluster2

Implementation

Future<ModifyGlobalClusterResult> modifyGlobalCluster({
  required String globalClusterIdentifier,
  bool? deletionProtection,
  String? newGlobalClusterIdentifier,
}) async {
  final $request = <String, String>{
    'GlobalClusterIdentifier': globalClusterIdentifier,
    if (deletionProtection != null)
      'DeletionProtection': deletionProtection.toString(),
    if (newGlobalClusterIdentifier != null)
      'NewGlobalClusterIdentifier': newGlobalClusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ModifyGlobalCluster',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ModifyGlobalClusterResult',
  );
  return ModifyGlobalClusterResult.fromXml($result);
}