restoreDBClusterFromSnapshot method
- required String dBClusterIdentifier,
- required String engine,
- required String snapshotIdentifier,
- List<
String> ? availabilityZones, - String? dBClusterParameterGroupName,
- String? dBSubnetGroupName,
- bool? deletionProtection,
- List<
String> ? enableCloudwatchLogsExports, - String? engineVersion,
- String? kmsKeyId,
- String? networkType,
- int? port,
- ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
- String? storageType,
- List<
Tag> ? tags, - List<
String> ? vpcSecurityGroupIds,
Creates a new cluster from a snapshot or cluster snapshot.
If a snapshot is specified, the target cluster is created from the source DB snapshot with a default configuration and default security group.
If a cluster snapshot is specified, the target cluster is created from the source cluster restore point with the same configuration as the original source DB cluster, except that the new cluster is created with the default security group.
May throw DBClusterAlreadyExistsFault.
May throw DBClusterQuotaExceededFault.
May throw DBClusterSnapshotNotFoundFault.
May throw DBSnapshotNotFoundFault.
May throw DBSubnetGroupNotFoundFault.
May throw InsufficientDBClusterCapacityFault.
May throw InsufficientStorageClusterCapacityFault.
May throw InvalidDBClusterSnapshotStateFault.
May throw InvalidDBSnapshotStateFault.
May throw InvalidRestoreFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw NetworkTypeNotSupported.
May throw StorageQuotaExceededFault.
Parameter dBClusterIdentifier :
The name of the cluster to create from the snapshot or cluster snapshot.
This parameter isn't case sensitive.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- The first character must be a letter.
- Cannot end with a hyphen or contain two consecutive hyphens.
my-snapshot-id
Parameter engine :
The database engine to use for the new cluster.
Default: The same as source.
Constraint: Must be compatible with the engine of the source.
Parameter snapshotIdentifier :
The identifier for the snapshot or cluster snapshot to restore from.
You can use either the name or the Amazon Resource Name (ARN) to specify a cluster snapshot. However, you can use only the ARN to specify a snapshot.
Constraints:
- Must match the identifier of an existing snapshot.
Parameter availabilityZones :
Provides the list of Amazon EC2 Availability Zones that instances in the
restored DB cluster can be created in.
Parameter dBClusterParameterGroupName :
The name of the DB cluster parameter group to associate with this DB
cluster.
Type: String. Required: No.
If this argument is omitted, the default DB cluster parameter group is used. If supplied, must match the name of an existing default DB cluster parameter group. The string must consist of from 1 to 255 letters, numbers or hyphens. Its first character must be a letter, and it cannot end with a hyphen or contain two consecutive hyphens.
Parameter dBSubnetGroupName :
The name of the subnet group to use for the new cluster.
Constraints: If provided, must match the name of an existing
DBSubnetGroup.
Example: mySubnetgroup
Parameter deletionProtection :
Specifies whether this cluster can be deleted. If
DeletionProtection is enabled, the cluster cannot be deleted
unless it is modified and DeletionProtection is disabled.
DeletionProtection protects clusters from being accidentally
deleted.
Parameter enableCloudwatchLogsExports :
A list of log types that must be enabled for exporting to Amazon
CloudWatch Logs.
Parameter engineVersion :
The version of the database engine to use for the new cluster.
Parameter kmsKeyId :
The KMS key identifier to use when restoring an encrypted cluster from a
DB snapshot or cluster snapshot.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a cluster with the same Amazon Web Services account that owns the KMS encryption key used to encrypt the new cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
If you do not specify a value for the KmsKeyId parameter,
then the following occurs:
-
If the snapshot or cluster snapshot in
SnapshotIdentifieris encrypted, then the restored cluster is encrypted using the KMS key that was used to encrypt the snapshot or the cluster snapshot. -
If the snapshot or the cluster snapshot in
SnapshotIdentifieris not encrypted, then the restored DB cluster is not encrypted.
Parameter networkType :
The network type of the cluster.
The network type is determined by the DBSubnetGroup specified
for the cluster. A DBSubnetGroup can support only the IPv4
protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see DocumentDB clusters in a VPC in the Amazon DocumentDB Developer Guide.
Valid Values: IPV4 | DUAL
Parameter port :
The port number on which the new cluster accepts connections.
Constraints: Must be a value from 1150 to 65535.
Default: The same port as the original cluster.
Parameter serverlessV2ScalingConfiguration :
Contains the scaling configuration of an Amazon DocumentDB Serverless
cluster.
Parameter storageType :
The storage type to associate with the DB cluster.
For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.
Valid values for storage type - standard | iopt1
Default value is standard
Parameter tags :
The tags to be assigned to the restored cluster.
Parameter vpcSecurityGroupIds :
A list of virtual private cloud (VPC) security groups that the new cluster
will belong to.
Implementation
Future<RestoreDBClusterFromSnapshotResult> restoreDBClusterFromSnapshot({
required String dBClusterIdentifier,
required String engine,
required String snapshotIdentifier,
List<String>? availabilityZones,
String? dBClusterParameterGroupName,
String? dBSubnetGroupName,
bool? deletionProtection,
List<String>? enableCloudwatchLogsExports,
String? engineVersion,
String? kmsKeyId,
String? networkType,
int? port,
ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
String? storageType,
List<Tag>? tags,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
'Engine': engine,
'SnapshotIdentifier': snapshotIdentifier,
if (availabilityZones != null)
if (availabilityZones.isEmpty)
'AvailabilityZones': ''
else
for (var i1 = 0; i1 < availabilityZones.length; i1++)
'AvailabilityZones.AvailabilityZone.${i1 + 1}':
availabilityZones[i1],
if (dBClusterParameterGroupName != null)
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (engineVersion != null) 'EngineVersion': engineVersion,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (networkType != null) 'NetworkType': networkType,
if (port != null) 'Port': port.toString(),
if (serverlessV2ScalingConfiguration != null)
for (var e1 in serverlessV2ScalingConfiguration.toQueryMap().entries)
'ServerlessV2ScalingConfiguration.${e1.key}': e1.value,
if (storageType != null) 'StorageType': storageType,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreDBClusterFromSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreDBClusterFromSnapshotResult',
);
return RestoreDBClusterFromSnapshotResult.fromXml($result);
}