restoreDBClusterToPointInTime method

Future<RestoreDBClusterToPointInTimeResult> restoreDBClusterToPointInTime({
  1. required String dBClusterIdentifier,
  2. required String sourceDBClusterIdentifier,
  3. String? dBSubnetGroupName,
  4. bool? deletionProtection,
  5. List<String>? enableCloudwatchLogsExports,
  6. String? kmsKeyId,
  7. String? networkType,
  8. int? port,
  9. DateTime? restoreToTime,
  10. String? restoreType,
  11. ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
  12. String? storageType,
  13. List<Tag>? tags,
  14. bool? useLatestRestorableTime,
  15. List<String>? vpcSecurityGroupIds,
})

Restores a cluster to an arbitrary point in time. Users can restore to any point in time before LatestRestorableTime for up to BackupRetentionPeriod days. The target cluster is created from the source cluster with the same configuration as the original cluster, except that the new cluster is created with the default security group.

May throw DBClusterAlreadyExistsFault. May throw DBClusterNotFoundFault. May throw DBClusterQuotaExceededFault. May throw DBClusterSnapshotNotFoundFault. May throw DBSubnetGroupNotFoundFault. May throw InsufficientDBClusterCapacityFault. May throw InsufficientStorageClusterCapacityFault. May throw InvalidDBClusterSnapshotStateFault. May throw InvalidDBClusterStateFault. May throw InvalidDBSnapshotStateFault. May throw InvalidRestoreFault. May throw InvalidSubnet. May throw InvalidVPCNetworkStateFault. May throw KMSKeyNotAccessibleFault. May throw NetworkTypeNotSupported. May throw StorageQuotaExceededFault.

Parameter dBClusterIdentifier : The name of the new cluster to be created.

Constraints:

  • Must contain from 1 to 63 letters, numbers, or hyphens.
  • The first character must be a letter.
  • Cannot end with a hyphen or contain two consecutive hyphens.

Parameter sourceDBClusterIdentifier : The identifier of the source cluster from which to restore.

Constraints:

  • Must match the identifier of an existing DBCluster.

Parameter dBSubnetGroupName : The subnet group name to use for the new cluster.

Constraints: If provided, must match the name of an existing DBSubnetGroup.

Example: mySubnetgroup

Parameter deletionProtection : Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted.

Parameter enableCloudwatchLogsExports : A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.

Parameter kmsKeyId : The KMS key identifier to use when restoring an encrypted cluster from an encrypted cluster.

The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a cluster with the same Amazon Web Services account that owns the KMS encryption key used to encrypt the new cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.

You can restore to a new cluster and encrypt the new cluster with an KMS key that is different from the KMS key used to encrypt the source cluster. The new DB cluster is encrypted with the KMS key identified by the KmsKeyId parameter.

If you do not specify a value for the KmsKeyId parameter, then the following occurs:

  • If the cluster is encrypted, then the restored cluster is encrypted using the KMS key that was used to encrypt the source cluster.
  • If the cluster is not encrypted, then the restored cluster is not encrypted.
If DBClusterIdentifier refers to a cluster that is not encrypted, then the restore request is rejected.

Parameter networkType : The network type of the cluster.

The network type is determined by the DBSubnetGroup specified for the cluster. A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).

For more information, see DocumentDB clusters in a VPC in the Amazon DocumentDB Developer Guide.

Valid Values: IPV4 | DUAL

Parameter port : The port number on which the new cluster accepts connections.

Constraints: Must be a value from 1150 to 65535.

Default: The default port for the engine.

Parameter restoreToTime : The date and time to restore the cluster to.

Valid values: A time in Universal Coordinated Time (UTC) format.

Constraints:

  • Must be before the latest restorable time for the instance.
  • Must be specified if the UseLatestRestorableTime parameter is not provided.
  • Cannot be specified if the UseLatestRestorableTime parameter is true.
  • Cannot be specified if the RestoreType parameter is copy-on-write.
Example: 2015-03-07T23:45:00Z

Parameter restoreType : The type of restore to be performed. You can specify one of the following values:

  • full-copy - The new DB cluster is restored as a full copy of the source DB cluster.
  • copy-on-write - The new DB cluster is restored as a clone of the source DB cluster.
Constraints: You can't specify copy-on-write if the engine version of the source DB cluster is earlier than 1.11.

If you don't specify a RestoreType value, then the new DB cluster is restored as a full copy of the source DB cluster.

Parameter serverlessV2ScalingConfiguration : Contains the scaling configuration of an Amazon DocumentDB Serverless cluster.

Parameter storageType : The storage type to associate with the DB cluster.

For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.

Valid values for storage type - standard | iopt1

Default value is standard

Parameter tags : The tags to be assigned to the restored cluster.

Parameter useLatestRestorableTime : A value that is set to true to restore the cluster to the latest restorable backup time, and false otherwise.

Default: false

Constraints: Cannot be specified if the RestoreToTime parameter is provided.

Parameter vpcSecurityGroupIds : A list of VPC security groups that the new cluster belongs to.

Implementation

Future<RestoreDBClusterToPointInTimeResult> restoreDBClusterToPointInTime({
  required String dBClusterIdentifier,
  required String sourceDBClusterIdentifier,
  String? dBSubnetGroupName,
  bool? deletionProtection,
  List<String>? enableCloudwatchLogsExports,
  String? kmsKeyId,
  String? networkType,
  int? port,
  DateTime? restoreToTime,
  String? restoreType,
  ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
  String? storageType,
  List<Tag>? tags,
  bool? useLatestRestorableTime,
  List<String>? vpcSecurityGroupIds,
}) async {
  final $request = <String, String>{
    'DBClusterIdentifier': dBClusterIdentifier,
    'SourceDBClusterIdentifier': sourceDBClusterIdentifier,
    if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
    if (deletionProtection != null)
      'DeletionProtection': deletionProtection.toString(),
    if (enableCloudwatchLogsExports != null)
      if (enableCloudwatchLogsExports.isEmpty)
        'EnableCloudwatchLogsExports': ''
      else
        for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
          'EnableCloudwatchLogsExports.member.${i1 + 1}':
              enableCloudwatchLogsExports[i1],
    if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
    if (networkType != null) 'NetworkType': networkType,
    if (port != null) 'Port': port.toString(),
    if (restoreToTime != null)
      'RestoreToTime': _s.iso8601ToJson(restoreToTime),
    if (restoreType != null) 'RestoreType': restoreType,
    if (serverlessV2ScalingConfiguration != null)
      for (var e1 in serverlessV2ScalingConfiguration.toQueryMap().entries)
        'ServerlessV2ScalingConfiguration.${e1.key}': e1.value,
    if (storageType != null) 'StorageType': storageType,
    if (tags != null)
      if (tags.isEmpty)
        'Tags': ''
      else
        for (var i1 = 0; i1 < tags.length; i1++)
          for (var e3 in tags[i1].toQueryMap().entries)
            'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
    if (useLatestRestorableTime != null)
      'UseLatestRestorableTime': useLatestRestorableTime.toString(),
    if (vpcSecurityGroupIds != null)
      if (vpcSecurityGroupIds.isEmpty)
        'VpcSecurityGroupIds': ''
      else
        for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
          'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
              vpcSecurityGroupIds[i1],
  };
  final $result = await _protocol.send(
    $request,
    action: 'RestoreDBClusterToPointInTime',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RestoreDBClusterToPointInTimeResult',
  );
  return RestoreDBClusterToPointInTimeResult.fromXml($result);
}