switchoverGlobalCluster method
Switches over the specified secondary Amazon DocumentDB cluster to be the new primary Amazon DocumentDB cluster in the global database cluster.
May throw DBClusterNotFoundFault.
May throw GlobalClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidGlobalClusterStateFault.
Parameter globalClusterIdentifier :
The identifier of the Amazon DocumentDB global database cluster to switch
over. The identifier is the unique key assigned by the user when the
cluster is created. In other words, it's the name of the global cluster.
This parameter isn’t case-sensitive.
Constraints:
- Must match the identifier of an existing global cluster (Amazon DocumentDB global database).
- Minimum length of 1. Maximum length of 255.
\[A-Za-z\]\[0-9A-Za-z-:._\]*
Parameter targetDbClusterIdentifier :
The identifier of the secondary Amazon DocumentDB cluster to promote to
the new primary for the global database cluster. Use the Amazon Resource
Name (ARN) for the identifier so that Amazon DocumentDB can locate the
cluster in its Amazon Web Services region.
Constraints:
- Must match the identifier of an existing secondary cluster.
- Minimum length of 1. Maximum length of 255.
\[A-Za-z\]\[0-9A-Za-z-:._\]*
Implementation
Future<SwitchoverGlobalClusterResult> switchoverGlobalCluster({
required String globalClusterIdentifier,
required String targetDbClusterIdentifier,
}) async {
final $request = <String, String>{
'GlobalClusterIdentifier': globalClusterIdentifier,
'TargetDbClusterIdentifier': targetDbClusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'SwitchoverGlobalCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'SwitchoverGlobalClusterResult',
);
return SwitchoverGlobalClusterResult.fromXml($result);
}