DocDBElastic class
Amazon DocumentDB elastic-clusters support workloads with millions of reads/writes per second and petabytes of storage capacity. Amazon DocumentDB elastic clusters also simplify how developers interact with Amazon DocumentDB elastic-clusters by eliminating the need to choose, manage or upgrade instances.
Constructors
- DocDBElastic({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyPendingMaintenanceAction(
{required String applyAction, required OptInType optInType, required String resourceArn, String? applyOn}) → Future< ApplyPendingMaintenanceActionOutput> - The type of pending maintenance action to be applied to the resource.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
copyClusterSnapshot(
{required String snapshotArn, required String targetSnapshotName, bool? copyTags, String? kmsKeyId, Map< String, String> ? tags}) → Future<CopyClusterSnapshotOutput> - Copies a snapshot of an elastic cluster.
-
createCluster(
{required String adminUserName, required String adminUserPassword, required Auth authType, required String clusterName, required int shardCapacity, required int shardCount, int? backupRetentionPeriod, String? clientToken, String? kmsKeyId, String? preferredBackupWindow, String? preferredMaintenanceWindow, int? shardInstanceCount, List< String> ? subnetIds, Map<String, String> ? tags, List<String> ? vpcSecurityGroupIds}) → Future<CreateClusterOutput> - Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
-
createClusterSnapshot(
{required String clusterArn, required String snapshotName, Map< String, String> ? tags}) → Future<CreateClusterSnapshotOutput> - Creates a snapshot of an elastic cluster.
-
deleteCluster(
{required String clusterArn}) → Future< DeleteClusterOutput> - Delete an elastic cluster.
-
deleteClusterSnapshot(
{required String snapshotArn}) → Future< DeleteClusterSnapshotOutput> - Delete an elastic cluster snapshot.
-
getCluster(
{required String clusterArn}) → Future< GetClusterOutput> - Returns information about a specific elastic cluster.
-
getClusterSnapshot(
{required String snapshotArn}) → Future< GetClusterSnapshotOutput> - Returns information about a specific elastic cluster snapshot
-
getPendingMaintenanceAction(
{required String resourceArn}) → Future< GetPendingMaintenanceActionOutput> - Retrieves all maintenance actions that are pending.
-
listClusters(
{int? maxResults, String? nextToken}) → Future< ListClustersOutput> - Returns information about provisioned Amazon DocumentDB elastic clusters.
-
listClusterSnapshots(
{String? clusterArn, int? maxResults, String? nextToken, String? snapshotType}) → Future< ListClusterSnapshotsOutput> - Returns information about snapshots for a specified elastic cluster.
-
listPendingMaintenanceActions(
{int? maxResults, String? nextToken}) → Future< ListPendingMaintenanceActionsOutput> - Retrieves a list of all maintenance actions that are pending.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists all tags on a elastic cluster resource
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreClusterFromSnapshot(
{required String clusterName, required String snapshotArn, String? kmsKeyId, int? shardCapacity, int? shardInstanceCount, List< String> ? subnetIds, Map<String, String> ? tags, List<String> ? vpcSecurityGroupIds}) → Future<RestoreClusterFromSnapshotOutput> - Restores an elastic cluster from a snapshot.
-
startCluster(
{required String clusterArn}) → Future< StartClusterOutput> -
Restarts the stopped elastic cluster that is specified by
clusterARN. -
stopCluster(
{required String clusterArn}) → Future< StopClusterOutput> -
Stops the running elastic cluster that is specified by
clusterArn. The elastic cluster must be in the available state. -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds metadata tags to an elastic cluster resource
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes metadata tags from an elastic cluster resource
-
updateCluster(
{required String clusterArn, String? adminUserPassword, Auth? authType, int? backupRetentionPeriod, String? clientToken, String? preferredBackupWindow, String? preferredMaintenanceWindow, int? shardCapacity, int? shardCount, int? shardInstanceCount, List< String> ? subnetIds, List<String> ? vpcSecurityGroupIds}) → Future<UpdateClusterOutput> - Modifies an elastic cluster. This includes updating admin-username/password, upgrading the API version, and setting up a backup window and maintenance window
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited