listPendingMaintenanceActions method

Future<ListPendingMaintenanceActionsOutput> listPendingMaintenanceActions({
  1. int? maxResults,
  2. String? nextToken,
})

Retrieves a list of all maintenance actions that are pending.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to include in the response. If more records exist than the specified maxResults value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by maxResults.

Implementation

Future<ListPendingMaintenanceActionsOutput> listPendingMaintenanceActions({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/pending-actions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListPendingMaintenanceActionsOutput.fromJson(response);
}