stopCluster method

Future<StopClusterOutput> stopCluster({
  1. required String clusterArn,
})

Stops the running elastic cluster that is specified by clusterArn. The elastic cluster must be in the available state.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter clusterArn : The ARN identifier of the elastic cluster.

Implementation

Future<StopClusterOutput> stopCluster({
  required String clusterArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/cluster/${Uri.encodeComponent(clusterArn)}/stop',
    exceptionFnMap: _exceptionFns,
  );
  return StopClusterOutput.fromJson(response);
}