Drs class

AWS Elastic Disaster Recovery Service.

Constructors

Drs({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateSourceNetworkStack({required String cfnStackName, required String sourceNetworkID}) Future<AssociateSourceNetworkStackResponse>
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createExtendedSourceServer({required String sourceServerArn, Map<String, String>? tags}) Future<CreateExtendedSourceServerResponse>
Create an extended source server in the target Account based on the source server in staging account.
createLaunchConfigurationTemplate({bool? copyPrivateIp, bool? copyTags, String? exportBucketArn, LaunchDisposition? launchDisposition, bool? launchIntoSourceInstance, Licensing? licensing, bool? postLaunchEnabled, Map<String, String>? tags, TargetInstanceTypeRightSizingMethod? targetInstanceTypeRightSizingMethod}) Future<CreateLaunchConfigurationTemplateResponse>
Creates a new Launch Configuration Template.
createReplicationConfigurationTemplate({required int bandwidthThrottling, required ReplicationConfigurationEbsEncryption ebsEncryption, required List<PITPolicyRule> pitPolicy, required List<String> replicationServersSecurityGroupsIDs, required String stagingAreaSubnetId, required Map<String, String> stagingAreaTags, bool? associateDefaultSecurityGroup, bool? autoReplicateNewDisks, bool? createPublicIP, ReplicationConfigurationDataPlaneRouting? dataPlaneRouting, ReplicationConfigurationDefaultLargeStagingDiskType? defaultLargeStagingDiskType, String? ebsEncryptionKeyArn, InternetProtocol? internetProtocol, String? replicationServerInstanceType, Map<String, String>? tags, bool? useDedicatedReplicationServer}) Future<ReplicationConfigurationTemplate>
Creates a new ReplicationConfigurationTemplate.
createSourceNetwork({required String originAccountID, required String originRegion, required String vpcID, Map<String, String>? tags}) Future<CreateSourceNetworkResponse>
Create a new Source Network resource for a provided VPC ID.
deleteJob({required String jobID}) Future<void>
Deletes a single Job by ID.
deleteLaunchAction({required String actionId, required String resourceId}) Future<void>
Deletes a resource launch action.
deleteLaunchConfigurationTemplate({required String launchConfigurationTemplateID}) Future<void>
Deletes a single Launch Configuration Template by ID.
deleteRecoveryInstance({required String recoveryInstanceID}) Future<void>
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
deleteReplicationConfigurationTemplate({required String replicationConfigurationTemplateID}) Future<void>
Deletes a single Replication Configuration Template by ID
deleteSourceNetwork({required String sourceNetworkID}) Future<void>
Delete Source Network resource.
deleteSourceServer({required String sourceServerID}) Future<void>
Deletes a single Source Server by ID. The Source Server must be disconnected first.
describeJobLogItems({required String jobID, int? maxResults, String? nextToken}) Future<DescribeJobLogItemsResponse>
Retrieves a detailed Job log with pagination.
describeJobs({DescribeJobsRequestFilters? filters, int? maxResults, String? nextToken}) Future<DescribeJobsResponse>
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime
describeLaunchConfigurationTemplates({List<String>? launchConfigurationTemplateIDs, int? maxResults, String? nextToken}) Future<DescribeLaunchConfigurationTemplatesResponse>
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs
describeRecoveryInstances({DescribeRecoveryInstancesRequestFilters? filters, int? maxResults, String? nextToken}) Future<DescribeRecoveryInstancesResponse>
Lists all Recovery Instances or multiple Recovery Instances by ID.
describeRecoverySnapshots({required String sourceServerID, DescribeRecoverySnapshotsRequestFilters? filters, int? maxResults, String? nextToken, RecoverySnapshotsOrder? order}) Future<DescribeRecoverySnapshotsResponse>
Lists all Recovery Snapshots for a single Source Server.
describeReplicationConfigurationTemplates({int? maxResults, String? nextToken, List<String>? replicationConfigurationTemplateIDs}) Future<DescribeReplicationConfigurationTemplatesResponse>
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
describeSourceNetworks({DescribeSourceNetworksRequestFilters? filters, int? maxResults, String? nextToken}) Future<DescribeSourceNetworksResponse>
Lists all Source Networks or multiple Source Networks filtered by ID.
describeSourceServers({DescribeSourceServersRequestFilters? filters, int? maxResults, String? nextToken}) Future<DescribeSourceServersResponse>
Lists all Source Servers or multiple Source Servers filtered by ID.
disconnectRecoveryInstance({required String recoveryInstanceID}) Future<void>
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
disconnectSourceServer({required String sourceServerID}) Future<SourceServer>
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
exportSourceNetworkCfnTemplate({required String sourceNetworkID}) Future<ExportSourceNetworkCfnTemplateResponse>
Export the Source Network CloudFormation template to an S3 bucket.
getFailbackReplicationConfiguration({required String recoveryInstanceID}) Future<GetFailbackReplicationConfigurationResponse>
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
getLaunchConfiguration({required String sourceServerID}) Future<LaunchConfiguration>
Gets a LaunchConfiguration, filtered by Source Server IDs.
getReplicationConfiguration({required String sourceServerID}) Future<ReplicationConfiguration>
Gets a ReplicationConfiguration, filtered by Source Server ID.
initializeService() Future<void>
Initialize Elastic Disaster Recovery.
listExtensibleSourceServers({required String stagingAccountID, int? maxResults, String? nextToken}) Future<ListExtensibleSourceServersResponse>
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
listLaunchActions({required String resourceId, LaunchActionsRequestFilters? filters, int? maxResults, String? nextToken}) Future<ListLaunchActionsResponse>
Lists resource launch actions.
listStagingAccounts({int? maxResults, String? nextToken}) Future<ListStagingAccountsResponse>
Returns an array of staging accounts for existing extended source servers.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List all tags for your Elastic Disaster Recovery resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putLaunchAction({required String actionCode, required String actionId, required String actionVersion, required bool active, required LaunchActionCategory category, required String description, required String name, required bool optional, required int order, required String resourceId, Map<String, LaunchActionParameter>? parameters}) Future<PutLaunchActionResponse>
Puts a resource launch action.
retryDataReplication({required String sourceServerID}) Future<SourceServer>
WARNING: RetryDataReplication is deprecated. Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
reverseReplication({required String recoveryInstanceID}) Future<ReverseReplicationResponse>
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region
startFailbackLaunch({required List<String> recoveryInstanceIDs, Map<String, String>? tags}) Future<StartFailbackLaunchResponse>
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
startRecovery({required List<StartRecoveryRequestSourceServer> sourceServers, bool? isDrill, Map<String, String>? tags}) Future<StartRecoveryResponse>
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
startReplication({required String sourceServerID}) Future<StartReplicationResponse>
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
startSourceNetworkRecovery({required List<StartSourceNetworkRecoveryRequestNetworkEntry> sourceNetworks, bool? deployAsNew, Map<String, String>? tags}) Future<StartSourceNetworkRecoveryResponse>
Deploy VPC for the specified Source Network and modify launch templates to use this network. The VPC will be deployed using a dedicated CloudFormation stack.
startSourceNetworkReplication({required String sourceNetworkID}) Future<StartSourceNetworkReplicationResponse>
Starts replication for a Source Network. This action would make the Source Network protected.
stopFailback({required String recoveryInstanceID}) Future<void>
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
stopReplication({required String sourceServerID}) Future<StopReplicationResponse>
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
stopSourceNetworkReplication({required String sourceNetworkID}) Future<StopSourceNetworkReplicationResponse>
Stops replication for a Source Network. This action would make the Source Network unprotected.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
terminateRecoveryInstances({required List<String> recoveryInstanceIDs}) Future<TerminateRecoveryInstancesResponse>
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
updateFailbackReplicationConfiguration({required String recoveryInstanceID, int? bandwidthThrottling, InternetProtocol? internetProtocol, String? name, bool? usePrivateIP}) Future<void>
Allows you to update the failback replication configuration of a Recovery Instance by ID.
updateLaunchConfiguration({required String sourceServerID, bool? copyPrivateIp, bool? copyTags, LaunchDisposition? launchDisposition, LaunchIntoInstanceProperties? launchIntoInstanceProperties, Licensing? licensing, String? name, bool? postLaunchEnabled, TargetInstanceTypeRightSizingMethod? targetInstanceTypeRightSizingMethod}) Future<LaunchConfiguration>
Updates a LaunchConfiguration by Source Server ID.
updateLaunchConfigurationTemplate({required String launchConfigurationTemplateID, bool? copyPrivateIp, bool? copyTags, String? exportBucketArn, LaunchDisposition? launchDisposition, bool? launchIntoSourceInstance, Licensing? licensing, bool? postLaunchEnabled, TargetInstanceTypeRightSizingMethod? targetInstanceTypeRightSizingMethod}) Future<UpdateLaunchConfigurationTemplateResponse>
Updates an existing Launch Configuration Template by ID.
updateReplicationConfiguration({required String sourceServerID, bool? associateDefaultSecurityGroup, bool? autoReplicateNewDisks, int? bandwidthThrottling, bool? createPublicIP, ReplicationConfigurationDataPlaneRouting? dataPlaneRouting, ReplicationConfigurationDefaultLargeStagingDiskType? defaultLargeStagingDiskType, ReplicationConfigurationEbsEncryption? ebsEncryption, String? ebsEncryptionKeyArn, InternetProtocol? internetProtocol, String? name, List<PITPolicyRule>? pitPolicy, List<ReplicationConfigurationReplicatedDisk>? replicatedDisks, String? replicationServerInstanceType, List<String>? replicationServersSecurityGroupsIDs, String? stagingAreaSubnetId, Map<String, String>? stagingAreaTags, bool? useDedicatedReplicationServer}) Future<ReplicationConfiguration>
Allows you to update a ReplicationConfiguration by Source Server ID.
updateReplicationConfigurationTemplate({required String replicationConfigurationTemplateID, String? arn, bool? associateDefaultSecurityGroup, bool? autoReplicateNewDisks, int? bandwidthThrottling, bool? createPublicIP, ReplicationConfigurationDataPlaneRouting? dataPlaneRouting, ReplicationConfigurationDefaultLargeStagingDiskType? defaultLargeStagingDiskType, ReplicationConfigurationEbsEncryption? ebsEncryption, String? ebsEncryptionKeyArn, InternetProtocol? internetProtocol, List<PITPolicyRule>? pitPolicy, String? replicationServerInstanceType, List<String>? replicationServersSecurityGroupsIDs, String? stagingAreaSubnetId, Map<String, String>? stagingAreaTags, bool? useDedicatedReplicationServer}) Future<ReplicationConfigurationTemplate>
Updates a ReplicationConfigurationTemplate by ID.

Operators

operator ==(Object other) bool
The equality operator.
inherited