associateSourceNetworkStack method

Future<AssociateSourceNetworkStackResponse> associateSourceNetworkStack({
  1. required String cfnStackName,
  2. required String sourceNetworkID,
})

Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UninitializedAccountException. May throw ValidationException.

Parameter cfnStackName : CloudFormation template to associate with a Source Network.

Parameter sourceNetworkID : The Source Network ID to associate with CloudFormation template.

Implementation

Future<AssociateSourceNetworkStackResponse> associateSourceNetworkStack({
  required String cfnStackName,
  required String sourceNetworkID,
}) async {
  final $payload = <String, dynamic>{
    'cfnStackName': cfnStackName,
    'sourceNetworkID': sourceNetworkID,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/AssociateSourceNetworkStack',
    exceptionFnMap: _exceptionFns,
  );
  return AssociateSourceNetworkStackResponse.fromJson(response);
}