createExtendedSourceServer method
Create an extended source server in the target Account based on the source server in staging account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter sourceServerArn :
This defines the ARN of the source server in staging Account based on
which you want to create an extended source server.
Parameter tags :
A list of tags associated with the extended source server.
Implementation
Future<CreateExtendedSourceServerResponse> createExtendedSourceServer({
required String sourceServerArn,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'sourceServerArn': sourceServerArn,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateExtendedSourceServer',
exceptionFnMap: _exceptionFns,
);
return CreateExtendedSourceServerResponse.fromJson(response);
}