deleteRecoveryInstance method
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter recoveryInstanceID :
The ID of the Recovery Instance to be deleted.
Implementation
Future<void> deleteRecoveryInstance({
required String recoveryInstanceID,
}) async {
final $payload = <String, dynamic>{
'recoveryInstanceID': recoveryInstanceID,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteRecoveryInstance',
exceptionFnMap: _exceptionFns,
);
}