describeJobLogItems method
Retrieves a detailed Job log with pagination.
May throw InternalServerException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter jobID :
The ID of the Job for which Job log items will be retrieved.
Parameter maxResults :
Maximum number of Job log items to retrieve.
Parameter nextToken :
The token of the next Job log items to retrieve.
Implementation
Future<DescribeJobLogItemsResponse> describeJobLogItems({
required String jobID,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final $payload = <String, dynamic>{
'jobID': jobID,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DescribeJobLogItems',
exceptionFnMap: _exceptionFns,
);
return DescribeJobLogItemsResponse.fromJson(response);
}