describeLaunchConfigurationTemplates method

Future<DescribeLaunchConfigurationTemplatesResponse> describeLaunchConfigurationTemplates({
  1. List<String>? launchConfigurationTemplateIDs,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UninitializedAccountException. May throw ValidationException.

Parameter launchConfigurationTemplateIDs : Request to filter Launch Configuration Templates list by Launch Configuration Template ID.

Parameter maxResults : Maximum results to be returned in DescribeLaunchConfigurationTemplates.

Parameter nextToken : The token of the next Launch Configuration Template to retrieve.

Implementation

Future<DescribeLaunchConfigurationTemplatesResponse>
    describeLaunchConfigurationTemplates({
  List<String>? launchConfigurationTemplateIDs,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (launchConfigurationTemplateIDs != null)
      'launchConfigurationTemplateIDs': launchConfigurationTemplateIDs,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DescribeLaunchConfigurationTemplates',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeLaunchConfigurationTemplatesResponse.fromJson(response);
}