listLaunchActions method

Future<ListLaunchActionsResponse> listLaunchActions({
  1. required String resourceId,
  2. LaunchActionsRequestFilters? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Lists resource launch actions.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UninitializedAccountException.

Parameter filters : Filters to apply when listing resource launch actions.

Parameter maxResults : Maximum amount of items to return when listing resource launch actions.

Parameter nextToken : Next token to use when listing resource launch actions.

Implementation

Future<ListLaunchActionsResponse> listLaunchActions({
  required String resourceId,
  LaunchActionsRequestFilters? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    'resourceId': resourceId,
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListLaunchActions',
    exceptionFnMap: _exceptionFns,
  );
  return ListLaunchActionsResponse.fromJson(response);
}