retryDataReplication method
WARNING: RetryDataReplication is deprecated. Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter sourceServerID :
The ID of the Source Server whose data replication should be retried.
Implementation
Future<SourceServer> retryDataReplication({
required String sourceServerID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/RetryDataReplication',
exceptionFnMap: _exceptionFns,
);
return SourceServer.fromJson(response);
}