startFailbackLaunch method

Future<StartFailbackLaunchResponse> startFailbackLaunch({
  1. required List<String> recoveryInstanceIDs,
  2. Map<String, String>? tags,
})

Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.

May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UninitializedAccountException. May throw ValidationException.

Parameter recoveryInstanceIDs : The IDs of the Recovery Instance whose failback launch we want to request.

Parameter tags : The tags to be associated with the failback launch Job.

Implementation

Future<StartFailbackLaunchResponse> startFailbackLaunch({
  required List<String> recoveryInstanceIDs,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'recoveryInstanceIDs': recoveryInstanceIDs,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/StartFailbackLaunch',
    exceptionFnMap: _exceptionFns,
  );
  return StartFailbackLaunchResponse.fromJson(response);
}