startReplication method
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter sourceServerID :
The ID of the Source Server to start replication for.
Implementation
Future<StartReplicationResponse> startReplication({
required String sourceServerID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StartReplication',
exceptionFnMap: _exceptionFns,
);
return StartReplicationResponse.fromJson(response);
}