terminateRecoveryInstances method

Future<TerminateRecoveryInstancesResponse> terminateRecoveryInstances({
  1. required List<String> recoveryInstanceIDs,
})

Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.

May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UninitializedAccountException.

Parameter recoveryInstanceIDs : The IDs of the Recovery Instances that should be terminated.

Implementation

Future<TerminateRecoveryInstancesResponse> terminateRecoveryInstances({
  required List<String> recoveryInstanceIDs,
}) async {
  final $payload = <String, dynamic>{
    'recoveryInstanceIDs': recoveryInstanceIDs,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/TerminateRecoveryInstances',
    exceptionFnMap: _exceptionFns,
  );
  return TerminateRecoveryInstancesResponse.fromJson(response);
}