Dsql class

This is an interface reference for Amazon Aurora DSQL. It contains documentation for one of the programming or command line interfaces you can use to manage Amazon Aurora DSQL.

Amazon Aurora DSQL is a serverless, distributed SQL database suitable for workloads of any size. is available in both single-Region and multi-Region configurations, so your clusters and databases are always available even if an Availability Zone or an Amazon Web Services Region are unavailable. lets you focus on using your data to acquire new insights for your business and customers.

Constructors

Dsql({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCluster({bool? bypassPolicyLockoutSafetyCheck, String? clientToken, bool? deletionProtectionEnabled, String? kmsEncryptionKey, MultiRegionProperties? multiRegionProperties, String? policy, Map<String, String>? tags}) Future<CreateClusterOutput>
The CreateCluster API allows you to create both single-Region clusters and multi-Region clusters. With the addition of the multiRegionProperties parameter, you can create a cluster with witness Region support and establish peer relationships with clusters in other Regions during creation. Required permissions
createStream({required String clusterIdentifier, required StreamFormat format, required StreamOrdering ordering, required TargetDefinition targetDefinition, String? clientToken, Map<String, String>? tags}) Future<CreateStreamOutput>
Creates a new change data capture (CDC) stream for a cluster. The stream captures database changes and delivers them to the specified target destination.
deleteCluster({required String identifier, String? clientToken}) Future<DeleteClusterOutput>
Deletes a cluster in Amazon Aurora DSQL.
deleteClusterPolicy({required String identifier, String? clientToken, String? expectedPolicyVersion}) Future<DeleteClusterPolicyOutput>
Deletes the resource-based policy attached to a cluster. This removes all access permissions defined by the policy, reverting to default access controls.
deleteStream({required String clusterIdentifier, required String streamIdentifier, String? clientToken}) Future<DeleteStreamOutput>
Deletes a stream from a cluster.
getCluster({required String identifier}) Future<GetClusterOutput>
Retrieves information about a cluster.
getClusterPolicy({required String identifier}) Future<GetClusterPolicyOutput>
Retrieves the resource-based policy document attached to a cluster. This policy defines the access permissions and conditions for the cluster.
getStream({required String clusterIdentifier, required String streamIdentifier}) Future<GetStreamOutput>
Retrieves information about a stream.
getVpcEndpointServiceName({required String identifier}) Future<GetVpcEndpointServiceNameOutput>
Retrieves the VPC endpoint service name.
listClusters({int? maxResults, String? nextToken}) Future<ListClustersOutput>
Retrieves information about a list of clusters.
listStreams({required String clusterIdentifier, int? maxResults, String? nextToken}) Future<ListStreamsOutput>
Retrieves information about a list of streams for a cluster.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists all of the tags for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putClusterPolicy({required String identifier, required String policy, bool? bypassPolicyLockoutSafetyCheck, String? clientToken, String? expectedPolicyVersion}) Future<PutClusterPolicyOutput>
Attaches a resource-based policy to a cluster. This policy defines access permissions and conditions for the cluster, allowing you to control which principals can perform actions on the cluster.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Tags a resource with a map of key and value pairs.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag from a resource.
updateCluster({required String identifier, String? clientToken, bool? deletionProtectionEnabled, String? kmsEncryptionKey, MultiRegionProperties? multiRegionProperties}) Future<UpdateClusterOutput>
The UpdateCluster API allows you to modify both single-Region and multi-Region cluster configurations. With the multiRegionProperties parameter, you can add or modify witness Region support and manage peer relationships with clusters in other Regions. Required permissions

Operators

operator ==(Object other) bool
The equality operator.
inherited