listClusters method

Future<ListClustersOutput> listClusters({
  1. int? maxResults,
  2. String? nextToken,
})

Retrieves information about a list of clusters.

May throw ResourceNotFoundException.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.

Parameter nextToken : If your initial ListClusters operation returns a nextToken, you can include the returned nextToken in following ListClusters operations, which returns results in the next page.

Implementation

Future<ListClustersOutput> listClusters({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cluster',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListClustersOutput.fromJson(response);
}