tagResource method

Future<void> tagResource({
  1. required String resourceArn,
  2. required Map<String, String> tags,
})

Tags a resource with a map of key and value pairs.

May throw ResourceNotFoundException. May throw ServiceQuotaExceededException.

Parameter resourceArn : The ARN of the resource that you want to tag.

Parameter tags : A map of key and value pairs to use to tag your resource.

Implementation

Future<void> tagResource({
  required String resourceArn,
  required Map<String, String> tags,
}) async {
  final $payload = <String, dynamic>{
    'tags': tags,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
    exceptionFnMap: _exceptionFns,
  );
}