batchGetItem method
The BatchGetItem operation returns the attributes of one or
more items from one or more tables. You identify requested items by
primary key.
A single operation can retrieve up to 16 MB of data, which can contain as
many as 100 items. BatchGetItem returns a partial result if
the response size limit is exceeded, the table's provisioned throughput is
exceeded, more than 1MB per partition is requested, or an internal
processing failure occurs. If a partial result is returned, the operation
returns a value for UnprocessedKeys. You can use this value
to retry the operation starting with the next item to get.
For example, if you ask to retrieve 100 items, but each individual item is
300 KB in size, the system returns 52 items (so as not to exceed the 16 MB
limit). It also returns an appropriate UnprocessedKeys value
so you can get the next page of results. If desired, your application can
include its own logic to assemble the pages of results into one dataset.
If none of the items can be processed due to insufficient
provisioned throughput on all of the tables in the request, then
BatchGetItem returns a
ProvisionedThroughputExceededException. If at least
one of the items is successfully processed, then
BatchGetItem completes successfully, while returning the keys
of the unread items in UnprocessedKeys.
For more information, see Batch
Operations and Error Handling in the Amazon DynamoDB Developer
Guide.
By default, BatchGetItem performs eventually consistent reads
on every table in the request. If you want strongly consistent reads
instead, you can set ConsistentRead to true for
any or all tables.
In order to minimize response latency, BatchGetItem may
retrieve items in parallel.
When designing your application, keep in mind that DynamoDB does not
return items in any particular order. To help parse the response by item,
include the primary key values for the items in your request in the
ProjectionExpression parameter.
If a requested item does not exist, it is not returned in the result. Requests for nonexistent items consume the minimum read capacity units according to the type of read. For more information, see Working with Tables in the Amazon DynamoDB Developer Guide.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw ProvisionedThroughputExceededException.
May throw RequestLimitExceeded.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter requestItems :
A map of one or more table names or table ARNs and, for each table, a map
that describes one or more items to retrieve from that table. Each table
name or ARN can be used only once per BatchGetItem request.
Each element in the map of items to retrieve consists of the following:
-
ConsistentRead- Iftrue, a strongly consistent read is used; iffalse(the default), an eventually consistent read is used. -
ExpressionAttributeNames- One or more substitution tokens for attribute names in theProjectionExpressionparameter. The following are some use cases for usingExpressionAttributeNames:- To access an attribute whose name conflicts with a DynamoDB reserved word.
- To create a placeholder for repeating occurrences of an attribute name in an expression.
- To prevent special characters in an attribute name from being misinterpreted in an expression.
-
Percentile
ExpressionAttributeNames:-
{"#P":"Percentile"}
-
#P = :val
-
Keys- An array of primary key attribute values that define specific items in the table. For each primary key, you must provide all of the key attributes. For example, with a simple primary key, you only need to provide the partition key value. For a composite key, you must provide both the partition key value and the sort key value. -
ProjectionExpression- A string that identifies one or more attributes to retrieve from the table. These attributes can include scalars, sets, or elements of a JSON document. The attributes in the expression must be separated by commas.If no attribute names are specified, then all attributes are returned. If any of the requested attributes are not found, they do not appear in the result.
For more information, see Accessing Item Attributes in the Amazon DynamoDB Developer Guide.
-
AttributesToGet- This is a legacy parameter. UseProjectionExpressioninstead. For more information, see AttributesToGet in the Amazon DynamoDB Developer Guide.
Implementation
Future<BatchGetItemOutput> batchGetItem({
required Map<String, KeysAndAttributes> requestItems,
ReturnConsumedCapacity? returnConsumedCapacity,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.BatchGetItem'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RequestItems': requestItems,
if (returnConsumedCapacity != null)
'ReturnConsumedCapacity': returnConsumedCapacity.value,
},
);
return BatchGetItemOutput.fromJson(jsonResponse.body);
}