describeContinuousBackups method
Checks the status of continuous backups and point in time recovery on the
specified table. Continuous backups are ENABLED on all tables
at table creation. If point in time recovery is enabled,
PointInTimeRecoveryStatus will be set to ENABLED.
After continuous backups and point in time recovery are enabled, you can
restore to any point in time within
EarliestRestorableDateTime and
LatestRestorableDateTime.
LatestRestorableDateTime is typically 5 minutes before the
current time. You can restore your table to any point in time in the last
35 days. You can set the recovery period to any value between 1 and 35
days.
You can call DescribeContinuousBackups at a maximum rate of
10 times per second.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw TableNotFoundException.
Parameter tableName :
Name of the table for which the customer wants to check the continuous
backups and point in time recovery settings.
You can also provide the Amazon Resource Name (ARN) of the table in this parameter.
Implementation
Future<DescribeContinuousBackupsOutput> describeContinuousBackups({
required String tableName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.DescribeContinuousBackups'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TableName': tableName,
},
);
return DescribeContinuousBackupsOutput.fromJson(jsonResponse.body);
}