describeTableReplicaAutoScaling method

Future<DescribeTableReplicaAutoScalingOutput> describeTableReplicaAutoScaling({
  1. required String tableName,
})

Describes auto scaling settings across replicas of the global table at once.

May throw InternalServerError. May throw ResourceNotFoundException.

Parameter tableName : The name of the table. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

Implementation

Future<DescribeTableReplicaAutoScalingOutput>
    describeTableReplicaAutoScaling({
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'DynamoDB_20120810.DescribeTableReplicaAutoScaling'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TableName': tableName,
    },
  );

  return DescribeTableReplicaAutoScalingOutput.fromJson(jsonResponse.body);
}