describeTimeToLive method

Future<DescribeTimeToLiveOutput> describeTimeToLive({
  1. required String tableName,
})

Gives a description of the Time to Live (TTL) status on the specified table.

May throw InternalServerError. May throw InvalidEndpointException. May throw ResourceNotFoundException.

Parameter tableName : The name of the table to be described. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

Implementation

Future<DescribeTimeToLiveOutput> describeTimeToLive({
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'DynamoDB_20120810.DescribeTimeToLive'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TableName': tableName,
    },
  );

  return DescribeTimeToLiveOutput.fromJson(jsonResponse.body);
}