disableKinesisStreamingDestination method
Stops replication from the DynamoDB table to the Kinesis data stream. This is done without deleting either of the resources.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter streamArn :
The ARN for a Kinesis data stream.
Parameter tableName :
The name of the DynamoDB table. You can also provide the Amazon Resource
Name (ARN) of the table in this parameter.
Parameter enableKinesisStreamingConfiguration :
The source for the Kinesis streaming information that is being enabled.
Implementation
Future<KinesisStreamingDestinationOutput> disableKinesisStreamingDestination({
required String streamArn,
required String tableName,
EnableKinesisStreamingConfiguration? enableKinesisStreamingConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.DisableKinesisStreamingDestination'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'StreamArn': streamArn,
'TableName': tableName,
if (enableKinesisStreamingConfiguration != null)
'EnableKinesisStreamingConfiguration':
enableKinesisStreamingConfiguration,
},
);
return KinesisStreamingDestinationOutput.fromJson(jsonResponse.body);
}