updateTable method

Future<UpdateTableOutput> updateTable({
  1. required String tableName,
  2. List<AttributeDefinition>? attributeDefinitions,
  3. BillingMode? billingMode,
  4. bool? deletionProtectionEnabled,
  5. List<GlobalSecondaryIndexUpdate>? globalSecondaryIndexUpdates,
  6. GlobalTableSettingsReplicationMode? globalTableSettingsReplicationMode,
  7. List<GlobalTableWitnessGroupUpdate>? globalTableWitnessUpdates,
  8. MultiRegionConsistency? multiRegionConsistency,
  9. OnDemandThroughput? onDemandThroughput,
  10. ProvisionedThroughput? provisionedThroughput,
  11. List<ReplicationGroupUpdate>? replicaUpdates,
  12. SSESpecification? sSESpecification,
  13. StreamSpecification? streamSpecification,
  14. TableClass? tableClass,
  15. WarmThroughput? warmThroughput,
})

Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.

You can only perform one of the following operations at once:

  • Modify the provisioned throughput settings of the table.
  • Remove a global secondary index from the table.
  • Create a new global secondary index on the table. After the index begins backfilling, you can use UpdateTable to perform other operations.
UpdateTable is an asynchronous operation; while it's executing, the table status changes from ACTIVE to UPDATING. While it's UPDATING, you can't issue another UpdateTable request. When the table returns to the ACTIVE state, the UpdateTable operation is complete.

May throw InternalServerError. May throw InvalidEndpointException. May throw LimitExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter tableName : The name of the table to be updated. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

Parameter attributeDefinitions : An array of attributes that describe the key schema for the table and indexes. If you are adding a new global secondary index to the table, AttributeDefinitions must include the key element(s) of the new index.

Parameter billingMode : Controls how you are charged for read and write throughput and how you manage capacity. When switching from pay-per-request to provisioned capacity, initial provisioned capacity values must be set. The initial provisioned capacity values are estimated based on the consumed read and write capacity of your table and global secondary indexes over the past 30 minutes.

  • PAY_PER_REQUEST - We recommend using PAY_PER_REQUEST for most DynamoDB workloads. PAY_PER_REQUEST sets the billing mode to On-demand capacity mode.
  • PROVISIONED - We recommend using PROVISIONED for steady workloads with predictable growth where capacity requirements can be reliably forecasted. PROVISIONED sets the billing mode to Provisioned capacity mode.

Parameter deletionProtectionEnabled : Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.

Parameter globalSecondaryIndexUpdates : An array of one or more global secondary indexes for the table. For each index in the array, you can request one action:

  • Create - add a new global secondary index to the table.
  • Update - modify the provisioned throughput settings of an existing global secondary index.
  • Delete - remove a global secondary index from the table.
You can create or delete only one global secondary index per UpdateTable operation.

For more information, see Managing Global Secondary Indexes in the Amazon DynamoDB Developer Guide.

Parameter globalTableSettingsReplicationMode : Controls the settings replication mode for a global table replica. This attribute can be defined using UpdateTable operation only on a regional table with values:

  • ENABLED: Defines settings replication on a regional table to be used as a source table for creating Multi-Account Global Table.
  • DISABLED: Remove settings replication on a regional table. Settings replication needs to be defined to ENABLED again in order to create a Multi-Account Global Table using this table.

Parameter globalTableWitnessUpdates : A list of witness updates for a MRSC global table. A witness provides a cost-effective alternative to a full replica in a MRSC global table by maintaining replicated change data written to global table replicas. You cannot perform read or write operations on a witness. For each witness, you can request one action:

  • Create - add a new witness to the global table.
  • Delete - remove a witness from the global table.
You can create or delete only one witness per UpdateTable operation.

For more information, see Multi-Region strong consistency (MRSC) in the Amazon DynamoDB Developer Guide

Parameter multiRegionConsistency : Specifies the consistency mode for a new global table. This parameter is only valid when you create a global table by specifying one or more Create actions in the ReplicaUpdates action list.

You can specify one of the following consistency modes:

  • EVENTUAL: Configures a new global table for multi-Region eventual consistency (MREC). This is the default consistency mode for global tables.
  • STRONG: Configures a new global table for multi-Region strong consistency (MRSC).
If you don't specify this field, the global table consistency mode defaults to EVENTUAL. For more information about global tables consistency modes, see Consistency modes in DynamoDB developer guide.

Parameter onDemandThroughput : Updates the maximum number of read and write units for the specified table in on-demand capacity mode. If you use this parameter, you must specify MaxReadRequestUnits, MaxWriteRequestUnits, or both.

Parameter provisionedThroughput : The new provisioned throughput settings for the specified table or index.

Parameter replicaUpdates : A list of replica update actions (create, delete, or update) for the table.

Parameter sSESpecification : The new server-side encryption settings for the specified table.

Parameter streamSpecification : Represents the DynamoDB Streams configuration for the table.

Parameter tableClass : The table class of the table to be updated. Valid values are STANDARD and STANDARD_INFREQUENT_ACCESS.

Parameter warmThroughput : Represents the warm throughput (in read units per second and write units per second) for updating a table.

Implementation

Future<UpdateTableOutput> updateTable({
  required String tableName,
  List<AttributeDefinition>? attributeDefinitions,
  BillingMode? billingMode,
  bool? deletionProtectionEnabled,
  List<GlobalSecondaryIndexUpdate>? globalSecondaryIndexUpdates,
  GlobalTableSettingsReplicationMode? globalTableSettingsReplicationMode,
  List<GlobalTableWitnessGroupUpdate>? globalTableWitnessUpdates,
  MultiRegionConsistency? multiRegionConsistency,
  OnDemandThroughput? onDemandThroughput,
  ProvisionedThroughput? provisionedThroughput,
  List<ReplicationGroupUpdate>? replicaUpdates,
  SSESpecification? sSESpecification,
  StreamSpecification? streamSpecification,
  TableClass? tableClass,
  WarmThroughput? warmThroughput,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'DynamoDB_20120810.UpdateTable'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TableName': tableName,
      if (attributeDefinitions != null)
        'AttributeDefinitions': attributeDefinitions,
      if (billingMode != null) 'BillingMode': billingMode.value,
      if (deletionProtectionEnabled != null)
        'DeletionProtectionEnabled': deletionProtectionEnabled,
      if (globalSecondaryIndexUpdates != null)
        'GlobalSecondaryIndexUpdates': globalSecondaryIndexUpdates,
      if (globalTableSettingsReplicationMode != null)
        'GlobalTableSettingsReplicationMode':
            globalTableSettingsReplicationMode.value,
      if (globalTableWitnessUpdates != null)
        'GlobalTableWitnessUpdates': globalTableWitnessUpdates,
      if (multiRegionConsistency != null)
        'MultiRegionConsistency': multiRegionConsistency.value,
      if (onDemandThroughput != null)
        'OnDemandThroughput': onDemandThroughput,
      if (provisionedThroughput != null)
        'ProvisionedThroughput': provisionedThroughput,
      if (replicaUpdates != null) 'ReplicaUpdates': replicaUpdates,
      if (sSESpecification != null) 'SSESpecification': sSESpecification,
      if (streamSpecification != null)
        'StreamSpecification': streamSpecification,
      if (tableClass != null) 'TableClass': tableClass.value,
      if (warmThroughput != null) 'WarmThroughput': warmThroughput,
    },
  );

  return UpdateTableOutput.fromJson(jsonResponse.body);
}