deleteSigningConfiguration method

Future<DeleteSigningConfigurationResponse> deleteSigningConfiguration()

Deletes the registry's signing configuration. Images pushed after deletion of the signing configuration will no longer be automatically signed.

For more information, see Managed signing in the Amazon Elastic Container Registry User Guide.

May throw ServerException. May throw SigningConfigurationNotFoundException. May throw ValidationException.

Implementation

Future<DeleteSigningConfigurationResponse>
    deleteSigningConfiguration() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.DeleteSigningConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return DeleteSigningConfigurationResponse.fromJson(jsonResponse.body);
}