deregisterPullTimeUpdateExclusion method

Future<DeregisterPullTimeUpdateExclusionResponse> deregisterPullTimeUpdateExclusion({
  1. required String principalArn,
})

Removes a principal from the pull time update exclusion list for a registry. Once removed, Amazon ECR will resume updating the pull time if the specified principal pulls an image.

May throw ExclusionNotFoundException. May throw InvalidParameterException. May throw LimitExceededException. May throw ServerException. May throw ValidationException.

Parameter principalArn : The ARN of the IAM principal to remove from the pull time update exclusion list.

Implementation

Future<DeregisterPullTimeUpdateExclusionResponse>
    deregisterPullTimeUpdateExclusion({
  required String principalArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.DeregisterPullTimeUpdateExclusion'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'principalArn': principalArn,
    },
  );

  return DeregisterPullTimeUpdateExclusionResponse.fromJson(
      jsonResponse.body);
}