describeImageReplicationStatus method

Future<DescribeImageReplicationStatusResponse> describeImageReplicationStatus({
  1. required ImageIdentifier imageId,
  2. required String repositoryName,
  3. String? registryId,
})

Returns the replication status for a specified image.

May throw ImageNotFoundException. May throw InvalidParameterException. May throw RepositoryNotFoundException. May throw ServerException. May throw ValidationException.

Parameter repositoryName : The name of the repository that the image is in.

Parameter registryId : The Amazon Web Services account ID associated with the registry. If you do not specify a registry, the default registry is assumed.

Implementation

Future<DescribeImageReplicationStatusResponse>
    describeImageReplicationStatus({
  required ImageIdentifier imageId,
  required String repositoryName,
  String? registryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.DescribeImageReplicationStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'imageId': imageId,
      'repositoryName': repositoryName,
      if (registryId != null) 'registryId': registryId,
    },
  );

  return DescribeImageReplicationStatusResponse.fromJson(jsonResponse.body);
}