describeImageSigningStatus method

Future<DescribeImageSigningStatusResponse> describeImageSigningStatus({
  1. required ImageIdentifier imageId,
  2. required String repositoryName,
  3. String? registryId,
})

Returns the signing status for a specified image. If the image matched signing rules that reference different signing profiles, a status is returned for each profile.

For more information, see Managed signing in the Amazon Elastic Container Registry User Guide.

May throw ImageNotFoundException. May throw InvalidParameterException. May throw RepositoryNotFoundException. May throw ServerException. May throw ValidationException.

Parameter imageId : An object containing identifying information for an image.

Parameter repositoryName : The name of the repository that contains the image.

Parameter registryId : The Amazon Web Services account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed.

Implementation

Future<DescribeImageSigningStatusResponse> describeImageSigningStatus({
  required ImageIdentifier imageId,
  required String repositoryName,
  String? registryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.DescribeImageSigningStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'imageId': imageId,
      'repositoryName': repositoryName,
      if (registryId != null) 'registryId': registryId,
    },
  );

  return DescribeImageSigningStatusResponse.fromJson(jsonResponse.body);
}