getAccountSetting method

Future<GetAccountSettingResponse> getAccountSetting({
  1. required String name,
})

Retrieves the account setting value for the specified setting name.

May throw InvalidParameterException. May throw ServerException. May throw ValidationException.

Parameter name : The name of the account setting, such as BASIC_SCAN_TYPE_VERSION, REGISTRY_POLICY_SCOPE, or BLOB_MOUNTING.

Implementation

Future<GetAccountSettingResponse> getAccountSetting({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonEC2ContainerRegistry_V20150921.GetAccountSetting'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'name': name,
    },
  );

  return GetAccountSettingResponse.fromJson(jsonResponse.body);
}