getSigningConfiguration method
Retrieves the registry's signing configuration, which defines rules for automatically signing images using Amazon Web Services Signer.
For more information, see Managed signing in the Amazon Elastic Container Registry User Guide.
May throw InvalidParameterException.
May throw ServerException.
May throw SigningConfigurationNotFoundException.
May throw ValidationException.
Implementation
Future<GetSigningConfigurationResponse> getSigningConfiguration() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerRegistry_V20150921.GetSigningConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetSigningConfigurationResponse.fromJson(jsonResponse.body);
}