listPullTimeUpdateExclusions method

Future<ListPullTimeUpdateExclusionsResponse> listPullTimeUpdateExclusions({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the IAM principals that are excluded from having their image pull times recorded.

May throw InvalidParameterException. May throw LimitExceededException. May throw ServerException. May throw ValidationException.

Parameter maxResults : The maximum number of pull time update exclusion results returned by ListPullTimeUpdateExclusions in paginated output. When this parameter is used, ListPullTimeUpdateExclusions only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListPullTimeUpdateExclusions request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then ListPullTimeUpdateExclusions returns up to 100 results and a nextToken value, if applicable.

Parameter nextToken : The nextToken value returned from a previous paginated ListPullTimeUpdateExclusions request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Implementation

Future<ListPullTimeUpdateExclusionsResponse> listPullTimeUpdateExclusions({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.ListPullTimeUpdateExclusions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListPullTimeUpdateExclusionsResponse.fromJson(jsonResponse.body);
}