updateRepositoryCreationTemplate method

Future<UpdateRepositoryCreationTemplateResponse> updateRepositoryCreationTemplate({
  1. required String prefix,
  2. List<RCTAppliedFor>? appliedFor,
  3. String? customRoleArn,
  4. String? description,
  5. EncryptionConfigurationForRepositoryCreationTemplate? encryptionConfiguration,
  6. ImageTagMutability? imageTagMutability,
  7. List<ImageTagMutabilityExclusionFilter>? imageTagMutabilityExclusionFilters,
  8. String? lifecyclePolicy,
  9. String? repositoryPolicy,
  10. List<Tag>? resourceTags,
})

Updates an existing repository creation template.

May throw InvalidParameterException. May throw ServerException. May throw TemplateNotFoundException. May throw ValidationException.

Parameter prefix : The repository namespace prefix that matches an existing repository creation template in the registry. All repositories created using this namespace prefix will have the settings defined in this template applied. For example, a prefix of prod would apply to all repositories beginning with prod/. This includes a repository named prod/team1 as well as a repository named prod/repository1.

To apply a template to all repositories in your registry that don't have an associated creation template, you can use ROOT as the prefix.

Parameter appliedFor : Updates the list of enumerable strings representing the Amazon ECR repository creation scenarios that this template will apply towards. The supported scenarios are PULL_THROUGH_CACHE, REPLICATION, and CREATE_ON_PUSH

Parameter customRoleArn : The ARN of the role to be assumed by Amazon ECR. This role must be in the same account as the registry that you are configuring. Amazon ECR will assume your supplied role when the customRoleArn is specified. When this field isn't specified, Amazon ECR will use the service-linked role for the repository creation template.

Parameter description : A description for the repository creation template.

Parameter imageTagMutability : Updates the tag mutability setting for the repository. If this parameter is omitted, the default setting of MUTABLE will be used which will allow image tags to be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten.

Parameter imageTagMutabilityExclusionFilters : A list of filters that specify which image tags should be excluded from the repository creation template's image tag mutability setting.

Parameter lifecyclePolicy : Updates the lifecycle policy associated with the specified repository creation template.

Parameter repositoryPolicy : Updates the repository policy created using the template. A repository policy is a permissions policy associated with a repository to control access permissions.

Parameter resourceTags : The metadata to apply to the repository to help you categorize and organize. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.

Implementation

Future<UpdateRepositoryCreationTemplateResponse>
    updateRepositoryCreationTemplate({
  required String prefix,
  List<RCTAppliedFor>? appliedFor,
  String? customRoleArn,
  String? description,
  EncryptionConfigurationForRepositoryCreationTemplate?
      encryptionConfiguration,
  ImageTagMutability? imageTagMutability,
  List<ImageTagMutabilityExclusionFilter>? imageTagMutabilityExclusionFilters,
  String? lifecyclePolicy,
  String? repositoryPolicy,
  List<Tag>? resourceTags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerRegistry_V20150921.UpdateRepositoryCreationTemplate'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'prefix': prefix,
      if (appliedFor != null)
        'appliedFor': appliedFor.map((e) => e.value).toList(),
      if (customRoleArn != null) 'customRoleArn': customRoleArn,
      if (description != null) 'description': description,
      if (encryptionConfiguration != null)
        'encryptionConfiguration': encryptionConfiguration,
      if (imageTagMutability != null)
        'imageTagMutability': imageTagMutability.value,
      if (imageTagMutabilityExclusionFilters != null)
        'imageTagMutabilityExclusionFilters':
            imageTagMutabilityExclusionFilters,
      if (lifecyclePolicy != null) 'lifecyclePolicy': lifecyclePolicy,
      if (repositoryPolicy != null) 'repositoryPolicy': repositoryPolicy,
      if (resourceTags != null) 'resourceTags': resourceTags,
    },
  );

  return UpdateRepositoryCreationTemplateResponse.fromJson(jsonResponse.body);
}