EcrPublic class

Amazon Elastic Container Registry Public (Amazon ECR Public) is a managed container image registry service. Amazon ECR provides both public and private registries to host your container images. You can use the Docker CLI or your preferred client to push, pull, and manage images. Amazon ECR provides a secure, scalable, and reliable registry for your Docker or Open Container Initiative (OCI) images. Amazon ECR supports public repositories with this API. For information about the Amazon ECR API for private repositories, see Amazon Elastic Container Registry API Reference.

Constructors

EcrPublic({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchCheckLayerAvailability({required List<String> layerDigests, required String repositoryName, String? registryId}) Future<BatchCheckLayerAvailabilityResponse>
Checks the availability of one or more image layers that are within a repository in a public registry. When an image is pushed to a repository, each image layer is checked to verify if it has been uploaded before. If it has been uploaded, then the image layer is skipped.
batchDeleteImage({required List<ImageIdentifier> imageIds, required String repositoryName, String? registryId}) Future<BatchDeleteImageResponse>
Deletes a list of specified images that are within a repository in a public registry. Images are specified with either an imageTag or imageDigest.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
completeLayerUpload({required List<String> layerDigests, required String repositoryName, required String uploadId, String? registryId}) Future<CompleteLayerUploadResponse>
Informs Amazon ECR that the image layer upload is complete for a specified public registry, repository name, and upload ID. You can optionally provide a sha256 digest of the image layer for data validation purposes.
createRepository({required String repositoryName, RepositoryCatalogDataInput? catalogData, List<Tag>? tags}) Future<CreateRepositoryResponse>
Creates a repository in a public registry. For more information, see Amazon ECR repositories in the Amazon Elastic Container Registry User Guide.
deleteRepository({required String repositoryName, bool? force, String? registryId}) Future<DeleteRepositoryResponse>
Deletes a repository in a public registry. If the repository contains images, you must either manually delete all images in the repository or use the force option. This option deletes all images on your behalf before deleting the repository.
deleteRepositoryPolicy({required String repositoryName, String? registryId}) Future<DeleteRepositoryPolicyResponse>
Deletes the repository policy that's associated with the specified repository.
describeImages({required String repositoryName, List<ImageIdentifier>? imageIds, int? maxResults, String? nextToken, String? registryId}) Future<DescribeImagesResponse>
Returns metadata that's related to the images in a repository in a public registry.
describeImageTags({required String repositoryName, int? maxResults, String? nextToken, String? registryId}) Future<DescribeImageTagsResponse>
Returns the image tag details for a repository in a public registry.
describeRegistries({int? maxResults, String? nextToken}) Future<DescribeRegistriesResponse>
Returns details for a public registry.
describeRepositories({int? maxResults, String? nextToken, String? registryId, List<String>? repositoryNames}) Future<DescribeRepositoriesResponse>
Describes repositories that are in a public registry.
getAuthorizationToken() Future<GetAuthorizationTokenResponse>
Retrieves an authorization token. An authorization token represents your IAM authentication credentials. You can use it to access any Amazon ECR registry that your IAM principal has access to. The authorization token is valid for 12 hours. This API requires the ecr-public:GetAuthorizationToken and sts:GetServiceBearerToken permissions.
getRegistryCatalogData() Future<GetRegistryCatalogDataResponse>
Retrieves catalog metadata for a public registry.
getRepositoryCatalogData({required String repositoryName, String? registryId}) Future<GetRepositoryCatalogDataResponse>
Retrieve catalog metadata for a repository in a public registry. This metadata is displayed publicly in the Amazon ECR Public Gallery.
getRepositoryPolicy({required String repositoryName, String? registryId}) Future<GetRepositoryPolicyResponse>
Retrieves the repository policy for the specified repository.
initiateLayerUpload({required String repositoryName, String? registryId}) Future<InitiateLayerUploadResponse>
Notifies Amazon ECR that you intend to upload an image layer.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List the tags for an Amazon ECR Public resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putImage({required String imageManifest, required String repositoryName, String? imageDigest, String? imageManifestMediaType, String? imageTag, String? registryId}) Future<PutImageResponse>
Creates or updates the image manifest and tags that are associated with an image.
putRegistryCatalogData({String? displayName}) Future<PutRegistryCatalogDataResponse>
Create or update the catalog data for a public registry.
putRepositoryCatalogData({required RepositoryCatalogDataInput catalogData, required String repositoryName, String? registryId}) Future<PutRepositoryCatalogDataResponse>
Creates or updates the catalog data for a repository in a public registry.
setRepositoryPolicy({required String policyText, required String repositoryName, bool? force, String? registryId}) Future<SetRepositoryPolicyResponse>
Applies a repository policy to the specified public repository to control access permissions. For more information, see Amazon ECR Repository Policies in the Amazon Elastic Container Registry User Guide.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource aren't specified in the request parameters, they aren't changed. When a resource is deleted, the tags associated with that resource are also deleted.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes specified tags from a resource.
uploadLayerPart({required Uint8List layerPartBlob, required int partFirstByte, required int partLastByte, required String repositoryName, required String uploadId, String? registryId}) Future<UploadLayerPartResponse>
Uploads an image layer part to Amazon ECR.

Operators

operator ==(Object other) bool
The equality operator.
inherited