getRepositoryCatalogData method

Future<GetRepositoryCatalogDataResponse> getRepositoryCatalogData({
  1. required String repositoryName,
  2. String? registryId,
})

Retrieve catalog metadata for a repository in a public registry. This metadata is displayed publicly in the Amazon ECR Public Gallery.

May throw InvalidParameterException. May throw RepositoryCatalogDataNotFoundException. May throw RepositoryNotFoundException. May throw ServerException. May throw UnsupportedCommandException.

Parameter repositoryName : The name of the repository to retrieve the catalog metadata for.

Parameter registryId : The Amazon Web Services account ID that's associated with the registry that contains the repositories to be described. If you do not specify a registry, the default public registry is assumed.

Implementation

Future<GetRepositoryCatalogDataResponse> getRepositoryCatalogData({
  required String repositoryName,
  String? registryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SpencerFrontendService.GetRepositoryCatalogData'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'repositoryName': repositoryName,
      if (registryId != null) 'registryId': registryId,
    },
  );

  return GetRepositoryCatalogDataResponse.fromJson(jsonResponse.body);
}