Ecs class

Amazon Elastic Container Service (Amazon ECS) is a highly scalable, fast, container management service. It makes it easy to run, stop, and manage Docker containers. You can host your cluster on a serverless infrastructure that's managed by Amazon ECS by launching your services or tasks on Fargate. For more control, you can host your tasks on a cluster of Amazon Elastic Compute Cloud (Amazon EC2) or External (on-premises) instances that you manage.

Constructors

Ecs({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
continueServiceDeployment({required String hookId, required String serviceDeploymentArn, DeploymentLifecycleHookAction? action}) Future<ContinueServiceDeploymentResponse>
Continues or rolls back an Amazon ECS service deployment that is paused at a lifecycle hook.
createCapacityProvider({required String name, AutoScalingGroupProvider? autoScalingGroupProvider, String? cluster, CreateManagedInstancesProviderConfiguration? managedInstancesProvider, List<Tag>? tags}) Future<CreateCapacityProviderResponse>
Creates a capacity provider. Capacity providers are associated with a cluster and are used in capacity provider strategies to facilitate cluster auto scaling. You can create capacity providers for Amazon ECS Managed Instances and EC2 instances. Fargate has the predefined FARGATE and FARGATE_SPOT capacity providers.
createCluster({List<String>? capacityProviders, String? clusterName, ClusterConfiguration? configuration, List<CapacityProviderStrategyItem>? defaultCapacityProviderStrategy, ClusterServiceConnectDefaultsRequest? serviceConnectDefaults, List<ClusterSetting>? settings, List<Tag>? tags}) Future<CreateClusterResponse>
Creates a new Amazon ECS cluster. By default, your account receives a default cluster when you launch your first container instance. However, you can create your own cluster with a unique name.
createDaemon({required List<String> capacityProviderArns, required String daemonName, required String daemonTaskDefinitionArn, String? clientToken, String? clusterArn, DaemonDeploymentConfiguration? deploymentConfiguration, bool? enableECSManagedTags, bool? enableExecuteCommand, DaemonPropagateTags? propagateTags, List<Tag>? tags}) Future<CreateDaemonResponse>
Creates a new daemon in the specified cluster and capacity providers. A daemon deploys cross-cutting software agents such as security monitoring, telemetry, and logging independently across your Amazon ECS infrastructure.
createExpressGatewayService({required String executionRoleArn, required String infrastructureRoleArn, required ExpressGatewayContainer primaryContainer, String? cluster, String? cpu, String? healthCheckPath, String? memory, ExpressGatewayServiceNetworkConfiguration? networkConfiguration, ExpressGatewayScalingTarget? scalingTarget, String? serviceName, List<Tag>? tags, String? taskRoleArn}) Future<CreateExpressGatewayServiceResponse>
Creates an Express service that simplifies deploying containerized web applications on Amazon ECS with managed Amazon Web Services infrastructure. This operation provisions and configures Application Load Balancers, target groups, security groups, and auto-scaling policies automatically.
createService({required String serviceName, AvailabilityZoneRebalancing? availabilityZoneRebalancing, List<CapacityProviderStrategyItem>? capacityProviderStrategy, String? clientToken, String? cluster, DeploymentConfiguration? deploymentConfiguration, DeploymentController? deploymentController, int? desiredCount, bool? enableECSManagedTags, bool? enableExecuteCommand, int? healthCheckGracePeriodSeconds, LaunchType? launchType, List<LoadBalancer>? loadBalancers, NetworkConfiguration? networkConfiguration, List<PlacementConstraint>? placementConstraints, List<PlacementStrategy>? placementStrategy, String? platformVersion, PropagateTags? propagateTags, String? role, SchedulingStrategy? schedulingStrategy, ServiceConnectConfiguration? serviceConnectConfiguration, List<ServiceRegistry>? serviceRegistries, List<Tag>? tags, String? taskDefinition, List<ServiceVolumeConfiguration>? volumeConfigurations, List<VpcLatticeConfiguration>? vpcLatticeConfigurations}) Future<CreateServiceResponse>
Runs and maintains your desired number of tasks from a specified task definition. If the number of tasks running in a service drops below the desiredCount, Amazon ECS runs another copy of the task in the specified cluster. To update an existing service, use UpdateService. In addition to maintaining the desired count of tasks in your service, you can optionally run your service behind one or more load balancers. The load balancers distribute traffic across the tasks that are associated with the service. For more information, see Service load balancing in the Amazon Elastic Container Service Developer Guide.
createTaskSet({required String cluster, required String service, required String taskDefinition, List<CapacityProviderStrategyItem>? capacityProviderStrategy, String? clientToken, String? externalId, LaunchType? launchType, List<LoadBalancer>? loadBalancers, NetworkConfiguration? networkConfiguration, String? platformVersion, Scale? scale, List<ServiceRegistry>? serviceRegistries, List<Tag>? tags}) Future<CreateTaskSetResponse>
Create a task set in the specified cluster and service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS deployment types in the Amazon Elastic Container Service Developer Guide. For information about the maximum number of task sets and other quotas, see Amazon ECS service quotas in the Amazon Elastic Container Service Developer Guide.
deleteAccountSetting({required SettingName name, String? principalArn}) Future<DeleteAccountSettingResponse>
Disables an account setting for a specified user, role, or the root user for an account.
deleteAttributes({required List<Attribute> attributes, String? cluster}) Future<DeleteAttributesResponse>
Deletes one or more custom attributes from an Amazon ECS resource.
deleteCapacityProvider({required String capacityProvider, String? cluster}) Future<DeleteCapacityProviderResponse>
Deletes the specified capacity provider. Prior to a capacity provider being deleted, the capacity provider must be removed from the capacity provider strategy from all services. The UpdateService API can be used to remove a capacity provider from a service's capacity provider strategy. When updating a service, the forceNewDeployment option can be used to ensure that any tasks using the Amazon EC2 instance capacity provided by the capacity provider are transitioned to use the capacity from the remaining capacity providers. Only capacity providers that aren't associated with a cluster can be deleted. To remove a capacity provider from a cluster, you can either use PutClusterCapacityProviders or delete the cluster.
deleteCluster({required String cluster}) Future<DeleteClusterResponse>
Deletes the specified cluster. The cluster transitions to the INACTIVE state. Clusters with an INACTIVE status might remain discoverable in your account for a period of time. However, this behavior is subject to change in the future. We don't recommend that you rely on INACTIVE clusters persisting.
deleteDaemon({required String daemonArn}) Future<DeleteDaemonResponse>
Deletes the specified daemon. The daemon must be in an ACTIVE state to be deleted. Deleting a daemon stops all running daemon tasks on the associated container instances. Amazon ECS drains existing container instances and provisions new instances without the deleted daemon. Amazon ECS automatically launches replacement tasks for your Amazon ECS services.
deleteDaemonTaskDefinition({required String daemonTaskDefinition}) Future<DeleteDaemonTaskDefinitionResponse>
Deletes the specified daemon task definition. After a daemon task definition is deleted, no new daemons can be created using this definition. Existing daemons that reference the deleted daemon task definition continue to run.
deleteExpressGatewayService({required String serviceArn}) Future<DeleteExpressGatewayServiceResponse>
Deletes an Express service and removes all associated Amazon Web Services resources. This operation stops service tasks, removes the Application Load Balancer, target groups, security groups, auto-scaling policies, and other managed infrastructure components.
deleteService({required String service, String? cluster, bool? force}) Future<DeleteServiceResponse>
Deletes a specified service within a cluster. You can delete a service if you have no running tasks in it and the desired task count is zero. If the service is actively maintaining tasks, you can't delete it, and you must update the service to a desired task count of zero. For more information, see UpdateService.
deleteTaskDefinitions({required List<String> taskDefinitions}) Future<DeleteTaskDefinitionsResponse>
Deletes one or more task definitions.
deleteTaskSet({required String cluster, required String service, required String taskSet, bool? force}) Future<DeleteTaskSetResponse>
Deletes a specified task set within a service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS deployment types in the Amazon Elastic Container Service Developer Guide.
deregisterContainerInstance({required String containerInstance, String? cluster, bool? force}) Future<DeregisterContainerInstanceResponse>
Deregisters an Amazon ECS container instance from the specified cluster. This instance is no longer available to run tasks.
deregisterTaskDefinition({required String taskDefinition}) Future<DeregisterTaskDefinitionResponse>
Deregisters the specified task definition by family and revision. Upon deregistration, the task definition is marked as INACTIVE. Existing tasks and services that reference an INACTIVE task definition continue to run without disruption. Existing services that reference an INACTIVE task definition can still scale up or down by modifying the service's desired count. If you want to delete a task definition revision, you must first deregister the task definition revision.
describeCapacityProviders({List<String>? capacityProviders, String? cluster, List<CapacityProviderField>? include, int? maxResults, String? nextToken}) Future<DescribeCapacityProvidersResponse>
Describes one or more of your capacity providers.
describeClusters({List<String>? clusters, List<ClusterField>? include}) Future<DescribeClustersResponse>
Describes one or more of your clusters.
describeContainerInstances({required List<String> containerInstances, String? cluster, List<ContainerInstanceField>? include}) Future<DescribeContainerInstancesResponse>
Describes one or more container instances. Returns metadata about each container instance requested.
describeDaemon({required String daemonArn}) Future<DescribeDaemonResponse>
Describes the specified daemon.
describeDaemonDeployments({required List<String> daemonDeploymentArns}) Future<DescribeDaemonDeploymentsResponse>
Describes one or more of your daemon deployments.
describeDaemonRevisions({required List<String> daemonRevisionArns}) Future<DescribeDaemonRevisionsResponse>
Describes one or more of your daemon revisions.
describeDaemonTaskDefinition({required String daemonTaskDefinition}) Future<DescribeDaemonTaskDefinitionResponse>
Describes a daemon task definition. You can specify a family and revision to find information about a specific daemon task definition, or you can simply specify the family to find the latest ACTIVE revision in that family.
describeExpressGatewayService({required String serviceArn, List<ExpressGatewayServiceInclude>? include}) Future<DescribeExpressGatewayServiceResponse>
Retrieves detailed information about an Express service, including current status, configuration, managed infrastructure, and service revisions.
describeServiceDeployments({required List<String> serviceDeploymentArns}) Future<DescribeServiceDeploymentsResponse>
Describes one or more of your service deployments.
describeServiceRevisions({required List<String> serviceRevisionArns}) Future<DescribeServiceRevisionsResponse>
Describes one or more service revisions.
describeServices({required List<String> services, String? cluster, List<ServiceField>? include}) Future<DescribeServicesResponse>
Describes the specified services running in your cluster.
describeTaskDefinition({required String taskDefinition, List<TaskDefinitionField>? include}) Future<DescribeTaskDefinitionResponse>
Describes a task definition. You can specify a family and revision to find information about a specific task definition, or you can simply specify the family to find the latest ACTIVE revision in that family.
describeTasks({required List<String> tasks, String? cluster, List<TaskField>? include}) Future<DescribeTasksResponse>
Describes a specified task or tasks.
describeTaskSets({required String cluster, required String service, List<TaskSetField>? include, List<String>? taskSets}) Future<DescribeTaskSetsResponse>
Describes the task sets in the specified cluster and service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.
discoverPollEndpoint({String? cluster, String? containerInstance}) Future<DiscoverPollEndpointResponse>
May throw AccessDeniedException. May throw ClientException. May throw InvalidParameterException. May throw ServerException.
executeCommand({required String command, required bool interactive, required String task, String? cluster, String? container}) Future<ExecuteCommandResponse>
Runs a command remotely on a container within a task.
getTaskProtection({required String cluster, List<String>? tasks}) Future<GetTaskProtectionResponse>
Retrieves the protection status of tasks in an Amazon ECS service.
listAccountSettings({bool? effectiveSettings, int? maxResults, SettingName? name, String? nextToken, String? principalArn, String? value}) Future<ListAccountSettingsResponse>
Lists the account settings for a specified principal.
listAttributes({required TargetType targetType, String? attributeName, String? attributeValue, String? cluster, int? maxResults, String? nextToken}) Future<ListAttributesResponse>
Lists the attributes for Amazon ECS resources within a specified target type and cluster. When you specify a target type and cluster, ListAttributes returns a list of attribute objects, one for each attribute on each resource. You can filter the list of results to a single attribute name to only return results that have that name. You can also filter the results by attribute name and value. You can do this, for example, to see which container instances in a cluster are running a Linux AMI (ecs.os-type=linux).
listClusters({int? maxResults, String? nextToken}) Future<ListClustersResponse>
Returns a list of existing clusters.
listContainerInstances({String? cluster, String? filter, int? maxResults, String? nextToken, ContainerInstanceStatus? status}) Future<ListContainerInstancesResponse>
Returns a list of container instances in a specified cluster. You can filter the results of a ListContainerInstances operation with cluster query language statements inside the filter parameter. For more information, see Cluster Query Language in the Amazon Elastic Container Service Developer Guide.
listDaemonDeployments({required String daemonArn, CreatedAt? createdAt, int? maxResults, String? nextToken, List<DaemonDeploymentStatus>? status}) Future<ListDaemonDeploymentsResponse>
Returns a list of daemon deployments for a specified daemon. You can filter the results by status or creation time.
listDaemons({List<String>? capacityProviderArns, String? clusterArn, int? maxResults, String? nextToken}) Future<ListDaemonsResponse>
Returns a list of daemons. You can filter the results by cluster or capacity provider.
listDaemonTaskDefinitions({String? family, String? familyPrefix, int? maxResults, String? nextToken, DaemonTaskDefinitionRevisionFilter? revision, SortOrder? sort, DaemonTaskDefinitionStatusFilter? status}) Future<ListDaemonTaskDefinitionsResponse>
Returns a list of daemon task definitions that are registered to your account. You can filter the results by family name, status, or both to find daemon task definitions that match your criteria.
listServiceDeployments({required String service, String? cluster, CreatedAt? createdAt, int? maxResults, String? nextToken, List<ServiceDeploymentStatus>? status}) Future<ListServiceDeploymentsResponse>
This operation lists all the service deployments that meet the specified filter criteria.
listServices({String? cluster, LaunchType? launchType, int? maxResults, String? nextToken, ResourceManagementType? resourceManagementType, SchedulingStrategy? schedulingStrategy}) Future<ListServicesResponse>
Returns a list of services. You can filter the results by cluster, launch type, and scheduling strategy.
listServicesByNamespace({required String namespace, int? maxResults, String? nextToken}) Future<ListServicesByNamespaceResponse>
This operation lists all of the services that are associated with a Cloud Map namespace. This list might include services in different clusters. In contrast, ListServices can only list services in one cluster at a time. If you need to filter the list of services in a single cluster by various parameters, use ListServices. For more information, see Service Connect in the Amazon Elastic Container Service Developer Guide.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List the tags for an Amazon ECS resource.
listTaskDefinitionFamilies({String? familyPrefix, int? maxResults, String? nextToken, TaskDefinitionFamilyStatus? status}) Future<ListTaskDefinitionFamiliesResponse>
Returns a list of task definition families that are registered to your account. This list includes task definition families that no longer have any ACTIVE task definition revisions.
listTaskDefinitions({String? familyPrefix, int? maxResults, String? nextToken, SortOrder? sort, TaskDefinitionStatus? status}) Future<ListTaskDefinitionsResponse>
Returns a list of task definitions that are registered to your account. You can filter the results by family name with the familyPrefix parameter or by status with the status parameter.
listTasks({String? cluster, String? containerInstance, String? daemonName, DesiredStatus? desiredStatus, String? family, LaunchType? launchType, int? maxResults, String? nextToken, String? serviceName, String? startedBy}) Future<ListTasksResponse>
Returns a list of tasks. You can filter the results by cluster, task definition family, container instance, launch type, what IAM principal started the task, or by the desired status of the task.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAccountSetting({required SettingName name, required String value, String? principalArn}) Future<PutAccountSettingResponse>
Modifies an account setting. Account settings are set on a per-Region basis.
putAccountSettingDefault({required SettingName name, required String value}) Future<PutAccountSettingDefaultResponse>
Modifies an account setting for all users on an account for whom no individual account setting has been specified. Account settings are set on a per-Region basis.
putAttributes({required List<Attribute> attributes, String? cluster}) Future<PutAttributesResponse>
Create or update an attribute on an Amazon ECS resource. If the attribute doesn't exist, it's created. If the attribute exists, its value is replaced with the specified value. To delete an attribute, use DeleteAttributes. For more information, see Attributes in the Amazon Elastic Container Service Developer Guide.
putClusterCapacityProviders({required List<String> capacityProviders, required String cluster, required List<CapacityProviderStrategyItem> defaultCapacityProviderStrategy}) Future<PutClusterCapacityProvidersResponse>
Modifies the available capacity providers and the default capacity provider strategy for a cluster.
registerContainerInstance({List<Attribute>? attributes, String? cluster, String? containerInstanceArn, String? instanceIdentityDocument, String? instanceIdentityDocumentSignature, List<PlatformDevice>? platformDevices, List<Tag>? tags, List<Resource>? totalResources, VersionInfo? versionInfo}) Future<RegisterContainerInstanceResponse>
May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException.
registerDaemonTaskDefinition({required List<DaemonContainerDefinition> containerDefinitions, required String family, String? cpu, String? executionRoleArn, String? memory, List<Tag>? tags, String? taskRoleArn, List<DaemonVolume>? volumes}) Future<RegisterDaemonTaskDefinitionResponse>
Registers a new daemon task definition from the supplied family and containerDefinitions. Optionally, you can add data volumes to your containers with the volumes parameter. For more information, see Daemon task definitions in the Amazon Elastic Container Service Developer Guide.
registerTaskDefinition({required List<ContainerDefinition> containerDefinitions, required String family, String? cpu, bool? enableFaultInjection, EphemeralStorage? ephemeralStorage, String? executionRoleArn, List<InferenceAccelerator>? inferenceAccelerators, IpcMode? ipcMode, String? memory, NetworkMode? networkMode, PidMode? pidMode, List<TaskDefinitionPlacementConstraint>? placementConstraints, ProxyConfiguration? proxyConfiguration, List<Compatibility>? requiresCompatibilities, RuntimePlatform? runtimePlatform, List<Tag>? tags, String? taskRoleArn, List<Volume>? volumes}) Future<RegisterTaskDefinitionResponse>
Registers a new task definition from the supplied family and containerDefinitions. Optionally, you can add data volumes to your containers with the volumes parameter. For more information about task definition parameters and defaults, see Amazon ECS Task Definitions in the Amazon Elastic Container Service Developer Guide.
runTask({required String taskDefinition, List<CapacityProviderStrategyItem>? capacityProviderStrategy, String? clientToken, String? cluster, int? count, bool? enableECSManagedTags, bool? enableExecuteCommand, String? group, LaunchType? launchType, NetworkConfiguration? networkConfiguration, TaskOverride? overrides, List<PlacementConstraint>? placementConstraints, List<PlacementStrategy>? placementStrategy, String? platformVersion, PropagateTags? propagateTags, String? referenceId, String? startedBy, List<Tag>? tags, List<TaskVolumeConfiguration>? volumeConfigurations}) Future<RunTaskResponse>
Starts a new task using the specified task definition. You can allow Amazon ECS to place tasks for you, or you can customize how Amazon ECS places tasks using placement constraints and placement strategies. For more information, see Scheduling Tasks in the Amazon Elastic Container Service Developer Guide.
startTask({required List<String> containerInstances, required String taskDefinition, String? cluster, bool? enableECSManagedTags, bool? enableExecuteCommand, String? group, NetworkConfiguration? networkConfiguration, TaskOverride? overrides, PropagateTags? propagateTags, String? referenceId, String? startedBy, List<Tag>? tags, List<TaskVolumeConfiguration>? volumeConfigurations}) Future<StartTaskResponse>
Starts a new task from the specified task definition on the specified container instance or instances. Alternatively, you can useRunTask to place tasks for you. For more information, see Scheduling Tasks in the Amazon Elastic Container Service Developer Guide.
stopServiceDeployment({required String serviceDeploymentArn, StopServiceDeploymentStopType? stopType}) Future<StopServiceDeploymentResponse>
Stops an ongoing service deployment.
stopTask({required String task, String? cluster, String? reason}) Future<StopTaskResponse>
Stops a running task. Any tags associated with the task will be deleted.
submitAttachmentStateChanges({required List<AttachmentStateChange> attachments, String? cluster}) Future<SubmitAttachmentStateChangesResponse>
May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException.
submitContainerStateChange({String? cluster, String? containerName, int? exitCode, List<NetworkBinding>? networkBindings, String? reason, String? runtimeId, String? status, String? task}) Future<SubmitContainerStateChangeResponse>
May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException.
submitTaskStateChange({List<AttachmentStateChange>? attachments, String? cluster, List<ContainerStateChange>? containers, DateTime? executionStoppedAt, List<ManagedAgentStateChange>? managedAgents, DateTime? pullStartedAt, DateTime? pullStoppedAt, String? reason, String? status, String? task}) Future<SubmitTaskStateChangeResponse>
May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource aren't specified in the request parameters, they aren't changed. When a resource is deleted, the tags that are associated with that resource are deleted as well.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes specified tags from a resource.
updateCapacityProvider({required String name, AutoScalingGroupProviderUpdate? autoScalingGroupProvider, String? cluster, UpdateManagedInstancesProviderConfiguration? managedInstancesProvider}) Future<UpdateCapacityProviderResponse>
Modifies the parameters for a capacity provider.
updateCluster({required String cluster, ClusterConfiguration? configuration, ClusterServiceConnectDefaultsRequest? serviceConnectDefaults, List<ClusterSetting>? settings}) Future<UpdateClusterResponse>
Updates the cluster.
updateClusterSettings({required String cluster, required List<ClusterSetting> settings}) Future<UpdateClusterSettingsResponse>
Modifies the settings to use for a cluster.
updateContainerAgent({required String containerInstance, String? cluster}) Future<UpdateContainerAgentResponse>
Updates the Amazon ECS container agent on a specified container instance. Updating the Amazon ECS container agent doesn't interrupt running tasks or services on the container instance. The process for updating the agent differs depending on whether your container instance was launched with the Amazon ECS-optimized AMI or another operating system. The UpdateContainerAgent API requires an Amazon ECS-optimized AMI or Amazon Linux AMI with the ecs-init service installed and running. For help updating the Amazon ECS container agent on other operating systems, see Manually updating the Amazon ECS container agent in the Amazon Elastic Container Service Developer Guide.
updateContainerInstancesState({required List<String> containerInstances, required ContainerInstanceStatus status, String? cluster}) Future<UpdateContainerInstancesStateResponse>
Modifies the status of an Amazon ECS container instance.
updateDaemon({required List<String> capacityProviderArns, required String daemonArn, required String daemonTaskDefinitionArn, DaemonDeploymentConfiguration? deploymentConfiguration, bool? enableECSManagedTags, bool? enableExecuteCommand, DaemonPropagateTags? propagateTags}) Future<UpdateDaemonResponse>
Updates the specified daemon. When you update a daemon, a new deployment is triggered that progressively rolls out the changes to the container instances associated with the daemon's capacity providers. For more information, see Daemon deployments in the Amazon Elastic Container Service Developer Guide.
updateExpressGatewayService({required String serviceArn, String? cpu, String? executionRoleArn, String? healthCheckPath, String? memory, ExpressGatewayServiceNetworkConfiguration? networkConfiguration, ExpressGatewayContainer? primaryContainer, ExpressGatewayScalingTarget? scalingTarget, String? taskRoleArn}) Future<UpdateExpressGatewayServiceResponse>
Updates an existing Express service configuration. Modifies container settings, resource allocation, auto-scaling configuration, and other service parameters without recreating the service.
updateService({required String service, AvailabilityZoneRebalancing? availabilityZoneRebalancing, List<CapacityProviderStrategyItem>? capacityProviderStrategy, String? cluster, DeploymentConfiguration? deploymentConfiguration, DeploymentController? deploymentController, int? desiredCount, bool? enableECSManagedTags, bool? enableExecuteCommand, bool? forceNewDeployment, int? healthCheckGracePeriodSeconds, List<LoadBalancer>? loadBalancers, NetworkConfiguration? networkConfiguration, List<PlacementConstraint>? placementConstraints, List<PlacementStrategy>? placementStrategy, String? platformVersion, PropagateTags? propagateTags, ServiceConnectConfiguration? serviceConnectConfiguration, List<ServiceRegistry>? serviceRegistries, String? taskDefinition, List<ServiceVolumeConfiguration>? volumeConfigurations, List<VpcLatticeConfiguration>? vpcLatticeConfigurations}) Future<UpdateServiceResponse>
Modifies the parameters of a service. For services using the rolling update (ECS) you can update the desired count, deployment configuration, network configuration, load balancers, service registries, enable ECS managed tags option, propagate tags option, task placement constraints and strategies, and task definition. When you update any of these parameters, Amazon ECS starts new tasks with the new configuration.
updateServicePrimaryTaskSet({required String cluster, required String primaryTaskSet, required String service}) Future<UpdateServicePrimaryTaskSetResponse>
Modifies which task set in a service is the primary task set. Any parameters that are updated on the primary task set in a service will transition to the service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.
updateTaskProtection({required String cluster, required bool protectionEnabled, required List<String> tasks, int? expiresInMinutes}) Future<UpdateTaskProtectionResponse>
Updates the protection status of a task. You can set protectionEnabled to true to protect your task from termination during scale-in events from Service Autoscaling or deployments.
updateTaskSet({required String cluster, required Scale scale, required String service, required String taskSet}) Future<UpdateTaskSetResponse>
Modifies a task set. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

Operators

operator ==(Object other) bool
The equality operator.
inherited