createCapacityProvider method

Future<CreateCapacityProviderResponse> createCapacityProvider({
  1. required String name,
  2. AutoScalingGroupProvider? autoScalingGroupProvider,
  3. String? cluster,
  4. CreateManagedInstancesProviderConfiguration? managedInstancesProvider,
  5. List<Tag>? tags,
})

Creates a capacity provider. Capacity providers are associated with a cluster and are used in capacity provider strategies to facilitate cluster auto scaling. You can create capacity providers for Amazon ECS Managed Instances and EC2 instances. Fargate has the predefined FARGATE and FARGATE_SPOT capacity providers.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw LimitExceededException. May throw ServerException. May throw UnsupportedFeatureException. May throw UpdateInProgressException.

Parameter name : The name of the capacity provider. Up to 255 characters are allowed. They include letters (both upper and lowercase letters), numbers, underscores (_), and hyphens (-). The name can't be prefixed with "aws", "ecs", or "fargate".

Parameter autoScalingGroupProvider : The details of the Auto Scaling group for the capacity provider.

Parameter cluster : The name of the cluster to associate with the capacity provider. When you create a capacity provider with Amazon ECS Managed Instances, it becomes available only within the specified cluster.

Parameter managedInstancesProvider : The configuration for the Amazon ECS Managed Instances provider. This configuration specifies how Amazon ECS manages Amazon EC2 instances on your behalf, including the infrastructure role, instance launch template, and tag propagation settings.

Parameter tags : The metadata that you apply to the capacity provider to categorize and organize them more conveniently. Each tag consists of a key and an optional value. You define both of them.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50
  • For each resource, each tag key must be unique, and each tag key can have only one value.
  • Maximum key length - 128 Unicode characters in UTF-8
  • Maximum value length - 256 Unicode characters in UTF-8
  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
  • Tag keys and values are case-sensitive.
  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.

Implementation

Future<CreateCapacityProviderResponse> createCapacityProvider({
  required String name,
  AutoScalingGroupProvider? autoScalingGroupProvider,
  String? cluster,
  CreateManagedInstancesProviderConfiguration? managedInstancesProvider,
  List<Tag>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.CreateCapacityProvider'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'name': name,
      if (autoScalingGroupProvider != null)
        'autoScalingGroupProvider': autoScalingGroupProvider,
      if (cluster != null) 'cluster': cluster,
      if (managedInstancesProvider != null)
        'managedInstancesProvider': managedInstancesProvider,
      if (tags != null) 'tags': tags,
    },
  );

  return CreateCapacityProviderResponse.fromJson(jsonResponse.body);
}