createTaskSet method

Future<CreateTaskSetResponse> createTaskSet({
  1. required String cluster,
  2. required String service,
  3. required String taskDefinition,
  4. List<CapacityProviderStrategyItem>? capacityProviderStrategy,
  5. String? clientToken,
  6. String? externalId,
  7. LaunchType? launchType,
  8. List<LoadBalancer>? loadBalancers,
  9. NetworkConfiguration? networkConfiguration,
  10. String? platformVersion,
  11. Scale? scale,
  12. List<ServiceRegistry>? serviceRegistries,
  13. List<Tag>? tags,
})

Create a task set in the specified cluster and service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS deployment types in the Amazon Elastic Container Service Developer Guide. For information about the maximum number of task sets and other quotas, see Amazon ECS service quotas in the Amazon Elastic Container Service Developer Guide.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw LimitExceededException. May throw NamespaceNotFoundException. May throw PlatformTaskDefinitionIncompatibilityException. May throw PlatformUnknownException. May throw ServerException. May throw ServiceNotActiveException. May throw ServiceNotFoundException. May throw UnsupportedFeatureException.

Parameter cluster : The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.

Parameter service : The short name or full Amazon Resource Name (ARN) of the service to create the task set in.

Parameter taskDefinition : The task definition for the tasks in the task set to use. If a revision isn't specified, the latest ACTIVE revision is used.

Parameter capacityProviderStrategy : The capacity provider strategy to use for the task set.

A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used.

If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used.

If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProviderProviderAPI operation.

To use a Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.

The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created.

Parameter clientToken : An identifier that you provide to ensure the idempotency of the request. It must be unique and is case sensitive. Up to 36 ASCII characters in the range of 33-126 (inclusive) are allowed.

Parameter externalId : An optional non-unique tag that identifies this task set in external systems. If the task set is associated with a service discovery registry, the tasks in this task set will have the ECS_TASK_SET_EXTERNAL_ID Cloud Map attribute set to the provided value.

Parameter launchType : The launch type that new tasks in the task set uses. For more information, see Amazon ECS launch types in the Amazon Elastic Container Service Developer Guide.

If a launchType is specified, the capacityProviderStrategy parameter must be omitted.

Parameter loadBalancers : A load balancer object representing the load balancer to use with the task set. The supported load balancer types are either an Application Load Balancer or a Network Load Balancer.

Parameter networkConfiguration : An object representing the network configuration for a task set.

Parameter platformVersion : The platform version that the tasks in the task set uses. A platform version is specified only for tasks using the Fargate launch type. If one isn't specified, the LATEST platform version is used.

Parameter scale : A floating-point percentage of the desired number of tasks to place and keep running in the task set.

Parameter serviceRegistries : The details of the service discovery registries to assign to this task set. For more information, see Service discovery.

Parameter tags : The metadata that you apply to the task set to help you categorize and organize them. Each tag consists of a key and an optional value. You define both. When a service is deleted, the tags are deleted.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50
  • For each resource, each tag key must be unique, and each tag key can have only one value.
  • Maximum key length - 128 Unicode characters in UTF-8
  • Maximum value length - 256 Unicode characters in UTF-8
  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
  • Tag keys and values are case-sensitive.
  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.

Implementation

Future<CreateTaskSetResponse> createTaskSet({
  required String cluster,
  required String service,
  required String taskDefinition,
  List<CapacityProviderStrategyItem>? capacityProviderStrategy,
  String? clientToken,
  String? externalId,
  LaunchType? launchType,
  List<LoadBalancer>? loadBalancers,
  NetworkConfiguration? networkConfiguration,
  String? platformVersion,
  Scale? scale,
  List<ServiceRegistry>? serviceRegistries,
  List<Tag>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.CreateTaskSet'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'cluster': cluster,
      'service': service,
      'taskDefinition': taskDefinition,
      if (capacityProviderStrategy != null)
        'capacityProviderStrategy': capacityProviderStrategy,
      if (clientToken != null) 'clientToken': clientToken,
      if (externalId != null) 'externalId': externalId,
      if (launchType != null) 'launchType': launchType.value,
      if (loadBalancers != null) 'loadBalancers': loadBalancers,
      if (networkConfiguration != null)
        'networkConfiguration': networkConfiguration,
      if (platformVersion != null) 'platformVersion': platformVersion,
      if (scale != null) 'scale': scale,
      if (serviceRegistries != null) 'serviceRegistries': serviceRegistries,
      if (tags != null) 'tags': tags,
    },
  );

  return CreateTaskSetResponse.fromJson(jsonResponse.body);
}