deleteDaemon method

Future<DeleteDaemonResponse> deleteDaemon({
  1. required String daemonArn,
})

Deletes the specified daemon. The daemon must be in an ACTIVE state to be deleted. Deleting a daemon stops all running daemon tasks on the associated container instances. Amazon ECS drains existing container instances and provisions new instances without the deleted daemon. Amazon ECS automatically launches replacement tasks for your Amazon ECS services.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw DaemonNotActiveException. May throw DaemonNotFoundException. May throw InvalidParameterException. May throw ServerException. May throw UnsupportedFeatureException.

Parameter daemonArn : The Amazon Resource Name (ARN) of the daemon to delete.

Implementation

Future<DeleteDaemonResponse> deleteDaemon({
  required String daemonArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.DeleteDaemon'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'daemonArn': daemonArn,
    },
  );

  return DeleteDaemonResponse.fromJson(jsonResponse.body);
}