describeDaemonDeployments method

Future<DescribeDaemonDeploymentsResponse> describeDaemonDeployments({
  1. required List<String> daemonDeploymentArns,
})

Describes one or more of your daemon deployments.

A daemon deployment orchestrates the progressive rollout of daemon task updates across container instances managed by the daemon's capacity providers. Each deployment includes circuit breaker and alarm-based rollback capabilities.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException. May throw UnsupportedFeatureException.

Parameter daemonDeploymentArns : The ARN of the daemon deployments to describe. You can specify up to 20 ARNs.

Implementation

Future<DescribeDaemonDeploymentsResponse> describeDaemonDeployments({
  required List<String> daemonDeploymentArns,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.DescribeDaemonDeployments'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'daemonDeploymentArns': daemonDeploymentArns,
    },
  );

  return DescribeDaemonDeploymentsResponse.fromJson(jsonResponse.body);
}