describeDaemonTaskDefinition method

Future<DescribeDaemonTaskDefinitionResponse> describeDaemonTaskDefinition({
  1. required String daemonTaskDefinition,
})

Describes a daemon task definition. You can specify a family and revision to find information about a specific daemon task definition, or you can simply specify the family to find the latest ACTIVE revision in that family.

May throw AccessDeniedException. May throw ClientException. May throw InvalidParameterException. May throw ServerException.

Parameter daemonTaskDefinition : The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the daemon task definition to describe.

Implementation

Future<DescribeDaemonTaskDefinitionResponse> describeDaemonTaskDefinition({
  required String daemonTaskDefinition,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.DescribeDaemonTaskDefinition'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'daemonTaskDefinition': daemonTaskDefinition,
    },
  );

  return DescribeDaemonTaskDefinitionResponse.fromJson(jsonResponse.body);
}