describeExpressGatewayService method

Future<DescribeExpressGatewayServiceResponse> describeExpressGatewayService({
  1. required String serviceArn,
  2. List<ExpressGatewayServiceInclude>? include,
})

Retrieves detailed information about an Express service, including current status, configuration, managed infrastructure, and service revisions.

Returns comprehensive service details, active service revisions, ingress paths with endpoints, and managed Amazon Web Services resource status including load balancers and auto-scaling policies.

Use the include parameter to retrieve additional information such as resource tags.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServerException. May throw UnsupportedFeatureException.

Parameter serviceArn : The Amazon Resource Name (ARN) of the Express service to describe. The ARN uniquely identifies the service within your Amazon Web Services account and region.

Parameter include : Specifies additional information to include in the response. Valid values are TAGS to include resource tags associated with the Express service.

Implementation

Future<DescribeExpressGatewayServiceResponse> describeExpressGatewayService({
  required String serviceArn,
  List<ExpressGatewayServiceInclude>? include,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.DescribeExpressGatewayService'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceArn': serviceArn,
      if (include != null) 'include': include.map((e) => e.value).toList(),
    },
  );

  return DescribeExpressGatewayServiceResponse.fromJson(jsonResponse.body);
}