describeServiceDeployments method

Future<DescribeServiceDeploymentsResponse> describeServiceDeployments({
  1. required List<String> serviceDeploymentArns,
})

Describes one or more of your service deployments.

A service deployment happens when you release a software update for the service. For more information, see View service history using Amazon ECS service deployments.

May throw AccessDeniedException. May throw ClientException. May throw ClusterNotFoundException. May throw InvalidParameterException. May throw ServerException. May throw ServiceNotFoundException. May throw UnsupportedFeatureException.

Parameter serviceDeploymentArns : The ARN of the service deployment.

You can specify a maximum of 20 ARNs.

Implementation

Future<DescribeServiceDeploymentsResponse> describeServiceDeployments({
  required List<String> serviceDeploymentArns,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.DescribeServiceDeployments'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceDeploymentArns': serviceDeploymentArns,
    },
  );

  return DescribeServiceDeploymentsResponse.fromJson(jsonResponse.body);
}