describeServiceRevisions method
Describes one or more service revisions.
A service revision is a version of the service that includes the values for the Amazon ECS resources (for example, task definition) and the environment resources (for example, load balancers, subnets, and security groups). For more information, see Amazon ECS service revisions.
You can't describe a service revision that was created before October 25, 2024.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ServerException.
May throw ServiceNotFoundException.
May throw UnsupportedFeatureException.
Parameter serviceRevisionArns :
The ARN of the service revision.
You can specify a maximum of 20 ARNs.
You can call ListServiceDeployments to get the ARNs.
Implementation
Future<DescribeServiceRevisionsResponse> describeServiceRevisions({
required List<String> serviceRevisionArns,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.DescribeServiceRevisions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'serviceRevisionArns': serviceRevisionArns,
},
);
return DescribeServiceRevisionsResponse.fromJson(jsonResponse.body);
}