listContainerInstances method
Returns a list of container instances in a specified cluster. You can
filter the results of a ListContainerInstances operation with
cluster query language statements inside the filter
parameter. For more information, see Cluster
Query Language in the Amazon Elastic Container Service Developer
Guide.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ServerException.
Parameter cluster :
The short name or full Amazon Resource Name (ARN) of the cluster that
hosts the container instances to list. If you do not specify a cluster,
the default cluster is assumed.
Parameter filter :
You can filter the results of a ListContainerInstances
operation with cluster query language statements. For more information,
see Cluster
Query Language in the Amazon Elastic Container Service Developer
Guide.
Parameter maxResults :
The maximum number of container instance results that
ListContainerInstances returned in paginated output. When
this parameter is used, ListContainerInstances only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListContainerInstances request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListContainerInstances returns up
to 100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a
ListContainerInstances request indicating that more results
are available to fulfill the request and further calls are needed. If
maxResults was provided, it's possible the number of results
to be fewer than maxResults.
Parameter status :
Filters the container instances by status. For example, if you specify the
DRAINING status, the results include only container instances
that have been set to DRAINING using UpdateContainerInstancesState.
If you don't specify this parameter, the The default is to include
container instances set to all states other than INACTIVE.
Implementation
Future<ListContainerInstancesResponse> listContainerInstances({
String? cluster,
String? filter,
int? maxResults,
String? nextToken,
ContainerInstanceStatus? status,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.ListContainerInstances'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (cluster != null) 'cluster': cluster,
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (status != null) 'status': status.value,
},
);
return ListContainerInstancesResponse.fromJson(jsonResponse.body);
}