listDaemonTaskDefinitions method

Future<ListDaemonTaskDefinitionsResponse> listDaemonTaskDefinitions({
  1. String? family,
  2. String? familyPrefix,
  3. int? maxResults,
  4. String? nextToken,
  5. DaemonTaskDefinitionRevisionFilter? revision,
  6. SortOrder? sort,
  7. DaemonTaskDefinitionStatusFilter? status,
})

Returns a list of daemon task definitions that are registered to your account. You can filter the results by family name, status, or both to find daemon task definitions that match your criteria.

May throw AccessDeniedException. May throw ClientException. May throw InvalidParameterException. May throw ServerException.

Parameter family : The exact name of the daemon task definition family to filter results with.

Parameter familyPrefix : The full family name to filter the ListDaemonTaskDefinitions results with. Specifying a familyPrefix limits the listed daemon task definitions to daemon task definition families that start with the familyPrefix string.

Parameter maxResults : The maximum number of daemon task definition results that ListDaemonTaskDefinitions returned in paginated output. When this parameter is used, ListDaemonTaskDefinitions only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListDaemonTaskDefinitions request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then ListDaemonTaskDefinitions returns up to 100 results and a nextToken value if applicable.

Parameter nextToken : The nextToken value returned from a ListDaemonTaskDefinitions request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it's possible for the number of results to be fewer than maxResults.

Parameter revision : The revision filter to apply. Specify LAST_REGISTERED to return only the last registered revision for each daemon task definition family.

Parameter sort : The order to sort the results. Valid values are ASC and DESC. By default (ASC), daemon task definitions are listed in ascending order by family name and revision number.

Parameter status : The daemon task definition status to filter the ListDaemonTaskDefinitions results with. By default, only ACTIVE daemon task definitions are listed. If you set this parameter to DELETE_IN_PROGRESS, only daemon task definitions that are in the process of being deleted are listed. If you set this parameter to ALL, all daemon task definitions are listed regardless of status.

Implementation

Future<ListDaemonTaskDefinitionsResponse> listDaemonTaskDefinitions({
  String? family,
  String? familyPrefix,
  int? maxResults,
  String? nextToken,
  DaemonTaskDefinitionRevisionFilter? revision,
  SortOrder? sort,
  DaemonTaskDefinitionStatusFilter? status,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AmazonEC2ContainerServiceV20141113.ListDaemonTaskDefinitions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (family != null) 'family': family,
      if (familyPrefix != null) 'familyPrefix': familyPrefix,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
      if (revision != null) 'revision': revision.value,
      if (sort != null) 'sort': sort.value,
      if (status != null) 'status': status.value,
    },
  );

  return ListDaemonTaskDefinitionsResponse.fromJson(jsonResponse.body);
}