listTaskDefinitionFamilies method
Returns a list of task definition families that are registered to your
account. This list includes task definition families that no longer have
any ACTIVE task definition revisions.
You can filter out task definition families that don't contain any
ACTIVE task definition revisions by setting the
status parameter to ACTIVE. You can also filter
the results with the familyPrefix parameter.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw ServerException.
Parameter familyPrefix :
The familyPrefix is a string that's used to filter the
results of ListTaskDefinitionFamilies. If you specify a
familyPrefix, only task definition family names that begin
with the familyPrefix string are returned.
Parameter maxResults :
The maximum number of task definition family results that
ListTaskDefinitionFamilies returned in paginated output. When
this parameter is used, ListTaskDefinitions only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListTaskDefinitionFamilies request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListTaskDefinitionFamilies returns
up to 100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a
ListTaskDefinitionFamilies request indicating that more
results are available to fulfill the request and further calls will be
needed. If maxResults was provided, it is possible the number
of results to be fewer than maxResults.
Parameter status :
The task definition family status to filter the
ListTaskDefinitionFamilies results with. By default, both
ACTIVE and INACTIVE task definition families are
listed. If this parameter is set to ACTIVE, only task
definition families that have an ACTIVE task definition
revision are returned. If this parameter is set to INACTIVE,
only task definition families that do not have any ACTIVE
task definition revisions are returned. If you paginate the resulting
output, be sure to keep the status value constant in each
subsequent request.
Implementation
Future<ListTaskDefinitionFamiliesResponse> listTaskDefinitionFamilies({
String? familyPrefix,
int? maxResults,
String? nextToken,
TaskDefinitionFamilyStatus? status,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.ListTaskDefinitionFamilies'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (familyPrefix != null) 'familyPrefix': familyPrefix,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (status != null) 'status': status.value,
},
);
return ListTaskDefinitionFamiliesResponse.fromJson(jsonResponse.body);
}