listTaskDefinitions method
Returns a list of task definitions that are registered to your account.
You can filter the results by family name with the
familyPrefix parameter or by status with the
status parameter.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw ServerException.
Parameter familyPrefix :
The full family name to filter the ListTaskDefinitions
results with. Specifying a familyPrefix limits the listed
task definitions to task definition revisions that belong to that family.
Parameter maxResults :
The maximum number of task definition results that
ListTaskDefinitions returned in paginated output. When this
parameter is used, ListTaskDefinitions only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListTaskDefinitions request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListTaskDefinitions returns up to
100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a
ListTaskDefinitions request indicating that more results are
available to fulfill the request and further calls will be needed. If
maxResults was provided, it is possible the number of results
to be fewer than maxResults.
Parameter sort :
The order to sort the results in. Valid values are ASC and
DESC. By default, (ASC) task definitions are
listed lexicographically by family name and in ascending numerical order
by revision so that the newest task definitions in a family are listed
last. Setting this parameter to DESC reverses the sort order
on family name and revision. This is so that the newest task definitions
in a family are listed first.
Parameter status :
The task definition status to filter the ListTaskDefinitions
results with. By default, only ACTIVE task definitions are
listed. By setting this parameter to INACTIVE, you can view
task definitions that are INACTIVE as long as an active task
or service still references them. If you paginate the resulting output, be
sure to keep the status value constant in each subsequent
request.
Implementation
Future<ListTaskDefinitionsResponse> listTaskDefinitions({
String? familyPrefix,
int? maxResults,
String? nextToken,
SortOrder? sort,
TaskDefinitionStatus? status,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.ListTaskDefinitions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (familyPrefix != null) 'familyPrefix': familyPrefix,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (sort != null) 'sort': sort.value,
if (status != null) 'status': status.value,
},
);
return ListTaskDefinitionsResponse.fromJson(jsonResponse.body);
}