putAccountSetting method
Modifies an account setting. Account settings are set on a per-Region basis.
If you change the root user account setting, the default settings are reset for users and roles that do not have specified individual account settings. For more information, see Account Settings in the Amazon Elastic Container Service Developer Guide.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw ServerException.
Parameter name :
The Amazon ECS account setting name to modify.
The following are the valid values for the account setting name.
-
serviceLongArnFormat- When modified, the Amazon Resource Name (ARN) and resource ID format of the resource type for a specified user, role, or the root user for an account is affected. The opt-in and opt-out account setting must be set for each Amazon ECS resource separately. The ARN and resource ID format of a resource is defined by the opt-in status of the user or role that created the resource. You must turn on this setting to use Amazon ECS features such as resource tagging. -
taskLongArnFormat- When modified, the Amazon Resource Name (ARN) and resource ID format of the resource type for a specified user, role, or the root user for an account is affected. The opt-in and opt-out account setting must be set for each Amazon ECS resource separately. The ARN and resource ID format of a resource is defined by the opt-in status of the user or role that created the resource. You must turn on this setting to use Amazon ECS features such as resource tagging. -
containerInstanceLongArnFormat- When modified, the Amazon Resource Name (ARN) and resource ID format of the resource type for a specified user, role, or the root user for an account is affected. The opt-in and opt-out account setting must be set for each Amazon ECS resource separately. The ARN and resource ID format of a resource is defined by the opt-in status of the user or role that created the resource. You must turn on this setting to use Amazon ECS features such as resource tagging. -
awsvpcTrunking- When modified, the elastic network interface (ENI) limit for any new container instances that support the feature is changed. IfawsvpcTrunkingis turned on, any new container instances that support the feature are launched have the increased ENI limits available to them. For more information, see Elastic Network Interface Trunking in the Amazon Elastic Container Service Developer Guide. -
containerInsights- Container Insights with enhanced observability provides all the Container Insights metrics, plus additional task and container metrics. This version supports enhanced observability for Amazon ECS clusters using the Amazon EC2 and Fargate launch types. After you configure Container Insights with enhanced observability on Amazon ECS, Container Insights auto-collects detailed infrastructure telemetry from the cluster level down to the container level in your environment and displays these critical performance data in curated dashboards removing the heavy lifting in observability set-up.To use Container Insights with enhanced observability, set the
containerInsightsaccount setting toenhanced.To use Container Insights, set the
containerInsightsaccount setting toenabled.For more information, see Monitor Amazon ECS containers using Container Insights with enhanced observability in the Amazon Elastic Container Service Developer Guide.
-
dualStackIPv6- When turned on, when using a VPC in dual stack mode, your tasks using theawsvpcnetwork mode can have an IPv6 address assigned. For more information on using IPv6 with tasks launched on Amazon EC2 instances, see Using a VPC in dual-stack mode. For more information on using IPv6 with tasks launched on Fargate, see Using a VPC in dual-stack mode. -
fargateTaskRetirementWaitPeriod- When Amazon Web Services determines that a security or infrastructure update is needed for an Amazon ECS task hosted on Fargate, the tasks need to be stopped and new tasks launched to replace them. UsefargateTaskRetirementWaitPeriodto configure the wait time to retire a Fargate task. For information about the Fargate tasks maintenance, see Amazon Web Services Fargate task maintenance in the Amazon ECS Developer Guide. -
fargateEventWindows- When Amazon Web Services determines that a security or infrastructure update is needed for an Amazon ECS task hosted on Fargate, the tasks need to be stopped and new tasks launched to replace them. UsefargateEventWindowsto use EC2 Event Windows associated with Fargate tasks to configure time windows for task retirement. -
tagResourceAuthorization- Amazon ECS is introducing tagging authorization for resource creation. Users must have permissions for actions that create the resource, such asecsCreateCluster. If tags are specified when you create a resource, Amazon Web Services performs additional authorization to verify if users or roles have permissions to create tags. Therefore, you must grant explicit permissions to use theecs:TagResourceaction. For more information, see Grant permission to tag resources on creation in the Amazon ECS Developer Guide. -
defaultLogDriverMode- Amazon ECS supports setting a default delivery mode of log messages from a container to thelogDriverthat you specify in the container'slogConfiguration. The delivery mode affects application stability when the flow of logs from the container to the log driver is interrupted. ThedefaultLogDriverModesetting supports two values:blockingandnon-blocking. If you don't specify a delivery mode in your container definition'slogConfiguration, the mode you specify using this account setting will be used as the default. For more information about log delivery modes, see LogConfiguration. -
guardDutyActivate- TheguardDutyActivateparameter is read-only in Amazon ECS and indicates whether Amazon ECS Runtime Monitoring is enabled or disabled by your security administrator in your Amazon ECS account. Amazon GuardDuty controls this account setting on your behalf. For more information, see Protecting Amazon ECS workloads with Amazon ECS Runtime Monitoring.
Parameter value :
The account setting value for the specified principal ARN. Accepted values
are enabled, disabled, enhanced,
on, and off.
When you specify fargateTaskRetirementWaitPeriod for the
name, the following are the valid values:
-
0- Amazon Web Services sends the notification, and immediately retires the affected tasks. -
7- Amazon Web Services sends the notification, and waits 7 calendar days to retire the tasks. -
14- Amazon Web Services sends the notification, and waits 14 calendar days to retire the tasks.
Parameter principalArn :
The ARN of the principal, which can be a user, role, or the root user. If
you specify the root user, it modifies the account setting for all users,
roles, and the root user of the account unless a user or role explicitly
overrides these settings. If this field is omitted, the setting is changed
only for the authenticated user.
In order to use this parameter, you must be the root user, or the principal.
Federated users assume the account setting of the root user and can't have explicit account settings set for them.
Implementation
Future<PutAccountSettingResponse> putAccountSetting({
required SettingName name,
required String value,
String? principalArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.PutAccountSetting'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'name': name.value,
'value': value,
if (principalArn != null) 'principalArn': principalArn,
},
);
return PutAccountSettingResponse.fromJson(jsonResponse.body);
}