runTask method
- required String taskDefinition,
- List<
CapacityProviderStrategyItem> ? capacityProviderStrategy, - String? clientToken,
- String? cluster,
- int? count,
- bool? enableECSManagedTags,
- bool? enableExecuteCommand,
- String? group,
- LaunchType? launchType,
- NetworkConfiguration? networkConfiguration,
- TaskOverride? overrides,
- List<
PlacementConstraint> ? placementConstraints, - List<
PlacementStrategy> ? placementStrategy, - String? platformVersion,
- PropagateTags? propagateTags,
- String? referenceId,
- String? startedBy,
- List<
Tag> ? tags, - List<
TaskVolumeConfiguration> ? volumeConfigurations,
Starts a new task using the specified task definition. You can allow Amazon ECS to place tasks for you, or you can customize how Amazon ECS places tasks using placement constraints and placement strategies. For more information, see Scheduling Tasks in the Amazon Elastic Container Service Developer Guide.
Alternatively, you can use StartTask to use your own
scheduler or place tasks manually on specific container instances.
You can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume when creating or updating a service. For more information, see Amazon EBS volumes in the Amazon Elastic Container Service Developer Guide.
The Amazon ECS API follows an eventual consistency model. This is because of the distributed nature of the system supporting the API. This means that the result of an API command you run that affects your Amazon ECS resources might not be immediately visible to all subsequent commands you run. Keep this in mind when you carry out an API command that immediately follows a previous API command.
To manage eventual consistency, you can do the following:
- Confirm the state of the resource before you run a command to modify it. Run the DescribeTasks command using an exponential backoff algorithm to ensure that you allow enough time for the previous command to propagate through the system. To do this, run the DescribeTasks command repeatedly, starting with a couple of seconds of wait time and increasing gradually up to five minutes of wait time.
- Add wait time between subsequent commands, even if the DescribeTasks command returns an accurate response. Apply an exponential backoff algorithm starting with a couple of seconds of wait time, and increase gradually up to about five minutes of wait time.
ConflictException error, the
RunTask request could not be processed due to conflicts. The
provided clientToken is already in use with a different
RunTask request. The resourceIds are the
existing task ARNs which are already associated with the
clientToken.
To fix this issue:
-
Run
RunTaskwith a uniqueclientToken. -
Run
RunTaskwith theclientTokenand the original set of parameters
ClientExceptionerror, the RunTask
could not be processed because you use managed scaling and there is a
capacity error because the quota of tasks in the PROVISIONING
per cluster has been reached. For information about the service quotas,
see Amazon
ECS service quotas.
May throw AccessDeniedException.
May throw BlockedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw ConflictException.
May throw InvalidParameterException.
May throw PlatformTaskDefinitionIncompatibilityException.
May throw PlatformUnknownException.
May throw ServerException.
May throw UnsupportedFeatureException.
Parameter taskDefinition :
The family and revision
(family:revision) or full ARN of the task definition to run.
If a revision isn't specified, the latest ACTIVE
revision is used.
The full ARN value must match the value that you specified as the
Resource of the principal's permissions policy.
When you specify a task definition, you must either specify a specific revision, or all revisions in the ARN.
To specify a specific revision, include the revision number in the ARN.
For example, to specify revision 2, use
arn:aws:ecs:us-east-1:111122223333:task-definition/TaskFamilyName:2.
To specify all revisions, use the wildcard () in the ARN. For example, to
specify all revisions, use
arn:aws:ecs:us-east-1:111122223333:task-definition/TaskFamilyName:.
For more information, see Policy Resources for Amazon ECS in the Amazon Elastic Container Service Developer Guide.
Parameter capacityProviderStrategy :
The capacity provider strategy to use for the task.
If a capacityProviderStrategy is specified, the
launchType parameter must be omitted. If no
capacityProviderStrategy or launchType is
specified, the defaultCapacityProviderStrategy for the
cluster is used.
When you use cluster auto scaling, you must specify
capacityProviderStrategy and not launchType.
A capacity provider strategy can contain a maximum of 20 capacity providers.
Parameter clientToken :
An identifier that you provide to ensure the idempotency of the request.
It must be unique and is case sensitive. Up to 64 characters are allowed.
The valid characters are characters in the range of 33-126, inclusive. For
more information, see Ensuring
idempotency.
Parameter cluster :
The short name or full Amazon Resource Name (ARN) of the cluster to run
your task on. If you do not specify a cluster, the default cluster is
assumed.
Each account receives a default cluster the first time you use the service, but you may also create other clusters.
Parameter count :
The number of instantiations of the specified task to place on your
cluster. You can specify up to 10 tasks for each call.
Parameter enableECSManagedTags :
Specifies whether to use Amazon ECS managed tags for the task. For more
information, see Tagging
Your Amazon ECS Resources in the Amazon Elastic Container Service
Developer Guide.
Parameter enableExecuteCommand :
Determines whether to use the execute command functionality for the
containers in this task. If true, this enables execute
command functionality on all containers in the task.
If true, then the task definition must have a task role, or
you must provide one as an override.
Parameter group :
The name of the task group to associate with the task. The default value
is the family name of the task definition (for example,
family:my-family-name).
Parameter launchType :
The infrastructure to run your standalone task on. For more information,
see Amazon
ECS launch types in the Amazon Elastic Container Service Developer
Guide.
The FARGATE launch type runs your tasks on Fargate On-Demand
infrastructure.
The EC2 launch type runs your tasks on Amazon EC2 instances
registered to your cluster.
The EXTERNAL launch type runs your tasks on your on-premises
server or virtual machine (VM) capacity registered to your cluster.
A task can use either a launch type or a capacity provider strategy. If a
launchType is specified, the
capacityProviderStrategy parameter must be omitted.
When you use cluster auto scaling, you must specify
capacityProviderStrategy and not launchType.
Parameter networkConfiguration :
The network configuration for the task. This parameter is required for
task definitions that use the awsvpc network mode to receive
their own elastic network interface, and it isn't supported for other
network modes. For more information, see Task
networking in the Amazon Elastic Container Service Developer
Guide.
Parameter overrides :
A list of container overrides in JSON format that specify the name of a
container in the specified task definition and the overrides it should
receive. You can override the default command for a container (that's
specified in the task definition or Docker image) with a
command override. You can also override existing environment
variables (that are specified in the task definition or Docker image) on a
container or add new environment variables to it with an
environment override.
A total of 8192 characters are allowed for overrides. This limit includes the JSON formatting characters of the override structure.
Parameter placementConstraints :
An array of placement constraint objects to use for the task. You can
specify up to 10 constraints for each task (including constraints in the
task definition and those specified at runtime).
Parameter placementStrategy :
The placement strategy objects to use for the task. You can specify a
maximum of 5 strategy rules for each task.
Parameter platformVersion :
The platform version the task uses. A platform version is only specified
for tasks hosted on Fargate. If one isn't specified, the
LATEST platform version is used. For more information, see Fargate
platform versions in the Amazon Elastic Container Service Developer
Guide.
Parameter propagateTags :
Specifies whether to propagate the tags from the task definition to the
task. If no value is specified, the tags aren't propagated. Tags can only
be propagated to the task during task creation. To add tags to a task
after task creation, use theTagResource
API action.
Parameter referenceId :
This parameter is only used by Amazon ECS. It is not intended for use by
customers.
Parameter startedBy :
An optional tag specified when a task is started. For example, if you
automatically trigger a task to run a batch process job, you could apply a
unique identifier for that job to your task with the
startedBy parameter. You can then identify which tasks belong
to that job by filtering the results of a ListTasks
call with the startedBy value. Up to 128 letters (uppercase
and lowercase), numbers, hyphens (-), forward slash (/), and underscores
(_) are allowed.
If a task is started by an Amazon ECS service, then the
startedBy parameter contains the deployment ID of the service
that starts it.
Parameter tags :
The metadata that you apply to the task to help you categorize and
organize them. Each tag consists of a key and an optional value, both of
which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8
- Maximum value length - 256 Unicode characters in UTF-8
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
Parameter volumeConfigurations :
The details of the volume that was configuredAtLaunch. You
can configure the size, volumeType, IOPS, throughput, snapshot and
encryption in TaskManagedEBSVolumeConfiguration.
The name of the volume must match the name from
the task definition.
Implementation
Future<RunTaskResponse> runTask({
required String taskDefinition,
List<CapacityProviderStrategyItem>? capacityProviderStrategy,
String? clientToken,
String? cluster,
int? count,
bool? enableECSManagedTags,
bool? enableExecuteCommand,
String? group,
LaunchType? launchType,
NetworkConfiguration? networkConfiguration,
TaskOverride? overrides,
List<PlacementConstraint>? placementConstraints,
List<PlacementStrategy>? placementStrategy,
String? platformVersion,
PropagateTags? propagateTags,
String? referenceId,
String? startedBy,
List<Tag>? tags,
List<TaskVolumeConfiguration>? volumeConfigurations,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.RunTask'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'taskDefinition': taskDefinition,
if (capacityProviderStrategy != null)
'capacityProviderStrategy': capacityProviderStrategy,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (cluster != null) 'cluster': cluster,
if (count != null) 'count': count,
if (enableECSManagedTags != null)
'enableECSManagedTags': enableECSManagedTags,
if (enableExecuteCommand != null)
'enableExecuteCommand': enableExecuteCommand,
if (group != null) 'group': group,
if (launchType != null) 'launchType': launchType.value,
if (networkConfiguration != null)
'networkConfiguration': networkConfiguration,
if (overrides != null) 'overrides': overrides,
if (placementConstraints != null)
'placementConstraints': placementConstraints,
if (placementStrategy != null) 'placementStrategy': placementStrategy,
if (platformVersion != null) 'platformVersion': platformVersion,
if (propagateTags != null) 'propagateTags': propagateTags.value,
if (referenceId != null) 'referenceId': referenceId,
if (startedBy != null) 'startedBy': startedBy,
if (tags != null) 'tags': tags,
if (volumeConfigurations != null)
'volumeConfigurations': volumeConfigurations,
},
);
return RunTaskResponse.fromJson(jsonResponse.body);
}