updateClusterSettings method
Modifies the settings to use for a cluster.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ServerException.
May throw UpdateInProgressException.
Parameter cluster :
The name of the cluster to modify the settings for.
Parameter settings :
The setting to use by default for a cluster. This parameter is used to
turn on CloudWatch Container Insights for a cluster. If this value is
specified, it overrides the containerInsights value set with
PutAccountSetting
or PutAccountSettingDefault.
Implementation
Future<UpdateClusterSettingsResponse> updateClusterSettings({
required String cluster,
required List<ClusterSetting> settings,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.UpdateClusterSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'cluster': cluster,
'settings': settings,
},
);
return UpdateClusterSettingsResponse.fromJson(jsonResponse.body);
}