describeAccountPreferences method

Future<DescribeAccountPreferencesResponse> describeAccountPreferences({
  1. int? maxResults,
  2. String? nextToken,
})

Returns the account preferences settings for the Amazon Web Services account associated with the user making the request, in the current Amazon Web Services Region.

May throw InternalServerError.

Parameter maxResults : (Optional) When retrieving account preferences, you can optionally specify the MaxItems parameter to limit the number of objects returned in a response. The default value is 100.

Parameter nextToken : (Optional) You can use NextToken in a subsequent request to fetch the next page of Amazon Web Services account preferences if the response payload was paginated.

Implementation

Future<DescribeAccountPreferencesResponse> describeAccountPreferences({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1152921504606846976,
  );
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2015-02-01/account-preferences',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAccountPreferencesResponse.fromJson(response);
}