describeLifecycleConfiguration method

Future<LifecycleConfigurationDescription> describeLifecycleConfiguration({
  1. required String fileSystemId,
})

Returns the current LifecycleConfiguration object for the specified EFS file system. Lifecycle management uses the LifecycleConfiguration object to identify when to move files between storage classes. For a file system without a LifecycleConfiguration object, the call returns an empty array in the response.

This operation requires permissions for the elasticfilesystem:DescribeLifecycleConfiguration operation.

May throw BadRequest. May throw FileSystemNotFound. May throw InternalServerError.

Parameter fileSystemId : The ID of the file system whose LifecycleConfiguration object you want to retrieve (String).

Implementation

Future<LifecycleConfigurationDescription> describeLifecycleConfiguration({
  required String fileSystemId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2015-02-01/file-systems/${Uri.encodeComponent(fileSystemId)}/lifecycle-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return LifecycleConfigurationDescription.fromJson(response);
}