describeReplicationConfigurations method
Retrieves the replication configuration for a specific file system. If a file system is not specified, all of the replication configurations for the Amazon Web Services account in an Amazon Web Services Region are retrieved.
May throw BadRequest.
May throw FileSystemNotFound.
May throw InternalServerError.
May throw ReplicationNotFound.
May throw ValidationException.
Parameter fileSystemId :
You can retrieve the replication configuration for a specific file system
by providing its file system ID. For cross-account,cross-region
replication, an account can only describe the replication configuration
for a file system in its own Region.
Parameter maxResults :
(Optional) To limit the number of objects returned in a response, you can
specify the MaxItems parameter. The default value is 100.
Parameter nextToken :
NextToken is present if the response is paginated. You can
use NextToken in a subsequent request to fetch the next page
of output.
Implementation
Future<DescribeReplicationConfigurationsResponse>
describeReplicationConfigurations({
String? fileSystemId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final $query = <String, List<String>>{
if (fileSystemId != null) 'FileSystemId': [fileSystemId],
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2015-02-01/file-systems/replication-configurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeReplicationConfigurationsResponse.fromJson(response);
}