putAccountPreferences method

Future<PutAccountPreferencesResponse> putAccountPreferences({
  1. required ResourceIdType resourceIdType,
})

Use this operation to set the account preference in the current Amazon Web Services Region to use long 17 character (63 bit) or short 8 character (32 bit) resource IDs for new EFS file system and mount target resources. All existing resource IDs are not affected by any changes you make. You can set the ID preference during the opt-in period as EFS transitions to long resource IDs. For more information, see Managing Amazon EFS resource IDs.

May throw BadRequest. May throw InternalServerError.

Parameter resourceIdType : Specifies the EFS resource ID preference to set for the user's Amazon Web Services account, in the current Amazon Web Services Region, either LONG_ID (17 characters), or SHORT_ID (8 characters).

Implementation

Future<PutAccountPreferencesResponse> putAccountPreferences({
  required ResourceIdType resourceIdType,
}) async {
  final $payload = <String, dynamic>{
    'ResourceIdType': resourceIdType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/2015-02-01/account-preferences',
    exceptionFnMap: _exceptionFns,
  );
  return PutAccountPreferencesResponse.fromJson(response);
}