putFileSystemPolicy method

Future<FileSystemPolicyDescription> putFileSystemPolicy({
  1. required String fileSystemId,
  2. required String policy,
  3. bool? bypassPolicyLockoutSafetyCheck,
})

Applies an Amazon EFS FileSystemPolicy to an Amazon EFS file system. A file system policy is an IAM resource-based policy and can contain multiple policy statements. A file system always has exactly one file system policy, which can be the default policy or an explicit policy set or updated using this API operation. EFS file system policies have a 20,000 character limit. When an explicit policy is set, it overrides the default policy. For more information about the default file system policy, see Default EFS file system policy. This operation requires permissions for the elasticfilesystem:PutFileSystemPolicy action.

May throw BadRequest. May throw FileSystemNotFound. May throw IncorrectFileSystemLifeCycleState. May throw InternalServerError. May throw InvalidPolicyException.

Parameter fileSystemId : The ID of the EFS file system that you want to create or update the FileSystemPolicy for.

Parameter policy : The FileSystemPolicy that you're creating. Accepts a JSON formatted policy definition. EFS file system policies have a 20,000 character limit. To find out more about the elements that make up a file system policy, see Resource-based policies within Amazon EFS.

Parameter bypassPolicyLockoutSafetyCheck : (Optional) A boolean that specifies whether or not to bypass the FileSystemPolicy lockout safety check. The lockout safety check determines whether the policy in the request will lock out, or prevent, the IAM principal that is making the request from making future PutFileSystemPolicy requests on this file system. Set BypassPolicyLockoutSafetyCheck to True only when you intend to prevent the IAM principal that is making the request from making subsequent PutFileSystemPolicy requests on this file system. The default value is False.

Implementation

Future<FileSystemPolicyDescription> putFileSystemPolicy({
  required String fileSystemId,
  required String policy,
  bool? bypassPolicyLockoutSafetyCheck,
}) async {
  final $payload = <String, dynamic>{
    'Policy': policy,
    if (bypassPolicyLockoutSafetyCheck != null)
      'BypassPolicyLockoutSafetyCheck': bypassPolicyLockoutSafetyCheck,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/2015-02-01/file-systems/${Uri.encodeComponent(fileSystemId)}/policy',
    exceptionFnMap: _exceptionFns,
  );
  return FileSystemPolicyDescription.fromJson(response);
}