Eks class

Amazon Elastic Kubernetes Service (Amazon EKS) is a managed service that makes it easy for you to run Kubernetes on Amazon Web Services without needing to setup or maintain your own Kubernetes control plane. Kubernetes is an open-source system for automating the deployment, scaling, and management of containerized applications.

Amazon EKS runs up-to-date versions of the open-source Kubernetes software, so you can use all the existing plugins and tooling from the Kubernetes community. Applications running on Amazon EKS are fully compatible with applications running on any standard Kubernetes environment, whether running in on-premises data centers or public clouds. This means that you can easily migrate any standard Kubernetes application to Amazon EKS without any code modification required.

Constructors

Eks({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateAccessPolicy({required AccessScope accessScope, required String clusterName, required String policyArn, required String principalArn}) Future<AssociateAccessPolicyResponse>
Associates an access policy and its scope to an access entry. For more information about associating access policies, see Associating and disassociating access policies to and from access entries in the Amazon EKS User Guide.
associateEncryptionConfig({required String clusterName, required List<EncryptionConfig> encryptionConfig, String? clientRequestToken}) Future<AssociateEncryptionConfigResponse>
Associates an encryption configuration to an existing cluster.
associateIdentityProviderConfig({required String clusterName, required OidcIdentityProviderConfigRequest oidc, String? clientRequestToken, Map<String, String>? tags}) Future<AssociateIdentityProviderConfigResponse>
Associates an identity provider configuration to a cluster.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAccessEntry({required String clusterName, required String principalArn, String? clientRequestToken, List<String>? kubernetesGroups, Map<String, String>? tags, String? type, String? username}) Future<CreateAccessEntryResponse>
Creates an access entry.
createAddon({required String addonName, required String clusterName, String? addonVersion, String? clientRequestToken, String? configurationValues, AddonNamespaceConfigRequest? namespaceConfig, List<AddonPodIdentityAssociations>? podIdentityAssociations, ResolveConflicts? resolveConflicts, String? serviceAccountRoleArn, Map<String, String>? tags}) Future<CreateAddonResponse>
Creates an Amazon EKS add-on.
createCapability({required String capabilityName, required String clusterName, required CapabilityDeletePropagationPolicy deletePropagationPolicy, required String roleArn, required CapabilityType type, String? clientRequestToken, CapabilityConfigurationRequest? configuration, Map<String, String>? tags}) Future<CreateCapabilityResponse>
Creates a managed capability resource for an Amazon EKS cluster.
createCluster({required String name, required VpcConfigRequest resourcesVpcConfig, required String roleArn, CreateAccessConfigRequest? accessConfig, bool? bootstrapSelfManagedAddons, String? clientRequestToken, ComputeConfigRequest? computeConfig, ControlPlaneScalingConfig? controlPlaneScalingConfig, bool? deletionProtection, List<EncryptionConfig>? encryptionConfig, KubernetesNetworkConfigRequest? kubernetesNetworkConfig, Logging? logging, OutpostConfigRequest? outpostConfig, RemoteNetworkConfigRequest? remoteNetworkConfig, StorageConfigRequest? storageConfig, Map<String, String>? tags, UpgradePolicyRequest? upgradePolicy, String? version, ZonalShiftConfigRequest? zonalShiftConfig}) Future<CreateClusterResponse>
Creates an Amazon EKS control plane.
createEksAnywhereSubscription({required String name, required EksAnywhereSubscriptionTerm term, bool? autoRenew, String? clientRequestToken, int? licenseQuantity, EksAnywhereSubscriptionLicenseType? licenseType, Map<String, String>? tags}) Future<CreateEksAnywhereSubscriptionResponse>
Creates an EKS Anywhere subscription. When a subscription is created, it is a contract agreement for the length of the term specified in the request. Licenses that are used to validate support are provisioned in Amazon Web Services License Manager and the caller account is granted access to EKS Anywhere Curated Packages.
createFargateProfile({required String clusterName, required String fargateProfileName, required String podExecutionRoleArn, String? clientRequestToken, List<FargateProfileSelector>? selectors, List<String>? subnets, Map<String, String>? tags}) Future<CreateFargateProfileResponse>
Creates an Fargate profile for your Amazon EKS cluster. You must have at least one Fargate profile in a cluster to be able to run pods on Fargate.
createNodegroup({required String clusterName, required String nodeRole, required String nodegroupName, required List<String> subnets, AMITypes? amiType, CapacityTypes? capacityType, String? clientRequestToken, int? diskSize, List<String>? instanceTypes, Map<String, String>? labels, LaunchTemplateSpecification? launchTemplate, NodeRepairConfig? nodeRepairConfig, String? releaseVersion, RemoteAccessConfig? remoteAccess, NodegroupScalingConfig? scalingConfig, Map<String, String>? tags, List<Taint>? taints, NodegroupUpdateConfig? updateConfig, String? version, WarmPoolConfig? warmPoolConfig}) Future<CreateNodegroupResponse>
Creates a managed node group for an Amazon EKS cluster.
createPodIdentityAssociation({required String clusterName, required String namespace, required String roleArn, required String serviceAccount, String? clientRequestToken, bool? disableSessionTags, String? policy, Map<String, String>? tags, String? targetRoleArn}) Future<CreatePodIdentityAssociationResponse>
Creates an EKS Pod Identity association between a service account in an Amazon EKS cluster and an IAM role with EKS Pod Identity. Use EKS Pod Identity to give temporary IAM credentials to Pods and the credentials are rotated automatically.
deleteAccessEntry({required String clusterName, required String principalArn}) Future<void>
Deletes an access entry.
deleteAddon({required String addonName, required String clusterName, bool? preserve}) Future<DeleteAddonResponse>
Deletes an Amazon EKS add-on.
deleteCapability({required String capabilityName, required String clusterName}) Future<DeleteCapabilityResponse>
Deletes a managed capability from your Amazon EKS cluster. When you delete a capability, Amazon EKS removes the capability infrastructure but retains all resources that were managed by the capability.
deleteCluster({required String name}) Future<DeleteClusterResponse>
Deletes an Amazon EKS cluster control plane.
deleteEksAnywhereSubscription({required String id}) Future<DeleteEksAnywhereSubscriptionResponse>
Deletes an expired or inactive subscription. Deleting inactive subscriptions removes them from the Amazon Web Services Management Console view and from list/describe API responses. Subscriptions can only be cancelled within 7 days of creation and are cancelled by creating a ticket in the Amazon Web Services Support Center.
deleteFargateProfile({required String clusterName, required String fargateProfileName}) Future<DeleteFargateProfileResponse>
Deletes an Fargate profile.
deleteNodegroup({required String clusterName, required String nodegroupName}) Future<DeleteNodegroupResponse>
Deletes a managed node group.
deletePodIdentityAssociation({required String associationId, required String clusterName}) Future<DeletePodIdentityAssociationResponse>
Deletes a EKS Pod Identity association.
deregisterCluster({required String name}) Future<DeregisterClusterResponse>
Deregisters a connected cluster to remove it from the Amazon EKS control plane.
describeAccessEntry({required String clusterName, required String principalArn}) Future<DescribeAccessEntryResponse>
Describes an access entry.
describeAddon({required String addonName, required String clusterName}) Future<DescribeAddonResponse>
Describes an Amazon EKS add-on.
describeAddonConfiguration({required String addonName, required String addonVersion}) Future<DescribeAddonConfigurationResponse>
Returns configuration options.
describeAddonVersions({String? addonName, String? kubernetesVersion, int? maxResults, String? nextToken, List<String>? owners, List<String>? publishers, List<String>? types}) Future<DescribeAddonVersionsResponse>
Describes the versions for an add-on.
describeCapability({required String capabilityName, required String clusterName}) Future<DescribeCapabilityResponse>
Returns detailed information about a specific managed capability in your Amazon EKS cluster, including its current status, configuration, health information, and any issues that may be affecting its operation.
describeCluster({required String name}) Future<DescribeClusterResponse>
Describes an Amazon EKS cluster.
describeClusterVersions({String? clusterType, List<String>? clusterVersions, bool? defaultOnly, bool? includeAll, int? maxResults, String? nextToken, ClusterVersionStatus? status, VersionStatus? versionStatus}) Future<DescribeClusterVersionsResponse>
Lists available Kubernetes versions for Amazon EKS clusters.
describeEksAnywhereSubscription({required String id}) Future<DescribeEksAnywhereSubscriptionResponse>
Returns descriptive information about a subscription.
describeFargateProfile({required String clusterName, required String fargateProfileName}) Future<DescribeFargateProfileResponse>
Describes an Fargate profile.
describeIdentityProviderConfig({required String clusterName, required IdentityProviderConfig identityProviderConfig}) Future<DescribeIdentityProviderConfigResponse>
Describes an identity provider configuration.
describeInsight({required String clusterName, required String id}) Future<DescribeInsightResponse>
Returns details about an insight that you specify using its ID.
describeInsightsRefresh({required String clusterName}) Future<DescribeInsightsRefreshResponse>
Returns the status of the latest on-demand cluster insights refresh operation.
describeNodegroup({required String clusterName, required String nodegroupName}) Future<DescribeNodegroupResponse>
Describes a managed node group.
describePodIdentityAssociation({required String associationId, required String clusterName}) Future<DescribePodIdentityAssociationResponse>
Returns descriptive information about an EKS Pod Identity association.
describeUpdate({required String name, required String updateId, String? addonName, String? capabilityName, String? nodegroupName}) Future<DescribeUpdateResponse>
Describes an update to an Amazon EKS resource.
disassociateAccessPolicy({required String clusterName, required String policyArn, required String principalArn}) Future<void>
Disassociates an access policy from an access entry.
disassociateIdentityProviderConfig({required String clusterName, required IdentityProviderConfig identityProviderConfig, String? clientRequestToken}) Future<DisassociateIdentityProviderConfigResponse>
Disassociates an identity provider configuration from a cluster.
listAccessEntries({required String clusterName, String? associatedPolicyArn, int? maxResults, String? nextToken}) Future<ListAccessEntriesResponse>
Lists the access entries for your cluster.
listAccessPolicies({int? maxResults, String? nextToken}) Future<ListAccessPoliciesResponse>
Lists the available access policies.
listAddons({required String clusterName, int? maxResults, String? nextToken}) Future<ListAddonsResponse>
Lists the installed add-ons.
listAssociatedAccessPolicies({required String clusterName, required String principalArn, int? maxResults, String? nextToken}) Future<ListAssociatedAccessPoliciesResponse>
Lists the access policies associated with an access entry.
listCapabilities({required String clusterName, int? maxResults, String? nextToken}) Future<ListCapabilitiesResponse>
Lists all managed capabilities in your Amazon EKS cluster. You can use this operation to get an overview of all capabilities and their current status.
listClusters({List<String>? include, int? maxResults, String? nextToken}) Future<ListClustersResponse>
Lists the Amazon EKS clusters in your Amazon Web Services account in the specified Amazon Web Services Region.
listEksAnywhereSubscriptions({List<EksAnywhereSubscriptionStatus>? includeStatus, int? maxResults, String? nextToken}) Future<ListEksAnywhereSubscriptionsResponse>
Displays the full description of the subscription.
listFargateProfiles({required String clusterName, int? maxResults, String? nextToken}) Future<ListFargateProfilesResponse>
Lists the Fargate profiles associated with the specified cluster in your Amazon Web Services account in the specified Amazon Web Services Region.
listIdentityProviderConfigs({required String clusterName, int? maxResults, String? nextToken}) Future<ListIdentityProviderConfigsResponse>
Lists the identity provider configurations for your cluster.
listInsights({required String clusterName, InsightsFilter? filter, int? maxResults, String? nextToken}) Future<ListInsightsResponse>
Returns a list of all insights checked for against the specified cluster. You can filter which insights are returned by category, associated Kubernetes version, and status. The default filter lists all categories and every status.
listNodegroups({required String clusterName, int? maxResults, String? nextToken}) Future<ListNodegroupsResponse>
Lists the managed node groups associated with the specified cluster in your Amazon Web Services account in the specified Amazon Web Services Region. Self-managed node groups aren't listed.
listPodIdentityAssociations({required String clusterName, int? maxResults, String? namespace, String? nextToken, String? serviceAccount}) Future<ListPodIdentityAssociationsResponse>
List the EKS Pod Identity associations in a cluster. You can filter the list by the namespace that the association is in or the service account that the association uses.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List the tags for an Amazon EKS resource.
listUpdates({required String name, String? addonName, String? capabilityName, int? maxResults, String? nextToken, String? nodegroupName}) Future<ListUpdatesResponse>
Lists the updates associated with an Amazon EKS resource in your Amazon Web Services account, in the specified Amazon Web Services Region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCluster({required ConnectorConfigRequest connectorConfig, required String name, String? clientRequestToken, Map<String, String>? tags}) Future<RegisterClusterResponse>
Connects a Kubernetes cluster to the Amazon EKS control plane.
startInsightsRefresh({required String clusterName}) Future<StartInsightsRefreshResponse>
Initiates an on-demand refresh operation for cluster insights, getting the latest analysis outside of the standard refresh schedule.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Associates the specified tags to an Amazon EKS resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they aren't changed. When a resource is deleted, the tags associated with that resource are also deleted. Tags that you create for Amazon EKS resources don't propagate to any other resources associated with the cluster. For example, if you tag a cluster with this operation, that tag doesn't automatically propagate to the subnets and nodes associated with the cluster.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes specified tags from an Amazon EKS resource.
updateAccessEntry({required String clusterName, required String principalArn, String? clientRequestToken, List<String>? kubernetesGroups, String? username}) Future<UpdateAccessEntryResponse>
Updates an access entry.
updateAddon({required String addonName, required String clusterName, String? addonVersion, String? clientRequestToken, String? configurationValues, List<AddonPodIdentityAssociations>? podIdentityAssociations, ResolveConflicts? resolveConflicts, String? serviceAccountRoleArn}) Future<UpdateAddonResponse>
Updates an Amazon EKS add-on.
updateCapability({required String capabilityName, required String clusterName, String? clientRequestToken, UpdateCapabilityConfiguration? configuration, CapabilityDeletePropagationPolicy? deletePropagationPolicy, String? roleArn}) Future<UpdateCapabilityResponse>
Updates the configuration of a managed capability in your Amazon EKS cluster. You can update the IAM role, configuration settings, and delete propagation policy for a capability.
updateClusterConfig({required String name, UpdateAccessConfigRequest? accessConfig, String? clientRequestToken, ComputeConfigRequest? computeConfig, ControlPlaneScalingConfig? controlPlaneScalingConfig, bool? deletionProtection, KubernetesNetworkConfigRequest? kubernetesNetworkConfig, Logging? logging, RemoteNetworkConfigRequest? remoteNetworkConfig, VpcConfigRequest? resourcesVpcConfig, StorageConfigRequest? storageConfig, UpgradePolicyRequest? upgradePolicy, ZonalShiftConfigRequest? zonalShiftConfig}) Future<UpdateClusterConfigResponse>
Updates an Amazon EKS cluster configuration. Your cluster continues to function during the update. The response output includes an update ID that you can use to track the status of your cluster update with DescribeUpdate.
updateClusterVersion({required String name, required String version, String? clientRequestToken, bool? force}) Future<UpdateClusterVersionResponse>
Updates an Amazon EKS cluster to the specified Kubernetes version. Your cluster continues to function during the update. The response output includes an update ID that you can use to track the status of your cluster update with the DescribeUpdate API operation.
updateEksAnywhereSubscription({required bool autoRenew, required String id, String? clientRequestToken}) Future<UpdateEksAnywhereSubscriptionResponse>
Update an EKS Anywhere Subscription. Only auto renewal and tags can be updated after subscription creation.
updateNodegroupConfig({required String clusterName, required String nodegroupName, String? clientRequestToken, UpdateLabelsPayload? labels, NodeRepairConfig? nodeRepairConfig, NodegroupScalingConfig? scalingConfig, UpdateTaintsPayload? taints, NodegroupUpdateConfig? updateConfig, WarmPoolConfig? warmPoolConfig}) Future<UpdateNodegroupConfigResponse>
Updates an Amazon EKS managed node group configuration. Your node group continues to function during the update. The response output includes an update ID that you can use to track the status of your node group update with the DescribeUpdate API operation. You can update the Kubernetes labels and taints for a node group and the scaling and version update configuration.
updateNodegroupVersion({required String clusterName, required String nodegroupName, String? clientRequestToken, bool? force, LaunchTemplateSpecification? launchTemplate, String? releaseVersion, String? version}) Future<UpdateNodegroupVersionResponse>
Updates the Kubernetes version or AMI version of an Amazon EKS managed node group.
updatePodIdentityAssociation({required String associationId, required String clusterName, String? clientRequestToken, bool? disableSessionTags, String? policy, String? roleArn, String? targetRoleArn}) Future<UpdatePodIdentityAssociationResponse>
Updates a EKS Pod Identity association. In an update, you can change the IAM role, the target IAM role, or disableSessionTags. You must change at least one of these in an update. An association can't be moved between clusters, namespaces, or service accounts. If you need to edit the namespace or service account, you need to delete the association and then create a new association with your desired settings.

Operators

operator ==(Object other) bool
The equality operator.
inherited