createAccessEntry method
Creates an access entry.
An access entry allows an IAM principal to access your cluster. Access
entries can replace the need to maintain entries in the
aws-auth ConfigMap for authentication. You have
the following options for authorizing an IAM principal to access
Kubernetes objects on your cluster: Kubernetes role-based access control
(RBAC), Amazon EKS, or both. Kubernetes RBAC authorization requires you to
create and manage Kubernetes Role, ClusterRole,
RoleBinding, and ClusterRoleBinding objects, in
addition to managing access entries. If you use Amazon EKS authorization
exclusively, you don't need to create and manage Kubernetes
Role, ClusterRole, RoleBinding, and
ClusterRoleBinding objects.
For more information about access entries, see Access entries in the Amazon EKS User Guide.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ResourceLimitExceededException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter clusterName :
The name of your cluster.
Parameter principalArn :
The ARN of the IAM principal for the AccessEntry. You can
specify one ARN for each access entry. You can't specify the same ARN in
more than one access entry. This value can't be changed after access entry
creation.
The valid principals differ depending on the type of the access entry in
the type field. For STANDARD access entries, you
can use every IAM principal type. For nodes (EC2 (for EKS
Auto Mode), EC2_LINUX, EC2_WINDOWS,
FARGATE_LINUX, and HYBRID_LINUX), the only valid
ARN is IAM roles. You can't use the STS session principal type with access
entries because this is a temporary principal for each session and not a
permanent identity that can be assigned permissions.
IAM best practices recommend using IAM roles with temporary credentials, rather than IAM users with long-term credentials.
Parameter clientRequestToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Parameter kubernetesGroups :
The value for name that you've specified for kind:
Group as a subject in a Kubernetes
RoleBinding or ClusterRoleBinding object. Amazon
EKS doesn't confirm that the value for name exists in any
bindings on your cluster. You can specify one or more names.
Kubernetes authorizes the principalArn of the access entry to
access any cluster objects that you've specified in a Kubernetes
Role or ClusterRole object that is also
specified in a binding's roleRef. For more information about
creating Kubernetes RoleBinding,
ClusterRoleBinding, Role, or
ClusterRole objects, see Using
RBAC Authorization in the Kubernetes documentation.
If you want Amazon EKS to authorize the principalArn (instead
of, or in addition to Kubernetes authorizing the
principalArn), you can associate one or more access policies
to the access entry using AssociateAccessPolicy. If you
associate any access policies, the principalARN has all
permissions assigned in the associated access policies and all permissions
in any Kubernetes Role or ClusterRole objects
that the group names are bound to.
Parameter tags :
Metadata that assists with categorization and organization. Each tag
consists of a key and an optional value. You define both. Tags don't
propagate to any other cluster or Amazon Web Services resources.
Parameter type :
The type of the new access entry. Valid values are STANDARD,
FARGATE_LINUX, EC2_LINUX,
EC2_WINDOWS, EC2 (for EKS Auto Mode),
HYBRID_LINUX, and HYPERPOD_LINUX.
If the principalArn is for an IAM role that's used for
self-managed Amazon EC2 nodes, specify EC2_LINUX or
EC2_WINDOWS. Amazon EKS grants the necessary permissions to
the node for you. If the principalArn is for any other
purpose, specify STANDARD. If you don't specify a value,
Amazon EKS sets the value to STANDARD. If you have the access
mode of the cluster set to API_AND_CONFIG_MAP, it's
unnecessary to create access entries for IAM roles used with Fargate
profiles or managed Amazon EC2 nodes, because Amazon EKS creates entries
in the aws-auth ConfigMap for the roles. You
can't change this value once you've created the access entry.
If you set the value to EC2_LINUX or
EC2_WINDOWS, you can't specify values for
kubernetesGroups, or associate an AccessPolicy
to the access entry.
Parameter username :
The username to authenticate to Kubernetes with. We recommend not
specifying a username and letting Amazon EKS specify it for you. For more
information about the value Amazon EKS specifies for you, or constraints
before specifying your own username, see Creating
access entries in the Amazon EKS User Guide.
Implementation
Future<CreateAccessEntryResponse> createAccessEntry({
required String clusterName,
required String principalArn,
String? clientRequestToken,
List<String>? kubernetesGroups,
Map<String, String>? tags,
String? type,
String? username,
}) async {
final $payload = <String, dynamic>{
'principalArn': principalArn,
'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (kubernetesGroups != null) 'kubernetesGroups': kubernetesGroups,
if (tags != null) 'tags': tags,
if (type != null) 'type': type,
if (username != null) 'username': username,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/access-entries',
exceptionFnMap: _exceptionFns,
);
return CreateAccessEntryResponse.fromJson(response);
}