createFargateProfile method
Creates an Fargate profile for your Amazon EKS cluster. You must have at least one Fargate profile in a cluster to be able to run pods on Fargate.
The Fargate profile allows an administrator to declare which pods run on Fargate and specify which pods run on which Fargate profile. This declaration is done through the profile's selectors. Each profile can have up to five selectors that contain a namespace and labels. A namespace is required for every selector. The label field consists of multiple optional key-value pairs. Pods that match the selectors are scheduled on Fargate. If a to-be-scheduled pod matches any of the selectors in the Fargate profile, then that pod is run on Fargate.
When you create a Fargate profile, you must specify a pod execution role
to use with the pods that are scheduled with the profile. This role is
added to the cluster's Kubernetes Role
Based Access Control (RBAC) for authorization so that the
kubelet that is running on the Fargate infrastructure can
register with your Amazon EKS cluster so that it can appear in your
cluster as a node. The pod execution role also provides IAM permissions to
the Fargate infrastructure to allow read access to Amazon ECR image
repositories. For more information, see Pod
Execution Role in the Amazon EKS User Guide.
Fargate profiles are immutable. However, you can create a new updated profile to replace an existing profile and then delete the original after the updated profile has finished creating.
If any Fargate profiles in a cluster are in the DELETING
status, you must wait for that Fargate profile to finish deleting before
you can create any other profiles in that cluster.
For more information, see Fargate profile in the Amazon EKS User Guide.
May throw ClientException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceLimitExceededException.
May throw ServerException.
May throw UnsupportedAvailabilityZoneException.
Parameter clusterName :
The name of your cluster.
Parameter fargateProfileName :
The name of the Fargate profile.
Parameter podExecutionRoleArn :
The Amazon Resource Name (ARN) of the Pod execution role to
use for a Pod that matches the selectors in the Fargate
profile. The Pod execution role allows Fargate infrastructure
to register with your cluster as a node, and it provides read access to
Amazon ECR image repositories. For more information, see
Pod execution role in the Amazon EKS User Guide.
Parameter clientRequestToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Parameter selectors :
The selectors to match for a Pod to use this Fargate profile.
Each selector must have an associated Kubernetes namespace.
Optionally, you can also specify labels for a
namespace. You may specify up to five selectors in a Fargate
profile.
Parameter subnets :
The IDs of subnets to launch a Pod into. A Pod
running on Fargate isn't assigned a public IP address, so only private
subnets (with no direct route to an Internet Gateway) are accepted for
this parameter.
Parameter tags :
Metadata that assists with categorization and organization. Each tag
consists of a key and an optional value. You define both. Tags don't
propagate to any other cluster or Amazon Web Services resources.
Implementation
Future<CreateFargateProfileResponse> createFargateProfile({
required String clusterName,
required String fargateProfileName,
required String podExecutionRoleArn,
String? clientRequestToken,
List<FargateProfileSelector>? selectors,
List<String>? subnets,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'fargateProfileName': fargateProfileName,
'podExecutionRoleArn': podExecutionRoleArn,
'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (selectors != null) 'selectors': selectors,
if (subnets != null) 'subnets': subnets,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/fargate-profiles',
exceptionFnMap: _exceptionFns,
);
return CreateFargateProfileResponse.fromJson(response);
}