deleteAccessEntry method

Future<void> deleteAccessEntry({
  1. required String clusterName,
  2. required String principalArn,
})

Deletes an access entry.

Deleting an access entry of a type other than Standard can cause your cluster to function improperly. If you delete an access entry in error, you can recreate it.

May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServerException.

Parameter clusterName : The name of your cluster.

Parameter principalArn : The ARN of the IAM principal for the AccessEntry.

Implementation

Future<void> deleteAccessEntry({
  required String clusterName,
  required String principalArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/clusters/${Uri.encodeComponent(clusterName)}/access-entries/${Uri.encodeComponent(principalArn)}',
    exceptionFnMap: _exceptionFns,
  );
}