deleteEksAnywhereSubscription method

Future<DeleteEksAnywhereSubscriptionResponse> deleteEksAnywhereSubscription({
  1. required String id,
})

Deletes an expired or inactive subscription. Deleting inactive subscriptions removes them from the Amazon Web Services Management Console view and from list/describe API responses. Subscriptions can only be cancelled within 7 days of creation and are cancelled by creating a ticket in the Amazon Web Services Support Center.

May throw ClientException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServerException.

Parameter id : The ID of the subscription.

Implementation

Future<DeleteEksAnywhereSubscriptionResponse> deleteEksAnywhereSubscription({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/eks-anywhere-subscriptions/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteEksAnywhereSubscriptionResponse.fromJson(response);
}