deleteFargateProfile method
Deletes an Fargate profile.
When you delete a Fargate profile, any Pod running on Fargate
that was created with the profile is deleted. If the Pod
matches another Fargate profile, then it is scheduled on Fargate with that
profile. If it no longer matches any Fargate profiles, then it's not
scheduled on Fargate and may remain in a pending state.
Only one Fargate profile in a cluster can be in the DELETING
status at a time. You must wait for a Fargate profile to finish deleting
before you can delete any other profiles in that cluster.
May throw ClientException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter clusterName :
The name of your cluster.
Parameter fargateProfileName :
The name of the Fargate profile to delete.
Implementation
Future<DeleteFargateProfileResponse> deleteFargateProfile({
required String clusterName,
required String fargateProfileName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/fargate-profiles/${Uri.encodeComponent(fargateProfileName)}',
exceptionFnMap: _exceptionFns,
);
return DeleteFargateProfileResponse.fromJson(response);
}