deletePodIdentityAssociation method
Deletes a EKS Pod Identity association.
The temporary Amazon Web Services credentials from the previous IAM role session might still be valid until the session expiry. If you need to immediately revoke the temporary session credentials, then go to the role in the IAM console.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter associationId :
The ID of the association to be deleted.
Parameter clusterName :
The cluster name that
Implementation
Future<DeletePodIdentityAssociationResponse> deletePodIdentityAssociation({
required String associationId,
required String clusterName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/pod-identity-associations/${Uri.encodeComponent(associationId)}',
exceptionFnMap: _exceptionFns,
);
return DeletePodIdentityAssociationResponse.fromJson(response);
}