deregisterCluster method

Future<DeregisterClusterResponse> deregisterCluster({
  1. required String name,
})

Deregisters a connected cluster to remove it from the Amazon EKS control plane.

A connected cluster is a Kubernetes cluster that you've connected to your control plane using the Amazon EKS Connector.

May throw AccessDeniedException. May throw ClientException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ServerException. May throw ServiceUnavailableException.

Parameter name : The name of the connected cluster to deregister.

Implementation

Future<DeregisterClusterResponse> deregisterCluster({
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/cluster-registrations/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeregisterClusterResponse.fromJson(response);
}