describeCapability method

Future<DescribeCapabilityResponse> describeCapability({
  1. required String capabilityName,
  2. required String clusterName,
})

Returns detailed information about a specific managed capability in your Amazon EKS cluster, including its current status, configuration, health information, and any issues that may be affecting its operation.

May throw AccessDeniedException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServerException.

Parameter capabilityName : The name of the capability to describe.

Parameter clusterName : The name of the Amazon EKS cluster that contains the capability you want to describe.

Implementation

Future<DescribeCapabilityResponse> describeCapability({
  required String capabilityName,
  required String clusterName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/clusters/${Uri.encodeComponent(clusterName)}/capabilities/${Uri.encodeComponent(capabilityName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeCapabilityResponse.fromJson(response);
}