describePodIdentityAssociation method

Future<DescribePodIdentityAssociationResponse> describePodIdentityAssociation({
  1. required String associationId,
  2. required String clusterName,
})

Returns descriptive information about an EKS Pod Identity association.

This action requires the ID of the association. You can get the ID from the response to the CreatePodIdentityAssocation for newly created associations. Or, you can list the IDs for associations with ListPodIdentityAssociations and filter the list by namespace or service account.

May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServerException.

Parameter associationId : The ID of the association that you want the description of.

Parameter clusterName : The name of the cluster that the association is in.

Implementation

Future<DescribePodIdentityAssociationResponse>
    describePodIdentityAssociation({
  required String associationId,
  required String clusterName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/clusters/${Uri.encodeComponent(clusterName)}/pod-identity-associations/${Uri.encodeComponent(associationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribePodIdentityAssociationResponse.fromJson(response);
}