disassociateIdentityProviderConfig method
Disassociates an identity provider configuration from a cluster.
If you disassociate an identity provider from your cluster, users included in the provider can no longer access the cluster. However, you can still access the cluster with IAM principals.
May throw ClientException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ServerException.
May throw ThrottlingException.
Parameter clusterName :
The name of your cluster.
Parameter identityProviderConfig :
An object representing an identity provider configuration.
Parameter clientRequestToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Implementation
Future<DisassociateIdentityProviderConfigResponse>
disassociateIdentityProviderConfig({
required String clusterName,
required IdentityProviderConfig identityProviderConfig,
String? clientRequestToken,
}) async {
final $payload = <String, dynamic>{
'identityProviderConfig': identityProviderConfig,
'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/identity-provider-configs/disassociate',
exceptionFnMap: _exceptionFns,
);
return DisassociateIdentityProviderConfigResponse.fromJson(response);
}