listClusters method

Future<ListClustersResponse> listClusters({
  1. List<String>? include,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the Amazon EKS clusters in your Amazon Web Services account in the specified Amazon Web Services Region.

May throw ClientException. May throw InvalidParameterException. May throw ServerException. May throw ServiceUnavailableException.

Parameter include : Indicates whether external clusters are included in the returned list. Use 'all' to return https://docs.aws.amazon.com/eks/latest/userguide/eks-connector.htmlconnected clusters, or blank to return only Amazon EKS clusters. 'all' must be in lowercase otherwise an error occurs.

Parameter maxResults : The maximum number of results, returned in paginated output. You receive maxResults in a single page, along with a nextToken response element. You can see the remaining results of the initial request by sending another request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, 100 results and a nextToken value, if applicable, are returned.

Parameter nextToken : The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Implementation

Future<ListClustersResponse> listClusters({
  List<String>? include,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (include != null) 'include': include,
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/clusters',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListClustersResponse.fromJson(response);
}