listIdentityProviderConfigs method
Lists the identity provider configurations for your cluster.
May throw ClientException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServerException.
May throw ServiceUnavailableException.
Parameter clusterName :
The name of your cluster.
Parameter maxResults :
The maximum number of results, returned in paginated output. You receive
maxResults in a single page, along with a
nextToken response element. You can see the remaining results
of the initial request by sending another request with the returned
nextToken value. This value can be between 1 and 100. If you
don't use this parameter, 100 results and a nextToken value,
if applicable, are returned.
Parameter nextToken :
The nextToken value returned from a previous paginated
request, where maxResults was used and the results exceeded
the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value. This
value is null when there are no more results to return.
Implementation
Future<ListIdentityProviderConfigsResponse> listIdentityProviderConfigs({
required String clusterName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/identity-provider-configs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIdentityProviderConfigsResponse.fromJson(response);
}