listUpdates method

Future<ListUpdatesResponse> listUpdates({
  1. required String name,
  2. String? addonName,
  3. String? capabilityName,
  4. int? maxResults,
  5. String? nextToken,
  6. String? nodegroupName,
})

Lists the updates associated with an Amazon EKS resource in your Amazon Web Services account, in the specified Amazon Web Services Region.

May throw ClientException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServerException.

Parameter name : The name of the Amazon EKS cluster to list updates for.

Parameter addonName : The names of the installed add-ons that have available updates.

Parameter capabilityName : The name of the capability for which you want to list updates.

Parameter maxResults : The maximum number of results, returned in paginated output. You receive maxResults in a single page, along with a nextToken response element. You can see the remaining results of the initial request by sending another request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, 100 results and a nextToken value, if applicable, are returned.

Parameter nextToken : The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Parameter nodegroupName : The name of the Amazon EKS managed node group to list updates for.

Implementation

Future<ListUpdatesResponse> listUpdates({
  required String name,
  String? addonName,
  String? capabilityName,
  int? maxResults,
  String? nextToken,
  String? nodegroupName,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (addonName != null) 'addonName': [addonName],
    if (capabilityName != null) 'capabilityName': [capabilityName],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (nodegroupName != null) 'nodegroupName': [nodegroupName],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/clusters/${Uri.encodeComponent(name)}/updates',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListUpdatesResponse.fromJson(response);
}