startInsightsRefresh method

Future<StartInsightsRefreshResponse> startInsightsRefresh({
  1. required String clusterName,
})

Initiates an on-demand refresh operation for cluster insights, getting the latest analysis outside of the standard refresh schedule.

May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServerException.

Parameter clusterName : The name of the cluster for the refresh insights operation.

Implementation

Future<StartInsightsRefreshResponse> startInsightsRefresh({
  required String clusterName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/clusters/${Uri.encodeComponent(clusterName)}/insights-refresh',
    exceptionFnMap: _exceptionFns,
  );
  return StartInsightsRefreshResponse.fromJson(response);
}