updateClusterConfig method

Future<UpdateClusterConfigResponse> updateClusterConfig({
  1. required String name,
  2. UpdateAccessConfigRequest? accessConfig,
  3. String? clientRequestToken,
  4. ComputeConfigRequest? computeConfig,
  5. ControlPlaneScalingConfig? controlPlaneScalingConfig,
  6. bool? deletionProtection,
  7. KubernetesNetworkConfigRequest? kubernetesNetworkConfig,
  8. Logging? logging,
  9. RemoteNetworkConfigRequest? remoteNetworkConfig,
  10. VpcConfigRequest? resourcesVpcConfig,
  11. StorageConfigRequest? storageConfig,
  12. UpgradePolicyRequest? upgradePolicy,
  13. ZonalShiftConfigRequest? zonalShiftConfig,
})

Updates an Amazon EKS cluster configuration. Your cluster continues to function during the update. The response output includes an update ID that you can use to track the status of your cluster update with DescribeUpdate.

You can use this operation to do the following actions:

  • You can use this API operation to enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs. By default, cluster control plane logs aren't exported to CloudWatch Logs. For more information, see Amazon EKS Cluster control plane logs in the Amazon EKS User Guide .
  • You can also use this API operation to enable or disable public and private access to your cluster's Kubernetes API server endpoint. By default, public access is enabled, and private access is disabled. For more information, see Cluster API server endpoint in the Amazon EKS User Guide .
  • You can also use this API operation to choose different subnets and security groups for the cluster. You must specify at least two subnets that are in different Availability Zones. You can't change which VPC the subnets are from, the subnets must be in the same VPC as the subnets that the cluster was created with. For more information about the VPC requirements, see https://docs.aws.amazon.com/eks/latest/userguide/network_reqs.html in the Amazon EKS User Guide .
  • You can also use this API operation to enable or disable ARC zonal shift. If zonal shift is enabled, Amazon Web Services configures zonal autoshift for the cluster.
  • You can also use this API operation to add, change, or remove the configuration in the cluster for EKS Hybrid Nodes. To remove the configuration, use the remoteNetworkConfig key with an object containing both subkeys with empty arrays for each. Here is an inline example: "remoteNetworkConfig": { "remoteNodeNetworks": \[\], "remotePodNetworks": \[\] }.
Cluster updates are asynchronous, and they should finish within a few minutes. During an update, the cluster status moves to UPDATING (this status transition is eventually consistent). When the update is complete (either Failed or Successful), the cluster status moves to Active.

May throw ClientException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ServerException. May throw ThrottlingException.

Parameter name : The name of the Amazon EKS cluster to update.

Parameter accessConfig : The access configuration for the cluster.

Parameter clientRequestToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Parameter computeConfig : Update the configuration of the compute capability of your EKS Auto Mode cluster. For example, enable the capability.

Parameter controlPlaneScalingConfig : The control plane scaling tier configuration. For more information, see EKS Provisioned Control Plane in the Amazon EKS User Guide.

Parameter deletionProtection : Specifies whether to enable or disable deletion protection for the cluster. When enabled (true), the cluster cannot be deleted until deletion protection is explicitly disabled. When disabled (false), the cluster can be deleted normally.

Parameter logging : Enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs . By default, cluster control plane logs aren't exported to CloudWatch Logs . For more information, see Amazon EKS cluster control plane logs in the Amazon EKS User Guide .

Parameter storageConfig : Update the configuration of the block storage capability of your EKS Auto Mode cluster. For example, enable the capability.

Parameter upgradePolicy : You can enable or disable extended support for clusters currently on standard support. You cannot disable extended support once it starts. You must enable extended support before your cluster exits standard support.

Parameter zonalShiftConfig : Enable or disable ARC zonal shift for the cluster. If zonal shift is enabled, Amazon Web Services configures zonal autoshift for the cluster.

Zonal shift is a feature of Amazon Application Recovery Controller (ARC). ARC zonal shift is designed to be a temporary measure that allows you to move traffic for a resource away from an impaired AZ until the zonal shift expires or you cancel it. You can extend the zonal shift if necessary.

You can start a zonal shift for an EKS cluster, or you can allow Amazon Web Services to do it for you by enabling zonal autoshift. This shift updates the flow of east-to-west network traffic in your cluster to only consider network endpoints for Pods running on worker nodes in healthy AZs. Additionally, any ALB or NLB handling ingress traffic for applications in your EKS cluster will automatically route traffic to targets in the healthy AZs. For more information about zonal shift in EKS, see Learn about Amazon Application Recovery Controller (ARC) Zonal Shift in Amazon EKS in the Amazon EKS User Guide .

Implementation

Future<UpdateClusterConfigResponse> updateClusterConfig({
  required String name,
  UpdateAccessConfigRequest? accessConfig,
  String? clientRequestToken,
  ComputeConfigRequest? computeConfig,
  ControlPlaneScalingConfig? controlPlaneScalingConfig,
  bool? deletionProtection,
  KubernetesNetworkConfigRequest? kubernetesNetworkConfig,
  Logging? logging,
  RemoteNetworkConfigRequest? remoteNetworkConfig,
  VpcConfigRequest? resourcesVpcConfig,
  StorageConfigRequest? storageConfig,
  UpgradePolicyRequest? upgradePolicy,
  ZonalShiftConfigRequest? zonalShiftConfig,
}) async {
  final $payload = <String, dynamic>{
    if (accessConfig != null) 'accessConfig': accessConfig,
    'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
    if (computeConfig != null) 'computeConfig': computeConfig,
    if (controlPlaneScalingConfig != null)
      'controlPlaneScalingConfig': controlPlaneScalingConfig,
    if (deletionProtection != null) 'deletionProtection': deletionProtection,
    if (kubernetesNetworkConfig != null)
      'kubernetesNetworkConfig': kubernetesNetworkConfig,
    if (logging != null) 'logging': logging,
    if (remoteNetworkConfig != null)
      'remoteNetworkConfig': remoteNetworkConfig,
    if (resourcesVpcConfig != null) 'resourcesVpcConfig': resourcesVpcConfig,
    if (storageConfig != null) 'storageConfig': storageConfig,
    if (upgradePolicy != null) 'upgradePolicy': upgradePolicy,
    if (zonalShiftConfig != null) 'zonalShiftConfig': zonalShiftConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/clusters/${Uri.encodeComponent(name)}/update-config',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateClusterConfigResponse.fromJson(response);
}