updateNodegroupVersion method
Updates the Kubernetes version or AMI version of an Amazon EKS managed node group.
You can update a node group using a launch template only if the node group was originally deployed with a launch template. Additionally, the launch template ID or name must match what was used when the node group was created. You can update the launch template version with necessary changes.
If you need to update a custom AMI in a node group that was deployed with a launch template, then update your custom AMI, specify the new ID in a new version of the launch template, and then update the node group to the new version of the launch template.
If you update without a launch template, then you can update to the latest available AMI version of a node group's current Kubernetes version by not specifying a Kubernetes version in the request. You can update to the latest AMI version of your cluster's current Kubernetes version by specifying your cluster's Kubernetes version in the request. For information about Linux versions, see Amazon EKS optimized Amazon Linux AMI versions in the Amazon EKS User Guide. For information about Windows versions, see Amazon EKS optimized Windows AMI versions in the Amazon EKS User Guide.
You cannot roll back a node group to an earlier Kubernetes version or AMI version.
When a node in a managed node group is terminated due to a scaling action
or update, every Pod on that node is drained first. Amazon
EKS attempts to drain the nodes gracefully and will fail if it is unable
to do so. You can force the update if Amazon EKS is unable to
drain the nodes as a result of a Pod disruption budget issue.
May throw ClientException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter clusterName :
The name of your cluster.
Parameter nodegroupName :
The name of the managed node group to update.
Parameter clientRequestToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Parameter force :
Force the update if any Pod on the existing node group can't
be drained due to a Pod disruption budget issue. If an update
fails because all Pods can't be drained, you can force the update after it
fails to terminate the old node whether or not any Pod is
running on the node.
Parameter launchTemplate :
An object representing a node group's launch template specification. You
can only update a node group using a launch template if the node group was
originally deployed with a launch template. When updating, you must
specify the same launch template ID or name that was used to create the
node group.
Parameter releaseVersion :
The AMI version of the Amazon EKS optimized AMI to use for the update. By
default, the latest available AMI version for the node group's Kubernetes
version is used. For information about Linux versions, see Amazon
EKS optimized Amazon Linux AMI versions in the Amazon EKS User
Guide. Amazon EKS managed node groups support the November 2022 and
later releases of the Windows AMIs. For information about Windows
versions, see Amazon
EKS optimized Windows AMI versions in the Amazon EKS User
Guide.
If you specify launchTemplate, and your launch template uses
a custom AMI, then don't specify releaseVersion, or the node
group update will fail. For more information about using launch templates
with Amazon EKS, see Customizing
managed nodes with launch templates in the Amazon EKS User
Guide.
Parameter version :
The Kubernetes version to update to. If no version is specified, then the
node group will be updated to match the cluster's current Kubernetes
version, and the latest available AMI for that version will be used. You
can also specify the Kubernetes version of the cluster to update the node
group to the latest AMI version of the cluster's Kubernetes version. If
you specify launchTemplate, and your launch template uses a
custom AMI, then don't specify version, or the node group
update will fail. For more information about using launch templates with
Amazon EKS, see Customizing
managed nodes with launch templates in the Amazon EKS User
Guide.
Implementation
Future<UpdateNodegroupVersionResponse> updateNodegroupVersion({
required String clusterName,
required String nodegroupName,
String? clientRequestToken,
bool? force,
LaunchTemplateSpecification? launchTemplate,
String? releaseVersion,
String? version,
}) async {
final $payload = <String, dynamic>{
'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (force != null) 'force': force,
if (launchTemplate != null) 'launchTemplate': launchTemplate,
if (releaseVersion != null) 'releaseVersion': releaseVersion,
if (version != null) 'version': version,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/node-groups/${Uri.encodeComponent(nodegroupName)}/update-version',
exceptionFnMap: _exceptionFns,
);
return UpdateNodegroupVersionResponse.fromJson(response);
}