elasti_cache library

Classes

AwsClientCredentials
AWS credentials.
ElastiCache
Amazon ElastiCache is a web service that makes it easier to set up, operate, and scale a distributed cache in the cloud.