authorizeCacheSecurityGroupIngress method
Allows network ingress to a cache security group. Applications using ElastiCache must be running on Amazon EC2, and Amazon EC2 security groups are used as the authorization mechanism.
May throw AuthorizationAlreadyExistsFault.
May throw CacheSecurityGroupNotFoundFault.
May throw InvalidCacheSecurityGroupStateFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
Parameter cacheSecurityGroupName :
The cache security group that allows network ingress.
Parameter eC2SecurityGroupName :
The Amazon EC2 security group to be authorized for ingress to the cache
security group.
Parameter eC2SecurityGroupOwnerId :
The Amazon account number of the Amazon EC2 security group owner. Note
that this is not the same thing as an Amazon access key ID - you must
provide a valid Amazon account number for this parameter.
Implementation
Future<AuthorizeCacheSecurityGroupIngressResult>
authorizeCacheSecurityGroupIngress({
required String cacheSecurityGroupName,
required String eC2SecurityGroupName,
required String eC2SecurityGroupOwnerId,
}) async {
final $request = <String, String>{
'CacheSecurityGroupName': cacheSecurityGroupName,
'EC2SecurityGroupName': eC2SecurityGroupName,
'EC2SecurityGroupOwnerId': eC2SecurityGroupOwnerId,
};
final $result = await _protocol.send(
$request,
action: 'AuthorizeCacheSecurityGroupIngress',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'AuthorizeCacheSecurityGroupIngressResult',
);
return AuthorizeCacheSecurityGroupIngressResult.fromXml($result);
}