createReplicationGroup method

Future<CreateReplicationGroupResult> createReplicationGroup({
  1. required String replicationGroupDescription,
  2. required String replicationGroupId,
  3. bool? atRestEncryptionEnabled,
  4. String? authToken,
  5. bool? autoMinorVersionUpgrade,
  6. bool? automaticFailoverEnabled,
  7. String? cacheNodeType,
  8. String? cacheParameterGroupName,
  9. List<String>? cacheSecurityGroupNames,
  10. String? cacheSubnetGroupName,
  11. ClusterMode? clusterMode,
  12. bool? dataTieringEnabled,
  13. Durability? durability,
  14. String? engine,
  15. String? engineVersion,
  16. String? globalReplicationGroupId,
  17. IpDiscovery? ipDiscovery,
  18. String? kmsKeyId,
  19. List<LogDeliveryConfigurationRequest>? logDeliveryConfigurations,
  20. bool? multiAZEnabled,
  21. NetworkType? networkType,
  22. List<NodeGroupConfiguration>? nodeGroupConfiguration,
  23. String? notificationTopicArn,
  24. int? numCacheClusters,
  25. int? numNodeGroups,
  26. int? port,
  27. List<String>? preferredCacheClusterAZs,
  28. String? preferredMaintenanceWindow,
  29. String? primaryClusterId,
  30. int? replicasPerNodeGroup,
  31. List<String>? securityGroupIds,
  32. String? serverlessCacheSnapshotName,
  33. List<String>? snapshotArns,
  34. String? snapshotName,
  35. int? snapshotRetentionLimit,
  36. String? snapshotWindow,
  37. List<Tag>? tags,
  38. bool? transitEncryptionEnabled,
  39. TransitEncryptionMode? transitEncryptionMode,
  40. List<String>? userGroupIds,
})

Creates a Valkey or Redis OSS (cluster mode disabled) or a Valkey or Redis OSS (cluster mode enabled) replication group.

This API can be used to create a standalone regional replication group or a secondary replication group associated with a Global datastore.

A Valkey or Redis OSS (cluster mode disabled) replication group is a collection of nodes, where one of the nodes is a read/write primary and the others are read-only replicas. Writes to the primary are asynchronously propagated to the replicas.

A Valkey or Redis OSS cluster-mode enabled cluster is comprised of from 1 to 90 shards (API/CLI: node groups). Each shard has a primary node and up to 5 read-only replica nodes. The configuration can range from 90 shards and 0 replicas to 15 shards and 5 replicas, which is the maximum number or replicas allowed.

The node or shard limit can be increased to a maximum of 500 per cluster if the Valkey or Redis OSS engine version is 5.0.6 or higher. For example, you can choose to configure a 500 node cluster that ranges between 83 shards (one primary and 5 replicas per shard) and 500 shards (single primary and no replicas). Make sure there are enough available IP addresses to accommodate the increase. Common pitfalls include the subnets in the subnet group have too small a CIDR range or the subnets are shared and heavily used by other clusters. For more information, see Creating a Subnet Group. For versions below 5.0.6, the limit is 250 per cluster.

To request a limit increase, see Amazon Service Limits and choose the limit type Nodes per cluster per instance type.

When a Valkey or Redis OSS (cluster mode disabled) replication group has been successfully created, you can add one or more read replicas to it, up to a total of 5 read replicas. If you need to increase or decrease the number of node groups (console: shards), you can use scaling. For more information, see Scaling self-designed clusters in the ElastiCache User Guide.

May throw CacheClusterNotFoundFault. May throw CacheParameterGroupNotFoundFault. May throw CacheSecurityGroupNotFoundFault. May throw CacheSubnetGroupNotFoundFault. May throw ClusterQuotaForCustomerExceededFault. May throw GlobalReplicationGroupNotFoundFault. May throw InsufficientCacheClusterCapacityFault. May throw InvalidCacheClusterStateFault. May throw InvalidGlobalReplicationGroupStateFault. May throw InvalidParameterCombinationException. May throw InvalidParameterValueException. May throw InvalidUserGroupStateFault. May throw InvalidVPCNetworkStateFault. May throw NodeGroupsPerReplicationGroupQuotaExceededFault. May throw NodeQuotaForClusterExceededFault. May throw NodeQuotaForCustomerExceededFault. May throw ReplicationGroupAlreadyExistsFault. May throw TagQuotaPerResourceExceeded. May throw UserGroupNotFoundFault.

Parameter replicationGroupDescription : A user-created description for the replication group.

Parameter replicationGroupId : The replication group identifier. This parameter is stored as a lowercase string.

Constraints:

  • A name must contain from 1 to 40 alphanumeric characters or hyphens.
  • The first character must be a letter.
  • A name cannot end with a hyphen or contain two consecutive hyphens.

Parameter atRestEncryptionEnabled : A flag that enables encryption at-rest on the replication group when set to true. In some cases, encryption at-rest may be enabled even when this value is false. Use StorageEncryptionType to view the effective encryption state of a cluster.

You cannot modify the value of AtRestEncryptionEnabled after the replication group is created.

Default: true when using Valkey, false when using Redis OSS

Parameter authToken : Reserved parameter. The password used to access a password protected server.

AuthToken can be specified only on replication groups where TransitEncryptionEnabled is true. Password constraints:

  • Must be only printable ASCII characters.
  • Must be at least 16 characters and no more than 128 characters in length.
  • The only permitted printable special characters are !, &, #, $, ^, <, >, and -. Other printable special characters cannot be used in the AUTH token.
For more information, see AUTH password at http://redis.io/commands/AUTH.

Parameter autoMinorVersionUpgrade : If you are running Valkey 7.2 and above or Redis OSS engine version 6.0 and above, set this parameter to yes to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.

Parameter automaticFailoverEnabled : Specifies whether a read-only replica is automatically promoted to read/write primary if the existing primary fails.

AutomaticFailoverEnabled must be enabled for Valkey or Redis OSS (cluster mode enabled) replication groups.

Default: false

Parameter cacheNodeType : The compute and memory capacity of the nodes in the node group (shard).

The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.

  • General purpose:
    • Current generation:

      M7g node types: cache.m7g.large, cache.m7g.xlarge, cache.m7g.2xlarge, cache.m7g.4xlarge, cache.m7g.8xlarge, cache.m7g.12xlarge, cache.m7g.16xlarge M6g node types (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward): cache.m6g.large, cache.m6g.xlarge, cache.m6g.2xlarge, cache.m6g.4xlarge, cache.m6g.8xlarge, cache.m6g.12xlarge, cache.m6g.16xlarge

      M5 node types: cache.m5.large, cache.m5.xlarge, cache.m5.2xlarge, cache.m5.4xlarge, cache.m5.12xlarge, cache.m5.24xlarge

      M4 node types: cache.m4.large, cache.m4.xlarge, cache.m4.2xlarge, cache.m4.4xlarge, cache.m4.10xlarge

      T4g node types (available only for Redis OSS engine version 5.0.6 onward and Memcached engine version 1.5.16 onward): cache.t4g.micro, cache.t4g.small, cache.t4g.medium

      T3 node types: cache.t3.micro, cache.t3.small, cache.t3.medium

      T2 node types: cache.t2.micro, cache.t2.small, cache.t2.medium

    • Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)

      T1 node types: cache.t1.micro

      M1 node types: cache.m1.small, cache.m1.medium, cache.m1.large, cache.m1.xlarge

      M3 node types: cache.m3.medium, cache.m3.large, cache.m3.xlarge, cache.m3.2xlarge

  • Compute optimized:
    • Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)

      C1 node types: cache.c1.xlarge

  • Memory optimized:
    • Current generation:

      R7g node types: cache.r7g.large, cache.r7g.xlarge, cache.r7g.2xlarge, cache.r7g.4xlarge, cache.r7g.8xlarge, cache.r7g.12xlarge, cache.r7g.16xlarge R6g node types (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward): cache.r6g.large, cache.r6g.xlarge, cache.r6g.2xlarge, cache.r6g.4xlarge, cache.r6g.8xlarge, cache.r6g.12xlarge, cache.r6g.16xlarge

      R5 node types: cache.r5.large, cache.r5.xlarge, cache.r5.2xlarge, cache.r5.4xlarge, cache.r5.12xlarge, cache.r5.24xlarge

      R4 node types: cache.r4.large, cache.r4.xlarge, cache.r4.2xlarge, cache.r4.4xlarge, cache.r4.8xlarge, cache.r4.16xlarge

    • Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)

      M2 node types: cache.m2.xlarge, cache.m2.2xlarge, cache.m2.4xlarge

      R3 node types: cache.r3.large, cache.r3.xlarge, cache.r3.2xlarge, cache.r3.4xlarge, cache.r3.8xlarge

Additional node type info
  • All current generation instance types are created in Amazon VPC by default.
  • Valkey or Redis OSS append-only files (AOF) are not supported for T1 or T2 instances.
  • Valkey or Redis OSS Multi-AZ with automatic failover is not supported on T1 instances.
  • The configuration variables appendonly and appendfsync are not supported on Valkey, or on Redis OSS version 2.8.22 and later.

Parameter cacheParameterGroupName : The name of the parameter group to associate with this replication group. If this argument is omitted, the default cache parameter group for the specified engine is used.

If you are running Valkey or Redis OSS version 3.2.4 or later, only one node group (shard), and want to use a default parameter group, we recommend that you specify the parameter group by name.

  • To create a Valkey or Redis OSS (cluster mode disabled) replication group, use CacheParameterGroupName=default.redis3.2.
  • To create a Valkey or Redis OSS (cluster mode enabled) replication group, use CacheParameterGroupName=default.redis3.2.cluster.on.

Parameter cacheSecurityGroupNames : A list of cache security group names to associate with this replication group.

Parameter cacheSubnetGroupName : The name of the cache subnet group to be used for the replication group.

Parameter clusterMode : Enabled or Disabled. To modify cluster mode from Disabled to Enabled, you must first set the cluster mode to Compatible. Compatible mode allows your Valkey or Redis OSS clients to connect using both cluster mode enabled and cluster mode disabled. After you migrate all Valkey or Redis OSS clients to use cluster mode enabled, you can then complete cluster mode configuration and set the cluster mode to Enabled.

Parameter dataTieringEnabled : Enables data tiering. Data tiering is only supported for replication groups using the r6gd node type. This parameter must be set to true when using r6gd nodes. For more information, see Data tiering.

Parameter durability : Specifies the durability setting for the replication group. When set to default, the service determines the effective durability based on the engine version, cluster mode, and other parameters. The resolved setting is reflected in the EffectiveDurability property of the replication group. For more information, see Durability.

Parameter engine : The name of the cache engine to be used for the clusters in this replication group. The value must be set to valkey or redis.

Parameter engineVersion : The version number of the cache engine to be used for the clusters in this replication group. To view the supported cache engine versions, use the DescribeCacheEngineVersions operation.

Important: You can upgrade to a newer engine version (see Selecting a Cache Engine and Version) in the ElastiCache User Guide, but you cannot downgrade to an earlier engine version. If you want to use an earlier engine version, you must delete the existing cluster or replication group and create it anew with the earlier engine version.

Parameter globalReplicationGroupId : The name of the Global datastore

Parameter ipDiscovery : The network type you choose when creating a replication group, either ipv4 | ipv6. IPv6 is supported for workloads using Valkey 7.2 and above, Redis OSS engine version 6.2 to 7.1 or Memcached engine version 1.6.6 and above on all instances built on the Nitro system.

Parameter kmsKeyId : The ID of the KMS key used to encrypt the disk in the cluster.

Parameter logDeliveryConfigurations : Specifies the destination, format and type of the logs.

Parameter multiAZEnabled : A flag indicating if you have Multi-AZ enabled to enhance fault tolerance. For more information, see Minimizing Downtime: Multi-AZ.

Parameter networkType : Must be either ipv4 | ipv6 | dual_stack. IPv6 is supported for workloads using Valkey 7.2 and above, Redis OSS engine version 6.2 to 7.1 and Memcached engine version 1.6.6 and above on all instances built on the Nitro system.

Parameter nodeGroupConfiguration : A list of node group (shard) configuration options. Each node group (shard) configuration has the following members: PrimaryAvailabilityZone, ReplicaAvailabilityZones, ReplicaCount, and Slots.

If you're creating a Valkey or Redis OSS (cluster mode disabled) or a Valkey or Redis OSS (cluster mode enabled) replication group, you can use this parameter to individually configure each node group (shard), or you can omit this parameter. However, it is required when seeding a Valkey or Redis OSS (cluster mode enabled) cluster from a S3 rdb file. You must configure each node group (shard) using this parameter because you must specify the slots for each node group.

Parameter notificationTopicArn : The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) topic to which notifications are sent.

Parameter numCacheClusters : The number of clusters this replication group initially has.

This parameter is not used if there is more than one node group (shard). You should use ReplicasPerNodeGroup instead.

If AutomaticFailoverEnabled is true, the value of this parameter must be at least 2. If AutomaticFailoverEnabled is false you can omit this parameter (it will default to 1), or you can explicitly set it to a value between 2 and 6.

The maximum permitted value for NumCacheClusters is 6 (1 primary plus 5 replicas).

Parameter numNodeGroups : An optional parameter that specifies the number of node groups (shards) for this Valkey or Redis OSS (cluster mode enabled) replication group. For Valkey or Redis OSS (cluster mode disabled) either omit this parameter or set it to 1.

Default: 1

Parameter port : The port number on which each member of the replication group accepts connections.

Parameter preferredCacheClusterAZs : A list of EC2 Availability Zones in which the replication group's clusters are created. The order of the Availability Zones in the list is the order in which clusters are allocated. The primary cluster is created in the first AZ in the list.

This parameter is not used if there is more than one node group (shard). You should use NodeGroupConfiguration instead.

The number of Availability Zones listed must equal the value of NumCacheClusters. Default: system chosen Availability Zones.

Parameter preferredMaintenanceWindow : Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.

Valid values for ddd are:

  • sun
  • mon
  • tue
  • wed
  • thu
  • fri
  • sat
Example: sun:23:00-mon:01:30

Parameter primaryClusterId : The identifier of the cluster that serves as the primary for this replication group. This cluster must already exist and have a status of available.

This parameter is not required if NumCacheClusters, NumNodeGroups, or ReplicasPerNodeGroup is specified.

Parameter replicasPerNodeGroup : An optional parameter that specifies the number of replica nodes in each node group (shard). Valid values are 0 to 5.

Parameter securityGroupIds : One or more Amazon VPC security groups associated with this replication group.

Use this parameter only when you are creating a replication group in an Amazon Virtual Private Cloud (Amazon VPC).

Parameter serverlessCacheSnapshotName : The name of the snapshot used to create a replication group. Available for Valkey, Redis OSS only.

Parameter snapshotArns : A list of Amazon Resource Names (ARN) that uniquely identify the Valkey or Redis OSS RDB snapshot files stored in Amazon S3. The snapshot files are used to populate the new replication group. The Amazon S3 object name in the ARN cannot contain any commas. The new replication group will have the number of node groups (console: shards) specified by the parameter NumNodeGroups or the number of node groups configured by NodeGroupConfiguration regardless of the number of ARNs specified here.

Example of an Amazon S3 ARN: arn:aws:s3:::my_bucket/snapshot1.rdb

Parameter snapshotName : The name of a snapshot from which to restore data into the new replication group. The snapshot status changes to restoring while the new replication group is being created.

Parameter snapshotRetentionLimit : The number of days for which ElastiCache retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.

Default: 0 (i.e., automatic backups are disabled for this cluster).

Parameter snapshotWindow : The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your node group (shard).

Example: 05:00-09:00

If you do not specify this parameter, ElastiCache automatically chooses an appropriate time range.

Parameter tags : A list of tags to be added to this resource. Tags are comma-separated key,value pairs (e.g. Key=myKey, Value=myKeyValue. You can include multiple tags as shown following: Key=myKey, Value=myKeyValue Key=mySecondKey, Value=mySecondKeyValue. Tags on replication groups will be replicated to all nodes.

Parameter transitEncryptionEnabled : A flag that enables in-transit encryption when set to true.

This parameter is valid only if the Engine parameter is redis, the EngineVersion parameter is 3.2.6, 4.x or later, and the cluster is being created in an Amazon VPC.

If you enable in-transit encryption, you must also specify a value for CacheSubnetGroup.

Required: Only available when creating a replication group in an Amazon VPC using Redis OSS version 3.2.6, 4.x or later.

Default: false

Parameter transitEncryptionMode : A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.

When setting TransitEncryptionEnabled to true, you can set your TransitEncryptionMode to preferred in the same request, to allow both encrypted and unencrypted connections at the same time. Once you migrate all your Valkey or Redis OSS clients to use encrypted connections you can modify the value to required to allow encrypted connections only.

Setting TransitEncryptionMode to required is a two-step process that requires you to first set the TransitEncryptionMode to preferred, after that you can set TransitEncryptionMode to required.

This process will not trigger the replacement of the replication group.

Parameter userGroupIds : The user group to associate with the replication group.

Implementation

Future<CreateReplicationGroupResult> createReplicationGroup({
  required String replicationGroupDescription,
  required String replicationGroupId,
  bool? atRestEncryptionEnabled,
  String? authToken,
  bool? autoMinorVersionUpgrade,
  bool? automaticFailoverEnabled,
  String? cacheNodeType,
  String? cacheParameterGroupName,
  List<String>? cacheSecurityGroupNames,
  String? cacheSubnetGroupName,
  ClusterMode? clusterMode,
  bool? dataTieringEnabled,
  Durability? durability,
  String? engine,
  String? engineVersion,
  String? globalReplicationGroupId,
  IpDiscovery? ipDiscovery,
  String? kmsKeyId,
  List<LogDeliveryConfigurationRequest>? logDeliveryConfigurations,
  bool? multiAZEnabled,
  NetworkType? networkType,
  List<NodeGroupConfiguration>? nodeGroupConfiguration,
  String? notificationTopicArn,
  int? numCacheClusters,
  int? numNodeGroups,
  int? port,
  List<String>? preferredCacheClusterAZs,
  String? preferredMaintenanceWindow,
  String? primaryClusterId,
  int? replicasPerNodeGroup,
  List<String>? securityGroupIds,
  String? serverlessCacheSnapshotName,
  List<String>? snapshotArns,
  String? snapshotName,
  int? snapshotRetentionLimit,
  String? snapshotWindow,
  List<Tag>? tags,
  bool? transitEncryptionEnabled,
  TransitEncryptionMode? transitEncryptionMode,
  List<String>? userGroupIds,
}) async {
  final $request = <String, String>{
    'ReplicationGroupDescription': replicationGroupDescription,
    'ReplicationGroupId': replicationGroupId,
    if (atRestEncryptionEnabled != null)
      'AtRestEncryptionEnabled': atRestEncryptionEnabled.toString(),
    if (authToken != null) 'AuthToken': authToken,
    if (autoMinorVersionUpgrade != null)
      'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
    if (automaticFailoverEnabled != null)
      'AutomaticFailoverEnabled': automaticFailoverEnabled.toString(),
    if (cacheNodeType != null) 'CacheNodeType': cacheNodeType,
    if (cacheParameterGroupName != null)
      'CacheParameterGroupName': cacheParameterGroupName,
    if (cacheSecurityGroupNames != null)
      if (cacheSecurityGroupNames.isEmpty)
        'CacheSecurityGroupNames': ''
      else
        for (var i1 = 0; i1 < cacheSecurityGroupNames.length; i1++)
          'CacheSecurityGroupNames.CacheSecurityGroupName.${i1 + 1}':
              cacheSecurityGroupNames[i1],
    if (cacheSubnetGroupName != null)
      'CacheSubnetGroupName': cacheSubnetGroupName,
    if (clusterMode != null) 'ClusterMode': clusterMode.value,
    if (dataTieringEnabled != null)
      'DataTieringEnabled': dataTieringEnabled.toString(),
    if (durability != null) 'Durability': durability.value,
    if (engine != null) 'Engine': engine,
    if (engineVersion != null) 'EngineVersion': engineVersion,
    if (globalReplicationGroupId != null)
      'GlobalReplicationGroupId': globalReplicationGroupId,
    if (ipDiscovery != null) 'IpDiscovery': ipDiscovery.value,
    if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
    if (logDeliveryConfigurations != null)
      if (logDeliveryConfigurations.isEmpty)
        'LogDeliveryConfigurations': ''
      else
        for (var i1 = 0; i1 < logDeliveryConfigurations.length; i1++)
          for (var e3 in logDeliveryConfigurations[i1].toQueryMap().entries)
            'LogDeliveryConfigurations.LogDeliveryConfigurationRequest.${i1 + 1}.${e3.key}':
                e3.value,
    if (multiAZEnabled != null) 'MultiAZEnabled': multiAZEnabled.toString(),
    if (networkType != null) 'NetworkType': networkType.value,
    if (nodeGroupConfiguration != null)
      if (nodeGroupConfiguration.isEmpty)
        'NodeGroupConfiguration': ''
      else
        for (var i1 = 0; i1 < nodeGroupConfiguration.length; i1++)
          for (var e3 in nodeGroupConfiguration[i1].toQueryMap().entries)
            'NodeGroupConfiguration.NodeGroupConfiguration.${i1 + 1}.${e3.key}':
                e3.value,
    if (notificationTopicArn != null)
      'NotificationTopicArn': notificationTopicArn,
    if (numCacheClusters != null)
      'NumCacheClusters': numCacheClusters.toString(),
    if (numNodeGroups != null) 'NumNodeGroups': numNodeGroups.toString(),
    if (port != null) 'Port': port.toString(),
    if (preferredCacheClusterAZs != null)
      if (preferredCacheClusterAZs.isEmpty)
        'PreferredCacheClusterAZs': ''
      else
        for (var i1 = 0; i1 < preferredCacheClusterAZs.length; i1++)
          'PreferredCacheClusterAZs.AvailabilityZone.${i1 + 1}':
              preferredCacheClusterAZs[i1],
    if (preferredMaintenanceWindow != null)
      'PreferredMaintenanceWindow': preferredMaintenanceWindow,
    if (primaryClusterId != null) 'PrimaryClusterId': primaryClusterId,
    if (replicasPerNodeGroup != null)
      'ReplicasPerNodeGroup': replicasPerNodeGroup.toString(),
    if (securityGroupIds != null)
      if (securityGroupIds.isEmpty)
        'SecurityGroupIds': ''
      else
        for (var i1 = 0; i1 < securityGroupIds.length; i1++)
          'SecurityGroupIds.SecurityGroupId.${i1 + 1}': securityGroupIds[i1],
    if (serverlessCacheSnapshotName != null)
      'ServerlessCacheSnapshotName': serverlessCacheSnapshotName,
    if (snapshotArns != null)
      if (snapshotArns.isEmpty)
        'SnapshotArns': ''
      else
        for (var i1 = 0; i1 < snapshotArns.length; i1++)
          'SnapshotArns.SnapshotArn.${i1 + 1}': snapshotArns[i1],
    if (snapshotName != null) 'SnapshotName': snapshotName,
    if (snapshotRetentionLimit != null)
      'SnapshotRetentionLimit': snapshotRetentionLimit.toString(),
    if (snapshotWindow != null) 'SnapshotWindow': snapshotWindow,
    if (tags != null)
      if (tags.isEmpty)
        'Tags': ''
      else
        for (var i1 = 0; i1 < tags.length; i1++)
          for (var e3 in tags[i1].toQueryMap().entries)
            'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
    if (transitEncryptionEnabled != null)
      'TransitEncryptionEnabled': transitEncryptionEnabled.toString(),
    if (transitEncryptionMode != null)
      'TransitEncryptionMode': transitEncryptionMode.value,
    if (userGroupIds != null)
      if (userGroupIds.isEmpty)
        'UserGroupIds': ''
      else
        for (var i1 = 0; i1 < userGroupIds.length; i1++)
          'UserGroupIds.member.${i1 + 1}': userGroupIds[i1],
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateReplicationGroup',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateReplicationGroupResult',
  );
  return CreateReplicationGroupResult.fromXml($result);
}