deleteCacheParameterGroup method
Deletes the specified cache parameter group. You cannot delete a cache parameter group if it is associated with any cache clusters. You cannot delete the default cache parameter groups in your account.
May throw CacheParameterGroupNotFoundFault.
May throw InvalidCacheParameterGroupStateFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
Parameter cacheParameterGroupName :
The name of the cache parameter group to delete.
Implementation
Future<void> deleteCacheParameterGroup({
required String cacheParameterGroupName,
}) async {
final $request = <String, String>{
'CacheParameterGroupName': cacheParameterGroupName,
};
await _protocol.send(
$request,
action: 'DeleteCacheParameterGroup',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}