deleteUserGroup method

Future<UserGroup> deleteUserGroup({
  1. required String userGroupId,
})

For Valkey engine version 7.2 onwards and Redis OSS 6.0 onwards: Deletes a user group. The user group must first be disassociated from the replication group before it can be deleted. For more information, see Using Role Based Access Control (RBAC).

May throw InvalidParameterValueException. May throw InvalidUserGroupStateFault. May throw ServiceLinkedRoleNotFoundFault. May throw UserGroupNotFoundFault.

Parameter userGroupId : The ID of the user group.

Implementation

Future<UserGroup> deleteUserGroup({
  required String userGroupId,
}) async {
  final $request = <String, String>{
    'UserGroupId': userGroupId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteUserGroup',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteUserGroupResult',
  );
  return UserGroup.fromXml($result);
}