describeServerlessCaches method

Future<DescribeServerlessCachesResponse> describeServerlessCaches({
  1. int? maxResults,
  2. String? nextToken,
  3. String? serverlessCacheName,
})

Returns information about a specific serverless cache. If no identifier is specified, then the API returns information on all the serverless caches belonging to this Amazon Web Services account.

May throw InvalidParameterCombinationException. May throw InvalidParameterValueException. May throw ServerlessCacheNotFoundFault.

Parameter maxResults : The maximum number of records in the response. If more records exist than the specified max-records value, the next token is included in the response so that remaining results can be retrieved. The default is 50.

Parameter nextToken : An optional marker returned from a prior request to support pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxResults.

Parameter serverlessCacheName : The identifier for the serverless cache. If this parameter is specified, only information about that specific serverless cache is returned. Default: NULL

Implementation

Future<DescribeServerlessCachesResponse> describeServerlessCaches({
  int? maxResults,
  String? nextToken,
  String? serverlessCacheName,
}) async {
  final $request = <String, String>{
    if (maxResults != null) 'MaxResults': maxResults.toString(),
    if (nextToken != null) 'NextToken': nextToken,
    if (serverlessCacheName != null)
      'ServerlessCacheName': serverlessCacheName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeServerlessCaches',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeServerlessCachesResult',
  );
  return DescribeServerlessCachesResponse.fromXml($result);
}