describeServiceUpdates method
Returns details of the service updates
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw ServiceUpdateNotFoundFault.
Parameter marker :
An optional marker returned from a prior request. Use this marker for
pagination of results from this operation. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response
Parameter serviceUpdateName :
The unique ID of the service update
Parameter serviceUpdateStatus :
The status of the service update
Implementation
Future<ServiceUpdatesMessage> describeServiceUpdates({
String? marker,
int? maxRecords,
String? serviceUpdateName,
List<ServiceUpdateStatus>? serviceUpdateStatus,
}) async {
final $request = <String, String>{
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (serviceUpdateName != null) 'ServiceUpdateName': serviceUpdateName,
if (serviceUpdateStatus != null)
if (serviceUpdateStatus.isEmpty)
'ServiceUpdateStatus': ''
else
for (var i1 = 0; i1 < serviceUpdateStatus.length; i1++)
'ServiceUpdateStatus.member.${i1 + 1}':
serviceUpdateStatus[i1].value,
};
final $result = await _protocol.send(
$request,
action: 'DescribeServiceUpdates',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeServiceUpdatesResult',
);
return ServiceUpdatesMessage.fromXml($result);
}