describeUsers method
Returns a list of users.
May throw InvalidParameterCombinationException.
May throw ServiceLinkedRoleNotFoundFault.
May throw UserNotFoundFault.
Parameter engine :
The engine.
Parameter filters :
Filter to determine the list of User IDs to return.
Parameter marker :
An optional marker returned from a prior request. Use this marker for
pagination of results from this operation. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords. >
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a marker is included in the
response so that the remaining results can be retrieved.
Parameter userId :
The ID of the user.
Implementation
Future<DescribeUsersResult> describeUsers({
String? engine,
List<Filter>? filters,
String? marker,
int? maxRecords,
String? userId,
}) async {
final $request = <String, String>{
if (engine != null) 'Engine': engine,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.member.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (userId != null) 'UserId': userId,
};
final $result = await _protocol.send(
$request,
action: 'DescribeUsers',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeUsersResult',
);
return DescribeUsersResult.fromXml($result);
}