disassociateGlobalReplicationGroup method

Future<DisassociateGlobalReplicationGroupResult> disassociateGlobalReplicationGroup({
  1. required String globalReplicationGroupId,
  2. required String replicationGroupId,
  3. required String replicationGroupRegion,
})

Remove a secondary cluster from the Global datastore using the Global datastore name. The secondary cluster will no longer receive updates from the primary cluster, but will remain as a standalone cluster in that Amazon region.

May throw GlobalReplicationGroupNotFoundFault. May throw InvalidGlobalReplicationGroupStateFault. May throw InvalidParameterCombinationException. May throw InvalidParameterValueException.

Parameter globalReplicationGroupId : The name of the Global datastore

Parameter replicationGroupId : The name of the secondary cluster you wish to remove from the Global datastore

Parameter replicationGroupRegion : The Amazon region of secondary cluster you wish to remove from the Global datastore

Implementation

Future<DisassociateGlobalReplicationGroupResult>
    disassociateGlobalReplicationGroup({
  required String globalReplicationGroupId,
  required String replicationGroupId,
  required String replicationGroupRegion,
}) async {
  final $request = <String, String>{
    'GlobalReplicationGroupId': globalReplicationGroupId,
    'ReplicationGroupId': replicationGroupId,
    'ReplicationGroupRegion': replicationGroupRegion,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DisassociateGlobalReplicationGroup',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DisassociateGlobalReplicationGroupResult',
  );
  return DisassociateGlobalReplicationGroupResult.fromXml($result);
}