exportServerlessCacheSnapshot method

Future<ExportServerlessCacheSnapshotResponse> exportServerlessCacheSnapshot({
  1. required String s3BucketName,
  2. required String serverlessCacheSnapshotName,
})

Provides the functionality to export the serverless cache snapshot data to Amazon S3. Available for Valkey and Redis OSS only.

May throw InvalidParameterValueException. May throw InvalidServerlessCacheSnapshotStateFault. May throw ServerlessCacheSnapshotNotFoundFault. May throw ServiceLinkedRoleNotFoundFault.

Parameter s3BucketName : Name of the Amazon S3 bucket to export the snapshot to. The Amazon S3 bucket must also be in same region as the snapshot. Available for Valkey and Redis OSS only.

Parameter serverlessCacheSnapshotName : The identifier of the serverless cache snapshot to be exported to S3. Available for Valkey and Redis OSS only.

Implementation

Future<ExportServerlessCacheSnapshotResponse> exportServerlessCacheSnapshot({
  required String s3BucketName,
  required String serverlessCacheSnapshotName,
}) async {
  final $request = <String, String>{
    'S3BucketName': s3BucketName,
    'ServerlessCacheSnapshotName': serverlessCacheSnapshotName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ExportServerlessCacheSnapshot',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ExportServerlessCacheSnapshotResult',
  );
  return ExportServerlessCacheSnapshotResponse.fromXml($result);
}