revokeCacheSecurityGroupIngress method

Future<RevokeCacheSecurityGroupIngressResult> revokeCacheSecurityGroupIngress({
  1. required String cacheSecurityGroupName,
  2. required String eC2SecurityGroupName,
  3. required String eC2SecurityGroupOwnerId,
})

Revokes ingress from a cache security group. Use this operation to disallow access from an Amazon EC2 security group that had been previously authorized.

May throw AuthorizationNotFoundFault. May throw CacheSecurityGroupNotFoundFault. May throw InvalidCacheSecurityGroupStateFault. May throw InvalidParameterCombinationException. May throw InvalidParameterValueException.

Parameter cacheSecurityGroupName : The name of the cache security group to revoke ingress from.

Parameter eC2SecurityGroupName : The name of the Amazon EC2 security group to revoke access from.

Parameter eC2SecurityGroupOwnerId : The Amazon account number of the Amazon EC2 security group owner. Note that this is not the same thing as an Amazon access key ID - you must provide a valid Amazon account number for this parameter.

Implementation

Future<RevokeCacheSecurityGroupIngressResult>
    revokeCacheSecurityGroupIngress({
  required String cacheSecurityGroupName,
  required String eC2SecurityGroupName,
  required String eC2SecurityGroupOwnerId,
}) async {
  final $request = <String, String>{
    'CacheSecurityGroupName': cacheSecurityGroupName,
    'EC2SecurityGroupName': eC2SecurityGroupName,
    'EC2SecurityGroupOwnerId': eC2SecurityGroupOwnerId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'RevokeCacheSecurityGroupIngress',
    version: '2015-02-02',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RevokeCacheSecurityGroupIngressResult',
  );
  return RevokeCacheSecurityGroupIngressResult.fromXml($result);
}