testFailover method
Represents the input of a TestFailover operation which tests
automatic failover on a specified node group (called shard in the console)
in a replication group (called cluster in the console).
This API is designed for testing the behavior of your application in case of ElastiCache failover. It is not designed to be an operational tool for initiating a failover to overcome a problem you may have with the cluster. Moreover, in certain conditions such as large-scale operational events, Amazon may block this API.
Note the following
- A customer can use this operation to test automatic failover on up to 15 shards (called node groups in the ElastiCache API and Amazon CLI) in any rolling 24-hour period.
- If calling this operation on shards in different clusters (called replication groups in the API and CLI), the calls can be made concurrently.
- If calling this operation multiple times on different shards in the same Valkey or Redis OSS (cluster mode enabled) replication group, the first node replacement must complete before a subsequent call can be made.
-
To determine whether the node replacement is complete you can check Events
using the Amazon ElastiCache console, the Amazon CLI, or the ElastiCache
API. Look for the following automatic failover related events, listed here
in order of occurrance:
-
Replication group message:
Test Failover API called for node group -
Cache cluster message:
Failover from primary node -
Replication group message:
Failover from primary node -
Cache cluster message:
Recovering cache nodes -
Cache cluster message:
Finished recovery for cache nodes
- Viewing ElastiCache Events in the ElastiCache User Guide
- DescribeEvents in the ElastiCache API Reference
-
Replication group message:
May throw APICallRateForCustomerExceededFault.
May throw InvalidCacheClusterStateFault.
May throw InvalidKMSKeyFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw InvalidReplicationGroupStateFault.
May throw NodeGroupNotFoundFault.
May throw ReplicationGroupNotFoundFault.
May throw TestFailoverNotAvailableFault.
Parameter nodeGroupId :
The name of the node group (called shard in the console) in this
replication group on which automatic failover is to be tested. You may
test automatic failover on up to 15 node groups in any rolling 24-hour
period.
Parameter replicationGroupId :
The name of the replication group (console: cluster) whose automatic
failover is being tested by this operation.
Implementation
Future<TestFailoverResult> testFailover({
required String nodeGroupId,
required String replicationGroupId,
}) async {
final $request = <String, String>{
'NodeGroupId': nodeGroupId,
'ReplicationGroupId': replicationGroupId,
};
final $result = await _protocol.send(
$request,
action: 'TestFailover',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'TestFailoverResult',
);
return TestFailoverResult.fromXml($result);
}