retrieveEnvironmentInfo method

Future<RetrieveEnvironmentInfoResultMessage> retrieveEnvironmentInfo({
  1. required EnvironmentInfoType infoType,
  2. String? environmentId,
  3. String? environmentName,
})

Retrieves the compiled information from a RequestEnvironmentInfo request.

Related Topics

Parameter infoType : The type of information to retrieve.

Parameter environmentId : The ID of the data's environment.

If no such environment is found, returns an InvalidParameterValue error.

Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

Parameter environmentName : The name of the data's environment.

If no such environment is found, returns an InvalidParameterValue error.

Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

Implementation

Future<RetrieveEnvironmentInfoResultMessage> retrieveEnvironmentInfo({
  required EnvironmentInfoType infoType,
  String? environmentId,
  String? environmentName,
}) async {
  final $request = <String, String>{
    'InfoType': infoType.value,
    if (environmentId != null) 'EnvironmentId': environmentId,
    if (environmentName != null) 'EnvironmentName': environmentName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'RetrieveEnvironmentInfo',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RetrieveEnvironmentInfoResult',
  );
  return RetrieveEnvironmentInfoResultMessage.fromXml($result);
}