terminateEnvironment method

Future<EnvironmentDescription> terminateEnvironment({
  1. String? environmentId,
  2. String? environmentName,
  3. bool? forceTerminate,
  4. bool? terminateResources,
})

Terminates the specified environment.

May throw InsufficientPrivilegesException.

Parameter environmentId : The ID of the environment to terminate.

Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

Parameter environmentName : The name of the environment to terminate.

Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

Parameter forceTerminate : Terminates the target environment even if another environment in the same group is dependent on it.

Parameter terminateResources : Indicates whether the associated AWS resources should shut down when the environment is terminated:

  • true: The specified environment as well as the associated AWS resources, such as Auto Scaling group and LoadBalancer, are terminated.
  • false: AWS Elastic Beanstalk resource management is removed from the environment, but the AWS resources continue to operate.
For more information, see the AWS Elastic Beanstalk User Guide.

Default: true

Valid Values: true | false

Implementation

Future<EnvironmentDescription> terminateEnvironment({
  String? environmentId,
  String? environmentName,
  bool? forceTerminate,
  bool? terminateResources,
}) async {
  final $request = <String, String>{
    if (environmentId != null) 'EnvironmentId': environmentId,
    if (environmentName != null) 'EnvironmentName': environmentName,
    if (forceTerminate != null) 'ForceTerminate': forceTerminate.toString(),
    if (terminateResources != null)
      'TerminateResources': terminateResources.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'TerminateEnvironment',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'TerminateEnvironmentResult',
  );
  return EnvironmentDescription.fromXml($result);
}