deleteLoadBalancerPolicy method

Future<void> deleteLoadBalancerPolicy({
  1. required String loadBalancerName,
  2. required String policyName,
})

Deletes the specified policy from the specified load balancer. This policy must not be enabled for any listeners.

May throw AccessPointNotFoundException. May throw InvalidConfigurationRequestException.

Parameter loadBalancerName : The name of the load balancer.

Parameter policyName : The name of the policy.

Implementation

Future<void> deleteLoadBalancerPolicy({
  required String loadBalancerName,
  required String policyName,
}) async {
  final $request = <String, String>{
    'LoadBalancerName': loadBalancerName,
    'PolicyName': policyName,
  };
  await _protocol.send(
    $request,
    action: 'DeleteLoadBalancerPolicy',
    version: '2012-06-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteLoadBalancerPolicyResult',
  );
}