describeAccountLimits method

Future<DescribeAccountLimitsOutput> describeAccountLimits({
  1. String? marker,
  2. int? pageSize,
})

Describes the current Elastic Load Balancing resource limits for your AWS account.

For more information, see Limits for Your Classic Load Balancer in the Classic Load Balancers Guide.

Parameter marker : The marker for the next set of results. (You received this marker from a previous call.)

Parameter pageSize : The maximum number of results to return with this call.

Implementation

Future<DescribeAccountLimitsOutput> describeAccountLimits({
  String? marker,
  int? pageSize,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    1,
    400,
  );
  final $request = <String, String>{
    if (marker != null) 'Marker': marker,
    if (pageSize != null) 'PageSize': pageSize.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeAccountLimits',
    version: '2012-06-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeAccountLimitsResult',
  );
  return DescribeAccountLimitsOutput.fromXml($result);
}