ElasticLoadBalancingV2 class

A load balancer distributes incoming traffic across targets, such as your EC2 instances. This enables you to increase the availability of your application. The load balancer also monitors the health of its registered targets and ensures that it routes traffic only to healthy targets. You configure your load balancer to accept incoming traffic by specifying one or more listeners, which are configured with a protocol and port number for connections from clients to the load balancer. You configure a target group with a protocol and port number for connections from the load balancer to the targets, and with health check settings to be used when checking the health status of the targets.

Constructors

ElasticLoadBalancingV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListenerCertificates({required List<Certificate> certificates, required String listenerArn}) Future<AddListenerCertificatesOutput>
Adds the specified SSL server certificate to the certificate list for the specified HTTPS or TLS listener.
addTags({required List<String> resourceArns, required List<Tag> tags}) Future<void>
Adds the specified tags to the specified Elastic Load Balancing resource. You can tag your Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, trust stores, listeners, and rules.
addTrustStoreRevocations({required String trustStoreArn, List<RevocationContent>? revocationContents}) Future<AddTrustStoreRevocationsOutput>
Adds the specified revocation file to the specified trust store.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createListener({required List<Action> defaultActions, required String loadBalancerArn, List<String>? alpnPolicy, List<Certificate>? certificates, MutualAuthenticationAttributes? mutualAuthentication, int? port, ProtocolEnum? protocol, String? sslPolicy, List<Tag>? tags}) Future<CreateListenerOutput>
Creates a listener for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer.
createLoadBalancer({required String name, String? customerOwnedIpv4Pool, EnablePrefixForIpv6SourceNatEnum? enablePrefixForIpv6SourceNat, IpAddressType? ipAddressType, IpamPools? ipamPools, LoadBalancerSchemeEnum? scheme, List<String>? securityGroups, List<SubnetMapping>? subnetMappings, List<String>? subnets, List<Tag>? tags, LoadBalancerTypeEnum? type}) Future<CreateLoadBalancerOutput>
Creates an Application Load Balancer, Network Load Balancer, or Gateway Load Balancer.
createRule({required List<Action> actions, required List<RuleCondition> conditions, required String listenerArn, required int priority, List<Tag>? tags, List<RuleTransform>? transforms}) Future<CreateRuleOutput>
Creates a rule for the specified listener. The listener must be associated with an Application Load Balancer.
createTargetGroup({required String name, bool? healthCheckEnabled, int? healthCheckIntervalSeconds, String? healthCheckPath, String? healthCheckPort, ProtocolEnum? healthCheckProtocol, int? healthCheckTimeoutSeconds, int? healthyThresholdCount, TargetGroupIpAddressTypeEnum? ipAddressType, Matcher? matcher, int? port, ProtocolEnum? protocol, String? protocolVersion, List<Tag>? tags, int? targetControlPort, TargetTypeEnum? targetType, int? unhealthyThresholdCount, String? vpcId}) Future<CreateTargetGroupOutput>
Creates a target group.
createTrustStore({required String caCertificatesBundleS3Bucket, required String caCertificatesBundleS3Key, required String name, String? caCertificatesBundleS3ObjectVersion, List<Tag>? tags}) Future<CreateTrustStoreOutput>
Creates a trust store.
deleteListener({required String listenerArn}) Future<void>
Deletes the specified listener.
deleteLoadBalancer({required String loadBalancerArn}) Future<void>
Deletes the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. Deleting a load balancer also deletes its listeners.
deleteRule({required String ruleArn}) Future<void>
Deletes the specified rule.
deleteSharedTrustStoreAssociation({required String resourceArn, required String trustStoreArn}) Future<void>
Deletes a shared trust store association.
deleteTargetGroup({required String targetGroupArn}) Future<void>
Deletes the specified target group.
deleteTrustStore({required String trustStoreArn}) Future<void>
Deletes a trust store.
deregisterTargets({required String targetGroupArn, required List<TargetDescription> targets}) Future<void>
Deregisters the specified targets from the specified target group. After the targets are deregistered, they no longer receive traffic from the load balancer.
describeAccountLimits({String? marker, int? pageSize}) Future<DescribeAccountLimitsOutput>
Describes the current Elastic Load Balancing resource limits for your Amazon Web Services account.
describeCapacityReservation({required String loadBalancerArn}) Future<DescribeCapacityReservationOutput>
Describes the capacity reservation status for the specified load balancer.
describeListenerAttributes({required String listenerArn}) Future<DescribeListenerAttributesOutput>
Describes the attributes for the specified listener.
describeListenerCertificates({required String listenerArn, String? marker, int? pageSize}) Future<DescribeListenerCertificatesOutput>
Describes the default certificate and the certificate list for the specified HTTPS or TLS listener.
describeListeners({List<String>? listenerArns, String? loadBalancerArn, String? marker, int? pageSize}) Future<DescribeListenersOutput>
Describes the specified listeners or the listeners for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. You must specify either a load balancer or one or more listeners.
describeLoadBalancerAttributes({required String loadBalancerArn}) Future<DescribeLoadBalancerAttributesOutput>
Describes the attributes for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer.
describeLoadBalancers({List<String>? loadBalancerArns, String? marker, List<String>? names, int? pageSize}) Future<DescribeLoadBalancersOutput>
Describes the specified load balancers or all of your load balancers.
describeRules({String? listenerArn, String? marker, int? pageSize, List<String>? ruleArns}) Future<DescribeRulesOutput>
Describes the specified rules or the rules for the specified listener. You must specify either a listener or rules.
describeSSLPolicies({LoadBalancerTypeEnum? loadBalancerType, String? marker, List<String>? names, int? pageSize}) Future<DescribeSSLPoliciesOutput>
Describes the specified policies or all policies used for SSL negotiation.
describeTags({required List<String> resourceArns}) Future<DescribeTagsOutput>
Describes the tags for the specified Elastic Load Balancing resources. You can describe the tags for one or more Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, listeners, or rules.
describeTargetGroupAttributes({required String targetGroupArn}) Future<DescribeTargetGroupAttributesOutput>
Describes the attributes for the specified target group.
describeTargetGroups({String? loadBalancerArn, String? marker, List<String>? names, int? pageSize, List<String>? targetGroupArns}) Future<DescribeTargetGroupsOutput>
Describes the specified target groups or all of your target groups. By default, all target groups are described. Alternatively, you can specify one of the following to filter the results: the ARN of the load balancer, the names of one or more target groups, or the ARNs of one or more target groups.
describeTargetHealth({required String targetGroupArn, List<DescribeTargetHealthInputIncludeEnum>? include, List<TargetDescription>? targets}) Future<DescribeTargetHealthOutput>
Describes the health of the specified targets or all of your targets.
describeTrustStoreAssociations({required String trustStoreArn, String? marker, int? pageSize}) Future<DescribeTrustStoreAssociationsOutput>
Describes all resources associated with the specified trust store.
describeTrustStoreRevocations({required String trustStoreArn, String? marker, int? pageSize, List<int>? revocationIds}) Future<DescribeTrustStoreRevocationsOutput>
Describes the revocation files in use by the specified trust store or revocation files.
describeTrustStores({String? marker, List<String>? names, int? pageSize, List<String>? trustStoreArns}) Future<DescribeTrustStoresOutput>
Describes all trust stores for the specified account.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyOutput>
Retrieves the resource policy for a specified resource.
getTrustStoreCaCertificatesBundle({required String trustStoreArn}) Future<GetTrustStoreCaCertificatesBundleOutput>
Retrieves the ca certificate bundle.
getTrustStoreRevocationContent({required int revocationId, required String trustStoreArn}) Future<GetTrustStoreRevocationContentOutput>
Retrieves the specified revocation file.
modifyCapacityReservation({required String loadBalancerArn, MinimumLoadBalancerCapacity? minimumLoadBalancerCapacity, bool? resetCapacityReservation}) Future<ModifyCapacityReservationOutput>
Modifies the capacity reservation of the specified load balancer.
modifyIpPools({required String loadBalancerArn, IpamPools? ipamPools, List<RemoveIpamPoolEnum>? removeIpamPools}) Future<ModifyIpPoolsOutput>
[Application Load Balancers] Modify the IP pool associated to a load balancer.
modifyListener({required String listenerArn, List<String>? alpnPolicy, List<Certificate>? certificates, List<Action>? defaultActions, MutualAuthenticationAttributes? mutualAuthentication, int? port, ProtocolEnum? protocol, String? sslPolicy}) Future<ModifyListenerOutput>
Replaces the specified properties of the specified listener. Any properties that you do not specify remain unchanged.
modifyListenerAttributes({required List<ListenerAttribute> attributes, required String listenerArn}) Future<ModifyListenerAttributesOutput>
Modifies the specified attributes of the specified listener.
modifyLoadBalancerAttributes({required List<LoadBalancerAttribute> attributes, required String loadBalancerArn}) Future<ModifyLoadBalancerAttributesOutput>
Modifies the specified attributes of the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer.
modifyRule({required String ruleArn, List<Action>? actions, List<RuleCondition>? conditions, bool? resetTransforms, List<RuleTransform>? transforms}) Future<ModifyRuleOutput>
Replaces the specified properties of the specified rule. Any properties that you do not specify are unchanged.
modifyTargetGroup({required String targetGroupArn, bool? healthCheckEnabled, int? healthCheckIntervalSeconds, String? healthCheckPath, String? healthCheckPort, ProtocolEnum? healthCheckProtocol, int? healthCheckTimeoutSeconds, int? healthyThresholdCount, Matcher? matcher, int? unhealthyThresholdCount}) Future<ModifyTargetGroupOutput>
Modifies the health checks used when evaluating the health state of the targets in the specified target group.
modifyTargetGroupAttributes({required List<TargetGroupAttribute> attributes, required String targetGroupArn}) Future<ModifyTargetGroupAttributesOutput>
Modifies the specified attributes of the specified target group.
modifyTrustStore({required String caCertificatesBundleS3Bucket, required String caCertificatesBundleS3Key, required String trustStoreArn, String? caCertificatesBundleS3ObjectVersion}) Future<ModifyTrustStoreOutput>
Update the ca certificate bundle for the specified trust store.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerTargets({required String targetGroupArn, required List<TargetDescription> targets}) Future<void>
Registers the specified targets with the specified target group.
removeListenerCertificates({required List<Certificate> certificates, required String listenerArn}) Future<void>
Removes the specified certificate from the certificate list for the specified HTTPS or TLS listener.
removeTags({required List<String> resourceArns, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified Elastic Load Balancing resources. You can remove the tags for one or more Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, listeners, or rules.
removeTrustStoreRevocations({required List<int> revocationIds, required String trustStoreArn}) Future<void>
Removes the specified revocation file from the specified trust store.
setIpAddressType({required IpAddressType ipAddressType, required String loadBalancerArn}) Future<SetIpAddressTypeOutput>
Sets the type of IP addresses used by the subnets of the specified load balancer.
setRulePriorities({required List<RulePriorityPair> rulePriorities}) Future<SetRulePrioritiesOutput>
Sets the priorities of the specified rules.
setSecurityGroups({required String loadBalancerArn, required List<String> securityGroups, EnforceSecurityGroupInboundRulesOnPrivateLinkTrafficEnum? enforceSecurityGroupInboundRulesOnPrivateLinkTraffic}) Future<SetSecurityGroupsOutput>
Associates the specified security groups with the specified Application Load Balancer or Network Load Balancer. The specified security groups override the previously associated security groups.
setSubnets({required String loadBalancerArn, EnablePrefixForIpv6SourceNatEnum? enablePrefixForIpv6SourceNat, IpAddressType? ipAddressType, List<SubnetMapping>? subnetMappings, List<String>? subnets}) Future<SetSubnetsOutput>
Enables the Availability Zones for the specified public subnets for the specified Application Load Balancer, Network Load Balancer or Gateway Load Balancer. The specified subnets replace the previously enabled subnets.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited