createTargetGroup method
- required String name,
- bool? healthCheckEnabled,
- int? healthCheckIntervalSeconds,
- String? healthCheckPath,
- String? healthCheckPort,
- ProtocolEnum? healthCheckProtocol,
- int? healthCheckTimeoutSeconds,
- int? healthyThresholdCount,
- TargetGroupIpAddressTypeEnum? ipAddressType,
- Matcher? matcher,
- int? port,
- ProtocolEnum? protocol,
- String? protocolVersion,
- List<
Tag> ? tags, - int? targetControlPort,
- TargetTypeEnum? targetType,
- int? unhealthyThresholdCount,
- String? vpcId,
Creates a target group.
For more information, see the following:
- Target groups for your Application Load Balancers
- Target groups for your Network Load Balancers
- Target groups for your Gateway Load Balancers
May throw DuplicateTargetGroupNameException.
May throw InvalidConfigurationRequestException.
May throw TooManyTagsException.
May throw TooManyTargetGroupsException.
Parameter name :
The name of the target group.
This name must be unique per region per account, can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, and must not begin or end with a hyphen.
Parameter healthCheckEnabled :
Indicates whether health checks are enabled. If the target type is
lambda, health checks are disabled by default but can be
enabled. If the target type is instance, ip, or
alb, health checks are always enabled and can't be disabled.
Parameter healthCheckIntervalSeconds :
The approximate amount of time, in seconds, between health checks of an
individual target. The range is 5-300. If the target group protocol is
TCP, TLS, UDP, TCP_UDP, QUIC, TCP_QUIC, HTTP or HTTPS, the default is 30
seconds. If the target group protocol is GENEVE, the default is 10
seconds. If the target type is lambda, the default is 35
seconds.
Parameter healthCheckPath :
[HTTP/HTTPS health checks] The destination for health checks on the
targets.
[HTTP1 or HTTP2 protocol version] The ping path. The default is /.
[GRPC protocol version] The path of a custom health check method with the format /package.service/method. The default is /Amazon Web Services.ALB/healthcheck.
Parameter healthCheckPort :
The port the load balancer uses when performing health checks on targets.
If the protocol is HTTP, HTTPS, TCP, TLS, UDP, TCP_UDP, QUIC, or TCP_QUIC
the default is traffic-port, which is the port on which each
target receives traffic from the load balancer. If the protocol is GENEVE,
the default is port 80.
Parameter healthCheckProtocol :
The protocol the load balancer uses when performing health checks on
targets. For Application Load Balancers, the default is HTTP. For Network
Load Balancers and Gateway Load Balancers, the default is TCP. The TCP
protocol is not supported for health checks if the protocol of the target
group is HTTP or HTTPS. The GENEVE, TLS, UDP, TCP_UDP, QUIC, and TCP_QUIC
protocols are not supported for health checks.
Parameter healthCheckTimeoutSeconds :
The amount of time, in seconds, during which no response from a target
means a failed health check. The range is 2–120 seconds. For target groups
with a protocol of HTTP, the default is 6 seconds. For target groups with
a protocol of TCP, TLS or HTTPS, the default is 10 seconds. For target
groups with a protocol of GENEVE, the default is 5 seconds. If the target
type is lambda, the default is 30 seconds.
Parameter healthyThresholdCount :
The number of consecutive health check successes required before
considering a target healthy. The range is 2-10. If the target group
protocol is TCP, TCP_UDP, UDP, TLS, HTTP or HTTPS, the default is 5. For
target groups with a protocol of GENEVE, the default is 5. If the target
type is lambda, the default is 5.
Parameter ipAddressType :
The IP address type. The default value is ipv4.
Parameter matcher :
[HTTP/HTTPS health checks] The HTTP or gRPC codes to use when checking
for a successful response from a target. For target groups with a protocol
of TCP, TCP_UDP, UDP, QUIC, TCP_QUIC, or TLS the range is 200-599. For
target groups with a protocol of HTTP or HTTPS, the range is 200-499. For
target groups with a protocol of GENEVE, the range is 200-399.
Parameter port :
The port on which the targets receive traffic. This port is used unless
you specify a port override when registering the target. If the target is
a Lambda function, this parameter does not apply. If the protocol is
GENEVE, the supported port is 6081.
Parameter protocol :
The protocol to use for routing traffic to the targets. For Application
Load Balancers, the supported protocols are HTTP and HTTPS. For Network
Load Balancers, the supported protocols are TCP, TLS, UDP, TCP_UDP, QUIC,
or TCP_QUIC. For Gateway Load Balancers, the supported protocol is GENEVE.
A TCP_UDP listener must be associated with a TCP_UDP target group. A
TCP_QUIC listener must be associated with a TCP_QUIC target group. If the
target is a Lambda function, this parameter does not apply.
Parameter protocolVersion :
[HTTP/HTTPS protocol] The protocol version. Specify GRPC to
send requests to targets using gRPC. Specify HTTP2 to send
requests to targets using HTTP/2. The default is HTTP1, which
sends requests to targets using HTTP/1.1.
Parameter tags :
The tags to assign to the target group.
Parameter targetControlPort :
The port on which the target control agent and application load balancer
exchange management traffic for the target optimizer feature.
Parameter targetType :
The type of target that you must specify when registering targets with
this target group. You can't specify targets for a target group using more
than one target type.
-
instance- Register targets by instance ID. This is the default value. -
ip- Register targets by IP address. You can specify IP addresses from the subnets of the virtual private cloud (VPC) for the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and 192.168.0.0/16), and the RFC 6598 range (100.64.0.0/10). You can't specify publicly routable IP addresses. -
lambda- Register a single Lambda function as a target. -
alb- Register a single Application Load Balancer as a target.
Parameter unhealthyThresholdCount :
The number of consecutive health check failures required before
considering a target unhealthy. The range is 2-10. If the target group
protocol is TCP, TCP_UDP, UDP, TLS, QUIC, TCP_QUIC, HTTP or HTTPS, the
default is 2. For target groups with a protocol of GENEVE, the default is
2. If the target type is lambda, the default is 5.
Parameter vpcId :
The identifier of the virtual private cloud (VPC). If the target is a
Lambda function, this parameter does not apply. Otherwise, this parameter
is required.
Implementation
Future<CreateTargetGroupOutput> createTargetGroup({
required String name,
bool? healthCheckEnabled,
int? healthCheckIntervalSeconds,
String? healthCheckPath,
String? healthCheckPort,
ProtocolEnum? healthCheckProtocol,
int? healthCheckTimeoutSeconds,
int? healthyThresholdCount,
TargetGroupIpAddressTypeEnum? ipAddressType,
Matcher? matcher,
int? port,
ProtocolEnum? protocol,
String? protocolVersion,
List<Tag>? tags,
int? targetControlPort,
TargetTypeEnum? targetType,
int? unhealthyThresholdCount,
String? vpcId,
}) async {
_s.validateNumRange(
'healthCheckIntervalSeconds',
healthCheckIntervalSeconds,
5,
300,
);
_s.validateNumRange(
'healthCheckTimeoutSeconds',
healthCheckTimeoutSeconds,
2,
120,
);
_s.validateNumRange(
'healthyThresholdCount',
healthyThresholdCount,
2,
10,
);
_s.validateNumRange(
'port',
port,
1,
65535,
);
_s.validateNumRange(
'targetControlPort',
targetControlPort,
1,
65535,
);
_s.validateNumRange(
'unhealthyThresholdCount',
unhealthyThresholdCount,
2,
10,
);
final $request = <String, String>{
'Name': name,
if (healthCheckEnabled != null)
'HealthCheckEnabled': healthCheckEnabled.toString(),
if (healthCheckIntervalSeconds != null)
'HealthCheckIntervalSeconds': healthCheckIntervalSeconds.toString(),
if (healthCheckPath != null) 'HealthCheckPath': healthCheckPath,
if (healthCheckPort != null) 'HealthCheckPort': healthCheckPort,
if (healthCheckProtocol != null)
'HealthCheckProtocol': healthCheckProtocol.value,
if (healthCheckTimeoutSeconds != null)
'HealthCheckTimeoutSeconds': healthCheckTimeoutSeconds.toString(),
if (healthyThresholdCount != null)
'HealthyThresholdCount': healthyThresholdCount.toString(),
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (matcher != null)
for (var e1 in matcher.toQueryMap().entries)
'Matcher.${e1.key}': e1.value,
if (port != null) 'Port': port.toString(),
if (protocol != null) 'Protocol': protocol.value,
if (protocolVersion != null) 'ProtocolVersion': protocolVersion,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
if (targetControlPort != null)
'TargetControlPort': targetControlPort.toString(),
if (targetType != null) 'TargetType': targetType.value,
if (unhealthyThresholdCount != null)
'UnhealthyThresholdCount': unhealthyThresholdCount.toString(),
if (vpcId != null) 'VpcId': vpcId,
};
final $result = await _protocol.send(
$request,
action: 'CreateTargetGroup',
version: '2015-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateTargetGroupResult',
);
return CreateTargetGroupOutput.fromXml($result);
}