describeRules method
Describes the specified rules or the rules for the specified listener. You must specify either a listener or rules.
May throw ListenerNotFoundException.
May throw RuleNotFoundException.
May throw UnsupportedProtocolException.
Parameter listenerArn :
The Amazon Resource Name (ARN) of the listener.
Parameter marker :
The marker for the next set of results. (You received this marker from a
previous call.)
Parameter pageSize :
The maximum number of results to return with this call.
Parameter ruleArns :
The Amazon Resource Names (ARN) of the rules.
Implementation
Future<DescribeRulesOutput> describeRules({
String? listenerArn,
String? marker,
int? pageSize,
List<String>? ruleArns,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
400,
);
final $request = <String, String>{
if (listenerArn != null) 'ListenerArn': listenerArn,
if (marker != null) 'Marker': marker,
if (pageSize != null) 'PageSize': pageSize.toString(),
if (ruleArns != null)
if (ruleArns.isEmpty)
'RuleArns': ''
else
for (var i1 = 0; i1 < ruleArns.length; i1++)
'RuleArns.member.${i1 + 1}': ruleArns[i1],
};
final $result = await _protocol.send(
$request,
action: 'DescribeRules',
version: '2015-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeRulesResult',
);
return DescribeRulesOutput.fromXml($result);
}