describeTargetGroupAttributes method
Future<DescribeTargetGroupAttributesOutput>
describeTargetGroupAttributes({
- required String targetGroupArn,
Describes the attributes for the specified target group.
For more information, see the following:
- Target group attributes in the Application Load Balancers Guide
- Target group attributes in the Network Load Balancers Guide
- Target group attributes in the Gateway Load Balancers Guide
May throw TargetGroupNotFoundException.
Parameter targetGroupArn :
The Amazon Resource Name (ARN) of the target group.
Implementation
Future<DescribeTargetGroupAttributesOutput> describeTargetGroupAttributes({
required String targetGroupArn,
}) async {
final $request = <String, String>{
'TargetGroupArn': targetGroupArn,
};
final $result = await _protocol.send(
$request,
action: 'DescribeTargetGroupAttributes',
version: '2015-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeTargetGroupAttributesResult',
);
return DescribeTargetGroupAttributesOutput.fromXml($result);
}