Elasticsearch class
Use the Amazon Elasticsearch Configuration API to create, configure, and manage Elasticsearch domains.
Constructors
- Elasticsearch({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptInboundCrossClusterSearchConnection(
{required String crossClusterSearchConnectionId}) → Future< AcceptInboundCrossClusterSearchConnectionResponse> - Allows the destination domain owner to accept an inbound cross-cluster search connection request.
-
addTags(
{required String arn, required List< Tag> tagList}) → Future<void> - Attaches tags to an existing Elasticsearch domain. Tags are a set of case-sensitive key value pairs. An Elasticsearch domain may have up to 10 tags. See Tagging Amazon Elasticsearch Service Domains for more information.
-
associatePackage(
{required String domainName, required String packageID}) → Future< AssociatePackageResponse> - Associates a package with an Amazon ES domain.
- Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
cancelDomainConfigChange(
{required String domainName, bool? dryRun}) → Future< CancelDomainConfigChangeResponse> - Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
cancelElasticsearchServiceSoftwareUpdate(
{required String domainName}) → Future< CancelElasticsearchServiceSoftwareUpdateResponse> -
Cancels a scheduled service software update for an Amazon ES domain. You
can only perform this operation before the
AutomatedUpdateDateand when theUpdateStatusis in thePENDING_UPDATEstate. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createElasticsearchDomain(
{required String domainName, String? accessPolicies, Map< String, String> ? advancedOptions, AdvancedSecurityOptionsInput? advancedSecurityOptions, AutoTuneOptionsInput? autoTuneOptions, AutomatedSnapshotPauseRequestOptions? automatedSnapshotPauseOptions, CognitoOptions? cognitoOptions, DeploymentStrategyOptions? deploymentStrategyOptions, DomainEndpointOptions? domainEndpointOptions, EBSOptions? eBSOptions, ElasticsearchClusterConfig? elasticsearchClusterConfig, String? elasticsearchVersion, EncryptionAtRestOptions? encryptionAtRestOptions, Map<LogType, LogPublishingOption> ? logPublishingOptions, NodeToNodeEncryptionOptions? nodeToNodeEncryptionOptions, SnapshotOptions? snapshotOptions, List<Tag> ? tagList, VPCOptions? vPCOptions}) → Future<CreateElasticsearchDomainResponse> - Creates a new Elasticsearch domain. For more information, see Creating Elasticsearch Domains in the Amazon Elasticsearch Service Developer Guide.
-
createOutboundCrossClusterSearchConnection(
{required String connectionAlias, required DomainInformation destinationDomainInfo, required DomainInformation sourceDomainInfo}) → Future< CreateOutboundCrossClusterSearchConnectionResponse> - Creates a new cross-cluster search connection from a source domain to a destination domain.
-
createPackage(
{required String packageName, required PackageSource packageSource, required PackageType packageType, String? packageDescription}) → Future< CreatePackageResponse> - Create a package for use with Amazon ES domains.
-
createVpcEndpoint(
{required String domainArn, required VPCOptions vpcOptions, String? clientToken}) → Future< CreateVpcEndpointResponse> - Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
deleteElasticsearchDomain(
{required String domainName}) → Future< DeleteElasticsearchDomainResponse> - Permanently deletes the specified Elasticsearch domain and all of its data. Once a domain is deleted, it cannot be recovered.
-
deleteElasticsearchServiceRole(
) → Future< void> - Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains. Role deletion will fail if any existing VPC domains use the role. You must delete any such Elasticsearch domains before deleting the role. See Deleting Elasticsearch Service Role in VPC Endpoints for Amazon Elasticsearch Service Domains.
-
deleteInboundCrossClusterSearchConnection(
{required String crossClusterSearchConnectionId}) → Future< DeleteInboundCrossClusterSearchConnectionResponse> - Allows the destination domain owner to delete an existing inbound cross-cluster search connection.
-
deleteOutboundCrossClusterSearchConnection(
{required String crossClusterSearchConnectionId}) → Future< DeleteOutboundCrossClusterSearchConnectionResponse> - Allows the source domain owner to delete an existing outbound cross-cluster search connection.
-
deletePackage(
{required String packageID}) → Future< DeletePackageResponse> - Delete the package.
-
deleteVpcEndpoint(
{required String vpcEndpointId}) → Future< DeleteVpcEndpointResponse> - Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
describeDomainAutoTunes(
{required String domainName, int? maxResults, String? nextToken}) → Future< DescribeDomainAutoTunesResponse> - Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.
-
describeDomainChangeProgress(
{required String domainName, String? changeId}) → Future< DescribeDomainChangeProgressResponse> - Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages.
-
describeElasticsearchDomain(
{required String domainName}) → Future< DescribeElasticsearchDomainResponse> - Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.
-
describeElasticsearchDomainConfig(
{required String domainName}) → Future< DescribeElasticsearchDomainConfigResponse> - Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.
-
describeElasticsearchDomains(
{required List< String> domainNames}) → Future<DescribeElasticsearchDomainsResponse> - Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.
-
describeElasticsearchInstanceTypeLimits(
{required String elasticsearchVersion, required ESPartitionInstanceType instanceType, String? domainName}) → Future< DescribeElasticsearchInstanceTypeLimitsResponse> -
Describe Elasticsearch Limits for a given InstanceType and
ElasticsearchVersion. When modifying existing Domain, specify the
DomainNameto know what Limits are supported for modifying. -
describeInboundCrossClusterSearchConnections(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeInboundCrossClusterSearchConnectionsResponse> - Lists all the inbound cross-cluster search connections for a destination domain.
-
describeOutboundCrossClusterSearchConnections(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeOutboundCrossClusterSearchConnectionsResponse> - Lists all the outbound cross-cluster search connections for a source domain.
-
describePackages(
{List< DescribePackagesFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribePackagesResponse> - Describes all packages available to Amazon ES. Includes options for filtering, limiting the number of results, and pagination.
-
describeReservedElasticsearchInstanceOfferings(
{int? maxResults, String? nextToken, String? reservedElasticsearchInstanceOfferingId}) → Future< DescribeReservedElasticsearchInstanceOfferingsResponse> - Lists available reserved Elasticsearch instance offerings.
-
describeReservedElasticsearchInstances(
{int? maxResults, String? nextToken, String? reservedElasticsearchInstanceId}) → Future< DescribeReservedElasticsearchInstancesResponse> - Returns information about reserved Elasticsearch instances for this account.
-
describeVpcEndpoints(
{required List< String> vpcEndpointIds}) → Future<DescribeVpcEndpointsResponse> - Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
dissociatePackage(
{required String domainName, required String packageID}) → Future< DissociatePackageResponse> - Dissociates a package from the Amazon ES domain.
-
getCompatibleElasticsearchVersions(
{String? domainName}) → Future< GetCompatibleElasticsearchVersionsResponse> -
Returns a list of upgrade compatible Elastisearch versions. You can
optionally pass a
DomainNameto get all upgrade compatible Elasticsearch versions for that specific domain. -
getPackageVersionHistory(
{required String packageID, int? maxResults, String? nextToken}) → Future< GetPackageVersionHistoryResponse> - Returns a list of versions of the package, along with their creation time and commit message.
-
getUpgradeHistory(
{required String domainName, int? maxResults, String? nextToken}) → Future< GetUpgradeHistoryResponse> - Retrieves the complete history of the last 10 upgrades that were performed on the domain.
-
getUpgradeStatus(
{required String domainName}) → Future< GetUpgradeStatusResponse> - Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
-
listDomainNames(
{EngineType? engineType}) → Future< ListDomainNamesResponse> - Returns the name of all Elasticsearch domains owned by the current user's account.
-
listDomainsForPackage(
{required String packageID, int? maxResults, String? nextToken}) → Future< ListDomainsForPackageResponse> - Lists all Amazon ES domains associated with the package.
-
listElasticsearchInstanceTypes(
{required String elasticsearchVersion, String? domainName, int? maxResults, String? nextToken}) → Future< ListElasticsearchInstanceTypesResponse> - List all Elasticsearch instance types that are supported for given ElasticsearchVersion
-
listElasticsearchVersions(
{int? maxResults, String? nextToken}) → Future< ListElasticsearchVersionsResponse> - List all supported Elasticsearch versions
-
listPackagesForDomain(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListPackagesForDomainResponse> - Lists all packages associated with the Amazon ES domain.
-
listTags(
{required String arn}) → Future< ListTagsResponse> - Returns all tags for the given Elasticsearch domain.
-
listVpcEndpointAccess(
{required String domainName, String? nextToken}) → Future< ListVpcEndpointAccessResponse> - Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
listVpcEndpoints(
{String? nextToken}) → Future< ListVpcEndpointsResponse> - Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region.
-
listVpcEndpointsForDomain(
{required String domainName, String? nextToken}) → Future< ListVpcEndpointsForDomainResponse> - Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purchaseReservedElasticsearchInstanceOffering(
{required String reservationName, required String reservedElasticsearchInstanceOfferingId, int? instanceCount}) → Future< PurchaseReservedElasticsearchInstanceOfferingResponse> - Allows you to purchase reserved Elasticsearch instances.
-
rejectInboundCrossClusterSearchConnection(
{required String crossClusterSearchConnectionId}) → Future< RejectInboundCrossClusterSearchConnectionResponse> - Allows the destination domain owner to reject an inbound cross-cluster search connection request.
-
removeTags(
{required String arn, required List< String> tagKeys}) → Future<void> - Removes the specified set of tags from the specified Elasticsearch domain.
-
revokeVpcEndpointAccess(
{required String account, required String domainName}) → Future< void> - Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
startElasticsearchServiceSoftwareUpdate(
{required String domainName}) → Future< StartElasticsearchServiceSoftwareUpdateResponse> - Schedules a service software update for an Amazon ES domain.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateElasticsearchDomainConfig(
{required String domainName, String? accessPolicies, Map< String, String> ? advancedOptions, AdvancedSecurityOptionsInput? advancedSecurityOptions, AutoTuneOptions? autoTuneOptions, AutomatedSnapshotPauseRequestOptions? automatedSnapshotPauseOptions, CognitoOptions? cognitoOptions, DeploymentStrategyOptions? deploymentStrategyOptions, DomainEndpointOptions? domainEndpointOptions, bool? dryRun, EBSOptions? eBSOptions, ElasticsearchClusterConfig? elasticsearchClusterConfig, EncryptionAtRestOptions? encryptionAtRestOptions, Map<LogType, LogPublishingOption> ? logPublishingOptions, NodeToNodeEncryptionOptions? nodeToNodeEncryptionOptions, SnapshotOptions? snapshotOptions, VPCOptions? vPCOptions}) → Future<UpdateElasticsearchDomainConfigResponse> - Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.
-
updatePackage(
{required String packageID, required PackageSource packageSource, String? commitMessage, String? packageDescription}) → Future< UpdatePackageResponse> - Updates a package for use with Amazon ES domains.
-
updateVpcEndpoint(
{required String vpcEndpointId, required VPCOptions vpcOptions}) → Future< UpdateVpcEndpointResponse> - Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
upgradeElasticsearchDomain(
{required String domainName, required String targetVersion, bool? performCheckOnly}) → Future< UpgradeElasticsearchDomainResponse> - Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited