deleteOutboundCrossClusterSearchConnection method

Future<DeleteOutboundCrossClusterSearchConnectionResponse> deleteOutboundCrossClusterSearchConnection({
  1. required String crossClusterSearchConnectionId,
})

Allows the source domain owner to delete an existing outbound cross-cluster search connection.

May throw DisabledOperationException. May throw ResourceNotFoundException.

Parameter crossClusterSearchConnectionId : The id of the outbound connection that you want to permanently delete.

Implementation

Future<DeleteOutboundCrossClusterSearchConnectionResponse>
    deleteOutboundCrossClusterSearchConnection({
  required String crossClusterSearchConnectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2015-01-01/es/ccs/outboundConnection/${Uri.encodeComponent(crossClusterSearchConnectionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteOutboundCrossClusterSearchConnectionResponse.fromJson(
      response);
}