listDomainNames method
Returns the name of all Elasticsearch domains owned by the current user's account.
May throw BaseException.
May throw ValidationException.
Parameter engineType :
Optional parameter to filter the output by domain engine type. Acceptable
values are 'Elasticsearch' and 'OpenSearch'.
Implementation
Future<ListDomainNamesResponse> listDomainNames({
EngineType? engineType,
}) async {
final $query = <String, List<String>>{
if (engineType != null) 'engineType': [engineType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2015-01-01/domain',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDomainNamesResponse.fromJson(response);
}