rejectInboundCrossClusterSearchConnection method

Future<RejectInboundCrossClusterSearchConnectionResponse> rejectInboundCrossClusterSearchConnection({
  1. required String crossClusterSearchConnectionId,
})

Allows the destination domain owner to reject an inbound cross-cluster search connection request.

May throw DisabledOperationException. May throw ResourceNotFoundException.

Parameter crossClusterSearchConnectionId : The id of the inbound connection that you want to reject.

Implementation

Future<RejectInboundCrossClusterSearchConnectionResponse>
    rejectInboundCrossClusterSearchConnection({
  required String crossClusterSearchConnectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/2015-01-01/es/ccs/inboundConnection/${Uri.encodeComponent(crossClusterSearchConnectionId)}/reject',
    exceptionFnMap: _exceptionFns,
  );
  return RejectInboundCrossClusterSearchConnectionResponse.fromJson(response);
}