ElementalInference class

This is the AWS Elemental Inference REST API Reference. It provides information on the URL, request contents, and response contents of each AWS Elemental Inference REST operation.

We assume that you have the IAM permissions that you need to use AWS Elemental Inference via the REST API. We also assume that you are familiar with the features and operations of AWS Elemental Inference as described in AWS Elemental Inference User Guide.

Constructors

ElementalInference({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateFeed({required String id, required List<CreateOutput> outputs, String? associatedResourceName, bool? dryRun}) Future<AssociateFeedResponse>
Associates a resource with the feed. The resource provides the input that Elemental Inference needs in order to perform an Elemental Inference feature, such as cropping video. You always provide the resource by associating it with a feed. You can associate only one resource with each feed. With an association, a specific source media is claiming ownership of the feed.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createDictionary({required DictionaryLanguage language, required String name, String? entries, Map<String, String>? tags}) Future<CreateDictionaryResponse>
Creates a custom dictionary for improving transcription accuracy. A dictionary contains custom words and phrases that the ASR engine might not recognize, such as brand names, technical terms, or proper nouns. You can reference a dictionary when configuring a smart subtitles output.
createFeed({required String name, required List<CreateOutput> outputs, Map<String, String>? tags}) Future<CreateFeedResponse>
Creates a feed. The feed is the target for the live media stream that is being sent by the calling application. An example of a calling application is AWS Elemental MediaLive.
deleteDictionary({required String id}) Future<DeleteDictionaryResponse>
Deletes the specified dictionary. You cannot delete a dictionary that is referenced by a feed. You must first remove the dictionary reference from the feed's subtitling configuration.
deleteFeed({required String id}) Future<DeleteFeedResponse>
Deletes the specified feed. You can delete the feed at any time. Elemental Inference doesn't block you from deleting a feed when the calling application is calling PutMedia or GetMetadata on that feed, although both these calls will start to fail. For more information about managing inactive feeds, see the Elemental Inference User Guide.
disassociateFeed({required String id, String? associatedResourceName, bool? dryRun}) Future<DisassociateFeedResponse>
Releases the resource (the source media) that is associated with this feed. The outputs in the feed become DISABLED.
exportDictionaryEntries({required String id}) Future<ExportDictionaryEntriesResponse>
Exports the entries from the specified dictionary.
getDictionary({required String id}) Future<GetDictionaryResponse>
Retrieves information about the specified dictionary.
getFeed({required String id}) Future<GetFeedResponse>
Retrieves information about the specified feed.
listDictionaries({int? maxResults, String? nextToken}) Future<ListDictionariesResponse>
Lists the dictionaries in your account.
listFeeds({int? maxResults, String? nextToken}) Future<ListFeedsResponse>
Displays a list of feeds that belong to this AWS account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List all tags that are on an Elemental Inference resource in the current region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Associates the specified tags to the resource identified by the specified resourceArn in the current region. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes specified tags from the specified resource in the current region.
updateDictionary({required String id, String? entries, DictionaryLanguage? language, String? name}) Future<UpdateDictionaryResponse>
Updates the specified dictionary.
updateFeed({required String id, required String name, required List<UpdateOutput> outputs}) Future<UpdateFeedResponse>
Updates the name and/or outputs in a feed.

Operators

operator ==(Object other) bool
The equality operator.
inherited