createFeed method
Creates a feed. The feed is the target for the live media stream that is being sent by the calling application. An example of a calling application is AWS Elemental MediaLive.
The key contents of the feed is an array of outputs. Each output represents an Elemental Inference feature. After you create the feed, you must associate a resource with the feed. At that point, you will have a useable feed: resource - feed - output or outputs.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerErrorException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestException.
May throw ValidationException.
Parameter name :
A user-friendly name for this feed.
Parameter outputs :
An array of outputs for this feed. Each output represents a specific
Elemental Inference feature. For example, there is one output type for the
smart crop feature. You must specify at least one output, but you can
later add outputs using AssociateFeed, or add, modify, and delete outputs
using UpdateFeed.
Parameter tags :
Optional tags. You can also add tags later, using TagResource.
Implementation
Future<CreateFeedResponse> createFeed({
required String name,
required List<CreateOutput> outputs,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'name': name,
'outputs': outputs,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/feed',
exceptionFnMap: _exceptionFns,
);
return CreateFeedResponse.fromJson(response);
}