deleteDictionary method

Future<DeleteDictionaryResponse> deleteDictionary({
  1. required String id,
})

Deletes the specified dictionary. You cannot delete a dictionary that is referenced by a feed. You must first remove the dictionary reference from the feed's subtitling configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw TooManyRequestException. May throw ValidationException.

Parameter id : The ID of the dictionary to delete.

Implementation

Future<DeleteDictionaryResponse> deleteDictionary({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/v1/dictionary/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDictionaryResponse.fromJson(response);
}