deleteFeed method

Future<DeleteFeedResponse> deleteFeed({
  1. required String id,
})

Deletes the specified feed. You can delete the feed at any time. Elemental Inference doesn't block you from deleting a feed when the calling application is calling PutMedia or GetMetadata on that feed, although both these calls will start to fail. For more information about managing inactive feeds, see the Elemental Inference User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw TooManyRequestException. May throw ValidationException.

Parameter id : The ID of the feed.

Implementation

Future<DeleteFeedResponse> deleteFeed({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/v1/feed/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFeedResponse.fromJson(response);
}