disassociateFeed method

Future<DisassociateFeedResponse> disassociateFeed({
  1. required String id,
  2. String? associatedResourceName,
  3. bool? dryRun,
})

Releases the resource (the source media) that is associated with this feed. The outputs in the feed become DISABLED.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw TooManyRequestException. May throw ValidationException.

Parameter id : The ID of the feed where you want to release the resource.

Parameter associatedResourceName : The name of the resource currently associated with the feed.

Parameter dryRun : Set to true if you want to do a dry run of the disassociate action.

Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions. If the dry run fails, the action returns a 4xx error code.

Implementation

Future<DisassociateFeedResponse> disassociateFeed({
  required String id,
  String? associatedResourceName,
  bool? dryRun,
}) async {
  final $payload = <String, dynamic>{
    'associatedResourceName':
        associatedResourceName ?? _s.generateIdempotencyToken(),
    if (dryRun != null) 'dryRun': dryRun,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/feed/${Uri.encodeComponent(id)}/disassociate',
    exceptionFnMap: _exceptionFns,
  );
  return DisassociateFeedResponse.fromJson(response);
}