listDictionaries method

Future<ListDictionariesResponse> listDictionaries({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the dictionaries in your account.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw TooManyRequestException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return per API request. Valid range: 1 to 100.

Parameter nextToken : The token that identifies the next batch of results to return.

Implementation

Future<ListDictionariesResponse> listDictionaries({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/dictionaries',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDictionariesResponse.fromJson(response);
}