listFeeds method

Future<ListFeedsResponse> listFeeds({
  1. int? maxResults,
  2. String? nextToken,
})

Displays a list of feeds that belong to this AWS account.

May throw AccessDeniedException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw TooManyRequestException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return per API request.

For example, you submit a list request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)

The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.

Valid Range: Minimum value of 1. Maximum value of 1000.

Parameter nextToken : The token that identifies the batch of results that you want to see.

For example, you submit a ListFeeds request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListFeeds request a second time and specify the NextToken value.

Implementation

Future<ListFeedsResponse> listFeeds({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/feeds',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListFeedsResponse.fromJson(response);
}