untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Deletes specified tags from the specified resource in the current region.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerErrorException. May throw ResourceNotFoundException. May throw TooManyRequestException. May throw ValidationException.

Parameter resourceArn : The ARN of the resource where you want to delete one or more tags.

Parameter tagKeys : The keys of the tags to delete.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/v1/tags/${Uri.encodeComponent(resourceArn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}