addJobFlowSteps method

Future<AddJobFlowStepsOutput> addJobFlowSteps({
  1. required String jobFlowId,
  2. required List<StepConfig> steps,
  3. String? executionRoleArn,
})

AddJobFlowSteps adds new steps to a running cluster. A maximum of 256 steps are allowed in each job flow.

If your cluster is long-running (such as a Hive data warehouse) or complex, you may require more than 256 steps to process your data. You can bypass the 256-step limitation in various ways, including using SSH to connect to the master node and submitting queries directly to the software running on the master node, such as Hive and Hadoop.

A step specifies the location of a JAR file stored either on the master node of the cluster or in Amazon S3. Each step is performed by the main function of the main class of the JAR file. The main class can be specified either in the manifest of the JAR or by using the MainFunction parameter of the step.

Amazon EMR executes each step in the order listed. For a step to be considered complete, the main function must exit with a zero exit code and all Hadoop jobs started while the step was running must have completed and run successfully.

You can only add steps to a cluster that is in one of the following states: STARTING, BOOTSTRAPPING, RUNNING, or WAITING.

May throw InternalServerError.

Parameter jobFlowId : A string that uniquely identifies the job flow. This identifier is returned by RunJobFlow and can also be obtained from ListClusters.

Parameter steps : A list of StepConfig to be executed by the job flow.

Parameter executionRoleArn : The Amazon Resource Name (ARN) of the runtime role for a step on the cluster. The runtime role can be a cross-account IAM role. The runtime role ARN is a combination of account ID, role name, and role type using the following format: arn:partition:service:region:account:resource.

For example, arn:aws:IAM::1234567890:role/ReadOnly is a correctly formatted runtime role ARN.

Implementation

Future<AddJobFlowStepsOutput> addJobFlowSteps({
  required String jobFlowId,
  required List<StepConfig> steps,
  String? executionRoleArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ElasticMapReduce.AddJobFlowSteps'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'JobFlowId': jobFlowId,
      'Steps': steps,
      if (executionRoleArn != null) 'ExecutionRoleArn': executionRoleArn,
    },
  );

  return AddJobFlowStepsOutput.fromJson(jsonResponse.body);
}