deleteStudioSessionMapping method
Removes a user or group from an Amazon EMR Studio.
May throw InternalServerError.
May throw InvalidRequestException.
Parameter identityType :
Specifies whether the identity to delete from the Amazon EMR Studio is a
user or a group.
Parameter studioId :
The ID of the Amazon EMR Studio.
Parameter identityId :
The globally unique identifier (GUID) of the user or group to remove from
the Amazon EMR Studio. For more information, see UserId
and GroupId
in the IAM Identity Center Identity Store API Reference. Either
IdentityName or IdentityId must be specified.
Parameter identityName :
The name of the user name or group to remove from the Amazon EMR Studio.
For more information, see UserName
and DisplayName
in the IAM Identity Center Store API Reference. Either
IdentityName or IdentityId must be specified.
Implementation
Future<void> deleteStudioSessionMapping({
required IdentityType identityType,
required String studioId,
String? identityId,
String? identityName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.DeleteStudioSessionMapping'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IdentityType': identityType.value,
'StudioId': studioId,
if (identityId != null) 'IdentityId': identityId,
if (identityName != null) 'IdentityName': identityName,
},
);
}