getPersistentAppUIPresignedURL method

Future<GetPersistentAppUIPresignedURLOutput> getPersistentAppUIPresignedURL({
  1. required String persistentAppUIId,
  2. String? applicationId,
  3. bool? authProxyCall,
  4. String? executionRoleArn,
  5. PersistentAppUIType? persistentAppUIType,
})

The presigned URL properties for the cluster's application user interface.

May throw InternalServerError. May throw InvalidRequestException.

Parameter persistentAppUIId : The persistent application user interface ID associated with the presigned URL.

Parameter applicationId : The application ID associated with the presigned URL.

Parameter authProxyCall : A boolean that represents if the caller is an authentication proxy call.

Parameter executionRoleArn : The execution role ARN associated with the presigned URL.

Parameter persistentAppUIType : The persistent application user interface type associated with the presigned URL.

Implementation

Future<GetPersistentAppUIPresignedURLOutput> getPersistentAppUIPresignedURL({
  required String persistentAppUIId,
  String? applicationId,
  bool? authProxyCall,
  String? executionRoleArn,
  PersistentAppUIType? persistentAppUIType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ElasticMapReduce.GetPersistentAppUIPresignedURL'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'PersistentAppUIId': persistentAppUIId,
      if (applicationId != null) 'ApplicationId': applicationId,
      if (authProxyCall != null) 'AuthProxyCall': authProxyCall,
      if (executionRoleArn != null) 'ExecutionRoleArn': executionRoleArn,
      if (persistentAppUIType != null)
        'PersistentAppUIType': persistentAppUIType.value,
    },
  );

  return GetPersistentAppUIPresignedURLOutput.fromJson(jsonResponse.body);
}