listStudioSessionMappings method
Returns a list of all user or group session mappings for the Amazon EMR
Studio specified by StudioId.
May throw InternalServerError.
May throw InvalidRequestException.
Parameter identityType :
Specifies whether to return session mappings for users or groups. If not
specified, the results include session mapping details for both users and
groups.
Parameter marker :
The pagination token that indicates the set of results to retrieve.
Parameter studioId :
The ID of the Amazon EMR Studio.
Implementation
Future<ListStudioSessionMappingsOutput> listStudioSessionMappings({
IdentityType? identityType,
String? marker,
String? studioId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.ListStudioSessionMappings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (identityType != null) 'IdentityType': identityType.value,
if (marker != null) 'Marker': marker,
if (studioId != null) 'StudioId': studioId,
},
);
return ListStudioSessionMappingsOutput.fromJson(jsonResponse.body);
}