modifyCluster method

Future<ModifyClusterOutput> modifyCluster({
  1. required String clusterId,
  2. bool? extendedSupport,
  3. int? stepConcurrencyLevel,
})

Modifies the number of steps that can be executed concurrently for the cluster specified using ClusterID.

May throw InternalServerError. May throw InvalidRequestException.

Parameter clusterId : The unique identifier of the cluster.

Parameter extendedSupport : Reserved.

Parameter stepConcurrencyLevel : The number of steps that can be executed concurrently. You can specify a minimum of 1 step and a maximum of 256 steps. We recommend that you do not change this parameter while steps are running or the ActionOnFailure setting may not behave as expected. For more information see Step$ActionOnFailure.

Implementation

Future<ModifyClusterOutput> modifyCluster({
  required String clusterId,
  bool? extendedSupport,
  int? stepConcurrencyLevel,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ElasticMapReduce.ModifyCluster'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ClusterId': clusterId,
      if (extendedSupport != null) 'ExtendedSupport': extendedSupport,
      if (stepConcurrencyLevel != null)
        'StepConcurrencyLevel': stepConcurrencyLevel,
    },
  );

  return ModifyClusterOutput.fromJson(jsonResponse.body);
}