removeManagedScalingPolicy method
Removes a managed scaling policy from a specified Amazon EMR cluster.
Parameter clusterId :
Specifies the ID of the cluster from which the managed scaling policy will
be removed.
Implementation
Future<void> removeManagedScalingPolicy({
required String clusterId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.RemoveManagedScalingPolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ClusterId': clusterId,
},
);
}