runJobFlow method
- required JobFlowInstancesConfig instances,
- required String name,
- String? additionalInfo,
- String? amiVersion,
- List<
Application> ? applications, - String? autoScalingRole,
- AutoTerminationPolicy? autoTerminationPolicy,
- List<
BootstrapActionConfig> ? bootstrapActions, - List<
Configuration> ? configurations, - String? customAmiId,
- int? ebsRootVolumeIops,
- int? ebsRootVolumeSize,
- int? ebsRootVolumeThroughput,
- bool? extendedSupport,
- String? jobFlowRole,
- KerberosAttributes? kerberosAttributes,
- String? logEncryptionKmsKeyId,
- String? logUri,
- ManagedScalingPolicy? managedScalingPolicy,
- MonitoringConfiguration? monitoringConfiguration,
- List<
SupportedProductConfig> ? newSupportedProducts, - String? oSReleaseLabel,
- List<
PlacementGroupConfig> ? placementGroupConfigs, - String? releaseLabel,
- RepoUpgradeOnBoot? repoUpgradeOnBoot,
- ScaleDownBehavior? scaleDownBehavior,
- String? securityConfiguration,
- String? serviceRole,
- bool? sessionEnabled,
- int? stepConcurrencyLevel,
- String? stepExecutionRoleArn,
- List<
StepConfig> ? steps, - List<
String> ? supportedProducts, - List<
Tag> ? tags, - bool? visibleToAllUsers,
RunJobFlow creates and starts running a new cluster (job flow). The
cluster runs the steps specified. After the steps complete, the cluster
stops and the HDFS partition is lost. To prevent loss of data, configure
the last step of the job flow to store results in Amazon S3. If the
JobFlowInstancesConfig KeepJobFlowAliveWhenNoSteps
parameter is set to TRUE, the cluster transitions to the
WAITING state rather than shutting down after the steps have completed.
For additional protection, you can set the JobFlowInstancesConfig
TerminationProtected parameter to TRUE to lock
the cluster and prevent it from being terminated by API call, user
intervention, or in the event of a job flow error.
A maximum of 256 steps are allowed in each job flow.
If your cluster is long-running (such as a Hive data warehouse) or complex, you may require more than 256 steps to process your data. You can bypass the 256-step limitation in various ways, including using the SSH shell to connect to the master node and submitting queries directly to the software running on the master node, such as Hive and Hadoop.
For long-running clusters, we recommend that you periodically store your results.
May throw InternalServerError.
Parameter instances :
A specification of the number and type of Amazon EC2 instances.
Parameter name :
The name of the job flow.
Parameter additionalInfo :
A JSON string for selecting additional features.
Parameter amiVersion :
Applies only to Amazon EMR AMI versions 3.x and 2.x. For Amazon EMR
releases 4.0 and later, ReleaseLabel is used. To specify a
custom AMI, use CustomAmiID.
Parameter applications :
Applies to Amazon EMR releases 4.0 and later. A case-insensitive list of
applications for Amazon EMR to install and configure when launching the
cluster. For a list of applications available for each Amazon EMR release
version, see the Amazon
EMRRelease Guide.
Parameter autoScalingRole :
An IAM role for automatic scaling policies. The default role is
EMR_AutoScaling_DefaultRole. The IAM role provides
permissions that the automatic scaling feature requires to launch and
terminate Amazon EC2 instances in an instance group.
Parameter bootstrapActions :
A list of bootstrap actions to run before Hadoop starts on the cluster
nodes.
Parameter configurations :
For Amazon EMR releases 4.0 and later. The list of configurations supplied
for the Amazon EMR cluster that you are creating.
Parameter customAmiId :
Available only in Amazon EMR releases 5.7.0 and later. The ID of a custom
Amazon EBS-backed Linux AMI. If specified, Amazon EMR uses this AMI when
it launches cluster Amazon EC2 instances. For more information about
custom AMIs in Amazon EMR, see Using
a Custom AMI in the Amazon EMR Management Guide. If omitted,
the cluster uses the base Linux AMI for the ReleaseLabel
specified. For Amazon EMR releases 2.x and 3.x, use
AmiVersion instead.
For information about creating a custom AMI, see Creating an Amazon EBS-Backed Linux AMI in the Amazon Elastic Compute Cloud User Guide for Linux Instances. For information about finding an AMI ID, see Finding a Linux AMI.
Parameter ebsRootVolumeIops :
The IOPS, of the Amazon EBS root device volume of the Linux AMI that is
used for each Amazon EC2 instance. Available in Amazon EMR releases 6.15.0
and later.
Parameter ebsRootVolumeSize :
The size, in GiB, of the Amazon EBS root device volume of the Linux AMI
that is used for each Amazon EC2 instance. Available in Amazon EMR
releases 4.x and later.
Parameter ebsRootVolumeThroughput :
The throughput, in MiB/s, of the Amazon EBS root device volume of the
Linux AMI that is used for each Amazon EC2 instance. Available in Amazon
EMR releases 6.15.0 and later.
Parameter extendedSupport :
Reserved.
Parameter jobFlowRole :
Also called instance profile and Amazon EC2 role. An IAM role for an
Amazon EMR cluster. The Amazon EC2 instances of the cluster assume this
role. The default role is EMR_EC2_DefaultRole. In order to
use the default role, you must have already created it using the CLI or
console.
Parameter kerberosAttributes :
Attributes for Kerberos configuration when Kerberos authentication is
enabled using a security configuration. For more information see Use
Kerberos Authentication in the Amazon EMR Management Guide.
Parameter logEncryptionKmsKeyId :
The KMS key used for encrypting log files. If a value is not provided, the
logs remain encrypted by AES-256. This attribute is only available with
Amazon EMR releases 5.30.0 and later, excluding Amazon EMR 6.0.0.
Parameter logUri :
The location in Amazon S3 to write the log files of the job flow. If a
value is not provided, logs are not created.
Parameter managedScalingPolicy :
The specified managed scaling policy for an Amazon EMR cluster.
Parameter monitoringConfiguration :
Contains CloudWatch log configuration metadata and settings.
Parameter newSupportedProducts :
A list of strings that indicates third-party software to use with the job
flow that accepts a user argument list. Amazon EMR accepts and forwards
the argument list to the corresponding installation script as bootstrap
action arguments. For more information, see "Launch a Job Flow on the MapR
Distribution for Hadoop" in the Amazon
EMR Developer Guide. Supported values are:
- "mapr-m3" - launch the cluster using MapR M3 Edition.
- "mapr-m5" - launch the cluster using MapR M5 Edition.
- "mapr" with the user arguments specifying "--edition,m3" or "--edition,m5" - launch the job flow using MapR M3 or M5 Edition respectively.
- "mapr-m7" - launch the cluster using MapR M7 Edition.
- "hunk" - launch the cluster with the Hunk Big Data Analytics Platform.
- "hue"- launch the cluster with Hue installed.
- "spark" - launch the cluster with Apache Spark installed.
- "ganglia" - launch the cluster with the Ganglia Monitoring System installed.
Parameter oSReleaseLabel :
Specifies a particular Amazon Linux release for all nodes in a cluster
launch RunJobFlow request. If a release is not specified, Amazon EMR uses
the latest validated Amazon Linux release for cluster launch.
Parameter placementGroupConfigs :
The specified placement group configuration for an Amazon EMR cluster.
Parameter releaseLabel :
The Amazon EMR release label, which determines the version of open-source
application packages installed on the cluster. Release labels are in the
form emr-x.x.x, where x.x.x is an Amazon EMR release version
such as emr-5.14.0. For more information about Amazon EMR
release versions and included application versions and features, see https://docs.aws.amazon.com/emr/latest/ReleaseGuide/.
The release label applies only to Amazon EMR releases version 4.0 and
later. Earlier versions use AmiVersion.
Parameter repoUpgradeOnBoot :
Applies only when CustomAmiID is used. Specifies which
updates from the Amazon Linux AMI package repositories to apply
automatically when the instance boots using the AMI. If omitted, the
default is SECURITY, which indicates that only security
updates are applied. If NONE is specified, no updates are
applied, and all updates must be applied manually.
Parameter scaleDownBehavior :
Specifies the way that individual Amazon EC2 instances terminate when an
automatic scale-in activity occurs or an instance group is resized.
TERMINATE_AT_INSTANCE_HOUR indicates that Amazon EMR
terminates nodes at the instance-hour boundary, regardless of when the
request to terminate the instance was submitted. This option is only
available with Amazon EMR 5.1.0 and later and is the default for clusters
created using that version. TERMINATE_AT_TASK_COMPLETION
indicates that Amazon EMR adds nodes to a deny list and drains tasks from
nodes before terminating the Amazon EC2 instances, regardless of the
instance-hour boundary. With either behavior, Amazon EMR removes the least
active nodes first and blocks instance termination if it could lead to
HDFS corruption. TERMINATE_AT_TASK_COMPLETION available only
in Amazon EMR releases 4.1.0 and later, and is the default for releases of
Amazon EMR earlier than 5.1.0.
Parameter securityConfiguration :
The name of a security configuration to apply to the cluster.
Parameter serviceRole :
The IAM role that Amazon EMR assumes in order to access Amazon Web
Services resources on your behalf. If you've created a custom service role
path, you must specify it for the service role when you launch your
cluster.
Parameter sessionEnabled :
Indicates whether Spark Connect sessions are enabled on the cluster. When
set to true, you can start Spark Connect sessions using the
StartSession operation.
Parameter stepConcurrencyLevel :
Specifies the number of steps that can be executed concurrently. The
default value is 1. The maximum value is 256.
Parameter stepExecutionRoleArn :
The Amazon Resource Name (ARN) of the runtime role for steps specified in
the RunJobFlow request. The runtime role can be a cross-account IAM role.
The runtime role ARN is a combination of account ID, role name, and role
type using the following format:
arn:partition:iam::account-id:role/role-name.
For example, arn:aws:iam::1234567890:role/ReadOnly is a
correctly formatted runtime role ARN.
This parameter applies only to steps included in the Steps
parameter of this RunJobFlow request. It does not apply to steps added
later to the cluster.
Parameter steps :
A list of steps to run.
Parameter supportedProducts :
A list of strings that indicates third-party software to use. For more
information, see the Amazon
EMR Developer Guide. Currently supported values are:
- "mapr-m3" - launch the job flow using MapR M3 Edition.
- "mapr-m5" - launch the job flow using MapR M5 Edition.
Parameter tags :
A list of tags to associate with a cluster and propagate to Amazon EC2
instances.
Parameter visibleToAllUsers :
Set this value to true so that IAM principals in the Amazon
Web Services account associated with the cluster can perform Amazon EMR
actions on the cluster that their IAM policies allow. This value defaults
to true for clusters created using the Amazon EMR API or the
CLI create-cluster
command.
When set to false, only the IAM principal that created the
cluster and the Amazon Web Services account root user can perform Amazon
EMR actions for the cluster, regardless of the IAM permissions policies
attached to other IAM principals. For more information, see Understanding
the Amazon EMR cluster VisibleToAllUsers setting in the Amazon EMR
Management Guide.
Implementation
Future<RunJobFlowOutput> runJobFlow({
required JobFlowInstancesConfig instances,
required String name,
String? additionalInfo,
String? amiVersion,
List<Application>? applications,
String? autoScalingRole,
AutoTerminationPolicy? autoTerminationPolicy,
List<BootstrapActionConfig>? bootstrapActions,
List<Configuration>? configurations,
String? customAmiId,
int? ebsRootVolumeIops,
int? ebsRootVolumeSize,
int? ebsRootVolumeThroughput,
bool? extendedSupport,
String? jobFlowRole,
KerberosAttributes? kerberosAttributes,
String? logEncryptionKmsKeyId,
String? logUri,
ManagedScalingPolicy? managedScalingPolicy,
MonitoringConfiguration? monitoringConfiguration,
List<SupportedProductConfig>? newSupportedProducts,
String? oSReleaseLabel,
List<PlacementGroupConfig>? placementGroupConfigs,
String? releaseLabel,
RepoUpgradeOnBoot? repoUpgradeOnBoot,
ScaleDownBehavior? scaleDownBehavior,
String? securityConfiguration,
String? serviceRole,
bool? sessionEnabled,
int? stepConcurrencyLevel,
String? stepExecutionRoleArn,
List<StepConfig>? steps,
List<String>? supportedProducts,
List<Tag>? tags,
bool? visibleToAllUsers,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.RunJobFlow'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Instances': instances,
'Name': name,
if (additionalInfo != null) 'AdditionalInfo': additionalInfo,
if (amiVersion != null) 'AmiVersion': amiVersion,
if (applications != null) 'Applications': applications,
if (autoScalingRole != null) 'AutoScalingRole': autoScalingRole,
if (autoTerminationPolicy != null)
'AutoTerminationPolicy': autoTerminationPolicy,
if (bootstrapActions != null) 'BootstrapActions': bootstrapActions,
if (configurations != null) 'Configurations': configurations,
if (customAmiId != null) 'CustomAmiId': customAmiId,
if (ebsRootVolumeIops != null) 'EbsRootVolumeIops': ebsRootVolumeIops,
if (ebsRootVolumeSize != null) 'EbsRootVolumeSize': ebsRootVolumeSize,
if (ebsRootVolumeThroughput != null)
'EbsRootVolumeThroughput': ebsRootVolumeThroughput,
if (extendedSupport != null) 'ExtendedSupport': extendedSupport,
if (jobFlowRole != null) 'JobFlowRole': jobFlowRole,
if (kerberosAttributes != null)
'KerberosAttributes': kerberosAttributes,
if (logEncryptionKmsKeyId != null)
'LogEncryptionKmsKeyId': logEncryptionKmsKeyId,
if (logUri != null) 'LogUri': logUri,
if (managedScalingPolicy != null)
'ManagedScalingPolicy': managedScalingPolicy,
if (monitoringConfiguration != null)
'MonitoringConfiguration': monitoringConfiguration,
if (newSupportedProducts != null)
'NewSupportedProducts': newSupportedProducts,
if (oSReleaseLabel != null) 'OSReleaseLabel': oSReleaseLabel,
if (placementGroupConfigs != null)
'PlacementGroupConfigs': placementGroupConfigs,
if (releaseLabel != null) 'ReleaseLabel': releaseLabel,
if (repoUpgradeOnBoot != null)
'RepoUpgradeOnBoot': repoUpgradeOnBoot.value,
if (scaleDownBehavior != null)
'ScaleDownBehavior': scaleDownBehavior.value,
if (securityConfiguration != null)
'SecurityConfiguration': securityConfiguration,
if (serviceRole != null) 'ServiceRole': serviceRole,
if (sessionEnabled != null) 'SessionEnabled': sessionEnabled,
if (stepConcurrencyLevel != null)
'StepConcurrencyLevel': stepConcurrencyLevel,
if (stepExecutionRoleArn != null)
'StepExecutionRoleArn': stepExecutionRoleArn,
if (steps != null) 'Steps': steps,
if (supportedProducts != null) 'SupportedProducts': supportedProducts,
if (tags != null) 'Tags': tags,
if (visibleToAllUsers != null) 'VisibleToAllUsers': visibleToAllUsers,
},
);
return RunJobFlowOutput.fromJson(jsonResponse.body);
}