EmrContainers class

Amazon EMR on EKS provides a deployment option for Amazon EMR that allows you to run open-source big data frameworks on Amazon Elastic Kubernetes Service (Amazon EKS). With this deployment option, you can focus on running analytics workloads while Amazon EMR on EKS builds, configures, and manages containers for open-source applications. For more information about Amazon EMR on EKS concepts and tasks, see What is Amazon EMR on EKS.

Amazon EMR containers is the API name for Amazon EMR on EKS. The emr-containers prefix is used in the following scenarios:

  • It is the prefix in the CLI commands for Amazon EMR on EKS. For example, aws emr-containers start-job-run.
  • It is the prefix before IAM policy actions for Amazon EMR on EKS. For example, "Action": \[ "emr-containers:StartJobRun"\]. For more information, see Policy actions for Amazon EMR on EKS.
  • It is the prefix used in Amazon EMR on EKS service endpoints. For example, emr-containers.us-east-2.amazonaws.com. For more information, see Amazon EMR on EKSService Endpoints.

Constructors

EmrContainers({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelJobRun({required String id, required String virtualClusterId}) Future<CancelJobRunResponse>
Cancels a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createJobTemplate({required JobTemplateData jobTemplateData, required String name, String? clientToken, String? kmsKeyArn, Map<String, String>? tags}) Future<CreateJobTemplateResponse>
Creates a job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
createManagedEndpoint({required String executionRoleArn, required String name, required String releaseLabel, required String type, required String virtualClusterId, String? certificateArn, String? clientToken, ConfigurationOverrides? configurationOverrides, Map<String, String>? tags}) Future<CreateManagedEndpointResponse>
Creates a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
createSecurityConfiguration({required String name, required SecurityConfigurationData securityConfigurationData, String? clientToken, ContainerProvider? containerProvider, Map<String, String>? tags}) Future<CreateSecurityConfigurationResponse>
Creates a security configuration. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
createVirtualCluster({required ContainerProvider containerProvider, required String name, String? clientToken, String? securityConfigurationId, Map<String, String>? tags}) Future<CreateVirtualClusterResponse>
Creates a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
deleteJobTemplate({required String id}) Future<DeleteJobTemplateResponse>
Deletes a job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
deleteManagedEndpoint({required String id, required String virtualClusterId}) Future<DeleteManagedEndpointResponse>
Deletes a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
deleteVirtualCluster({required String id}) Future<DeleteVirtualClusterResponse>
Deletes a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
describeJobRun({required String id, required String virtualClusterId}) Future<DescribeJobRunResponse>
Displays detailed information about a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
describeJobTemplate({required String id}) Future<DescribeJobTemplateResponse>
Displays detailed information about a specified job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
describeManagedEndpoint({required String id, required String virtualClusterId}) Future<DescribeManagedEndpointResponse>
Displays detailed information about a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
describeSecurityConfiguration({required String id}) Future<DescribeSecurityConfigurationResponse>
Displays detailed information about a specified security configuration. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
describeVirtualCluster({required String id}) Future<DescribeVirtualClusterResponse>
Displays detailed information about a specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
getManagedEndpointSessionCredentials({required String credentialType, required String endpointIdentifier, required String executionRoleArn, required String virtualClusterIdentifier, String? clientToken, int? durationInSeconds, String? logContext}) Future<GetManagedEndpointSessionCredentialsResponse>
Generate a session token to connect to a managed endpoint.
listJobRuns({required String virtualClusterId, DateTime? createdAfter, DateTime? createdBefore, int? maxResults, String? name, String? nextToken, List<JobRunState>? states}) Future<ListJobRunsResponse>
Lists job runs based on a set of parameters. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
listJobTemplates({DateTime? createdAfter, DateTime? createdBefore, int? maxResults, String? nextToken}) Future<ListJobTemplatesResponse>
Lists job templates based on a set of parameters. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
listManagedEndpoints({required String virtualClusterId, DateTime? createdAfter, DateTime? createdBefore, int? maxResults, String? nextToken, List<EndpointState>? states, List<String>? types}) Future<ListManagedEndpointsResponse>
Lists managed endpoints based on a set of parameters. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
listSecurityConfigurations({DateTime? createdAfter, DateTime? createdBefore, int? maxResults, String? nextToken}) Future<ListSecurityConfigurationsResponse>
Lists security configurations based on a set of parameters. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags assigned to the resources.
listVirtualClusters({String? containerProviderId, ContainerProviderType? containerProviderType, DateTime? createdAfter, DateTime? createdBefore, bool? eksAccessEntryIntegrated, int? maxResults, String? nextToken, List<VirtualClusterState>? states}) Future<ListVirtualClustersResponse>
Lists information about the specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startJobRun({required String virtualClusterId, String? clientToken, ConfigurationOverrides? configurationOverrides, String? executionRoleArn, JobDriver? jobDriver, String? jobTemplateId, Map<String, String>? jobTemplateParameters, String? name, String? releaseLabel, RetryPolicyConfiguration? retryPolicyConfiguration, Map<String, String>? tags}) Future<StartJobRunResponse>
Starts a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns tags to resources. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you've assigned to it. For example, you can define a set of tags for your Amazon EMR on EKS clusters to help you track each cluster's owner and stack level. We recommend that you devise a consistent set of tag keys for each resource type. You can then search and filter the resources based on the tags that you add.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from resources.

Operators

operator ==(Object other) bool
The equality operator.
inherited