cancelJobRun method

Future<CancelJobRunResponse> cancelJobRun({
  1. required String id,
  2. required String virtualClusterId,
})

Cancels a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.

May throw InternalServerException. May throw ValidationException.

Parameter id : The ID of the job run to cancel.

Parameter virtualClusterId : The ID of the virtual cluster for which the job run will be canceled.

Implementation

Future<CancelJobRunResponse> cancelJobRun({
  required String id,
  required String virtualClusterId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/virtualclusters/${Uri.encodeComponent(virtualClusterId)}/jobruns/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return CancelJobRunResponse.fromJson(response);
}