describeJobRun method
Displays detailed information about a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter id :
The ID of the job run request.
Parameter virtualClusterId :
The ID of the virtual cluster for which the job run is submitted.
Implementation
Future<DescribeJobRunResponse> describeJobRun({
required String id,
required String virtualClusterId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/virtualclusters/${Uri.encodeComponent(virtualClusterId)}/jobruns/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return DescribeJobRunResponse.fromJson(response);
}