listSecurityConfigurations method
Lists security configurations based on a set of parameters. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
May throw InternalServerException.
May throw ValidationException.
Parameter createdAfter :
The date and time after which the security configuration was created.
Parameter createdBefore :
The date and time before which the security configuration was created.
Parameter maxResults :
The maximum number of security configurations the operation can list.
Parameter nextToken :
The token for the next set of security configurations to return.
Implementation
Future<ListSecurityConfigurationsResponse> listSecurityConfigurations({
DateTime? createdAfter,
DateTime? createdBefore,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (createdAfter != null)
'createdAfter': [_s.iso8601ToJson(createdAfter).toString()],
if (createdBefore != null)
'createdBefore': [_s.iso8601ToJson(createdBefore).toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/securityconfigurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSecurityConfigurationsResponse.fromJson(response);
}