listVirtualClusters method
Lists information about the specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
May throw InternalServerException.
May throw ValidationException.
Parameter containerProviderId :
The container provider ID of the virtual cluster.
Parameter containerProviderType :
The container provider type of the virtual cluster. Amazon EKS is the only
supported type as of now.
Parameter createdAfter :
The date and time after which the virtual clusters are created.
Parameter createdBefore :
The date and time before which the virtual clusters are created.
Parameter eksAccessEntryIntegrated :
Optional Boolean that specifies whether the operation should return the
virtual clusters that have the access entry integration enabled or
disabled. If not specified, the operation returns all applicable virtual
clusters.
Parameter maxResults :
The maximum number of virtual clusters that can be listed.
Parameter nextToken :
The token for the next set of virtual clusters to return.
Parameter states :
The states of the requested virtual clusters.
Implementation
Future<ListVirtualClustersResponse> listVirtualClusters({
String? containerProviderId,
ContainerProviderType? containerProviderType,
DateTime? createdAfter,
DateTime? createdBefore,
bool? eksAccessEntryIntegrated,
int? maxResults,
String? nextToken,
List<VirtualClusterState>? states,
}) async {
final $query = <String, List<String>>{
if (containerProviderId != null)
'containerProviderId': [containerProviderId],
if (containerProviderType != null)
'containerProviderType': [containerProviderType.value],
if (createdAfter != null)
'createdAfter': [_s.iso8601ToJson(createdAfter).toString()],
if (createdBefore != null)
'createdBefore': [_s.iso8601ToJson(createdBefore).toString()],
if (eksAccessEntryIntegrated != null)
'eksAccessEntryIntegrated': [eksAccessEntryIntegrated.toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (states != null) 'states': states.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/virtualclusters',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListVirtualClustersResponse.fromJson(response);
}