EmrServerless class
Amazon EMR Serverless is a new deployment option for Amazon EMR. Amazon EMR Serverless provides a serverless runtime environment that simplifies running analytics applications using the latest open source frameworks such as Apache Spark and Apache Hive. With Amazon EMR Serverless, you don’t have to configure, optimize, secure, or operate clusters to run applications with these frameworks.
The API reference to Amazon EMR Serverless is emr-serverless.
The emr-serverless prefix is used in the following scenarios:
-
It is the prefix in the CLI commands for Amazon EMR Serverless. For example,
aws emr-serverless start-job-run. -
It is the prefix before IAM policy actions for Amazon EMR Serverless. For
example,
"Action": \["emr-serverless:StartJobRun"\]. For more information, see Policy actions for Amazon EMR Serverless. -
It is the prefix used in Amazon EMR Serverless service endpoints. For
example,
emr-serverless.us-east-2.amazonaws.com.
Constructors
- EmrServerless({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelJobRun(
{required String applicationId, required String jobRunId, int? shutdownGracePeriodInSeconds}) → Future< CancelJobRunResponse> - Cancels a job run.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createApplication(
{required String releaseLabel, required String type, Architecture? architecture, AutoStartConfig? autoStartConfiguration, AutoStopConfig? autoStopConfiguration, String? clientToken, DiskEncryptionConfiguration? diskEncryptionConfiguration, IdentityCenterConfigurationInput? identityCenterConfiguration, ImageConfigurationInput? imageConfiguration, Map< String, InitialCapacityConfig> ? initialCapacity, InteractiveConfiguration? interactiveConfiguration, JobLevelCostAllocationConfiguration? jobLevelCostAllocationConfiguration, MaximumAllowedResources? maximumCapacity, MonitoringConfiguration? monitoringConfiguration, String? name, NetworkConfiguration? networkConfiguration, List<Configuration> ? runtimeConfiguration, SchedulerConfiguration? schedulerConfiguration, Map<String, String> ? tags, Map<String, WorkerTypeSpecificationInput> ? workerTypeSpecifications}) → Future<CreateApplicationResponse> - Creates an application.
-
deleteApplication(
{required String applicationId}) → Future< void> - Deletes an application. An application has to be in a stopped or created state in order to be deleted.
-
getApplication(
{required String applicationId}) → Future< GetApplicationResponse> - Displays detailed information about a specified application.
-
getDashboardForJobRun(
{required String applicationId, required String jobRunId, bool? accessSystemProfileLogs, int? attempt}) → Future< GetDashboardForJobRunResponse> - Creates and returns a URL that you can use to access the application UIs for a job run.
-
getJobRun(
{required String applicationId, required String jobRunId, int? attempt}) → Future< GetJobRunResponse> - Displays detailed information about a job run.
-
getResourceDashboard(
{required String applicationId, required String resourceId, required ResourceType resourceType}) → Future< GetResourceDashboardResponse> - Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
-
getSession(
{required String applicationId, required String sessionId}) → Future< GetSessionResponse> - Displays detailed information about a session.
-
getSessionEndpoint(
{required String applicationId, required String sessionId}) → Future< GetSessionEndpointResponse> - Returns the session endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a client to the session. Call this operation again when the authentication token expires to obtain a new token.
-
listApplications(
{int? maxResults, String? nextToken, List< ApplicationState> ? states}) → Future<ListApplicationsResponse> - Lists applications based on a set of parameters.
-
listJobRunAttempts(
{required String applicationId, required String jobRunId, int? maxResults, String? nextToken}) → Future< ListJobRunAttemptsResponse> - Lists all attempt of a job run.
-
listJobRuns(
{required String applicationId, DateTime? createdAtAfter, DateTime? createdAtBefore, int? maxResults, JobRunMode? mode, String? nextToken, List< JobRunState> ? states}) → Future<ListJobRunsResponse> - Lists job runs based on a set of parameters.
-
listSessions(
{required String applicationId, DateTime? createdAtAfter, DateTime? createdAtBefore, int? maxResults, String? nextToken, List< SessionState> ? states}) → Future<ListSessionsResponse> - Lists sessions for the specified application. You can filter sessions by state and creation time.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags assigned to the resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startApplication(
{required String applicationId}) → Future< void> - Starts a specified application and initializes initial capacity if configured.
-
startJobRun(
{required String applicationId, required String executionRoleArn, String? clientToken, ConfigurationOverrides? configurationOverrides, JobRunExecutionIamPolicy? executionIamPolicy, int? executionTimeoutMinutes, JobDriver? jobDriver, JobRunMode? mode, String? name, RetryPolicy? retryPolicy, Map< String, String> ? tags}) → Future<StartJobRunResponse> - Starts a job run.
-
startSession(
{required String applicationId, required String executionRoleArn, String? clientToken, SessionConfigurationOverrides? configurationOverrides, int? idleTimeoutMinutes, String? name, Map< String, String> ? tags}) → Future<StartSessionResponse> -
Creates and starts a new session on the specified application. The
application must be in the
STARTEDstate or haveAutoStartenabled, and have interactive sessions enabled. This operation is supported for EMR release 7.13.0 and later. -
stopApplication(
{required String applicationId}) → Future< void> - Stops a specified application and releases initial capacity if configured. All scheduled and running jobs must be completed or cancelled before stopping an application.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns tags to resources. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you've assigned to it.
-
terminateSession(
{required String applicationId, required String sessionId}) → Future< TerminateSessionResponse> -
Terminates the specified session. After you terminate a session, it enters
the
TERMINATINGstate and then theTERMINATEDstate. You can still access the Spark History Server for a terminated session through theGetResourceDashboardoperation. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from resources.
-
updateApplication(
{required String applicationId, Architecture? architecture, AutoStartConfig? autoStartConfiguration, AutoStopConfig? autoStopConfiguration, String? clientToken, DiskEncryptionConfiguration? diskEncryptionConfiguration, IdentityCenterConfigurationInput? identityCenterConfiguration, ImageConfigurationInput? imageConfiguration, Map< String, InitialCapacityConfig> ? initialCapacity, InteractiveConfiguration? interactiveConfiguration, JobLevelCostAllocationConfiguration? jobLevelCostAllocationConfiguration, MaximumAllowedResources? maximumCapacity, MonitoringConfiguration? monitoringConfiguration, NetworkConfiguration? networkConfiguration, String? releaseLabel, List<Configuration> ? runtimeConfiguration, SchedulerConfiguration? schedulerConfiguration, Map<String, WorkerTypeSpecificationInput> ? workerTypeSpecifications}) → Future<UpdateApplicationResponse> - Updates a specified application. An application has to be in a stopped or created state in order to be updated.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited