getDashboardForJobRun method

Future<GetDashboardForJobRunResponse> getDashboardForJobRun({
  1. required String applicationId,
  2. required String jobRunId,
  3. bool? accessSystemProfileLogs,
  4. int? attempt,
})

Creates and returns a URL that you can use to access the application UIs for a job run.

For jobs in a running state, the application UI is a live user interface such as the Spark or Tez web UI. For completed jobs, the application UI is a persistent application user interface such as the Spark History Server or persistent Tez UI.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application.

Parameter jobRunId : The ID of the job run.

Parameter accessSystemProfileLogs : Allows access to system profile logs for Lake Formation-enabled jobs. Default is false.

Parameter attempt : An optimal parameter that indicates the amount of attempts for the job. If not specified, this value defaults to the attempt of the latest job.

Implementation

Future<GetDashboardForJobRunResponse> getDashboardForJobRun({
  required String applicationId,
  required String jobRunId,
  bool? accessSystemProfileLogs,
  int? attempt,
}) async {
  _s.validateNumRange(
    'attempt',
    attempt,
    1,
    1152921504606846976,
  );
  final $query = <String, List<String>>{
    if (accessSystemProfileLogs != null)
      'accessSystemProfileLogs': [accessSystemProfileLogs.toString()],
    if (attempt != null) 'attempt': [attempt.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/jobruns/${Uri.encodeComponent(jobRunId)}/dashboard',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetDashboardForJobRunResponse.fromJson(response);
}