getJobRun method

Future<GetJobRunResponse> getJobRun({
  1. required String applicationId,
  2. required String jobRunId,
  3. int? attempt,
})

Displays detailed information about a job run.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application on which the job run is submitted.

Parameter jobRunId : The ID of the job run.

Parameter attempt : An optimal parameter that indicates the amount of attempts for the job. If not specified, this value defaults to the attempt of the latest job.

Implementation

Future<GetJobRunResponse> getJobRun({
  required String applicationId,
  required String jobRunId,
  int? attempt,
}) async {
  _s.validateNumRange(
    'attempt',
    attempt,
    1,
    1152921504606846976,
  );
  final $query = <String, List<String>>{
    if (attempt != null) 'attempt': [attempt.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/jobruns/${Uri.encodeComponent(jobRunId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetJobRunResponse.fromJson(response);
}