getSessionEndpoint method

Future<GetSessionEndpointResponse> getSessionEndpoint({
  1. required String applicationId,
  2. required String sessionId,
})

Returns the session endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a client to the session. Call this operation again when the authentication token expires to obtain a new token.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application that the session belongs to.

Parameter sessionId : The ID of the session.

Implementation

Future<GetSessionEndpointResponse> getSessionEndpoint({
  required String applicationId,
  required String sessionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/sessions/${Uri.encodeComponent(sessionId)}/endpoint',
    exceptionFnMap: _exceptionFns,
  );
  return GetSessionEndpointResponse.fromJson(response);
}