stopApplication method

Future<void> stopApplication({
  1. required String applicationId,
})

Stops a specified application and releases initial capacity if configured. All scheduled and running jobs must be completed or cancelled before stopping an application.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application to stop.

Implementation

Future<void> stopApplication({
  required String applicationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/applications/${Uri.encodeComponent(applicationId)}/stop',
    exceptionFnMap: _exceptionFns,
  );
}