deleteSchemaMapping method

Future<DeleteSchemaMappingOutput> deleteSchemaMapping({
  1. required String schemaName,
})

Deletes the SchemaMapping with a given name. This operation will succeed even if a schema with the given name does not exist. This operation will fail if there is a MatchingWorkflow object that references the SchemaMapping in the workflow's InputSourceConfig.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter schemaName : The name of the schema to delete.

Implementation

Future<DeleteSchemaMappingOutput> deleteSchemaMapping({
  required String schemaName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/schemas/${Uri.encodeComponent(schemaName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteSchemaMappingOutput.fromJson(response);
}