startMatchingJob method

Future<StartMatchingJobOutput> startMatchingJob({
  1. required String workflowName,
})

Starts the MatchingJob of a workflow. The workflow must have previously been created using the CreateMatchingWorkflow endpoint.

May throw AccessDeniedException. May throw ConflictException. May throw ExceedsLimitException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter workflowName : The name of the matching job to be retrieved.

Implementation

Future<StartMatchingJobOutput> startMatchingJob({
  required String workflowName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/matchingworkflows/${Uri.encodeComponent(workflowName)}/jobs',
    exceptionFnMap: _exceptionFns,
  );
  return StartMatchingJobOutput.fromJson(response);
}