tagResource method
Assigns one or more tags (key-value pairs) to the specified Entity
Resolution resource. Tags can help you organize and categorize your
resources. You can also use them to scope user permissions by granting a
user permission to access or change only resources with certain tag
values. In Entity Resolution, SchemaMapping and
MatchingWorkflow can be tagged. Tags don't have any semantic
meaning to Amazon Web Services and are interpreted strictly as strings of
characters. You can use the TagResource action with a
resource that already has tags. If you specify a new tag key, this tag is
appended to the list of tags associated with the resource. If you specify
a tag key that is already associated with the resource, the new tag value
that you specify replaces the previous value for that tag.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the resource for which you want to view tags.
Parameter tags :
The tags used to organize, track, or control access for this resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}