updateIdMappingWorkflow method

Future<UpdateIdMappingWorkflowOutput> updateIdMappingWorkflow({
  1. required IdMappingTechniques idMappingTechniques,
  2. required List<IdMappingWorkflowInputSource> inputSourceConfig,
  3. required String workflowName,
  4. String? description,
  5. IdMappingIncrementalRunConfig? incrementalRunConfig,
  6. List<IdMappingWorkflowOutputSource>? outputSourceConfig,
  7. String? roleArn,
})

Updates an existing IdMappingWorkflow. This method is identical to CreateIdMappingWorkflow, except it uses an HTTP PUT request instead of a POST request, and the IdMappingWorkflow must already exist for the method to succeed.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter idMappingTechniques : An object which defines the ID mapping technique and any additional configurations.

Parameter inputSourceConfig : A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

Parameter workflowName : The name of the workflow.

Parameter description : A description of the workflow.

Parameter incrementalRunConfig : The incremental run configuration for the update ID mapping workflow.

Parameter outputSourceConfig : A list of OutputSource objects, each of which contains fields outputS3Path and KMSArn.

Parameter roleArn : The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.

Implementation

Future<UpdateIdMappingWorkflowOutput> updateIdMappingWorkflow({
  required IdMappingTechniques idMappingTechniques,
  required List<IdMappingWorkflowInputSource> inputSourceConfig,
  required String workflowName,
  String? description,
  IdMappingIncrementalRunConfig? incrementalRunConfig,
  List<IdMappingWorkflowOutputSource>? outputSourceConfig,
  String? roleArn,
}) async {
  final $payload = <String, dynamic>{
    'idMappingTechniques': idMappingTechniques,
    'inputSourceConfig': inputSourceConfig,
    if (description != null) 'description': description,
    if (incrementalRunConfig != null)
      'incrementalRunConfig': incrementalRunConfig,
    if (outputSourceConfig != null) 'outputSourceConfig': outputSourceConfig,
    if (roleArn != null) 'roleArn': roleArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/idmappingworkflows/${Uri.encodeComponent(workflowName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateIdMappingWorkflowOutput.fromJson(response);
}