updateIdNamespace method

Future<UpdateIdNamespaceOutput> updateIdNamespace({
  1. required String idNamespaceName,
  2. String? description,
  3. List<IdNamespaceIdMappingWorkflowProperties>? idMappingWorkflowProperties,
  4. List<IdNamespaceInputSource>? inputSourceConfig,
  5. String? roleArn,
})

Updates an existing ID namespace.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter idNamespaceName : The name of the ID namespace.

Parameter description : The description of the ID namespace.

Parameter idMappingWorkflowProperties : Determines the properties of IdMappingWorkflow where this IdNamespace can be used as a Source or a Target.

Parameter inputSourceConfig : A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

Parameter roleArn : The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access the resources defined in this IdNamespace on your behalf as part of a workflow run.

Implementation

Future<UpdateIdNamespaceOutput> updateIdNamespace({
  required String idNamespaceName,
  String? description,
  List<IdNamespaceIdMappingWorkflowProperties>? idMappingWorkflowProperties,
  List<IdNamespaceInputSource>? inputSourceConfig,
  String? roleArn,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (idMappingWorkflowProperties != null)
      'idMappingWorkflowProperties': idMappingWorkflowProperties,
    if (inputSourceConfig != null) 'inputSourceConfig': inputSourceConfig,
    if (roleArn != null) 'roleArn': roleArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/idnamespaces/${Uri.encodeComponent(idNamespaceName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateIdNamespaceOutput.fromJson(response);
}