updateMatchingWorkflow method

Future<UpdateMatchingWorkflowOutput> updateMatchingWorkflow({
  1. required List<InputSource> inputSourceConfig,
  2. required List<OutputSource> outputSourceConfig,
  3. required ResolutionTechniques resolutionTechniques,
  4. required String roleArn,
  5. required String workflowName,
  6. String? description,
  7. IncrementalRunConfig? incrementalRunConfig,
})

Updates an existing matching workflow. The workflow must already exist for this operation to succeed.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter inputSourceConfig : A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

Parameter outputSourceConfig : A list of OutputSource objects, each of which contains fields outputS3Path, applyNormalization, KMSArn, and output.

Parameter resolutionTechniques : An object which defines the resolutionType and the ruleBasedProperties.

Parameter roleArn : The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.

Parameter workflowName : The name of the workflow to be retrieved.

Parameter description : A description of the workflow.

Parameter incrementalRunConfig : Optional. An object that defines the incremental run type. This object contains only the incrementalRunType field, which appears as "Automatic" in the console.

Implementation

Future<UpdateMatchingWorkflowOutput> updateMatchingWorkflow({
  required List<InputSource> inputSourceConfig,
  required List<OutputSource> outputSourceConfig,
  required ResolutionTechniques resolutionTechniques,
  required String roleArn,
  required String workflowName,
  String? description,
  IncrementalRunConfig? incrementalRunConfig,
}) async {
  final $payload = <String, dynamic>{
    'inputSourceConfig': inputSourceConfig,
    'outputSourceConfig': outputSourceConfig,
    'resolutionTechniques': resolutionTechniques,
    'roleArn': roleArn,
    if (description != null) 'description': description,
    if (incrementalRunConfig != null)
      'incrementalRunConfig': incrementalRunConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/matchingworkflows/${Uri.encodeComponent(workflowName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateMatchingWorkflowOutput.fromJson(response);
}