updateSchemaMapping method

Future<UpdateSchemaMappingOutput> updateSchemaMapping({
  1. required List<SchemaInputAttribute> mappedInputFields,
  2. required String schemaName,
  3. String? description,
})

Updates a schema mapping.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter mappedInputFields : A list of MappedInputFields. Each MappedInputField corresponds to a column the source data table, and contains column name plus additional information that Entity Resolution uses for matching.

Parameter schemaName : The name of the schema. There can't be multiple SchemaMappings with the same name.

Parameter description : A description of the schema.

Implementation

Future<UpdateSchemaMappingOutput> updateSchemaMapping({
  required List<SchemaInputAttribute> mappedInputFields,
  required String schemaName,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    'mappedInputFields': mappedInputFields,
    if (description != null) 'description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/schemas/${Uri.encodeComponent(schemaName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSchemaMappingOutput.fromJson(response);
}