deleteEndpoint method
Delete an existing global endpoint. For more information about global endpoints, see Making applications Regional-fault tolerant with global endpoints and event replication in the Amazon EventBridge User Guide .
May throw ConcurrentModificationException.
May throw InternalException.
May throw ResourceNotFoundException.
Parameter name :
The name of the endpoint you want to delete. For example,
"Name":"us-east-2-custom_bus_A-endpoint"..
Implementation
Future<void> deleteEndpoint({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.DeleteEndpoint'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
}