listConnections method

Future<ListConnectionsResponse> listConnections({
  1. ConnectionState? connectionState,
  2. int? limit,
  3. String? namePrefix,
  4. String? nextToken,
})

Retrieves a list of connections from the account.

May throw InternalException.

Parameter connectionState : The state of the connection.

Parameter limit : The maximum number of connections to return.

Parameter namePrefix : A name prefix to filter results returned. Only connections with a name that starts with the prefix are returned.

Parameter nextToken : The token returned by a previous call, which you can use to retrieve the next set of results.

The value of nextToken is a unique pagination token for each page. To retrieve the next page of results, make the call again using the returned token. Keep all other arguments unchanged.

Using an expired pagination token results in an HTTP 400 InvalidToken error.

Implementation

Future<ListConnectionsResponse> listConnections({
  ConnectionState? connectionState,
  int? limit,
  String? namePrefix,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSEvents.ListConnections'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (connectionState != null) 'ConnectionState': connectionState.value,
      if (limit != null) 'Limit': limit,
      if (namePrefix != null) 'NamePrefix': namePrefix,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListConnectionsResponse.fromJson(jsonResponse.body);
}