listTargetsByRule method

Future<ListTargetsByRuleResponse> listTargetsByRule({
  1. required String rule,
  2. String? eventBusName,
  3. int? limit,
  4. String? nextToken,
})

Lists the targets assigned to the specified rule.

The maximum number of results per page for requests is 100.

May throw InternalException. May throw ResourceNotFoundException.

Parameter rule : The name of the rule.

Parameter eventBusName : The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used.

Parameter limit : The maximum number of results to return.

Parameter nextToken : The token returned by a previous call, which you can use to retrieve the next set of results.

The value of nextToken is a unique pagination token for each page. To retrieve the next page of results, make the call again using the returned token. Keep all other arguments unchanged.

Using an expired pagination token results in an HTTP 400 InvalidToken error.

Implementation

Future<ListTargetsByRuleResponse> listTargetsByRule({
  required String rule,
  String? eventBusName,
  int? limit,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSEvents.ListTargetsByRule'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Rule': rule,
      if (eventBusName != null) 'EventBusName': eventBusName,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListTargetsByRuleResponse.fromJson(jsonResponse.body);
}