putPartnerEvents method
Future<PutPartnerEventsResponse>
putPartnerEvents({
- required List<
PutPartnerEventsRequestEntry> entries,
This is used by SaaS partners to write events to a customer's partner event bus. Amazon Web Services customers do not use this operation.
For information on calculating event batch size, see Calculating EventBridge PutEvents event entry size in the EventBridge User Guide.
May throw InternalException.
May throw OperationDisabledException.
Parameter entries :
The list of events to write to the event bus.
Implementation
Future<PutPartnerEventsResponse> putPartnerEvents({
required List<PutPartnerEventsRequestEntry> entries,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.PutPartnerEvents'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Entries': entries,
},
);
return PutPartnerEventsResponse.fromJson(jsonResponse.body);
}