untagResource method
Removes one or more tags from the specified EventBridge resource. In Amazon EventBridge, rules and event buses can be tagged.
May throw ConcurrentModificationException.
May throw InternalException.
May throw ManagedRuleException.
May throw ResourceNotFoundException.
Parameter resourceARN :
The ARN of the EventBridge resource from which you are removing tags.
Parameter tagKeys :
The list of tag keys to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceARN,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'TagKeys': tagKeys,
},
);
}