Evs class
Amazon Elastic VMware Service (Amazon EVS) is a service that you can use to deploy a VMware Cloud Foundation (VCF) software environment directly on EC2 bare metal instances within an Amazon Virtual Private Cloud (VPC).
Workloads running on Amazon EVS are fully compatible with workloads running on any standard VMware vSphere environment. This means that you can migrate any VMware-based workload to Amazon EVS without workload modification.
Constructors
- Evs({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateEipToVlan(
{required String allocationId, required String environmentId, required String vlanName, String? clientToken}) → Future< AssociateEipToVlanResponse> - Associates an Elastic IP address with a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createEntitlement(
{required String connectorId, required EntitlementType entitlementType, required String environmentId, required List< String> vmIds, String? clientToken}) → Future<CreateEntitlementResponse> - Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector. This is an asynchronous operation. Amazon EVS validates the specified virtual machines before starting usage tracking.
-
createEnvironment(
{required ConnectivityInfo connectivityInfo, required List< HostInfoForCreate> hosts, required InitialVlans initialVlans, required List<LicenseInfo> licenseInfo, required String serviceAccessSubnetId, required String siteId, required bool termsAccepted, required VcfHostnames vcfHostnames, required VcfVersion vcfVersion, required String vpcId, String? clientToken, String? environmentName, String? kmsKeyId, ServiceAccessSecurityGroups? serviceAccessSecurityGroups, Map<String, String> ? tags}) → Future<CreateEnvironmentResponse> - Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
-
createEnvironmentConnector(
{required String applianceFqdn, required String environmentId, required String secretIdentifier, required ConnectorType type, String? clientToken}) → Future< CreateEnvironmentConnectorResponse> - Creates a connector for an Amazon EVS environment. A connector establishes a connection to a VCF appliance, such as vCenter, using a fully qualified domain name and an Amazon Web Services Secrets Manager secret that stores the appliance credentials.
-
createEnvironmentHost(
{required String environmentId, required HostInfoForCreate host, String? clientToken, String? esxVersion}) → Future< CreateEnvironmentHostResponse> - Creates an ESX host and adds it to an Amazon EVS environment. Amazon EVS supports 4-32 hosts per environment.
-
deleteEntitlement(
{required String connectorId, required EntitlementType entitlementType, required String environmentId, required List< String> vmIds, String? clientToken}) → Future<DeleteEntitlementResponse> - Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment. Deleting an entitlement stops usage tracking for the specified virtual machines.
-
deleteEnvironment(
{required String environmentId, String? clientToken}) → Future< DeleteEnvironmentResponse> - Deletes an Amazon EVS environment.
-
deleteEnvironmentConnector(
{required String connectorId, required String environmentId, String? clientToken}) → Future< DeleteEnvironmentConnectorResponse> - Deletes a connector from an Amazon EVS environment.
-
deleteEnvironmentHost(
{required String environmentId, required String hostName, String? clientToken}) → Future< DeleteEnvironmentHostResponse> - Deletes a host from an Amazon EVS environment.
-
disassociateEipFromVlan(
{required String associationId, required String environmentId, required String vlanName, String? clientToken}) → Future< DisassociateEipFromVlanResponse> - Disassociates an Elastic IP address from a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
-
getDepotUrl(
{required String environmentId, bool? rotate}) → Future< GetDepotUrlResponse> - Returns a URL and authentication token for accessing the Amazon EVS Custom Addon depot. Configure the depot URL as a download source in vSphere Lifecycle Manager (vLCM) to sync and install the Amazon EVS Custom Addon.
-
getEnvironment(
{required String environmentId}) → Future< GetEnvironmentResponse> - Returns a description of the specified environment.
-
getVersions(
) → Future< GetVersionsResponse> - Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS. For each VCF version, the response also includes the default ESX version and provided EC2 instance types.
-
listEnvironmentConnectors(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListEnvironmentConnectorsResponse> - Lists the connectors within an environment. Returns the status of each connector and its applicable checks, among other connector details.
-
listEnvironmentHosts(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListEnvironmentHostsResponse> - List the hosts within an environment.
-
listEnvironments(
{int? maxResults, String? nextToken, List< EnvironmentState> ? state}) → Future<ListEnvironmentsResponse> - Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
-
listEnvironmentVlans(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListEnvironmentVlansResponse> - Lists environment VLANs that are associated with the specified environment.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for an Amazon EVS resource.
-
listVmEntitlements(
{required String connectorId, required EntitlementType entitlementType, required String environmentId, int? maxResults, String? nextToken}) → Future< ListVmEntitlementsResponse> - Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment. Returns existing entitlements for virtual machines associated with the specified environment and connector.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> -
Associates the specified tags to an Amazon EVS resource with the specified
resourceArn. If existing tags on a resource are not specified in the request parameters, they aren't changed. When a resource is deleted, the tags associated with that resource are also deleted. Tags that you create for Amazon EVS resources don't propagate to any other resources associated with the environment. For example, if you tag an environment with this operation, that tag doesn't automatically propagate to the VLAN subnets and hosts associated with the environment. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Deletes specified tags from an Amazon EVS resource.
-
updateEnvironmentConnector(
{required String connectorId, required String environmentId, String? applianceFqdn, String? clientToken, String? secretIdentifier}) → Future< UpdateEnvironmentConnectorResponse> - Updates a connector for an Amazon EVS environment. You can update the Amazon Web Services Secrets Manager secret ARN or the appliance FQDN to reconfigure the connector metadata.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited