FSx class

Amazon FSx is a fully managed service that makes it easy for storage and application administrators to launch and use shared file storage.

Constructors

FSx({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateFileSystemAliases({required List<String> aliases, required String fileSystemId, String? clientRequestToken}) Future<AssociateFileSystemAliasesResponse>
Use this action to associate one or more Domain Name Server (DNS) aliases with an existing Amazon FSx for Windows File Server file system. A file system can have a maximum of 50 DNS aliases associated with it at any one time. If you try to associate a DNS alias that is already associated with the file system, FSx takes no action on that alias in the request. For more information, see Working with DNS Aliases and Walkthrough 5: Using DNS aliases to access your file system, including additional steps you must take to be able to access your file system using a DNS alias.
cancelDataRepositoryTask({required String taskId}) Future<CancelDataRepositoryTaskResponse>
Cancels an existing Amazon FSx for Lustre data repository task if that task is in either the PENDING or EXECUTING state. When you cancel an export task, Amazon FSx does the following.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
copyBackup({required String sourceBackupId, String? clientRequestToken, bool? copyTags, String? kmsKeyId, String? sourceRegion, List<Tag>? tags}) Future<CopyBackupResponse>
Copies an existing backup within the same Amazon Web Services account to another Amazon Web Services Region (cross-Region copy) or within the same Amazon Web Services Region (in-Region copy). You can have up to five backup copy requests in progress to a single destination Region per account.
copySnapshotAndUpdateVolume({required String sourceSnapshotARN, required String volumeId, String? clientRequestToken, OpenZFSCopyStrategy? copyStrategy, List<UpdateOpenZFSVolumeOption>? options}) Future<CopySnapshotAndUpdateVolumeResponse>
Updates an existing volume by using a snapshot from another Amazon FSx for OpenZFS file system. For more information, see on-demand data replication in the Amazon FSx for OpenZFS User Guide.
createAndAttachS3AccessPoint({required String name, required S3AccessPointAttachmentType type, String? clientRequestToken, CreateAndAttachS3AccessPointOntapConfiguration? ontapConfiguration, CreateAndAttachS3AccessPointOpenZFSConfiguration? openZFSConfiguration, CreateAndAttachS3AccessPointS3Configuration? s3AccessPoint}) Future<CreateAndAttachS3AccessPointResponse>
Creates an S3 access point and attaches it to an Amazon FSx volume. For FSx for OpenZFS file systems, the volume must be hosted on a high-availability file system, either Single-AZ or Multi-AZ. For more information, see Accessing your data using Amazon S3 access points. in the Amazon FSx for OpenZFS User Guide.
createBackup({String? clientRequestToken, String? fileSystemId, List<Tag>? tags, String? volumeId}) Future<CreateBackupResponse>
Creates a backup of an existing Amazon FSx for Windows File Server file system, Amazon FSx for Lustre file system, Amazon FSx for NetApp ONTAP volume, or Amazon FSx for OpenZFS file system. We recommend creating regular backups so that you can restore a file system or volume from a backup if an issue arises with the original file system or volume.
createDataRepositoryAssociation({required String dataRepositoryPath, required String fileSystemId, bool? batchImportMetaDataOnCreate, String? clientRequestToken, String? fileSystemPath, int? importedFileChunkSize, S3DataRepositoryConfiguration? s3, List<Tag>? tags}) Future<CreateDataRepositoryAssociationResponse>
Creates an Amazon FSx for Lustre data repository association (DRA). A data repository association is a link between a directory on the file system and an Amazon S3 bucket or prefix. You can have a maximum of 8 data repository associations on a file system. Data repository associations are supported on all FSx for Lustre 2.12 and 2.15 file systems, excluding scratch_1 deployment type.
createDataRepositoryTask({required String fileSystemId, required CompletionReport report, required DataRepositoryTaskType type, int? capacityToRelease, String? clientRequestToken, List<String>? paths, ReleaseConfiguration? releaseConfiguration, List<Tag>? tags}) Future<CreateDataRepositoryTaskResponse>
Creates an Amazon FSx for Lustre data repository task. A CreateDataRepositoryTask operation will fail if a data repository is not linked to the FSx file system.
createFileCache({required FileCacheType fileCacheType, required String fileCacheTypeVersion, required int storageCapacity, required List<String> subnetIds, String? clientRequestToken, bool? copyTagsToDataRepositoryAssociations, List<FileCacheDataRepositoryAssociation>? dataRepositoryAssociations, String? kmsKeyId, CreateFileCacheLustreConfiguration? lustreConfiguration, List<String>? securityGroupIds, List<Tag>? tags}) Future<CreateFileCacheResponse>
Creates a new Amazon File Cache resource.
createFileSystem({required FileSystemType fileSystemType, required List<String> subnetIds, String? clientRequestToken, String? fileSystemTypeVersion, String? kmsKeyId, CreateFileSystemLustreConfiguration? lustreConfiguration, NetworkType? networkType, CreateFileSystemOntapConfiguration? ontapConfiguration, CreateFileSystemOpenZFSConfiguration? openZFSConfiguration, List<String>? securityGroupIds, int? storageCapacity, StorageType? storageType, List<Tag>? tags, CreateFileSystemWindowsConfiguration? windowsConfiguration}) Future<CreateFileSystemResponse>
Creates a new, empty Amazon FSx file system. You can create the following supported Amazon FSx file systems using the CreateFileSystem API operation:
createFileSystemFromBackup({required String backupId, required List<String> subnetIds, String? clientRequestToken, String? fileSystemTypeVersion, String? kmsKeyId, CreateFileSystemLustreConfiguration? lustreConfiguration, NetworkType? networkType, CreateFileSystemOpenZFSConfiguration? openZFSConfiguration, List<String>? securityGroupIds, int? storageCapacity, StorageType? storageType, List<Tag>? tags, CreateFileSystemWindowsConfiguration? windowsConfiguration}) Future<CreateFileSystemFromBackupResponse>
Creates a new Amazon FSx for Lustre, Amazon FSx for Windows File Server, or Amazon FSx for OpenZFS file system from an existing Amazon FSx backup.
createSnapshot({required String name, required String volumeId, String? clientRequestToken, List<Tag>? tags}) Future<CreateSnapshotResponse>
Creates a snapshot of an existing Amazon FSx for OpenZFS volume. With snapshots, you can easily undo file changes and compare file versions by restoring the volume to a previous version.
createStorageVirtualMachine({required String fileSystemId, required String name, CreateSvmActiveDirectoryConfiguration? activeDirectoryConfiguration, String? clientRequestToken, StorageVirtualMachineRootVolumeSecurityStyle? rootVolumeSecurityStyle, String? svmAdminPassword, List<Tag>? tags}) Future<CreateStorageVirtualMachineResponse>
Creates a storage virtual machine (SVM) for an Amazon FSx for ONTAP file system.
createVolume({required String name, required VolumeType volumeType, String? clientRequestToken, CreateOntapVolumeConfiguration? ontapConfiguration, CreateOpenZFSVolumeConfiguration? openZFSConfiguration, List<Tag>? tags}) Future<CreateVolumeResponse>
Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage volume.
createVolumeFromBackup({required String backupId, required String name, String? clientRequestToken, CreateOntapVolumeConfiguration? ontapConfiguration, List<Tag>? tags}) Future<CreateVolumeFromBackupResponse>
Creates a new Amazon FSx for NetApp ONTAP volume from an existing Amazon FSx volume backup.
deleteBackup({required String backupId, String? clientRequestToken}) Future<DeleteBackupResponse>
Deletes an Amazon FSx backup. After deletion, the backup no longer exists, and its data is gone.
deleteDataRepositoryAssociation({required String associationId, String? clientRequestToken, bool? deleteDataInFileSystem}) Future<DeleteDataRepositoryAssociationResponse>
Deletes a data repository association on an Amazon FSx for Lustre file system. Deleting the data repository association unlinks the file system from the Amazon S3 bucket. When deleting a data repository association, you have the option of deleting the data in the file system that corresponds to the data repository association. Data repository associations are supported on all FSx for Lustre 2.12 and 2.15 file systems, excluding scratch_1 deployment type.
deleteFileCache({required String fileCacheId, String? clientRequestToken}) Future<DeleteFileCacheResponse>
Deletes an Amazon File Cache resource. After deletion, the cache no longer exists, and its data is gone.
deleteFileSystem({required String fileSystemId, String? clientRequestToken, DeleteFileSystemLustreConfiguration? lustreConfiguration, DeleteFileSystemOpenZFSConfiguration? openZFSConfiguration, DeleteFileSystemWindowsConfiguration? windowsConfiguration}) Future<DeleteFileSystemResponse>
Deletes a file system. After deletion, the file system no longer exists, and its data is gone. Any existing automatic backups and snapshots are also deleted.
deleteSnapshot({required String snapshotId, String? clientRequestToken}) Future<DeleteSnapshotResponse>
Deletes an Amazon FSx for OpenZFS snapshot. After deletion, the snapshot no longer exists, and its data is gone. Deleting a snapshot doesn't affect snapshots stored in a file system backup.
deleteStorageVirtualMachine({required String storageVirtualMachineId, String? clientRequestToken}) Future<DeleteStorageVirtualMachineResponse>
Deletes an existing Amazon FSx for ONTAP storage virtual machine (SVM). Prior to deleting an SVM, you must delete all non-root volumes in the SVM, otherwise the operation will fail.
deleteVolume({required String volumeId, String? clientRequestToken, DeleteVolumeOntapConfiguration? ontapConfiguration, DeleteVolumeOpenZFSConfiguration? openZFSConfiguration}) Future<DeleteVolumeResponse>
Deletes an Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volume.
describeBackups({List<String>? backupIds, List<Filter>? filters, int? maxResults, String? nextToken}) Future<DescribeBackupsResponse>
Returns the description of a specific Amazon FSx backup, if a BackupIds value is provided for that backup. Otherwise, it returns all backups owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
describeDataRepositoryAssociations({List<String>? associationIds, List<Filter>? filters, int? maxResults, String? nextToken}) Future<DescribeDataRepositoryAssociationsResponse>
Returns the description of specific Amazon FSx for Lustre or Amazon File Cache data repository associations, if one or more AssociationIds values are provided in the request, or if filters are used in the request. Data repository associations are supported on Amazon File Cache resources and all FSx for Lustre 2.12 and 2,15 file systems, excluding scratch_1 deployment type.
describeDataRepositoryTasks({List<DataRepositoryTaskFilter>? filters, int? maxResults, String? nextToken, List<String>? taskIds}) Future<DescribeDataRepositoryTasksResponse>
Returns the description of specific Amazon FSx for Lustre or Amazon File Cache data repository tasks, if one or more TaskIds values are provided in the request, or if filters are used in the request. You can use filters to narrow the response to include just tasks for specific file systems or caches, or tasks in a specific lifecycle state. Otherwise, it returns all data repository tasks owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
describeFileCaches({List<String>? fileCacheIds, int? maxResults, String? nextToken}) Future<DescribeFileCachesResponse>
Returns the description of a specific Amazon File Cache resource, if a FileCacheIds value is provided for that cache. Otherwise, it returns descriptions of all caches owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
describeFileSystemAliases({required String fileSystemId, String? clientRequestToken, int? maxResults, String? nextToken}) Future<DescribeFileSystemAliasesResponse>
Returns the DNS aliases that are associated with the specified Amazon FSx for Windows File Server file system. A history of all DNS aliases that have been associated with and disassociated from the file system is available in the list of AdministrativeAction provided in the DescribeFileSystems operation response.
describeFileSystems({List<String>? fileSystemIds, int? maxResults, String? nextToken}) Future<DescribeFileSystemsResponse>
Returns the description of specific Amazon FSx file systems, if a FileSystemIds value is provided for that file system. Otherwise, it returns descriptions of all file systems owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
describeS3AccessPointAttachments({List<S3AccessPointAttachmentsFilter>? filters, int? maxResults, List<String>? names, String? nextToken}) Future<DescribeS3AccessPointAttachmentsResponse>
Describes one or more S3 access points attached to Amazon FSx volumes.
describeSharedVpcConfiguration() Future<DescribeSharedVpcConfigurationResponse>
Indicates whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see Creating FSx for ONTAP file systems in shared subnets.
describeSnapshots({List<SnapshotFilter>? filters, bool? includeShared, int? maxResults, String? nextToken, List<String>? snapshotIds}) Future<DescribeSnapshotsResponse>
Returns the description of specific Amazon FSx for OpenZFS snapshots, if a SnapshotIds value is provided. Otherwise, this operation returns all snapshots owned by your Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling.
describeStorageVirtualMachines({List<StorageVirtualMachineFilter>? filters, int? maxResults, String? nextToken, List<String>? storageVirtualMachineIds}) Future<DescribeStorageVirtualMachinesResponse>
Describes one or more Amazon FSx for NetApp ONTAP storage virtual machines (SVMs).
describeVolumes({List<VolumeFilter>? filters, int? maxResults, String? nextToken, List<String>? volumeIds}) Future<DescribeVolumesResponse>
Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volumes.
detachAndDeleteS3AccessPoint({required String name, String? clientRequestToken}) Future<DetachAndDeleteS3AccessPointResponse>
Detaches an S3 access point from an Amazon FSx volume and deletes the S3 access point.
disassociateFileSystemAliases({required List<String> aliases, required String fileSystemId, String? clientRequestToken}) Future<DisassociateFileSystemAliasesResponse>
Use this action to disassociate, or remove, one or more Domain Name Service (DNS) aliases from an Amazon FSx for Windows File Server file system. If you attempt to disassociate a DNS alias that is not associated with the file system, Amazon FSx responds with an HTTP status code 400 (Bad Request). For more information, see Working with DNS Aliases.
listTagsForResource({required String resourceARN, int? maxResults, String? nextToken}) Future<ListTagsForResourceResponse>
Lists tags for Amazon FSx resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseFileSystemNfsV3Locks({required String fileSystemId, String? clientRequestToken}) Future<ReleaseFileSystemNfsV3LocksResponse>
Releases the file system lock from an Amazon FSx for OpenZFS file system.
restoreVolumeFromSnapshot({required String snapshotId, required String volumeId, String? clientRequestToken, List<RestoreOpenZFSVolumeOption>? options}) Future<RestoreVolumeFromSnapshotResponse>
Returns an Amazon FSx for OpenZFS volume to the state saved by the specified snapshot.
startMisconfiguredStateRecovery({required String fileSystemId, String? clientRequestToken}) Future<StartMisconfiguredStateRecoveryResponse>
After performing steps to repair the Active Directory configuration of an FSx for Windows File Server file system, use this action to initiate the process of Amazon FSx attempting to reconnect to the file system.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Tags an Amazon FSx resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
This action removes a tag from an Amazon FSx resource.
updateDataRepositoryAssociation({required String associationId, String? clientRequestToken, int? importedFileChunkSize, S3DataRepositoryConfiguration? s3}) Future<UpdateDataRepositoryAssociationResponse>
Updates the configuration of an existing data repository association on an Amazon FSx for Lustre file system. Data repository associations are supported on all FSx for Lustre 2.12 and 2.15 file systems, excluding scratch_1 deployment type.
updateFileCache({required String fileCacheId, String? clientRequestToken, UpdateFileCacheLustreConfiguration? lustreConfiguration}) Future<UpdateFileCacheResponse>
Updates the configuration of an existing Amazon File Cache resource. You can update multiple properties in a single request.
updateFileSystem({required String fileSystemId, String? clientRequestToken, String? fileSystemTypeVersion, UpdateFileSystemLustreConfiguration? lustreConfiguration, NetworkType? networkType, UpdateFileSystemOntapConfiguration? ontapConfiguration, UpdateFileSystemOpenZFSConfiguration? openZFSConfiguration, int? storageCapacity, StorageType? storageType, UpdateFileSystemWindowsConfiguration? windowsConfiguration}) Future<UpdateFileSystemResponse>
Use this operation to update the configuration of an existing Amazon FSx file system. You can update multiple properties in a single request.
updateSharedVpcConfiguration({String? clientRequestToken, String? enableFsxRouteTableUpdatesFromParticipantAccounts}) Future<UpdateSharedVpcConfigurationResponse>
Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see the Amazon FSx for NetApp ONTAP User Guide.
updateSnapshot({required String name, required String snapshotId, String? clientRequestToken}) Future<UpdateSnapshotResponse>
Updates the name of an Amazon FSx for OpenZFS snapshot.
updateStorageVirtualMachine({required String storageVirtualMachineId, UpdateSvmActiveDirectoryConfiguration? activeDirectoryConfiguration, String? clientRequestToken, String? svmAdminPassword}) Future<UpdateStorageVirtualMachineResponse>
Updates an FSx for ONTAP storage virtual machine (SVM).
updateVolume({required String volumeId, String? clientRequestToken, String? name, UpdateOntapVolumeConfiguration? ontapConfiguration, UpdateOpenZFSVolumeConfiguration? openZFSConfiguration}) Future<UpdateVolumeResponse>
Updates the configuration of an Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volume.

Operators

operator ==(Object other) bool
The equality operator.
inherited