createDataRepositoryAssociation method
Creates an Amazon FSx for Lustre data repository association (DRA). A data
repository association is a link between a directory on the file system
and an Amazon S3 bucket or prefix. You can have a maximum of 8 data
repository associations on a file system. Data repository associations are
supported on all FSx for Lustre 2.12 and 2.15 file systems, excluding
scratch_1 deployment type.
Each data repository association must have a unique Amazon FSx file system directory and a unique S3 bucket or prefix associated with it. You can configure a data repository association for automatic import only, for automatic export only, or for both. To learn more about linking a data repository to your file system, see Linking your file system to an S3 bucket.
May throw BadRequest.
May throw FileSystemNotFound.
May throw IncompatibleParameterError.
May throw InternalServerError.
May throw ServiceLimitExceeded.
May throw UnsupportedOperation.
Parameter dataRepositoryPath :
The path to the Amazon S3 data repository that will be linked to the file
system. The path can be an S3 bucket or prefix in the format
s3://bucket-name/prefix/ (where prefix is
optional). This path specifies where in the S3 data repository files will
be imported from or exported to.
Parameter batchImportMetaDataOnCreate :
Set to true to run an import data repository task to import
metadata from the data repository to the file system after the data
repository association is created. Default is false.
Parameter fileSystemPath :
A path on the file system that points to a high-level directory (such as
/ns1/) or subdirectory (such as /ns1/subdir/)
that will be mapped 1-1 with DataRepositoryPath. The leading
forward slash in the name is required. Two data repository associations
cannot have overlapping file system paths. For example, if a data
repository is associated with file system path /ns1/, then
you cannot link another data repository with file system path
/ns1/ns2.
This path specifies where in your file system files will be exported from or imported to. This file system directory can be linked to only one Amazon S3 bucket, and no other S3 bucket can be linked to the directory.
Parameter importedFileChunkSize :
For files imported from a data repository, this value determines the
stripe count and maximum amount of data per file (in MiB) stored on a
single physical disk. The maximum number of disks that a single file can
be striped across is limited by the total number of disks that make up the
file system.
The default chunk size is 1,024 MiB (1 GiB) and can go as high as 512,000 MiB (500 GiB). Amazon S3 objects have a maximum size of 5 TB.
Parameter s3 :
The configuration for an Amazon S3 data repository linked to an Amazon FSx
Lustre file system with a data repository association. The configuration
defines which file events (new, changed, or deleted files or directories)
are automatically imported from the linked data repository to the file
system or automatically exported from the file system to the data
repository.
Implementation
Future<CreateDataRepositoryAssociationResponse>
createDataRepositoryAssociation({
required String dataRepositoryPath,
required String fileSystemId,
bool? batchImportMetaDataOnCreate,
String? clientRequestToken,
String? fileSystemPath,
int? importedFileChunkSize,
S3DataRepositoryConfiguration? s3,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'importedFileChunkSize',
importedFileChunkSize,
1,
512000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSSimbaAPIService_v20180301.CreateDataRepositoryAssociation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DataRepositoryPath': dataRepositoryPath,
'FileSystemId': fileSystemId,
if (batchImportMetaDataOnCreate != null)
'BatchImportMetaDataOnCreate': batchImportMetaDataOnCreate,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (fileSystemPath != null) 'FileSystemPath': fileSystemPath,
if (importedFileChunkSize != null)
'ImportedFileChunkSize': importedFileChunkSize,
if (s3 != null) 'S3': s3,
if (tags != null) 'Tags': tags,
},
);
return CreateDataRepositoryAssociationResponse.fromJson(jsonResponse.body);
}