createDataRepositoryTask method
Creates an Amazon FSx for Lustre data repository task. A
CreateDataRepositoryTask operation will fail if a data
repository is not linked to the FSx file system.
You use import and export data repository tasks to perform bulk operations between your FSx for Lustre file system and its linked data repositories. An example of a data repository task is exporting any data and metadata changes, including POSIX metadata, to files, directories, and symbolic links (symlinks) from your FSx file system to a linked data repository.
You use release data repository tasks to release data from your file system for files that are exported to S3. The metadata of released files remains on the file system so users or applications can still access released files by reading the files again, which will restore data from Amazon S3 to the FSx for Lustre file system.
To learn more about data repository tasks, see Data Repository Tasks. To learn more about linking a data repository to your file system, see Linking your file system to an S3 bucket.
May throw BadRequest.
May throw DataRepositoryTaskExecuting.
May throw FileSystemNotFound.
May throw IncompatibleParameterError.
May throw InternalServerError.
May throw ServiceLimitExceeded.
May throw UnsupportedOperation.
Parameter report :
Defines whether or not Amazon FSx provides a CompletionReport once the
task has completed. A CompletionReport provides a detailed report on the
files that Amazon FSx processed that meet the criteria specified by the
Scope parameter. For more information, see Working
with Task Completion Reports.
Parameter type :
Specifies the type of data repository task to create.
-
EXPORT_TO_REPOSITORYtasks export from your Amazon FSx for Lustre file system to a linked data repository. -
IMPORT_METADATA_FROM_REPOSITORYtasks import metadata changes from a linked S3 bucket to your Amazon FSx for Lustre file system. -
RELEASE_DATA_FROM_FILESYSTEMtasks release files in your Amazon FSx for Lustre file system that have been exported to a linked S3 bucket and that meet your specified release criteria. -
AUTO_RELEASE_DATAtasks automatically release files from an Amazon File Cache resource.
Parameter capacityToRelease :
Specifies the amount of data to release, in GiB, by an Amazon File Cache
AUTO_RELEASE_DATA task that automatically releases files from
the cache.
Parameter paths :
A list of paths for the data repository task to use when the task is
processed. If a path that you provide isn't valid, the task fails. If you
don't provide paths, the default behavior is to export all files to S3
(for export tasks), import all files from S3 (for import tasks), or
release all exported files that meet the last accessed time criteria (for
release tasks).
-
For export tasks, the list contains paths on the FSx for Lustre file
system from which the files are exported to the Amazon S3 bucket. The
default path is the file system root directory. The paths you provide need
to be relative to the mount point of the file system. If the mount point
is
/mnt/fsxand/mnt/fsx/path1is a directory or file on the file system you want to export, then the path to provide ispath1. -
For import tasks, the list contains paths in the Amazon S3 bucket from
which POSIX metadata changes are imported to the FSx for Lustre file
system. The path can be an S3 bucket or prefix in the format
s3://bucket-name/prefix(whereprefixis optional). - For release tasks, the list contains directory or file paths on the FSx for Lustre file system from which to release exported files. If a directory is specified, files within the directory are released. If a file path is specified, only that file is released. To release all exported files in the file system, specify a forward slash (/) as the path.
Parameter releaseConfiguration :
The configuration that specifies the last accessed time criteria for files
that will be released from an Amazon FSx for Lustre file system.
Implementation
Future<CreateDataRepositoryTaskResponse> createDataRepositoryTask({
required String fileSystemId,
required CompletionReport report,
required DataRepositoryTaskType type,
int? capacityToRelease,
String? clientRequestToken,
List<String>? paths,
ReleaseConfiguration? releaseConfiguration,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'capacityToRelease',
capacityToRelease,
1,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.CreateDataRepositoryTask'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileSystemId': fileSystemId,
'Report': report,
'Type': type.value,
if (capacityToRelease != null) 'CapacityToRelease': capacityToRelease,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (paths != null) 'Paths': paths,
if (releaseConfiguration != null)
'ReleaseConfiguration': releaseConfiguration,
if (tags != null) 'Tags': tags,
},
);
return CreateDataRepositoryTaskResponse.fromJson(jsonResponse.body);
}