createFileCache method

Future<CreateFileCacheResponse> createFileCache({
  1. required FileCacheType fileCacheType,
  2. required String fileCacheTypeVersion,
  3. required int storageCapacity,
  4. required List<String> subnetIds,
  5. String? clientRequestToken,
  6. bool? copyTagsToDataRepositoryAssociations,
  7. List<FileCacheDataRepositoryAssociation>? dataRepositoryAssociations,
  8. String? kmsKeyId,
  9. CreateFileCacheLustreConfiguration? lustreConfiguration,
  10. List<String>? securityGroupIds,
  11. List<Tag>? tags,
})

Creates a new Amazon File Cache resource.

You can use this operation with a client request token in the request that Amazon File Cache uses to ensure idempotent creation. If a cache with the specified client request token exists and the parameters match, CreateFileCache returns the description of the existing cache. If a cache with the specified client request token exists and the parameters don't match, this call returns IncompatibleParameterError. If a file cache with the specified client request token doesn't exist, CreateFileCache does the following:

  • Creates a new, empty Amazon File Cache resource with an assigned ID, and an initial lifecycle state of CREATING.
  • Returns the description of the cache in JSON format.

May throw BadRequest. May throw IncompatibleParameterError. May throw InternalServerError. May throw InvalidNetworkSettings. May throw InvalidPerUnitStorageThroughput. May throw MissingFileCacheConfiguration. May throw ServiceLimitExceeded.

Parameter fileCacheType : The type of cache that you're creating, which must be LUSTRE.

Parameter fileCacheTypeVersion : Sets the Lustre version for the cache that you're creating, which must be 2.12.

Parameter storageCapacity : The storage capacity of the cache in gibibytes (GiB). Valid values are 1200 GiB, 2400 GiB, and increments of 2400 GiB.

Parameter clientRequestToken : An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

By using the idempotent operation, you can retry a CreateFileCache operation without the risk of creating an extra cache. This approach can be useful when an initial call fails in a way that makes it unclear whether a cache was created. Examples are if a transport level timeout occurred, or your connection was reset. If you use the same client request token and the initial call created a cache, the client receives success as long as the parameters are the same.

Parameter copyTagsToDataRepositoryAssociations : A boolean flag indicating whether tags for the cache should be copied to data repository associations. This value defaults to false.

Parameter dataRepositoryAssociations : A list of up to 8 configurations for data repository associations (DRAs) to be created during the cache creation. The DRAs link the cache to either an Amazon S3 data repository or a Network File System (NFS) data repository that supports the NFSv3 protocol.

The DRA configurations must meet the following requirements:

  • All configurations on the list must be of the same data repository type, either all S3 or all NFS. A cache can't link to different data repository types at the same time.
  • An NFS DRA must link to an NFS file system that supports the NFSv3 protocol.
DRA automatic import and automatic export is not supported.

Parameter kmsKeyId : Specifies the ID of the Key Management Service (KMS) key to use for encrypting data on an Amazon File Cache. If a KmsKeyId isn't specified, the Amazon FSx-managed KMS key for your account is used. For more information, see Encrypt in the Key Management Service API Reference.

Parameter lustreConfiguration : The configuration for the Amazon File Cache resource being created.

Parameter securityGroupIds : A list of IDs specifying the security groups to apply to all network interfaces created for Amazon File Cache access. This list isn't returned in later requests to describe the cache.

Implementation

Future<CreateFileCacheResponse> createFileCache({
  required FileCacheType fileCacheType,
  required String fileCacheTypeVersion,
  required int storageCapacity,
  required List<String> subnetIds,
  String? clientRequestToken,
  bool? copyTagsToDataRepositoryAssociations,
  List<FileCacheDataRepositoryAssociation>? dataRepositoryAssociations,
  String? kmsKeyId,
  CreateFileCacheLustreConfiguration? lustreConfiguration,
  List<String>? securityGroupIds,
  List<Tag>? tags,
}) async {
  _s.validateNumRange(
    'storageCapacity',
    storageCapacity,
    0,
    2147483647,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSSimbaAPIService_v20180301.CreateFileCache'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'FileCacheType': fileCacheType.value,
      'FileCacheTypeVersion': fileCacheTypeVersion,
      'StorageCapacity': storageCapacity,
      'SubnetIds': subnetIds,
      'ClientRequestToken':
          clientRequestToken ?? _s.generateIdempotencyToken(),
      if (copyTagsToDataRepositoryAssociations != null)
        'CopyTagsToDataRepositoryAssociations':
            copyTagsToDataRepositoryAssociations,
      if (dataRepositoryAssociations != null)
        'DataRepositoryAssociations': dataRepositoryAssociations,
      if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
      if (lustreConfiguration != null)
        'LustreConfiguration': lustreConfiguration,
      if (securityGroupIds != null) 'SecurityGroupIds': securityGroupIds,
      if (tags != null) 'Tags': tags,
    },
  );

  return CreateFileCacheResponse.fromJson(jsonResponse.body);
}