deleteFileSystem method
Deletes a file system. After deletion, the file system no longer exists, and its data is gone. Any existing automatic backups and snapshots are also deleted.
To delete an Amazon FSx for NetApp ONTAP file system, first delete all the
volumes and storage virtual machines (SVMs) on the file system. Then
provide a FileSystemId value to the
DeleteFileSystem operation.
Before deleting an Amazon FSx for OpenZFS file system, make sure that there aren't any Amazon S3 access points attached to any volume. For more information on how to list S3 access points that are attached to volumes, see Listing S3 access point attachments. For more information on how to delete S3 access points, see Deleting an S3 access point attachment.
By default, when you delete an Amazon FSx for Windows File Server file system, a final backup is created upon deletion. This final backup isn't subject to the file system's retention policy, and must be manually deleted.
To delete an Amazon FSx for Lustre file system, first unmount
it from every connected Amazon EC2 instance, then provide a
FileSystemId value to the DeleteFileSystem
operation. By default, Amazon FSx will not take a final backup when the
DeleteFileSystem operation is invoked. On file systems not
linked to an Amazon S3 bucket, set SkipFinalBackup to
false to take a final backup of the file system you are
deleting. Backups cannot be enabled on S3-linked file systems. To ensure
all of your data is written back to S3 before deleting your file system,
you can either monitor for the AgeOfOldestQueuedMessage
metric to be zero (if using automatic export) or you can run an export
data repository task. If you have automatic export enabled and want to
use an export data repository task, you have to disable automatic export
before executing the export data repository task.
The DeleteFileSystem operation returns while the file system
has the DELETING status. You can check the file system
deletion status by calling the DescribeFileSystems
operation, which returns a list of file systems in your account. If you
pass the file system ID for a deleted file system, the
DescribeFileSystems operation returns a
FileSystemNotFound error.
May throw BadRequest.
May throw FileSystemNotFound.
May throw IncompatibleParameterError.
May throw InternalServerError.
May throw ServiceLimitExceeded.
Parameter fileSystemId :
The ID of the file system that you want to delete.
Parameter clientRequestToken :
A string of up to 63 ASCII characters that Amazon FSx uses to ensure
idempotent deletion. This token is automatically filled on your behalf
when using the Command Line Interface (CLI) or an Amazon Web Services SDK.
Parameter openZFSConfiguration :
The configuration object for the OpenZFS file system used in the
DeleteFileSystem operation.
Implementation
Future<DeleteFileSystemResponse> deleteFileSystem({
required String fileSystemId,
String? clientRequestToken,
DeleteFileSystemLustreConfiguration? lustreConfiguration,
DeleteFileSystemOpenZFSConfiguration? openZFSConfiguration,
DeleteFileSystemWindowsConfiguration? windowsConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.DeleteFileSystem'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileSystemId': fileSystemId,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (lustreConfiguration != null)
'LustreConfiguration': lustreConfiguration,
if (openZFSConfiguration != null)
'OpenZFSConfiguration': openZFSConfiguration,
if (windowsConfiguration != null)
'WindowsConfiguration': windowsConfiguration,
},
);
return DeleteFileSystemResponse.fromJson(jsonResponse.body);
}