describeBackups method
Returns the description of a specific Amazon FSx backup, if a
BackupIds value is provided for that backup. Otherwise, it
returns all backups owned by your Amazon Web Services account in the
Amazon Web Services Region of the endpoint that you're calling.
When retrieving all backups, you can optionally specify the
MaxResults parameter to limit the number of backups in a
response. If more backups remain, Amazon FSx returns a
NextToken value in the response. In this case, send a later
request with the NextToken request parameter set to the value
of the NextToken value from the last response.
This operation is used in an iterative process to retrieve a list of your
backups. DescribeBackups is called first without a
NextToken value. Then the operation continues to be called
with the NextToken parameter set to the value of the last
NextToken value until a response has no
NextToken value.
When using this operation, keep the following in mind:
-
The operation might return fewer than the
MaxResultsvalue of backup descriptions while still including aNextTokenvalue. -
The order of the backups returned in the response of one
DescribeBackupscall and the order of the backups returned across the responses of a multi-call iteration is unspecified.
May throw BackupNotFound.
May throw BadRequest.
May throw FileSystemNotFound.
May throw InternalServerError.
May throw VolumeNotFound.
Parameter backupIds :
The IDs of the backups that you want to retrieve. This parameter value
overrides any filters. If any IDs aren't found, a
BackupNotFound error occurs.
Parameter filters :
The filters structure. The supported names are
file-system-id, backup-type,
file-system-type, and volume-id.
Parameter maxResults :
Maximum number of backups to return in the response. This parameter value
must be greater than 0. The number of items that Amazon FSx returns is the
minimum of the MaxResults parameter specified in the request
and the service's internal maximum number of items per page.
Parameter nextToken :
An opaque pagination token returned from a previous
DescribeBackups operation. If a token is present, the
operation continues the list from where the returning call left off.
Implementation
Future<DescribeBackupsResponse> describeBackups({
List<String>? backupIds,
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.DescribeBackups'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (backupIds != null) 'BackupIds': backupIds,
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeBackupsResponse.fromJson(jsonResponse.body);
}