describeFileCaches method
Returns the description of a specific Amazon File Cache resource, if a
FileCacheIds value is provided for that cache. Otherwise, it
returns descriptions of all caches owned by your Amazon Web Services
account in the Amazon Web Services Region of the endpoint that you're
calling.
When retrieving all cache descriptions, you can optionally specify the
MaxResults parameter to limit the number of descriptions in a
response. If more cache descriptions remain, the operation returns a
NextToken value in the response. In this case, send a later
request with the NextToken request parameter set to the value
of NextToken from the last response.
This operation is used in an iterative process to retrieve a list of your
cache descriptions. DescribeFileCaches is called first
without a NextTokenvalue. Then the operation continues to be
called with the NextToken parameter set to the value of the
last NextToken value until a response has no
NextToken.
When using this operation, keep the following in mind:
-
The implementation might return fewer than
MaxResultscache descriptions while still including aNextTokenvalue. -
The order of caches returned in the response of one
DescribeFileCachescall and the order of caches returned across the responses of a multicall iteration is unspecified.
May throw BadRequest.
May throw FileCacheNotFound.
May throw InternalServerError.
Parameter fileCacheIds :
IDs of the caches whose descriptions you want to retrieve (String).
Implementation
Future<DescribeFileCachesResponse> describeFileCaches({
List<String>? fileCacheIds,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.DescribeFileCaches'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (fileCacheIds != null) 'FileCacheIds': fileCacheIds,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeFileCachesResponse.fromJson(jsonResponse.body);
}