describeFileSystems method
Returns the description of specific Amazon FSx file systems, if a
FileSystemIds value is provided for that file system.
Otherwise, it returns descriptions of all file systems owned by your
Amazon Web Services account in the Amazon Web Services Region of the
endpoint that you're calling.
When retrieving all file system descriptions, you can optionally specify
the MaxResults parameter to limit the number of descriptions
in a response. If more file system descriptions remain, Amazon FSx returns
a NextToken value in the response. In this case, send a later
request with the NextToken request parameter set to the value
of NextToken from the last response.
This operation is used in an iterative process to retrieve a list of your
file system descriptions. DescribeFileSystems is called first
without a NextTokenvalue. Then the operation continues to be
called with the NextToken parameter set to the value of the
last NextToken value until a response has no
NextToken.
When using this operation, keep the following in mind:
-
The implementation might return fewer than
MaxResultsfile system descriptions while still including aNextTokenvalue. -
The order of file systems returned in the response of one
DescribeFileSystemscall and the order of file systems returned across the responses of a multicall iteration is unspecified.
May throw BadRequest.
May throw FileSystemNotFound.
May throw InternalServerError.
Parameter fileSystemIds :
IDs of the file systems whose descriptions you want to retrieve (String).
Parameter maxResults :
Maximum number of file systems to return in the response (integer). This
parameter value must be greater than 0. The number of items that Amazon
FSx returns is the minimum of the MaxResults parameter
specified in the request and the service's internal maximum number of
items per page.
Parameter nextToken :
Opaque pagination token returned from a previous
DescribeFileSystems operation (String). If a token present,
the operation continues the list from where the returning call left off.
Implementation
Future<DescribeFileSystemsResponse> describeFileSystems({
List<String>? fileSystemIds,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.DescribeFileSystems'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (fileSystemIds != null) 'FileSystemIds': fileSystemIds,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeFileSystemsResponse.fromJson(jsonResponse.body);
}