describeSharedVpcConfiguration method

Future<DescribeSharedVpcConfigurationResponse> describeSharedVpcConfiguration()

Indicates whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see Creating FSx for ONTAP file systems in shared subnets.

May throw BadRequest. May throw InternalServerError.

Implementation

Future<DescribeSharedVpcConfigurationResponse>
    describeSharedVpcConfiguration() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSSimbaAPIService_v20180301.DescribeSharedVpcConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return DescribeSharedVpcConfigurationResponse.fromJson(jsonResponse.body);
}