updateFileSystem method
- required String fileSystemId,
- String? clientRequestToken,
- String? fileSystemTypeVersion,
- UpdateFileSystemLustreConfiguration? lustreConfiguration,
- NetworkType? networkType,
- UpdateFileSystemOntapConfiguration? ontapConfiguration,
- UpdateFileSystemOpenZFSConfiguration? openZFSConfiguration,
- int? storageCapacity,
- StorageType? storageType,
- UpdateFileSystemWindowsConfiguration? windowsConfiguration,
Use this operation to update the configuration of an existing Amazon FSx file system. You can update multiple properties in a single request.
For FSx for Windows File Server file systems, you can update the following properties:
-
AuditLogConfiguration -
AutomaticBackupRetentionDays -
DailyAutomaticBackupStartTime -
DiskIopsConfiguration -
SelfManagedActiveDirectoryConfiguration -
StorageCapacity -
StorageType -
ThroughputCapacity -
WeeklyMaintenanceStartTime
-
AutoImportPolicy -
AutomaticBackupRetentionDays -
DailyAutomaticBackupStartTime -
DataCompressionType -
FileSystemTypeVersion -
LogConfiguration -
LustreReadCacheConfiguration -
LustreRootSquashConfiguration -
MetadataConfiguration -
PerUnitStorageThroughput -
StorageCapacity -
ThroughputCapacity -
WeeklyMaintenanceStartTime
-
AddRouteTableIds -
AutomaticBackupRetentionDays -
DailyAutomaticBackupStartTime -
DiskIopsConfiguration -
EndpointIpv6AddressRange -
FsxAdminPassword -
HAPairs -
RemoveRouteTableIds -
StorageCapacity -
ThroughputCapacity -
ThroughputCapacityPerHAPair -
WeeklyMaintenanceStartTime
-
AddRouteTableIds -
AutomaticBackupRetentionDays -
CopyTagsToBackups -
CopyTagsToVolumes -
DailyAutomaticBackupStartTime -
DiskIopsConfiguration -
EndpointIpv6AddressRange -
ReadCacheConfiguration -
RemoveRouteTableIds -
StorageCapacity -
ThroughputCapacity -
WeeklyMaintenanceStartTime
May throw BadRequest.
May throw FileSystemNotFound.
May throw IncompatibleParameterError.
May throw InternalServerError.
May throw InvalidNetworkSettings.
May throw MissingFileSystemConfiguration.
May throw ServiceLimitExceeded.
May throw UnsupportedOperation.
Parameter fileSystemId :
The ID of the file system that you are updating.
Parameter clientRequestToken :
A string of up to 63 ASCII characters that Amazon FSx uses to ensure
idempotent updates. This string is automatically filled on your behalf
when you use the Command Line Interface (CLI) or an Amazon Web Services
SDK.
Parameter fileSystemTypeVersion :
The Lustre version you are updating an FSx for Lustre file system to.
Valid values are 2.12 and 2.15. The value you
choose must be newer than the file system's current Lustre version.
Parameter networkType :
Changes the network type of an FSx for OpenZFS file system.
Parameter openZFSConfiguration :
The configuration updates for an FSx for OpenZFS file system.
Parameter storageCapacity :
Use this parameter to increase the storage capacity of an FSx for Windows
File Server, FSx for Lustre, FSx for OpenZFS, or FSx for ONTAP file
system. For second-generation FSx for ONTAP file systems, you can also
decrease the storage capacity. Specifies the storage capacity target
value, in GiB, for the file system that you're updating.
For Lustre file systems, the storage capacity target value can be the
following:
-
For
SCRATCH_2,PERSISTENT_1, andPERSISTENT_2 SSDdeployment types, valid values are in multiples of 2400 GiB. The value must be greater than the current storage capacity. -
For
PERSISTENT HDDfile systems, valid values are multiples of 6000 GiB for 12-MBps throughput per TiB file systems and multiples of 1800 GiB for 40-MBps throughput per TiB file systems. The values must be greater than the current storage capacity. -
For
SCRATCH_1file systems, you can't increase the storage capacity.
For FSx for OpenZFS file systems, the storage capacity target value must be at least 10 percent greater than the current storage capacity value. For more information, see Managing storage capacity in the FSx for OpenZFS User Guide.
For Windows file systems, the storage capacity target value must be at least 10 percent greater than the current storage capacity value. To increase storage capacity, the file system must have at least 16 MBps of throughput capacity. For more information, see Managing storage capacity in the Amazon FSxfor Windows File Server User Guide.
For ONTAP file systems, when increasing storage capacity, the storage capacity target value must be at least 10 percent greater than the current storage capacity value. When decreasing storage capacity on second-generation file systems, the target value must be at least 9 percent smaller than the current SSD storage capacity. For more information, see File system storage capacity and IOPS in the Amazon FSx for NetApp ONTAP User Guide.
Parameter windowsConfiguration :
The configuration updates for an Amazon FSx for Windows File Server file
system.
Implementation
Future<UpdateFileSystemResponse> updateFileSystem({
required String fileSystemId,
String? clientRequestToken,
String? fileSystemTypeVersion,
UpdateFileSystemLustreConfiguration? lustreConfiguration,
NetworkType? networkType,
UpdateFileSystemOntapConfiguration? ontapConfiguration,
UpdateFileSystemOpenZFSConfiguration? openZFSConfiguration,
int? storageCapacity,
StorageType? storageType,
UpdateFileSystemWindowsConfiguration? windowsConfiguration,
}) async {
_s.validateNumRange(
'storageCapacity',
storageCapacity,
0,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.UpdateFileSystem'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileSystemId': fileSystemId,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (fileSystemTypeVersion != null)
'FileSystemTypeVersion': fileSystemTypeVersion,
if (lustreConfiguration != null)
'LustreConfiguration': lustreConfiguration,
if (networkType != null) 'NetworkType': networkType.value,
if (ontapConfiguration != null)
'OntapConfiguration': ontapConfiguration,
if (openZFSConfiguration != null)
'OpenZFSConfiguration': openZFSConfiguration,
if (storageCapacity != null) 'StorageCapacity': storageCapacity,
if (storageType != null) 'StorageType': storageType.value,
if (windowsConfiguration != null)
'WindowsConfiguration': windowsConfiguration,
},
);
return UpdateFileSystemResponse.fromJson(jsonResponse.body);
}