updateSharedVpcConfiguration method

Future<UpdateSharedVpcConfigurationResponse> updateSharedVpcConfiguration({
  1. String? clientRequestToken,
  2. String? enableFsxRouteTableUpdatesFromParticipantAccounts,
})

Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner. For more information, see the Amazon FSx for NetApp ONTAP User Guide.

May throw BadRequest. May throw IncompatibleParameterError. May throw InternalServerError.

Parameter enableFsxRouteTableUpdatesFromParticipantAccounts : Specifies whether participant accounts can create FSx for ONTAP Multi-AZ file systems in shared subnets. Set to true to enable or false to disable.

Implementation

Future<UpdateSharedVpcConfigurationResponse> updateSharedVpcConfiguration({
  String? clientRequestToken,
  String? enableFsxRouteTableUpdatesFromParticipantAccounts,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSSimbaAPIService_v20180301.UpdateSharedVpcConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ClientRequestToken':
          clientRequestToken ?? _s.generateIdempotencyToken(),
      if (enableFsxRouteTableUpdatesFromParticipantAccounts != null)
        'EnableFsxRouteTableUpdatesFromParticipantAccounts':
            enableFsxRouteTableUpdatesFromParticipantAccounts,
    },
  );

  return UpdateSharedVpcConfigurationResponse.fromJson(jsonResponse.body);
}