f_sx_2018_03_01 library

Classes

AwsClientCredentials
AWS credentials.
FSx
Amazon FSx is a fully managed service that makes it easy for storage and application administrators to launch and use shared file storage.