Finspace class
The FinSpace management service provides the APIs for managing FinSpace environments.
Constructors
- Finspace({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createEnvironment(
{required String name, List< String> ? dataBundles, String? description, FederationMode? federationMode, FederationParameters? federationParameters, String? kmsKeyId, SuperuserParameters? superuserParameters, Map<String, String> ? tags}) → Future<CreateEnvironmentResponse> - Create a new FinSpace environment.
-
createKxChangeset(
{required List< ChangeRequest> changeRequests, required String databaseName, required String environmentId, String? clientToken}) → Future<CreateKxChangesetResponse> - Creates a changeset for a kdb database. A changeset allows you to add and delete existing files by using an ordered list of change requests.
-
createKxCluster(
{required KxAzMode azMode, required String clusterName, required KxClusterType clusterType, required String environmentId, required String releaseLabel, required VpcConfiguration vpcConfiguration, AutoScalingConfiguration? autoScalingConfiguration, String? availabilityZoneId, List< KxCacheStorageConfiguration> ? cacheStorageConfigurations, CapacityConfiguration? capacityConfiguration, String? clientToken, String? clusterDescription, CodeConfiguration? code, List<KxCommandLineArgument> ? commandLineArguments, List<KxDatabaseConfiguration> ? databases, String? executionRole, String? initializationScript, KxSavedownStorageConfiguration? savedownStorageConfiguration, KxScalingGroupConfiguration? scalingGroupConfiguration, Map<String, String> ? tags, TickerplantLogConfiguration? tickerplantLogConfiguration}) → Future<CreateKxClusterResponse> - Creates a new kdb cluster.
-
createKxDatabase(
{required String databaseName, required String environmentId, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateKxDatabaseResponse> - Creates a new kdb database in the environment.
-
createKxDataview(
{required KxAzMode azMode, required String databaseName, required String dataviewName, required String environmentId, bool? autoUpdate, String? availabilityZoneId, String? changesetId, String? clientToken, String? description, bool? readWrite, List< KxDataviewSegmentConfiguration> ? segmentConfigurations, Map<String, String> ? tags}) → Future<CreateKxDataviewResponse> - Creates a snapshot of kdb database with tiered storage capabilities and a pre-warmed cache, ready for mounting on kdb clusters. Dataviews are only available for clusters running on a scaling group. They are not supported on dedicated clusters.
-
createKxEnvironment(
{required String kmsKeyId, required String name, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateKxEnvironmentResponse> - Creates a managed kdb environment for the account.
-
createKxScalingGroup(
{required String availabilityZoneId, required String environmentId, required String hostType, required String scalingGroupName, String? clientToken, Map< String, String> ? tags}) → Future<CreateKxScalingGroupResponse> - Creates a new scaling group.
-
createKxUser(
{required String environmentId, required String iamRole, required String userName, String? clientToken, Map< String, String> ? tags}) → Future<CreateKxUserResponse> - Creates a user in FinSpace kdb environment with an associated IAM role.
-
createKxVolume(
{required List< String> availabilityZoneIds, required KxAzMode azMode, required String environmentId, required String volumeName, required KxVolumeType volumeType, String? clientToken, String? description, KxNAS1Configuration? nas1Configuration, Map<String, String> ? tags}) → Future<CreateKxVolumeResponse> - Creates a new volume with a specific amount of throughput and storage capacity.
-
deleteEnvironment(
{required String environmentId}) → Future< void> - Delete an FinSpace environment.
-
deleteKxCluster(
{required String clusterName, required String environmentId, String? clientToken}) → Future< void> - Deletes a kdb cluster.
-
deleteKxClusterNode(
{required String clusterName, required String environmentId, required String nodeId}) → Future< void> - Deletes the specified nodes from a cluster.
-
deleteKxDatabase(
{required String databaseName, required String environmentId, String? clientToken}) → Future< void> - Deletes the specified database and all of its associated data. This action is irreversible. You must copy any data out of the database before deleting it if the data is to be retained.
-
deleteKxDataview(
{required String databaseName, required String dataviewName, required String environmentId, String? clientToken}) → Future< void> - Deletes the specified dataview. Before deleting a dataview, make sure that it is not in use by any cluster.
-
deleteKxEnvironment(
{required String environmentId, String? clientToken}) → Future< void> - Deletes the kdb environment. This action is irreversible. Deleting a kdb environment will remove all the associated data and any services running in it.
-
deleteKxScalingGroup(
{required String environmentId, required String scalingGroupName, String? clientToken}) → Future< void> - Deletes the specified scaling group. This action is irreversible. You cannot delete a scaling group until all the clusters running on it have been deleted.
-
deleteKxUser(
{required String environmentId, required String userName, String? clientToken}) → Future< void> - Deletes a user in the specified kdb environment.
-
deleteKxVolume(
{required String environmentId, required String volumeName, String? clientToken}) → Future< void> - Deletes a volume. You can only delete a volume if it's not attached to a cluster or a dataview. When a volume is deleted, any data on the volume is lost. This action is irreversible.
-
getEnvironment(
{required String environmentId}) → Future< GetEnvironmentResponse> - Returns the FinSpace environment object.
-
getKxChangeset(
{required String changesetId, required String databaseName, required String environmentId}) → Future< GetKxChangesetResponse> - Returns information about a kdb changeset.
-
getKxCluster(
{required String clusterName, required String environmentId}) → Future< GetKxClusterResponse> - Retrieves information about a kdb cluster.
-
getKxConnectionString(
{required String clusterName, required String environmentId, required String userArn}) → Future< GetKxConnectionStringResponse> - Retrieves a connection string for a user to connect to a kdb cluster. You must call this API using the same role that you have defined while creating a user.
-
getKxDatabase(
{required String databaseName, required String environmentId}) → Future< GetKxDatabaseResponse> - Returns database information for the specified environment ID.
-
getKxDataview(
{required String databaseName, required String dataviewName, required String environmentId}) → Future< GetKxDataviewResponse> - Retrieves details of the dataview.
-
getKxEnvironment(
{required String environmentId}) → Future< GetKxEnvironmentResponse> - Retrieves all the information for the specified kdb environment.
-
getKxScalingGroup(
{required String environmentId, required String scalingGroupName}) → Future< GetKxScalingGroupResponse> - Retrieves details of a scaling group.
-
getKxUser(
{required String environmentId, required String userName}) → Future< GetKxUserResponse> - Retrieves information about the specified kdb user.
-
getKxVolume(
{required String environmentId, required String volumeName}) → Future< GetKxVolumeResponse> - Retrieves the information about the volume.
-
listEnvironments(
{int? maxResults, String? nextToken}) → Future< ListEnvironmentsResponse> - A list of all of your FinSpace environments.
-
listKxChangesets(
{required String databaseName, required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxChangesetsResponse> - Returns a list of all the changesets for a database.
-
listKxClusterNodes(
{required String clusterName, required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxClusterNodesResponse> - Lists all the nodes in a kdb cluster.
-
listKxClusters(
{required String environmentId, KxClusterType? clusterType, int? maxResults, String? nextToken}) → Future< ListKxClustersResponse> - Returns a list of clusters.
-
listKxDatabases(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxDatabasesResponse> - Returns a list of all the databases in the kdb environment.
-
listKxDataviews(
{required String databaseName, required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxDataviewsResponse> - Returns a list of all the dataviews in the database.
-
listKxEnvironments(
{int? maxResults, String? nextToken}) → Future< ListKxEnvironmentsResponse> - Returns a list of kdb environments created in an account.
-
listKxScalingGroups(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxScalingGroupsResponse> - Returns a list of scaling groups in a kdb environment.
-
listKxUsers(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListKxUsersResponse> - Lists all the users in a kdb environment.
-
listKxVolumes(
{required String environmentId, int? maxResults, String? nextToken, KxVolumeType? volumeType}) → Future< ListKxVolumesResponse> - Lists all the volumes in a kdb environment.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - A list of all tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds metadata tags to a FinSpace resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes metadata tags from a FinSpace resource.
-
updateEnvironment(
{required String environmentId, String? description, FederationMode? federationMode, FederationParameters? federationParameters, String? name}) → Future< UpdateEnvironmentResponse> - Update your FinSpace environment.
-
updateKxClusterCodeConfiguration(
{required String clusterName, required CodeConfiguration code, required String environmentId, String? clientToken, List< KxCommandLineArgument> ? commandLineArguments, KxClusterCodeDeploymentConfiguration? deploymentConfiguration, String? initializationScript}) → Future<void> - Allows you to update code configuration on a running cluster. By using this API you can update the code, the initialization script path, and the command line arguments for a specific cluster. The configuration that you want to update will override any existing configurations on the cluster.
-
updateKxClusterDatabases(
{required String clusterName, required List< KxDatabaseConfiguration> databases, required String environmentId, String? clientToken, KxDeploymentConfiguration? deploymentConfiguration}) → Future<void> -
Updates the databases mounted on a kdb cluster, which includes the
changesetIdand all the dbPaths to be cached. This API does not allow you to change a database name or add a database if you created a cluster without one. -
updateKxDatabase(
{required String databaseName, required String environmentId, String? clientToken, String? description}) → Future< UpdateKxDatabaseResponse> - Updates information for the given kdb database.
-
updateKxDataview(
{required String databaseName, required String dataviewName, required String environmentId, String? changesetId, String? clientToken, String? description, List< KxDataviewSegmentConfiguration> ? segmentConfigurations}) → Future<UpdateKxDataviewResponse> - Updates the specified dataview. The dataviews get automatically updated when any new changesets are ingested. Each update of the dataview creates a new version, including changeset details and cache configurations
-
updateKxEnvironment(
{required String environmentId, String? clientToken, String? description, String? name}) → Future< UpdateKxEnvironmentResponse> - Updates information for the given kdb environment.
-
updateKxEnvironmentNetwork(
{required String environmentId, String? clientToken, List< CustomDNSServer> ? customDNSConfiguration, TransitGatewayConfiguration? transitGatewayConfiguration}) → Future<UpdateKxEnvironmentNetworkResponse> - Updates environment network to connect to your internal network by using a transit gateway. This API supports request to create a transit gateway attachment from FinSpace VPC to your transit gateway ID and create a custom Route-53 outbound resolvers.
-
updateKxUser(
{required String environmentId, required String iamRole, required String userName, String? clientToken}) → Future< UpdateKxUserResponse> - Updates the user details. You can only update the IAM role associated with a user.
-
updateKxVolume(
{required String environmentId, required String volumeName, String? clientToken, String? description, KxNAS1Configuration? nas1Configuration}) → Future< UpdateKxVolumeResponse> - Updates the throughput or capacity of a volume. During the update process, the filesystem might be unavailable for a few minutes. You can retry any operations after the update is complete.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited