createEnvironment method

Future<CreateEnvironmentResponse> createEnvironment({
  1. required String name,
  2. List<String>? dataBundles,
  3. String? description,
  4. FederationMode? federationMode,
  5. FederationParameters? federationParameters,
  6. String? kmsKeyId,
  7. SuperuserParameters? superuserParameters,
  8. Map<String, String>? tags,
})

Create a new FinSpace environment.

May throw AccessDeniedException. May throw InternalServerException. May throw LimitExceededException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter name : The name of the FinSpace environment to be created.

Parameter dataBundles : The list of Amazon Resource Names (ARN) of the data bundles to install. Currently supported data bundle ARNs:

  • arn:aws:finspace:${Region}::data-bundle/capital-markets-sample - Contains sample Capital Markets datasets, categories and controlled vocabularies.
  • arn:aws:finspace:${Region}::data-bundle/taq (default) - Contains trades and quotes data in addition to sample Capital Markets data.

Parameter description : The description of the FinSpace environment to be created.

Parameter federationMode : Authentication mode for the environment.

  • FEDERATED - Users access FinSpace through Single Sign On (SSO) via your Identity provider.
  • LOCAL - Users access FinSpace via email and password managed within the FinSpace environment.

Parameter federationParameters : Configuration information when authentication mode is FEDERATED.

Parameter kmsKeyId : The KMS key id to encrypt your data in the FinSpace environment.

Parameter superuserParameters : Configuration information for the superuser.

Parameter tags : Add tags to your FinSpace environment.

Implementation

Future<CreateEnvironmentResponse> createEnvironment({
  required String name,
  List<String>? dataBundles,
  String? description,
  FederationMode? federationMode,
  FederationParameters? federationParameters,
  String? kmsKeyId,
  SuperuserParameters? superuserParameters,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'name': name,
    if (dataBundles != null) 'dataBundles': dataBundles,
    if (description != null) 'description': description,
    if (federationMode != null) 'federationMode': federationMode.value,
    if (federationParameters != null)
      'federationParameters': federationParameters,
    if (kmsKeyId != null) 'kmsKeyId': kmsKeyId,
    if (superuserParameters != null)
      'superuserParameters': superuserParameters,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/environment',
    exceptionFnMap: _exceptionFns,
  );
  return CreateEnvironmentResponse.fromJson(response);
}