deleteKxDatabase method
Deletes the specified database and all of its associated data. This action is irreversible. You must copy any data out of the database before deleting it if the data is to be retained.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter databaseName :
The name of the kdb database that you want to delete.
Parameter environmentId :
A unique identifier for the kdb environment.
Parameter clientToken :
A token that ensures idempotency. This token expires in 10 minutes.
Implementation
Future<void> deleteKxDatabase({
required String databaseName,
required String environmentId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/databases/${Uri.encodeComponent(databaseName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}