deleteKxDataview method
Deletes the specified dataview. Before deleting a dataview, make sure that it is not in use by any cluster.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter databaseName :
The name of the database whose dataview you want to delete.
Parameter dataviewName :
The name of the dataview that you want to delete.
Parameter environmentId :
A unique identifier for the kdb environment, from where you want to delete
the dataview.
Parameter clientToken :
A token that ensures idempotency. This token expires in 10 minutes.
Implementation
Future<void> deleteKxDataview({
required String databaseName,
required String dataviewName,
required String environmentId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/databases/${Uri.encodeComponent(databaseName)}/dataviews/${Uri.encodeComponent(dataviewName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}