deleteKxScalingGroup method

Future<void> deleteKxScalingGroup({
  1. required String environmentId,
  2. required String scalingGroupName,
  3. String? clientToken,
})

Deletes the specified scaling group. This action is irreversible. You cannot delete a scaling group until all the clusters running on it have been deleted.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : A unique identifier for the kdb environment, from where you want to delete the dataview.

Parameter scalingGroupName : A unique identifier for the kdb scaling group.

Parameter clientToken : A token that ensures idempotency. This token expires in 10 minutes.

Implementation

Future<void> deleteKxScalingGroup({
  required String environmentId,
  required String scalingGroupName,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/kx/environments/${Uri.encodeComponent(environmentId)}/scalingGroups/${Uri.encodeComponent(scalingGroupName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}