deleteKxVolume method
Deletes a volume. You can only delete a volume if it's not attached to a cluster or a dataview. When a volume is deleted, any data on the volume is lost. This action is irreversible.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter environmentId :
A unique identifier for the kdb environment, whose clusters can attach to
the volume.
Parameter volumeName :
The name of the volume that you want to delete.
Parameter clientToken :
A token that ensures idempotency. This token expires in 10 minutes.
Implementation
Future<void> deleteKxVolume({
required String environmentId,
required String volumeName,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/kxvolumes/${Uri.encodeComponent(volumeName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}