getKxConnectionString method
Retrieves a connection string for a user to connect to a kdb cluster. You must call this API using the same role that you have defined while creating a user.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterName :
A name of the kdb cluster.
Parameter environmentId :
A unique identifier for the kdb environment.
Parameter userArn :
The Amazon Resource Name (ARN) that identifies the user. For more
information about ARNs and how to use ARNs in policies, see IAM
Identifiers in the IAM User Guide.
Implementation
Future<GetKxConnectionStringResponse> getKxConnectionString({
required String clusterName,
required String environmentId,
required String userArn,
}) async {
final $query = <String, List<String>>{
'clusterName': [clusterName],
'userArn': [userArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/connectionString',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetKxConnectionStringResponse.fromJson(response);
}