getKxDataview method
Retrieves details of the dataview.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter databaseName :
The name of the database where you created the dataview.
Parameter dataviewName :
A unique identifier for the dataview.
Parameter environmentId :
A unique identifier for the kdb environment, from where you want to
retrieve the dataview details.
Implementation
Future<GetKxDataviewResponse> getKxDataview({
required String databaseName,
required String dataviewName,
required String environmentId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/databases/${Uri.encodeComponent(databaseName)}/dataviews/${Uri.encodeComponent(dataviewName)}',
exceptionFnMap: _exceptionFns,
);
return GetKxDataviewResponse.fromJson(response);
}