listKxClusterNodes method

Future<ListKxClusterNodesResponse> listKxClusterNodes({
  1. required String clusterName,
  2. required String environmentId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the nodes in a kdb cluster.

May throw AccessDeniedException. May throw InternalServerException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter clusterName : A unique name for the cluster.

Parameter environmentId : A unique identifier for the kdb environment.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : A token that indicates where a results page should begin.

Implementation

Future<ListKxClusterNodesResponse> listKxClusterNodes({
  required String clusterName,
  required String environmentId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/kx/environments/${Uri.encodeComponent(environmentId)}/clusters/${Uri.encodeComponent(clusterName)}/nodes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListKxClusterNodesResponse.fromJson(response);
}