listKxClusters method
Returns a list of clusters.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter environmentId :
A unique identifier for the kdb environment.
Parameter clusterType :
Specifies the type of KDB database that is being created. The following
types are available:
- HDB – A Historical Database. The data is only accessible with read-only permissions from one of the FinSpace managed kdb databases mounted to the cluster.
-
RDB – A Realtime Database. This type of database captures all the data
from a ticker plant and stores it in memory until the end of day, after
which it writes all of its data to a disk and reloads the HDB. This
cluster type requires local storage for temporary storage of data during
the savedown process. If you specify this field in your request, you must
provide the
savedownStorageConfigurationparameter. - GATEWAY – A gateway cluster allows you to access data across processes in kdb systems. It allows you to create your own routing logic using the initialization scripts and custom code. This type of cluster does not require a writable local storage.
-
GP – A general purpose cluster allows you to quickly iterate on code
during development by granting greater access to system commands and
enabling a fast reload of custom code. This cluster type can optionally
mount databases including cache and savedown storage. For this cluster
type, the node count is fixed at 1. It does not support autoscaling and
supports only
SINGLEAZ mode. - Tickerplant – A tickerplant cluster allows you to subscribe to feed handlers based on IAM permissions. It can publish to RDBs, other Tickerplants, and real-time subscribers (RTS). Tickerplants can persist messages to log, which is readable by any RDB environment. It supports only single-node that is only one kdb process.
Parameter maxResults :
The maximum number of results to return in this request.
Parameter nextToken :
A token that indicates where a results page should begin.
Implementation
Future<ListKxClustersResponse> listKxClusters({
required String environmentId,
KxClusterType? clusterType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final $query = <String, List<String>>{
if (clusterType != null) 'clusterType': [clusterType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/clusters',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListKxClustersResponse.fromJson(response);
}