listKxEnvironments method

Future<ListKxEnvironmentsResponse> listKxEnvironments({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of kdb environments created in an account.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : A token that indicates where a results page should begin.

Implementation

Future<ListKxEnvironmentsResponse> listKxEnvironments({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/kx/environments',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListKxEnvironmentsResponse.fromJson(response);
}