listKxScalingGroups method

Future<ListKxScalingGroupsResponse> listKxScalingGroups({
  1. required String environmentId,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of scaling groups in a kdb environment.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : A unique identifier for the kdb environment, for which you want to retrieve a list of scaling groups.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : A token that indicates where a results page should begin.

Implementation

Future<ListKxScalingGroupsResponse> listKxScalingGroups({
  required String environmentId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/kx/environments/${Uri.encodeComponent(environmentId)}/scalingGroups',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListKxScalingGroupsResponse.fromJson(response);
}