listKxVolumes method

Future<ListKxVolumesResponse> listKxVolumes({
  1. required String environmentId,
  2. int? maxResults,
  3. String? nextToken,
  4. KxVolumeType? volumeType,
})

Lists all the volumes in a kdb environment.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : A unique identifier for the kdb environment, whose clusters can attach to the volume.

Parameter maxResults : The maximum number of results to return in this request.

Parameter nextToken : A token that indicates where a results page should begin.

Parameter volumeType : The type of file system volume. Currently, FinSpace only supports NAS_1 volume type.

Implementation

Future<ListKxVolumesResponse> listKxVolumes({
  required String environmentId,
  int? maxResults,
  String? nextToken,
  KxVolumeType? volumeType,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (volumeType != null) 'volumeType': [volumeType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/kx/environments/${Uri.encodeComponent(environmentId)}/kxvolumes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListKxVolumesResponse.fromJson(response);
}