updateKxEnvironmentNetwork method
Updates environment network to connect to your internal network by using a transit gateway. This API supports request to create a transit gateway attachment from FinSpace VPC to your transit gateway ID and create a custom Route-53 outbound resolvers.
Once you send a request to update a network, you cannot change it again. Network update might require termination of any clusters that are running in the existing network.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter environmentId :
A unique identifier for the kdb environment.
Parameter clientToken :
A token that ensures idempotency. This token expires in 10 minutes.
Parameter customDNSConfiguration :
A list of DNS server name and server IP. This is used to set up Route-53
outbound resolvers.
Parameter transitGatewayConfiguration :
Specifies the transit gateway and network configuration to connect the kdb
environment to an internal network.
Implementation
Future<UpdateKxEnvironmentNetworkResponse> updateKxEnvironmentNetwork({
required String environmentId,
String? clientToken,
List<CustomDNSServer>? customDNSConfiguration,
TransitGatewayConfiguration? transitGatewayConfiguration,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (customDNSConfiguration != null)
'customDNSConfiguration': customDNSConfiguration,
if (transitGatewayConfiguration != null)
'transitGatewayConfiguration': transitGatewayConfiguration,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/network',
exceptionFnMap: _exceptionFns,
);
return UpdateKxEnvironmentNetworkResponse.fromJson(response);
}