updateKxVolume method

Future<UpdateKxVolumeResponse> updateKxVolume({
  1. required String environmentId,
  2. required String volumeName,
  3. String? clientToken,
  4. String? description,
  5. KxNAS1Configuration? nas1Configuration,
})

Updates the throughput or capacity of a volume. During the update process, the filesystem might be unavailable for a few minutes. You can retry any operations after the update is complete.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : A unique identifier for the kdb environment where you created the storage volume.

Parameter volumeName : A unique identifier for the volume.

Parameter clientToken : A token that ensures idempotency. This token expires in 10 minutes.

Parameter description : A description of the volume.

Parameter nas1Configuration : Specifies the configuration for the Network attached storage (NAS_1) file system volume.

Implementation

Future<UpdateKxVolumeResponse> updateKxVolume({
  required String environmentId,
  required String volumeName,
  String? clientToken,
  String? description,
  KxNAS1Configuration? nas1Configuration,
}) async {
  final $payload = <String, dynamic>{
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (description != null) 'description': description,
    if (nas1Configuration != null) 'nas1Configuration': nas1Configuration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/kx/environments/${Uri.encodeComponent(environmentId)}/kxvolumes/${Uri.encodeComponent(volumeName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateKxVolumeResponse.fromJson(response);
}