FinspaceData class

The FinSpace APIs let you take actions inside the FinSpace.

Constructors

FinspaceData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateUserToPermissionGroup({required String permissionGroupId, required String userId, String? clientToken}) Future<AssociateUserToPermissionGroupResponse>
Adds a user to a permission group to grant permissions for actions a user can perform in FinSpace.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createChangeset({required ChangeType changeType, required String datasetId, required Map<String, String> formatParams, required Map<String, String> sourceParams, String? clientToken}) Future<CreateChangesetResponse>
Creates a new Changeset in a FinSpace Dataset.
createDataset({required String datasetTitle, required DatasetKind kind, required PermissionGroupParams permissionGroupParams, String? alias, String? clientToken, String? datasetDescription, DatasetOwnerInfo? ownerInfo, SchemaUnion? schemaDefinition}) Future<CreateDatasetResponse>
Creates a new FinSpace Dataset.
createDataView({required String datasetId, required DataViewDestinationTypeParams destinationTypeParams, int? asOfTimestamp, bool? autoUpdate, String? clientToken, List<String>? partitionColumns, List<String>? sortColumns}) Future<CreateDataViewResponse>
Creates a Dataview for a Dataset.
createPermissionGroup({required List<ApplicationPermission> applicationPermissions, required String name, String? clientToken, String? description}) Future<CreatePermissionGroupResponse>
Creates a group of permissions for various actions that a user can perform in FinSpace.
createUser({required String emailAddress, required UserType type, ApiAccess? apiAccess, String? apiAccessPrincipalArn, String? clientToken, String? firstName, String? lastName}) Future<CreateUserResponse>
Creates a new user in FinSpace.
deleteDataset({required String datasetId, String? clientToken}) Future<DeleteDatasetResponse>
Deletes a FinSpace Dataset.
deletePermissionGroup({required String permissionGroupId, String? clientToken}) Future<DeletePermissionGroupResponse>
Deletes a permission group. This action is irreversible.
disableUser({required String userId, String? clientToken}) Future<DisableUserResponse>
Denies access to the FinSpace web application and API for the specified user.
disassociateUserFromPermissionGroup({required String permissionGroupId, required String userId, String? clientToken}) Future<DisassociateUserFromPermissionGroupResponse>
Removes a user from a permission group.
enableUser({required String userId, String? clientToken}) Future<EnableUserResponse>
Allows the specified user to access the FinSpace web application and API.
getChangeset({required String changesetId, required String datasetId}) Future<GetChangesetResponse>
Get information about a Changeset.
getDataset({required String datasetId}) Future<GetDatasetResponse>
Returns information about a Dataset.
getDataView({required String dataViewId, required String datasetId}) Future<GetDataViewResponse>
Gets information about a Dataview.
getExternalDataViewAccessDetails({required String dataViewId, required String datasetId}) Future<GetExternalDataViewAccessDetailsResponse>
Returns the credentials to access the external Dataview from an S3 location. To call this API:
getPermissionGroup({required String permissionGroupId}) Future<GetPermissionGroupResponse>
Retrieves the details of a specific permission group.
getProgrammaticAccessCredentials({required String environmentId, int? durationInMinutes}) Future<GetProgrammaticAccessCredentialsResponse>
Request programmatic credentials to use with FinSpace SDK. For more information, see Step 2. Access credentials programmatically using IAM access key id and secret access key.
getUser({required String userId}) Future<GetUserResponse>
Retrieves details for a specific user.
getWorkingLocation({LocationType? locationType}) Future<GetWorkingLocationResponse>
A temporary Amazon S3 location, where you can copy your files from a source location to stage or use as a scratch space in FinSpace notebook.
listChangesets({required String datasetId, int? maxResults, String? nextToken}) Future<ListChangesetsResponse>
Lists the FinSpace Changesets for a Dataset.
listDatasets({int? maxResults, String? nextToken}) Future<ListDatasetsResponse>
Lists all of the active Datasets that a user has access to.
listDataViews({required String datasetId, int? maxResults, String? nextToken}) Future<ListDataViewsResponse>
Lists all available Dataviews for a Dataset.
listPermissionGroups({required int maxResults, String? nextToken}) Future<ListPermissionGroupsResponse>
Lists all available permission groups in FinSpace.
listPermissionGroupsByUser({required int maxResults, required String userId, String? nextToken}) Future<ListPermissionGroupsByUserResponse>
Lists all the permission groups that are associated with a specific user.
listUsers({required int maxResults, String? nextToken}) Future<ListUsersResponse>
Lists all available users in FinSpace.
listUsersByPermissionGroup({required int maxResults, required String permissionGroupId, String? nextToken}) Future<ListUsersByPermissionGroupResponse>
Lists details of all the users in a specific permission group.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetUserPassword({required String userId, String? clientToken}) Future<ResetUserPasswordResponse>
Resets the password for a specified user ID and generates a temporary one. Only a superuser can reset password for other users. Resetting the password immediately invalidates the previous password associated with the user.
toString() String
A string representation of this object.
inherited
updateChangeset({required String changesetId, required String datasetId, required Map<String, String> formatParams, required Map<String, String> sourceParams, String? clientToken}) Future<UpdateChangesetResponse>
Updates a FinSpace Changeset.
updateDataset({required String datasetId, required String datasetTitle, required DatasetKind kind, String? alias, String? clientToken, String? datasetDescription, SchemaUnion? schemaDefinition}) Future<UpdateDatasetResponse>
Updates a FinSpace Dataset.
updatePermissionGroup({required String permissionGroupId, List<ApplicationPermission>? applicationPermissions, String? clientToken, String? description, String? name}) Future<UpdatePermissionGroupResponse>
Modifies the details of a permission group. You cannot modify a permissionGroupID.
updateUser({required String userId, ApiAccess? apiAccess, String? apiAccessPrincipalArn, String? clientToken, String? firstName, String? lastName, UserType? type}) Future<UpdateUserResponse>
Modifies the details of the specified user. You cannot update the userId for a user.

Operators

operator ==(Object other) bool
The equality operator.
inherited