getExternalDataViewAccessDetails method

Future<GetExternalDataViewAccessDetailsResponse> getExternalDataViewAccessDetails({
  1. required String dataViewId,
  2. required String datasetId,
})

Returns the credentials to access the external Dataview from an S3 location. To call this API:

  • You must retrieve the programmatic credentials.
  • You must be a member of a FinSpace user group, where the dataset that you want to access has Read Dataset Data permissions.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter dataViewId : The unique identifier for the Dataview that you want to access.

Parameter datasetId : The unique identifier for the Dataset.

Implementation

Future<GetExternalDataViewAccessDetailsResponse>
    getExternalDataViewAccessDetails({
  required String dataViewId,
  required String datasetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/datasets/${Uri.encodeComponent(datasetId)}/dataviewsv2/${Uri.encodeComponent(dataViewId)}/external-access-details',
    exceptionFnMap: _exceptionFns,
  );
  return GetExternalDataViewAccessDetailsResponse.fromJson(response);
}