getWorkingLocation method

Future<GetWorkingLocationResponse> getWorkingLocation({
  1. LocationType? locationType,
})

A temporary Amazon S3 location, where you can copy your files from a source location to stage or use as a scratch space in FinSpace notebook.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter locationType : Specify the type of the working location.

  • SAGEMAKER – Use the Amazon S3 location as a temporary location to store data content when working with FinSpace Notebooks that run on SageMaker studio.
  • INGESTION – Use the Amazon S3 location as a staging location to copy your data content and then use the location with the Changeset creation operation.

Implementation

Future<GetWorkingLocationResponse> getWorkingLocation({
  LocationType? locationType,
}) async {
  final $payload = <String, dynamic>{
    if (locationType != null) 'locationType': locationType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/workingLocationV1',
    exceptionFnMap: _exceptionFns,
  );
  return GetWorkingLocationResponse.fromJson(response);
}