Firehose class

Amazon Data Firehose was previously known as Amazon Kinesis Data Firehose. Amazon Data Firehose is a fully managed service that delivers real-time streaming data to destinations such as Amazon Simple Storage Service (Amazon S3), Amazon OpenSearch Service, Amazon Redshift, Splunk, and various other supported destinations.

Constructors

Firehose({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createDeliveryStream({required String deliveryStreamName, AmazonOpenSearchServerlessDestinationConfiguration? amazonOpenSearchServerlessDestinationConfiguration, AmazonopensearchserviceDestinationConfiguration? amazonopensearchserviceDestinationConfiguration, DatabaseSourceConfiguration? databaseSourceConfiguration, DeliveryStreamEncryptionConfigurationInput? deliveryStreamEncryptionConfigurationInput, DeliveryStreamType? deliveryStreamType, DirectPutSourceConfiguration? directPutSourceConfiguration, ElasticsearchDestinationConfiguration? elasticsearchDestinationConfiguration, ExtendedS3DestinationConfiguration? extendedS3DestinationConfiguration, HttpEndpointDestinationConfiguration? httpEndpointDestinationConfiguration, IcebergDestinationConfiguration? icebergDestinationConfiguration, KinesisStreamSourceConfiguration? kinesisStreamSourceConfiguration, MSKSourceConfiguration? mSKSourceConfiguration, RedshiftDestinationConfiguration? redshiftDestinationConfiguration, S3DestinationConfiguration? s3DestinationConfiguration, SnowflakeDestinationConfiguration? snowflakeDestinationConfiguration, SplunkDestinationConfiguration? splunkDestinationConfiguration, List<Tag>? tags}) Future<CreateDeliveryStreamOutput>
Creates a Firehose stream.
deleteDeliveryStream({required String deliveryStreamName, bool? allowForceDelete}) Future<void>
Deletes a Firehose stream and its data.
describeDeliveryStream({required String deliveryStreamName, String? exclusiveStartDestinationId, int? limit}) Future<DescribeDeliveryStreamOutput>
Describes the specified Firehose stream and its status. For example, after your Firehose stream is created, call DescribeDeliveryStream to see whether the Firehose stream is ACTIVE and therefore ready for data to be sent to it.
listDeliveryStreams({DeliveryStreamType? deliveryStreamType, String? exclusiveStartDeliveryStreamName, int? limit}) Future<ListDeliveryStreamsOutput>
Lists your Firehose streams in alphabetical order of their names.
listTagsForDeliveryStream({required String deliveryStreamName, String? exclusiveStartTagKey, int? limit}) Future<ListTagsForDeliveryStreamOutput>
Lists the tags for the specified Firehose stream. This operation has a limit of five transactions per second per account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putRecord({required String deliveryStreamName, required Record record}) Future<PutRecordOutput>
Writes a single data record into an Firehose stream. To write multiple data records into a Firehose stream, use PutRecordBatch. Applications using these operations are referred to as producers.
putRecordBatch({required String deliveryStreamName, required List<Record> records}) Future<PutRecordBatchOutput>
Writes multiple data records into a Firehose stream in a single call, which can achieve higher throughput per producer than when writing single records. To write single data records into a Firehose stream, use PutRecord. Applications using these operations are referred to as producers.
startDeliveryStreamEncryption({required String deliveryStreamName, DeliveryStreamEncryptionConfigurationInput? deliveryStreamEncryptionConfigurationInput}) Future<void>
Enables server-side encryption (SSE) for the Firehose stream.
stopDeliveryStreamEncryption({required String deliveryStreamName}) Future<void>
Disables server-side encryption (SSE) for the Firehose stream.
tagDeliveryStream({required String deliveryStreamName, required List<Tag> tags}) Future<void>
Adds or updates tags for the specified Firehose stream. A tag is a key-value pair that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. Tags are metadata. For example, you can add friendly names and descriptions or other types of information that can help you distinguish the Firehose stream. For more information about tags, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide.
toString() String
A string representation of this object.
inherited
untagDeliveryStream({required String deliveryStreamName, required List<String> tagKeys}) Future<void>
Removes tags from the specified Firehose stream. Removed tags are deleted, and you can't recover them after this operation successfully completes.
updateDestination({required String currentDeliveryStreamVersionId, required String deliveryStreamName, required String destinationId, AmazonOpenSearchServerlessDestinationUpdate? amazonOpenSearchServerlessDestinationUpdate, AmazonopensearchserviceDestinationUpdate? amazonopensearchserviceDestinationUpdate, ElasticsearchDestinationUpdate? elasticsearchDestinationUpdate, ExtendedS3DestinationUpdate? extendedS3DestinationUpdate, HttpEndpointDestinationUpdate? httpEndpointDestinationUpdate, IcebergDestinationUpdate? icebergDestinationUpdate, RedshiftDestinationUpdate? redshiftDestinationUpdate, S3DestinationUpdate? s3DestinationUpdate, SnowflakeDestinationUpdate? snowflakeDestinationUpdate, SplunkDestinationUpdate? splunkDestinationUpdate}) Future<void>
Updates the specified destination of the specified Firehose stream.

Operators

operator ==(Object other) bool
The equality operator.
inherited