deleteDeliveryStream method
Deletes a Firehose stream and its data.
You can delete a Firehose stream only if it is in one of the following
states: ACTIVE, DELETING,
CREATING_FAILED, or DELETING_FAILED. You can't
delete a Firehose stream that is in the CREATING state. To
check the state of a Firehose stream, use DescribeDeliveryStream.
DeleteDeliveryStream is an asynchronous API. When an API request to
DeleteDeliveryStream succeeds, the Firehose stream is marked for deletion,
and it goes into the DELETING state.While the Firehose stream
is in the DELETING state, the service might continue to
accept records, but it doesn't make any guarantees with respect to
delivering the data. Therefore, as a best practice, first stop any
applications that are sending records before you delete a Firehose stream.
Removal of a Firehose stream that is in the DELETING state is
a low priority operation for the service. A stream may remain in the
DELETING state for several minutes. Therefore, as a best
practice, applications should not wait for streams in the
DELETING state to be removed.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter deliveryStreamName :
The name of the Firehose stream.
Parameter allowForceDelete :
Set this to true if you want to delete the Firehose stream even if
Firehose is unable to retire the grant for the CMK. Firehose might be
unable to retire the grant due to a customer error, such as when the CMK
or the grant are in an invalid state. If you force deletion, you can then
use the RevokeGrant
operation to revoke the grant you gave to Firehose. If a failure to retire
the grant happens due to an Amazon Web Services KMS issue, Firehose keeps
retrying the delete operation.
The default value is false.
Implementation
Future<void> deleteDeliveryStream({
required String deliveryStreamName,
bool? allowForceDelete,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Firehose_20150804.DeleteDeliveryStream'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DeliveryStreamName': deliveryStreamName,
if (allowForceDelete != null) 'AllowForceDelete': allowForceDelete,
},
);
}