untagDeliveryStream method

Future<void> untagDeliveryStream({
  1. required String deliveryStreamName,
  2. required List<String> tagKeys,
})

Removes tags from the specified Firehose stream. Removed tags are deleted, and you can't recover them after this operation successfully completes.

If you specify a tag that doesn't exist, the operation ignores it.

This operation has a limit of five transactions per second per account.

May throw InvalidArgumentException. May throw LimitExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter deliveryStreamName : The name of the Firehose stream.

Parameter tagKeys : A list of tag keys. Each corresponding tag is removed from the delivery stream.

Implementation

Future<void> untagDeliveryStream({
  required String deliveryStreamName,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Firehose_20150804.UntagDeliveryStream'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DeliveryStreamName': deliveryStreamName,
      'TagKeys': tagKeys,
    },
  );
}