listTargetAccountConfigurations method

Future<ListTargetAccountConfigurationsResponse> listTargetAccountConfigurations({
  1. required String experimentTemplateId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the target account configurations of the specified experiment template.

May throw ResourceNotFoundException. May throw ValidationException.

Parameter experimentTemplateId : The ID of the experiment template.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListTargetAccountConfigurationsResponse>
    listTargetAccountConfigurations({
  required String experimentTemplateId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/experimentTemplates/${Uri.encodeComponent(experimentTemplateId)}/targetAccountConfigurations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTargetAccountConfigurationsResponse.fromJson(response);
}