Fms class
This is the Firewall Manager API Reference. This guide is for developers who need detailed information about the Firewall Manager API actions, data types, and errors. For detailed information about Firewall Manager features, see the Firewall Manager Developer Guide.
Some API actions require explicit resource permissions. For information, see the developer guide topic Service roles for Firewall Manager.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateAdminAccount(
{required String adminAccount}) → Future< void> - Sets a Firewall Manager default administrator account. The Firewall Manager default administrator account can manage third-party firewalls and has full administrative scope that allows administration of all policy types, accounts, organizational units, and Regions. This account must be a member account of the organization in Organizations whose resources you want to protect.
-
associateThirdPartyFirewall(
{required ThirdPartyFirewall thirdPartyFirewall}) → Future< AssociateThirdPartyFirewallResponse> - Sets the Firewall Manager policy administrator as a tenant administrator of a third-party firewall service. A tenant is an instance of the third-party firewall service that's associated with your Amazon Web Services customer account.
-
batchAssociateResource(
{required List< String> items, required String resourceSetIdentifier}) → Future<BatchAssociateResourceResponse> - Associate resources to a Firewall Manager resource set.
-
batchDisassociateResource(
{required List< String> items, required String resourceSetIdentifier}) → Future<BatchDisassociateResourceResponse> - Disassociates resources from a Firewall Manager resource set.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deleteAppsList(
{required String listId}) → Future< void> - Permanently deletes an Firewall Manager applications list.
-
deleteNotificationChannel(
) → Future< void> - Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
-
deletePolicy(
{required String policyId, bool? deleteAllPolicyResources}) → Future< void> - Permanently deletes an Firewall Manager policy.
-
deleteProtocolsList(
{required String listId}) → Future< void> - Permanently deletes an Firewall Manager protocols list.
-
deleteResourceSet(
{required String identifier}) → Future< void> - Deletes the specified ResourceSet.
-
disassociateAdminAccount(
) → Future< void> - Disassociates an Firewall Manager administrator account. To set a different account as an Firewall Manager administrator, submit a PutAdminAccount request. To set an account as a default administrator account, you must submit an AssociateAdminAccount request.
-
disassociateThirdPartyFirewall(
{required ThirdPartyFirewall thirdPartyFirewall}) → Future< DisassociateThirdPartyFirewallResponse> -
Disassociates a Firewall Manager policy administrator from a third-party
firewall tenant. When you call
DisassociateThirdPartyFirewall, the third-party firewall vendor deletes all of the firewalls that are associated with the account. -
getAdminAccount(
) → Future< GetAdminAccountResponse> - Returns the Organizations account that is associated with Firewall Manager as the Firewall Manager default administrator.
-
getAdminScope(
{required String adminAccount}) → Future< GetAdminScopeResponse> - Returns information about the specified account's administrative scope. The administrative scope defines the resources that an Firewall Manager administrator can manage.
-
getAppsList(
{required String listId, bool? defaultList}) → Future< GetAppsListResponse> - Returns information about the specified Firewall Manager applications list.
-
getComplianceDetail(
{required String memberAccount, required String policyId}) → Future< GetComplianceDetailResponse> - Returns detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy.
-
getNotificationChannel(
) → Future< GetNotificationChannelResponse> - Information about the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
-
getPolicy(
{required String policyId}) → Future< GetPolicyResponse> - Returns information about the specified Firewall Manager policy.
-
getProtectionStatus(
{required String policyId, DateTime? endTime, int? maxResults, String? memberAccountId, String? nextToken, DateTime? startTime}) → Future< GetProtectionStatusResponse> - If you created a Shield Advanced policy, returns policy-level attack summary information in the event of a potential DDoS attack. Other policy types are currently unsupported.
-
getProtocolsList(
{required String listId, bool? defaultList}) → Future< GetProtocolsListResponse> - Returns information about the specified Firewall Manager protocols list.
-
getResourceSet(
{required String identifier}) → Future< GetResourceSetResponse> - Gets information about a specific resource set.
-
getThirdPartyFirewallAssociationStatus(
{required ThirdPartyFirewall thirdPartyFirewall}) → Future< GetThirdPartyFirewallAssociationStatusResponse> - The onboarding status of a Firewall Manager admin account to third-party firewall vendor tenant.
-
getViolationDetails(
{required String memberAccount, required String policyId, required String resourceId, required String resourceType}) → Future< GetViolationDetailsResponse> - Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account.
-
listAdminAccountsForOrganization(
{int? maxResults, String? nextToken}) → Future< ListAdminAccountsForOrganizationResponse> -
Returns a
AdminAccountsobject that lists the Firewall Manager administrators within the organization that are onboarded to Firewall Manager by AssociateAdminAccount. -
listAdminsManagingAccount(
{int? maxResults, String? nextToken}) → Future< ListAdminsManagingAccountResponse> - Lists the accounts that are managing the specified Organizations member account. This is useful for any member account so that they can view the accounts who are managing their account. This operation only returns the managing administrators that have the requested account within their AdminScope.
-
listAppsLists(
{required int maxResults, bool? defaultLists, String? nextToken}) → Future< ListAppsListsResponse> -
Returns an array of
AppsListDataSummaryobjects. -
listComplianceStatus(
{required String policyId, int? maxResults, String? nextToken}) → Future< ListComplianceStatusResponse> -
Returns an array of
PolicyComplianceStatusobjects. UsePolicyComplianceStatusto get a summary of which member accounts are protected by the specified policy. -
listDiscoveredResources(
{required List< String> memberAccountIds, required String resourceType, int? maxResults, String? nextToken}) → Future<ListDiscoveredResourcesResponse> - Returns an array of resources in the organization's accounts that are available to be associated with a resource set.
-
listMemberAccounts(
{int? maxResults, String? nextToken}) → Future< ListMemberAccountsResponse> -
Returns a
MemberAccountsobject that lists the member accounts in the administrator's Amazon Web Services organization. -
listPolicies(
{int? maxResults, String? nextToken}) → Future< ListPoliciesResponse> -
Returns an array of
PolicySummaryobjects. -
listProtocolsLists(
{required int maxResults, bool? defaultLists, String? nextToken}) → Future< ListProtocolsListsResponse> -
Returns an array of
ProtocolsListDataSummaryobjects. -
listResourceSetResources(
{required String identifier, int? maxResults, String? nextToken}) → Future< ListResourceSetResourcesResponse> - Returns an array of resources that are currently associated to a resource set.
-
listResourceSets(
{int? maxResults, String? nextToken}) → Future< ListResourceSetsResponse> -
Returns an array of
ResourceSetSummaryobjects. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Retrieves the list of tags for the specified Amazon Web Services resource.
-
listThirdPartyFirewallFirewallPolicies(
{required int maxResults, required ThirdPartyFirewall thirdPartyFirewall, String? nextToken}) → Future< ListThirdPartyFirewallFirewallPoliciesResponse> - Retrieves a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAdminAccount(
{required String adminAccount, AdminScope? adminScope}) → Future< void> - Creates or updates an Firewall Manager administrator account. The account must be a member of the organization that was onboarded to Firewall Manager by AssociateAdminAccount. Only the organization's management account can create an Firewall Manager administrator account. When you create an Firewall Manager administrator account, the service checks to see if the account is already a delegated administrator within Organizations. If the account isn't a delegated administrator, Firewall Manager calls Organizations to delegate the account within Organizations. For more information about administrator accounts within Organizations, see Managing the Amazon Web Services Accounts in Your Organization.
-
putAppsList(
{required AppsListData appsList, List< Tag> ? tagList}) → Future<PutAppsListResponse> - Creates an Firewall Manager applications list.
-
putNotificationChannel(
{required String snsRoleName, required String snsTopicArn}) → Future< void> - Designates the IAM role and Amazon Simple Notification Service (SNS) topic that Firewall Manager uses to record SNS logs.
-
putPolicy(
{required Policy policy, List< Tag> ? tagList}) → Future<PutPolicyResponse> - Creates an Firewall Manager policy.
-
putProtocolsList(
{required ProtocolsListData protocolsList, List< Tag> ? tagList}) → Future<PutProtocolsListResponse> - Creates an Firewall Manager protocols list.
-
putResourceSet(
{required ResourceSet resourceSet, List< Tag> ? tagList}) → Future<PutResourceSetResponse> - Creates the resource set.
-
tagResource(
{required String resourceArn, required List< Tag> tagList}) → Future<void> - Adds one or more tags to an Amazon Web Services resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from an Amazon Web Services resource.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited