associateThirdPartyFirewall method
Future<AssociateThirdPartyFirewallResponse>
associateThirdPartyFirewall({
- required ThirdPartyFirewall thirdPartyFirewall,
Sets the Firewall Manager policy administrator as a tenant administrator of a third-party firewall service. A tenant is an instance of the third-party firewall service that's associated with your Amazon Web Services customer account.
May throw InternalErrorException.
May throw InvalidInputException.
May throw InvalidOperationException.
May throw ResourceNotFoundException.
Parameter thirdPartyFirewall :
The name of the third-party firewall vendor.
Implementation
Future<AssociateThirdPartyFirewallResponse> associateThirdPartyFirewall({
required ThirdPartyFirewall thirdPartyFirewall,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.AssociateThirdPartyFirewall'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ThirdPartyFirewall': thirdPartyFirewall.value,
},
);
return AssociateThirdPartyFirewallResponse.fromJson(jsonResponse.body);
}