batchDisassociateResource method

Future<BatchDisassociateResourceResponse> batchDisassociateResource({
  1. required List<String> items,
  2. required String resourceSetIdentifier,
})

Disassociates resources from a Firewall Manager resource set.

May throw InternalErrorException. May throw InvalidInputException. May throw InvalidOperationException. May throw ResourceNotFoundException.

Parameter items : The uniform resource identifiers (URI) of resources that should be disassociated from the resource set. The URIs must be Amazon Resource Names (ARNs).

Parameter resourceSetIdentifier : A unique identifier for the resource set, used in a request to refer to the resource set.

Implementation

Future<BatchDisassociateResourceResponse> batchDisassociateResource({
  required List<String> items,
  required String resourceSetIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.BatchDisassociateResource'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Items': items,
      'ResourceSetIdentifier': resourceSetIdentifier,
    },
  );

  return BatchDisassociateResourceResponse.fromJson(jsonResponse.body);
}