deleteNotificationChannel method

Future<void> deleteNotificationChannel()

Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.

May throw InternalErrorException. May throw InvalidOperationException. May throw ResourceNotFoundException.

Implementation

Future<void> deleteNotificationChannel() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.DeleteNotificationChannel'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );
}