deleteResourceSet method

Future<void> deleteResourceSet({
  1. required String identifier,
})

Deletes the specified ResourceSet.

May throw InternalErrorException. May throw InvalidInputException. May throw InvalidOperationException. May throw ResourceNotFoundException.

Parameter identifier : A unique identifier for the resource set, used in a request to refer to the resource set.

Implementation

Future<void> deleteResourceSet({
  required String identifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.DeleteResourceSet'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Identifier': identifier,
    },
  );
}