disassociateThirdPartyFirewall method

Future<DisassociateThirdPartyFirewallResponse> disassociateThirdPartyFirewall({
  1. required ThirdPartyFirewall thirdPartyFirewall,
})

Disassociates a Firewall Manager policy administrator from a third-party firewall tenant. When you call DisassociateThirdPartyFirewall, the third-party firewall vendor deletes all of the firewalls that are associated with the account.

May throw InternalErrorException. May throw InvalidInputException. May throw InvalidOperationException. May throw ResourceNotFoundException.

Parameter thirdPartyFirewall : The name of the third-party firewall vendor.

Implementation

Future<DisassociateThirdPartyFirewallResponse>
    disassociateThirdPartyFirewall({
  required ThirdPartyFirewall thirdPartyFirewall,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.DisassociateThirdPartyFirewall'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ThirdPartyFirewall': thirdPartyFirewall.value,
    },
  );

  return DisassociateThirdPartyFirewallResponse.fromJson(jsonResponse.body);
}