getAdminScope method
Returns information about the specified account's administrative scope. The administrative scope defines the resources that an Firewall Manager administrator can manage.
May throw InternalErrorException.
May throw InvalidInputException.
May throw InvalidOperationException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter adminAccount :
The administrator account that you want to get the details for.
Implementation
Future<GetAdminScopeResponse> getAdminScope({
required String adminAccount,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.GetAdminScope'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AdminAccount': adminAccount,
},
);
return GetAdminScopeResponse.fromJson(jsonResponse.body);
}