getAppsList method
Returns information about the specified Firewall Manager applications list.
May throw InternalErrorException.
May throw InvalidOperationException.
May throw ResourceNotFoundException.
Parameter listId :
The ID of the Firewall Manager applications list that you want the details
for.
Parameter defaultList :
Specifies whether the list to retrieve is a default list owned by Firewall
Manager.
Implementation
Future<GetAppsListResponse> getAppsList({
required String listId,
bool? defaultList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.GetAppsList'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ListId': listId,
if (defaultList != null) 'DefaultList': defaultList,
},
);
return GetAppsListResponse.fromJson(jsonResponse.body);
}