listDiscoveredResources method

Future<ListDiscoveredResourcesResponse> listDiscoveredResources({
  1. required List<String> memberAccountIds,
  2. required String resourceType,
  3. int? maxResults,
  4. String? nextToken,
})

Returns an array of resources in the organization's accounts that are available to be associated with a resource set.

May throw InternalErrorException. May throw InvalidInputException. May throw InvalidOperationException.

Parameter memberAccountIds : The Amazon Web Services account IDs to discover resources in. Only one account is supported per request. The account must be a member of your organization.

Parameter resourceType : The type of resources to discover.

Parameter maxResults : The maximum number of objects that you want Firewall Manager to return for this request. If more objects are available, in the response, Firewall Manager provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

Parameter nextToken : When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Firewall Manager returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request.

Implementation

Future<ListDiscoveredResourcesResponse> listDiscoveredResources({
  required List<String> memberAccountIds,
  required String resourceType,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.ListDiscoveredResources'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MemberAccountIds': memberAccountIds,
      'ResourceType': resourceType,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListDiscoveredResourcesResponse.fromJson(jsonResponse.body);
}