listResourceSetResources method

Future<ListResourceSetResourcesResponse> listResourceSetResources({
  1. required String identifier,
  2. int? maxResults,
  3. String? nextToken,
})

Returns an array of resources that are currently associated to a resource set.

May throw InternalErrorException. May throw InvalidInputException. May throw InvalidOperationException. May throw ResourceNotFoundException.

Parameter identifier : A unique identifier for the resource set, used in a request to refer to the resource set.

Parameter maxResults : The maximum number of objects that you want Firewall Manager to return for this request. If more objects are available, in the response, Firewall Manager provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

Parameter nextToken : When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Firewall Manager returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request.

Implementation

Future<ListResourceSetResourcesResponse> listResourceSetResources({
  required String identifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSFMS_20180101.ListResourceSetResources'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Identifier': identifier,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListResourceSetResourcesResponse.fromJson(jsonResponse.body);
}