tagResource method
Adds one or more tags to an Amazon Web Services resource.
May throw InternalErrorException.
May throw InvalidInputException.
May throw InvalidOperationException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to return tags for. The
Firewall Manager resources that support tagging are policies, applications
lists, and protocols lists.
Parameter tagList :
The tags to add to the resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tagList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagList': tagList,
},
);
}