Forecast class
Provides APIs for creating and managing Amazon Forecast resources.
Constructors
- Forecast({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAutoPredictor(
{required String predictorName, DataConfig? dataConfig, EncryptionConfig? encryptionConfig, bool? explainPredictor, List< String> ? forecastDimensions, String? forecastFrequency, int? forecastHorizon, List<String> ? forecastTypes, MonitorConfig? monitorConfig, OptimizationMetric? optimizationMetric, String? referencePredictorArn, List<Tag> ? tags, TimeAlignmentBoundary? timeAlignmentBoundary}) → Future<CreateAutoPredictorResponse> - Creates an Amazon Forecast predictor.
-
createDataset(
{required String datasetName, required DatasetType datasetType, required Domain domain, required Schema schema, String? dataFrequency, EncryptionConfig? encryptionConfig, List< Tag> ? tags}) → Future<CreateDatasetResponse> - Creates an Amazon Forecast dataset. The information about the dataset that you provide helps Forecast understand how to consume the data for model training. This includes the following:
-
createDatasetGroup(
{required String datasetGroupName, required Domain domain, List< String> ? datasetArns, List<Tag> ? tags}) → Future<CreateDatasetGroupResponse> - Creates a dataset group, which holds a collection of related datasets. You can add datasets to the dataset group when you create the dataset group, or later by using the UpdateDatasetGroup operation.
-
createDatasetImportJob(
{required DataSource dataSource, required String datasetArn, required String datasetImportJobName, String? format, String? geolocationFormat, ImportMode? importMode, List< Tag> ? tags, String? timeZone, String? timestampFormat, bool? useGeolocationForTimeZone}) → Future<CreateDatasetImportJobResponse> - Imports your training data to an Amazon Forecast dataset. You provide the location of your training data in an Amazon Simple Storage Service (Amazon S3) bucket and the Amazon Resource Name (ARN) of the dataset that you want to import the data to.
-
createExplainability(
{required ExplainabilityConfig explainabilityConfig, required String explainabilityName, required String resourceArn, DataSource? dataSource, bool? enableVisualization, String? endDateTime, Schema? schema, String? startDateTime, List< Tag> ? tags}) → Future<CreateExplainabilityResponse> - Explainability helps you better understand how the attributes in your datasets impact forecast. Amazon Forecast uses a metric called Impact scores to quantify the relative impact of each attribute and determine whether they increase or decrease forecast values.
-
createExplainabilityExport(
{required DataDestination destination, required String explainabilityArn, required String explainabilityExportName, String? format, List< Tag> ? tags}) → Future<CreateExplainabilityExportResponse> - Exports an Explainability resource created by the CreateExplainability operation. Exported files are exported to an Amazon Simple Storage Service (Amazon S3) bucket.
-
createForecast(
{required String forecastName, required String predictorArn, List< String> ? forecastTypes, List<Tag> ? tags, TimeSeriesSelector? timeSeriesSelector}) → Future<CreateForecastResponse> -
Creates a forecast for each item in the
TARGET_TIME_SERIESdataset that was used to train the predictor. This is known as inference. To retrieve the forecast for a single item at low latency, use the operation. To export the complete forecast into your Amazon Simple Storage Service (Amazon S3) bucket, use the CreateForecastExportJob operation. -
createForecastExportJob(
{required DataDestination destination, required String forecastArn, required String forecastExportJobName, String? format, List< Tag> ? tags}) → Future<CreateForecastExportJobResponse> - Exports a forecast created by the CreateForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket. The forecast file name will match the following conventions:
-
createMonitor(
{required String monitorName, required String resourceArn, List< Tag> ? tags}) → Future<CreateMonitorResponse> - Creates a predictor monitor resource for an existing auto predictor. Predictor monitoring allows you to see how your predictor's performance changes over time. For more information, see Predictor Monitoring.
-
createPredictor(
{required FeaturizationConfig featurizationConfig, required int forecastHorizon, required InputDataConfig inputDataConfig, required String predictorName, String? algorithmArn, AutoMLOverrideStrategy? autoMLOverrideStrategy, EncryptionConfig? encryptionConfig, EvaluationParameters? evaluationParameters, List< String> ? forecastTypes, HyperParameterTuningJobConfig? hPOConfig, OptimizationMetric? optimizationMetric, bool? performAutoML, bool? performHPO, List<Tag> ? tags, Map<String, String> ? trainingParameters}) → Future<CreatePredictorResponse> - In the request, provide a dataset group and either specify an algorithm or let Amazon Forecast choose an algorithm for you using AutoML. If you specify an algorithm, you also can override algorithm-specific hyperparameters.
-
createPredictorBacktestExportJob(
{required DataDestination destination, required String predictorArn, required String predictorBacktestExportJobName, String? format, List< Tag> ? tags}) → Future<CreatePredictorBacktestExportJobResponse> - Exports backtest forecasts and accuracy metrics generated by the CreateAutoPredictor or CreatePredictor operations. Two folders containing CSV or Parquet files are exported to your specified S3 bucket.
-
createWhatIfAnalysis(
{required String forecastArn, required String whatIfAnalysisName, List< Tag> ? tags, TimeSeriesSelector? timeSeriesSelector}) → Future<CreateWhatIfAnalysisResponse> - What-if analysis is a scenario modeling technique where you make a hypothetical change to a time series and compare the forecasts generated by these changes against the baseline, unchanged time series. It is important to remember that the purpose of a what-if analysis is to understand how a forecast can change given different modifications to the baseline time series.
-
createWhatIfForecast(
{required String whatIfAnalysisArn, required String whatIfForecastName, List< Tag> ? tags, TimeSeriesReplacementsDataSource? timeSeriesReplacementsDataSource, List<TimeSeriesTransformation> ? timeSeriesTransformations}) → Future<CreateWhatIfForecastResponse> - A what-if forecast is a forecast that is created from a modified version of the baseline forecast. Each what-if forecast incorporates either a replacement dataset or a set of transformations to the original dataset.
-
createWhatIfForecastExport(
{required DataDestination destination, required List< String> whatIfForecastArns, required String whatIfForecastExportName, String? format, List<Tag> ? tags}) → Future<CreateWhatIfForecastExportResponse> - Exports a forecast created by the CreateWhatIfForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket. The forecast file name will match the following conventions:
-
deleteDataset(
{required String datasetArn}) → Future< void> -
Deletes an Amazon Forecast dataset that was created using the CreateDataset
operation. You can only delete datasets that have a status of
ACTIVEorCREATE_FAILED. To get the status use the DescribeDataset operation. -
deleteDatasetGroup(
{required String datasetGroupArn}) → Future< void> -
Deletes a dataset group created using the CreateDatasetGroup
operation. You can only delete dataset groups that have a status of
ACTIVE,CREATE_FAILED, orUPDATE_FAILED. To get the status, use the DescribeDatasetGroup operation. -
deleteDatasetImportJob(
{required String datasetImportJobArn}) → Future< void> -
Deletes a dataset import job created using the CreateDatasetImportJob
operation. You can delete only dataset import jobs that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeDatasetImportJob operation. -
deleteExplainability(
{required String explainabilityArn}) → Future< void> - Deletes an Explainability resource.
-
deleteExplainabilityExport(
{required String explainabilityExportArn}) → Future< void> - Deletes an Explainability export.
-
deleteForecast(
{required String forecastArn}) → Future< void> -
Deletes a forecast created using the CreateForecast operation. You
can delete only forecasts that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeForecast operation. -
deleteForecastExportJob(
{required String forecastExportJobArn}) → Future< void> -
Deletes a forecast export job created using the
CreateForecastExportJob operation. You can delete only export jobs
that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeForecastExportJob operation. -
deleteMonitor(
{required String monitorArn}) → Future< void> -
Deletes a monitor resource. You can only delete a monitor resource with a
status of
ACTIVE,ACTIVE_STOPPED,CREATE_FAILED, orCREATE_STOPPED. -
deletePredictor(
{required String predictorArn}) → Future< void> -
Deletes a predictor created using the DescribePredictor or
CreatePredictor operations. You can delete only predictor that have
a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribePredictor operation. -
deletePredictorBacktestExportJob(
{required String predictorBacktestExportJobArn}) → Future< void> - Deletes a predictor backtest export job.
-
deleteResourceTree(
{required String resourceArn}) → Future< void> - Deletes an entire resource tree. This operation will delete the parent resource and its child resources.
-
deleteWhatIfAnalysis(
{required String whatIfAnalysisArn}) → Future< void> -
Deletes a what-if analysis created using the CreateWhatIfAnalysis
operation. You can delete only what-if analyses that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeWhatIfAnalysis operation. -
deleteWhatIfForecast(
{required String whatIfForecastArn}) → Future< void> -
Deletes a what-if forecast created using the CreateWhatIfForecast
operation. You can delete only what-if forecasts that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeWhatIfForecast operation. -
deleteWhatIfForecastExport(
{required String whatIfForecastExportArn}) → Future< void> -
Deletes a what-if forecast export created using the
CreateWhatIfForecastExport operation. You can delete only what-if
forecast exports that have a status of
ACTIVEorCREATE_FAILED. To get the status, use the DescribeWhatIfForecastExport operation. -
describeAutoPredictor(
{required String predictorArn}) → Future< DescribeAutoPredictorResponse> - Describes a predictor created using the CreateAutoPredictor operation.
-
describeDataset(
{required String datasetArn}) → Future< DescribeDatasetResponse> - Describes an Amazon Forecast dataset created using the CreateDataset operation.
-
describeDatasetGroup(
{required String datasetGroupArn}) → Future< DescribeDatasetGroupResponse> - Describes a dataset group created using the CreateDatasetGroup operation.
-
describeDatasetImportJob(
{required String datasetImportJobArn}) → Future< DescribeDatasetImportJobResponse> - Describes a dataset import job created using the CreateDatasetImportJob operation.
-
describeExplainability(
{required String explainabilityArn}) → Future< DescribeExplainabilityResponse> - Describes an Explainability resource created using the CreateExplainability operation.
-
describeExplainabilityExport(
{required String explainabilityExportArn}) → Future< DescribeExplainabilityExportResponse> - Describes an Explainability export created using the CreateExplainabilityExport operation.
-
describeForecast(
{required String forecastArn}) → Future< DescribeForecastResponse> - Describes a forecast created using the CreateForecast operation.
-
describeForecastExportJob(
{required String forecastExportJobArn}) → Future< DescribeForecastExportJobResponse> - Describes a forecast export job created using the CreateForecastExportJob operation.
-
describeMonitor(
{required String monitorArn}) → Future< DescribeMonitorResponse> - Describes a monitor resource. In addition to listing the properties provided in the CreateMonitor request, this operation lists the following properties:
-
describePredictor(
{required String predictorArn}) → Future< DescribePredictorResponse> - CreatePredictor
-
describePredictorBacktestExportJob(
{required String predictorBacktestExportJobArn}) → Future< DescribePredictorBacktestExportJobResponse> - Describes a predictor backtest export job created using the CreatePredictorBacktestExportJob operation.
-
describeWhatIfAnalysis(
{required String whatIfAnalysisArn}) → Future< DescribeWhatIfAnalysisResponse> - Describes the what-if analysis created using the CreateWhatIfAnalysis operation.
-
describeWhatIfForecast(
{required String whatIfForecastArn}) → Future< DescribeWhatIfForecastResponse> - Describes the what-if forecast created using the CreateWhatIfForecast operation.
-
describeWhatIfForecastExport(
{required String whatIfForecastExportArn}) → Future< DescribeWhatIfForecastExportResponse> - Describes the what-if forecast export created using the CreateWhatIfForecastExport operation.
-
getAccuracyMetrics(
{required String predictorArn}) → Future< GetAccuracyMetricsResponse> - Provides metrics on the accuracy of the models that were trained by the CreatePredictor operation. Use metrics to see how well the model performed and to decide whether to use the predictor to generate a forecast. For more information, see Predictor Metrics.
-
listDatasetGroups(
{int? maxResults, String? nextToken}) → Future< ListDatasetGroupsResponse> - Returns a list of dataset groups created using the CreateDatasetGroup operation. For each dataset group, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the dataset group ARN with the DescribeDatasetGroup operation.
-
listDatasetImportJobs(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListDatasetImportJobsResponse> - Returns a list of dataset import jobs created using the CreateDatasetImportJob operation. For each import job, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the ARN with the DescribeDatasetImportJob operation. You can filter the list by providing an array of Filter objects.
-
listDatasets(
{int? maxResults, String? nextToken}) → Future< ListDatasetsResponse> - Returns a list of datasets created using the CreateDataset operation. For each dataset, a summary of its properties, including its Amazon Resource Name (ARN), is returned. To retrieve the complete set of properties, use the ARN with the DescribeDataset operation.
-
listExplainabilities(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListExplainabilitiesResponse> - Returns a list of Explainability resources created using the CreateExplainability operation. This operation returns a summary for each Explainability. You can filter the list using an array of Filter objects.
-
listExplainabilityExports(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListExplainabilityExportsResponse> - Returns a list of Explainability exports created using the CreateExplainabilityExport operation. This operation returns a summary for each Explainability export. You can filter the list using an array of Filter objects.
-
listForecastExportJobs(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListForecastExportJobsResponse> - Returns a list of forecast export jobs created using the CreateForecastExportJob operation. For each forecast export job, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). To retrieve the complete set of properties, use the ARN with the DescribeForecastExportJob operation. You can filter the list using an array of Filter objects.
-
listForecasts(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListForecastsResponse> - Returns a list of forecasts created using the CreateForecast operation. For each forecast, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). To retrieve the complete set of properties, specify the ARN with the DescribeForecast operation. You can filter the list using an array of Filter objects.
-
listMonitorEvaluations(
{required String monitorArn, List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListMonitorEvaluationsResponse> - Returns a list of the monitoring evaluation results and predictor events collected by the monitor resource during different windows of time.
-
listMonitors(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListMonitorsResponse> - Returns a list of monitors created with the CreateMonitor operation and CreateAutoPredictor operation. For each monitor resource, this operation returns of a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve a complete set of properties of a monitor resource by specify the monitor's ARN in the DescribeMonitor operation.
-
listPredictorBacktestExportJobs(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListPredictorBacktestExportJobsResponse> - Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation. This operation returns a summary for each backtest export job. You can filter the list using an array of Filter objects.
-
listPredictors(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListPredictorsResponse> - Returns a list of predictors created using the CreateAutoPredictor or CreatePredictor operations. For each predictor, this operation returns a summary of its properties, including its Amazon Resource Name (ARN).
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for an Amazon Forecast resource.
-
listWhatIfAnalyses(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListWhatIfAnalysesResponse> - Returns a list of what-if analyses created using the CreateWhatIfAnalysis operation. For each what-if analysis, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the what-if analysis ARN with the DescribeWhatIfAnalysis operation.
-
listWhatIfForecastExports(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListWhatIfForecastExportsResponse> - Returns a list of what-if forecast exports created using the CreateWhatIfForecastExport operation. For each what-if forecast export, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the what-if forecast export ARN with the DescribeWhatIfForecastExport operation.
-
listWhatIfForecasts(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListWhatIfForecastsResponse> - Returns a list of what-if forecasts created using the CreateWhatIfForecast operation. For each what-if forecast, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the what-if forecast ARN with the DescribeWhatIfForecast operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resumeResource(
{required String resourceArn}) → Future< void> - Resumes a stopped monitor resource.
-
stopResource(
{required String resourceArn}) → Future< void> - Stops a resource.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> -
Associates the specified tags to a resource with the specified
resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Deletes the specified tags from a resource.
-
updateDatasetGroup(
{required List< String> datasetArns, required String datasetGroupArn}) → Future<void> - Replaces the datasets in a dataset group with the specified datasets.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited