createExplainability method
Explainability helps you better understand how the attributes in your datasets impact forecast. Amazon Forecast uses a metric called Impact scores to quantify the relative impact of each attribute and determine whether they increase or decrease forecast values.
To enable Forecast Explainability, your predictor must include at least one of the following: related time series, item metadata, or additional datasets like Holidays and the Weather Index.
CreateExplainability accepts either a Predictor ARN or Forecast ARN. To receive aggregated Impact scores for all time series and time points in your datasets, provide a Predictor ARN. To receive Impact scores for specific time series and time points, provide a Forecast ARN.
CreateExplainability with a Predictor ARN The following parameters are required when providing a Predictor ARN:
-
ExplainabilityName- A unique name for the Explainability. -
ResourceArn- The Arn of the predictor. -
TimePointGranularity- Must be set to “ALL”. -
TimeSeriesGranularity- Must be set to “ALL”.
-
DataSource- Only valid when TimeSeriesGranularity is “SPECIFIC”. -
Schema- Only valid when TimeSeriesGranularity is “SPECIFIC”. -
StartDateTime- Only valid when TimePointGranularity is “SPECIFIC”. -
EndDateTime- Only valid when TimePointGranularity is “SPECIFIC”.
-
ExplainabilityName- A unique name for the Explainability. -
ResourceArn- The Arn of the forecast. -
TimePointGranularity- Either “ALL” or “SPECIFIC”. -
TimeSeriesGranularity- Either “ALL” or “SPECIFIC”.
-
DataSource- The S3 location of the CSV file specifying your time series. -
Schema- The Schema defines the attributes and attribute types listed in the Data Source.
-
StartDateTime- The first timestamp in the range of time points. -
EndDateTime- The last timestamp in the range of time points.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceAlreadyExistsException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter explainabilityConfig :
The configuration settings that define the granularity of time series and
time points for the Explainability.
Parameter explainabilityName :
A unique name for the Explainability.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Predictor or Forecast used to create
the Explainability.
Parameter enableVisualization :
Create an Explainability visualization that is viewable within the Amazon
Web Services console.
Parameter endDateTime :
If TimePointGranularity is set to SPECIFIC,
define the last time point for the Explainability.
Use the following timestamp format: yyyy-MM-ddTHH:mm:ss (example: 2015-01-01T20:00:00)
Parameter startDateTime :
If TimePointGranularity is set to SPECIFIC,
define the first point for the Explainability.
Use the following timestamp format: yyyy-MM-ddTHH:mm:ss (example: 2015-01-01T20:00:00)
Parameter tags :
Optional metadata to help you categorize and organize your resources. Each
tag consists of a key and an optional value, both of which you define. Tag
keys and values are case sensitive.
The following restrictions apply to tags:
- For each resource, each tag key must be unique and each tag key must have one value.
- Maximum number of tags per resource: 50.
- Maximum key length: 128 Unicode characters in UTF-8.
- Maximum value length: 256 Unicode characters in UTF-8.
- Accepted characters: all letters and numbers, spaces representable in UTF-8, and + - = . _ : / @. If your tagging schema is used across other services and resources, the character restrictions of those services also apply.
-
Key prefixes cannot include any upper or lowercase combination of
aws:orAWS:. Values can have this prefix. If a tag value hasawsas its prefix but the key does not, Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix ofawsdo not count against your tags per resource limit. You cannot edit or delete tag keys with this prefix.
Implementation
Future<CreateExplainabilityResponse> createExplainability({
required ExplainabilityConfig explainabilityConfig,
required String explainabilityName,
required String resourceArn,
DataSource? dataSource,
bool? enableVisualization,
String? endDateTime,
Schema? schema,
String? startDateTime,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.CreateExplainability'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ExplainabilityConfig': explainabilityConfig,
'ExplainabilityName': explainabilityName,
'ResourceArn': resourceArn,
if (dataSource != null) 'DataSource': dataSource,
if (enableVisualization != null)
'EnableVisualization': enableVisualization,
if (endDateTime != null) 'EndDateTime': endDateTime,
if (schema != null) 'Schema': schema,
if (startDateTime != null) 'StartDateTime': startDateTime,
if (tags != null) 'Tags': tags,
},
);
return CreateExplainabilityResponse.fromJson(jsonResponse.body);
}