createForecast method
Creates a forecast for each item in the TARGET_TIME_SERIES
dataset that was used to train the predictor. This is known as inference.
To retrieve the forecast for a single item at low latency, use the
operation. To export the complete forecast into your Amazon Simple Storage
Service (Amazon S3) bucket, use the CreateForecastExportJob
operation.
The range of the forecast is determined by the
ForecastHorizon value, which you specify in the
CreatePredictor request. When you query a forecast, you can request
a specific date range within the forecast.
To get a list of all your forecasts, use the ListForecasts
operation.
For more information, see howitworks-forecast.
By default, a forecast includes predictions for every item
(item_id) in the dataset group that was used to train the
predictor. However, you can use the TimeSeriesSelector object
to generate a forecast on a subset of time series. Forecast creation is
skipped for any time series that you specify that are not in the input
dataset. The forecast export file will not contain these time series or
their forecasted values.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceAlreadyExistsException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter forecastName :
A name for the forecast.
Parameter predictorArn :
The Amazon Resource Name (ARN) of the predictor to use to generate the
forecast.
Parameter forecastTypes :
The quantiles at which probabilistic forecasts are generated. You can
currently specify up to 5 quantiles per forecast. Accepted values
include 0.01 to 0.99 (increments of .01 only) and
mean. The mean forecast is different from the median (0.50)
when the distribution is not symmetric (for example, Beta and Negative
Binomial).
The default quantiles are the quantiles you specified during predictor
creation. If you didn't specify quantiles, the default values are
["0.1", "0.5", "0.9"].
Parameter tags :
The optional metadata that you apply to the forecast to help you
categorize and organize them. Each tag consists of a key and an optional
value, both of which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50.
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8.
- Maximum value length - 256 Unicode characters in UTF-8.
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value hasawsas its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix ofawsdo not count against your tags per resource limit.
Parameter timeSeriesSelector :
Defines the set of time series that are used to create the forecasts in a
TimeSeriesIdentifiers object.
The TimeSeriesIdentifiers object needs the following
information:
-
DataSource -
Format -
Schema
Implementation
Future<CreateForecastResponse> createForecast({
required String forecastName,
required String predictorArn,
List<String>? forecastTypes,
List<Tag>? tags,
TimeSeriesSelector? timeSeriesSelector,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.CreateForecast'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ForecastName': forecastName,
'PredictorArn': predictorArn,
if (forecastTypes != null) 'ForecastTypes': forecastTypes,
if (tags != null) 'Tags': tags,
if (timeSeriesSelector != null)
'TimeSeriesSelector': timeSeriesSelector,
},
);
return CreateForecastResponse.fromJson(jsonResponse.body);
}