createPredictorBacktestExportJob method
Exports backtest forecasts and accuracy metrics generated by the CreateAutoPredictor or CreatePredictor operations. Two folders containing CSV or Parquet files are exported to your specified S3 bucket.
The export file names will match the following conventions:
The
You must specify a DataDestination object that includes an Amazon S3 bucket and an Identity and Access Management (IAM) role that Amazon Forecast can assume to access the Amazon S3 bucket. For more information, see aws-forecast-iam-roles.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceAlreadyExistsException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter predictorArn :
The Amazon Resource Name (ARN) of the predictor that you want to export.
Parameter predictorBacktestExportJobName :
The name for the backtest export job.
Parameter format :
The format of the exported data, CSV or PARQUET. The default value is CSV.
Parameter tags :
Optional metadata to help you categorize and organize your backtests. Each
tag consists of a key and an optional value, both of which you define. Tag
keys and values are case sensitive.
The following restrictions apply to tags:
- For each resource, each tag key must be unique and each tag key must have one value.
- Maximum number of tags per resource: 50.
- Maximum key length: 128 Unicode characters in UTF-8.
- Maximum value length: 256 Unicode characters in UTF-8.
- Accepted characters: all letters and numbers, spaces representable in UTF-8, and + - = . _ : / @. If your tagging schema is used across other services and resources, the character restrictions of those services also apply.
-
Key prefixes cannot include any upper or lowercase combination of
aws:orAWS:. Values can have this prefix. If a tag value hasawsas its prefix but the key does not, Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix ofawsdo not count against your tags per resource limit. You cannot edit or delete tag keys with this prefix.
Implementation
Future<CreatePredictorBacktestExportJobResponse>
createPredictorBacktestExportJob({
required DataDestination destination,
required String predictorArn,
required String predictorBacktestExportJobName,
String? format,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.CreatePredictorBacktestExportJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Destination': destination,
'PredictorArn': predictorArn,
'PredictorBacktestExportJobName': predictorBacktestExportJobName,
if (format != null) 'Format': format,
if (tags != null) 'Tags': tags,
},
);
return CreatePredictorBacktestExportJobResponse.fromJson(jsonResponse.body);
}