createWhatIfAnalysis method
What-if analysis is a scenario modeling technique where you make a hypothetical change to a time series and compare the forecasts generated by these changes against the baseline, unchanged time series. It is important to remember that the purpose of a what-if analysis is to understand how a forecast can change given different modifications to the baseline time series.
For example, imagine you are a clothing retailer who is considering an end of season sale to clear space for new styles. After creating a baseline forecast, you can use a what-if analysis to investigate how different sales tactics might affect your goals.
You could create a scenario where everything is given a 25% markdown, and another where everything is given a fixed dollar markdown. You could create a scenario where the sale lasts for one week and another where the sale lasts for one month. With a what-if analysis, you can compare many different scenarios against each other.
Note that a what-if analysis is meant to display what the forecasting model has learned and how it will behave in the scenarios that you are evaluating. Do not blindly use the results of the what-if analysis to make business decisions. For instance, forecasts might not be accurate for novel scenarios where there is no reference available to determine whether a forecast is good.
The TimeSeriesSelector object defines the items that you want in the what-if analysis.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceAlreadyExistsException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter forecastArn :
The Amazon Resource Name (ARN) of the baseline forecast.
Parameter whatIfAnalysisName :
The name of the what-if analysis. Each name must be unique.
Parameter tags :
A list of tags
to apply to the what if forecast.
Parameter timeSeriesSelector :
Defines the set of time series that are used in the what-if analysis with
a TimeSeriesIdentifiers object. What-if analyses are
performed only for the time series in this object.
The TimeSeriesIdentifiers object needs the following
information:
-
DataSource -
Format -
Schema
Implementation
Future<CreateWhatIfAnalysisResponse> createWhatIfAnalysis({
required String forecastArn,
required String whatIfAnalysisName,
List<Tag>? tags,
TimeSeriesSelector? timeSeriesSelector,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.CreateWhatIfAnalysis'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ForecastArn': forecastArn,
'WhatIfAnalysisName': whatIfAnalysisName,
if (tags != null) 'Tags': tags,
if (timeSeriesSelector != null)
'TimeSeriesSelector': timeSeriesSelector,
},
);
return CreateWhatIfAnalysisResponse.fromJson(jsonResponse.body);
}