deleteDatasetGroup method
Deletes a dataset group created using the CreateDatasetGroup
operation. You can only delete dataset groups that have a status of
ACTIVE, CREATE_FAILED, or
UPDATE_FAILED. To get the status, use the DescribeDatasetGroup
operation.
This operation deletes only the dataset group, not the datasets in the group.
May throw InvalidInputException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter datasetGroupArn :
The Amazon Resource Name (ARN) of the dataset group to delete.
Implementation
Future<void> deleteDatasetGroup({
required String datasetGroupArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.DeleteDatasetGroup'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatasetGroupArn': datasetGroupArn,
},
);
}