listMonitors method
Returns a list of monitors created with the CreateMonitor operation and CreateAutoPredictor operation. For each monitor resource, this operation returns of a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve a complete set of properties of a monitor resource by specify the monitor's ARN in the DescribeMonitor operation.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter filters :
An array of filters. For each filter, provide a condition and a match
statement. The condition is either IS or IS_NOT,
which specifies whether to include or exclude the resources that match the
statement from the list. The match statement consists of a key and a
value.
Filter properties
-
Condition- The condition to apply. Valid values areISandIS_NOT. -
Key- The name of the parameter to filter on. The only valid value isStatus. -
Value- The value to match.
"Filters": [ { "Condition": "IS", "Key": "Status", "Value":
"ACTIVE" } ]
Parameter maxResults :
The maximum number of monitors to include in the response.
Parameter nextToken :
If the result of the previous request was truncated, the response includes
a NextToken. To retrieve the next set of results, use the
token in the next request. Tokens expire after 24 hours.
Implementation
Future<ListMonitorsResponse> listMonitors({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.ListMonitors'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListMonitorsResponse.fromJson(jsonResponse.body);
}