listPredictorBacktestExportJobs method
Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation. This operation returns a summary for each backtest export job. You can filter the list using an array of Filter objects.
To retrieve the complete set of properties for a particular backtest export job, use the ARN with the DescribePredictorBacktestExportJob operation.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter filters :
An array of filters. For each filter, provide a condition and a match
statement. The condition is either IS or IS_NOT,
which specifies whether to include or exclude the predictor backtest
export jobs that match the statement from the list. The match statement
consists of a key and a value.
Filter properties
-
Condition- The condition to apply. Valid values areISandIS_NOT. To include the predictor backtest export jobs that match the statement, specifyIS. To exclude matching predictor backtest export jobs, specifyIS_NOT. -
Key- The name of the parameter to filter on. Valid values arePredictorArnandStatus. -
Value- The value to match.
Parameter maxResults :
The number of items to return in the response.
Parameter nextToken :
If the result of the previous request was truncated, the response includes
a NextToken. To retrieve the next set of results, use the token in the
next request. Tokens expire after 24 hours.
Implementation
Future<ListPredictorBacktestExportJobsResponse>
listPredictorBacktestExportJobs({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.ListPredictorBacktestExportJobs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListPredictorBacktestExportJobsResponse.fromJson(jsonResponse.body);
}