deleteEvent method
Deletes the specified event.
When you delete an event, Amazon Fraud Detector permanently deletes that
event and the event data is no longer stored in Amazon Fraud Detector. If
deleteAuditHistory is True, event data is
available through search for up to 30 seconds after the delete operation
is completed.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter eventId :
The ID of the event to delete.
Parameter eventTypeName :
The name of the event type.
Parameter deleteAuditHistory :
Specifies whether or not to delete any predictions associated with the
event. If set to True,
Implementation
Future<void> deleteEvent({
required String eventId,
required String eventTypeName,
bool? deleteAuditHistory,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSHawksNestServiceFacade.DeleteEvent'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'eventId': eventId,
'eventTypeName': eventTypeName,
if (deleteAuditHistory != null)
'deleteAuditHistory': deleteAuditHistory,
},
);
}