updateEventLabel method

Future<void> updateEventLabel({
  1. required String assignedLabel,
  2. required String eventId,
  3. required String eventTypeName,
  4. required String labelTimestamp,
})

Updates the specified event with a new label.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter assignedLabel : The new label to assign to the event.

Parameter eventId : The ID of the event associated with the label to update.

Parameter eventTypeName : The event type of the event associated with the label to update.

Parameter labelTimestamp : The timestamp associated with the label. The timestamp must be specified using ISO 8601 standard in UTC.

Implementation

Future<void> updateEventLabel({
  required String assignedLabel,
  required String eventId,
  required String eventTypeName,
  required String labelTimestamp,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSHawksNestServiceFacade.UpdateEventLabel'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'assignedLabel': assignedLabel,
      'eventId': eventId,
      'eventTypeName': eventTypeName,
      'labelTimestamp': labelTimestamp,
    },
  );
}