FreeTier class

You can use the Amazon Web Services Free Tier API to query programmatically your Free Tier usage data.

Free Tier tracks your monthly usage data for all free tier offers that are associated with your Amazon Web Services account. You can use the Free Tier API to filter and show only the data that you want.

Service endpoint

The Free Tier API provides the following endpoint:

Constructors

FreeTier({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getAccountActivity({required String activityId, LanguageCode? languageCode}) Future<GetAccountActivityResponse>
Returns a specific activity record that is available to the customer.
getAccountPlanState() Future<GetAccountPlanStateResponse>
This returns all of the information related to the state of the account plan related to Free Tier.
getFreeTierUsage({Expression? filter, int? maxResults, String? nextToken}) Future<GetFreeTierUsageResponse>
Returns a list of all Free Tier usage objects that match your filters.
listAccountActivities({List<ActivityStatus>? filterActivityStatuses, LanguageCode? languageCode, int? maxResults, String? nextToken}) Future<ListAccountActivitiesResponse>
Returns a list of activities that are available. This operation supports pagination and filtering by status.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upgradeAccountPlan({required AccountPlanType accountPlanType}) Future<UpgradeAccountPlanResponse>
The account plan type for the Amazon Web Services account.

Operators

operator ==(Object other) bool
The equality operator.
inherited