upgradeAccountPlan method

Future<UpgradeAccountPlanResponse> upgradeAccountPlan({
  1. required AccountPlanType accountPlanType,
})

The account plan type for the Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accountPlanType : The target account plan type. This makes it explicit about the change and latest value of the accountPlanType.

Implementation

Future<UpgradeAccountPlanResponse> upgradeAccountPlan({
  required AccountPlanType accountPlanType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSFreeTierService.UpgradeAccountPlan'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'accountPlanType': accountPlanType.value,
    },
  );

  return UpgradeAccountPlanResponse.fromJson(jsonResponse.body);
}