GameLift class

Amazon GameLift Servers provides solutions for hosting session-based multiplayer game servers in the cloud, including tools for deploying, operating, and scaling game servers. Built on Amazon Web Services global computing infrastructure, GameLift helps you deliver high-performance, high-reliability, low-cost game servers while dynamically scaling your resource usage to meet player demand.

About Amazon GameLift Servers solutions

Get more information on these Amazon GameLift Servers solutions in the Amazon GameLift Servers Developer Guide.

  • Amazon GameLift Servers managed hosting -- Amazon GameLift Servers offers a fully managed service to set up and maintain computing machines for hosting, manage game session and player session life cycle, and handle security, storage, and performance tracking. You can use automatic scaling tools to balance player demand and hosting costs, configure your game session management to minimize player latency, and add FlexMatch for matchmaking.
  • Managed hosting with Amazon GameLift Servers Realtime -- With Amazon GameLift Servers Amazon GameLift Servers Realtime, you can quickly configure and set up ready-to-go game servers for your game. Amazon GameLift Servers Realtime provides a game server framework with core Amazon GameLift Servers infrastructure already built in. Then use the full range of Amazon GameLift Servers managed hosting features, including FlexMatch, for your game.
  • Amazon GameLift Servers FleetIQ -- Use Amazon GameLift Servers FleetIQ as a standalone service while hosting your games using EC2 instances and Auto Scaling groups. Amazon GameLift Servers FleetIQ provides optimizations for game hosting, including boosting the viability of low-cost Spot Instances gaming. For a complete solution, pair the Amazon GameLift Servers FleetIQ and FlexMatch standalone services.
  • Amazon GameLift Servers FlexMatch -- Add matchmaking to your game hosting solution. FlexMatch is a customizable matchmaking service for multiplayer games. Use FlexMatch as integrated with Amazon GameLift Servers managed hosting or incorporate FlexMatch as a standalone service into your own hosting solution.
About this API Reference

This reference guide describes the low-level service API for Amazon GameLift Servers. With each topic in this guide, you can find links to language-specific SDK guides and the Amazon Web Services CLI reference. Useful links:

Constructors

GameLift({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptMatch({required AcceptanceType acceptanceType, required List<String> playerIds, required String ticketId}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
claimGameServer({required String gameServerGroupName, ClaimFilterOption? filterOption, String? gameServerData, String? gameServerId}) Future<ClaimGameServerOutput>
This API works with the following fleet types: EC2 (FleetIQ)
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAlias({required String name, required RoutingStrategy routingStrategy, String? description, List<Tag>? tags}) Future<CreateAliasOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createBuild({String? name, OperatingSystem? operatingSystem, String? serverSdkVersion, S3Location? storageLocation, List<Tag>? tags, String? version}) Future<CreateBuildOutput>
This API works with the following fleet types: EC2, Anywhere
createContainerFleet({required String fleetRoleArn, ContainerFleetBillingType? billingType, String? description, String? gameServerContainerGroupDefinitionName, int? gameServerContainerGroupsPerInstance, GameSessionCreationLimitPolicy? gameSessionCreationLimitPolicy, ConnectionPortRange? instanceConnectionPortRange, List<IpPermission>? instanceInboundPermissions, String? instanceType, List<LocationConfiguration>? locations, LogConfiguration? logConfiguration, List<String>? metricGroups, ProtectionPolicy? newGameSessionProtectionPolicy, String? perInstanceContainerGroupDefinitionName, PlayerGatewayMode? playerGatewayMode, List<Tag>? tags}) Future<CreateContainerFleetOutput>
This API works with the following fleet types: Container
createContainerGroupDefinition({required String name, required ContainerOperatingSystem operatingSystem, required int totalMemoryLimitMebibytes, required double totalVcpuLimit, ContainerGroupType? containerGroupType, GameServerContainerDefinitionInput? gameServerContainerDefinition, List<SupportContainerDefinitionInput>? supportContainerDefinitions, List<Tag>? tags, String? versionDescription}) Future<CreateContainerGroupDefinitionOutput>
This API works with the following fleet types: Container
createFleet({required String name, AnywhereConfiguration? anywhereConfiguration, String? buildId, CertificateConfiguration? certificateConfiguration, ComputeType? computeType, String? description, List<IpPermission>? eC2InboundPermissions, EC2InstanceType? eC2InstanceType, FleetType? fleetType, String? instanceRoleArn, InstanceRoleCredentialsProvider? instanceRoleCredentialsProvider, List<LocationConfiguration>? locations, List<String>? logPaths, List<String>? metricGroups, ProtectionPolicy? newGameSessionProtectionPolicy, String? peerVpcAwsAccountId, String? peerVpcId, PlayerGatewayConfiguration? playerGatewayConfiguration, PlayerGatewayMode? playerGatewayMode, ResourceCreationLimitPolicy? resourceCreationLimitPolicy, RuntimeConfiguration? runtimeConfiguration, String? scriptId, String? serverLaunchParameters, String? serverLaunchPath, List<Tag>? tags}) Future<CreateFleetOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createFleetLocations({required String fleetId, required List<LocationConfiguration> locations}) Future<CreateFleetLocationsOutput>
This API works with the following fleet types: EC2, Container
createGameServerGroup({required String gameServerGroupName, required List<InstanceDefinition> instanceDefinitions, required LaunchTemplateSpecification launchTemplate, required int maxSize, required int minSize, required String roleArn, GameServerGroupAutoScalingPolicy? autoScalingPolicy, BalancingStrategy? balancingStrategy, GameServerProtectionPolicy? gameServerProtectionPolicy, List<Tag>? tags, List<String>? vpcSubnets}) Future<CreateGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
createGameSession({required int maximumPlayerSessionCount, String? aliasId, String? creatorId, String? fleetId, List<GameProperty>? gameProperties, String? gameSessionData, String? gameSessionId, String? idempotencyToken, String? location, String? name}) Future<CreateGameSessionOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createGameSessionQueue({required String name, String? customEventData, List<GameSessionQueueDestination>? destinations, FilterConfiguration? filterConfiguration, String? notificationTarget, List<PlayerLatencyPolicy>? playerLatencyPolicies, PriorityConfiguration? priorityConfiguration, List<Tag>? tags, int? timeoutInSeconds}) Future<CreateGameSessionQueueOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createLocation({required String locationName, List<Tag>? tags}) Future<CreateLocationOutput>
This API works with the following fleet types: Anywhere
createMatchmakingConfiguration({required bool acceptanceRequired, required String name, required int requestTimeoutSeconds, required String ruleSetName, int? acceptanceTimeoutSeconds, int? additionalPlayerCount, BackfillMode? backfillMode, String? customEventData, String? description, FlexMatchMode? flexMatchMode, List<GameProperty>? gameProperties, String? gameSessionData, List<String>? gameSessionQueueArns, String? notificationTarget, List<Tag>? tags}) Future<CreateMatchmakingConfigurationOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createMatchmakingRuleSet({required String name, required String ruleSetBody, List<Tag>? tags}) Future<CreateMatchmakingRuleSetOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createPlayerSession({required String gameSessionId, required String playerId, String? playerData}) Future<CreatePlayerSessionOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createPlayerSessions({required String gameSessionId, required List<String> playerIds, Map<String, String>? playerDataMap}) Future<CreatePlayerSessionsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
createScript({String? name, String? nodeJsVersion, S3Location? storageLocation, List<Tag>? tags, String? version, Uint8List? zipFile}) Future<CreateScriptOutput>
This API works with the following fleet types: EC2, Anywhere
createVpcPeeringAuthorization({required String gameLiftAwsAccountId, required String peerVpcId}) Future<CreateVpcPeeringAuthorizationOutput>
This API works with the following fleet types: EC2
createVpcPeeringConnection({required String fleetId, required String peerVpcAwsAccountId, required String peerVpcId}) Future<void>
This API works with the following fleet types: EC2
deleteAlias({required String aliasId}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
deleteBuild({required String buildId}) Future<void>
This API works with the following fleet types: EC2
deleteContainerFleet({required String fleetId}) Future<void>
This API works with the following fleet types: Container
deleteContainerGroupDefinition({required String name, int? versionCountToRetain, int? versionNumber}) Future<void>
This API works with the following fleet types: Container
deleteFleet({required String fleetId}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
deleteFleetLocations({required String fleetId, required List<String> locations}) Future<DeleteFleetLocationsOutput>
This API works with the following fleet types: EC2, Container
deleteGameServerGroup({required String gameServerGroupName, GameServerGroupDeleteOption? deleteOption}) Future<DeleteGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
deleteGameSessionQueue({required String name}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
deleteLocation({required String locationName}) Future<void>
This API works with the following fleet types: Anywhere
deleteMatchmakingConfiguration({required String name}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
deleteMatchmakingRuleSet({required String name}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
deleteScalingPolicy({required String fleetId, required String name}) Future<void>
This API works with the following fleet types: EC2
deleteScript({required String scriptId}) Future<void>
This API works with the following fleet types: EC2
deleteVpcPeeringAuthorization({required String gameLiftAwsAccountId, required String peerVpcId}) Future<void>
This API works with the following fleet types: EC2
deleteVpcPeeringConnection({required String fleetId, required String vpcPeeringConnectionId}) Future<void>
This API works with the following fleet types: EC2
deregisterCompute({required String computeName, required String fleetId}) Future<void>
This API works with the following fleet types: Anywhere
deregisterGameServer({required String gameServerGroupName, required String gameServerId}) Future<void>
This API works with the following fleet types: EC2 (FleetIQ)
describeAlias({required String aliasId}) Future<DescribeAliasOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeBuild({required String buildId}) Future<DescribeBuildOutput>
This API works with the following fleet types: EC2
describeCompute({required String computeName, required String fleetId}) Future<DescribeComputeOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeContainerFleet({required String fleetId}) Future<DescribeContainerFleetOutput>
This API works with the following fleet types: Container
describeContainerGroupDefinition({required String name, int? versionNumber}) Future<DescribeContainerGroupDefinitionOutput>
This API works with the following fleet types: Container
describeContainerGroupPortMappings({required ContainerGroupType containerGroupType, required String fleetId, String? computeName, String? containerName, String? instanceId}) Future<DescribeContainerGroupPortMappingsOutput>
This API works with the following fleet types: Container
describeEC2InstanceLimits({EC2InstanceType? eC2InstanceType, String? location}) Future<DescribeEC2InstanceLimitsOutput>
This API works with the following fleet types: EC2
describeFleetAttributes({List<String>? fleetIds, int? limit, String? nextToken}) Future<DescribeFleetAttributesOutput>
This API works with the following fleet types: EC2, Anywhere
describeFleetCapacity({List<String>? fleetIds, int? limit, String? nextToken}) Future<DescribeFleetCapacityOutput>
This API works with the following fleet types: EC2, Container
describeFleetDeployment({required String fleetId, String? deploymentId}) Future<DescribeFleetDeploymentOutput>
This API works with the following fleet types: Container
describeFleetEvents({required String fleetId, DateTime? endTime, int? limit, String? nextToken, DateTime? startTime}) Future<DescribeFleetEventsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeFleetLocationAttributes({required String fleetId, int? limit, List<String>? locations, String? nextToken}) Future<DescribeFleetLocationAttributesOutput>
This API works with the following fleet types: EC2, Container
describeFleetLocationCapacity({required String fleetId, required String location}) Future<DescribeFleetLocationCapacityOutput>
This API works with the following fleet types: EC2, Container
describeFleetLocationUtilization({required String fleetId, required String location}) Future<DescribeFleetLocationUtilizationOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeFleetPortSettings({required String fleetId, String? location}) Future<DescribeFleetPortSettingsOutput>
This API works with the following fleet types: EC2, Container
describeFleetUtilization({List<String>? fleetIds, int? limit, String? nextToken}) Future<DescribeFleetUtilizationOutput>
This API works with the following fleet types: EC2, Container
describeGameServer({required String gameServerGroupName, required String gameServerId}) Future<DescribeGameServerOutput>
This API works with the following fleet types: EC2 (FleetIQ)
describeGameServerGroup({required String gameServerGroupName}) Future<DescribeGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
describeGameServerInstances({required String gameServerGroupName, List<String>? instanceIds, int? limit, String? nextToken}) Future<DescribeGameServerInstancesOutput>
This API works with the following fleet types: EC2 (FleetIQ)
describeGameSessionDetails({String? aliasId, String? fleetId, String? gameSessionId, int? limit, String? location, String? nextToken, String? statusFilter}) Future<DescribeGameSessionDetailsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeGameSessionPlacement({required String placementId}) Future<DescribeGameSessionPlacementOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeGameSessionQueues({int? limit, List<String>? names, String? nextToken}) Future<DescribeGameSessionQueuesOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeGameSessions({String? aliasId, String? fleetId, String? gameSessionId, int? limit, String? location, String? nextToken, String? statusFilter}) Future<DescribeGameSessionsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeInstances({required String fleetId, String? instanceId, int? limit, String? location, String? nextToken}) Future<DescribeInstancesOutput>
This API works with the following fleet types:EC2, Container
describeMatchmaking({required List<String> ticketIds}) Future<DescribeMatchmakingOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeMatchmakingConfigurations({int? limit, List<String>? names, String? nextToken, String? ruleSetName}) Future<DescribeMatchmakingConfigurationsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeMatchmakingRuleSets({int? limit, List<String>? names, String? nextToken}) Future<DescribeMatchmakingRuleSetsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describePlayerSessions({String? gameSessionId, int? limit, String? nextToken, String? playerId, String? playerSessionId, String? playerSessionStatusFilter}) Future<DescribePlayerSessionsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
describeRuntimeConfiguration({required String fleetId}) Future<DescribeRuntimeConfigurationOutput>
This API works with the following fleet types: EC2
describeScalingPolicies({required String fleetId, int? limit, String? location, String? nextToken, ScalingStatusType? statusFilter}) Future<DescribeScalingPoliciesOutput>
This API works with the following fleet types: EC2
describeScript({required String scriptId}) Future<DescribeScriptOutput>
This API works with the following fleet types: EC2
describeVpcPeeringAuthorizations() Future<DescribeVpcPeeringAuthorizationsOutput>
This API works with the following fleet types: EC2
describeVpcPeeringConnections({String? fleetId}) Future<DescribeVpcPeeringConnectionsOutput>
This API works with the following fleet types: EC2
getComputeAccess({required String computeName, required String fleetId}) Future<GetComputeAccessOutput>
This API works with the following fleet types: EC2, Container
getComputeAuthToken({required String computeName, required String fleetId}) Future<GetComputeAuthTokenOutput>
This API works with the following fleet types: EC2, Anywhere, Container
getGameSessionLogUrl({required String gameSessionId}) Future<GetGameSessionLogUrlOutput>
This API works with the following fleet types: EC2
getInstanceAccess({required String fleetId, required String instanceId}) Future<GetInstanceAccessOutput>
This API works with the following fleet types: EC2
getPlayerConnectionDetails({required String gameSessionId, required List<String> playerIds}) Future<GetPlayerConnectionDetailsOutput>
This API works with the following fleet types: EC2 (server SDK 5.x or later), Container
listAliases({int? limit, String? name, String? nextToken, RoutingStrategyType? routingStrategyType}) Future<ListAliasesOutput>
This API works with the following fleet types: EC2, Anywhere, Container
listBuilds({int? limit, String? nextToken, BuildStatus? status}) Future<ListBuildsOutput>
This API works with the following fleet types: EC2
listCompute({required String fleetId, ListComputeInputStatus? computeStatus, String? containerGroupDefinitionName, int? limit, String? location, String? nextToken}) Future<ListComputeOutput>
This API works with the following fleet types: EC2, Anywhere, Container
listContainerFleets({String? containerGroupDefinitionName, int? limit, String? nextToken}) Future<ListContainerFleetsOutput>
This API works with the following fleet types: Container
listContainerGroupDefinitions({ContainerGroupType? containerGroupType, int? limit, String? nextToken}) Future<ListContainerGroupDefinitionsOutput>
This API works with the following fleet types: Container
listContainerGroupDefinitionVersions({required String name, int? limit, String? nextToken}) Future<ListContainerGroupDefinitionVersionsOutput>
This API works with the following fleet types: Container
listFleetDeployments({String? fleetId, int? limit, String? nextToken}) Future<ListFleetDeploymentsOutput>
This API works with the following fleet types: Container
listFleets({String? buildId, int? limit, String? nextToken, String? scriptId}) Future<ListFleetsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
listGameServerGroups({int? limit, String? nextToken}) Future<ListGameServerGroupsOutput>
This API works with the following fleet types: EC2 (FleetIQ)
listGameServers({required String gameServerGroupName, int? limit, String? nextToken, SortOrder? sortOrder}) Future<ListGameServersOutput>
This API works with the following fleet types: EC2 (FleetIQ)
listLocations({List<LocationFilter>? filters, int? limit, String? nextToken}) Future<ListLocationsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
listScripts({int? limit, String? nextToken}) Future<ListScriptsOutput>
This API works with the following fleet types: EC2
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
This API works with the following fleet types: EC2, Anywhere, Container
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putScalingPolicy({required String fleetId, required MetricName metricName, required String name, ComparisonOperatorType? comparisonOperator, int? evaluationPeriods, PolicyType? policyType, int? scalingAdjustment, ScalingAdjustmentType? scalingAdjustmentType, TargetConfiguration? targetConfiguration, double? threshold}) Future<PutScalingPolicyOutput>
This API works with the following fleet types: EC2
registerCompute({required String computeName, required String fleetId, String? certificatePath, String? dnsName, String? ipAddress, String? location}) Future<RegisterComputeOutput>
This API works with the following fleet types: Anywhere, Container
registerGameServer({required String gameServerGroupName, required String gameServerId, required String instanceId, String? connectionInfo, String? gameServerData}) Future<RegisterGameServerOutput>
This API works with the following fleet types: EC2 (FleetIQ)
requestUploadCredentials({required String buildId}) Future<RequestUploadCredentialsOutput>
This API works with the following fleet types: EC2
resolveAlias({required String aliasId}) Future<ResolveAliasOutput>
This API works with the following fleet types: EC2, Anywhere, Container
resumeGameServerGroup({required String gameServerGroupName, required List<GameServerGroupAction> resumeActions}) Future<ResumeGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
searchGameSessions({String? aliasId, String? filterExpression, String? fleetId, int? limit, String? location, String? nextToken, String? sortExpression}) Future<SearchGameSessionsOutput>
This API works with the following fleet types: EC2, Anywhere, Container
startFleetActions({required List<FleetAction> actions, required String fleetId, String? location}) Future<StartFleetActionsOutput>
This API works with the following fleet types: EC2, Container
startGameSessionPlacement({required String gameSessionQueueName, required int maximumPlayerSessionCount, required String placementId, List<DesiredPlayerSession>? desiredPlayerSessions, List<GameProperty>? gameProperties, String? gameSessionData, String? gameSessionName, List<PlayerLatency>? playerLatencies, PriorityConfigurationOverride? priorityConfigurationOverride}) Future<StartGameSessionPlacementOutput>
This API works with the following fleet types: EC2, Anywhere, Container
startMatchBackfill({required String configurationName, required List<Player> players, String? gameSessionArn, String? ticketId}) Future<StartMatchBackfillOutput>
This API works with the following fleet types: EC2, Anywhere, Container
startMatchmaking({required String configurationName, required List<Player> players, String? ticketId}) Future<StartMatchmakingOutput>
This API works with the following fleet types: EC2, Anywhere, Container
stopFleetActions({required List<FleetAction> actions, required String fleetId, String? location}) Future<StopFleetActionsOutput>
This API works with the following fleet types: EC2, Container
stopGameSessionPlacement({required String placementId}) Future<StopGameSessionPlacementOutput>
This API works with the following fleet types: EC2, Anywhere, Container
stopMatchmaking({required String ticketId}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
suspendGameServerGroup({required String gameServerGroupName, required List<GameServerGroupAction> suspendActions}) Future<SuspendGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
terminateGameSession({required String gameSessionId, required TerminationMode terminationMode}) Future<TerminateGameSessionOutput>
This API works with the following fleet types: EC2, Anywhere, Container
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
This API works with the following fleet types: EC2, Anywhere, Container
updateAlias({required String aliasId, String? description, String? name, RoutingStrategy? routingStrategy}) Future<UpdateAliasOutput>
This API works with the following fleet types: EC2, Anywhere, Container
updateBuild({required String buildId, String? name, String? version}) Future<UpdateBuildOutput>
This API works with the following fleet types: EC2
updateContainerFleet({required String fleetId, DeploymentConfiguration? deploymentConfiguration, String? description, String? gameServerContainerGroupDefinitionName, int? gameServerContainerGroupsPerInstance, GameSessionCreationLimitPolicy? gameSessionCreationLimitPolicy, ConnectionPortRange? instanceConnectionPortRange, List<IpPermission>? instanceInboundPermissionAuthorizations, List<IpPermission>? instanceInboundPermissionRevocations, LogConfiguration? logConfiguration, List<String>? metricGroups, ProtectionPolicy? newGameSessionProtectionPolicy, String? perInstanceContainerGroupDefinitionName, List<ContainerFleetRemoveAttribute>? removeAttributes}) Future<UpdateContainerFleetOutput>
This API works with the following fleet types: Container
updateContainerGroupDefinition({required String name, GameServerContainerDefinitionInput? gameServerContainerDefinition, ContainerOperatingSystem? operatingSystem, int? sourceVersionNumber, List<SupportContainerDefinitionInput>? supportContainerDefinitions, int? totalMemoryLimitMebibytes, double? totalVcpuLimit, String? versionDescription}) Future<UpdateContainerGroupDefinitionOutput>
This API works with the following fleet types: Container
updateFleetAttributes({required String fleetId, AnywhereConfiguration? anywhereConfiguration, String? description, List<String>? metricGroups, String? name, ProtectionPolicy? newGameSessionProtectionPolicy, ResourceCreationLimitPolicy? resourceCreationLimitPolicy}) Future<UpdateFleetAttributesOutput>
This API works with the following fleet types: EC2, Anywhere, Container
updateFleetCapacity({required String fleetId, int? desiredInstances, String? location, ManagedCapacityConfiguration? managedCapacityConfiguration, int? maxSize, int? minSize}) Future<UpdateFleetCapacityOutput>
This API works with the following fleet types: EC2, Container
updateFleetPortSettings({required String fleetId, List<IpPermission>? inboundPermissionAuthorizations, List<IpPermission>? inboundPermissionRevocations}) Future<UpdateFleetPortSettingsOutput>
This API works with the following fleet types: EC2, Container
updateGameServer({required String gameServerGroupName, required String gameServerId, String? gameServerData, GameServerHealthCheck? healthCheck, GameServerUtilizationStatus? utilizationStatus}) Future<UpdateGameServerOutput>
This API works with the following fleet types: EC2 (FleetIQ)
updateGameServerGroup({required String gameServerGroupName, BalancingStrategy? balancingStrategy, GameServerProtectionPolicy? gameServerProtectionPolicy, List<InstanceDefinition>? instanceDefinitions, String? roleArn}) Future<UpdateGameServerGroupOutput>
This API works with the following fleet types: EC2 (FleetIQ)
updateGameSession({required String gameSessionId, List<GameProperty>? gameProperties, int? maximumPlayerSessionCount, String? name, PlayerSessionCreationPolicy? playerSessionCreationPolicy, ProtectionPolicy? protectionPolicy}) Future<UpdateGameSessionOutput>
This API works with the following fleet types: EC2, Anywhere, Container
updateGameSessionQueue({required String name, String? customEventData, List<GameSessionQueueDestination>? destinations, FilterConfiguration? filterConfiguration, String? notificationTarget, List<PlayerLatencyPolicy>? playerLatencyPolicies, PriorityConfiguration? priorityConfiguration, int? timeoutInSeconds}) Future<UpdateGameSessionQueueOutput>
This API works with the following fleet types: EC2, Anywhere, Container
updateMatchmakingConfiguration({required String name, bool? acceptanceRequired, int? acceptanceTimeoutSeconds, int? additionalPlayerCount, BackfillMode? backfillMode, String? customEventData, String? description, FlexMatchMode? flexMatchMode, List<GameProperty>? gameProperties, String? gameSessionData, List<String>? gameSessionQueueArns, String? notificationTarget, int? requestTimeoutSeconds, String? ruleSetName}) Future<UpdateMatchmakingConfigurationOutput>
This API works with the following fleet types: EC2, Anywhere, Container
updateRuntimeConfiguration({required String fleetId, required RuntimeConfiguration runtimeConfiguration}) Future<UpdateRuntimeConfigurationOutput>
This API works with the following fleet types: EC2
updateScript({required String scriptId, String? name, S3Location? storageLocation, String? version, Uint8List? zipFile}) Future<UpdateScriptOutput>
This API works with the following fleet types: EC2
validateMatchmakingRuleSet({required String ruleSetBody}) Future<ValidateMatchmakingRuleSetOutput>
This API works with the following fleet types: EC2, Anywhere, Container

Operators

operator ==(Object other) bool
The equality operator.
inherited