createContainerFleet method
- required String fleetRoleArn,
- ContainerFleetBillingType? billingType,
- String? description,
- String? gameServerContainerGroupDefinitionName,
- int? gameServerContainerGroupsPerInstance,
- GameSessionCreationLimitPolicy? gameSessionCreationLimitPolicy,
- ConnectionPortRange? instanceConnectionPortRange,
- List<
IpPermission> ? instanceInboundPermissions, - String? instanceType,
- List<
LocationConfiguration> ? locations, - LogConfiguration? logConfiguration,
- List<
String> ? metricGroups, - ProtectionPolicy? newGameSessionProtectionPolicy,
- String? perInstanceContainerGroupDefinitionName,
- PlayerGatewayMode? playerGatewayMode,
- List<
Tag> ? tags,
This API works with the following fleet types: Container
Creates a managed fleet of Amazon Elastic Compute Cloud (Amazon EC2) instances to host your containerized game servers. Use this operation to define how to deploy a container architecture onto each fleet instance and configure fleet settings. You can create a container fleet in any Amazon Web Services Regions that Amazon GameLift Servers supports for multi-location fleets. A container fleet can be deployed to a single location or multiple locations. Container fleets are deployed with Amazon Linux 2023 as the instance operating system.
Define the fleet's container architecture using container group definitions. Each fleet can have one of the following container group types:
- The game server container group runs your game server build and dependent software. Amazon GameLift Servers deploys one or more replicas of this container group to each fleet instance. The number of replicas depends on the computing capabilities of the fleet instance in use.
- An optional per-instance container group might be used to run other software that only needs to run once per instance, such as background services, logging, or test processes. One per-instance container group is deployed to each fleet instance.
Request options
Use this operation to make the following types of requests. Most fleet settings have default values, so you can create a working fleet with a minimal configuration and default values, which you can customize later.
-
Create a fleet with no container groups. You can configure a container
fleet and then add container group definitions later. In this scenario, no
fleet instances are deployed, and the fleet can't host game sessions until
you add a game server container group definition. Provide the following
required parameter values:
-
FleetRoleArn
-
-
Create a fleet with a game server container group. Provide the following
required parameter values:
-
FleetRoleArn -
GameServerContainerGroupDefinitionName
-
-
Create a fleet with a game server container group and a per-instance
container group. Provide the following required parameter values:
-
FleetRoleArn -
GameServerContainerGroupDefinitionName -
PerInstanceContainerGroupDefinitionName
-
If successful, this operation creates a new container fleet resource,
places it in PENDING status, and initiates the fleet
creation workflow. For fleets with container groups, this workflow
starts a fleet deployment and transitions the status to
ACTIVE. Fleets without a container group are placed in
CREATED status.
You can update most of the properties of a fleet, including container group definitions, and deploy the update across all fleet instances. Use UpdateContainerFleet to deploy a new game server version update across the container fleet.
May throw ConflictException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw TaggingFailedException.
May throw UnauthorizedException.
May throw UnsupportedRegionException.
Parameter fleetRoleArn :
The unique identifier for an Identity and Access Management (IAM) role
with permissions to run your containers on resources that are managed by
Amazon GameLift Servers. Use an IAM service role with the
GameLiftContainerFleetPolicy managed policy attached. For
more information, see Set
up an IAM service role. You can't change this fleet property after the
fleet is created.
IAM role ARN values use the following pattern: arn:aws:iam::[Amazon
Web Services account]:role/[role name].
Parameter billingType :
Indicates whether to use On-Demand or Spot instances for this fleet. Learn
more about when to use
On-Demand versus Spot Instances. This fleet property can't be changed
after the fleet is created.
By default, this property is set to ON_DEMAND.
You can't update this fleet property later.
Parameter description :
A meaningful description of the container fleet.
Parameter gameServerContainerGroupDefinitionName :
A container group definition resource that describes how to deploy
containers with your game server build and support software onto each
fleet instance. You can specify the container group definition's name to
use the latest version. Alternatively, provide an ARN value with a
specific version number.
Create a container group definition by calling CreateContainerGroupDefinition. This operation creates a ContainerGroupDefinition resource.
Parameter gameServerContainerGroupsPerInstance :
The number of times to replicate the game server container group on each
fleet instance.
By default, Amazon GameLift Servers calculates the maximum number of game server container groups that can fit on each instance. This calculation is based on the CPU and memory resources of the fleet's instance type). To use the calculated maximum, don't set this parameter. If you set this number manually, Amazon GameLift Servers uses your value as long as it's less than the calculated maximum.
Parameter gameSessionCreationLimitPolicy :
A policy that limits the number of game sessions that each individual
player can create on instances in this fleet. The limit applies for a
specified span of time.
Parameter instanceConnectionPortRange :
The set of port numbers to open on each fleet instance. A fleet's
connection ports map to container ports that are configured in the fleet's
container group definitions.
By default, Amazon GameLift Servers calculates an optimal port range based on your fleet configuration. To use the calculated range, don't set this parameter. The values are:
-
Port range: 4192 to a number calculated based on your fleet configuration.
Amazon GameLift Servers uses the following formula:
4192 + \[# of game server container groups per fleet instance\] * \[# of container ports in the game server container group definition\] + \[# of container ports in the game server container group definition\]
4092-4191. This range is reserved for internal
Amazon GameLift Servers services.
Parameter instanceInboundPermissions :
The IP address ranges and port settings that allow inbound traffic to
access game server processes and other processes on this fleet. As a best
practice, when remotely accessing a fleet instance, we recommend opening
ports only when you need them and closing them when you're finished.
By default, Amazon GameLift Servers calculates an optimal port range based on your fleet configuration. To use the calculated range, don't set this parameter. The values are:
- Protocol: UDP
-
Port range: 4192 to a number calculated based on your fleet configuration.
Amazon GameLift Servers uses the following formula:
4192 + \[# of game server container groups per fleet instance\] * \[# of container ports in the game server container group definition\] + \[# of container ports in the game server container group definition\]
4092-4191. This range is reserved for internal
Amazon GameLift Servers services.
Parameter instanceType :
The Amazon EC2 instance type to use for all instances in the fleet. For
multi-location fleets, the instance type must be available in the home
region and all remote locations. Instance type determines the computing
resources and processing power that's available to host your game servers.
This includes including CPU, memory, storage, and networking capacity.
By default, Amazon GameLift Servers selects an instance type that fits the needs of your container groups and is available in all selected fleet locations. You can also choose to manually set this parameter. See Amazon Elastic Compute Cloud Instance Types for detailed descriptions of Amazon EC2 instance types.
You can't update this fleet property later.
Parameter locations :
A set of locations to deploy container fleet instances to. You can add any
Amazon Web Services Region or Local Zone that's supported by Amazon
GameLift Servers. Provide a list of one or more Amazon Web Services Region
codes, such as us-west-2, or Local Zone names. Also include
the fleet's home Region, which is the Amazon Web Services Region where the
fleet is created. For a list of supported Regions and Local Zones, see
Amazon GameLift Servers service locations for managed hosting.
Parameter logConfiguration :
A method for collecting container logs for the fleet. Amazon GameLift
Servers saves all standard output for each container in logs, including
game session logs. You can select from the following methods:
-
CLOUDWATCH-- Send logs to an Amazon CloudWatch log group that you define. Each container emits a log stream, which is organized in the log group. -
S3-- Store logs in an Amazon S3 bucket that you define. -
NONE-- Don't collect container logs.
CLOUDWATCH.
Amazon GameLift Servers requires permissions to send logs other Amazon Web
Services services in your account. These permissions are included in the
IAM fleet role for this container fleet (see FleetRoleArn).
Parameter metricGroups :
The name of an Amazon Web Services CloudWatch metric group to add this
fleet to. You can use a metric group to aggregate metrics for multiple
fleets. You can specify an existing metric group name or use a new name to
create a new metric group. Each fleet can have only one metric group, but
you can change this value at any time.
Parameter newGameSessionProtectionPolicy :
Determines whether Amazon GameLift Servers can shut down game sessions on
the fleet that are actively running and hosting players. Amazon GameLift
Servers might prompt an instance shutdown when scaling down fleet capacity
or when retiring unhealthy instances. You can also set game session
protection for individual game sessions using UpdateGameSession.
- NoProtection -- Game sessions can be shut down during active gameplay.
-
FullProtection -- Game sessions in
ACTIVEstatus can't be shut down.
NoProtection.
Parameter perInstanceContainerGroupDefinitionName :
The name of a container group definition resource that describes a set of
axillary software. A fleet instance has one process for executables in
this container group. A per-instance container group is optional. You can
update the fleet to add or remove a per-instance container group at any
time. You can specify the container group definition's name to use the
latest version. Alternatively, provide an ARN value with a specific
version number.
Create a container group definition by calling https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateContainerGroupDefinition.html. This operation creates a https://docs.aws.amazon.com/gamelift/latest/apireference/API_ContainerGroupDefinition.html resource.
Parameter playerGatewayMode :
Configures player gateway for your fleet. Player gateway provides benefits
such as DDoS protection by rate limiting and validating traffic before it
reaches game servers, hiding game server IP addresses from players, and
providing updated endpoints when relay endpoints become unhealthy.
How it works: When enabled, game clients connect to relay endpoints instead of to your game servers. Player gateway validates player gateway tokens and routes traffic to the appropriate game server. Your game backend calls GetPlayerConnectionDetails to retrieve relay endpoints and player gateway tokens for your game clients. To learn more about this topic, see DDoS protection with Amazon GameLift Servers player gateway.
Possible values include:
-
DISABLED(default) -- Game clients connect to the game server endpoint. Use this when you do not intend to integrate your game with player gateway. -
ENABLED-- Player gateway is available in fleet locations where it is supported. Your game backend can call GetPlayerConnectionDetails to obtain a player gateway token and endpoints for game clients. -
REQUIRED-- Player gateway is available in fleet locations where it is supported, and the fleet can only use locations that support this feature. Attempting to add a remote location to your fleet which does not support player gateway will result in anInvalidRequestException.
Parameter tags :
A list of labels to assign to the new fleet resource. Tags are
developer-defined key-value pairs. Tagging Amazon Web Services resources
are useful for resource management, access management and cost allocation.
For more information, see
Tagging Amazon Web Services Resources in the Amazon Web Services
General Reference.
Implementation
Future<CreateContainerFleetOutput> createContainerFleet({
required String fleetRoleArn,
ContainerFleetBillingType? billingType,
String? description,
String? gameServerContainerGroupDefinitionName,
int? gameServerContainerGroupsPerInstance,
GameSessionCreationLimitPolicy? gameSessionCreationLimitPolicy,
ConnectionPortRange? instanceConnectionPortRange,
List<IpPermission>? instanceInboundPermissions,
String? instanceType,
List<LocationConfiguration>? locations,
LogConfiguration? logConfiguration,
List<String>? metricGroups,
ProtectionPolicy? newGameSessionProtectionPolicy,
String? perInstanceContainerGroupDefinitionName,
PlayerGatewayMode? playerGatewayMode,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'gameServerContainerGroupsPerInstance',
gameServerContainerGroupsPerInstance,
1,
5000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.CreateContainerFleet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FleetRoleArn': fleetRoleArn,
if (billingType != null) 'BillingType': billingType.value,
if (description != null) 'Description': description,
if (gameServerContainerGroupDefinitionName != null)
'GameServerContainerGroupDefinitionName':
gameServerContainerGroupDefinitionName,
if (gameServerContainerGroupsPerInstance != null)
'GameServerContainerGroupsPerInstance':
gameServerContainerGroupsPerInstance,
if (gameSessionCreationLimitPolicy != null)
'GameSessionCreationLimitPolicy': gameSessionCreationLimitPolicy,
if (instanceConnectionPortRange != null)
'InstanceConnectionPortRange': instanceConnectionPortRange,
if (instanceInboundPermissions != null)
'InstanceInboundPermissions': instanceInboundPermissions,
if (instanceType != null) 'InstanceType': instanceType,
if (locations != null) 'Locations': locations,
if (logConfiguration != null) 'LogConfiguration': logConfiguration,
if (metricGroups != null) 'MetricGroups': metricGroups,
if (newGameSessionProtectionPolicy != null)
'NewGameSessionProtectionPolicy':
newGameSessionProtectionPolicy.value,
if (perInstanceContainerGroupDefinitionName != null)
'PerInstanceContainerGroupDefinitionName':
perInstanceContainerGroupDefinitionName,
if (playerGatewayMode != null)
'PlayerGatewayMode': playerGatewayMode.value,
if (tags != null) 'Tags': tags,
},
);
return CreateContainerFleetOutput.fromJson(jsonResponse.body);
}