createGameServerGroup method
- required String gameServerGroupName,
- required List<
InstanceDefinition> instanceDefinitions, - required LaunchTemplateSpecification launchTemplate,
- required int maxSize,
- required int minSize,
- required String roleArn,
- GameServerGroupAutoScalingPolicy? autoScalingPolicy,
- BalancingStrategy? balancingStrategy,
- GameServerProtectionPolicy? gameServerProtectionPolicy,
- List<
Tag> ? tags, - List<
String> ? vpcSubnets,
This API works with the following fleet types: EC2 (FleetIQ)
Creates a Amazon GameLift Servers FleetIQ game server group for managing game hosting on a collection of Amazon Elastic Compute Cloud instances for game hosting. This operation creates the game server group, creates an Auto Scaling group in your Amazon Web Services account, and establishes a link between the two groups. You can view the status of your game server groups in the Amazon GameLift Servers console. Game server group metrics and events are emitted to Amazon CloudWatch.
Before creating a new game server group, you must have the following:
- An Amazon Elastic Compute Cloud launch template that specifies how to launch Amazon Elastic Compute Cloud instances with your game server build. For more information, see Launching an Instance from a Launch Template in the Amazon Elastic Compute Cloud User Guide.
- An IAM role that extends limited access to your Amazon Web Services account to allow Amazon GameLift Servers FleetIQ to create and interact with the Auto Scaling group. For more information, see Create IAM roles for cross-service interaction in the Amazon GameLift Servers FleetIQ Developer Guide.
Once the game server group and corresponding Auto Scaling group are created, you have full access to change the Auto Scaling group's configuration as needed. Several properties that are set when creating a game server group, including maximum/minimum size and auto-scaling policy settings, must be updated directly in the Auto Scaling group. Keep in mind that some Auto Scaling group properties are periodically updated by Amazon GameLift Servers FleetIQ as part of its balancing activities to optimize for availability and cost.
Learn more
Amazon GameLift Servers FleetIQ Guide
May throw ConflictException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw UnauthorizedException.
Parameter gameServerGroupName :
An identifier for the new game server group. This value is used to
generate unique ARN identifiers for the Amazon EC2 Auto Scaling group and
the Amazon GameLift Servers FleetIQ game server group. The name must be
unique per Region per Amazon Web Services account.
Parameter instanceDefinitions :
The Amazon EC2 instance types and sizes to use in the Auto Scaling group.
The instance definitions must specify at least two different instance
types that are supported by Amazon GameLift Servers FleetIQ. For more
information on instance types, see EC2
Instance Types in the Amazon Elastic Compute Cloud User Guide.
You can optionally specify capacity weighting for each instance type. If
no weight value is specified for an instance type, it is set to the
default value "1". For more information about capacity weighting, see
Instance Weighting for Amazon EC2 Auto Scaling in the Amazon EC2 Auto
Scaling User Guide.
Parameter launchTemplate :
The Amazon EC2 launch template that contains configuration settings and
game server code to be deployed to all instances in the game server group.
You can specify the template using either the template name or ID. For
help with creating a launch template, see Creating
a Launch Template for an Auto Scaling Group in the Amazon Elastic
Compute Cloud Auto Scaling User Guide. After the Auto Scaling group is
created, update this value directly in the Auto Scaling group using the
Amazon Web Services console or APIs.
Parameter maxSize :
The maximum number of instances allowed in the Amazon EC2 Auto Scaling
group. During automatic scaling events, Amazon GameLift Servers FleetIQ
and EC2 do not scale up the group above this maximum. After the Auto
Scaling group is created, update this value directly in the Auto Scaling
group using the Amazon Web Services console or APIs.
Parameter minSize :
The minimum number of instances allowed in the Amazon EC2 Auto Scaling
group. During automatic scaling events, Amazon GameLift Servers FleetIQ
and Amazon EC2 do not scale down the group below this minimum. In
production, this value should be set to at least 1. After the Auto Scaling
group is created, update this value directly in the Auto Scaling group
using the Amazon Web Services console or APIs.
Parameter roleArn :
The Amazon Resource Name (ARN)
for an IAM role that allows Amazon GameLift Servers to access your Amazon
EC2 Auto Scaling groups.
Parameter autoScalingPolicy :
Configuration settings to define a scaling policy for the Auto Scaling
group that is optimized for game hosting. The scaling policy uses the
metric "PercentUtilizedGameServers" to maintain a buffer of
idle game servers that can immediately accommodate new games and players.
After the Auto Scaling group is created, update this value directly in the
Auto Scaling group using the Amazon Web Services console or APIs.
Parameter balancingStrategy :
Indicates how Amazon GameLift Servers FleetIQ balances the use of Spot
Instances and On-Demand Instances in the game server group. Method options
include the following:
-
SPOT_ONLY- Only Spot Instances are used in the game server group. If Spot Instances are unavailable or not viable for game hosting, the game server group provides no hosting capacity until Spot Instances can again be used. Until then, no new instances are started, and the existing nonviable Spot Instances are terminated (after current gameplay ends) and are not replaced. -
SPOT_PREFERRED- (default value) Spot Instances are used whenever available in the game server group. If Spot Instances are unavailable, the game server group continues to provide hosting capacity by falling back to On-Demand Instances. Existing nonviable Spot Instances are terminated (after current gameplay ends) and are replaced with new On-Demand Instances. -
ON_DEMAND_ONLY- Only On-Demand Instances are used in the game server group. No Spot Instances are used, even when available, while this balancing strategy is in force.
Parameter gameServerProtectionPolicy :
A flag that indicates whether instances in the game server group are
protected from early termination. Unprotected instances that have active
game servers running might be terminated during a scale-down event,
causing players to be dropped from the game. Protected instances cannot be
terminated while there are active game servers running except in the event
of a forced game server group deletion (see ). An exception to this is
with Spot Instances, which can be terminated by Amazon Web Services
regardless of protection status. This property is set to
NO_PROTECTION by default.
Parameter tags :
A list of labels to assign to the new game server group resource. Tags are
developer-defined key-value pairs. Tagging Amazon Web Services resources
is useful for resource management, access management, and cost allocation.
For more information, see
Tagging Amazon Web Services Resources in the Amazon Web Services
General Reference.
Parameter vpcSubnets :
A list of virtual private cloud (VPC) subnets to use with instances in the
game server group. By default, all Amazon GameLift Servers
FleetIQ-supported Availability Zones are used. You can use this parameter
to specify VPCs that you've set up. This property cannot be updated after
the game server group is created, and the corresponding Auto Scaling group
will always use the property value that is set with this request, even if
the Auto Scaling group is updated directly.
Implementation
Future<CreateGameServerGroupOutput> createGameServerGroup({
required String gameServerGroupName,
required List<InstanceDefinition> instanceDefinitions,
required LaunchTemplateSpecification launchTemplate,
required int maxSize,
required int minSize,
required String roleArn,
GameServerGroupAutoScalingPolicy? autoScalingPolicy,
BalancingStrategy? balancingStrategy,
GameServerProtectionPolicy? gameServerProtectionPolicy,
List<Tag>? tags,
List<String>? vpcSubnets,
}) async {
_s.validateNumRange(
'maxSize',
maxSize,
1,
1152921504606846976,
isRequired: true,
);
_s.validateNumRange(
'minSize',
minSize,
0,
1152921504606846976,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.CreateGameServerGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GameServerGroupName': gameServerGroupName,
'InstanceDefinitions': instanceDefinitions,
'LaunchTemplate': launchTemplate,
'MaxSize': maxSize,
'MinSize': minSize,
'RoleArn': roleArn,
if (autoScalingPolicy != null) 'AutoScalingPolicy': autoScalingPolicy,
if (balancingStrategy != null)
'BalancingStrategy': balancingStrategy.value,
if (gameServerProtectionPolicy != null)
'GameServerProtectionPolicy': gameServerProtectionPolicy.value,
if (tags != null) 'Tags': tags,
if (vpcSubnets != null) 'VpcSubnets': vpcSubnets,
},
);
return CreateGameServerGroupOutput.fromJson(jsonResponse.body);
}