deleteAlias method

Future<void> deleteAlias({
  1. required String aliasId,
})

This API works with the following fleet types: EC2, Anywhere, Container

Deletes an alias. This operation removes all record of the alias. Game clients attempting to access a server process using the deleted alias receive an error. To delete an alias, specify the alias ID to be deleted.

Related actions

All APIs by task

May throw InternalServiceException. May throw InvalidRequestException. May throw NotFoundException. May throw TaggingFailedException. May throw UnauthorizedException.

Parameter aliasId : A unique identifier of the alias that you want to delete. You can use either the alias ID or ARN value.

Implementation

Future<void> deleteAlias({
  required String aliasId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'GameLift.DeleteAlias'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AliasId': aliasId,
    },
  );
}