deleteBuild method
This API works with the following fleet types: EC2
Deletes a build. This operation permanently deletes the build resource and any uploaded build files. Deleting a build does not affect the status of any active fleets using the build, but you can no longer create new fleets with the deleted build.
To delete a build, specify the build ID.
Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw TaggingFailedException.
May throw UnauthorizedException.
Parameter buildId :
A unique identifier for the build to delete. You can use either the build
ID or ARN value.
Implementation
Future<void> deleteBuild({
required String buildId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DeleteBuild'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'BuildId': buildId,
},
);
}