deleteContainerGroupDefinition method
This API works with the following fleet types: Container
Request options:
Deletes a container group definition.
- Delete an entire container group definition, including all versions. Specify the container group definition name, or use an ARN value without the version number.
- Delete a particular version. Specify the container group definition name and a version number, or use an ARN value that includes the version number.
-
Keep the newest versions and delete all older versions. Specify the
container group definition name and the number of versions to retain. For
example, set
VersionCountToRetainto 5 to delete all but the five most recent versions.
If successful, Amazon GameLift Servers removes the container group definition versions that you request deletion for. This request will fail for any requested versions if the following is true:
- If the version is being used in an active fleet
- If the version is being deployed to a fleet in a deployment that's currently in progress.
- If the version is designated as a rollback definition in a fleet deployment that's currently in progress.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw TaggingFailedException.
May throw UnauthorizedException.
May throw UnsupportedRegionException.
Parameter name :
The unique identifier for the container group definition to delete. You
can use either the Name or ARN value.
Parameter versionCountToRetain :
The number of most recent versions to keep while deleting all older
versions.
Parameter versionNumber :
The specific version to delete.
Implementation
Future<void> deleteContainerGroupDefinition({
required String name,
int? versionCountToRetain,
int? versionNumber,
}) async {
_s.validateNumRange(
'versionCountToRetain',
versionCountToRetain,
0,
1152921504606846976,
);
_s.validateNumRange(
'versionNumber',
versionNumber,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DeleteContainerGroupDefinition'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (versionCountToRetain != null)
'VersionCountToRetain': versionCountToRetain,
if (versionNumber != null) 'VersionNumber': versionNumber,
},
);
}