deleteMatchmakingConfiguration method

Future<void> deleteMatchmakingConfiguration({
  1. required String name,
})

This API works with the following fleet types: EC2, Anywhere, Container

Permanently removes a FlexMatch matchmaking configuration. To delete, specify the configuration name. A matchmaking configuration cannot be deleted if it is being used in any active matchmaking tickets.

May throw InternalServiceException. May throw InvalidRequestException. May throw NotFoundException. May throw TaggingFailedException. May throw UnsupportedRegionException.

Parameter name : A unique identifier for the matchmaking configuration. You can use either the configuration name or ARN value.

Implementation

Future<void> deleteMatchmakingConfiguration({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'GameLift.DeleteMatchmakingConfiguration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}