describeBuild method
This API works with the following fleet types: EC2
Retrieves properties for a custom game build. To request a build resource, specify a build ID. If successful, an object containing the build properties is returned.
Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter buildId :
A unique identifier for the build to retrieve properties for. You can use
either the build ID or ARN value.
Implementation
Future<DescribeBuildOutput> describeBuild({
required String buildId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DescribeBuild'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'BuildId': buildId,
},
);
return DescribeBuildOutput.fromJson(jsonResponse.body);
}