describeContainerGroupDefinition method

Future<DescribeContainerGroupDefinitionOutput> describeContainerGroupDefinition({
  1. required String name,
  2. int? versionNumber,
})

This API works with the following fleet types: Container

Retrieves the properties of a container group definition, including all container definitions in the group.

Request options:

  • Retrieve the latest version of a container group definition. Specify the container group definition name only, or use an ARN value without a version number.
  • Retrieve a particular version. Specify the container group definition name and a version number, or use an ARN value that includes the version number.
Results:

If successful, this operation returns the complete properties of a container group definition version.

Learn more

May throw InternalServiceException. May throw InvalidRequestException. May throw NotFoundException. May throw UnauthorizedException. May throw UnsupportedRegionException.

Parameter name : The unique identifier for the container group definition to retrieve properties for. You can use either the Name or ARN value.

Parameter versionNumber : The specific version to retrieve.

Implementation

Future<DescribeContainerGroupDefinitionOutput>
    describeContainerGroupDefinition({
  required String name,
  int? versionNumber,
}) async {
  _s.validateNumRange(
    'versionNumber',
    versionNumber,
    1,
    1152921504606846976,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'GameLift.DescribeContainerGroupDefinition'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (versionNumber != null) 'VersionNumber': versionNumber,
    },
  );

  return DescribeContainerGroupDefinitionOutput.fromJson(jsonResponse.body);
}