describeGameServerGroup method
- required String gameServerGroupName,
This API works with the following fleet types: EC2 (FleetIQ)
Retrieves information on a game server group. This operation returns only properties related to Amazon GameLift Servers FleetIQ. To view or update properties for the corresponding Auto Scaling group, such as launch template, auto scaling policies, and maximum/minimum group size, access the Auto Scaling group directly.
To get attributes for a game server group, provide a group name or ARN
value. If successful, a GameServerGroup object is returned.
Learn more
Amazon GameLift Servers FleetIQ Guide
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter gameServerGroupName :
A unique identifier for the game server group. Use either the name or ARN
value.
Implementation
Future<DescribeGameServerGroupOutput> describeGameServerGroup({
required String gameServerGroupName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DescribeGameServerGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GameServerGroupName': gameServerGroupName,
},
);
return DescribeGameServerGroupOutput.fromJson(jsonResponse.body);
}