describeRuntimeConfiguration method
- required String fleetId,
This API works with the following fleet types: EC2
Retrieves a fleet's runtime configuration settings. The runtime configuration determines which server processes run, and how, on computes in the fleet. For managed EC2 fleets, the runtime configuration describes server processes that run on each fleet instance. You can update a fleet's runtime configuration at any time using UpdateRuntimeConfiguration.
To get the current runtime configuration for a fleet, provide the fleet ID.
If successful, a RuntimeConfiguration object is returned for
the requested fleet. If the requested fleet has been deleted, the result
set is empty.
Learn more
Setting up Amazon GameLift Servers fleets
Running multiple processes on a fleet
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter fleetId :
A unique identifier for the fleet to get the runtime configuration for.
You can use either the fleet ID or ARN value.
Implementation
Future<DescribeRuntimeConfigurationOutput> describeRuntimeConfiguration({
required String fleetId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DescribeRuntimeConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FleetId': fleetId,
},
);
return DescribeRuntimeConfigurationOutput.fromJson(jsonResponse.body);
}