startMatchBackfill method
This API works with the following fleet types: EC2, Anywhere, Container
Finds new players to fill open slots in currently running game sessions. The backfill match process is essentially identical to the process of forming new matches. Backfill requests use the same matchmaker that was used to make the original match, and they provide matchmaking data for all players currently in the game session. FlexMatch uses this information to select new players so that backfilled match continues to meet the original match requirements.
When using FlexMatch with Amazon GameLift Servers managed hosting, you can
request a backfill match from a client service by calling this operation
with a GameSessions ID. You also have the option of making
backfill requests directly from your game server. In response to a
request, FlexMatch creates player sessions for the new players, updates
the GameSession resource, and sends updated matchmaking data
to the game server. You can request a backfill match at any point after a
game session is started. Each game session can have only one active
backfill request at a time; a subsequent request automatically replaces
the earlier request.
When using FlexMatch as a standalone component, request a backfill match by calling this operation without a game session identifier. As with newly formed matches, matchmaking results are returned in a matchmaking event so that your game can update the game session that is being backfilled.
To request a backfill match, specify a unique ticket ID, the original
matchmaking configuration, and matchmaking data for all current players in
the game session being backfilled. Optionally, specify the
GameSession ARN. If successful, a match backfill ticket is
created and returned with status set to QUEUED. Track the status of
backfill tickets using the same method for tracking tickets for new
matches.
Only game sessions created by FlexMatch are supported for match backfill.
Learn more
Backfill existing games with FlexMatch
Matchmaking events (reference)
How Amazon GameLift Servers FlexMatch works
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnsupportedRegionException.
Parameter configurationName :
Name of the matchmaker to use for this request. You can use either the
configuration name or ARN value. The ARN of the matchmaker that was used
with the original game session is listed in the GameSession
object, MatchmakerData property.
Parameter players :
Match information on all players that are currently assigned to the game
session. This information is used by the matchmaker to find new players
and add them to the existing game.
You can include up to 199 Players in a
StartMatchBackfill request.
-
PlayerID, PlayerAttributes, Team -- This information is maintained in the
GameSessionobject,MatchmakerDataproperty, for all players who are currently assigned to the game session. The matchmaker data is in JSON syntax, formatted as a string. For more details, see Match Data.The backfill request must specify the team membership for every player. Do not specify team if you are not using backfill.
- LatencyInMs -- If the matchmaker uses player latency, include a latency value, in milliseconds, for the Region that the game session is currently in. Do not include latency values for any other Region.
Parameter gameSessionArn :
An identifier for the game session that is unique across all regions. The
value is always a full ARN in the following format:
arn:aws:gamelift:. When using FlexMatch as a standalone matchmaking solution,
this parameter is not needed.
Parameter ticketId :
A unique identifier for a matchmaking ticket. If no ticket ID is specified
here, Amazon GameLift Servers will generate one in the form of a UUID. Use
this identifier to track the match backfill ticket status and retrieve
match results.
Implementation
Future<StartMatchBackfillOutput> startMatchBackfill({
required String configurationName,
required List<Player> players,
String? gameSessionArn,
String? ticketId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.StartMatchBackfill'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigurationName': configurationName,
'Players': players,
if (gameSessionArn != null) 'GameSessionArn': gameSessionArn,
if (ticketId != null) 'TicketId': ticketId,
},
);
return StartMatchBackfillOutput.fromJson(jsonResponse.body);
}