startMatchmaking method

Future<StartMatchmakingOutput> startMatchmaking({
  1. required String configurationName,
  2. required List<Player> players,
  3. String? ticketId,
})

This API works with the following fleet types: EC2, Anywhere, Container

Uses FlexMatch to create a game match for a group of players based on custom matchmaking rules. With games that use Amazon GameLift Servers managed hosting, this operation also triggers Amazon GameLift Servers to find hosting resources and start a new game session for the new match. Each matchmaking request includes information on one or more players and specifies the FlexMatch matchmaker to use. When a request is for multiple players, FlexMatch attempts to build a match that includes all players in the request, placing them in the same team and finding additional players as needed to fill the match.

To start matchmaking, provide a unique ticket ID, specify a matchmaking configuration, and include the players to be matched. You must also include any player attributes that are required by the matchmaking configuration's rule set. If successful, a matchmaking ticket is returned with status set to QUEUED.

Track matchmaking events to respond as needed and acquire game session connection information for successfully completed matches. Ticket status updates are tracked using event notification through Amazon Simple Notification Service, which is defined in the matchmaking configuration.

Learn more

Add FlexMatch to a game client

Set Up FlexMatch event notification

How Amazon GameLift Servers FlexMatch works

May throw InternalServiceException. May throw InvalidRequestException. May throw NotFoundException. May throw UnsupportedRegionException.

Parameter configurationName : Name of the matchmaking configuration to use for this request. Matchmaking configurations must exist in the same Region as this request. You can use either the configuration name or ARN value.

Parameter players : Information on each player to be matched. This information must include a player ID, and may contain player attributes and latency data to be used in the matchmaking process. After a successful match, Player objects contain the name of the team the player is assigned to.

You can include up to 10 Players in a StartMatchmaking request.

Parameter ticketId : A unique identifier for a matchmaking ticket. If no ticket ID is specified here, Amazon GameLift Servers will generate one in the form of a UUID. Use this identifier to track the matchmaking ticket status and retrieve match results.

Implementation

Future<StartMatchmakingOutput> startMatchmaking({
  required String configurationName,
  required List<Player> players,
  String? ticketId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'GameLift.StartMatchmaking'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConfigurationName': configurationName,
      'Players': players,
      if (ticketId != null) 'TicketId': ticketId,
    },
  );

  return StartMatchmakingOutput.fromJson(jsonResponse.body);
}