updateMatchmakingConfiguration method
- required String name,
- bool? acceptanceRequired,
- int? acceptanceTimeoutSeconds,
- int? additionalPlayerCount,
- BackfillMode? backfillMode,
- String? customEventData,
- String? description,
- FlexMatchMode? flexMatchMode,
- List<
GameProperty> ? gameProperties, - String? gameSessionData,
- List<
String> ? gameSessionQueueArns, - String? notificationTarget,
- int? requestTimeoutSeconds,
- String? ruleSetName,
This API works with the following fleet types: EC2, Anywhere, Container
Updates settings for a FlexMatch matchmaking configuration. These changes affect all matches and game sessions that are created after the update. To update settings, specify the configuration name to be updated and provide the new settings.
Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnsupportedRegionException.
Parameter name :
A unique identifier for the matchmaking configuration to update. You can
use either the configuration name or ARN value.
Parameter acceptanceRequired :
A flag that indicates whether a match that was created with this
configuration must be accepted by the matched players. To require
acceptance, set to TRUE. With this option enabled, matchmaking tickets use
the status REQUIRES_ACCEPTANCE to indicate when a completed
potential match is waiting for player acceptance.
Parameter acceptanceTimeoutSeconds :
The length of time (in seconds) to wait for players to accept a proposed
match, if acceptance is required.
Parameter additionalPlayerCount :
The number of player slots in a match to keep open for future players. For
example, if the configuration's rule set specifies a match for a single
12-person team, and the additional player count is set to 2, only 10
players are selected for the match. This parameter is not used if
FlexMatchMode is set to STANDALONE.
Parameter backfillMode :
The method that is used to backfill game sessions created with this
matchmaking configuration. Specify MANUAL when your game manages backfill
requests manually or does not use the match backfill feature. Specify
AUTOMATIC to have GameLift create a match backfill request whenever a game
session has one or more open slots. Learn more about manual and automatic
backfill in Backfill
Existing Games with FlexMatch. Automatic backfill is not available
when FlexMatchMode is set to STANDALONE.
Parameter customEventData :
Information to add to all events related to the matchmaking configuration.
Parameter description :
A description for the matchmaking configuration.
Parameter flexMatchMode :
Indicates whether this matchmaking configuration is being used with Amazon
GameLift Servers hosting or as a standalone matchmaking solution.
- STANDALONE - FlexMatch forms matches and returns match information, including players and team assignments, in a MatchmakingSucceeded event.
- WITH_QUEUE - FlexMatch forms matches and uses the specified Amazon GameLift Servers queue to start a game session for the match.
Parameter gameProperties :
A set of key-value pairs that can store custom data in a game session. For
example: {"Key": "difficulty", "Value": "novice"}. This
information is added to the new GameSession object that is
created for a successful match. This parameter is not used if
FlexMatchMode is set to STANDALONE.
- Avoid using periods (".") in property keys if you plan to search for game sessions by properties. Property keys containing periods cannot be searched and will be filtered out from search results due to search index limitations.
- If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.
Parameter gameSessionData :
A set of custom game session properties, formatted as a single string
value. This data is passed to a game server process with a request to
start a new game session. For more information, see Start
a game session. This information is added to the game session that is
created for a successful match. This parameter is not used if
FlexMatchMode is set to STANDALONE.
Parameter gameSessionQueueArns :
The Amazon Resource Name (ARN)
that is assigned to a Amazon GameLift Servers game session queue resource
and uniquely identifies it. ARNs are unique across all Regions. Format is
arn:aws:gamelift:.
Queues can be located in any Region. Queues are used to start new Amazon
GameLift Servers-hosted game sessions for matches that are created with
this matchmaking configuration. If FlexMatchMode is set to
STANDALONE, do not set this parameter.
Parameter notificationTarget :
An SNS topic ARN that is set up to receive matchmaking notifications. See
Setting up notifications for matchmaking for more information.
Parameter requestTimeoutSeconds :
The maximum duration, in seconds, that a matchmaking ticket can remain in
process before timing out. Requests that fail due to timing out can be
resubmitted as needed.
Parameter ruleSetName :
A unique identifier for the matchmaking rule set to use with this
configuration. You can use either the rule set name or ARN value. A
matchmaking configuration can only use rule sets that are defined in the
same Region.
Implementation
Future<UpdateMatchmakingConfigurationOutput> updateMatchmakingConfiguration({
required String name,
bool? acceptanceRequired,
int? acceptanceTimeoutSeconds,
int? additionalPlayerCount,
BackfillMode? backfillMode,
String? customEventData,
String? description,
FlexMatchMode? flexMatchMode,
List<GameProperty>? gameProperties,
String? gameSessionData,
List<String>? gameSessionQueueArns,
String? notificationTarget,
int? requestTimeoutSeconds,
String? ruleSetName,
}) async {
_s.validateNumRange(
'acceptanceTimeoutSeconds',
acceptanceTimeoutSeconds,
1,
600,
);
_s.validateNumRange(
'additionalPlayerCount',
additionalPlayerCount,
0,
1152921504606846976,
);
_s.validateNumRange(
'requestTimeoutSeconds',
requestTimeoutSeconds,
1,
43200,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.UpdateMatchmakingConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (acceptanceRequired != null)
'AcceptanceRequired': acceptanceRequired,
if (acceptanceTimeoutSeconds != null)
'AcceptanceTimeoutSeconds': acceptanceTimeoutSeconds,
if (additionalPlayerCount != null)
'AdditionalPlayerCount': additionalPlayerCount,
if (backfillMode != null) 'BackfillMode': backfillMode.value,
if (customEventData != null) 'CustomEventData': customEventData,
if (description != null) 'Description': description,
if (flexMatchMode != null) 'FlexMatchMode': flexMatchMode.value,
if (gameProperties != null) 'GameProperties': gameProperties,
if (gameSessionData != null) 'GameSessionData': gameSessionData,
if (gameSessionQueueArns != null)
'GameSessionQueueArns': gameSessionQueueArns,
if (notificationTarget != null)
'NotificationTarget': notificationTarget,
if (requestTimeoutSeconds != null)
'RequestTimeoutSeconds': requestTimeoutSeconds,
if (ruleSetName != null) 'RuleSetName': ruleSetName,
},
);
return UpdateMatchmakingConfigurationOutput.fromJson(jsonResponse.body);
}