updateScript method
This API works with the following fleet types: EC2
Updates Realtime script metadata and content.
To update script metadata, specify the script ID and provide updated name and/or version values.
To update script content, provide an updated zip file by pointing to either a local file or an Amazon S3 bucket location. You can use either method regardless of how the original script was uploaded. Use the Version parameter to track updates to the script.
If the call is successful, the updated metadata is stored in the script record and a revised script is uploaded to the Amazon GameLift Servers service. Once the script is updated and acquired by a fleet instance, the new version is used for all new game sessions.
Learn more
Amazon GameLift Servers Amazon GameLift Servers Realtime
Related actions
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter scriptId :
A unique identifier for the Realtime script to update. You can use either
the script ID or ARN value.
Parameter name :
A descriptive label that is associated with a script. Script names do not
need to be unique.
Parameter storageLocation :
The location of the Amazon S3 bucket where a zipped file containing your
Realtime scripts is stored. The storage location must specify the Amazon
S3 bucket name, the zip file name (the "key"), and a role ARN that allows
Amazon GameLift Servers to access the Amazon S3 storage location. The S3
bucket must be in the same Region where you want to create a new script.
By default, Amazon GameLift Servers uploads the latest version of the zip
file; if you have S3 object versioning turned on, you can use the
ObjectVersion parameter to specify an earlier version.
Parameter version :
Version information that is associated with a build or script. Version
strings do not need to be unique.
Parameter zipFile :
A data object containing your Realtime scripts and dependencies as a zip
file. The zip file can have one or multiple files. Maximum size of a zip
file is 5 MB.
When using the Amazon Web Services CLI tool to create a script, this
parameter is set to the zip file name. It must be prepended with the
string "fileb://" to indicate that the file data is a binary object. For
example: --zip-file fileb://myRealtimeScript.zip.
Implementation
Future<UpdateScriptOutput> updateScript({
required String scriptId,
String? name,
S3Location? storageLocation,
String? version,
Uint8List? zipFile,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.UpdateScript'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ScriptId': scriptId,
if (name != null) 'Name': name,
if (storageLocation != null) 'StorageLocation': storageLocation,
if (version != null) 'Version': version,
if (zipFile != null) 'ZipFile': base64Encode(zipFile),
},
);
return UpdateScriptOutput.fromJson(jsonResponse.body);
}