validateMatchmakingRuleSet method
Future<ValidateMatchmakingRuleSetOutput>
validateMatchmakingRuleSet({
- required String ruleSetBody,
This API works with the following fleet types: EC2, Anywhere, Container
Validates the syntax of a matchmaking rule or rule set. This operation checks that the rule set is using syntactically correct JSON and that it conforms to allowed property expressions. To validate syntax, provide a rule set JSON string.
Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw UnsupportedRegionException.
Parameter ruleSetBody :
A collection of matchmaking rules to validate, formatted as a JSON string.
Implementation
Future<ValidateMatchmakingRuleSetOutput> validateMatchmakingRuleSet({
required String ruleSetBody,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.ValidateMatchmakingRuleSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RuleSetBody': ruleSetBody,
},
);
return ValidateMatchmakingRuleSetOutput.fromJson(jsonResponse.body);
}