GameLiftStreams class
Amazon GameLift Streams provides a global cloud solution for content streaming experiences. Use Amazon GameLift Streams tools to upload and configure content for streaming, deploy and scale computing resources to host streams, and manage stream session placement to meet customer demand.
Constructors
- GameLiftStreams({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addStreamGroupLocations(
{required String identifier, required List< LocationConfiguration> locationConfigurations}) → Future<AddStreamGroupLocationsOutput> -
Add locations that can host stream sessions. To add a location, the stream
group must be in
ACTIVEstatus. You configure locations and their corresponding capacity for each stream group. Creating a stream group in a location that's nearest to your end users can help minimize latency and improve quality. -
associateApplications(
{required List< String> applicationIdentifiers, required String identifier}) → Future<AssociateApplicationsOutput> -
When you associate, or link, an application with a stream group, then
Amazon GameLift Streams can launch the application using the stream
group's allocated compute resources. The stream group must be in
ACTIVEstatus. You can reverse this action by using DisassociateApplications. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createApplication(
{required String applicationSourceUri, required String description, required String executablePath, required RuntimeEnvironment runtimeEnvironment, String? applicationLogOutputUri, List< String> ? applicationLogPaths, String? clientToken, Map<String, String> ? tags}) → Future<CreateApplicationOutput> - Creates an application resource in Amazon GameLift Streams, which specifies the application content you want to stream, such as a game build or other software, and configures the settings to run it.
-
createStreamGroup(
{required String description, required StreamClass streamClass, String? clientToken, String? defaultApplicationIdentifier, List< LocationConfiguration> ? locationConfigurations, Map<String, String> ? tags}) → Future<CreateStreamGroupOutput> - Stream groups manage how Amazon GameLift Streams allocates resources and handles concurrent streams, allowing you to effectively manage capacity and costs. Within a stream group, you specify an application to stream, streaming locations and their capacity, and the stream class you want to use when streaming applications to your end-users. A stream class defines the hardware configuration of the compute resources that Amazon GameLift Streams will use when streaming, such as the CPU, GPU, and memory.
-
createStreamSessionConnection(
{required String identifier, required String signalRequest, required String streamSessionIdentifier, String? clientToken}) → Future< CreateStreamSessionConnectionOutput> -
Enables clients to reconnect to a stream session while preserving all
session state and data in the disconnected session. This reconnection
process can be initiated when a stream session is in either
PENDING_CLIENT_RECONNECTIONorACTIVEstatus. The process works as follows: -
deleteApplication(
{required String identifier}) → Future< void> - Permanently deletes an Amazon GameLift Streams application resource. This also deletes the application content files stored with Amazon GameLift Streams. However, this does not delete the original files that you uploaded to your Amazon S3 bucket; you can delete these any time after Amazon GameLift Streams creates an application, which is the only time Amazon GameLift Streams accesses your Amazon S3 bucket.
-
deleteStreamGroup(
{required String identifier}) → Future< void> -
Permanently deletes all compute resources and information related to a
stream group. To delete a stream group, specify the unique stream group
identifier. During the deletion process, the stream group's status is
DELETING. This operation stops streams in progress and prevents new streams from starting. As a best practice, before deleting the stream group, call ListStreamSessions to check for streams in progress and take action to stop them. When you delete a stream group, any application associations referring to that stream group are automatically removed. -
disassociateApplications(
{required List< String> applicationIdentifiers, required String identifier}) → Future<DisassociateApplicationsOutput> -
When you disassociate, or unlink, an application from a stream group, you
can no longer stream this application by using that stream group's
allocated compute resources. Any streams in process will continue until
they terminate, which helps avoid interrupting an end-user's stream.
Amazon GameLift Streams will not initiate new streams in the stream group
using the disassociated application. The disassociate action does not
affect the stream capacity of a stream group. To disassociate an
application, the stream group must be in
ACTIVEstatus. -
exportStreamSessionFiles(
{required String identifier, required String outputUri, required String streamSessionIdentifier}) → Future< void> - Export the files that your application modifies or generates in a stream session, which can help you debug or verify your application. When your application runs, it generates output files such as logs, diagnostic information, crash dumps, save files, user data, screenshots, and so on. The files can be defined by the engine or frameworks that your application uses, or information that you've programmed your application to output.
-
getApplication(
{required String identifier}) → Future< GetApplicationOutput> - Retrieves properties for an Amazon GameLift Streams application resource. Specify the ID of the application that you want to retrieve. If the operation is successful, it returns properties for the requested application.
-
getStreamGroup(
{required String identifier}) → Future< GetStreamGroupOutput> - Retrieves properties for a Amazon GameLift Streams stream group resource. Specify the ID of the stream group that you want to retrieve. If the operation is successful, it returns properties for the requested stream group.
-
getStreamSession(
{required String identifier, required String streamSessionIdentifier}) → Future< GetStreamSessionOutput> - Retrieves properties for a Amazon GameLift Streams stream session resource. Specify the Amazon Resource Name (ARN) of the stream session that you want to retrieve and its stream group ARN. If the operation is successful, it returns properties for the requested resource.
-
listApplications(
{int? maxResults, String? nextToken}) → Future< ListApplicationsOutput> - Retrieves a list of all Amazon GameLift Streams applications that are associated with the Amazon Web Services account in use. This operation returns applications in all statuses, in no particular order. You can paginate the results as needed.
-
listStreamGroups(
{int? maxResults, String? nextToken}) → Future< ListStreamGroupsOutput> - Retrieves a list of all Amazon GameLift Streams stream groups that are associated with the Amazon Web Services account in use. This operation returns stream groups in all statuses, in no particular order. You can paginate the results as needed.
-
listStreamSessions(
{required String identifier, ExportFilesStatus? exportFilesStatus, int? maxResults, String? nextToken, StreamSessionStatus? status}) → Future< ListStreamSessionsOutput> - Retrieves a list of Amazon GameLift Streams stream sessions that a stream group is hosting.
-
listStreamSessionsByAccount(
{ExportFilesStatus? exportFilesStatus, int? maxResults, String? nextToken, StreamSessionStatus? status}) → Future< ListStreamSessionsByAccountOutput> - Retrieves a list of Amazon GameLift Streams stream sessions that this user account has access to.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Retrieves all tags assigned to a Amazon GameLift Streams resource. To list tags for a resource, specify the ARN value for the resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStreamGroupLocations(
{required String identifier, required List< String> locations}) → Future<void> -
Removes a set of remote locations from this stream group. To remove a
location, the stream group must be in
ACTIVEstatus. When you remove a location, Amazon GameLift Streams releases allocated compute resources in that location. Stream sessions can no longer start from removed locations in a stream group. Amazon GameLift Streams also deletes the content files of all associated applications that were in Amazon GameLift Streams's internal Amazon S3 bucket at this location. -
startStreamSession(
{required String applicationIdentifier, required String identifier, required Protocol protocol, required String signalRequest, Map< String, String> ? additionalEnvironmentVariables, List<String> ? additionalLaunchArgs, String? clientToken, int? connectionTimeoutSeconds, String? description, List<String> ? locations, PerformanceStatsConfiguration? performanceStatsConfiguration, int? sessionLengthSeconds, String? userId}) → Future<StartStreamSessionOutput> - This action initiates a new stream session and outputs connection information that clients can use to access the stream. A stream session refers to an instance of a stream that Amazon GameLift Streams transmits from the server to the end-user. A stream session runs on a compute resource that a stream group has allocated. The start stream session process works as follows:
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns one or more tags to a Amazon GameLift Streams resource. Use tags to organize Amazon Web Services resources for a range of purposes. You can assign tags to the following Amazon GameLift Streams resource types:
-
terminateStreamSession(
{required String identifier, required String streamSessionIdentifier}) → Future< void> -
Permanently terminates an active stream session. When called, the stream
session status changes to
TERMINATING. You can terminate a stream session in any status exceptACTIVATING. If the stream session is inACTIVATINGstatus, an exception is thrown. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from a Amazon GameLift Streams resource. To remove tags, specify the Amazon GameLift Streams resource and a list of one or more tags to remove.
-
updateApplication(
{required String identifier, String? applicationLogOutputUri, List< String> ? applicationLogPaths, String? description}) → Future<UpdateApplicationOutput> -
Updates the mutable configuration settings for a Amazon GameLift Streams
application resource. You can change the
Description,ApplicationLogOutputUri, andApplicationLogPaths. -
updateStreamGroup(
{required String identifier, String? defaultApplicationIdentifier, String? description, List< LocationConfiguration> ? locationConfigurations}) → Future<UpdateStreamGroupOutput> -
Updates the configuration settings for an Amazon GameLift Streams stream
group resource. To update a stream group, it must be in
ACTIVEstatus. You can change the description, the set of locations, and the requested capacity of a stream group per location. If you want to change the stream class, create a new stream group.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited