associateApplications method

Future<AssociateApplicationsOutput> associateApplications({
  1. required List<String> applicationIdentifiers,
  2. required String identifier,
})

When you associate, or link, an application with a stream group, then Amazon GameLift Streams can launch the application using the stream group's allocated compute resources. The stream group must be in ACTIVE status. You can reverse this action by using DisassociateApplications.

If a stream group does not already have a linked application, Amazon GameLift Streams will automatically assign the first application provided in ApplicationIdentifiers as the default.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationIdentifiers : A set of applications to associate with the stream group.

This value is a set of either Amazon Resource Names (ARN) or IDs that uniquely identify application resources. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6. Example ID: a-9ZY8X7Wv6.

Parameter identifier : A stream group to associate to the applications.

This value is an Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

Implementation

Future<AssociateApplicationsOutput> associateApplications({
  required List<String> applicationIdentifiers,
  required String identifier,
}) async {
  final $payload = <String, dynamic>{
    'ApplicationIdentifiers': applicationIdentifiers,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/streamgroups/${Uri.encodeComponent(identifier)}/associations',
    exceptionFnMap: _exceptionFns,
  );
  return AssociateApplicationsOutput.fromJson(response);
}