deleteStreamGroup method

Future<void> deleteStreamGroup({
  1. required String identifier,
})

Permanently deletes all compute resources and information related to a stream group. To delete a stream group, specify the unique stream group identifier. During the deletion process, the stream group's status is DELETING. This operation stops streams in progress and prevents new streams from starting. As a best practice, before deleting the stream group, call ListStreamSessions to check for streams in progress and take action to stop them. When you delete a stream group, any application associations referring to that stream group are automatically removed.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : An Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

Implementation

Future<void> deleteStreamGroup({
  required String identifier,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/streamgroups/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}