disassociateApplications method
When you disassociate, or unlink, an application from a stream group, you
can no longer stream this application by using that stream group's
allocated compute resources. Any streams in process will continue until
they terminate, which helps avoid interrupting an end-user's stream.
Amazon GameLift Streams will not initiate new streams in the stream group
using the disassociated application. The disassociate action does not
affect the stream capacity of a stream group. To disassociate an
application, the stream group must be in ACTIVE status.
If you disassociate the default application, Amazon GameLift Streams will
automatically choose a new default application from the remaining
associated applications. To change which application is the default
application, call UpdateStreamGroup
and specify a new DefaultApplicationIdentifier.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationIdentifiers :
A set of applications that you want to disassociate from the stream group.
This value is a set of either Amazon
Resource Names (ARN) or IDs that uniquely identify application
resources. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6.
Example ID: a-9ZY8X7Wv6.
Parameter identifier :
A stream group to disassociate these applications from.
This value is an Amazon
Resource Name (ARN) or ID that uniquely identifies the stream group
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
Implementation
Future<DisassociateApplicationsOutput> disassociateApplications({
required List<String> applicationIdentifiers,
required String identifier,
}) async {
final $payload = <String, dynamic>{
'ApplicationIdentifiers': applicationIdentifiers,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/streamgroups/${Uri.encodeComponent(identifier)}/disassociations',
exceptionFnMap: _exceptionFns,
);
return DisassociateApplicationsOutput.fromJson(response);
}