getApplication method

Future<GetApplicationOutput> getApplication({
  1. required String identifier,
})

Retrieves properties for an Amazon GameLift Streams application resource. Specify the ID of the application that you want to retrieve. If the operation is successful, it returns properties for the requested application.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : An Amazon Resource Name (ARN) or ID that uniquely identifies the application resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6. Example ID: a-9ZY8X7Wv6.

Implementation

Future<GetApplicationOutput> getApplication({
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetApplicationOutput.fromJson(response);
}