getStreamSession method
Retrieves properties for a Amazon GameLift Streams stream session resource. Specify the Amazon Resource Name (ARN) of the stream session that you want to retrieve and its stream group ARN. If the operation is successful, it returns properties for the requested resource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The stream group that runs this stream session.
This value is an Amazon
Resource Name (ARN) or ID that uniquely identifies the stream group
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
Parameter streamSessionIdentifier :
An Amazon
Resource Name (ARN) or ID that uniquely identifies the stream session
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567.
Example ID: ABC123def4567.
Implementation
Future<GetStreamSessionOutput> getStreamSession({
required String identifier,
required String streamSessionIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/streamgroups/${Uri.encodeComponent(identifier)}/streamsessions/${Uri.encodeComponent(streamSessionIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return GetStreamSessionOutput.fromJson(response);
}