getStreamUrl method

Future<GetStreamUrlOutput> getStreamUrl({
  1. required String identifier,
  2. required String streamUrlIdentifier,
})

Retrieves properties for a stream URL, including its current status, usage, and the stream sessions started through it.

If you delete the stream group or application that backs the stream URL, this operation updates the status of the stream URL to REVOKED.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : An Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

This is the stream group that owns the stream URL.

Parameter streamUrlIdentifier : The unique identifier of the stream URL. Specify a stream URL ID or Amazon Resource Name (ARN). Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamurl/sg-1AB2C3De4/su-1AB2C3De4. Example ID: su-1AB2C3De4.

Implementation

Future<GetStreamUrlOutput> getStreamUrl({
  required String identifier,
  required String streamUrlIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/streamgroups/${Uri.encodeComponent(identifier)}/streamurls/${Uri.encodeComponent(streamUrlIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetStreamUrlOutput.fromJson(response);
}