listStreamSessionsByAccount method

Future<ListStreamSessionsByAccountOutput> listStreamSessionsByAccount({
  1. ExportFilesStatus? exportFilesStatus,
  2. int? maxResults,
  3. String? nextToken,
  4. StreamSessionStatus? status,
})

Retrieves a list of Amazon GameLift Streams stream sessions that this user account has access to.

In the returned list of stream sessions, the ExportFilesMetadata property only shows the Status value. To get the OutpurUri and StatusReason values, use GetStreamSession.

We don't recommend using this operation to regularly check stream session statuses because it's costly. Instead, to check status updates for a specific stream session, use GetStreamSession.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter exportFilesStatus : Filter by the exported files status. You can specify one status in each request to retrieve only sessions that currently have that exported files status.

Parameter maxResults : The number of results to return. Use this parameter with NextToken to return results in sequential pages. Default value is 25.

Parameter nextToken : The token that marks the start of the next set of results. Use this token when you retrieve results as sequential pages. To get the first page of results, omit a token value. To get the remaining pages, provide the token returned with the previous result set.

Parameter status : Filter by the stream session status. You can specify one status in each request to retrieve only sessions that are currently in that status.

Implementation

Future<ListStreamSessionsByAccountOutput> listStreamSessionsByAccount({
  ExportFilesStatus? exportFilesStatus,
  int? maxResults,
  String? nextToken,
  StreamSessionStatus? status,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (exportFilesStatus != null)
      'ExportFilesStatus': [exportFilesStatus.value],
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
    if (status != null) 'Status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/streamsessions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListStreamSessionsByAccountOutput.fromJson(response);
}