listStreamUrls method

Future<ListStreamUrlsOutput> listStreamUrls({
  1. int? maxResults,
  2. String? nextToken,
  3. StreamUrlStatus? status,
  4. String? streamGroupIdentifier,
})

Retrieves a list of the stream URLs in the current Amazon Web Services Region for your Amazon Web Services account. You can filter the results by status or by stream group. Use the pagination parameters to retrieve results as a set of sequential pages. If you delete the stream group or application that backs a stream URL, this operation updates that stream URL's status to REVOKED.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return per page. Valid values are 1-100. The default is 25.

Parameter nextToken : The token that marks the start of the next set of results. Use this token when you retrieve results as sequential pages. To get the first page of results, omit a token value. To get the remaining pages, provide the token returned with the previous result set.

Parameter status : Filters the list to stream URLs with the specified status.

  • ACTIVE: The stream URL is valid and can start stream sessions.
  • EXPIRED: The stream URL has passed its expiration time and can no longer start stream sessions.
  • REVOKED: The stream URL was revoked and can no longer start stream sessions.
  • LIMIT_REACHED: The stream URL has been used the maximum number of times and can no longer start stream sessions.

Parameter streamGroupIdentifier : Filters the list to stream URLs that belong to the specified stream group.

This value is an Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

Implementation

Future<ListStreamUrlsOutput> listStreamUrls({
  int? maxResults,
  String? nextToken,
  StreamUrlStatus? status,
  String? streamGroupIdentifier,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
    if (status != null) 'Status': [status.value],
    if (streamGroupIdentifier != null)
      'StreamGroupIdentifier': [streamGroupIdentifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/streamurls',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListStreamUrlsOutput.fromJson(response);
}