removeStreamGroupLocations method
Removes a set of remote locations from this stream group. To remove a
location, the stream group must be in ACTIVE status. When you
remove a location, Amazon GameLift Streams releases allocated compute
resources in that location. Stream sessions can no longer start from
removed locations in a stream group. Amazon GameLift Streams also deletes
the content files of all associated applications that were in Amazon
GameLift Streams's internal Amazon S3 bucket at this location.
You cannot remove the Amazon Web Services Region location where you initially created this stream group, known as the primary location. However, you can set the stream capacity to zero to avoid incurring costs for allocated compute resources in that location.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
A stream group to remove the specified locations from.
This value is an Amazon
Resource Name (ARN) or ID that uniquely identifies the stream group
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
Parameter locations :
A set of locations to remove this stream group. For example,
us-east-1.
For a complete list of locations that Amazon GameLift Streams supports, refer to Regions, quotas, and limitations in the Amazon GameLift Streams Developer Guide.
Implementation
Future<void> removeStreamGroupLocations({
required String identifier,
required List<String> locations,
}) async {
final $query = <String, List<String>>{
'locations': locations,
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/streamgroups/${Uri.encodeComponent(identifier)}/locations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}