GeoMaps class

Integrate high-quality base map data into your applications using MapLibre. Capabilities include:

  • Access to comprehensive base map data, allowing you to tailor the map display to your specific needs.
  • Multiple pre-designed map styles suited for various application types, such as navigation, logistics, or data visualization.
  • Generation of static map images for scenarios where interactive maps aren't suitable, such as:
    • Embedding in emails or documents
    • Displaying in low-bandwidth environments
    • Creating printable maps
    • Enhancing application performance by reducing client-side rendering

Constructors

GeoMaps({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getGlyphs({required String fontStack, required String fontUnicodeRange}) Future<GetGlyphsResponse>
GetGlyphs returns the map's glyphs.
getSprites({required ColorScheme colorScheme, required String fileName, required MapStyle style, required Variant variant}) Future<GetSpritesResponse>
GetSprites returns the map's sprites.
getStaticMap({required String fileName, required int height, required int width, String? boundedPositions, String? boundingBox, String? center, ColorScheme? colorScheme, String? compactOverlay, bool? cropLabels, String? geoJsonOverlay, String? key, LabelSize? labelSize, String? language, int? padding, MapFeatureMode? pointsOfInterests, String? politicalView, int? radius, ScaleBarUnit? scaleBarUnit, StaticMapStyle? style, double? zoom}) Future<GetStaticMapResponse>
GetStaticMap
getStyleDescriptor({required MapStyle style, Buildings? buildings, ColorScheme? colorScheme, ContourDensity? contourDensity, String? key, String? politicalView, Terrain? terrain, Traffic? traffic, List<TravelMode>? travelModes}) Future<GetStyleDescriptorResponse>
GetStyleDescriptor returns information about the style.
getTile({required String tileset, required String x, required String y, required String z, List<TileAdditionalFeature>? additionalFeatures, String? key}) Future<GetTileResponse>
GetTile returns a tile. Map tiles are used by clients to render a map. They're addressed using a grid arrangement with an X coordinate, Y coordinate, and Z (zoom) level.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited