GeoPlaces class
The Places API enables powerful location search and geocoding capabilities for your applications, offering global coverage with rich, detailed information. Key features include:
- Forward and reverse geocoding for addresses and coordinates
-
Comprehensive place searches with detailed information, including:
- Business names and addresses
- Contact information
- Hours of operation
- POI (Points of Interest) categories
- Food types for restaurants
- Chain affiliation for relevant businesses
- Global data coverage with a wide range of POI categories
- Regular data updates to ensure accuracy and relevance
Constructors
- GeoPlaces({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autocomplete(
{required String queryText, List< AutocompleteAdditionalFeature> ? additionalFeatures, List<double> ? biasPosition, AutocompleteFilter? filter, AutocompleteIntendedUse? intendedUse, String? key, String? language, int? maxResults, String? politicalView, PostalCodeMode? postalCodeMode}) → Future<AutocompleteResponse> -
Autocompletecompletes potential places and addresses as the user types, based on the partial input. The API enhances the efficiency and accuracy of address by completing query based on a few entered keystrokes. It helps you by completing partial queries with valid address completion. Also, the API supports the filtering of results based on geographic location, country, or specific place types, and can be tailored using optional parameters like language and political views. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
geocode(
{List< GeocodeAdditionalFeature> ? additionalFeatures, List<double> ? biasPosition, GeocodeFilter? filter, GeocodeIntendedUse? intendedUse, String? key, String? language, int? maxResults, String? politicalView, GeocodeQueryComponents? queryComponents, String? queryText}) → Future<GeocodeResponse> -
Geocodeconverts a textual address or place into geographic coordinates. You can obtain geographic coordinates, address component, and other related information. It supports flexible queries, including free-form text or structured queries with components like street names, postal codes, and regions. The Geocode API can also provide additional features such as time zone information and the inclusion of political views. -
getPlace(
{required String placeId, List< GetPlaceAdditionalFeature> ? additionalFeatures, GetPlaceIntendedUse? intendedUse, String? key, String? language, String? politicalView}) → Future<GetPlaceResponse> -
GetPlacefinds a place by its unique ID. APlaceIdis returned by other place operations. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverseGeocode(
{required List< double> queryPosition, List<ReverseGeocodeAdditionalFeature> ? additionalFeatures, ReverseGeocodeFilter? filter, double? heading, ReverseGeocodeIntendedUse? intendedUse, String? key, String? language, int? maxResults, String? politicalView, int? queryRadius}) → Future<ReverseGeocodeResponse> -
ReverseGeocodeconverts geographic coordinates into a human-readable address or place. You can obtain address component, and other related information such as place type, category, street information. The Reverse Geocode API supports filtering to on place type so that you can refine result based on your need. Also, The Reverse Geocode API can also provide additional features such as time zone information and the inclusion of political views. -
searchNearby(
{required List< double> queryPosition, List<SearchNearbyAdditionalFeature> ? additionalFeatures, SearchNearbyFilter? filter, SearchNearbyIntendedUse? intendedUse, String? key, String? language, int? maxResults, String? nextToken, String? politicalView, int? queryRadius}) → Future<SearchNearbyResponse> -
SearchNearbyqueries for points of interest within a radius from a central coordinates, returning place results with optional filters such as categories, business chains, food types and more. The API returns details such as a place name, address, phone, category, food type, contact, opening hours. Also, the API can return phonemes, time zones and more based on requested parameters. -
searchText(
{List< SearchTextAdditionalFeature> ? additionalFeatures, List<double> ? biasPosition, SearchTextFilter? filter, SearchTextIntendedUse? intendedUse, String? key, String? language, int? maxResults, String? nextToken, String? politicalView, String? queryId, String? queryText}) → Future<SearchTextResponse> -
SearchTextsearches for geocode and place information. You can then complete a follow-up query suggested from theSuggestAPI via a query id. -
suggest(
{required String queryText, List< SuggestAdditionalFeature> ? additionalFeatures, List<double> ? biasPosition, SuggestFilter? filter, SuggestIntendedUse? intendedUse, String? key, String? language, int? maxQueryRefinements, int? maxResults, String? politicalView}) → Future<SuggestResponse> -
Suggestprovides intelligent predictions or recommendations based on the user's input or context, such as relevant places, points of interest, query terms or search category. It is designed to help users find places or point of interests candidates or identify a follow on query based on incomplete or misspelled queries. It returns a list of possible matches or refinements that can be used to formulate a more accurate query. Users can select the most appropriate suggestion and use it for further searching. The API provides options for filtering results by location and other attributes, and allows for additional features like phonemes and timezones. The response includes refined query terms and detailed place information. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited