geocode method

Future<GeocodeResponse> geocode({
  1. List<GeocodeAdditionalFeature>? additionalFeatures,
  2. List<double>? biasPosition,
  3. GeocodeFilter? filter,
  4. GeocodeIntendedUse? intendedUse,
  5. String? key,
  6. String? language,
  7. int? maxResults,
  8. String? politicalView,
  9. GeocodeQueryComponents? queryComponents,
  10. String? queryText,
})

Geocode converts a textual address or place into geographic coordinates. You can obtain geographic coordinates, address component, and other related information. It supports flexible queries, including free-form text or structured queries with components like street names, postal codes, and regions. The Geocode API can also provide additional features such as time zone information and the inclusion of political views.

For more information, see Geocode in the Amazon Location Service Developer Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter additionalFeatures : A list of optional additional parameters, such as time zone, that can be requested for each result.

Parameter biasPosition : The position, in longitude and latitude, that the results should be close to. Typically, place results returned are ranked higher the closer they are to this position. Stored in [lng, lat] and in the WGS 84 format.

Parameter filter : A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.

Parameter intendedUse : Indicates if the query results will be persisted in customer infrastructure. Defaults to SingleUse (not stored). Not supported in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Parameter key : Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Parameter language : A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.

Parameter maxResults : An optional limit for the number of results returned in a single call.

Default value: 20

Parameter politicalView : The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.

Parameter queryText : The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.

Implementation

Future<GeocodeResponse> geocode({
  List<GeocodeAdditionalFeature>? additionalFeatures,
  List<double>? biasPosition,
  GeocodeFilter? filter,
  GeocodeIntendedUse? intendedUse,
  String? key,
  String? language,
  int? maxResults,
  String? politicalView,
  GeocodeQueryComponents? queryComponents,
  String? queryText,
}) async {
  final $query = <String, List<String>>{
    if (key != null) 'key': [key],
  };
  final $payload = <String, dynamic>{
    if (additionalFeatures != null)
      'AdditionalFeatures': additionalFeatures.map((e) => e.value).toList(),
    if (biasPosition != null) 'BiasPosition': biasPosition,
    if (filter != null) 'Filter': filter,
    if (intendedUse != null) 'IntendedUse': intendedUse.value,
    if (language != null) 'Language': language,
    if (maxResults != null) 'MaxResults': maxResults,
    if (politicalView != null) 'PoliticalView': politicalView,
    if (queryComponents != null) 'QueryComponents': queryComponents,
    if (queryText != null) 'QueryText': queryText,
  };
  final response = await _protocol.sendRaw(
    payload: $payload,
    method: 'POST',
    requestUri: '/v2/geocode',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return GeocodeResponse(
    resultItems: ($json['ResultItems'] as List?)
        ?.nonNulls
        .map((e) => GeocodeResultItem.fromJson(e as Map<String, dynamic>))
        .toList(),
    pricingBucket: _s.extractHeaderStringValue(
        response.headers, 'x-amz-geo-pricing-bucket')!,
  );
}