suggest method

Future<SuggestResponse> suggest({
  1. required String queryText,
  2. List<SuggestAdditionalFeature>? additionalFeatures,
  3. List<double>? biasPosition,
  4. SuggestFilter? filter,
  5. SuggestIntendedUse? intendedUse,
  6. String? key,
  7. String? language,
  8. int? maxQueryRefinements,
  9. int? maxResults,
  10. String? politicalView,
})

Suggest provides intelligent predictions or recommendations based on the user's input or context, such as relevant places, points of interest, query terms or search category. It is designed to help users find places or point of interests candidates or identify a follow on query based on incomplete or misspelled queries. It returns a list of possible matches or refinements that can be used to formulate a more accurate query. Users can select the most appropriate suggestion and use it for further searching. The API provides options for filtering results by location and other attributes, and allows for additional features like phonemes and timezones. The response includes refined query terms and detailed place information.

For more information, see Suggest in the Amazon Location Service Developer Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter queryText : The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.

Parameter additionalFeatures : A list of optional additional parameters, such as time zone, that can be requested for each result. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the Core and TimeZone values.

Parameter biasPosition : The position, in longitude and latitude, that the results should be close to. Typically, place results returned are ranked higher the closer they are to this position. Stored in [lng, lat] and in the WGS 84 format.

Parameter filter : A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.

Parameter intendedUse : Indicates if the query results will be persisted in customer infrastructure. Defaults to SingleUse (not stored). Currently, Suggest does not support storage of results.

Parameter key : Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Parameter language : A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the following codes: en, id, km, lo, ms, my, pt, th, tl, vi, zh

Parameter maxQueryRefinements : Maximum number of query terms to be returned for use with a search text query. Not supported in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Parameter maxResults : An optional limit for the number of results returned in a single call.

Default value: 20

Parameter politicalView : The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not supported in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Implementation

Future<SuggestResponse> suggest({
  required String queryText,
  List<SuggestAdditionalFeature>? additionalFeatures,
  List<double>? biasPosition,
  SuggestFilter? filter,
  SuggestIntendedUse? intendedUse,
  String? key,
  String? language,
  int? maxQueryRefinements,
  int? maxResults,
  String? politicalView,
}) async {
  final $query = <String, List<String>>{
    if (key != null) 'key': [key],
  };
  final $payload = <String, dynamic>{
    'QueryText': queryText,
    if (additionalFeatures != null)
      'AdditionalFeatures': additionalFeatures.map((e) => e.value).toList(),
    if (biasPosition != null) 'BiasPosition': biasPosition,
    if (filter != null) 'Filter': filter,
    if (intendedUse != null) 'IntendedUse': intendedUse.value,
    if (language != null) 'Language': language,
    if (maxQueryRefinements != null)
      'MaxQueryRefinements': maxQueryRefinements,
    if (maxResults != null) 'MaxResults': maxResults,
    if (politicalView != null) 'PoliticalView': politicalView,
  };
  final response = await _protocol.sendRaw(
    payload: $payload,
    method: 'POST',
    requestUri: '/v2/suggest',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return SuggestResponse(
    queryRefinements: ($json['QueryRefinements'] as List?)
        ?.nonNulls
        .map((e) => QueryRefinement.fromJson(e as Map<String, dynamic>))
        .toList(),
    resultItems: ($json['ResultItems'] as List?)
        ?.nonNulls
        .map((e) => SuggestResultItem.fromJson(e as Map<String, dynamic>))
        .toList(),
    pricingBucket: _s.extractHeaderStringValue(
        response.headers, 'x-amz-geo-pricing-bucket')!,
  );
}