GeoRoutes class

With the Routes API you can calculate routes and estimate travel time based on up-to-date road network and live traffic information. Key features include:

  • Point-to-point routing with estimated travel time, distance, and turn-by-turn directions. See CalculateRoutes.
  • Multi-point route optimization to minimize travel time or distance. See OptimizeWaypoints.
  • Route matrices for efficient multi-destination planning. See CalculateRouteMatrix.
  • Isoline calculations to determine reachable areas within specified time or distance thresholds. See CalculateIsolines.
  • Map-matching to align GPS traces with the road network. See SnapToRoads.

Constructors

GeoRoutes({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateIsolines({required IsolineThresholds thresholds, IsolineAllowOptions? allow, String? arrivalTime, IsolineAvoidanceOptions? avoid, bool? departNow, String? departureTime, List<double>? destination, IsolineDestinationOptions? destinationOptions, GeometryFormat? isolineGeometryFormat, IsolineGranularityOptions? isolineGranularity, String? key, IsolineOptimizationObjective? optimizeIsolineFor, RoutingObjective? optimizeRoutingFor, List<double>? origin, IsolineOriginOptions? originOptions, IsolineTrafficOptions? traffic, IsolineTravelMode? travelMode, IsolineTravelModeOptions? travelModeOptions}) Future<CalculateIsolinesResponse>
Calculates areas that can be reached within specified time or distance thresholds from a given point. For example, you can use this operation to determine the area within a 30-minute drive of a store location, find neighborhoods within walking distance of a school, or identify delivery zones based on drive time.
calculateRouteMatrix({required List<RouteMatrixDestination> destinations, required List<RouteMatrixOrigin> origins, RouteMatrixAllowOptions? allow, RouteMatrixAvoidanceOptions? avoid, bool? departNow, String? departureTime, RouteMatrixExclusionOptions? exclude, String? key, RoutingObjective? optimizeRoutingFor, RouteMatrixBoundary? routingBoundary, RouteMatrixTrafficOptions? traffic, RouteMatrixTravelMode? travelMode, RouteMatrixTravelModeOptions? travelModeOptions}) Future<CalculateRouteMatrixResponse>
Use CalculateRouteMatrix to compute results for all pairs of Origins to Destinations. Each row corresponds to one entry in Origins. Each entry in the row corresponds to the route from that entry in Origins to an entry in Destinations positions.
calculateRoutes({required List<double> destination, required List<double> origin, RouteAllowOptions? allow, String? arrivalTime, RouteAvoidanceOptions? avoid, bool? departNow, String? departureTime, RouteDestinationOptions? destinationOptions, RouteDriverOptions? driver, RouteExclusionOptions? exclude, MeasurementSystem? instructionsMeasurementSystem, String? key, List<String>? languages, List<RouteLegAdditionalFeature>? legAdditionalFeatures, GeometryFormat? legGeometryFormat, int? maxAlternatives, RoutingObjective? optimizeRoutingFor, RouteOriginOptions? originOptions, List<RouteSpanAdditionalFeature>? spanAdditionalFeatures, RouteTollOptions? tolls, RouteTrafficOptions? traffic, RouteTravelMode? travelMode, RouteTravelModeOptions? travelModeOptions, RouteTravelStepType? travelStepType, List<RouteWaypoint>? waypoints}) Future<CalculateRoutesResponse>
CalculateRoutes computes routes given the following required parameters: Origin and Destination.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimizeWaypoints({required List<double> origin, WaypointOptimizationAvoidanceOptions? avoid, WaypointOptimizationClusteringOptions? clustering, String? departureTime, List<double>? destination, WaypointOptimizationDestinationOptions? destinationOptions, WaypointOptimizationDriverOptions? driver, WaypointOptimizationExclusionOptions? exclude, String? key, WaypointOptimizationSequencingObjective? optimizeSequencingFor, WaypointOptimizationOriginOptions? originOptions, WaypointOptimizationTrafficOptions? traffic, WaypointOptimizationTravelMode? travelMode, WaypointOptimizationTravelModeOptions? travelModeOptions, List<WaypointOptimizationWaypoint>? waypoints}) Future<OptimizeWaypointsResponse>
OptimizeWaypoints calculates the optimal order to travel between a set of waypoints to minimize either the travel time or the distance travelled during the journey, based on road network restrictions and the traffic pattern data.
snapToRoads({required List<RoadSnapTracePoint> tracePoints, String? key, int? snapRadius, GeometryFormat? snappedGeometryFormat, RoadSnapTravelMode? travelMode, RoadSnapTravelModeOptions? travelModeOptions}) Future<SnapToRoadsResponse>
SnapToRoads matches GPS trace to roads most likely traveled on.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited