getVaultLock method
This operation retrieves the following attributes from the
lock-policy subresource set on the specified vault:
- The vault lock policy set on the vault.
-
The state of the vault lock, which is either
InProgessorLocked. - When the lock ID expires. The lock ID is used to complete the vault locking process.
-
When the vault lock was initiated and put into the
InProgressstate.
InProgress state by calling
InitiateVaultLock. A vault lock is put into the Locked
state by calling CompleteVaultLock. You can abort the vault locking
process by calling AbortVaultLock. For more information about the
vault locking process, Amazon
Glacier Vault Lock.
If there is no vault lock policy set on the vault, the operation returns a
404 Not found error. For more information about vault lock
policies, Amazon
Glacier Access Control with Vault Lock Policies.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw NoLongerSupportedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter accountId :
The AccountId value is the AWS account ID of the account that
owns the vault. You can either specify an AWS account ID or optionally a
single '-' (hyphen), in which case Amazon Glacier uses the
AWS account ID associated with the credentials used to sign the request.
If you use an account ID, do not include any hyphens ('-') in the ID.
Parameter vaultName :
The name of the vault.
Implementation
Future<GetVaultLockOutput> getVaultLock({
required String accountId,
required String vaultName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/${Uri.encodeComponent(accountId)}/vaults/${Uri.encodeComponent(vaultName)}/lock-policy',
exceptionFnMap: _exceptionFns,
);
return GetVaultLockOutput.fromJson(response);
}