listProvisionedCapacity method

Future<ListProvisionedCapacityOutput> listProvisionedCapacity({
  1. required String accountId,
})

This operation lists the provisioned capacity units for the specified AWS account.

May throw InvalidParameterValueException. May throw MissingParameterValueException. May throw NoLongerSupportedException. May throw ServiceUnavailableException.

Parameter accountId : The AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, don't include any hyphens ('-') in the ID.

Implementation

Future<ListProvisionedCapacityOutput> listProvisionedCapacity({
  required String accountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/${Uri.encodeComponent(accountId)}/provisioned-capacity',
    exceptionFnMap: _exceptionFns,
  );
  return ListProvisionedCapacityOutput.fromJson(response);
}