createCustomRoutingAccelerator method
Create a custom routing accelerator. A custom routing accelerator directs traffic to one of possibly thousands of Amazon EC2 instance destinations running in a single or multiple virtual private clouds (VPC) subnet endpoints.
Be aware that, by default, all destination EC2 instances in a VPC subnet endpoint cannot receive traffic. To enable all destinations to receive traffic, or to specify individual port mappings that can receive traffic, see the AllowCustomRoutingTraffic operation.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidArgumentException.
May throw LimitExceededException.
May throw TransactionInProgressException.
Parameter name :
The name of a custom routing accelerator. The name can have a maximum of
64 characters, must contain only alphanumeric characters or hyphens (-),
and must not begin or end with a hyphen.
Parameter enabled :
Indicates whether an accelerator is enabled. The value is true or false.
The default value is true.
If the value is set to true, an accelerator cannot be deleted. If set to false, the accelerator can be deleted.
Parameter idempotencyToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency—that is, the uniqueness—of the request.
Parameter ipAddressType :
The IP address type that an accelerator supports. For a custom routing
accelerator, the value must be IPV4.
Parameter ipAddresses :
Optionally, if you've added your own IP address pool to Global Accelerator
(BYOIP), you can choose an IPv4 address from your own pool to use for the
accelerator's static IPv4 address when you create an accelerator.
After you bring an address range to Amazon Web Services, it appears in your account as an address pool. When you create an accelerator, you can assign one IPv4 address from your range to it. Global Accelerator assigns you a second static IPv4 address from an Amazon IP address range. If you bring two IPv4 address ranges to Amazon Web Services, you can assign one IPv4 address from each range to your accelerator. This restriction is because Global Accelerator assigns each address range to a different network zone, for high availability.
You can specify one or two addresses, separated by a space. Do not include the /32 suffix.
Note that you can't update IP addresses for an existing accelerator. To change them, you must create a new accelerator with the new addresses.
For more information, see Bring your own IP addresses (BYOIP) in the Global Accelerator Developer Guide.
Parameter tags :
Create tags for an accelerator.
For more information, see Tagging in Global Accelerator in the Global Accelerator Developer Guide.
Implementation
Future<CreateCustomRoutingAcceleratorResponse>
createCustomRoutingAccelerator({
required String name,
bool? enabled,
String? idempotencyToken,
IpAddressType? ipAddressType,
List<String>? ipAddresses,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'GlobalAccelerator_V20180706.CreateCustomRoutingAccelerator'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (enabled != null) 'Enabled': enabled,
'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (ipAddresses != null) 'IpAddresses': ipAddresses,
if (tags != null) 'Tags': tags,
},
);
return CreateCustomRoutingAcceleratorResponse.fromJson(jsonResponse.body);
}