deleteCrossAccountAttachment method
Delete a cross-account attachment. When you delete an attachment, Global Accelerator revokes the permission to use the resources in the attachment from all principals in the list of principals. Global Accelerator revokes the permission for specific resources.
For more information, see Working with cross-account attachments and resources in Global Accelerator in the Global Accelerator Developer Guide.
May throw AccessDeniedException.
May throw AttachmentNotFoundException.
May throw InternalServiceErrorException.
May throw InvalidArgumentException.
May throw TransactionInProgressException.
Parameter attachmentArn :
The Amazon Resource Name (ARN) for the cross-account attachment to delete.
Implementation
Future<void> deleteCrossAccountAttachment({
required String attachmentArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GlobalAccelerator_V20180706.DeleteCrossAccountAttachment'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AttachmentArn': attachmentArn,
},
);
}