listCrossAccountAttachments method

Future<ListCrossAccountAttachmentsResponse> listCrossAccountAttachments({
  1. int? maxResults,
  2. String? nextToken,
})

List the cross-account attachments that have been created in Global Accelerator.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw InvalidArgumentException. May throw InvalidNextTokenException.

Parameter maxResults : The number of cross-account attachment objects that you want to return with this call. The default value is 10.

Parameter nextToken : The token for the next set of results. You receive this token from a previous call.

Implementation

Future<ListCrossAccountAttachmentsResponse> listCrossAccountAttachments({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'GlobalAccelerator_V20180706.ListCrossAccountAttachments'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListCrossAccountAttachmentsResponse.fromJson(jsonResponse.body);
}