batchDeletePartition method
Deletes one or more partitions in a batch operation.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter databaseName :
The name of the catalog database in which the table in question resides.
Parameter partitionsToDelete :
A list of PartitionInput structures that define the
partitions to be deleted.
Parameter tableName :
The name of the table that contains the partitions to be deleted.
Parameter catalogId :
The ID of the Data Catalog where the partition to be deleted resides. If
none is provided, the Amazon Web Services account ID is used by default.
Implementation
Future<BatchDeletePartitionResponse> batchDeletePartition({
required String databaseName,
required List<PartitionValueList> partitionsToDelete,
required String tableName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.BatchDeletePartition'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'PartitionsToDelete': partitionsToDelete,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
return BatchDeletePartitionResponse.fromJson(jsonResponse.body);
}