batchGetCustomEntityTypes method

Future<BatchGetCustomEntityTypesResponse> batchGetCustomEntityTypes({
  1. required List<String> names,
})

Retrieves the details for the custom patterns specified by a list of names.

May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter names : A list of names of the custom patterns that you want to retrieve.

Implementation

Future<BatchGetCustomEntityTypesResponse> batchGetCustomEntityTypes({
  required List<String> names,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.BatchGetCustomEntityTypes'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Names': names,
    },
  );

  return BatchGetCustomEntityTypesResponse.fromJson(jsonResponse.body);
}