batchGetDataQualityRulesetEvaluationRun method

Future<BatchGetDataQualityRulesetEvaluationRunResponse> batchGetDataQualityRulesetEvaluationRun({
  1. required List<String> runIds,
})

Retrieves the details of multiple evaluation runs in a single request.

May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter runIds : A list of unique run identifiers for the evaluation runs to retrieve.

Implementation

Future<BatchGetDataQualityRulesetEvaluationRunResponse>
    batchGetDataQualityRulesetEvaluationRun({
  required List<String> runIds,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.BatchGetDataQualityRulesetEvaluationRun'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RunIds': runIds,
    },
  );

  return BatchGetDataQualityRulesetEvaluationRunResponse.fromJson(
      jsonResponse.body);
}