batchGetDevEndpoints method
Returns a list of resource metadata for a given list of development
endpoint names. After calling the ListDevEndpoints operation,
you can call this operation to access the data to which you have been
granted permissions. This operation supports all IAM permissions,
including permission conditions that uses tags.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter devEndpointNames :
The list of DevEndpoint names, which might be the names
returned from the ListDevEndpoint operation.
Implementation
Future<BatchGetDevEndpointsResponse> batchGetDevEndpoints({
required List<String> devEndpointNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.BatchGetDevEndpoints'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DevEndpointNames': devEndpointNames,
},
);
return BatchGetDevEndpointsResponse.fromJson(jsonResponse.body);
}