batchPutDataQualityStatisticAnnotation method

Future<BatchPutDataQualityStatisticAnnotationResponse> batchPutDataQualityStatisticAnnotation({
  1. required List<DatapointInclusionAnnotation> inclusionAnnotations,
  2. String? clientToken,
})

Annotate datapoints over time for a specific data quality statistic. The API requires both profileID and statisticID as part of the InclusionAnnotation input. The API only works for a single statisticId across multiple profiles.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw ResourceNumberLimitExceededException.

Parameter inclusionAnnotations : A list of DatapointInclusionAnnotation's. The InclusionAnnotations must contain a profileId and statisticId. If there are multiple InclusionAnnotations, the list must refer to a single statisticId across multiple profileIds.

Parameter clientToken : Client Token.

Implementation

Future<BatchPutDataQualityStatisticAnnotationResponse>
    batchPutDataQualityStatisticAnnotation({
  required List<DatapointInclusionAnnotation> inclusionAnnotations,
  String? clientToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.BatchPutDataQualityStatisticAnnotation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InclusionAnnotations': inclusionAnnotations,
      if (clientToken != null) 'ClientToken': clientToken,
    },
  );

  return BatchPutDataQualityStatisticAnnotationResponse.fromJson(
      jsonResponse.body);
}