createGlueIdentityCenterConfiguration method

Future<CreateGlueIdentityCenterConfigurationResponse> createGlueIdentityCenterConfiguration({
  1. required String instanceArn,
  2. List<String>? scopes,
  3. bool? userBackgroundSessionsEnabled,
})

Creates a new Glue Identity Center configuration to enable integration between Glue and Amazon Web Services IAM Identity Center for authentication and authorization.

May throw AccessDeniedException. May throw AlreadyExistsException. May throw ConcurrentModificationException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter instanceArn : The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.

Parameter scopes : A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.

Parameter userBackgroundSessionsEnabled : Specifies whether users can run background sessions when using Identity Center authentication with Glue services.

Implementation

Future<CreateGlueIdentityCenterConfigurationResponse>
    createGlueIdentityCenterConfiguration({
  required String instanceArn,
  List<String>? scopes,
  bool? userBackgroundSessionsEnabled,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.CreateGlueIdentityCenterConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InstanceArn': instanceArn,
      if (scopes != null) 'Scopes': scopes,
      if (userBackgroundSessionsEnabled != null)
        'UserBackgroundSessionsEnabled': userBackgroundSessionsEnabled,
    },
  );

  return CreateGlueIdentityCenterConfigurationResponse.fromJson(
      jsonResponse.body);
}