createPartition method
Creates a new partition.
May throw AlreadyExistsException.
May throw EntityNotFoundException.
May throw GlueEncryptionException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
May throw ResourceNumberLimitExceededException.
Parameter databaseName :
The name of the metadata database in which the partition is to be created.
Parameter partitionInput :
A PartitionInput structure defining the partition to be
created.
Parameter tableName :
The name of the metadata table in which the partition is to be created.
Parameter catalogId :
The Amazon Web Services account ID of the catalog in which the partition
is to be created.
Implementation
Future<void> createPartition({
required String databaseName,
required PartitionInput partitionInput,
required String tableName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.CreatePartition'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'PartitionInput': partitionInput,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
}