createUsageProfile method

Future<CreateUsageProfileResponse> createUsageProfile({
  1. required ProfileConfiguration configuration,
  2. required String name,
  3. String? description,
  4. Map<String, String>? tags,
})

Creates an Glue usage profile.

May throw AlreadyExistsException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationNotSupportedException. May throw OperationTimeoutException. May throw ResourceNumberLimitExceededException.

Parameter configuration : A ProfileConfiguration object specifying the job and session values for the profile.

Parameter name : The name of the usage profile.

Parameter description : A description of the usage profile.

Parameter tags : A list of tags applied to the usage profile.

Implementation

Future<CreateUsageProfileResponse> createUsageProfile({
  required ProfileConfiguration configuration,
  required String name,
  String? description,
  Map<String, String>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.CreateUsageProfile'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Configuration': configuration,
      'Name': name,
      if (description != null) 'Description': description,
      if (tags != null) 'Tags': tags,
    },
  );

  return CreateUsageProfileResponse.fromJson(jsonResponse.body);
}