deleteConnectionType method

Future<void> deleteConnectionType({
  1. required String connectionType,
})

Deletes a custom connection type in Glue.

The connection type must exist and be registered before it can be deleted. This operation supports cleanup of connection type resources and helps maintain proper lifecycle management of custom connection types.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException. May throw ValidationException.

Parameter connectionType : The name of the connection type to delete. Must reference an existing registered connection type.

Implementation

Future<void> deleteConnectionType({
  required String connectionType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.DeleteConnectionType'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConnectionType': connectionType,
    },
  );
}