deletePartition method
Deletes a specified partition.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter databaseName :
The name of the catalog database in which the table in question resides.
Parameter partitionValues :
The values that define the partition.
Parameter tableName :
The name of the table that contains the partition to be deleted.
Parameter catalogId :
The ID of the Data Catalog where the partition to be deleted resides. If
none is provided, the Amazon Web Services account ID is used by default.
Implementation
Future<void> deletePartition({
required String databaseName,
required List<String> partitionValues,
required String tableName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeletePartition'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'PartitionValues': partitionValues,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
}