deleteResourcePolicy method
Deletes a specified policy.
May throw ConditionCheckFailureException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter policyHashCondition :
The hash value returned when this policy was set.
Parameter resourceArn :
The ARN of the Glue resource for the resource policy to be deleted.
Implementation
Future<void> deleteResourcePolicy({
String? policyHashCondition,
String? resourceArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteResourcePolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (policyHashCondition != null)
'PolicyHashCondition': policyHashCondition,
if (resourceArn != null) 'ResourceArn': resourceArn,
},
);
}