deleteSchemaVersions method
- required SchemaId schemaId,
- required String versions,
Remove versions from the specified schema. A version number or range may
be supplied. If the compatibility mode forbids deleting of a version that
is necessary, such as BACKWARDS_FULL, an error is returned. Calling the
GetSchemaVersions API after this call will list the status of
the deleted versions.
When the range of version numbers contain check pointed version, the API
will return a 409 conflict and will not proceed with the deletion. You
have to remove the checkpoint first using the
DeleteSchemaCheckpoint API before using this API.
You cannot use the DeleteSchemaVersions API to delete the
first schema version in the schema set. The first schema version can only
be deleted by the DeleteSchema API. This operation will also
delete the attached SchemaVersionMetadata under the schema
versions. Hard deletes will be enforced on the database.
If the compatibility mode forbids deleting of a version that is necessary, such as BACKWARDS_FULL, an error is returned.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InvalidInputException.
Parameter schemaId :
This is a wrapper structure that may contain the schema name and Amazon
Resource Name (ARN).
Parameter versions :
A version range may be supplied which may be of the format:
- a single version number, 5
- a range, 5-8 : deletes versions 5, 6, 7, 8
Implementation
Future<DeleteSchemaVersionsResponse> deleteSchemaVersions({
required SchemaId schemaId,
required String versions,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteSchemaVersions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SchemaId': schemaId,
'Versions': versions,
},
);
return DeleteSchemaVersionsResponse.fromJson(jsonResponse.body);
}