deleteTableOptimizer method

Future<void> deleteTableOptimizer({
  1. required String catalogId,
  2. required String databaseName,
  3. required String tableName,
  4. required TableOptimizerType type,
})

Deletes an optimizer and all associated metadata for a table. The optimization will no longer be performed on the table.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw ThrottlingException.

Parameter catalogId : The Catalog ID of the table.

Parameter databaseName : The name of the database in the catalog in which the table resides.

Parameter tableName : The name of the table.

Parameter type : The type of table optimizer.

Implementation

Future<void> deleteTableOptimizer({
  required String catalogId,
  required String databaseName,
  required String tableName,
  required TableOptimizerType type,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.DeleteTableOptimizer'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CatalogId': catalogId,
      'DatabaseName': databaseName,
      'TableName': tableName,
      'Type': type.value,
    },
  );
}