deleteTableVersion method

Future<void> deleteTableVersion({
  1. required String databaseName,
  2. required String tableName,
  3. required String versionId,
  4. String? catalogId,
})

Deletes a specified version of a table.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter databaseName : The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.

Parameter tableName : The name of the table. For Hive compatibility, this name is entirely lowercase.

Parameter versionId : The ID of the table version to be deleted. A VersionID is a string representation of an integer. Each version is incremented by 1.

Parameter catalogId : The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.

Implementation

Future<void> deleteTableVersion({
  required String databaseName,
  required String tableName,
  required String versionId,
  String? catalogId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.DeleteTableVersion'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DatabaseName': databaseName,
      'TableName': tableName,
      'VersionId': versionId,
      if (catalogId != null) 'CatalogId': catalogId,
    },
  );
}