deleteUserDefinedFunction method
Deletes an existing function definition from the Data Catalog.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter databaseName :
The name of the catalog database where the function is located.
Parameter functionName :
The name of the function definition to be deleted.
Parameter catalogId :
The ID of the Data Catalog where the function to be deleted is located. If
none is supplied, the Amazon Web Services account ID is used by default.
Implementation
Future<void> deleteUserDefinedFunction({
required String databaseName,
required String functionName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteUserDefinedFunction'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'FunctionName': functionName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
}