describeInboundIntegrations method

Future<DescribeInboundIntegrationsResponse> describeInboundIntegrations({
  1. String? integrationArn,
  2. String? marker,
  3. int? maxRecords,
  4. String? targetArn,
})

Returns a list of inbound integrations for the specified integration.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw IntegrationNotFoundFault. May throw InternalServerException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationNotSupportedException. May throw TargetResourceNotFound. May throw ValidationException.

Parameter integrationArn : The Amazon Resource Name (ARN) of the integration.

Parameter marker : A token to specify where to start paginating. This is the marker from a previously truncated response.

Parameter maxRecords : The total number of items to return in the output.

Parameter targetArn : The Amazon Resource Name (ARN) of the target resource in the integration.

Implementation

Future<DescribeInboundIntegrationsResponse> describeInboundIntegrations({
  String? integrationArn,
  String? marker,
  int? maxRecords,
  String? targetArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.DescribeInboundIntegrations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (integrationArn != null) 'IntegrationArn': integrationArn,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
      if (targetArn != null) 'TargetArn': targetArn,
    },
  );

  return DescribeInboundIntegrationsResponse.fromJson(jsonResponse.body);
}