describeIntegrations method

Future<DescribeIntegrationsResponse> describeIntegrations({
  1. List<IntegrationFilter>? filters,
  2. String? integrationIdentifier,
  3. String? marker,
  4. int? maxRecords,
})

The API is used to retrieve a list of integrations.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw IntegrationNotFoundFault. May throw InternalServerException. May throw InternalServiceException. May throw InvalidInputException. May throw ValidationException.

Parameter filters : A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.

Parameter integrationIdentifier : The Amazon Resource Name (ARN) for the integration.

Parameter marker : A value that indicates the starting point for the next set of response records in a subsequent request.

Parameter maxRecords : The total number of items to return in the output.

Implementation

Future<DescribeIntegrationsResponse> describeIntegrations({
  List<IntegrationFilter>? filters,
  String? integrationIdentifier,
  String? marker,
  int? maxRecords,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.DescribeIntegrations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (integrationIdentifier != null)
        'IntegrationIdentifier': integrationIdentifier,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
    },
  );

  return DescribeIntegrationsResponse.fromJson(jsonResponse.body);
}