getAsset method

Future<GetAssetOutput> getAsset({
  1. required String identifier,
})

Retrieves the metadata for an asset in Glue Data Catalog, including its forms, additional attachments, and associated glossary terms.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw ThrottlingException.

Parameter identifier : The unique identifier of the asset to retrieve.

Implementation

Future<GetAssetOutput> getAsset({
  required String identifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetAsset'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Identifier': identifier,
    },
  );

  return GetAssetOutput.fromJson(jsonResponse.body);
}