getBlueprint method

Future<GetBlueprintResponse> getBlueprint({
  1. required String name,
  2. bool? includeBlueprint,
  3. bool? includeParameterSpec,
})

Retrieves the details of a blueprint.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter name : The name of the blueprint.

Parameter includeBlueprint : Specifies whether or not to include the blueprint in the response.

Parameter includeParameterSpec : Specifies whether or not to include the parameter specification.

Implementation

Future<GetBlueprintResponse> getBlueprint({
  required String name,
  bool? includeBlueprint,
  bool? includeParameterSpec,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetBlueprint'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (includeBlueprint != null) 'IncludeBlueprint': includeBlueprint,
      if (includeParameterSpec != null)
        'IncludeParameterSpec': includeParameterSpec,
    },
  );

  return GetBlueprintResponse.fromJson(jsonResponse.body);
}