getColumnStatisticsForTable method
Retrieves table statistics of columns.
The Identity and Access Management (IAM) permission required for this
operation is GetTable.
May throw EntityNotFoundException.
May throw GlueEncryptionException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter columnNames :
A list of the column names.
Parameter databaseName :
The name of the catalog database where the partitions reside.
Parameter tableName :
The name of the partitions' table.
Parameter catalogId :
The ID of the Data Catalog where the partitions in question reside. If
none is supplied, the Amazon Web Services account ID is used by default.
Implementation
Future<GetColumnStatisticsForTableResponse> getColumnStatisticsForTable({
required List<String> columnNames,
required String databaseName,
required String tableName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetColumnStatisticsForTable'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ColumnNames': columnNames,
'DatabaseName': databaseName,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
return GetColumnStatisticsForTableResponse.fromJson(jsonResponse.body);
}