getColumnStatisticsTaskRuns method
Retrieves information about all runs associated with the specified table.
May throw OperationTimeoutException.
Parameter databaseName :
The name of the database where the table resides.
Parameter tableName :
The name of the table.
Parameter maxResults :
The maximum size of the response.
Parameter nextToken :
A continuation token, if this is a continuation call.
Implementation
Future<GetColumnStatisticsTaskRunsResponse> getColumnStatisticsTaskRuns({
required String databaseName,
required String tableName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetColumnStatisticsTaskRuns'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'TableName': tableName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetColumnStatisticsTaskRunsResponse.fromJson(jsonResponse.body);
}