getColumnStatisticsTaskSettings method

Future<GetColumnStatisticsTaskSettingsResponse> getColumnStatisticsTaskSettings({
  1. required String databaseName,
  2. required String tableName,
})

Gets settings for a column statistics task.

May throw EntityNotFoundException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter databaseName : The name of the database where the table resides.

Parameter tableName : The name of the table for which to retrieve column statistics.

Implementation

Future<GetColumnStatisticsTaskSettingsResponse>
    getColumnStatisticsTaskSettings({
  required String databaseName,
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetColumnStatisticsTaskSettings'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DatabaseName': databaseName,
      'TableName': tableName,
    },
  );

  return GetColumnStatisticsTaskSettingsResponse.fromJson(jsonResponse.body);
}