getDataCatalogEncryptionSettings method
Future<GetDataCatalogEncryptionSettingsResponse>
getDataCatalogEncryptionSettings({
- String? catalogId,
Retrieves the security configuration for a specified catalog.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter catalogId :
The ID of the Data Catalog to retrieve the security configuration for. If
none is provided, the Amazon Web Services account ID is used by default.
Implementation
Future<GetDataCatalogEncryptionSettingsResponse>
getDataCatalogEncryptionSettings({
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetDataCatalogEncryptionSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (catalogId != null) 'CatalogId': catalogId,
},
);
return GetDataCatalogEncryptionSettingsResponse.fromJson(jsonResponse.body);
}