getIntegrationTableProperties method

Future<GetIntegrationTablePropertiesResponse> getIntegrationTableProperties({
  1. required String resourceArn,
  2. required String tableName,
})

This API is used to retrieve optional override properties for the tables that need to be replicated. These properties can include properties for filtering and partition for source and target tables.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServerException. May throw InternalServiceException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter resourceArn : The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

Parameter tableName : The name of the table to be replicated.

Implementation

Future<GetIntegrationTablePropertiesResponse> getIntegrationTableProperties({
  required String resourceArn,
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetIntegrationTableProperties'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceArn': resourceArn,
      'TableName': tableName,
    },
  );

  return GetIntegrationTablePropertiesResponse.fromJson(jsonResponse.body);
}