getJobBookmark method
Returns information on a job bookmark entry.
For more information about enabling and using job bookmarks, see:
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
May throw ValidationException.
Parameter jobName :
The name of the job in question.
Parameter runId :
The unique run identifier associated with this job run.
Implementation
Future<GetJobBookmarkResponse> getJobBookmark({
required String jobName,
String? runId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetJobBookmark'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobName': jobName,
if (runId != null) 'RunId': runId,
},
);
return GetJobBookmarkResponse.fromJson(jsonResponse.body);
}