getMLTaskRun method
Gets details for a specific task run on a machine learning transform.
Machine learning task runs are asynchronous tasks that Glue runs on your
behalf as part of various machine learning workflows. You can check the
stats of any task run by calling GetMLTaskRun with the
TaskRunID and its parent transform's
TransformID.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter taskRunId :
The unique identifier of the task run.
Parameter transformId :
The unique identifier of the machine learning transform.
Implementation
Future<GetMLTaskRunResponse> getMLTaskRun({
required String taskRunId,
required String transformId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetMLTaskRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TaskRunId': taskRunId,
'TransformId': transformId,
},
);
return GetMLTaskRunResponse.fromJson(jsonResponse.body);
}