getMLTaskRuns method
Gets a list of runs for a machine learning transform. Machine learning
task runs are asynchronous tasks that Glue runs on your behalf as part of
various machine learning workflows. You can get a sortable, filterable
list of machine learning task runs by calling GetMLTaskRuns
with their parent transform's TransformID and other optional
parameters as documented in this section.
This operation returns a list of historic runs and must be paginated.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter transformId :
The unique identifier of the machine learning transform.
Parameter filter :
The filter criteria, in the TaskRunFilterCriteria structure,
for the task run.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
A token for pagination of the results. The default is empty.
Parameter sort :
The sorting criteria, in the TaskRunSortCriteria structure,
for the task run.
Implementation
Future<GetMLTaskRunsResponse> getMLTaskRuns({
required String transformId,
TaskRunFilterCriteria? filter,
int? maxResults,
String? nextToken,
TaskRunSortCriteria? sort,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetMLTaskRuns'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TransformId': transformId,
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sort != null) 'Sort': sort,
},
);
return GetMLTaskRunsResponse.fromJson(jsonResponse.body);
}