getMLTransform method

Future<GetMLTransformResponse> getMLTransform({
  1. required String transformId,
})

Gets an Glue machine learning transform artifact and all its corresponding metadata. Machine learning transforms are a special type of transform that use machine learning to learn the details of the transformation to be performed by learning from examples provided by humans. These transformations are then saved by Glue. You can retrieve their metadata by calling GetMLTransform.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter transformId : The unique identifier of the transform, generated at the time that the transform was created.

Implementation

Future<GetMLTransformResponse> getMLTransform({
  required String transformId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetMLTransform'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TransformId': transformId,
    },
  );

  return GetMLTransformResponse.fromJson(jsonResponse.body);
}