getMaterializedViewRefreshTaskRun method

Future<GetMaterializedViewRefreshTaskRunResponse> getMaterializedViewRefreshTaskRun({
  1. required String catalogId,
  2. required String materializedViewRefreshTaskRunId,
})

Get the associated metadata/information for a task run, given a task run ID.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter catalogId : The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

Parameter materializedViewRefreshTaskRunId : The identifier for the particular materialized view refresh task run.

Implementation

Future<GetMaterializedViewRefreshTaskRunResponse>
    getMaterializedViewRefreshTaskRun({
  required String catalogId,
  required String materializedViewRefreshTaskRunId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetMaterializedViewRefreshTaskRun'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CatalogId': catalogId,
      'MaterializedViewRefreshTaskRunId': materializedViewRefreshTaskRunId,
    },
  );

  return GetMaterializedViewRefreshTaskRunResponse.fromJson(
      jsonResponse.body);
}