getPartitionIndexes method
Retrieves the partition indexes associated with a table.
May throw ConflictException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter databaseName :
Specifies the name of a database from which you want to retrieve partition
indexes.
Parameter tableName :
Specifies the name of a table for which you want to retrieve the partition
indexes.
Parameter catalogId :
The catalog ID where the table resides.
Parameter nextToken :
A continuation token, included if this is a continuation call.
Implementation
Future<GetPartitionIndexesResponse> getPartitionIndexes({
required String databaseName,
required String tableName,
String? catalogId,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetPartitionIndexes'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetPartitionIndexesResponse.fromJson(jsonResponse.body);
}