getTableVersions method

Future<GetTableVersionsResponse> getTableVersions({
  1. required String databaseName,
  2. required String tableName,
  3. AuditContext? auditContext,
  4. String? catalogId,
  5. int? maxResults,
  6. String? nextToken,
})

Retrieves a list of strings that identify available versions of a specified table.

May throw EntityNotFoundException. May throw GlueEncryptionException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter databaseName : The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.

Parameter tableName : The name of the table. For Hive compatibility, this name is entirely lowercase.

Parameter catalogId : The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.

Parameter maxResults : The maximum number of table versions to return in one response.

Parameter nextToken : A continuation token, if this is not the first call.

Implementation

Future<GetTableVersionsResponse> getTableVersions({
  required String databaseName,
  required String tableName,
  AuditContext? auditContext,
  String? catalogId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.GetTableVersions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DatabaseName': databaseName,
      'TableName': tableName,
      if (auditContext != null) 'AuditContext': auditContext,
      if (catalogId != null) 'CatalogId': catalogId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return GetTableVersionsResponse.fromJson(jsonResponse.body);
}