getWorkflowRunProperties method
Retrieves the workflow run properties which were set during the run.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter name :
Name of the workflow which was run.
Parameter runId :
The ID of the workflow run whose run properties should be returned.
Implementation
Future<GetWorkflowRunPropertiesResponse> getWorkflowRunProperties({
required String name,
required String runId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetWorkflowRunProperties'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'RunId': runId,
},
);
return GetWorkflowRunPropertiesResponse.fromJson(jsonResponse.body);
}