listDataQualityStatistics method
Retrieves a list of data quality statistics.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
Parameter maxResults :
The maximum number of results to return in this request.
Parameter nextToken :
A pagination token to request the next page of results.
Parameter profileId :
The Profile ID.
Parameter statisticId :
The Statistic ID.
Parameter timestampFilter :
A timestamp filter.
Implementation
Future<ListDataQualityStatisticsResponse> listDataQualityStatistics({
int? maxResults,
String? nextToken,
String? profileId,
String? statisticId,
TimestampFilter? timestampFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.ListDataQualityStatistics'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (profileId != null) 'ProfileId': profileId,
if (statisticId != null) 'StatisticId': statisticId,
if (timestampFilter != null) 'TimestampFilter': timestampFilter,
},
);
return ListDataQualityStatisticsResponse.fromJson(jsonResponse.body);
}