listIntegrationResourceProperties method

Future<ListIntegrationResourcePropertiesResponse> listIntegrationResourceProperties({
  1. List<IntegrationResourcePropertyFilter>? filters,
  2. String? marker,
  3. int? maxRecords,
})

List integration resource properties for a single customer. It supports the filters, maxRecords and markers.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServerException. May throw InternalServiceException. May throw InvalidInputException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter filters : A list of filters, supported filter Key is SourceArn and TargetArn.

Parameter marker : This is the pagination token for next page, initial value is null.

Parameter maxRecords : This is total number of items to be evaluated.

Implementation

Future<ListIntegrationResourcePropertiesResponse>
    listIntegrationResourceProperties({
  List<IntegrationResourcePropertyFilter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.ListIntegrationResourceProperties'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (marker != null) 'Marker': marker,
      if (maxRecords != null) 'MaxRecords': maxRecords,
    },
  );

  return ListIntegrationResourcePropertiesResponse.fromJson(
      jsonResponse.body);
}