listMLTransforms method
Retrieves a sortable, filterable list of existing Glue machine learning
transforms in this Amazon Web Services account, or the resources with the
specified tag. This operation takes the optional Tags field,
which you can use as a filter of the responses so that tagged resources
can be retrieved as a group. If you choose to use tag filtering, only
resources with the tags are retrieved.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter filter :
A TransformFilterCriteria used to filter the machine learning
transforms.
Parameter maxResults :
The maximum size of a list to return.
Parameter nextToken :
A continuation token, if this is a continuation request.
Parameter sort :
A TransformSortCriteria used to sort the machine learning
transforms.
Parameter tags :
Specifies to return only these tagged resources.
Implementation
Future<ListMLTransformsResponse> listMLTransforms({
TransformFilterCriteria? filter,
int? maxResults,
String? nextToken,
TransformSortCriteria? sort,
Map<String, String>? tags,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.ListMLTransforms'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sort != null) 'Sort': sort,
if (tags != null) 'Tags': tags,
},
);
return ListMLTransformsResponse.fromJson(jsonResponse.body);
}