listMaterializedViewRefreshTaskRuns method

Future<ListMaterializedViewRefreshTaskRunsResponse> listMaterializedViewRefreshTaskRuns({
  1. required String catalogId,
  2. String? databaseName,
  3. int? maxResults,
  4. String? nextToken,
  5. String? tableName,
})

List all task runs for a particular account.

May throw AccessDeniedException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter catalogId : The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

Parameter databaseName : The database where the table resides.

Parameter maxResults : The maximum size of the response.

Parameter nextToken : A continuation token, if this is a continuation call.

Parameter tableName : The name of the table for which statistics is generated.

Implementation

Future<ListMaterializedViewRefreshTaskRunsResponse>
    listMaterializedViewRefreshTaskRuns({
  required String catalogId,
  String? databaseName,
  int? maxResults,
  String? nextToken,
  String? tableName,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.ListMaterializedViewRefreshTaskRuns'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CatalogId': catalogId,
      if (databaseName != null) 'DatabaseName': databaseName,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (tableName != null) 'TableName': tableName,
    },
  );

  return ListMaterializedViewRefreshTaskRunsResponse.fromJson(
      jsonResponse.body);
}