listUsageProfiles method

Future<ListUsageProfilesResponse> listUsageProfiles({
  1. int? maxResults,
  2. String? nextToken,
})

List all the Glue usage profiles.

May throw InternalServiceException. May throw InvalidInputException. May throw OperationNotSupportedException. May throw OperationTimeoutException.

Parameter maxResults : The maximum number of usage profiles to return in a single response.

Parameter nextToken : A continuation token, included if this is a continuation call.

Implementation

Future<ListUsageProfilesResponse> listUsageProfiles({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    200,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.ListUsageProfiles'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListUsageProfilesResponse.fromJson(jsonResponse.body);
}