resumeWorkflowRun method
Restarts selected nodes of a previous partially completed workflow run and resumes the workflow run. The selected nodes and all nodes that are downstream from the selected nodes are run.
May throw ConcurrentRunsExceededException.
May throw EntityNotFoundException.
May throw IllegalWorkflowStateException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter name :
The name of the workflow to resume.
Parameter nodeIds :
A list of the node IDs for the nodes you want to restart. The nodes that
are to be restarted must have a run attempt in the original run.
Parameter runId :
The ID of the workflow run to resume.
Implementation
Future<ResumeWorkflowRunResponse> resumeWorkflowRun({
required String name,
required List<String> nodeIds,
required String runId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.ResumeWorkflowRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'NodeIds': nodeIds,
'RunId': runId,
},
);
return ResumeWorkflowRunResponse.fromJson(jsonResponse.body);
}