startColumnStatisticsTaskRunSchedule method

Future<void> startColumnStatisticsTaskRunSchedule({
  1. required String databaseName,
  2. required String tableName,
})

Starts a column statistics task run schedule.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter databaseName : The name of the database where the table resides.

Parameter tableName : The name of the table for which to start a column statistic task run schedule.

Implementation

Future<void> startColumnStatisticsTaskRunSchedule({
  required String databaseName,
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.StartColumnStatisticsTaskRunSchedule'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DatabaseName': databaseName,
      'TableName': tableName,
    },
  );
}