startCrawler method
Starts a crawl using the specified crawler, regardless of what is scheduled. If the crawler is already running, returns a CrawlerRunningException.
May throw CrawlerRunningException.
May throw EntityNotFoundException.
May throw OperationTimeoutException.
Parameter name :
Name of the crawler to start.
Implementation
Future<void> startCrawler({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.StartCrawler'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
}