startMLLabelingSetGenerationTaskRun method
Starts the active learning workflow for your machine learning transform to improve the transform's quality by generating label sets and adding labels.
When the StartMLLabelingSetGenerationTaskRun finishes, Glue
will have generated a "labeling set" or a set of questions for humans to
answer.
In the case of the FindMatches transform, these questions are
of the form, “What is the correct way to group these rows together into
groups composed entirely of matching records?”
After the labeling process is finished, you can upload your labels with a
call to StartImportLabelsTaskRun. After
StartImportLabelsTaskRun finishes, all future runs of the
machine learning transform will use the new and improved labels and
perform a higher-quality transformation.
Note: The role used to write the generated labeling set to the
OutputS3Path is the role associated with the Machine Learning
Transform, specified in the CreateMLTransform API.
May throw ConcurrentRunsExceededException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter outputS3Path :
The Amazon Simple Storage Service (Amazon S3) path where you generate the
labeling set.
Parameter transformId :
The unique identifier of the machine learning transform.
Implementation
Future<StartMLLabelingSetGenerationTaskRunResponse>
startMLLabelingSetGenerationTaskRun({
required String outputS3Path,
required String transformId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.StartMLLabelingSetGenerationTaskRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OutputS3Path': outputS3Path,
'TransformId': transformId,
},
);
return StartMLLabelingSetGenerationTaskRunResponse.fromJson(
jsonResponse.body);
}