startWorkflowRun method

Future<StartWorkflowRunResponse> startWorkflowRun({
  1. required String name,
  2. Map<String, String>? runProperties,
})

Starts a new run of the specified workflow.

May throw ConcurrentRunsExceededException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException. May throw ResourceNumberLimitExceededException.

Parameter name : The name of the workflow to start.

Parameter runProperties : The workflow run properties for the new workflow run.

Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.

Implementation

Future<StartWorkflowRunResponse> startWorkflowRun({
  required String name,
  Map<String, String>? runProperties,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.StartWorkflowRun'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (runProperties != null) 'RunProperties': runProperties,
    },
  );

  return StartWorkflowRunResponse.fromJson(jsonResponse.body);
}