updateColumnStatisticsForPartition method
Creates or updates partition statistics of columns.
The Identity and Access Management (IAM) permission required for this
operation is UpdatePartition.
May throw EntityNotFoundException.
May throw GlueEncryptionException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter columnStatisticsList :
A list of the column statistics.
Parameter databaseName :
The name of the catalog database where the partitions reside.
Parameter partitionValues :
A list of partition values identifying the partition.
Parameter tableName :
The name of the partitions' table.
Parameter catalogId :
The ID of the Data Catalog where the partitions in question reside. If
none is supplied, the Amazon Web Services account ID is used by default.
Implementation
Future<UpdateColumnStatisticsForPartitionResponse>
updateColumnStatisticsForPartition({
required List<ColumnStatistics> columnStatisticsList,
required String databaseName,
required List<String> partitionValues,
required String tableName,
String? catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.UpdateColumnStatisticsForPartition'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ColumnStatisticsList': columnStatisticsList,
'DatabaseName': databaseName,
'PartitionValues': partitionValues,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
},
);
return UpdateColumnStatisticsForPartitionResponse.fromJson(
jsonResponse.body);
}