updateConnection method

Future<void> updateConnection({
  1. required ConnectionInput connectionInput,
  2. required String name,
  3. String? catalogId,
})

Updates a connection definition in the Data Catalog.

May throw EntityNotFoundException. May throw GlueEncryptionException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter connectionInput : A ConnectionInput object that redefines the connection in question.

Parameter name : The name of the connection definition to update.

Parameter catalogId : The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.

Implementation

Future<void> updateConnection({
  required ConnectionInput connectionInput,
  required String name,
  String? catalogId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.UpdateConnection'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConnectionInput': connectionInput,
      'Name': name,
      if (catalogId != null) 'CatalogId': catalogId,
    },
  );
}