updateDevEndpoint method
Updates a specified development endpoint.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
May throw ValidationException.
Parameter endpointName :
The name of the DevEndpoint to be updated.
Parameter addArguments :
The map of arguments to add the map of arguments used to configure the
DevEndpoint.
Valid arguments are:
-
"--enable-glue-datacatalog": ""
Arguments parameter in the
CreateDevEndpoint or UpdateDevEndpoint APIs. If
no arguments are provided, the version defaults to Python 2.
Parameter addPublicKeys :
The list of public keys for the DevEndpoint to use.
Parameter customLibraries :
Custom Python or Java libraries to be loaded in the
DevEndpoint.
Parameter deleteArguments :
The list of argument keys to be deleted from the map of arguments used to
configure the DevEndpoint.
Parameter deletePublicKeys :
The list of public keys to be deleted from the DevEndpoint.
Parameter publicKey :
The public key for the DevEndpoint to use.
Parameter updateEtlLibraries :
True if the list of custom libraries to be loaded in the
development endpoint needs to be updated, or False if
otherwise.
Implementation
Future<void> updateDevEndpoint({
required String endpointName,
Map<String, String>? addArguments,
List<String>? addPublicKeys,
DevEndpointCustomLibraries? customLibraries,
List<String>? deleteArguments,
List<String>? deletePublicKeys,
String? publicKey,
bool? updateEtlLibraries,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.UpdateDevEndpoint'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EndpointName': endpointName,
if (addArguments != null) 'AddArguments': addArguments,
if (addPublicKeys != null) 'AddPublicKeys': addPublicKeys,
if (customLibraries != null) 'CustomLibraries': customLibraries,
if (deleteArguments != null) 'DeleteArguments': deleteArguments,
if (deletePublicKeys != null) 'DeletePublicKeys': deletePublicKeys,
if (publicKey != null) 'PublicKey': publicKey,
if (updateEtlLibraries != null)
'UpdateEtlLibraries': updateEtlLibraries,
},
);
}