updateRegistry method

Future<UpdateRegistryResponse> updateRegistry({
  1. required String description,
  2. required RegistryId registryId,
})

Updates an existing registry which is used to hold a collection of schemas. The updated properties relate to the registry, and do not modify any of the schemas within the registry.

May throw AccessDeniedException. May throw ConcurrentModificationException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException.

Parameter description : A description of the registry. If description is not provided, this field will not be updated.

Parameter registryId : This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).

Implementation

Future<UpdateRegistryResponse> updateRegistry({
  required String description,
  required RegistryId registryId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSGlue.UpdateRegistry'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Description': description,
      'RegistryId': registryId,
    },
  );

  return UpdateRegistryResponse.fromJson(jsonResponse.body);
}