updateTrigger method
Future<UpdateTriggerResponse>
updateTrigger({
- required String name,
- required TriggerUpdate triggerUpdate,
Updates a trigger definition.
Job arguments may be logged. Do not pass plaintext secrets as arguments. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to keep them within the Job.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter name :
The name of the trigger to update.
Parameter triggerUpdate :
The new values with which to update the trigger.
Implementation
Future<UpdateTriggerResponse> updateTrigger({
required String name,
required TriggerUpdate triggerUpdate,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.UpdateTrigger'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'TriggerUpdate': triggerUpdate,
},
);
return UpdateTriggerResponse.fromJson(jsonResponse.body);
}