Grafana class

Amazon Managed Grafana is a fully managed and secure data visualization service that you can use to instantly query, correlate, and visualize operational metrics, logs, and traces from multiple sources. Amazon Managed Grafana makes it easy to deploy, operate, and scale Grafana, a widely deployed data visualization tool that is popular for its extensible data support.

With Amazon Managed Grafana, you create logically isolated Grafana servers called workspaces. In a workspace, you can create Grafana dashboards and visualizations to analyze your metrics, logs, and traces without having to build, package, or deploy any hardware to run Grafana servers.

Constructors

Grafana({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateLicense({required LicenseType licenseType, required String workspaceId, String? grafanaToken}) Future<AssociateLicenseResponse>
Assigns a Grafana Enterprise license to a workspace. To upgrade, you must use ENTERPRISE for the licenseType, and pass in a valid Grafana Labs token for the grafanaToken. Upgrading to Grafana Enterprise incurs additional fees. For more information, see Upgrade a workspace to Grafana Enterprise.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createWorkspace({required AccountAccessType accountAccessType, required List<AuthenticationProviderTypes> authenticationProviders, required PermissionType permissionType, String? clientToken, Object? configuration, String? grafanaVersion, IPAddressType? ipAddressType, String? kmsKeyId, NetworkAccessConfiguration? networkAccessControl, String? organizationRoleName, String? stackSetName, Map<String, String>? tags, VpcConfiguration? vpcConfiguration, List<DataSourceType>? workspaceDataSources, String? workspaceDescription, String? workspaceName, List<NotificationDestinationType>? workspaceNotificationDestinations, List<String>? workspaceOrganizationalUnits, String? workspaceRoleArn}) Future<CreateWorkspaceResponse>
Creates a workspace. In a workspace, you can create Grafana dashboards and visualizations to analyze your metrics, logs, and traces. You don't have to build, package, or deploy any hardware to run the Grafana server.
createWorkspaceApiKey({required String keyName, required String keyRole, required int secondsToLive, required String workspaceId}) Future<CreateWorkspaceApiKeyResponse>
Creates a Grafana API key for the workspace. This key can be used to authenticate requests sent to the workspace's HTTP API. See https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html for available APIs and example requests.
createWorkspaceServiceAccount({required Role grafanaRole, required String name, required String workspaceId}) Future<CreateWorkspaceServiceAccountResponse>
Creates a service account for the workspace. A service account can be used to call Grafana HTTP APIs, and run automated workloads. After creating the service account with the correct GrafanaRole for your use case, use CreateWorkspaceServiceAccountToken to create a token that can be used to authenticate and authorize Grafana HTTP API calls.
createWorkspaceServiceAccountToken({required String name, required int secondsToLive, required String serviceAccountId, required String workspaceId}) Future<CreateWorkspaceServiceAccountTokenResponse>
Creates a token that can be used to authenticate and authorize Grafana HTTP API operations for the given workspace service account. The service account acts as a user for the API operations, and defines the permissions that are used by the API.
deleteWorkspace({required String workspaceId}) Future<DeleteWorkspaceResponse>
Deletes an Amazon Managed Grafana workspace.
deleteWorkspaceApiKey({required String keyName, required String workspaceId}) Future<DeleteWorkspaceApiKeyResponse>
Deletes a Grafana API key for the workspace.
deleteWorkspaceServiceAccount({required String serviceAccountId, required String workspaceId}) Future<DeleteWorkspaceServiceAccountResponse>
Deletes a workspace service account from the workspace.
deleteWorkspaceServiceAccountToken({required String serviceAccountId, required String tokenId, required String workspaceId}) Future<DeleteWorkspaceServiceAccountTokenResponse>
Deletes a token for the workspace service account.
describeWorkspace({required String workspaceId}) Future<DescribeWorkspaceResponse>
Displays information about one Amazon Managed Grafana workspace.
describeWorkspaceAuthentication({required String workspaceId}) Future<DescribeWorkspaceAuthenticationResponse>
Displays information about the authentication methods used in one Amazon Managed Grafana workspace.
describeWorkspaceConfiguration({required String workspaceId}) Future<DescribeWorkspaceConfigurationResponse>
Gets the current configuration string for the given workspace.
disassociateLicense({required LicenseType licenseType, required String workspaceId}) Future<DisassociateLicenseResponse>
Removes the Grafana Enterprise license from a workspace.
listPermissions({required String workspaceId, String? groupId, int? maxResults, String? nextToken, String? userId, UserType? userType}) Future<ListPermissionsResponse>
Lists the users and groups who have the Grafana Admin and Editor roles in this workspace. If you use this operation without specifying userId or groupId, the operation returns the roles of all users and groups. If you specify a userId or a groupId, only the roles for that user or group are returned. If you do this, you can specify only one userId or one groupId.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
The ListTagsForResource operation returns the tags that are associated with the Amazon Managed Service for Grafana resource specified by the resourceArn. Currently, the only resource that can be tagged is a workspace.
listVersions({int? maxResults, String? nextToken, String? workspaceId}) Future<ListVersionsResponse>
Lists available versions of Grafana. These are available when calling CreateWorkspace. Optionally, include a workspace to list the versions to which it can be upgraded.
listWorkspaces({int? maxResults, String? nextToken}) Future<ListWorkspacesResponse>
Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace. For more complete information about one workspace, use DescribeWorkspace.
listWorkspaceServiceAccounts({required String workspaceId, int? maxResults, String? nextToken}) Future<ListWorkspaceServiceAccountsResponse>
Returns a list of service accounts for a workspace.
listWorkspaceServiceAccountTokens({required String serviceAccountId, required String workspaceId, int? maxResults, String? nextToken}) Future<ListWorkspaceServiceAccountTokensResponse>
Returns a list of tokens for a workspace service account. Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
The TagResource operation associates tags with an Amazon Managed Grafana resource. Currently, the only resource that can be tagged is workspaces.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
The UntagResource operation removes the association of the tag with the Amazon Managed Grafana resource.
updatePermissions({required List<UpdateInstruction> updateInstructionBatch, required String workspaceId}) Future<UpdatePermissionsResponse>
Updates which users in a workspace have the Grafana Admin or Editor roles.
updateWorkspace({required String workspaceId, AccountAccessType? accountAccessType, IPAddressType? ipAddressType, NetworkAccessConfiguration? networkAccessControl, String? organizationRoleName, PermissionType? permissionType, bool? removeNetworkAccessConfiguration, bool? removeVpcConfiguration, String? stackSetName, VpcConfiguration? vpcConfiguration, List<DataSourceType>? workspaceDataSources, String? workspaceDescription, String? workspaceName, List<NotificationDestinationType>? workspaceNotificationDestinations, List<String>? workspaceOrganizationalUnits, String? workspaceRoleArn}) Future<UpdateWorkspaceResponse>
Modifies an existing Amazon Managed Grafana workspace. If you use this operation and omit any optional parameters, the existing values of those parameters are not changed.
updateWorkspaceAuthentication({required List<AuthenticationProviderTypes> authenticationProviders, required String workspaceId, SamlConfiguration? samlConfiguration}) Future<UpdateWorkspaceAuthenticationResponse>
Use this operation to define the identity provider (IdP) that this workspace authenticates users from, using SAML. You can also map SAML assertion attributes to workspace user information and define which groups in the assertion attribute are to have the Admin and Editor roles in the workspace.
updateWorkspaceConfiguration({required Object configuration, required String workspaceId, String? grafanaVersion}) Future<void>
Updates the configuration string for the given workspace

Operators

operator ==(Object other) bool
The equality operator.
inherited