describeWorkspaceAuthentication method
Future<DescribeWorkspaceAuthenticationResponse>
describeWorkspaceAuthentication({
- required String workspaceId,
Displays information about the authentication methods used in one Amazon Managed Grafana workspace.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace to return authentication information about.
Implementation
Future<DescribeWorkspaceAuthenticationResponse>
describeWorkspaceAuthentication({
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/authentication',
exceptionFnMap: _exceptionFns,
);
return DescribeWorkspaceAuthenticationResponse.fromJson(response);
}