describeWorkspaceConfiguration method

Future<DescribeWorkspaceConfigurationResponse> describeWorkspaceConfiguration({
  1. required String workspaceId,
})

Gets the current configuration string for the given workspace.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter workspaceId : The ID of the workspace to get configuration information for.

Implementation

Future<DescribeWorkspaceConfigurationResponse>
    describeWorkspaceConfiguration({
  required String workspaceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeWorkspaceConfigurationResponse.fromJson(response);
}