GreengrassV2 class
IoT Greengrass brings local compute, messaging, data management, sync, and ML inference capabilities to edge devices. This enables devices to collect and analyze data closer to the source of information, react autonomously to local events, and communicate securely with each other on local networks. Local devices can also communicate securely with Amazon Web Services IoT Core and export IoT data to the Amazon Web Services Cloud. IoT Greengrass developers can use Lambda functions and components to create and deploy applications to fleets of edge devices for local operation.
IoT Greengrass Version 2 provides a new major version of the IoT Greengrass Core software, new APIs, and a new console. Use this API reference to learn how to use the IoT Greengrass V2 API operations to manage components, manage deployments, and core devices.
For more information, see What is IoT Greengrass? in the IoT Greengrass V2 Developer Guide.
Constructors
- GreengrassV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateServiceRoleToAccount(
{required String roleArn}) → Future< AssociateServiceRoleToAccountResponse> - Associates a Greengrass service role with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. The role must include the AWSGreengrassResourceAccessRolePolicy managed policy or a custom policy that defines equivalent permissions for the IoT Greengrass features that you use. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
-
batchAssociateClientDeviceWithCoreDevice(
{required String coreDeviceThingName, List< AssociateClientDeviceWithCoreDeviceEntry> ? entries}) → Future<BatchAssociateClientDeviceWithCoreDeviceResponse> - Associates a list of client devices with a core device. Use this API operation to specify which client devices can discover a core device through cloud discovery. With cloud discovery, client devices connect to IoT Greengrass to retrieve associated core devices' connectivity information and certificates. For more information, see Configure cloud discovery in the IoT Greengrass V2 Developer Guide.
-
batchDisassociateClientDeviceFromCoreDevice(
{required String coreDeviceThingName, List< DisassociateClientDeviceFromCoreDeviceEntry> ? entries}) → Future<BatchDisassociateClientDeviceFromCoreDeviceResponse> - Disassociates a list of client devices from a core device. After you disassociate a client device from a core device, the client device won't be able to use cloud discovery to retrieve the core device's connectivity information and certificates.
-
cancelDeployment(
{required String deploymentId}) → Future< CancelDeploymentResponse> - Cancels a deployment. This operation cancels the deployment for devices that haven't yet received it. If a device already received the deployment, this operation doesn't change anything for that device.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createComponentVersion(
{String? clientToken, Uint8List? inlineRecipe, LambdaFunctionRecipeSource? lambdaFunction, Map< String, String> ? tags}) → Future<CreateComponentVersionResponse> - Creates a component. Components are software that run on Greengrass core devices. After you develop and test a component on your core device, you can use this operation to upload your component to IoT Greengrass. Then, you can deploy the component to other core devices.
-
createDeployment(
{required String targetArn, String? clientToken, Map< String, ComponentDeploymentSpecification> ? components, String? deploymentName, DeploymentPolicies? deploymentPolicies, DeploymentIoTJobConfiguration? iotJobConfiguration, String? parentTargetArn, Map<String, String> ? tags}) → Future<CreateDeploymentResponse> - Creates a continuous deployment for a target, which is a Greengrass core device or group of core devices. When you add a new core device to a group of core devices that has a deployment, IoT Greengrass deploys that group's deployment to the new device.
-
deleteComponent(
{required String arn}) → Future< void> - Deletes a version of a component from IoT Greengrass.
-
deleteCoreDevice(
{required String coreDeviceThingName}) → Future< void> - Deletes a Greengrass core device, which is an IoT thing. This operation removes the core device from the list of core devices. This operation doesn't delete the IoT thing. For more information about how to delete the IoT thing, see DeleteThing in the IoT API Reference.
-
deleteDeployment(
{required String deploymentId}) → Future< void> - Deletes a deployment. To delete an active deployment, you must first cancel it. For more information, see CancelDeployment.
-
describeComponent(
{required String arn}) → Future< DescribeComponentResponse> - Retrieves metadata for a version of a component.
-
disassociateServiceRoleFromAccount(
) → Future< DisassociateServiceRoleFromAccountResponse> - Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. Without a service role, IoT Greengrass can't verify the identity of client devices or manage core device connectivity information. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
-
getComponent(
{required String arn, RecipeOutputFormat? recipeOutputFormat}) → Future< GetComponentResponse> - Gets the recipe for a version of a component.
-
getComponentVersionArtifact(
{required String arn, required String artifactName, IotEndpointType? iotEndpointType, S3EndpointType? s3EndpointType}) → Future< GetComponentVersionArtifactResponse> - Gets the pre-signed URL to download a public or a Lambda component artifact. Core devices call this operation to identify the URL that they can use to download an artifact to install.
-
getConnectivityInfo(
{required String thingName}) → Future< GetConnectivityInfoResponse> - Retrieves connectivity information for a Greengrass core device.
-
getCoreDevice(
{required String coreDeviceThingName}) → Future< GetCoreDeviceResponse> - Retrieves metadata for a Greengrass core device.
-
getDeployment(
{required String deploymentId}) → Future< GetDeploymentResponse> - Gets a deployment. Deployments define the components that run on Greengrass core devices.
-
getServiceRoleForAccount(
) → Future< GetServiceRoleForAccountResponse> - Gets the service role associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
-
listClientDevicesAssociatedWithCoreDevice(
{required String coreDeviceThingName, int? maxResults, String? nextToken}) → Future< ListClientDevicesAssociatedWithCoreDeviceResponse> - Retrieves a paginated list of client devices that are associated with a core device.
-
listComponents(
{int? maxResults, String? nextToken, ComponentVisibilityScope? scope}) → Future< ListComponentsResponse> - Retrieves a paginated list of component summaries. This list includes components that you have permission to view.
-
listComponentVersions(
{required String arn, int? maxResults, String? nextToken}) → Future< ListComponentVersionsResponse> - Retrieves a paginated list of all versions for a component. Greater versions are listed first.
-
listCoreDevices(
{int? maxResults, String? nextToken, String? runtime, CoreDeviceStatus? status, String? thingGroupArn}) → Future< ListCoreDevicesResponse> - Retrieves a paginated list of Greengrass core devices.
-
listDeployments(
{DeploymentHistoryFilter? historyFilter, int? maxResults, String? nextToken, String? parentTargetArn, String? targetArn}) → Future< ListDeploymentsResponse> - Retrieves a paginated list of deployments.
-
listEffectiveDeployments(
{required String coreDeviceThingName, int? maxResults, String? nextToken}) → Future< ListEffectiveDeploymentsResponse> - Retrieves a paginated list of deployment jobs that IoT Greengrass sends to Greengrass core devices.
-
listInstalledComponents(
{required String coreDeviceThingName, int? maxResults, String? nextToken, InstalledComponentTopologyFilter? topologyFilter}) → Future< ListInstalledComponentsResponse> -
Retrieves a paginated list of the components that a Greengrass core device
runs. By default, this list doesn't include components that are deployed
as dependencies of other components. To include dependencies in the
response, set the
topologyFilterparameter toALL. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Retrieves the list of tags for an IoT Greengrass resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveComponentCandidates(
{List< ComponentCandidate> ? componentCandidates, ComponentPlatform? platform}) → Future<ResolveComponentCandidatesResponse> - Retrieves a list of components that meet the component, version, and platform requirements of a deployment. Greengrass core devices call this operation when they receive a deployment to identify the components to install.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds tags to an IoT Greengrass resource. If a tag already exists for the resource, this operation updates the tag's value.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from an IoT Greengrass resource.
-
updateConnectivityInfo(
{required List< ConnectivityInfo> connectivityInfo, required String thingName}) → Future<UpdateConnectivityInfoResponse> - Updates connectivity information for a Greengrass core device.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited