deleteDeployment method

Future<void> deleteDeployment({
  1. required String deploymentId,
})

Deletes a deployment. To delete an active deployment, you must first cancel it. For more information, see CancelDeployment.

Deleting a deployment doesn't affect core devices that run that deployment, because core devices store the deployment's configuration on the device. Additionally, core devices can roll back to a previous deployment that has been deleted.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter deploymentId : The ID of the deployment.

Implementation

Future<void> deleteDeployment({
  required String deploymentId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/greengrass/v2/deployments/${Uri.encodeComponent(deploymentId)}',
    exceptionFnMap: _exceptionFns,
  );
}