disassociateServiceRoleFromAccount method

Future<DisassociateServiceRoleFromAccountResponse> disassociateServiceRoleFromAccount()

Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. Without a service role, IoT Greengrass can't verify the identity of client devices or manage core device connectivity information. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.

May throw InternalServerException.

Implementation

Future<DisassociateServiceRoleFromAccountResponse>
    disassociateServiceRoleFromAccount() async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/greengrass/servicerole',
    exceptionFnMap: _exceptionFns,
  );
  return DisassociateServiceRoleFromAccountResponse.fromJson(response);
}