listClientDevicesAssociatedWithCoreDevice method

Future<ListClientDevicesAssociatedWithCoreDeviceResponse> listClientDevicesAssociatedWithCoreDevice({
  1. required String coreDeviceThingName,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves a paginated list of client devices that are associated with a core device.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter coreDeviceThingName : The name of the core device. This is also the name of the IoT thing.

Parameter maxResults : The maximum number of results to be returned per paginated request.

Parameter nextToken : The token to be used for the next set of paginated results.

Implementation

Future<ListClientDevicesAssociatedWithCoreDeviceResponse>
    listClientDevicesAssociatedWithCoreDevice({
  required String coreDeviceThingName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/greengrass/v2/coreDevices/${Uri.encodeComponent(coreDeviceThingName)}/associatedClientDevices',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListClientDevicesAssociatedWithCoreDeviceResponse.fromJson(response);
}