GroundStation class

Welcome to the AWS Ground Station API Reference. AWS Ground Station is a fully managed service that enables you to control satellite communications, downlink and process satellite data, and scale your satellite operations efficiently and cost-effectively without having to build or manage your own ground station infrastructure.

Constructors

GroundStation({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelContact({required String contactId}) Future<ContactIdResponse>
Cancels or stops a contact with a specified contact ID based on its position in the contact lifecycle.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createConfig({required ConfigTypeData configData, required String name, Map<String, String>? tags}) Future<ConfigIdResponse>
Creates a Config with the specified configData parameters.
createDataflowEndpointGroup({required List<EndpointDetails> endpointDetails, int? contactPostPassDurationSeconds, int? contactPrePassDurationSeconds, Map<String, String>? tags}) Future<DataflowEndpointGroupIdResponse>
Creates a DataflowEndpoint group containing the specified list of DataflowEndpoint objects.
createDataflowEndpointGroupV2({required List<CreateEndpointDetails> endpoints, int? contactPostPassDurationSeconds, int? contactPrePassDurationSeconds, Map<String, String>? tags}) Future<CreateDataflowEndpointGroupV2Response>
Creates a DataflowEndpoint group containing the specified list of Ground Station Agent based endpoints.
createEphemeris({required String name, bool? enabled, EphemerisData? ephemeris, DateTime? expirationTime, String? kmsKeyArn, int? priority, String? satelliteId, Map<String, String>? tags}) Future<EphemerisIdResponse>
Create an ephemeris with your specified EphemerisData.
createMissionProfile({required List<List<String>> dataflowEdges, required int minimumViableContactDurationSeconds, required String name, required String trackingConfigArn, int? contactPostPassDurationSeconds, int? contactPrePassDurationSeconds, KmsKey? streamsKmsKey, String? streamsKmsRole, Map<String, String>? tags, String? telemetrySinkConfigArn}) Future<MissionProfileIdResponse>
Creates a mission profile.
deleteConfig({required String configId, required ConfigCapabilityType configType}) Future<ConfigIdResponse>
Deletes a Config.
deleteDataflowEndpointGroup({required String dataflowEndpointGroupId}) Future<DataflowEndpointGroupIdResponse>
Deletes a dataflow endpoint group.
deleteEphemeris({required String ephemerisId}) Future<EphemerisIdResponse>
Delete an ephemeris.
deleteMissionProfile({required String missionProfileId}) Future<MissionProfileIdResponse>
Deletes a mission profile.
describeContact({required String contactId}) Future<DescribeContactResponse>
Describes an existing contact.
describeContactVersion({required String contactId, required int versionId}) Future<DescribeContactVersionResponse>
Describes a specific version of a contact.
describeEphemeris({required String ephemerisId}) Future<DescribeEphemerisResponse>
Retrieve information about an existing ephemeris.
getAgentConfiguration({required String agentId}) Future<GetAgentConfigurationResponse>
May throw DependencyException. May throw InvalidParameterException. May throw ResourceNotFoundException.
getAgentTaskResponseUrl({required String agentId, required String taskId}) Future<GetAgentTaskResponseUrlResponse>
May throw DependencyException. May throw InvalidParameterException. May throw ResourceNotFoundException.
getConfig({required String configId, required ConfigCapabilityType configType}) Future<GetConfigResponse>
Returns Config information.
getDataflowEndpointGroup({required String dataflowEndpointGroupId}) Future<GetDataflowEndpointGroupResponse>
Returns the dataflow endpoint group.
getMinuteUsage({required int month, required int year}) Future<GetMinuteUsageResponse>
Returns the number of reserved minutes used by account.
getMissionProfile({required String missionProfileId}) Future<GetMissionProfileResponse>
Returns a mission profile.
getSatellite({required String satelliteId}) Future<GetSatelliteResponse>
Returns a satellite.
listAntennas({required String groundStationId, int? maxResults, String? nextToken}) Future<ListAntennasResponse>
Returns a list of antennas at a specified ground station.
listConfigs({int? maxResults, String? nextToken}) Future<ListConfigsResponse>
Returns a list of Config objects.
listContacts({required DateTime endTime, required DateTime startTime, required List<ContactStatus> statusList, EphemerisFilter? ephemeris, String? groundStation, int? maxResults, String? missionProfileArn, String? nextToken, String? satelliteArn}) Future<ListContactsResponse>
Returns a list of contacts.
listContactVersions({required String contactId, int? maxResults, String? nextToken}) Future<ListContactVersionsResponse>
Returns a list of versions for a specified contact.
listDataflowEndpointGroups({int? maxResults, String? nextToken}) Future<ListDataflowEndpointGroupsResponse>
Returns a list of DataflowEndpoint groups.
listEphemerides({required DateTime endTime, required DateTime startTime, EphemerisType? ephemerisType, int? maxResults, String? nextToken, String? satelliteId, List<EphemerisStatus>? statusList}) Future<ListEphemeridesResponse>
List your existing ephemerides.
listGroundStationReservations({required DateTime endTime, required String groundStationId, required DateTime startTime, int? maxResults, String? nextToken, List<ReservationType>? reservationTypes}) Future<ListGroundStationReservationsResponse>
Returns a list of reservations for a specified ground station.
listGroundStations({int? maxResults, String? nextToken, String? satelliteId}) Future<ListGroundStationsResponse>
Returns a list of ground stations.
listMissionProfiles({int? maxResults, String? nextToken}) Future<ListMissionProfilesResponse>
Returns a list of mission profiles.
listSatellites({int? maxResults, String? nextToken}) Future<ListSatellitesResponse>
Returns a list of satellites.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of tags for a specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAgent({required AgentDetails agentDetails, required DiscoveryData discoveryData, Map<String, String>? tags}) Future<RegisterAgentResponse>
May throw DependencyException. May throw InvalidParameterException. May throw ResourceNotFoundException.
reserveContact({required DateTime endTime, required String groundStation, required String missionProfileArn, required DateTime startTime, String? satelliteArn, Map<String, String>? tags, TrackingOverrides? trackingOverrides}) Future<ContactIdResponse>
Reserves a contact using specified parameters.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns a tag to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deassigns a resource tag.
updateAgentStatus({required String agentId, required AggregateStatus aggregateStatus, required List<ComponentStatusData> componentStatuses, required String taskId}) Future<UpdateAgentStatusResponse>
May throw DependencyException. May throw InvalidParameterException. May throw ResourceNotFoundException.
updateConfig({required ConfigTypeData configData, required String configId, required ConfigCapabilityType configType, required String name}) Future<ConfigIdResponse>
Updates the Config used when scheduling contacts.
updateContact({required String contactId, String? clientToken, String? satelliteArn, TrackingOverrides? trackingOverrides}) Future<UpdateContactResponse>
Updates a specific contact.
updateEphemeris({required bool enabled, required String ephemerisId, String? name, int? priority}) Future<EphemerisIdResponse>
Update an existing ephemeris.
updateMissionProfile({required String missionProfileId, int? contactPostPassDurationSeconds, int? contactPrePassDurationSeconds, List<List<String>>? dataflowEdges, int? minimumViableContactDurationSeconds, String? name, KmsKey? streamsKmsKey, String? streamsKmsRole, String? telemetrySinkConfigArn, String? trackingConfigArn}) Future<MissionProfileIdResponse>
Updates a mission profile.

Operators

operator ==(Object other) bool
The equality operator.
inherited