createDataflowEndpointGroupV2 method

Future<CreateDataflowEndpointGroupV2Response> createDataflowEndpointGroupV2({
  1. required List<CreateEndpointDetails> endpoints,
  2. int? contactPostPassDurationSeconds,
  3. int? contactPrePassDurationSeconds,
  4. Map<String, String>? tags,
})

Creates a DataflowEndpoint group containing the specified list of Ground Station Agent based endpoints.

The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a contact.

When a contact uses multiple DataflowEndpointConfig objects, each Config must match a DataflowEndpoint in the same group.

May throw DependencyException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException.

Parameter endpoints : Dataflow endpoint group's endpoint definitions

Parameter contactPostPassDurationSeconds : Amount of time, in seconds, after a contact ends that the Ground Station Dataflow Endpoint Group will be in a POSTPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the POSTPASS state.

Parameter contactPrePassDurationSeconds : Amount of time, in seconds, before a contact starts that the Ground Station Dataflow Endpoint Group will be in a PREPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the PREPASS state.

Parameter tags : Tags of a V2 dataflow endpoint group.

Implementation

Future<CreateDataflowEndpointGroupV2Response> createDataflowEndpointGroupV2({
  required List<CreateEndpointDetails> endpoints,
  int? contactPostPassDurationSeconds,
  int? contactPrePassDurationSeconds,
  Map<String, String>? tags,
}) async {
  _s.validateNumRange(
    'contactPostPassDurationSeconds',
    contactPostPassDurationSeconds,
    30,
    480,
  );
  _s.validateNumRange(
    'contactPrePassDurationSeconds',
    contactPrePassDurationSeconds,
    30,
    480,
  );
  final $payload = <String, dynamic>{
    'endpoints': endpoints,
    if (contactPostPassDurationSeconds != null)
      'contactPostPassDurationSeconds': contactPostPassDurationSeconds,
    if (contactPrePassDurationSeconds != null)
      'contactPrePassDurationSeconds': contactPrePassDurationSeconds,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/dataflowEndpointGroupV2',
    exceptionFnMap: _exceptionFns,
  );
  return CreateDataflowEndpointGroupV2Response.fromJson(response);
}