getMinuteUsage method
Returns the number of reserved minutes used by account.
May throw DependencyException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
Parameter month :
The month being requested, with a value of 1-12.
Parameter year :
The year being requested, in the format of YYYY.
Implementation
Future<GetMinuteUsageResponse> getMinuteUsage({
required int month,
required int year,
}) async {
_s.validateNumRange(
'month',
month,
1,
12,
isRequired: true,
);
_s.validateNumRange(
'year',
year,
2018,
3000,
isRequired: true,
);
final $payload = <String, dynamic>{
'month': month,
'year': year,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/minute-usage',
exceptionFnMap: _exceptionFns,
);
return GetMinuteUsageResponse.fromJson(response);
}