createTrustedEntitySet method
Creates a new trusted entity set. In the trusted entity set, you can provide IP addresses and domains that you believe are secure for communication in your Amazon Web Services environment. GuardDuty will not generate findings for the entries that are specified in a trusted entity set. At any given time, you can have only one trusted entity set.
Only users of the administrator account can manage the entity sets, which automatically apply to member accounts.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter activate :
A boolean value that indicates whether GuardDuty is to start using the
uploaded trusted entity set.
Parameter detectorId :
The unique ID of the detector of the GuardDuty account for which you want
to create a trusted entity set.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter format :
The format of the file that contains the trusted entity set.
Parameter location :
The URI of the file that contains the threat entity set. The format of the
Location URL must be a valid Amazon S3 URL format. Invalid
URL formats will result in an error, regardless of whether you activate
the entity set or not. For more information about format of the location
URLs, see Format
of location URL under Step 2: Adding trusted or threat intelligence
data in the Amazon GuardDuty User Guide.
Parameter name :
A user-friendly name to identify the trusted entity set.
The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).
Parameter clientToken :
The idempotency token for the create request.
Parameter expectedBucketOwner :
The Amazon Web Services account ID that owns the Amazon S3 bucket
specified in the location parameter.
Parameter tags :
The tags to be added to a new trusted entity set resource.
Implementation
Future<CreateTrustedEntitySetResponse> createTrustedEntitySet({
required bool activate,
required String detectorId,
required TrustedEntitySetFormat format,
required String location,
required String name,
String? clientToken,
String? expectedBucketOwner,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'activate': activate,
'format': format.value,
'location': location,
'name': name,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (expectedBucketOwner != null)
'expectedBucketOwner': expectedBucketOwner,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/trustedentityset',
exceptionFnMap: _exceptionFns,
);
return CreateTrustedEntitySetResponse.fromJson(response);
}