deleteInvitations method
Deletes invitations sent to the current member account by Amazon Web Services accounts specified by their account IDs.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter accountIds :
A list of account IDs of the Amazon Web Services accounts that sent
invitations to the current member account that you want to delete
invitations from.
Implementation
Future<DeleteInvitationsResponse> deleteInvitations({
required List<String> accountIds,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/invitation/delete',
exceptionFnMap: _exceptionFns,
);
return DeleteInvitationsResponse.fromJson(response);
}