deleteMalwareProtectionPlan method
Deletes the Malware Protection plan ID associated with the Malware Protection plan resource. Use this API only when you no longer want to protect the resource associated with this Malware Protection plan ID.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
Parameter malwareProtectionPlanId :
A unique identifier associated with Malware Protection plan resource.
Implementation
Future<void> deleteMalwareProtectionPlan({
required String malwareProtectionPlanId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/malware-protection-plan/${Uri.encodeComponent(malwareProtectionPlanId)}',
exceptionFnMap: _exceptionFns,
);
}