deletePublishingDestination method

Future<void> deletePublishingDestination({
  1. required String destinationId,
  2. required String detectorId,
})

Deletes the publishing definition with the specified destinationId.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter destinationId : The ID of the publishing destination to delete.

Parameter detectorId : The unique ID of the detector associated with the publishing destination to delete.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Implementation

Future<void> deletePublishingDestination({
  required String destinationId,
  required String detectorId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/publishingDestination/${Uri.encodeComponent(destinationId)}',
    exceptionFnMap: _exceptionFns,
  );
}