deleteThreatEntitySet method

Future<void> deleteThreatEntitySet({
  1. required String detectorId,
  2. required String threatEntitySetId,
})

Deletes the threat entity set that is associated with the specified threatEntitySetId.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter detectorId : The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Parameter threatEntitySetId : The unique ID that helps GuardDuty identify which threat entity set needs to be deleted.

Implementation

Future<void> deleteThreatEntitySet({
  required String detectorId,
  required String threatEntitySetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/threatentityset/${Uri.encodeComponent(threatEntitySetId)}',
    exceptionFnMap: _exceptionFns,
  );
}