deleteThreatIntelSet method

Future<void> deleteThreatIntelSet({
  1. required String detectorId,
  2. required String threatIntelSetId,
})

Deletes the ThreatIntelSet specified by the ThreatIntelSet ID.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter detectorId : The unique ID of the detector that is associated with the threatIntelSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Parameter threatIntelSetId : The unique ID of the threatIntelSet that you want to delete.

Implementation

Future<void> deleteThreatIntelSet({
  required String detectorId,
  required String threatIntelSetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/threatintelset/${Uri.encodeComponent(threatIntelSetId)}',
    exceptionFnMap: _exceptionFns,
  );
}