disassociateFromAdministratorAccount method

Future<void> disassociateFromAdministratorAccount({
  1. required String detectorId,
})

Disassociates the current GuardDuty member account from its administrator account.

When you disassociate an invited member from a GuardDuty delegated administrator, the member account details obtained from the CreateMembers API, including the associated email addresses, are retained. This is done so that the delegated administrator can invoke the InviteMembers API without the need to invoke the CreateMembers API again. To remove the details associated with a member account, the delegated administrator must invoke the DeleteMembers API.

With autoEnableOrganizationMembers configuration for your organization set to ALL, you'll receive an error if you attempt to disable GuardDuty in a member account.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter detectorId : The unique ID of the detector of the GuardDuty member account.

Implementation

Future<void> disassociateFromAdministratorAccount({
  required String detectorId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/administrator/disassociate',
    exceptionFnMap: _exceptionFns,
  );
}