disassociateMembers method
Disassociates GuardDuty member accounts (from the current administrator account) specified by the account IDs.
When you disassociate an invited member from a GuardDuty delegated administrator, the member account details obtained from the CreateMembers API, including the associated email addresses, are retained. This is done so that the delegated administrator can invoke the InviteMembers API without the need to invoke the CreateMembers API again. To remove the details associated with a member account, the delegated administrator must invoke the DeleteMembers API.
With autoEnableOrganizationMembers configuration for your
organization set to ALL, you'll receive an error if you
attempt to disassociate a member account before removing them from your
organization.
If you disassociate a member account that was added by invitation, the member account details obtained from this API, including the associated email addresses, will be retained. This is done so that the delegated administrator can invoke the InviteMembers API without the need to invoke the CreateMembers API again. To remove the details associated with a member account, the delegated administrator must invoke the DeleteMembers API.
When the member accounts added through Organizations are later disassociated, you (administrator) can't invite them by calling the InviteMembers API. You can create an association with these member accounts again only by calling the CreateMembers API.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter accountIds :
A list of account IDs of the GuardDuty member accounts that you want to
disassociate from the administrator account.
Parameter detectorId :
The unique ID of the detector of the GuardDuty account whose members you
want to disassociate from the administrator account.
Implementation
Future<DisassociateMembersResponse> disassociateMembers({
required List<String> accountIds,
required String detectorId,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/member/disassociate',
exceptionFnMap: _exceptionFns,
);
return DisassociateMembersResponse.fromJson(response);
}