getIPSet method

Future<GetIPSetResponse> getIPSet({
  1. required String detectorId,
  2. required String ipSetId,
})

Retrieves the IPSet specified by the ipSetId.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter detectorId : The unique ID of the detector that is associated with the IPSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Parameter ipSetId : The unique ID of the IPSet to retrieve.

Implementation

Future<GetIPSetResponse> getIPSet({
  required String detectorId,
  required String ipSetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/ipset/${Uri.encodeComponent(ipSetId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetIPSetResponse.fromJson(response);
}