getMalwareProtectionPlan method

Future<GetMalwareProtectionPlanResponse> getMalwareProtectionPlan({
  1. required String malwareProtectionPlanId,
})

Retrieves the Malware Protection plan details associated with a Malware Protection plan ID.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerErrorException. May throw ResourceNotFoundException.

Parameter malwareProtectionPlanId : A unique identifier associated with Malware Protection plan resource.

Implementation

Future<GetMalwareProtectionPlanResponse> getMalwareProtectionPlan({
  required String malwareProtectionPlanId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/malware-protection-plan/${Uri.encodeComponent(malwareProtectionPlanId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMalwareProtectionPlanResponse.fromJson(response);
}