getMalwareScan method

Future<GetMalwareScanResponse> getMalwareScan({
  1. required String scanId,
})

Retrieves the detailed information for a specific malware scan. Each member account can view the malware scan details for their own account. An administrator can view malware scan details for all accounts in the organization.

There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.

May throw BadRequestException. May throw InternalServerErrorException. May throw ResourceNotFoundException.

Parameter scanId : A unique identifier that gets generated when you invoke the API without any error. Each malware scan has a corresponding scan ID. Using this scan ID, you can monitor the status of your malware scan.

Implementation

Future<GetMalwareScanResponse> getMalwareScan({
  required String scanId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/malware-scan/${Uri.encodeComponent(scanId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMalwareScanResponse.fromJson(response);
}