getOrganizationStatistics method

Future<GetOrganizationStatisticsResponse> getOrganizationStatistics()

Retrieves how many active member accounts have each feature enabled within GuardDuty. Only a delegated GuardDuty administrator of an organization can run this API.

When you create a new organization, it might take up to 24 hours to generate the statistics for the entire organization.

May throw BadRequestException. May throw InternalServerErrorException.

Implementation

Future<GetOrganizationStatisticsResponse> getOrganizationStatistics() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/organization/statistics',
    exceptionFnMap: _exceptionFns,
  );
  return GetOrganizationStatisticsResponse.fromJson(response);
}