getRemainingFreeTrialDays method

Future<GetRemainingFreeTrialDaysResponse> getRemainingFreeTrialDays({
  1. required List<String> accountIds,
  2. required String detectorId,
})

Provides the number of days left for each data source used in the free trial period.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter accountIds : A list of account identifiers of the GuardDuty member account.

Parameter detectorId : The unique ID of the detector of the GuardDuty member account.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Implementation

Future<GetRemainingFreeTrialDaysResponse> getRemainingFreeTrialDays({
  required List<String> accountIds,
  required String detectorId,
}) async {
  final $payload = <String, dynamic>{
    'accountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/freeTrial/daysRemaining',
    exceptionFnMap: _exceptionFns,
  );
  return GetRemainingFreeTrialDaysResponse.fromJson(response);
}