getThreatEntitySet method

Future<GetThreatEntitySetResponse> getThreatEntitySet({
  1. required String detectorId,
  2. required String threatEntitySetId,
})

Retrieves the threat entity set associated with the specified threatEntitySetId.

May throw BadRequestException. May throw InternalServerErrorException.

Parameter detectorId : The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Parameter threatEntitySetId : The unique ID that helps GuardDuty identify the threat entity set.

Implementation

Future<GetThreatEntitySetResponse> getThreatEntitySet({
  required String detectorId,
  required String threatEntitySetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/detector/${Uri.encodeComponent(detectorId)}/threatentityset/${Uri.encodeComponent(threatEntitySetId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetThreatEntitySetResponse.fromJson(response);
}