listMalwareProtectionPlans method

Future<ListMalwareProtectionPlansResponse> listMalwareProtectionPlans({
  1. String? nextToken,
})

Lists the Malware Protection plan IDs associated with the protected resources in your Amazon Web Services account.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerErrorException.

Parameter nextToken : You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. The default page size is 100 plans.

Implementation

Future<ListMalwareProtectionPlansResponse> listMalwareProtectionPlans({
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/malware-protection-plan',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListMalwareProtectionPlansResponse.fromJson(response);
}