listTrustedEntitySets method
Lists the trusted entity sets associated with the specified GuardDuty detector ID. If you use this operation from a member account, the trusted entity sets that are returned as a response, belong to the administrator account.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the GuardDuty detector that is associated with this
threat entity set.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter maxResults :
You can use this parameter to indicate the maximum number of items you
want in the response. The default value is 50.
Parameter nextToken :
You can use this parameter when paginating results. Set the value of this
parameter to null on your first call to the list action. For subsequent
calls to the action, fill nextToken in the request with the value of
NextToken from the previous response to continue listing data.
Implementation
Future<ListTrustedEntitySetsResponse> listTrustedEntitySets({
required String detectorId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/trustedentityset',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListTrustedEntitySetsResponse.fromJson(response);
}