sendObjectMalwareScan method

Future<void> sendObjectMalwareScan({
  1. S3ObjectForSendObjectMalwareScan? s3Object,
})

Initiates a malware scan for a specific S3 object. This API allows you to perform on-demand malware scanning of individual objects in S3 buckets that have Malware Protection for S3 enabled.

When you use this API, the Amazon Web Services service terms for GuardDuty Malware Protection apply. For more information, see Amazon Web Services service terms for GuardDuty Malware Protection.

May throw AccessDeniedException. May throw BadRequestException. May throw InternalServerErrorException.

Parameter s3Object : The S3 object information for the object you want to scan. The bucket must have a Malware Protection plan configured to use this API.

Implementation

Future<void> sendObjectMalwareScan({
  S3ObjectForSendObjectMalwareScan? s3Object,
}) async {
  final $payload = <String, dynamic>{
    if (s3Object != null) 's3Object': s3Object,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/object-malware-scan/send',
    exceptionFnMap: _exceptionFns,
  );
}