Health class
The Health API provides access to the Health information that appears in the Health Dashboard. You can use the API operations to get information about events that might affect your Amazon Web Services services and resources.
Constructors
- Health({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
describeAffectedAccountsForOrganization(
{required String eventArn, int? maxResults, String? nextToken}) → Future< DescribeAffectedAccountsForOrganizationResponse> - Returns a list of accounts in the organization from Organizations that are affected by the provided event. For more information about the different types of Health events, see Event.
-
describeAffectedEntities(
{required EntityFilter filter, String? locale, int? maxResults, String? nextToken}) → Future< DescribeAffectedEntitiesResponse> - Returns a list of entities that have been affected by the specified events, based on the specified filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the Amazon Web Services service. Events that have impact beyond that of the affected entities, or where the extent of impact is unknown, include at least one entity indicating this.
-
describeAffectedEntitiesForOrganization(
{String? locale, int? maxResults, String? nextToken, List< EntityAccountFilter> ? organizationEntityAccountFilters, List<EventAccountFilter> ? organizationEntityFilters}) → Future<DescribeAffectedEntitiesForOrganizationResponse> - Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in Organizations, based on the filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the Amazon Web Services service.
-
describeEntityAggregates(
{List< String> ? eventArns}) → Future<DescribeEntityAggregatesResponse> - Returns the number of entities that are affected by each of the specified events.
-
describeEntityAggregatesForOrganization(
{required List< String> eventArns, List<String> ? awsAccountIds}) → Future<DescribeEntityAggregatesForOrganizationResponse> - Returns a list of entity aggregates for your Organizations that are affected by each of the specified events.
-
describeEventAggregates(
{required EventAggregateField aggregateField, EventFilter? filter, int? maxResults, String? nextToken}) → Future< DescribeEventAggregatesResponse> - Returns the number of events of each event type (issue, scheduled change, and account notification). If no filter is specified, the counts of all events in each category are returned.
-
describeEventDetails(
{required List< String> eventArns, String? locale}) → Future<DescribeEventDetailsResponse> - Returns detailed information about one or more specified events. Information includes standard event data (Amazon Web Services Region, service, and so on, as returned by DescribeEvents), a detailed event description, and possible additional metadata that depends upon the nature of the event. Affected entities are not included. To retrieve the entities, use the DescribeAffectedEntities operation.
-
describeEventDetailsForOrganization(
{required List< EventAccountFilter> organizationEventDetailFilters, String? locale}) → Future<DescribeEventDetailsForOrganizationResponse> -
Returns detailed information about one or more specified events for one or
more Amazon Web Services accounts in your organization. This information
includes standard event data (such as the Amazon Web Services Region and
service), an event description, and (depending on the event) possible
metadata. This operation doesn't return affected entities, such as the
resources related to the event. To return affected entities, use the DescribeAffectedEntitiesForOrganization
operation.
When you call the
DescribeEventDetailsForOrganizationoperation, specify theorganizationEventDetailFiltersobject in the request. Depending on the Health event type, note the following differences: -
describeEvents(
{EventFilter? filter, String? locale, int? maxResults, String? nextToken}) → Future< DescribeEventsResponse> - Returns information about events that meet the specified filter criteria. Events are returned in a summary form and do not include the detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the DescribeEventDetails and DescribeAffectedEntities operations.
-
describeEventsForOrganization(
{OrganizationEventFilter? filter, String? locale, int? maxResults, String? nextToken}) → Future< DescribeEventsForOrganizationResponse> -
Returns information about events across your organization in
Organizations. You can use the
filtersparameter to specify the events that you want to return. Events are returned in a summary form and don't include the affected accounts, detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the following operations: -
describeEventTypes(
{EventTypeFilter? filter, String? locale, int? maxResults, String? nextToken}) → Future< DescribeEventTypesResponse> - Returns the event types that meet the specified filter criteria. You can use this API operation to find information about the Health event, such as the category, Amazon Web Services service, and event code. The metadata for each event appears in the EventType object.
-
describeHealthServiceStatusForOrganization(
) → Future< DescribeHealthServiceStatusForOrganizationResponse> - This operation provides status information on enabling or disabling Health to work with your organization. To call this operation, you must use the organization's management account.
-
disableHealthServiceAccessForOrganization(
) → Future< void> - Disables Health from working with Organizations. To call this operation, you must sign in to the organization's management account. For more information, see Aggregating Health events in the Health User Guide.
-
enableHealthServiceAccessForOrganization(
) → Future< void> - Enables Health to work with Organizations. You can use the organizational view feature to aggregate events from all Amazon Web Services accounts in your organization in a centralized location.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited