describeAffectedEntitiesForOrganization method

Future<DescribeAffectedEntitiesForOrganizationResponse> describeAffectedEntitiesForOrganization({
  1. String? locale,
  2. int? maxResults,
  3. String? nextToken,
  4. List<EntityAccountFilter>? organizationEntityAccountFilters,
  5. List<EventAccountFilter>? organizationEntityFilters,
})

Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in Organizations, based on the filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the Amazon Web Services service.

At least one event Amazon Resource Name (ARN) and account ID are required.

Before you can call this operation, you must first enable Health to work with Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.

  • This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.
  • This operation doesn't support resource-level permissions. You can't use this operation to allow or deny access to specific Health events. For more information, see Resource- and action-based conditions in the Health User Guide.

May throw InvalidPaginationToken. May throw UnsupportedLocale.

Parameter locale : The locale (language) to return information in. English (en) is the default and the only supported value at this time.

Parameter maxResults : The maximum number of items to return in one batch, between 1 and 100, inclusive.

Parameter nextToken : If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

Parameter organizationEntityAccountFilters : A JSON set of elements including the awsAccountId, eventArn and a set of statusCodes.

Parameter organizationEntityFilters : A JSON set of elements including the awsAccountId and the eventArn.

Implementation

Future<DescribeAffectedEntitiesForOrganizationResponse>
    describeAffectedEntitiesForOrganization({
  String? locale,
  int? maxResults,
  String? nextToken,
  List<EntityAccountFilter>? organizationEntityAccountFilters,
  List<EventAccountFilter>? organizationEntityFilters,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSHealth_20160804.DescribeAffectedEntitiesForOrganization'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (locale != null) 'locale': locale,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
      if (organizationEntityAccountFilters != null)
        'organizationEntityAccountFilters': organizationEntityAccountFilters,
      if (organizationEntityFilters != null)
        'organizationEntityFilters': organizationEntityFilters,
    },
  );

  return DescribeAffectedEntitiesForOrganizationResponse.fromJson(
      jsonResponse.body);
}