describeHealthServiceStatusForOrganization method

Future<DescribeHealthServiceStatusForOrganizationResponse> describeHealthServiceStatusForOrganization()

This operation provides status information on enabling or disabling Health to work with your organization. To call this operation, you must use the organization's management account.

Implementation

Future<DescribeHealthServiceStatusForOrganizationResponse>
    describeHealthServiceStatusForOrganization() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSHealth_20160804.DescribeHealthServiceStatusForOrganization'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return DescribeHealthServiceStatusForOrganizationResponse.fromJson(
      jsonResponse.body);
}