addRoleToInstanceProfile method
Adds the specified IAM role to the specified instance profile. An instance profile can contain only one role, and this quota cannot be increased. You can remove the existing role and then add a different role to an instance profile. You must then wait for the change to appear across all of Amazon Web Services because of eventual consistency. To force the change, you must disassociate the instance profile and then associate the instance profile, or you can stop your instance and then restart it. For more information about roles, see IAM roles in the IAM User Guide. For more information about instance profiles, see Using instance profiles in the IAM User Guide.
May throw EntityAlreadyExistsException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
May throw UnmodifiableEntityException.
Parameter instanceProfileName :
The name of the instance profile to update.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter roleName :
The name of the role to add.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Implementation
Future<void> addRoleToInstanceProfile({
required String instanceProfileName,
required String roleName,
}) async {
final $request = <String, String>{
'InstanceProfileName': instanceProfileName,
'RoleName': roleName,
};
await _protocol.send(
$request,
action: 'AddRoleToInstanceProfile',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}