attachRolePolicy method
Attaches the specified managed policy to the specified IAM role. When you
attach a managed policy to a role, the managed policy becomes part of the
role's permission (access) policy.
Use this operation to attach a managed policy to a role. To embed
an inline policy in a role, use
PutRolePolicy . For more information about policies, see
Managed
policies and inline policies in the IAM User Guide.
As a best practice, you can validate your IAM policies. To learn more, see Validating IAM policies in the IAM User Guide.
May throw InvalidInputException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw PolicyNotAttachableException.
May throw ServiceFailureException.
May throw UnmodifiableEntityException.
Parameter policyArn :
The Amazon Resource Name (ARN) of the IAM policy you want to attach.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
Parameter roleName :
The name (friendly name, not ARN) of the role to attach the policy to.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Implementation
Future<void> attachRolePolicy({
required String policyArn,
required String roleName,
}) async {
final $request = <String, String>{
'PolicyArn': policyArn,
'RoleName': roleName,
};
await _protocol.send(
$request,
action: 'AttachRolePolicy',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}