createAccountAlias method
Creates an alias for your Amazon Web Services account. For information about using an Amazon Web Services account alias, see Creating, deleting, and listing an Amazon Web Services account alias in the Amazon Web Services Sign-In User Guide.
May throw ConcurrentModificationException.
May throw EntityAlreadyExistsException.
May throw LimitExceededException.
May throw ServiceFailureException.
Parameter accountAlias :
The account alias to create.
This parameter allows (through its regex pattern) a string of characters consisting of lowercase letters, digits, and dashes. You cannot start or finish with a dash, nor can you have two dashes in a row.
Implementation
Future<void> createAccountAlias({
required String accountAlias,
}) async {
final $request = <String, String>{
'AccountAlias': accountAlias,
};
await _protocol.send(
$request,
action: 'CreateAccountAlias',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}