createLoginProfile method

Future<CreateLoginProfileResponse> createLoginProfile({
  1. String? password,
  2. bool? passwordResetRequired,
  3. String? userName,
})

Creates a password for the specified IAM user. A password allows an IAM user to access Amazon Web Services services through the Amazon Web Services Management Console.

You can use the CLI, the Amazon Web Services API, or the Users page in the IAM console to create a password for any IAM user. Use ChangePassword to update your own existing password in the My Security Credentials page in the Amazon Web Services Management Console.

For more information about managing passwords, see Managing passwords in the IAM User Guide.

May throw EntityAlreadyExistsException. May throw LimitExceededException. May throw NoSuchEntityException. May throw PasswordPolicyViolationException. May throw ServiceFailureException.

Parameter password : The new password for the user.

This parameter must be omitted when you make the request with an AssumeRoot session. It is required in all other cases.

The regex pattern that is used to validate this parameter is a string of characters. That string can include almost any printable ASCII character from the space (\u0020) through the end of the ASCII character range (\u00FF). You can also include the tab (\u0009), line feed (\u000A), and carriage return (\u000D) characters. Any of these characters are valid in a password. However, many tools, such as the Amazon Web Services Management Console, might restrict the ability to type certain characters because they have special meaning within that tool.

Parameter passwordResetRequired : Specifies whether the user is required to set a new password on next sign-in.

Parameter userName : The name of the IAM user to create a password for. The user must already exist.

This parameter is optional. If no user name is included, it defaults to the principal making the request. When you make this request with root user credentials, you must use an AssumeRoot session to omit the user name.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<CreateLoginProfileResponse> createLoginProfile({
  String? password,
  bool? passwordResetRequired,
  String? userName,
}) async {
  final $request = <String, String>{
    if (password != null) 'Password': password,
    if (passwordResetRequired != null)
      'PasswordResetRequired': passwordResetRequired.toString(),
    if (userName != null) 'UserName': userName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateLoginProfile',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateLoginProfileResult',
  );
  return CreateLoginProfileResponse.fromXml($result);
}