createRole method
Creates a new role for your Amazon Web Services account.
For more information about roles, see IAM roles in the IAM User Guide. For information about quotas for role names and the number of roles you can create, see IAM and STS quotas in the IAM User Guide.
May throw ConcurrentModificationException.
May throw EntityAlreadyExistsException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw MalformedPolicyDocumentException.
May throw ServiceFailureException.
Parameter assumeRolePolicyDocument :
The trust relationship policy document that grants an entity permission to
assume the role.
In IAM, you must provide a JSON policy that has been converted to a string. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.
The regex pattern used to validate this parameter is a string of characters consisting of the following:
-
Any printable ASCII character ranging from the space character
(
\u0020) through the end of the ASCII character range -
The printable characters in the Basic Latin and Latin-1 Supplement
character set (through
\u00FF) -
The special characters tab (
\u0009), line feed (\u000A), and carriage return (\u000D)
Parameter roleName :
The name of the role to create.
IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter description :
A description of the role.
Parameter maxSessionDuration :
The maximum session duration (in seconds) that you want to set for the
specified role. If you do not specify a value for this setting, the
default value of one hour is applied. This setting can have a value from 1
hour to 12 hours.
Anyone who assumes the role from the CLI or API can use the
DurationSeconds API parameter or the
duration-seconds CLI parameter to request a longer session.
The MaxSessionDuration setting determines the maximum
duration that can be requested using the DurationSeconds
parameter. If users don't specify a value for the
DurationSeconds parameter, their security credentials are
valid for one hour by default. This applies when you use the
AssumeRole* API operations or the assume-role*
CLI operations but does not apply when you use those operations to create
a console URL. For more information, see Using
IAM roles in the IAM User Guide.
Parameter path :
The path to the role. For more information about paths, see IAM
Identifiers in the IAM User Guide.
This parameter is optional. If it is not included, it defaults to a slash (/).
This parameter allows (through its regex pattern) a string of
characters consisting of either a forward slash (/) by itself or a string
that must begin and end with forward slashes. In addition, it can contain
any ASCII character from the ! (\u0021) through the DEL
character (\u007F), including most punctuation characters,
digits, and upper and lowercased letters.
Parameter permissionsBoundary :
The ARN of the managed policy that is used to set the permissions boundary
for the role.
A permissions boundary policy defines the maximum permissions that identity-based policies can grant to an entity, but does not grant permissions. Permissions boundaries do not define the maximum permissions that a resource-based policy can grant to an entity. To learn more, see Permissions boundaries for IAM entities in the IAM User Guide.
For more information about policy types, see Policy types in the IAM User Guide.
Parameter tags :
A list of tags that you want to attach to the new role. Each tag consists
of a key name and an associated value. For more information about tagging,
see Tagging
IAM resources in the IAM User Guide.
Implementation
Future<CreateRoleResponse> createRole({
required String assumeRolePolicyDocument,
required String roleName,
String? description,
int? maxSessionDuration,
String? path,
String? permissionsBoundary,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'maxSessionDuration',
maxSessionDuration,
3600,
43200,
);
final $request = <String, String>{
'AssumeRolePolicyDocument': assumeRolePolicyDocument,
'RoleName': roleName,
if (description != null) 'Description': description,
if (maxSessionDuration != null)
'MaxSessionDuration': maxSessionDuration.toString(),
if (path != null) 'Path': path,
if (permissionsBoundary != null)
'PermissionsBoundary': permissionsBoundary,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CreateRole',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateRoleResult',
);
return CreateRoleResponse.fromXml($result);
}