createServiceLinkedRole method
Creates an IAM role that is linked to a specific Amazon Web Services service. The service controls the attached policies and when the role can be deleted. This helps ensure that the service is not broken by an unexpectedly changed or deleted role, which could put your Amazon Web Services resources into an unknown state. Allowing the service to control the role helps improve service stability and proper cleanup when a service and its role are no longer needed. For more information, see Using service-linked roles in the IAM User Guide.
To attach a policy to this service-linked role, you must make the request using the Amazon Web Services service that depends on this role.
May throw InvalidInputException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter awsServiceName :
The service principal for the Amazon Web Services service to which this
role is attached. You use a string similar to a URL but without the
http:// in front. For example:
elasticbeanstalk.amazonaws.com.
Service principals are unique and case-sensitive. To find the exact service principal for your service-linked role, see Amazon Web Services services that work with IAM in the IAM User Guide. Look for the services that have Yes in the Service-Linked Role column. Choose the Yes link to view the service-linked role documentation for that service.
Parameter customSuffix :
A string that you provide, which is combined with the service-provided
prefix to form the complete role name. If you make multiple requests for
the same service, then you must supply a different
CustomSuffix for each request. Otherwise the request fails
with a duplicate role name error. For example, you could add
-1 or -debug to the suffix.
Some services do not support the CustomSuffix parameter. If
you provide an optional suffix and the operation fails, try the operation
again without the suffix.
Parameter description :
The description of the role.
Implementation
Future<CreateServiceLinkedRoleResponse> createServiceLinkedRole({
required String awsServiceName,
String? customSuffix,
String? description,
}) async {
final $request = <String, String>{
'AWSServiceName': awsServiceName,
if (customSuffix != null) 'CustomSuffix': customSuffix,
if (description != null) 'Description': description,
};
final $result = await _protocol.send(
$request,
action: 'CreateServiceLinkedRole',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateServiceLinkedRoleResult',
);
return CreateServiceLinkedRoleResponse.fromXml($result);
}