createUser method
Creates a new IAM user for your Amazon Web Services account.
For information about quotas for the number of IAM users you can create, see IAM and STS quotas in the IAM User Guide.
May throw ConcurrentModificationException.
May throw EntityAlreadyExistsException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter userName :
The name of the user to create.
IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".
Parameter path :
The path for the user name. For more information about paths, see IAM
identifiers in the IAM User Guide.
This parameter is optional. If it is not included, it defaults to a slash (/).
This parameter allows (through its regex pattern) a string of
characters consisting of either a forward slash (/) by itself or a string
that must begin and end with forward slashes. In addition, it can contain
any ASCII character from the ! (\u0021) through the DEL
character (\u007F), including most punctuation characters,
digits, and upper and lowercased letters.
Parameter permissionsBoundary :
The ARN of the managed policy that is used to set the permissions boundary
for the user.
A permissions boundary policy defines the maximum permissions that identity-based policies can grant to an entity, but does not grant permissions. Permissions boundaries do not define the maximum permissions that a resource-based policy can grant to an entity. To learn more, see Permissions boundaries for IAM entities in the IAM User Guide.
For more information about policy types, see Policy types in the IAM User Guide.
Parameter tags :
A list of tags that you want to attach to the new user. Each tag consists
of a key name and an associated value. For more information about tagging,
see Tagging
IAM resources in the IAM User Guide.
Implementation
Future<CreateUserResponse> createUser({
required String userName,
String? path,
String? permissionsBoundary,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'UserName': userName,
if (path != null) 'Path': path,
if (permissionsBoundary != null)
'PermissionsBoundary': permissionsBoundary,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CreateUser',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateUserResult',
);
return CreateUserResponse.fromXml($result);
}