createVirtualMFADevice method

Future<CreateVirtualMFADeviceResponse> createVirtualMFADevice({
  1. required String virtualMFADeviceName,
  2. String? path,
  3. List<Tag>? tags,
})

Creates a new virtual MFA device for the Amazon Web Services account. After creating the virtual MFA, use EnableMFADevice to attach the MFA device to an IAM user. For more information about creating and working with virtual MFA devices, see Using a virtual MFA device in the IAM User Guide.

For information about the maximum number of MFA devices you can create, see IAM and STS quotas in the IAM User Guide.

May throw ConcurrentModificationException. May throw EntityAlreadyExistsException. May throw InvalidInputException. May throw LimitExceededException. May throw ServiceFailureException.

Parameter virtualMFADeviceName : The name of the virtual MFA device, which must be unique. Use with path to uniquely identify a virtual MFA device.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Parameter path : The path for the virtual MFA device. For more information about paths, see IAM identifiers in the IAM User Guide.

This parameter is optional. If it is not included, it defaults to a slash (/).

This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

Parameter tags : A list of tags that you want to attach to the new IAM virtual MFA device. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Implementation

Future<CreateVirtualMFADeviceResponse> createVirtualMFADevice({
  required String virtualMFADeviceName,
  String? path,
  List<Tag>? tags,
}) async {
  final $request = <String, String>{
    'VirtualMFADeviceName': virtualMFADeviceName,
    if (path != null) 'Path': path,
    if (tags != null)
      if (tags.isEmpty)
        'Tags': ''
      else
        for (var i1 = 0; i1 < tags.length; i1++)
          for (var e3 in tags[i1].toQueryMap().entries)
            'Tags.member.${i1 + 1}.${e3.key}': e3.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateVirtualMFADevice',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateVirtualMFADeviceResult',
  );
  return CreateVirtualMFADeviceResponse.fromXml($result);
}