deactivateMFADevice method
Deactivates the specified MFA device and removes it from association with the user name for which it was originally enabled.
For more information about creating and working with virtual MFA devices, see Enabling a virtual multi-factor authentication (MFA) device in the IAM User Guide.
May throw ConcurrentModificationException.
May throw EntityTemporarilyUnmodifiableException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter serialNumber :
The serial number that uniquely identifies the MFA device. For virtual MFA
devices, the serial number is the device ARN.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: =,.@:/-
Parameter userName :
The name of the user whose MFA device you want to deactivate.
This parameter is optional. If no user name is included, it defaults to the principal making the request. When you make this request with root user credentials, you must use an AssumeRoot session to omit the user name.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Implementation
Future<void> deactivateMFADevice({
required String serialNumber,
String? userName,
}) async {
final $request = <String, String>{
'SerialNumber': serialNumber,
if (userName != null) 'UserName': userName,
};
await _protocol.send(
$request,
action: 'DeactivateMFADevice',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}