deleteAccountAlias method
Deletes the specified Amazon Web Services account alias. For information about using an Amazon Web Services account alias, see Creating, deleting, and listing an Amazon Web Services account alias in the Amazon Web Services Sign-In User Guide.
May throw ConcurrentModificationException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter accountAlias :
The name of the account alias to delete.
This parameter allows (through its regex pattern) a string of characters consisting of lowercase letters, digits, and dashes. You cannot start or finish with a dash, nor can you have two dashes in a row.
Implementation
Future<void> deleteAccountAlias({
required String accountAlias,
}) async {
final $request = <String, String>{
'AccountAlias': accountAlias,
};
await _protocol.send(
$request,
action: 'DeleteAccountAlias',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}