deleteLoginProfile method

Future<void> deleteLoginProfile({
  1. String? userName,
})

Deletes the password for the specified IAM user or root user, For more information, see Managing passwords for IAM users.

You can use the CLI, the Amazon Web Services API, or the Users page in the IAM console to delete a password for any IAM user. You can use ChangePassword to update, but not delete, your own password in the My Security Credentials page in the Amazon Web Services Management Console.

May throw EntityTemporarilyUnmodifiableException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter userName : The name of the user whose password you want to delete.

This parameter is optional. If no user name is included, it defaults to the principal making the request. When you make this request with root user credentials, you must use an AssumeRoot session to omit the user name.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<void> deleteLoginProfile({
  String? userName,
}) async {
  final $request = <String, String>{
    if (userName != null) 'UserName': userName,
  };
  await _protocol.send(
    $request,
    action: 'DeleteLoginProfile',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}