deleteOpenIDConnectProvider method
Deletes an OpenID Connect identity provider (IdP) resource object in IAM.
Deleting an IAM OIDC provider resource does not update any roles that reference the provider as a principal in their trust policies. Any attempt to assume a role that references a deleted provider fails.
This operation is idempotent; it does not fail or return an error if you call the operation for a provider that does not exist.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter openIDConnectProviderArn :
The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource
object to delete. You can get a list of OpenID Connect provider resource
ARNs by using the ListOpenIDConnectProviders
operation.
Implementation
Future<void> deleteOpenIDConnectProvider({
required String openIDConnectProviderArn,
}) async {
final $request = <String, String>{
'OpenIDConnectProviderArn': openIDConnectProviderArn,
};
await _protocol.send(
$request,
action: 'DeleteOpenIDConnectProvider',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}