deleteSAMLProvider method

Future<void> deleteSAMLProvider({
  1. required String sAMLProviderArn,
})

Deletes a SAML provider resource in IAM.

Deleting the provider resource from IAM does not update any roles that reference the SAML provider resource's ARN as a principal in their trust policies. Any attempt to assume a role that references a non-existent provider resource ARN fails.

May throw InvalidInputException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter sAMLProviderArn : The Amazon Resource Name (ARN) of the SAML provider to delete.

Implementation

Future<void> deleteSAMLProvider({
  required String sAMLProviderArn,
}) async {
  final $request = <String, String>{
    'SAMLProviderArn': sAMLProviderArn,
  };
  await _protocol.send(
    $request,
    action: 'DeleteSAMLProvider',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}