deleteServerCertificate method
Deletes the specified server certificate.
For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic also includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM.
May throw DeleteConflictException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter serverCertificateName :
The name of the server certificate you want to delete.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Implementation
Future<void> deleteServerCertificate({
required String serverCertificateName,
}) async {
final $request = <String, String>{
'ServerCertificateName': serverCertificateName,
};
await _protocol.send(
$request,
action: 'DeleteServerCertificate',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}