deleteUser method

Future<void> deleteUser({
  1. required String userName,
})

Deletes the specified IAM user. Unlike the Amazon Web Services Management Console, when you delete a user programmatically, you must delete the items attached to the user manually, or the deletion fails. For more information, see Deleting an IAM user. Before attempting to delete a user, remove the following items:

May throw ConcurrentModificationException. May throw DeleteConflictException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter userName : The name of the user to delete.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<void> deleteUser({
  required String userName,
}) async {
  final $request = <String, String>{
    'UserName': userName,
  };
  await _protocol.send(
    $request,
    action: 'DeleteUser',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}