detachGroupPolicy method
Removes the specified managed policy from the specified IAM group.
A group can also have inline policies embedded with it. To delete an inline policy, use DeleteGroupPolicy. For information about policies, see Managed policies and inline policies in the IAM User Guide.
May throw InvalidInputException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter groupName :
The name (friendly name, not ARN) of the IAM group to detach the policy
from.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter policyArn :
The Amazon Resource Name (ARN) of the IAM policy you want to detach.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
Implementation
Future<void> detachGroupPolicy({
required String groupName,
required String policyArn,
}) async {
final $request = <String, String>{
'GroupName': groupName,
'PolicyArn': policyArn,
};
await _protocol.send(
$request,
action: 'DetachGroupPolicy',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}