disableOrganizationsRootSessions method
Disables root user sessions for privileged tasks across member accounts in your organization. When you disable this feature, the management account and the delegated administrator for IAM can no longer perform privileged tasks on member accounts in your organization.
May throw AccountNotManagementOrDelegatedAdministratorException.
May throw OrganizationNotFoundException.
May throw OrganizationNotInAllFeaturesModeException.
May throw ServiceAccessNotEnabledException.
Implementation
Future<DisableOrganizationsRootSessionsResponse>
disableOrganizationsRootSessions() async {
final $request = <String, String>{};
final $result = await _protocol.send(
$request,
action: 'DisableOrganizationsRootSessions',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DisableOrganizationsRootSessionsResult',
);
return DisableOrganizationsRootSessionsResponse.fromXml($result);
}