enableOrganizationsRootSessions method
Allows the management account or delegated administrator to perform privileged tasks on member accounts in your organization. For more information, see Centrally manage root access for member accounts in the Identity and Access Management User Guide.
Before you enable this feature, you must have an account configured with the following settings:
- You must manage your Amazon Web Services accounts in Organizations.
- Enable trusted access for Identity and Access Management in Organizations. For details, see IAM and Organizations in the Organizations User Guide.
May throw AccountNotManagementOrDelegatedAdministratorException.
May throw CallerIsNotManagementAccountException.
May throw OrganizationNotFoundException.
May throw OrganizationNotInAllFeaturesModeException.
May throw ServiceAccessNotEnabledException.
Implementation
Future<EnableOrganizationsRootSessionsResponse>
enableOrganizationsRootSessions() async {
final $request = <String, String>{};
final $result = await _protocol.send(
$request,
action: 'EnableOrganizationsRootSessions',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'EnableOrganizationsRootSessionsResult',
);
return EnableOrganizationsRootSessionsResponse.fromXml($result);
}