generateCredentialReport method

Future<GenerateCredentialReportResponse> generateCredentialReport()

Generates a credential report for the Amazon Web Services account. For more information about the credential report, see Getting credential reports in the IAM User Guide.

May throw LimitExceededException. May throw ServiceFailureException.

Implementation

Future<GenerateCredentialReportResponse> generateCredentialReport() async {
  final $request = <String, String>{};
  final $result = await _protocol.send(
    $request,
    action: 'GenerateCredentialReport',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'GenerateCredentialReportResult',
  );
  return GenerateCredentialReportResponse.fromXml($result);
}