getAccountPasswordPolicy method

Future<GetAccountPasswordPolicyResponse> getAccountPasswordPolicy()

Retrieves the password policy for the Amazon Web Services account. This tells you the complexity requirements and mandatory rotation periods for the IAM user passwords in your account. For more information about using a password policy, see Managing an IAM password policy.

May throw NoSuchEntityException. May throw ServiceFailureException.

Implementation

Future<GetAccountPasswordPolicyResponse> getAccountPasswordPolicy() async {
  final $request = <String, String>{};
  final $result = await _protocol.send(
    $request,
    action: 'GetAccountPasswordPolicy',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'GetAccountPasswordPolicyResult',
  );
  return GetAccountPasswordPolicyResponse.fromXml($result);
}