getDelegationRequest method

Future<GetDelegationRequestResponse> getDelegationRequest({
  1. required String delegationRequestId,
  2. bool? delegationPermissionCheck,
})

Retrieves information about a specific delegation request.

If a delegation request has no owner or owner account, GetDelegationRequest for that delegation request can be called by any account. If the owner account is assigned but there is no owner id, only identities within that owner account can call GetDelegationRequest for the delegation request. Once the delegation request is fully owned, the owner of the request gets a default permission to get that delegation request. For more details, see Managing Permissions for Delegation Requests.

May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter delegationRequestId : The unique identifier of the delegation request to retrieve.

Parameter delegationPermissionCheck : Specifies whether to perform a permission check for the delegation request.

If set to true, the GetDelegationRequest API call will start a permission check process. This process calculates whether the caller has sufficient permissions to cover the asks from this delegation request.

Setting this parameter to true does not guarantee an answer in the response. See the PermissionCheckStatus and the PermissionCheckResult response attributes for further details.

Implementation

Future<GetDelegationRequestResponse> getDelegationRequest({
  required String delegationRequestId,
  bool? delegationPermissionCheck,
}) async {
  final $request = <String, String>{
    'DelegationRequestId': delegationRequestId,
    if (delegationPermissionCheck != null)
      'DelegationPermissionCheck': delegationPermissionCheck.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'GetDelegationRequest',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'GetDelegationRequestResult',
  );
  return GetDelegationRequestResponse.fromXml($result);
}