getServiceLinkedRoleDeletionStatus method
Future<GetServiceLinkedRoleDeletionStatusResponse>
getServiceLinkedRoleDeletionStatus({
- required String deletionTaskId,
Retrieves the status of your service-linked role deletion. After you use
DeleteServiceLinkedRole
to submit a service-linked role for deletion, you can use the
DeletionTaskId parameter in
GetServiceLinkedRoleDeletionStatus to check the status of the
deletion. If the deletion fails, this operation returns the reason that it
failed, if that information is returned by the service.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter deletionTaskId :
The deletion task identifier. This identifier is returned by the DeleteServiceLinkedRole
operation in the format
task/aws-service-role/.
Implementation
Future<GetServiceLinkedRoleDeletionStatusResponse>
getServiceLinkedRoleDeletionStatus({
required String deletionTaskId,
}) async {
final $request = <String, String>{
'DeletionTaskId': deletionTaskId,
};
final $result = await _protocol.send(
$request,
action: 'GetServiceLinkedRoleDeletionStatus',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetServiceLinkedRoleDeletionStatusResult',
);
return GetServiceLinkedRoleDeletionStatusResponse.fromXml($result);
}