listAccountAliases method
Lists the account alias associated with the Amazon Web Services account (Note: you can have only one). For information about using an Amazon Web Services account alias, see Creating, deleting, and listing an Amazon Web Services account alias in the IAM User Guide.
May throw ServiceFailureException.
Parameter marker :
Use this parameter only when paginating results and only after you receive
a response indicating that the results are truncated. Set it to the value
of the Marker element in the response that you received to
indicate where the next call should start.
Parameter maxItems :
Use this only when paginating results to indicate the maximum number of
items you want in the response. If additional items exist beyond the
maximum you specify, the IsTruncated response element is
true.
If you do not include this parameter, the number of items defaults to 100.
Note that IAM might return fewer results, even when there are more results
available. In that case, the IsTruncated response element
returns true, and Marker contains a value to
include in the subsequent call that tells the service where to continue
from.
Implementation
Future<ListAccountAliasesResponse> listAccountAliases({
String? marker,
int? maxItems,
}) async {
_s.validateNumRange(
'maxItems',
maxItems,
1,
1000,
);
final $request = <String, String>{
if (marker != null) 'Marker': marker,
if (maxItems != null) 'MaxItems': maxItems.toString(),
};
final $result = await _protocol.send(
$request,
action: 'ListAccountAliases',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListAccountAliasesResult',
);
return ListAccountAliasesResponse.fromXml($result);
}