listDelegationRequests method

Future<ListDelegationRequestsResponse> listDelegationRequests({
  1. String? marker,
  2. int? maxItems,
  3. String? ownerId,
})

Lists delegation requests based on the specified criteria.

If a delegation request has no owner, even if it is assigned to a specific account, it will not be part of the ListDelegationRequests output for that account.

For more details, see Managing Permissions for Delegation Requests.

May throw InvalidInputException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter marker : Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.

Parameter maxItems : Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.

If you do not include this parameter, the number of items defaults to 100. Note that IAM may return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from.

Parameter ownerId : The owner ID to filter delegation requests by.

Implementation

Future<ListDelegationRequestsResponse> listDelegationRequests({
  String? marker,
  int? maxItems,
  String? ownerId,
}) async {
  _s.validateNumRange(
    'maxItems',
    maxItems,
    1,
    1000,
  );
  final $request = <String, String>{
    if (marker != null) 'Marker': marker,
    if (maxItems != null) 'MaxItems': maxItems.toString(),
    if (ownerId != null) 'OwnerId': ownerId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListDelegationRequests',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListDelegationRequestsResult',
  );
  return ListDelegationRequestsResponse.fromXml($result);
}