listSAMLProviders method

Future<ListSAMLProvidersResponse> listSAMLProviders()

Lists the SAML provider resource objects defined in IAM in the account. IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a SAML provider, see GetSAMLProvider.

May throw ServiceFailureException.

Implementation

Future<ListSAMLProvidersResponse> listSAMLProviders() async {
  final $request = <String, String>{};
  final $result = await _protocol.send(
    $request,
    action: 'ListSAMLProviders',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListSAMLProvidersResult',
  );
  return ListSAMLProvidersResponse.fromXml($result);
}