removeUserFromGroup method

Future<void> removeUserFromGroup({
  1. required String groupName,
  2. required String userName,
})

Removes the specified user from the specified group.

May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter groupName : The name of the group to update.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Parameter userName : The name of the user to remove.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<void> removeUserFromGroup({
  required String groupName,
  required String userName,
}) async {
  final $request = <String, String>{
    'GroupName': groupName,
    'UserName': userName,
  };
  await _protocol.send(
    $request,
    action: 'RemoveUserFromGroup',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}