sendDelegationToken method
Sends the exchange token for an accepted delegation request.
The exchange token is sent to the partner via an asynchronous notification channel, established by the partner.
The delegation request must be in the ACCEPTED state when
calling this API. After the SendDelegationToken API call is
successful, the request transitions to a FINALIZED state and
cannot be rolled back. However, a user may reject an accepted request
before the SendDelegationToken API is called.
For more details, see Managing Permissions for Delegation Requests.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter delegationRequestId :
The unique identifier of the delegation request for which to send the
token.
Implementation
Future<void> sendDelegationToken({
required String delegationRequestId,
}) async {
final $request = <String, String>{
'DelegationRequestId': delegationRequestId,
};
await _protocol.send(
$request,
action: 'SendDelegationToken',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}