setDefaultPolicyVersion method
Sets the specified version of the specified policy as the policy's default (operative) version.
This operation affects all users, groups, and roles that the policy is attached to. To list the users, groups, and roles that the policy is attached to, use ListEntitiesForPolicy.
For information about managed policies, see Managed policies and inline policies in the IAM User Guide.
May throw InvalidInputException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter policyArn :
The Amazon Resource Name (ARN) of the IAM policy whose default version you
want to set.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
Parameter versionId :
The version of the policy to set as the default (operative) version.
For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.
Implementation
Future<void> setDefaultPolicyVersion({
required String policyArn,
required String versionId,
}) async {
final $request = <String, String>{
'PolicyArn': policyArn,
'VersionId': versionId,
};
await _protocol.send(
$request,
action: 'SetDefaultPolicyVersion',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}