tagOpenIDConnectProvider method

Future<void> tagOpenIDConnectProvider({
  1. required String openIDConnectProviderArn,
  2. required List<Tag> tags,
})

Adds one or more tags to an OpenID Connect (OIDC)-compatible identity provider. For more information about these providers, see About web identity federation. If a tag with the same key name already exists, then that tag is overwritten with the new value.

A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:

  • Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.
  • Access control - Include tags in IAM identity-based and resource-based policies. You can use tags to restrict access to only an OIDC provider that has a specified tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.

May throw ConcurrentModificationException. May throw InvalidInputException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter openIDConnectProviderArn : The ARN of the OIDC identity provider in IAM to which you want to add tags.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Parameter tags : The list of tags that you want to attach to the OIDC identity provider in IAM. Each tag consists of a key name and an associated value.

Implementation

Future<void> tagOpenIDConnectProvider({
  required String openIDConnectProviderArn,
  required List<Tag> tags,
}) async {
  final $request = <String, String>{
    'OpenIDConnectProviderArn': openIDConnectProviderArn,
    if (tags.isEmpty)
      'Tags': ''
    else
      for (var i1 = 0; i1 < tags.length; i1++)
        for (var e3 in tags[i1].toQueryMap().entries)
          'Tags.member.${i1 + 1}.${e3.key}': e3.value,
  };
  await _protocol.send(
    $request,
    action: 'TagOpenIDConnectProvider',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}