tagUser method

Future<void> tagUser({
  1. required List<Tag> tags,
  2. required String userName,
})

Adds one or more tags to an IAM user. If a tag with the same key name already exists, then that tag is overwritten with the new value.

A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:

  • Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.
  • Access control - Include tags in IAM identity-based and resource-based policies. You can use tags to restrict access to only an IAM requesting user that has a specified tag attached. You can also restrict access to only those resources that have a certain tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.
  • Cost allocation - Use tags to help track which individuals and teams are using which Amazon Web Services resources.
For more information about tagging, see Tagging IAM identities in the IAM User Guide.

May throw ConcurrentModificationException. May throw InvalidInputException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter tags : The list of tags that you want to attach to the IAM user. Each tag consists of a key name and an associated value.

Parameter userName : The name of the IAM user to which you want to add tags.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<void> tagUser({
  required List<Tag> tags,
  required String userName,
}) async {
  final $request = <String, String>{
    if (tags.isEmpty)
      'Tags': ''
    else
      for (var i1 = 0; i1 < tags.length; i1++)
        for (var e3 in tags[i1].toQueryMap().entries)
          'Tags.member.${i1 + 1}.${e3.key}': e3.value,
    'UserName': userName,
  };
  await _protocol.send(
    $request,
    action: 'TagUser',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}