untagMFADevice method
Removes the specified tags from the IAM virtual multi-factor authentication (MFA) device. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter serialNumber :
The unique identifier for the IAM virtual MFA device from which you want
to remove tags. For virtual MFA devices, the serial number is the same as
the ARN.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter tagKeys :
A list of key names as a simple array of strings. The tags with matching
keys are removed from the specified instance profile.
Implementation
Future<void> untagMFADevice({
required String serialNumber,
required List<String> tagKeys,
}) async {
final $request = <String, String>{
'SerialNumber': serialNumber,
if (tagKeys.isEmpty)
'TagKeys': ''
else
for (var i1 = 0; i1 < tagKeys.length; i1++)
'TagKeys.member.${i1 + 1}': tagKeys[i1],
};
await _protocol.send(
$request,
action: 'UntagMFADevice',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}