untagOpenIDConnectProvider method
Removes the specified tags from the specified OpenID Connect (OIDC)-compatible identity provider in IAM. For more information about OIDC providers, see About web identity federation. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter openIDConnectProviderArn :
The ARN of the OIDC provider in IAM from which you want to remove tags.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter tagKeys :
A list of key names as a simple array of strings. The tags with matching
keys are removed from the specified OIDC provider.
Implementation
Future<void> untagOpenIDConnectProvider({
required String openIDConnectProviderArn,
required List<String> tagKeys,
}) async {
final $request = <String, String>{
'OpenIDConnectProviderArn': openIDConnectProviderArn,
if (tagKeys.isEmpty)
'TagKeys': ''
else
for (var i1 = 0; i1 < tagKeys.length; i1++)
'TagKeys.member.${i1 + 1}': tagKeys[i1],
};
await _protocol.send(
$request,
action: 'UntagOpenIDConnectProvider',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}