updateAccessKey method

Future<void> updateAccessKey({
  1. required String accessKeyId,
  2. required StatusType status,
  3. String? userName,
})

Changes the status of the specified access key from Active to Inactive, or vice versa. This operation can be used to disable a user's key as part of a key rotation workflow.

If the UserName is not specified, the user name is determined implicitly based on the Amazon Web Services access key ID used to sign the request. If a temporary access key is used, then UserName is required. If a long-term key is assigned to the user, then UserName is not required. This operation works for access keys under the Amazon Web Services account. Consequently, you can use this operation to manage Amazon Web Services account root user credentials even if the Amazon Web Services account has no associated users.

For information about rotating keys, see Managing keys and certificates in the IAM User Guide.

May throw InvalidInputException. May throw LimitExceededException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter accessKeyId : The access key ID of the secret access key you want to update.

This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.

Parameter status : The status you want to assign to the secret access key. Active means that the key can be used for programmatic calls to Amazon Web Services, while Inactive means that the key cannot be used.

Parameter userName : The name of the user whose key you want to update.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<void> updateAccessKey({
  required String accessKeyId,
  required StatusType status,
  String? userName,
}) async {
  final $request = <String, String>{
    'AccessKeyId': accessKeyId,
    'Status': status.value,
    if (userName != null) 'UserName': userName,
  };
  await _protocol.send(
    $request,
    action: 'UpdateAccessKey',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}