updateDelegationRequest method
Updates an existing delegation request with additional information. When
the delegation request is updated, it reaches the
PENDING_APPROVAL state.
Once a delegation request has an owner, that owner gets a default permission to update the delegation request. For more details, see Managing Permissions for Delegation Requests.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter delegationRequestId :
The unique identifier of the delegation request to update.
Parameter notes :
Additional notes or comments to add to the delegation request.
Implementation
Future<void> updateDelegationRequest({
required String delegationRequestId,
String? notes,
}) async {
final $request = <String, String>{
'DelegationRequestId': delegationRequestId,
if (notes != null) 'Notes': notes,
};
await _protocol.send(
$request,
action: 'UpdateDelegationRequest',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}