updateOpenIDConnectProviderThumbprint method
Replaces the existing list of server certificate thumbprints associated with an OpenID Connect (OIDC) provider resource object with a new list of thumbprints.
The list that you pass with this operation completely replaces the existing list of thumbprints. (The lists are not merged.)
Typically, you need to update a thumbprint only when the identity provider certificate changes, which occurs rarely. However, if the provider's certificate does change, any attempt to assume an IAM role that specifies the OIDC provider as a principal fails until the certificate thumbprint is updated.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter openIDConnectProviderArn :
The Amazon Resource Name (ARN) of the IAM OIDC provider resource object
for which you want to update the thumbprint. You can get a list of OIDC
provider ARNs by using the ListOpenIDConnectProviders
operation.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
Parameter thumbprintList :
A list of certificate thumbprints that are associated with the specified
IAM OpenID Connect provider. For more information, see CreateOpenIDConnectProvider.
Implementation
Future<void> updateOpenIDConnectProviderThumbprint({
required String openIDConnectProviderArn,
required List<String> thumbprintList,
}) async {
final $request = <String, String>{
'OpenIDConnectProviderArn': openIDConnectProviderArn,
if (thumbprintList.isEmpty)
'ThumbprintList': ''
else
for (var i1 = 0; i1 < thumbprintList.length; i1++)
'ThumbprintList.member.${i1 + 1}': thumbprintList[i1],
};
await _protocol.send(
$request,
action: 'UpdateOpenIDConnectProviderThumbprint',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}