updateRoleDescription method
Use UpdateRole instead.
Modifies only the description of a role. This operation performs the same
function as the Description parameter in the
UpdateRole operation.
May throw NoSuchEntityException.
May throw ServiceFailureException.
May throw UnmodifiableEntityException.
Parameter description :
The new description that you want to apply to the specified role.
Parameter roleName :
The name of the role that you want to modify.
Implementation
Future<UpdateRoleDescriptionResponse> updateRoleDescription({
required String description,
required String roleName,
}) async {
final $request = <String, String>{
'Description': description,
'RoleName': roleName,
};
final $result = await _protocol.send(
$request,
action: 'UpdateRoleDescription',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdateRoleDescriptionResult',
);
return UpdateRoleDescriptionResponse.fromXml($result);
}