uploadSigningCertificate method

Future<UploadSigningCertificateResponse> uploadSigningCertificate({
  1. required String certificateBody,
  2. String? userName,
})

Uploads an X.509 signing certificate and associates it with the specified IAM user. Some Amazon Web Services services require you to use certificates to validate requests that are signed with a corresponding private key. When you upload the certificate, its default status is Active.

For information about when you would use an X.509 signing certificate, see Managing server certificates in IAM in the IAM User Guide.

If the UserName is not specified, the IAM user name is determined implicitly based on the Amazon Web Services access key ID used to sign the request. This operation works for access keys under the Amazon Web Services account. Consequently, you can use this operation to manage Amazon Web Services account root user credentials even if the Amazon Web Services account has no associated users.

May throw ConcurrentModificationException. May throw DuplicateCertificateException. May throw EntityAlreadyExistsException. May throw InvalidCertificateException. May throw LimitExceededException. May throw MalformedCertificateException. May throw NoSuchEntityException. May throw ServiceFailureException.

Parameter certificateBody : The contents of the signing certificate.

The regex pattern used to validate this parameter is a string of characters consisting of the following:

  • Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range
  • The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)
  • The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)

Parameter userName : The name of the user the signing certificate is for.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Implementation

Future<UploadSigningCertificateResponse> uploadSigningCertificate({
  required String certificateBody,
  String? userName,
}) async {
  final $request = <String, String>{
    'CertificateBody': certificateBody,
    if (userName != null) 'UserName': userName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'UploadSigningCertificate',
    version: '2010-05-08',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'UploadSigningCertificateResult',
  );
  return UploadSigningCertificateResponse.fromXml($result);
}