deleteGroup method

Future<void> deleteGroup({
  1. required String groupId,
  2. required String identityStoreId,
})

Delete a group within an identity store given GroupId.

May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter groupId : The identifier for a group in the identity store.

Parameter identityStoreId : The globally unique identifier for the identity store.

Implementation

Future<void> deleteGroup({
  required String groupId,
  required String identityStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSIdentityStore.DeleteGroup'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GroupId': groupId,
      'IdentityStoreId': identityStoreId,
    },
  );
}