deleteUser method

Future<void> deleteUser({
  1. required String identityStoreId,
  2. required String userId,
})

Deletes a user within an identity store given UserId.

May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter identityStoreId : The globally unique identifier for the identity store.

Parameter userId : The identifier for a user in the identity store.

Implementation

Future<void> deleteUser({
  required String identityStoreId,
  required String userId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSIdentityStore.DeleteUser'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'IdentityStoreId': identityStoreId,
      'UserId': userId,
    },
  );
}