describeGroup method

Future<DescribeGroupResponse> describeGroup({
  1. required String groupId,
  2. required String identityStoreId,
})

Retrieves the group metadata and attributes from GroupId in an identity store.

May throw ResourceNotFoundException. May throw ValidationException.

Parameter groupId : The identifier for a group in the identity store.

Parameter identityStoreId : The globally unique identifier for the identity store, such as d-1234567890. In this example, d- is a fixed prefix, and 1234567890 is a randomly generated string that contains numbers and lower case letters. This value is generated at the time that a new identity store is created.

Implementation

Future<DescribeGroupResponse> describeGroup({
  required String groupId,
  required String identityStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSIdentityStore.DescribeGroup'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GroupId': groupId,
      'IdentityStoreId': identityStoreId,
    },
  );

  return DescribeGroupResponse.fromJson(jsonResponse.body);
}