Imagebuilder class
EC2 Image Builder is a fully managed Amazon Web Services service that makes it easier to automate the creation, management, and deployment of customized, secure, and up-to-date "golden" server images that are pre-installed and pre-configured with software and settings to meet specific IT standards.
Constructors
- Imagebuilder({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelImageCreation(
{required String imageBuildVersionArn, String? clientToken}) → Future< CancelImageCreationResponse> - CancelImageCreation cancels the creation of Image. This operation can only be used on images in a non-terminal state.
-
cancelLifecycleExecution(
{required String lifecycleExecutionId, String? clientToken}) → Future< CancelLifecycleExecutionResponse> - Cancel a specific image lifecycle policy runtime instance.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createComponent(
{required String name, required Platform platform, required String semanticVersion, String? changeDescription, String? clientToken, String? data, String? description, bool? dryRun, String? kmsKeyId, List< String> ? supportedOsVersions, Map<String, String> ? tags, String? uri}) → Future<CreateComponentResponse> - Creates a new component that can be used to build, validate, test, and assess your image. The component is based on a YAML document that you specify using exactly one of the following methods:
-
createContainerRecipe(
{required ContainerType containerType, required String name, required String parentImage, required String semanticVersion, required TargetContainerRepository targetRepository, String? clientToken, List< ComponentConfiguration> ? components, String? description, String? dockerfileTemplateData, String? dockerfileTemplateUri, String? imageOsVersionOverride, InstanceConfiguration? instanceConfiguration, String? kmsKeyId, Platform? platformOverride, Map<String, String> ? tags, String? workingDirectory}) → Future<CreateContainerRecipeResponse> - Creates a new container recipe. Container recipes define how images are configured, tested, and assessed.
-
createDistributionConfiguration(
{required List< Distribution> distributions, required String name, String? clientToken, String? description, Map<String, String> ? tags}) → Future<CreateDistributionConfigurationResponse> - Creates a new distribution configuration. Distribution configurations define and configure the outputs of your pipeline.
-
createImage(
{required String infrastructureConfigurationArn, String? clientToken, String? containerRecipeArn, String? distributionConfigurationArn, bool? enhancedImageMetadataEnabled, String? executionRole, String? imageRecipeArn, ImageScanningConfiguration? imageScanningConfiguration, ImageTestsConfiguration? imageTestsConfiguration, ImageLoggingConfiguration? loggingConfiguration, Map< String, String> ? tags, List<WorkflowConfiguration> ? workflows}) → Future<CreateImageResponse> - Creates a new image. This request will create a new image along with all of the configured output resources defined in the distribution configuration. You must specify exactly one recipe for your image, using either a ContainerRecipeArn or an ImageRecipeArn.
-
createImagePipeline(
{required String infrastructureConfigurationArn, required String name, String? clientToken, String? containerRecipeArn, String? description, String? distributionConfigurationArn, bool? enhancedImageMetadataEnabled, String? executionRole, String? imageRecipeArn, ImageScanningConfiguration? imageScanningConfiguration, Map< String, String> ? imageTags, ImageTestsConfiguration? imageTestsConfiguration, PipelineLoggingConfiguration? loggingConfiguration, Schedule? schedule, PipelineStatus? status, Map<String, String> ? tags, List<WorkflowConfiguration> ? workflows}) → Future<CreateImagePipelineResponse> - Creates a new image pipeline. Image pipelines enable you to automate the creation and distribution of images.
-
createImageRecipe(
{required String name, required String parentImage, required String semanticVersion, AdditionalInstanceConfiguration? additionalInstanceConfiguration, Map< String, String> ? amiTags, List<InstanceBlockDeviceMapping> ? blockDeviceMappings, String? clientToken, List<ComponentConfiguration> ? components, String? description, Map<String, String> ? tags, String? workingDirectory}) → Future<CreateImageRecipeResponse> - Creates a new image recipe. Image recipes define how images are configured, tested, and assessed.
-
createInfrastructureConfiguration(
{required String instanceProfileName, required String name, String? clientToken, String? description, InstanceMetadataOptions? instanceMetadataOptions, List< String> ? instanceTypes, String? keyPair, Logging? logging, Placement? placement, Map<String, String> ? resourceTags, List<String> ? securityGroupIds, String? snsTopicArn, String? subnetId, Map<String, String> ? tags, bool? terminateInstanceOnFailure}) → Future<CreateInfrastructureConfigurationResponse> - Creates a new infrastructure configuration. An infrastructure configuration defines the environment in which your image will be built and tested.
-
createLifecyclePolicy(
{required String executionRole, required String name, required List< LifecyclePolicyDetail> policyDetails, required LifecyclePolicyResourceSelection resourceSelection, required LifecyclePolicyResourceType resourceType, String? clientToken, String? description, LifecyclePolicyStatus? status, Map<String, String> ? tags}) → Future<CreateLifecyclePolicyResponse> - Create a lifecycle policy resource.
-
createWorkflow(
{required String name, required String semanticVersion, required WorkflowType type, String? changeDescription, String? clientToken, String? data, String? description, bool? dryRun, String? kmsKeyId, Map< String, String> ? tags, String? uri}) → Future<CreateWorkflowResponse> - Create a new workflow or a new version of an existing workflow.
-
deleteComponent(
{required String componentBuildVersionArn}) → Future< DeleteComponentResponse> - Deletes a component build version.
-
deleteContainerRecipe(
{required String containerRecipeArn}) → Future< DeleteContainerRecipeResponse> - Deletes a container recipe.
-
deleteDistributionConfiguration(
{required String distributionConfigurationArn}) → Future< DeleteDistributionConfigurationResponse> - Deletes a distribution configuration.
-
deleteImage(
{required String imageBuildVersionArn}) → Future< DeleteImageResponse> - Deletes an Image Builder image resource. This does not delete any EC2 AMIs or ECR container images that are created during the image build process. You must clean those up separately, using the appropriate Amazon EC2 or Amazon ECR console actions, or API or CLI commands.
-
deleteImagePipeline(
{required String imagePipelineArn}) → Future< DeleteImagePipelineResponse> - Deletes an image pipeline.
-
deleteImageRecipe(
{required String imageRecipeArn}) → Future< DeleteImageRecipeResponse> - Deletes an image recipe.
-
deleteInfrastructureConfiguration(
{required String infrastructureConfigurationArn}) → Future< DeleteInfrastructureConfigurationResponse> - Deletes an infrastructure configuration.
-
deleteLifecyclePolicy(
{required String lifecyclePolicyArn}) → Future< DeleteLifecyclePolicyResponse> - Delete the specified lifecycle policy resource.
-
deleteWorkflow(
{required String workflowBuildVersionArn}) → Future< DeleteWorkflowResponse> - Deletes a specific workflow resource.
-
distributeImage(
{required String distributionConfigurationArn, required String executionRole, required String sourceImage, String? clientToken, ImageLoggingConfiguration? loggingConfiguration, Map< String, String> ? tags}) → Future<DistributeImageResponse> - DistributeImage distributes existing AMIs to additional regions and accounts without rebuilding the image.
-
getComponent(
{required String componentBuildVersionArn}) → Future< GetComponentResponse> - Gets a component object.
-
getComponentPolicy(
{required String componentArn}) → Future< GetComponentPolicyResponse> - Gets a component policy.
-
getContainerRecipe(
{required String containerRecipeArn}) → Future< GetContainerRecipeResponse> - Retrieves a container recipe.
-
getContainerRecipePolicy(
{required String containerRecipeArn}) → Future< GetContainerRecipePolicyResponse> - Retrieves the policy for a container recipe.
-
getDistributionConfiguration(
{required String distributionConfigurationArn}) → Future< GetDistributionConfigurationResponse> - Gets a distribution configuration.
-
getImage(
{required String imageBuildVersionArn}) → Future< GetImageResponse> - Gets an image.
-
getImagePipeline(
{required String imagePipelineArn}) → Future< GetImagePipelineResponse> - Gets an image pipeline.
-
getImagePolicy(
{required String imageArn}) → Future< GetImagePolicyResponse> - Gets an image policy.
-
getImageRecipe(
{required String imageRecipeArn}) → Future< GetImageRecipeResponse> - Gets an image recipe.
-
getImageRecipePolicy(
{required String imageRecipeArn}) → Future< GetImageRecipePolicyResponse> - Gets an image recipe policy.
-
getInfrastructureConfiguration(
{required String infrastructureConfigurationArn}) → Future< GetInfrastructureConfigurationResponse> - Gets an infrastructure configuration.
-
getLifecycleExecution(
{required String lifecycleExecutionId}) → Future< GetLifecycleExecutionResponse> - Get the runtime information that was logged for a specific runtime instance of the lifecycle policy.
-
getLifecyclePolicy(
{required String lifecyclePolicyArn}) → Future< GetLifecyclePolicyResponse> - Get details for the specified image lifecycle policy.
-
getMarketplaceResource(
{required String resourceArn, required MarketplaceResourceType resourceType, String? resourceLocation}) → Future< GetMarketplaceResourceResponse> - Verify the subscription and perform resource dependency checks on the requested Amazon Web Services Marketplace resource. For Amazon Web Services Marketplace components, the response contains fields to download the components and their artifacts.
-
getWorkflow(
{required String workflowBuildVersionArn}) → Future< GetWorkflowResponse> - Get a workflow resource object.
-
getWorkflowExecution(
{required String workflowExecutionId}) → Future< GetWorkflowExecutionResponse> - Get the runtime information that was logged for a specific runtime instance of the workflow.
-
getWorkflowStepExecution(
{required String stepExecutionId}) → Future< GetWorkflowStepExecutionResponse> - Get the runtime information that was logged for a specific runtime instance of the workflow step.
-
importComponent(
{required ComponentFormat format, required String name, required Platform platform, required String semanticVersion, required ComponentType type, String? changeDescription, String? clientToken, String? data, String? description, String? kmsKeyId, Map< String, String> ? tags, String? uri}) → Future<ImportComponentResponse> - Imports a component and transforms its data into a component document.
-
importDiskImage(
{required String infrastructureConfigurationArn, required String name, required String osVersion, required String platform, required String semanticVersion, required String uri, String? clientToken, String? description, String? executionRole, ImageLoggingConfiguration? loggingConfiguration, RegisterImageOptions? registerImageOptions, Map< String, String> ? tags, WindowsConfiguration? windowsConfiguration}) → Future<ImportDiskImageResponse> - Import a Windows operating system image from a verified Microsoft ISO disk file. The following disk images are supported:
-
importVmImage(
{required String name, required Platform platform, required String semanticVersion, required String vmImportTaskId, String? clientToken, String? description, ImageLoggingConfiguration? loggingConfiguration, String? osVersion, Map< String, String> ? tags}) → Future<ImportVmImageResponse> - When you export your virtual machine (VM) from its virtualization environment, that process creates a set of one or more disk container files that act as snapshots of your VM’s environment, settings, and data. The Amazon EC2 API ImportImage action uses those files to import your VM and create an AMI. To import using the CLI command, see import-image
-
listComponentBuildVersions(
{String? componentVersionArn, int? maxResults, String? nextToken}) → Future< ListComponentBuildVersionsResponse> - Returns the list of component build versions for the specified component version Amazon Resource Name (ARN).
-
listComponents(
{bool? byName, List< Filter> ? filters, int? maxResults, String? nextToken, Ownership? owner}) → Future<ListComponentsResponse> -
Returns the list of components that can be filtered by name, or by using
the listed
filtersto streamline results. Newly created components can take up to two minutes to appear in the ListComponents API Results. -
listContainerRecipes(
{List< Filter> ? filters, int? maxResults, String? nextToken, Ownership? owner}) → Future<ListContainerRecipesResponse> - Returns a list of container recipes.
-
listDistributionConfigurations(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListDistributionConfigurationsResponse> - Returns a list of distribution configurations.
-
listImageBuildVersions(
{List< Filter> ? filters, String? imageVersionArn, int? maxResults, String? nextToken}) → Future<ListImageBuildVersionsResponse> - Returns a list of image build versions.
-
listImagePackages(
{required String imageBuildVersionArn, int? maxResults, String? nextToken}) → Future< ListImagePackagesResponse> - List the Packages that are associated with an Image Build Version, as determined by Amazon Web Services Systems Manager Inventory at build time.
-
listImagePipelineImages(
{required String imagePipelineArn, List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListImagePipelineImagesResponse> - Returns a list of images created by the specified pipeline.
-
listImagePipelines(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListImagePipelinesResponse> - Returns a list of image pipelines.
-
listImageRecipes(
{List< Filter> ? filters, int? maxResults, String? nextToken, Ownership? owner}) → Future<ListImageRecipesResponse> - Returns a list of image recipes.
-
listImages(
{bool? byName, List< Filter> ? filters, bool? includeDeprecated, int? maxResults, String? nextToken, Ownership? owner}) → Future<ListImagesResponse> - Returns the list of images that you have access to. Newly created images can take up to two minutes to appear in the ListImages API Results.
-
listImageScanFindingAggregations(
{Filter? filter, String? nextToken}) → Future< ListImageScanFindingAggregationsResponse> -
Returns a list of image scan aggregations for your account. You can filter
by the type of key that Image Builder uses to group results. For example,
if you want to get a list of findings by severity level for one of your
pipelines, you might specify your pipeline with the
imagePipelineArnfilter. If you don't specify a filter, Image Builder returns an aggregation for your account. -
listImageScanFindings(
{List< ImageScanFindingsFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListImageScanFindingsResponse> - Returns a list of image scan findings for your account.
-
listInfrastructureConfigurations(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListInfrastructureConfigurationsResponse> - Returns a list of infrastructure configurations.
-
listLifecycleExecutionResources(
{required String lifecycleExecutionId, int? maxResults, String? nextToken, String? parentResourceId}) → Future< ListLifecycleExecutionResourcesResponse> - List resources that the runtime instance of the image lifecycle identified for lifecycle actions.
-
listLifecycleExecutions(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListLifecycleExecutionsResponse> - Get the lifecycle runtime history for the specified resource.
-
listLifecyclePolicies(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListLifecyclePoliciesResponse> - Get a list of lifecycle policies in your Amazon Web Services account.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns the list of tags for the specified resource.
-
listWaitingWorkflowSteps(
{int? maxResults, String? nextToken}) → Future< ListWaitingWorkflowStepsResponse> - Get a list of workflow steps that are waiting for action for workflows in your Amazon Web Services account.
-
listWorkflowBuildVersions(
{int? maxResults, String? nextToken, String? workflowVersionArn}) → Future< ListWorkflowBuildVersionsResponse> - Returns a list of build versions for a specific workflow resource.
-
listWorkflowExecutions(
{required String imageBuildVersionArn, int? maxResults, String? nextToken}) → Future< ListWorkflowExecutionsResponse> - Returns a list of workflow runtime instance metadata objects for a specific image build version.
-
listWorkflows(
{bool? byName, List< Filter> ? filters, int? maxResults, String? nextToken, Ownership? owner}) → Future<ListWorkflowsResponse> - Lists workflow build versions based on filtering parameters.
-
listWorkflowStepExecutions(
{required String workflowExecutionId, int? maxResults, String? nextToken}) → Future< ListWorkflowStepExecutionsResponse> - Returns runtime data for each step in a runtime instance of the workflow that you specify in the request.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putComponentPolicy(
{required String componentArn, required String policy}) → Future< PutComponentPolicyResponse> -
Applies a policy to a component. We recommend that you call the RAM API CreateResourceShare
to share resources. If you call the Image Builder API
PutComponentPolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared. -
putContainerRecipePolicy(
{required String containerRecipeArn, required String policy}) → Future< PutContainerRecipePolicyResponse> -
Applies a policy to a container image. We recommend that you call the RAM
API CreateResourceShare
(https://docs.aws.amazon.com//ram/latest/APIReference/API_CreateResourceShare.html)
to share resources. If you call the Image Builder API
PutContainerImagePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy (https://docs.aws.amazon.com//ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html) in order for the resource to be visible to all principals with whom the resource is shared. -
putImagePolicy(
{required String imageArn, required String policy}) → Future< PutImagePolicyResponse> -
Applies a policy to an image. We recommend that you call the RAM API CreateResourceShare
to share resources. If you call the Image Builder API
PutImagePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared. -
putImageRecipePolicy(
{required String imageRecipeArn, required String policy}) → Future< PutImageRecipePolicyResponse> -
Applies a policy to an image recipe. We recommend that you call the RAM
API CreateResourceShare
to share resources. If you call the Image Builder API
PutImageRecipePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared. -
retryImage(
{required String imageBuildVersionArn, String? clientToken}) → Future< RetryImageResponse> - RetryImage retries an image distribution without rebuilding the image.
-
sendWorkflowStepAction(
{required WorkflowStepActionType action, required String imageBuildVersionArn, required String stepExecutionId, String? clientToken, String? reason}) → Future< SendWorkflowStepActionResponse> -
Pauses or resumes image creation when the associated workflow runs a
WaitForActionstep. -
startImagePipelineExecution(
{required String imagePipelineArn, String? clientToken, Map< String, String> ? tags}) → Future<StartImagePipelineExecutionResponse> - Manually triggers a pipeline to create an image.
-
startResourceStateUpdate(
{required String resourceArn, required ResourceState state, String? clientToken, ResourceStateUpdateExclusionRules? exclusionRules, String? executionRole, ResourceStateUpdateIncludeResources? includeResources, DateTime? updateAt}) → Future< StartResourceStateUpdateResponse> - Begin asynchronous resource state update for lifecycle changes to the specified image resources.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds a tag to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from a resource.
-
updateDistributionConfiguration(
{required String distributionConfigurationArn, required List< Distribution> distributions, String? clientToken, String? description}) → Future<UpdateDistributionConfigurationResponse> - Updates a new distribution configuration. Distribution configurations define and configure the outputs of your pipeline.
-
updateImagePipeline(
{required String imagePipelineArn, required String infrastructureConfigurationArn, String? clientToken, String? containerRecipeArn, String? description, String? distributionConfigurationArn, bool? enhancedImageMetadataEnabled, String? executionRole, String? imageRecipeArn, ImageScanningConfiguration? imageScanningConfiguration, Map< String, String> ? imageTags, ImageTestsConfiguration? imageTestsConfiguration, PipelineLoggingConfiguration? loggingConfiguration, Schedule? schedule, PipelineStatus? status, List<WorkflowConfiguration> ? workflows}) → Future<UpdateImagePipelineResponse> -
Updates an image pipeline. Image pipelines enable you to automate the
creation and distribution of images. You must specify exactly one recipe
for your image, using either a
containerRecipeArnor animageRecipeArn. -
updateInfrastructureConfiguration(
{required String infrastructureConfigurationArn, required String instanceProfileName, String? clientToken, String? description, InstanceMetadataOptions? instanceMetadataOptions, List< String> ? instanceTypes, String? keyPair, Logging? logging, Placement? placement, Map<String, String> ? resourceTags, List<String> ? securityGroupIds, String? snsTopicArn, String? subnetId, bool? terminateInstanceOnFailure}) → Future<UpdateInfrastructureConfigurationResponse> - Updates a new infrastructure configuration. An infrastructure configuration defines the environment in which your image will be built and tested.
-
updateLifecyclePolicy(
{required String executionRole, required String lifecyclePolicyArn, required List< LifecyclePolicyDetail> policyDetails, required LifecyclePolicyResourceSelection resourceSelection, required LifecyclePolicyResourceType resourceType, String? clientToken, String? description, LifecyclePolicyStatus? status}) → Future<UpdateLifecyclePolicyResponse> - Update the specified lifecycle policy.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited