cancelLifecycleExecution method
Cancel a specific image lifecycle policy runtime instance.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw IdempotentParameterMismatchException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter lifecycleExecutionId :
Identifies the specific runtime instance of the image lifecycle to cancel.
Parameter clientToken :
Unique, case-sensitive identifier you provide to ensure idempotency of the
request. For more information, see Ensuring
idempotency in the Amazon EC2 API Reference.
Implementation
Future<CancelLifecycleExecutionResponse> cancelLifecycleExecution({
required String lifecycleExecutionId,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'lifecycleExecutionId': lifecycleExecutionId,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/CancelLifecycleExecution',
exceptionFnMap: _exceptionFns,
);
return CancelLifecycleExecutionResponse.fromJson(response);
}