createComponent method

Future<CreateComponentResponse> createComponent({
  1. required String name,
  2. required Platform platform,
  3. required String semanticVersion,
  4. String? changeDescription,
  5. String? clientToken,
  6. String? data,
  7. String? description,
  8. bool? dryRun,
  9. String? kmsKeyId,
  10. List<String>? supportedOsVersions,
  11. Map<String, String>? tags,
  12. String? uri,
})

Creates a new component that can be used to build, validate, test, and assess your image. The component is based on a YAML document that you specify using exactly one of the following methods:

  • Inline, using the data property in the request body.
  • A URL that points to a YAML document file stored in Amazon S3, using the uri property in the request body.

May throw CallRateLimitExceededException. May throw ClientException. May throw DryRunOperationException. May throw ForbiddenException. May throw IdempotentParameterMismatchException. May throw InvalidParameterCombinationException. May throw InvalidRequestException. May throw InvalidVersionNumberException. May throw ResourceInUseException. May throw ServiceException. May throw ServiceQuotaExceededException. May throw ServiceUnavailableException.

Parameter name : The name of the component.

Parameter platform : The operating system platform of the component.

Parameter semanticVersion : The semantic version of the component. This version follows the semantic version syntax.

Assignment: For the first three nodes you can assign any positive integer value, including zero, with an upper limit of 2^30-1, or 1073741823 for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Parameter changeDescription : The change description of the component. Describes what change has been made in this version, or what makes this version different from other versions of the component.

Parameter clientToken : Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

Parameter data : Component data contains inline YAML document content for the component. Alternatively, you can specify the uri of a YAML document file stored in Amazon S3. However, you cannot specify both properties.

Parameter description : Describes the contents of the component.

Parameter dryRun : Validates the required permissions for the operation and the request parameters, without actually making the request, and provides an error response. Upon a successful request, the error response is DryRunOperationException.

Parameter kmsKeyId : The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this component. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.

Parameter supportedOsVersions : The operating system (OS) version supported by the component. If the OS information is available, a prefix match is performed against the base image OS version during image recipe creation.

Parameter tags : The tags that apply to the component.

Parameter uri : The uri of a YAML component document file. This must be an S3 URL (s3://bucket/key), and the requester must have permission to access the S3 bucket it points to. If you use Amazon S3, you can specify component content up to your service quota.

Alternatively, you can specify the YAML document inline, using the component data property. You cannot specify both properties.

Implementation

Future<CreateComponentResponse> createComponent({
  required String name,
  required Platform platform,
  required String semanticVersion,
  String? changeDescription,
  String? clientToken,
  String? data,
  String? description,
  bool? dryRun,
  String? kmsKeyId,
  List<String>? supportedOsVersions,
  Map<String, String>? tags,
  String? uri,
}) async {
  final $payload = <String, dynamic>{
    'name': name,
    'platform': platform.value,
    'semanticVersion': semanticVersion,
    if (changeDescription != null) 'changeDescription': changeDescription,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (data != null) 'data': data,
    if (description != null) 'description': description,
    if (dryRun != null) 'dryRun': dryRun,
    if (kmsKeyId != null) 'kmsKeyId': kmsKeyId,
    if (supportedOsVersions != null)
      'supportedOsVersions': supportedOsVersions,
    if (tags != null) 'tags': tags,
    if (uri != null) 'uri': uri,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/CreateComponent',
    exceptionFnMap: _exceptionFns,
  );
  return CreateComponentResponse.fromJson(response);
}