createWorkflow method
Create a new workflow or a new version of an existing workflow.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw DryRunOperationException.
May throw ForbiddenException.
May throw IdempotentParameterMismatchException.
May throw InvalidParameterCombinationException.
May throw InvalidRequestException.
May throw InvalidVersionNumberException.
May throw ResourceInUseException.
May throw ServiceException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
Parameter name :
The name of the workflow to create.
Parameter semanticVersion :
The semantic version of this workflow resource. The semantic version
syntax adheres to the following rules.
Assignment: For the first three nodes you can assign any positive integer value, including zero, with an upper limit of 2^30-1, or 1073741823 for each node. Image Builder automatically assigns the build number to the fourth node.
Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.
Parameter type :
The phase in the image build process for which the workflow resource is
responsible.
Parameter changeDescription :
Describes what change has been made in this version of the workflow, or
what makes this version different from other versions of the workflow.
Parameter clientToken :
Unique, case-sensitive identifier you provide to ensure idempotency of the
request. For more information, see Ensuring
idempotency in the Amazon EC2 API Reference.
Parameter data :
Contains the UTF-8 encoded YAML document content for the workflow.
Alternatively, you can specify the uri of a YAML document
file stored in Amazon S3. However, you cannot specify both properties.
Parameter description :
Describes the workflow.
Parameter dryRun :
Validates the required permissions for the operation and the request
parameters, without actually making the request, and provides an error
response. Upon a successful request, the error response is
DryRunOperationException.
Parameter kmsKeyId :
The Amazon Resource Name (ARN) that uniquely identifies the KMS key used
to encrypt this workflow resource. This can be either the Key ARN or the
Alias ARN. For more information, see Key
identifiers (KeyId) in the Key Management Service Developer
Guide.
Parameter tags :
Tags that apply to the workflow resource.
Parameter uri :
The uri of a YAML component document file. This must be an S3
URL (s3://bucket/key), and the requester must have permission
to access the S3 bucket it points to. If you use Amazon S3, you can
specify component content up to your service quota.
Alternatively, you can specify the YAML document inline, using the
component data property. You cannot specify both properties.
Implementation
Future<CreateWorkflowResponse> createWorkflow({
required String name,
required String semanticVersion,
required WorkflowType type,
String? changeDescription,
String? clientToken,
String? data,
String? description,
bool? dryRun,
String? kmsKeyId,
Map<String, String>? tags,
String? uri,
}) async {
final $payload = <String, dynamic>{
'name': name,
'semanticVersion': semanticVersion,
'type': type.value,
if (changeDescription != null) 'changeDescription': changeDescription,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (data != null) 'data': data,
if (description != null) 'description': description,
if (dryRun != null) 'dryRun': dryRun,
if (kmsKeyId != null) 'kmsKeyId': kmsKeyId,
if (tags != null) 'tags': tags,
if (uri != null) 'uri': uri,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/CreateWorkflow',
exceptionFnMap: _exceptionFns,
);
return CreateWorkflowResponse.fromJson(response);
}