getLifecycleExecution method

Future<GetLifecycleExecutionResponse> getLifecycleExecution({
  1. required String lifecycleExecutionId,
})

Get the runtime information that was logged for a specific runtime instance of the lifecycle policy.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter lifecycleExecutionId : Use the unique identifier for a runtime instance of the lifecycle policy to get runtime details.

Implementation

Future<GetLifecycleExecutionResponse> getLifecycleExecution({
  required String lifecycleExecutionId,
}) async {
  final $query = <String, List<String>>{
    'lifecycleExecutionId': [lifecycleExecutionId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/GetLifecycleExecution',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetLifecycleExecutionResponse.fromJson(response);
}