getMarketplaceResource method
Verify the subscription and perform resource dependency checks on the requested Amazon Web Services Marketplace resource. For Amazon Web Services Marketplace components, the response contains fields to download the components and their artifacts.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter resourceArn :
The Amazon Resource Name (ARN) that uniquely identifies an Amazon Web
Services Marketplace resource.
Parameter resourceType :
Specifies which type of Amazon Web Services Marketplace resource Image
Builder retrieves.
Parameter resourceLocation :
The bucket path that you can specify to download the resource from Amazon
S3.
Implementation
Future<GetMarketplaceResourceResponse> getMarketplaceResource({
required String resourceArn,
required MarketplaceResourceType resourceType,
String? resourceLocation,
}) async {
final $payload = <String, dynamic>{
'resourceArn': resourceArn,
'resourceType': resourceType.value,
if (resourceLocation != null) 'resourceLocation': resourceLocation,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetMarketplaceResource',
exceptionFnMap: _exceptionFns,
);
return GetMarketplaceResourceResponse.fromJson(response);
}