getWorkflowExecution method

Future<GetWorkflowExecutionResponse> getWorkflowExecution({
  1. required String workflowExecutionId,
})

Get the runtime information that was logged for a specific runtime instance of the workflow.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter workflowExecutionId : Use the unique identifier for a runtime instance of the workflow to get runtime details.

Implementation

Future<GetWorkflowExecutionResponse> getWorkflowExecution({
  required String workflowExecutionId,
}) async {
  final $query = <String, List<String>>{
    'workflowExecutionId': [workflowExecutionId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/GetWorkflowExecution',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetWorkflowExecutionResponse.fromJson(response);
}