getWorkflowStepExecution method

Future<GetWorkflowStepExecutionResponse> getWorkflowStepExecution({
  1. required String stepExecutionId,
})

Get the runtime information that was logged for a specific runtime instance of the workflow step.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter stepExecutionId : Use the unique identifier for a specific runtime instance of the workflow step to get runtime details for that step.

Implementation

Future<GetWorkflowStepExecutionResponse> getWorkflowStepExecution({
  required String stepExecutionId,
}) async {
  final $query = <String, List<String>>{
    'stepExecutionId': [stepExecutionId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/GetWorkflowStepExecution',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetWorkflowStepExecutionResponse.fromJson(response);
}