listComponentBuildVersions method
Returns the list of component build versions for the specified component version Amazon Resource Name (ARN).
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter componentVersionArn :
The component version Amazon Resource Name (ARN) whose versions you want
to list.
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListComponentBuildVersionsResponse> listComponentBuildVersions({
String? componentVersionArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
if (componentVersionArn != null)
'componentVersionArn': componentVersionArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListComponentBuildVersions',
exceptionFnMap: _exceptionFns,
);
return ListComponentBuildVersionsResponse.fromJson(response);
}