listImagePipelineImages method

Future<ListImagePipelineImagesResponse> listImagePipelineImages({
  1. required String imagePipelineArn,
  2. List<Filter>? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Returns a list of images created by the specified pipeline.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter imagePipelineArn : The Amazon Resource Name (ARN) of the image pipeline whose images you want to view.

Parameter filters : Use the following filters to streamline results:

  • name
  • version

Parameter maxResults : Specify the maximum number of items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListImagePipelineImagesResponse> listImagePipelineImages({
  required String imagePipelineArn,
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $payload = <String, dynamic>{
    'imagePipelineArn': imagePipelineArn,
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListImagePipelineImages',
    exceptionFnMap: _exceptionFns,
  );
  return ListImagePipelineImagesResponse.fromJson(response);
}