listImageRecipes method
Returns a list of image recipes.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter filters :
Use the following filters to streamline results:
-
name -
parentImage -
platform
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Parameter owner :
You can specify the recipe owner to filter results by that owner. By
default, this request will only show image recipes owned by your account.
To filter by a different owner, specify one of the Valid
Values that are listed for this parameter.
Implementation
Future<ListImageRecipesResponse> listImageRecipes({
List<Filter>? filters,
int? maxResults,
String? nextToken,
Ownership? owner,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (owner != null) 'owner': owner.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListImageRecipes',
exceptionFnMap: _exceptionFns,
);
return ListImageRecipesResponse.fromJson(response);
}