listImageScanFindingAggregations method

Future<ListImageScanFindingAggregationsResponse> listImageScanFindingAggregations({
  1. Filter? filter,
  2. String? nextToken,
})

Returns a list of image scan aggregations for your account. You can filter by the type of key that Image Builder uses to group results. For example, if you want to get a list of findings by severity level for one of your pipelines, you might specify your pipeline with the imagePipelineArn filter. If you don't specify a filter, Image Builder returns an aggregation for your account.

To streamline results, you can use the following filters in your request:

  • accountId
  • imageBuildVersionArn
  • imagePipelineArn
  • vulnerabilityId

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListImageScanFindingAggregationsResponse>
    listImageScanFindingAggregations({
  Filter? filter,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filter != null) 'filter': filter,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListImageScanFindingAggregations',
    exceptionFnMap: _exceptionFns,
  );
  return ListImageScanFindingAggregationsResponse.fromJson(response);
}