listImageScanFindings method
Returns a list of image scan findings for your account.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter filters :
An array of name value pairs that you can use to filter your results. You
can use the following filters to streamline results:
-
imageBuildVersionArn -
imagePipelineArn -
vulnerabilityId -
severity
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListImageScanFindingsResponse> listImageScanFindings({
List<ImageScanFindingsFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListImageScanFindings',
exceptionFnMap: _exceptionFns,
);
return ListImageScanFindingsResponse.fromJson(response);
}