listLifecycleExecutionResources method
List resources that the runtime instance of the image lifecycle identified for lifecycle actions.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter lifecycleExecutionId :
Use the unique identifier for a runtime instance of the lifecycle policy
to get runtime details.
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Parameter parentResourceId :
You can leave this empty to get a list of Image Builder resources that
were identified for lifecycle actions.
To get a list of associated resources that are impacted for an individual resource (the parent), specify its Amazon Resource Name (ARN). Associated resources are produced from your image and distributed when you run a build, such as AMIs or container images stored in ECR repositories.
Implementation
Future<ListLifecycleExecutionResourcesResponse>
listLifecycleExecutionResources({
required String lifecycleExecutionId,
int? maxResults,
String? nextToken,
String? parentResourceId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
'lifecycleExecutionId': lifecycleExecutionId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (parentResourceId != null) 'parentResourceId': parentResourceId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListLifecycleExecutionResources',
exceptionFnMap: _exceptionFns,
);
return ListLifecycleExecutionResourcesResponse.fromJson(response);
}