listLifecycleExecutions method
Get the lifecycle runtime history for the specified resource.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource for which to get a list of
lifecycle runtime instances.
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListLifecycleExecutionsResponse> listLifecycleExecutions({
required String resourceArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
'resourceArn': resourceArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListLifecycleExecutions',
exceptionFnMap: _exceptionFns,
);
return ListLifecycleExecutionsResponse.fromJson(response);
}