listWaitingWorkflowSteps method

Future<ListWaitingWorkflowStepsResponse> listWaitingWorkflowSteps({
  1. int? maxResults,
  2. String? nextToken,
})

Get a list of workflow steps that are waiting for action for workflows in your Amazon Web Services account.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter maxResults : Specify the maximum number of items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListWaitingWorkflowStepsResponse> listWaitingWorkflowSteps({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListWaitingWorkflowSteps',
    exceptionFnMap: _exceptionFns,
  );
  return ListWaitingWorkflowStepsResponse.fromJson(response);
}