listWorkflowStepExecutions method

Future<ListWorkflowStepExecutionsResponse> listWorkflowStepExecutions({
  1. required String workflowExecutionId,
  2. int? maxResults,
  3. String? nextToken,
})

Returns runtime data for each step in a runtime instance of the workflow that you specify in the request.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter workflowExecutionId : The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.

Parameter maxResults : Specify the maximum number of items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListWorkflowStepExecutionsResponse> listWorkflowStepExecutions({
  required String workflowExecutionId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $payload = <String, dynamic>{
    'workflowExecutionId': workflowExecutionId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListWorkflowStepExecutions',
    exceptionFnMap: _exceptionFns,
  );
  return ListWorkflowStepExecutionsResponse.fromJson(response);
}