listWorkflows method
Lists workflow build versions based on filtering parameters.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter byName :
Specify all or part of the workflow name to streamline results.
Parameter filters :
Used to streamline search results.
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Parameter owner :
Used to get a list of workflow build version filtered by the identity of
the creator.
Implementation
Future<ListWorkflowsResponse> listWorkflows({
bool? byName,
List<Filter>? filters,
int? maxResults,
String? nextToken,
Ownership? owner,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
if (byName != null) 'byName': byName,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (owner != null) 'owner': owner.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListWorkflows',
exceptionFnMap: _exceptionFns,
);
return ListWorkflowsResponse.fromJson(response);
}