startImagePipelineExecution method

Future<StartImagePipelineExecutionResponse> startImagePipelineExecution({
  1. required String imagePipelineArn,
  2. String? clientToken,
  3. Map<String, String>? tags,
})

Manually triggers a pipeline to create an image.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw IdempotentParameterMismatchException. May throw InvalidRequestException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter imagePipelineArn : The Amazon Resource Name (ARN) of the image pipeline that you want to manually invoke.

Parameter clientToken : Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

Parameter tags : Specify tags for Image Builder to apply to the image resource that's created When it starts pipeline execution.

Implementation

Future<StartImagePipelineExecutionResponse> startImagePipelineExecution({
  required String imagePipelineArn,
  String? clientToken,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'imagePipelineArn': imagePipelineArn,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/StartImagePipelineExecution',
    exceptionFnMap: _exceptionFns,
  );
  return StartImagePipelineExecutionResponse.fromJson(response);
}