updateDistributionConfiguration method
Updates a new distribution configuration. Distribution configurations define and configure the outputs of your pipeline.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw IdempotentParameterMismatchException.
May throw InvalidParameterCombinationException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter distributionConfigurationArn :
The Amazon Resource Name (ARN) of the distribution configuration that you
want to update.
Parameter distributions :
The distributions of the distribution configuration.
Parameter clientToken :
Unique, case-sensitive identifier you provide to ensure idempotency of the
request. For more information, see Ensuring
idempotency in the Amazon EC2 API Reference.
Parameter description :
The description of the distribution configuration.
Implementation
Future<UpdateDistributionConfigurationResponse>
updateDistributionConfiguration({
required String distributionConfigurationArn,
required List<Distribution> distributions,
String? clientToken,
String? description,
}) async {
final $payload = <String, dynamic>{
'distributionConfigurationArn': distributionConfigurationArn,
'distributions': distributions,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'description': description,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/UpdateDistributionConfiguration',
exceptionFnMap: _exceptionFns,
);
return UpdateDistributionConfigurationResponse.fromJson(response);
}