updateImagePipeline method
- required String imagePipelineArn,
- required String infrastructureConfigurationArn,
- String? clientToken,
- String? containerRecipeArn,
- String? description,
- String? distributionConfigurationArn,
- bool? enhancedImageMetadataEnabled,
- String? executionRole,
- String? imageRecipeArn,
- ImageScanningConfiguration? imageScanningConfiguration,
- Map<
String, String> ? imageTags, - ImageTestsConfiguration? imageTestsConfiguration,
- PipelineLoggingConfiguration? loggingConfiguration,
- Schedule? schedule,
- PipelineStatus? status,
- List<
WorkflowConfiguration> ? workflows,
Updates an image pipeline. Image pipelines enable you to automate the
creation and distribution of images. You must specify exactly one recipe
for your image, using either a containerRecipeArn or an
imageRecipeArn.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw IdempotentParameterMismatchException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter imagePipelineArn :
The Amazon Resource Name (ARN) of the image pipeline that you want to
update.
Parameter infrastructureConfigurationArn :
The Amazon Resource Name (ARN) of the infrastructure configuration that
Image Builder uses to build images that this image pipeline has updated.
Parameter clientToken :
Unique, case-sensitive identifier you provide to ensure idempotency of the
request. For more information, see Ensuring
idempotency in the Amazon EC2 API Reference.
Parameter containerRecipeArn :
The Amazon Resource Name (ARN) of the container pipeline to update.
Parameter description :
The description of the image pipeline.
Parameter distributionConfigurationArn :
The Amazon Resource Name (ARN) of the distribution configuration that
Image Builder uses to configure and distribute images that this image
pipeline has updated.
Parameter enhancedImageMetadataEnabled :
Collects additional information about the image being created, including
the operating system (OS) version and package list. This information is
used to enhance the overall experience of using EC2 Image Builder. Enabled
by default.
Parameter executionRole :
The name or Amazon Resource Name (ARN) for the IAM role you create that
grants Image Builder access to perform workflow actions.
Parameter imageRecipeArn :
The Amazon Resource Name (ARN) of the image recipe that will be used to
configure images updated by this image pipeline.
Parameter imageScanningConfiguration :
Contains settings for vulnerability scans.
Parameter imageTags :
The tags to be applied to the images produced by this pipeline.
Parameter imageTestsConfiguration :
The image test configuration of the image pipeline.
Parameter loggingConfiguration :
Update logging configuration for the output image that's created when the
pipeline runs.
Parameter schedule :
The schedule of the image pipeline.
Parameter status :
The status of the image pipeline.
Parameter workflows :
Contains the workflows to run for the pipeline.
Implementation
Future<UpdateImagePipelineResponse> updateImagePipeline({
required String imagePipelineArn,
required String infrastructureConfigurationArn,
String? clientToken,
String? containerRecipeArn,
String? description,
String? distributionConfigurationArn,
bool? enhancedImageMetadataEnabled,
String? executionRole,
String? imageRecipeArn,
ImageScanningConfiguration? imageScanningConfiguration,
Map<String, String>? imageTags,
ImageTestsConfiguration? imageTestsConfiguration,
PipelineLoggingConfiguration? loggingConfiguration,
Schedule? schedule,
PipelineStatus? status,
List<WorkflowConfiguration>? workflows,
}) async {
final $payload = <String, dynamic>{
'imagePipelineArn': imagePipelineArn,
'infrastructureConfigurationArn': infrastructureConfigurationArn,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (containerRecipeArn != null) 'containerRecipeArn': containerRecipeArn,
if (description != null) 'description': description,
if (distributionConfigurationArn != null)
'distributionConfigurationArn': distributionConfigurationArn,
if (enhancedImageMetadataEnabled != null)
'enhancedImageMetadataEnabled': enhancedImageMetadataEnabled,
if (executionRole != null) 'executionRole': executionRole,
if (imageRecipeArn != null) 'imageRecipeArn': imageRecipeArn,
if (imageScanningConfiguration != null)
'imageScanningConfiguration': imageScanningConfiguration,
if (imageTags != null) 'imageTags': imageTags,
if (imageTestsConfiguration != null)
'imageTestsConfiguration': imageTestsConfiguration,
if (loggingConfiguration != null)
'loggingConfiguration': loggingConfiguration,
if (schedule != null) 'schedule': schedule,
if (status != null) 'status': status.value,
if (workflows != null) 'workflows': workflows,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/UpdateImagePipeline',
exceptionFnMap: _exceptionFns,
);
return UpdateImagePipelineResponse.fromJson(response);
}