getTelemetryMetadata method
Information about the data that is collected for the specified assessment run.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidInputException.
May throw NoSuchEntityException.
Parameter assessmentRunArn :
The ARN that specifies the assessment run that has the telemetry data that
you want to obtain.
Implementation
Future<GetTelemetryMetadataResponse> getTelemetryMetadata({
required String assessmentRunArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'InspectorService.GetTelemetryMetadata'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'assessmentRunArn': assessmentRunArn,
},
);
return GetTelemetryMetadataResponse.fromJson(jsonResponse.body);
}