associateMember method

Future<AssociateMemberResponse> associateMember({
  1. required String accountId,
})

Associates an Amazon Web Services account with an Amazon Inspector delegated administrator. An HTTP 200 response indicates the association was successfully started, but doesn’t indicate whether it was completed. You can check if the association completed by using ListMembers for multiple accounts or GetMembers for a single account.

May throw AccessDeniedException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter accountId : The Amazon Web Services account ID of the member account to be associated.

Implementation

Future<AssociateMemberResponse> associateMember({
  required String accountId,
}) async {
  final $payload = <String, dynamic>{
    'accountId': accountId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/members/associate',
    exceptionFnMap: _exceptionFns,
  );
  return AssociateMemberResponse.fromJson(response);
}