batchGetAccountStatus method

Future<BatchGetAccountStatusResponse> batchGetAccountStatus({
  1. List<String>? accountIds,
})

Retrieves the Amazon Inspector status of multiple Amazon Web Services accounts within your environment.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accountIds : The 12-digit Amazon Web Services account IDs of the accounts to retrieve Amazon Inspector status for.

Implementation

Future<BatchGetAccountStatusResponse> batchGetAccountStatus({
  List<String>? accountIds,
}) async {
  final $payload = <String, dynamic>{
    if (accountIds != null) 'accountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/status/batch/get',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetAccountStatusResponse.fromJson(response);
}