batchUpdateMemberEc2DeepInspectionStatus method
Future<BatchUpdateMemberEc2DeepInspectionStatusResponse>
batchUpdateMemberEc2DeepInspectionStatus({
- required List<
MemberAccountEc2DeepInspectionStatus> accountIds,
Activates or deactivates Amazon Inspector deep inspection for the provided member accounts in your organization. You must be the delegated administrator of an organization in Amazon Inspector to use this API.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
The unique identifiers for the Amazon Web Services accounts to change
Amazon Inspector deep inspection status for.
Implementation
Future<BatchUpdateMemberEc2DeepInspectionStatusResponse>
batchUpdateMemberEc2DeepInspectionStatus({
required List<MemberAccountEc2DeepInspectionStatus> accountIds,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ec2deepinspectionstatus/member/batch/update',
exceptionFnMap: _exceptionFns,
);
return BatchUpdateMemberEc2DeepInspectionStatusResponse.fromJson(response);
}