createSbomExport method

Future<CreateSbomExportResponse> createSbomExport({
  1. required SbomReportFormat reportFormat,
  2. required Destination s3Destination,
  3. ResourceFilterCriteria? resourceFilterCriteria,
})

Creates a software bill of materials (SBOM) report.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter reportFormat : The output format for the software bill of materials (SBOM) report.

Parameter s3Destination : Contains details of the Amazon S3 bucket and KMS key used to export findings.

Parameter resourceFilterCriteria : The resource filter criteria for the software bill of materials (SBOM) report.

Implementation

Future<CreateSbomExportResponse> createSbomExport({
  required SbomReportFormat reportFormat,
  required Destination s3Destination,
  ResourceFilterCriteria? resourceFilterCriteria,
}) async {
  final $payload = <String, dynamic>{
    'reportFormat': reportFormat.value,
    's3Destination': s3Destination,
    if (resourceFilterCriteria != null)
      'resourceFilterCriteria': resourceFilterCriteria,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/sbomexport/create',
    exceptionFnMap: _exceptionFns,
  );
  return CreateSbomExportResponse.fromJson(response);
}