disable method
Disables Amazon Inspector scans for one or more Amazon Web Services accounts. Disabling all scan types in an account disables the Amazon Inspector service.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
An array of account IDs you want to disable Amazon Inspector scans for.
Parameter resourceTypes :
The resource scan types you want to disable.
Implementation
Future<DisableResponse> disable({
List<String>? accountIds,
List<ResourceScanType>? resourceTypes,
}) async {
final $payload = <String, dynamic>{
if (accountIds != null) 'accountIds': accountIds,
if (resourceTypes != null)
'resourceTypes': resourceTypes.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/disable',
exceptionFnMap: _exceptionFns,
);
return DisableResponse.fromJson(response);
}