listCodeSecurityScanConfigurations method

Future<ListCodeSecurityScanConfigurationsResponse> listCodeSecurityScanConfigurations({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all code security scan configurations in your account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Implementation

Future<ListCodeSecurityScanConfigurationsResponse>
    listCodeSecurityScanConfigurations({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/codesecurity/scan-configuration/list',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCodeSecurityScanConfigurationsResponse.fromJson(response);
}