listConnectors method

Future<ListConnectorsResponse> listConnectors({
  1. ConnectorFilterCriteria? filterCriteria,
  2. int? maxResults,
  3. String? nextToken,
})

Lists connectors in your account. Results are paginated. Use the nextToken parameter to retrieve the next page of results.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter filterCriteria : The filter criteria to apply to the list of connectors.

Parameter maxResults : The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the nextToken value returned from this request.

Parameter nextToken : A token to use for paginating results. Set this value to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Implementation

Future<ListConnectorsResponse> listConnectors({
  ConnectorFilterCriteria? filterCriteria,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filterCriteria != null) 'filterCriteria': filterCriteria,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/connector/list',
    exceptionFnMap: _exceptionFns,
  );
  return ListConnectorsResponse.fromJson(response);
}