listCoverageStatistics method

Future<ListCoverageStatisticsResponse> listCoverageStatistics({
  1. CoverageFilterCriteria? filterCriteria,
  2. GroupKey? groupBy,
  3. String? nextToken,
})

Lists Amazon Inspector coverage statistics for your environment.

May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter filterCriteria : An object that contains details on the filters to apply to the coverage data for your environment.

Parameter groupBy : The value to group the results by.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Implementation

Future<ListCoverageStatisticsResponse> listCoverageStatistics({
  CoverageFilterCriteria? filterCriteria,
  GroupKey? groupBy,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filterCriteria != null) 'filterCriteria': filterCriteria,
    if (groupBy != null) 'groupBy': groupBy.value,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/coverage/statistics/list',
    exceptionFnMap: _exceptionFns,
  );
  return ListCoverageStatisticsResponse.fromJson(response);
}