listFindings method
Lists findings for your environment.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filterCriteria :
Details on the filters to apply to your finding results.
Parameter maxResults :
The maximum number of results the response can return. If your request
would return more than the maximum the response will return a
nextToken value, use this value when you call the action
again to get the remaining results.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request to a list
action. If your response returns more than the maxResults
maximum value it will also return a nextToken value. For
subsequent calls, use the nextToken value returned from the
previous request to continue listing results after the first page.
Parameter sortCriteria :
Details on the sort criteria to apply to your finding results.
Implementation
Future<ListFindingsResponse> listFindings({
FilterCriteria? filterCriteria,
int? maxResults,
String? nextToken,
SortCriteria? sortCriteria,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filterCriteria != null) 'filterCriteria': filterCriteria,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (sortCriteria != null) 'sortCriteria': sortCriteria,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/findings/list',
exceptionFnMap: _exceptionFns,
);
return ListFindingsResponse.fromJson(response);
}