listMembers method
List members associated with the Amazon Inspector delegated administrator for your organization.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results the response can return. If your request
would return more than the maximum the response will return a
nextToken value, use this value when you call the action
again to get the remaining results.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request to a list
action. If your response returns more than the maxResults
maximum value it will also return a nextToken value. For
subsequent calls, use the nextToken value returned from the
previous request to continue listing results after the first page.
Parameter onlyAssociated :
Specifies whether to list only currently associated members if
True or to list all members within the organization if
False.
Implementation
Future<ListMembersResponse> listMembers({
int? maxResults,
String? nextToken,
bool? onlyAssociated,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (onlyAssociated != null) 'onlyAssociated': onlyAssociated,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/members/list',
exceptionFnMap: _exceptionFns,
);
return ListMembersResponse.fromJson(response);
}