resetEncryptionKey method

Future<void> resetEncryptionKey({
  1. required ResourceType resourceType,
  2. required ScanType scanType,
})

Resets an encryption key. After the key is reset your resources will be encrypted by an Amazon Web Services owned key.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceType : The resource type the key encrypts.

Parameter scanType : The scan type the key encrypts.

Implementation

Future<void> resetEncryptionKey({
  required ResourceType resourceType,
  required ScanType scanType,
}) async {
  final $payload = <String, dynamic>{
    'resourceType': resourceType.value,
    'scanType': scanType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/encryptionkey/reset',
    exceptionFnMap: _exceptionFns,
  );
}