startCodeSecurityScan method
Future<StartCodeSecurityScanResponse>
startCodeSecurityScan({
- required CodeSecurityResource resource,
- String? clientToken,
Initiates a code security scan on a specified repository.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resource :
The resource identifier for the code repository to scan.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Implementation
Future<StartCodeSecurityScanResponse> startCodeSecurityScan({
required CodeSecurityResource resource,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'resource': resource,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/codesecurity/scan/start',
exceptionFnMap: _exceptionFns,
);
return StartCodeSecurityScanResponse.fromJson(response);
}