updateCodeSecurityIntegration method

Future<UpdateCodeSecurityIntegrationResponse> updateCodeSecurityIntegration({
  1. required UpdateIntegrationDetails details,
  2. required String integrationArn,
})

Updates an existing code security integration.

After calling the CreateCodeSecurityIntegration operation, you complete authentication and authorization with your provider. Next you call the UpdateCodeSecurityIntegration operation to provide the details to complete the integration setup

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter details : The updated integration details specific to the repository provider type.

Parameter integrationArn : The Amazon Resource Name (ARN) of the code security integration to update.

Implementation

Future<UpdateCodeSecurityIntegrationResponse> updateCodeSecurityIntegration({
  required UpdateIntegrationDetails details,
  required String integrationArn,
}) async {
  final $payload = <String, dynamic>{
    'details': details,
    'integrationArn': integrationArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/codesecurity/integration/update',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateCodeSecurityIntegrationResponse.fromJson(response);
}