updateConfiguration method

Future<void> updateConfiguration({
  1. Ec2Configuration? ec2Configuration,
  2. EcrConfiguration? ecrConfiguration,
})

Updates setting configurations for your Amazon Inspector account. When you use this API as an Amazon Inspector delegated administrator this updates the setting for all accounts you manage. Member accounts in an organization cannot update this setting.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter ec2Configuration : Specifies how the Amazon EC2 automated scan will be updated for your environment.

Parameter ecrConfiguration : Specifies how the ECR automated re-scan will be updated for your environment.

Implementation

Future<void> updateConfiguration({
  Ec2Configuration? ec2Configuration,
  EcrConfiguration? ecrConfiguration,
}) async {
  final $payload = <String, dynamic>{
    if (ec2Configuration != null) 'ec2Configuration': ec2Configuration,
    if (ecrConfiguration != null) 'ecrConfiguration': ecrConfiguration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/configuration/update',
    exceptionFnMap: _exceptionFns,
  );
}