updateOrgEc2DeepInspectionConfiguration method

Future<void> updateOrgEc2DeepInspectionConfiguration({
  1. required List<String> orgPackagePaths,
})

Updates the Amazon Inspector deep inspection custom paths for your organization. You must be an Amazon Inspector delegated administrator to use this API.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter orgPackagePaths : The Amazon Inspector deep inspection custom paths you are adding for your organization.

Implementation

Future<void> updateOrgEc2DeepInspectionConfiguration({
  required List<String> orgPackagePaths,
}) async {
  final $payload = <String, dynamic>{
    'orgPackagePaths': orgPackagePaths,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ec2deepinspectionconfiguration/org/update',
    exceptionFnMap: _exceptionFns,
  );
}