describeConnectionProposal method

Future<DescribeConnectionProposalResponse> describeConnectionProposal({
  1. required String activationKey,
})

Describes the details of a connection proposal generated at a partner's portal.

Parameter activationKey : An Activation Key that was generated on a supported partner's portal. This key captures the desired parameters from the initial creation request.

Implementation

Future<DescribeConnectionProposalResponse> describeConnectionProposal({
  required String activationKey,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Interconnect.DescribeConnectionProposal'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'activationKey': activationKey,
    },
  );

  return DescribeConnectionProposalResponse.fromJson(jsonResponse.body);
}