listAttachPoints method

Future<ListAttachPointsResponse> listAttachPoints({
  1. required String environmentId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all Attach Points the caller has access to that are valid for the specified Environment.

Parameter environmentId : The identifier of the Environment for which to list valid Attach Points.

Parameter maxResults : The max number of list results in a single paginated response.

Parameter nextToken : A pagination token from a previous paginated response indicating you wish to get the next page.

Implementation

Future<ListAttachPointsResponse> listAttachPoints({
  required String environmentId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Interconnect.ListAttachPoints'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'environmentId': environmentId,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListAttachPointsResponse.fromJson(jsonResponse.body);
}