untagResource method

Future<void> untagResource({
  1. required String arn,
  2. required List<String> tagKeys,
})

Removes tags from the specified resource.

Parameter arn : The ARN of the resource from which the specified tags should be removed.

Parameter tagKeys : The list of tag keys that should be removed from the resource.

Implementation

Future<void> untagResource({
  required String arn,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Interconnect.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'arn': arn,
      'tagKeys': tagKeys,
    },
  );
}