InternetMonitor class
Amazon CloudWatch Internet Monitor provides visibility into how internet issues impact the performance and availability between your applications hosted on Amazon Web Services and your end users. It can reduce the time it takes for you to diagnose internet issues from days to minutes. Internet Monitor uses the connectivity data that Amazon Web Services captures from its global networking footprint to calculate a baseline of performance and availability for internet traffic. This is the same data that Amazon Web Services uses to monitor internet uptime and availability. With those measurements as a baseline, Internet Monitor raises awareness for you when there are significant problems for your end users in the different geographic locations where your application runs.
Internet Monitor publishes internet measurements to CloudWatch Logs and CloudWatch Metrics, to easily support using CloudWatch tools with health information for geographies and networks specific to your application. Internet Monitor sends health events to Amazon EventBridge so that you can set up notifications. If an issue is caused by the Amazon Web Services network, you also automatically receive an Amazon Web Services Health Dashboard notification with the steps that Amazon Web Services is taking to mitigate the problem.
To use Internet Monitor, you create a monitor and associate your application's resources with it - VPCs, NLBs, CloudFront distributions, or WorkSpaces directories - so Internet Monitor can determine where your application's internet traffic is. Internet Monitor then provides internet measurements from Amazon Web Services that are specific to the locations and ASNs (typically, internet service providers or ISPs) that communicate with your application.
For more information, see Using Amazon CloudWatch Internet Monitor in the Amazon CloudWatch User Guide.
Constructors
- InternetMonitor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createMonitor(
{required String monitorName, String? clientToken, HealthEventsConfig? healthEventsConfig, InternetMeasurementsLogDelivery? internetMeasurementsLogDelivery, int? maxCityNetworksToMonitor, List< String> ? resources, Map<String, String> ? tags, int? trafficPercentageToMonitor}) → Future<CreateMonitorOutput> - Creates a monitor in Amazon CloudWatch Internet Monitor. A monitor is built based on information from the application resources that you add: VPCs, Network Load Balancers (NLBs), Amazon CloudFront distributions, and Amazon WorkSpaces directories. Internet Monitor then publishes internet measurements from Amazon Web Services that are specific to the city-networks. That is, the locations and ASNs (typically internet service providers or ISPs), where clients access your application. For more information, see Using Amazon CloudWatch Internet Monitor in the Amazon CloudWatch User Guide.
-
deleteMonitor(
{required String monitorName}) → Future< void> - Deletes a monitor in Amazon CloudWatch Internet Monitor.
-
getHealthEvent(
{required String eventId, required String monitorName, String? linkedAccountId}) → Future< GetHealthEventOutput> - Gets information that Amazon CloudWatch Internet Monitor has created and stored about a health event for a specified monitor. This information includes the impacted locations, and all the information related to the event, by location.
-
getInternetEvent(
{required String eventId}) → Future< GetInternetEventOutput> - Gets information that Amazon CloudWatch Internet Monitor has generated about an internet event. Internet Monitor displays information about recent global health events, called internet events, on a global outages map that is available to all Amazon Web Services customers.
-
getMonitor(
{required String monitorName, String? linkedAccountId}) → Future< GetMonitorOutput> - Gets information about a monitor in Amazon CloudWatch Internet Monitor based on a monitor name. The information returned includes the Amazon Resource Name (ARN), create time, modified time, resources included in the monitor, and status information.
-
getQueryResults(
{required String monitorName, required String queryId, int? maxResults, String? nextToken}) → Future< GetQueryResultsOutput> -
Return the data for a query with the Amazon CloudWatch Internet Monitor
query interface. Specify the query that you want to return results for by
providing a
QueryIdand a monitor name. -
getQueryStatus(
{required String monitorName, required String queryId}) → Future< GetQueryStatusOutput> -
Returns the current status of a query for the Amazon CloudWatch Internet
Monitor query interface, for a specified query ID and monitor. When you
run a query, check the status to make sure that the query has
SUCCEEDEDbefore you review the results. -
listHealthEvents(
{required String monitorName, DateTime? endTime, HealthEventStatus? eventStatus, String? linkedAccountId, int? maxResults, String? nextToken, DateTime? startTime}) → Future< ListHealthEventsOutput> - Lists all health events for a monitor in Amazon CloudWatch Internet Monitor. Returns information for health events including the event start and end times, and the status.
-
listInternetEvents(
{DateTime? endTime, String? eventStatus, String? eventType, int? maxResults, String? nextToken, DateTime? startTime}) → Future< ListInternetEventsOutput> - Lists internet events that cause performance or availability issues for client locations. Amazon CloudWatch Internet Monitor displays information about recent global health events, called internet events, on a global outages map that is available to all Amazon Web Services customers.
-
listMonitors(
{bool? includeLinkedAccounts, int? maxResults, String? monitorStatus, String? nextToken}) → Future< ListMonitorsOutput> - Lists all of your monitors for Amazon CloudWatch Internet Monitor and their statuses, along with the Amazon Resource Name (ARN) and name of each monitor.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists the tags for a resource. Tags are supported only for monitors in Amazon CloudWatch Internet Monitor.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startQuery(
{required DateTime endTime, required String monitorName, required QueryType queryType, required DateTime startTime, List< FilterParameter> ? filterParameters, String? linkedAccountId}) → Future<StartQueryOutput> -
Start a query to return data for a specific query type for the Amazon
CloudWatch Internet Monitor query interface. Specify a time period for the
data that you want returned by using
StartTimeandEndTime. You filter the query results to return by providing parameters that you specify withFilterParameters. -
stopQuery(
{required String monitorName, required String queryId}) → Future< void> - Stop a query that is progress for a specific monitor.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds a tag to a resource. Tags are supported only for monitors in Amazon CloudWatch Internet Monitor. You can add a maximum of 50 tags in Internet Monitor.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from a resource.
-
updateMonitor(
{required String monitorName, String? clientToken, HealthEventsConfig? healthEventsConfig, InternetMeasurementsLogDelivery? internetMeasurementsLogDelivery, int? maxCityNetworksToMonitor, List< String> ? resourcesToAdd, List<String> ? resourcesToRemove, MonitorConfigState? status, int? trafficPercentageToMonitor}) → Future<UpdateMonitorOutput> - Updates a monitor. You can update a monitor to change the percentage of traffic to monitor or the maximum number of city-networks (locations and ASNs), to add or remove resources, or to change the status of the monitor. Note that you can't change the name of a monitor.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited