getInternetEvent method
Gets information that Amazon CloudWatch Internet Monitor has generated about an internet event. Internet Monitor displays information about recent global health events, called internet events, on a global outages map that is available to all Amazon Web Services customers.
The information returned here includes the impacted location, when the
event started and (if the event is over) ended, the type of event
(PERFORMANCE or AVAILABILITY), and the status
(ACTIVE or RESOLVED).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter eventId :
The EventId of the internet event to return information for.
Implementation
Future<GetInternetEventOutput> getInternetEvent({
required String eventId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v20210603/InternetEvents/${Uri.encodeComponent(eventId)}',
exceptionFnMap: _exceptionFns,
);
return GetInternetEventOutput.fromJson(response);
}