stopQuery method

Future<void> stopQuery({
  1. required String monitorName,
  2. required String queryId,
})

Stop a query that is progress for a specific monitor.

May throw AccessDeniedException. May throw InternalServerException. May throw LimitExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter monitorName : The name of the monitor.

Parameter queryId : The ID of the query that you want to stop. A QueryId is an internally-generated identifier for a specific query.

Implementation

Future<void> stopQuery({
  required String monitorName,
  required String queryId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v20210603/Monitors/${Uri.encodeComponent(monitorName)}/Queries/${Uri.encodeComponent(queryId)}',
    exceptionFnMap: _exceptionFns,
  );
}