Invoicing class

Amazon Web Services Invoice Configuration

You can use Amazon Web Services Invoice Configuration APIs to programmatically create, update, delete, get, and list invoice units. You can also programmatically fetch the information of the invoice receiver. For example, business legal name, address, and invoicing contacts.

You can use Amazon Web Services Invoice Configuration to receive separate Amazon Web Services invoices based your organizational needs. By using Amazon Web Services Invoice Configuration, you can configure invoice units that are groups of Amazon Web Services accounts that represent your business entities, and receive separate invoices for each business entity. You can also assign a unique member or payer account as the invoice receiver for each invoice unit. As you create new accounts within your Organizations using Amazon Web Services Invoice Configuration APIs, you can automate the creation of new invoice units and subsequently automate the addition of new accounts to your invoice units.

Amazon Web Services Procurement Portal Preferences

You can use Amazon Web Services Procurement Portal Preferences APIs to programmatically create, update, delete, get, and list procurement portal connections and e-invoice delivery settings. You can also programmatically fetch and modify the status of procurement portal configurations. For example, SAP Business Network or Coupa connections, configure e-invoice delivery and purchase order retrieval features.

You can use Amazon Web Services Procurement Portal Preferences to connect e-invoice delivery to your procurement portals based on your organizational needs. By using Amazon Web Services Procurement Portal Preferences, you can configure connections to SAP Business Network and Coupa procurement portals that retrieve purchase orders and deliver Amazon Web Services invoices on the same day they are generated. You can also set up testing environments to validate invoice delivery without affecting live transactions, and manage contact information for portal setup and support.

Administrative users should understand that billing read-only policies will show all procurement portal connection details. Review your IAM policies to ensure appropriate access controls are in place for procurement portal preferences.

Amazon Web Services Invoice Management

You can use Amazon Web Services Invoice Management APIs to programmatically list invoice summaries and get invoice documents. You can also programmatically fetch invoice documents with S3 pre-signed URLs.

You can use Amazon Web Services Invoice Management to access invoice information based on your organizational needs. By using Amazon Web Services Invoice Management, you can retrieve paginated lists of invoice summaries that include invoice metadata such as invoice IDs, amounts, and currencies without downloading documents. You can also download invoice documents in PDF format using S3 pre-signed URLs with built-in expiration. As you manage invoices across your organization using Amazon Web Services Invoice Management APIs, you can create invoice retrieval processes and integrate invoice data into your financial systems.

Service endpoint

You can use the following endpoints for Amazon Web Services Invoice Configuration, Amazon Web Services Procurement Portal Preferences, and Amazon Web Services Invoice Management:

  • https://invoicing.us-east-1.api.aws

Constructors

Invoicing({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetInvoiceProfile({required List<String> accountIds}) Future<BatchGetInvoiceProfileResponse>
This gets the invoice profile associated with a set of accounts. The accounts must be linked accounts under the requester management account organization.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createInvoiceUnit({required String invoiceReceiver, required String name, required InvoiceUnitRule rule, String? clientToken, String? description, List<ResourceTag>? resourceTags, bool? taxInheritanceDisabled}) Future<CreateInvoiceUnitResponse>
This creates a new invoice unit with the provided definition.
createProcurementPortalPreference({required BuyerDomain buyerDomain, required String buyerIdentifier, required List<Contact> contacts, required bool einvoiceDeliveryEnabled, required ProcurementPortalName procurementPortalName, required bool purchaseOrderRetrievalEnabled, required SupplierDomain supplierDomain, required String supplierIdentifier, String? clientToken, EinvoiceDeliveryPreference? einvoiceDeliveryPreference, String? procurementPortalInstanceEndpoint, String? procurementPortalSharedSecret, List<ResourceTag>? resourceTags, ProcurementPortalPreferenceSelector? selector, TestEnvPreferenceInput? testEnvPreference}) Future<CreateProcurementPortalPreferenceResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).
deleteInvoiceUnit({required String invoiceUnitArn, String? clientToken}) Future<DeleteInvoiceUnitResponse>
This deletes an invoice unit with the provided invoice unit ARN.
deleteProcurementPortalPreference({required String procurementPortalPreferenceArn, String? clientToken}) Future<DeleteProcurementPortalPreferenceResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).
getInvoicePDF({required String invoiceId}) Future<GetInvoicePDFResponse>
Returns a URL to download the invoice document and supplemental documents associated with an invoice. The URLs are pre-signed and have expiration time. For special cases like Brazil, where Amazon Web Services generated invoice identifiers and government provided identifiers do not match, use the Amazon Web Services generated invoice identifier when making API requests. To grant IAM permission to use this operation, the caller needs the invoicing:GetInvoicePDF policy action.
getInvoiceUnit({required String invoiceUnitArn, DateTime? asOf}) Future<GetInvoiceUnitResponse>
This retrieves the invoice unit definition.
getProcurementPortalPreference({required String procurementPortalPreferenceArn}) Future<GetProcurementPortalPreferenceResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).
listInvoiceSummaries({required InvoiceSummariesSelector selector, InvoiceSummariesFilter? filter, int? maxResults, String? nextToken}) Future<ListInvoiceSummariesResponse>
Retrieves your invoice details programmatically, without line item details.
listInvoiceUnits({DateTime? asOf, Filters? filters, int? maxResults, String? nextToken}) Future<ListInvoiceUnitsResponse>
This fetches a list of all invoice unit definitions for a given account, as of the provided AsOf date.
listProcurementPortalPreferences({int? maxResults, String? nextToken}) Future<ListProcurementPortalPreferencesResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putProcurementPortalPreference({required List<Contact> contacts, required bool einvoiceDeliveryEnabled, required String procurementPortalPreferenceArn, required bool purchaseOrderRetrievalEnabled, String? clientToken, EinvoiceDeliveryPreference? einvoiceDeliveryPreference, String? procurementPortalInstanceEndpoint, String? procurementPortalSharedSecret, ProcurementPortalPreferenceSelector? selector, TestEnvPreferenceInput? testEnvPreference}) Future<PutProcurementPortalPreferenceResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).
tagResource({required String resourceArn, required List<ResourceTag> resourceTags}) Future<void>
Adds a tag to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> resourceTagKeys}) Future<void>
Removes a tag from a resource.
updateInvoiceUnit({required String invoiceUnitArn, String? clientToken, String? description, InvoiceUnitRule? rule, bool? taxInheritanceDisabled}) Future<UpdateInvoiceUnitResponse>
You can update the invoice unit configuration at any time, and Amazon Web Services will use the latest configuration at the end of the month.
updateProcurementPortalPreferenceStatus({required String procurementPortalPreferenceArn, String? clientToken, ProcurementPortalPreferenceStatus? einvoiceDeliveryPreferenceStatus, String? einvoiceDeliveryPreferenceStatusReason, ProcurementPortalPreferenceStatus? purchaseOrderRetrievalPreferenceStatus, String? purchaseOrderRetrievalPreferenceStatusReason}) Future<UpdateProcurementPortalPreferenceStatusResponse>
This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).

Operators

operator ==(Object other) bool
The equality operator.
inherited