batchGetInvoiceProfile method
This gets the invoice profile associated with a set of accounts. The accounts must be linked accounts under the requester management account organization.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
Retrieves the corresponding invoice profile data for these account IDs.
Implementation
Future<BatchGetInvoiceProfileResponse> batchGetInvoiceProfile({
required List<String> accountIds,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Invoicing.BatchGetInvoiceProfile'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccountIds': accountIds,
},
);
return BatchGetInvoiceProfileResponse.fromJson(jsonResponse.body);
}