getProcurementPortalPreference method

Future<GetProcurementPortalPreferenceResponse> getProcurementPortalPreference({
  1. required String procurementPortalPreferenceArn,
})

This feature API is subject to changing at any time. For more information, see the Amazon Web Services Service Terms (Betas and Previews).

Retrieves the details of a specific procurement portal preference configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter procurementPortalPreferenceArn : The Amazon Resource Name (ARN) of the procurement portal preference to retrieve.

Implementation

Future<GetProcurementPortalPreferenceResponse>
    getProcurementPortalPreference({
  required String procurementPortalPreferenceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Invoicing.GetProcurementPortalPreference'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ProcurementPortalPreferenceArn': procurementPortalPreferenceArn,
    },
  );

  return GetProcurementPortalPreferenceResponse.fromJson(jsonResponse.body);
}