confirmTopicRuleDestination method
Confirms a topic rule destination. When you create a rule requiring a
destination, IoT sends a confirmation message to the endpoint or base
address you specify. The message includes a token which you pass back when
calling ConfirmTopicRuleDestination to confirm that you own
or have access to the endpoint.
Requires permission to access the ConfirmTopicRuleDestination action.
May throw ConflictingResourceUpdateException.
May throw InternalException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw UnauthorizedException.
Parameter confirmationToken :
The token used to confirm ownership or access to the topic rule
confirmation URL.
Implementation
Future<void> confirmTopicRuleDestination({
required String confirmationToken,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/confirmdestination/${confirmationToken.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
}