deleteAccountAuditConfiguration method
Restores the default settings for Device Defender audits for this account. Any configuration data you entered is deleted and all audit checks are reset to disabled.
Requires permission to access the DeleteAccountAuditConfiguration action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter deleteScheduledAudits :
If true, all scheduled audits are deleted.
Implementation
Future<void> deleteAccountAuditConfiguration({
bool? deleteScheduledAudits,
}) async {
final $query = <String, List<String>>{
if (deleteScheduledAudits != null)
'deleteScheduledAudits': [deleteScheduledAudits.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/audit/configuration',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}