deleteCommandExecution method

Future<void> deleteCommandExecution({
  1. required String executionId,
  2. required String targetArn,
})

Delete a command execution.

May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter executionId : The unique identifier of the command execution that you want to delete from your account.

Parameter targetArn : The Amazon Resource Number (ARN) of the target device for which you want to delete command executions.

Implementation

Future<void> deleteCommandExecution({
  required String executionId,
  required String targetArn,
}) async {
  final $query = <String, List<String>>{
    'targetArn': [targetArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/command-executions/${Uri.encodeComponent(executionId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}