deleteMitigationAction method
Deletes a defined mitigation action from your Amazon Web Services accounts.
Requires permission to access the DeleteMitigationAction action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter actionName :
The name of the mitigation action that you want to delete.
Implementation
Future<void> deleteMitigationAction({
required String actionName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/mitigationactions/actions/${Uri.encodeComponent(actionName)}',
exceptionFnMap: _exceptionFns,
);
}