deletePackageVersion method

Future<void> deletePackageVersion({
  1. required String packageName,
  2. required String versionName,
  3. String? clientToken,
})

Deletes a specific version from a software package.

Note: If a package version is designated as default, you must remove the designation from the software package using the UpdatePackage action.

May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter packageName : The name of the associated software package.

Parameter versionName : The name of the target package version.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Implementation

Future<void> deletePackageVersion({
  required String packageName,
  required String versionName,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/packages/${Uri.encodeComponent(packageName)}/versions/${Uri.encodeComponent(versionName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}