describeAccountAuditConfiguration method

Future<DescribeAccountAuditConfigurationResponse> describeAccountAuditConfiguration()

Gets information about the Device Defender audit settings for this account. Settings include how audit notifications are sent and which audit checks are enabled or disabled.

Requires permission to access the DescribeAccountAuditConfiguration action.

May throw InternalFailureException. May throw ThrottlingException.

Implementation

Future<DescribeAccountAuditConfigurationResponse>
    describeAccountAuditConfiguration() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/audit/configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAccountAuditConfigurationResponse.fromJson(response);
}