describeEncryptionConfiguration method

Future<DescribeEncryptionConfigurationResponse> describeEncryptionConfiguration()

Retrieves the encryption configuration for resources and data of your Amazon Web Services account in Amazon Web Services IoT Core. For more information, see Data encryption at rest in the Amazon Web Services IoT Core Developer Guide.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw UnauthorizedException.

Implementation

Future<DescribeEncryptionConfigurationResponse>
    describeEncryptionConfiguration() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/encryption-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeEncryptionConfigurationResponse.fromJson(response);
}