describeJob method
Describes a job.
Requires permission to access the DescribeJob action.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter jobId :
The unique identifier you assigned to this job when it was created.
Parameter beforeSubstitution :
Provides a view of the job document before and after the substitution
parameters have been resolved with their exact values.
Implementation
Future<DescribeJobResponse> describeJob({
required String jobId,
bool? beforeSubstitution,
}) async {
final $query = <String, List<String>>{
if (beforeSubstitution != null)
'beforeSubstitution': [beforeSubstitution.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/jobs/${Uri.encodeComponent(jobId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeJobResponse.fromJson(response);
}