describeJobExecution method

Future<DescribeJobExecutionResponse> describeJobExecution({
  1. required String jobId,
  2. required String thingName,
  3. int? executionNumber,
})

Describes a job execution.

Requires permission to access the DescribeJobExecution action.

May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter jobId : The unique identifier you assigned to this job when it was created.

Parameter thingName : The name of the thing on which the job execution is running.

Parameter executionNumber : A string (consisting of the digits "0" through "9" which is used to specify a particular job execution on a particular device.

Implementation

Future<DescribeJobExecutionResponse> describeJobExecution({
  required String jobId,
  required String thingName,
  int? executionNumber,
}) async {
  final $query = <String, List<String>>{
    if (executionNumber != null)
      'executionNumber': [executionNumber.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/things/${Uri.encodeComponent(thingName)}/jobs/${Uri.encodeComponent(jobId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeJobExecutionResponse.fromJson(response);
}