disassociateSbomFromPackageVersion method

Future<void> disassociateSbomFromPackageVersion({
  1. required String packageName,
  2. required String versionName,
  3. String? clientToken,
})

Disassociates the selected software bill of materials (SBOM) from a specific software package version.

Requires permission to access the DisassociateSbomWithPackageVersion action.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter packageName : The name of the new software package.

Parameter versionName : The name of the new package version.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Implementation

Future<void> disassociateSbomFromPackageVersion({
  required String packageName,
  required String versionName,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/packages/${Uri.encodeComponent(packageName)}/versions/${Uri.encodeComponent(versionName)}/sbom',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}