getRegistrationCode method
Gets a registration code used to register a CA certificate with IoT.
IoT will create a registration code as part of this API call if the registration code doesn't exist or has been deleted. If you already have a registration code, this API call will return the same registration code.
Requires permission to access the GetRegistrationCode action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Implementation
Future<GetRegistrationCodeResponse> getRegistrationCode() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/registrationcode',
exceptionFnMap: _exceptionFns,
);
return GetRegistrationCodeResponse.fromJson(response);
}