listAuthorizers method

Future<ListAuthorizersResponse> listAuthorizers({
  1. bool? ascendingOrder,
  2. String? marker,
  3. int? pageSize,
  4. AuthorizerStatus? status,
})

Lists the authorizers registered in your account.

Requires permission to access the ListAuthorizers action.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw UnauthorizedException.

Parameter ascendingOrder : Return the list of authorizers in ascending alphabetical order.

Parameter marker : A marker used to get the next set of results.

Parameter pageSize : The maximum number of results to return at one time.

Parameter status : The status of the list authorizers request.

Implementation

Future<ListAuthorizersResponse> listAuthorizers({
  bool? ascendingOrder,
  String? marker,
  int? pageSize,
  AuthorizerStatus? status,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    1,
    250,
  );
  final $query = <String, List<String>>{
    if (ascendingOrder != null)
      'isAscendingOrder': [ascendingOrder.toString()],
    if (marker != null) 'marker': [marker],
    if (pageSize != null) 'pageSize': [pageSize.toString()],
    if (status != null) 'status': [status.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/authorizers',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAuthorizersResponse.fromJson(response);
}