listCACertificates method

Future<ListCACertificatesResponse> listCACertificates({
  1. bool? ascendingOrder,
  2. String? marker,
  3. int? pageSize,
  4. String? templateName,
})

Lists the CA certificates registered for your Amazon Web Services account.

The results are paginated with a default page size of 25. You can use the returned marker to retrieve additional results.

Requires permission to access the ListCACertificates action.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw UnauthorizedException.

Parameter ascendingOrder : Determines the order of the results.

Parameter marker : The marker for the next set of results.

Parameter pageSize : The result page size.

Parameter templateName : The name of the provisioning template.

Implementation

Future<ListCACertificatesResponse> listCACertificates({
  bool? ascendingOrder,
  String? marker,
  int? pageSize,
  String? templateName,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    1,
    250,
  );
  final $query = <String, List<String>>{
    if (ascendingOrder != null)
      'isAscendingOrder': [ascendingOrder.toString()],
    if (marker != null) 'marker': [marker],
    if (pageSize != null) 'pageSize': [pageSize.toString()],
    if (templateName != null) 'templateName': [templateName],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cacertificates',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCACertificatesResponse.fromJson(response);
}