listCertificates method
Lists the certificates registered in your Amazon Web Services account.
The results are paginated with a default page size of 25. You can use the returned marker to retrieve additional results.
Requires permission to access the ListCertificates action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter ascendingOrder :
Specifies the order for results. If True, the results are returned in
ascending order, based on the creation date.
Parameter marker :
The marker for the next set of results.
Parameter pageSize :
The result page size.
Implementation
Future<ListCertificatesResponse> listCertificates({
bool? ascendingOrder,
String? marker,
int? pageSize,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
250,
);
final $query = <String, List<String>>{
if (ascendingOrder != null)
'isAscendingOrder': [ascendingOrder.toString()],
if (marker != null) 'marker': [marker],
if (pageSize != null) 'pageSize': [pageSize.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/certificates',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCertificatesResponse.fromJson(response);
}