listDimensions method
List the set of dimensions that are defined for your Amazon Web Services accounts.
Requires permission to access the ListDimensions action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of results to retrieve at one time.
Parameter nextToken :
The token for the next set of results.
Implementation
Future<ListDimensionsResponse> listDimensions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/dimensions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDimensionsResponse.fromJson(response);
}