listDomainConfigurations method
Gets a list of domain configurations for the user. This list is sorted alphabetically by domain configuration name.
Requires permission to access the ListDomainConfigurations action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter marker :
The marker for the next set of results.
Parameter pageSize :
The result page size.
Parameter serviceType :
The type of service delivered by the endpoint.
Implementation
Future<ListDomainConfigurationsResponse> listDomainConfigurations({
String? marker,
int? pageSize,
ServiceType? serviceType,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
250,
);
final $query = <String, List<String>>{
if (marker != null) 'marker': [marker],
if (pageSize != null) 'pageSize': [pageSize.toString()],
if (serviceType != null) 'serviceType': [serviceType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domainConfigurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDomainConfigurationsResponse.fromJson(response);
}