listFleetMetrics method
Lists all your fleet metrics.
Requires permission to access the ListFleetMetrics action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter maxResults :
The maximum number of results to return in this operation.
Parameter nextToken :
To retrieve the next set of results, the nextToken value from
a previous response; otherwise null to receive the first set
of results.
Implementation
Future<ListFleetMetricsResponse> listFleetMetrics({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/fleet-metrics',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFleetMetricsResponse.fromJson(response);
}