listJobTemplates method
Returns a list of job templates.
Requires permission to access the ListJobTemplates action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of results to return in the list.
Parameter nextToken :
The token to use to return the next set of results in the list.
Implementation
Future<ListJobTemplatesResponse> listJobTemplates({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/job-templates',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListJobTemplatesResponse.fromJson(response);
}