listMitigationActions method
Gets a list of all mitigation actions that match the specified filter criteria.
Requires permission to access the ListMitigationActions action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter actionType :
Specify a value to limit the result to mitigation actions with a specific
action type.
Parameter maxResults :
The maximum number of results to return at one time. The default is 25.
Parameter nextToken :
The token for the next set of results.
Implementation
Future<ListMitigationActionsResponse> listMitigationActions({
MitigationActionType? actionType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (actionType != null) 'actionType': [actionType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/mitigationactions/actions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMitigationActionsResponse.fromJson(response);
}