listProvisioningTemplates method

Future<ListProvisioningTemplatesResponse> listProvisioningTemplates({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the provisioning templates in your Amazon Web Services account.

Requires permission to access the ListProvisioningTemplates action.

May throw InternalFailureException. May throw InvalidRequestException. May throw ThrottlingException. May throw UnauthorizedException.

Parameter maxResults : The maximum number of results to return at one time.

Parameter nextToken : A token to retrieve the next set of results.

Implementation

Future<ListProvisioningTemplatesResponse> listProvisioningTemplates({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/provisioning-templates',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListProvisioningTemplatesResponse.fromJson(response);
}