listRoleAliases method
Lists the role aliases registered in your account.
Requires permission to access the ListRoleAliases action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter ascendingOrder :
Return the list of role aliases in ascending alphabetical order.
Parameter marker :
A marker used to get the next set of results.
Parameter pageSize :
The maximum number of results to return at one time.
Implementation
Future<ListRoleAliasesResponse> listRoleAliases({
bool? ascendingOrder,
String? marker,
int? pageSize,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
250,
);
final $query = <String, List<String>>{
if (ascendingOrder != null)
'isAscendingOrder': [ascendingOrder.toString()],
if (marker != null) 'marker': [marker],
if (pageSize != null) 'pageSize': [pageSize.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/role-aliases',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRoleAliasesResponse.fromJson(response);
}