listSbomValidationResults method

Future<ListSbomValidationResultsResponse> listSbomValidationResults({
  1. required String packageName,
  2. required String versionName,
  3. int? maxResults,
  4. String? nextToken,
  5. SbomValidationResult? validationResult,
})

The validation results for all software bill of materials (SBOM) attached to a specific software package version.

Requires permission to access the ListSbomValidationResults action.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter packageName : The name of the new software package.

Parameter versionName : The name of the new package version.

Parameter maxResults : The maximum number of results to return at one time.

Parameter nextToken : A token that can be used to retrieve the next set of results, or null if there are no additional results.

Parameter validationResult : The end result of the

Implementation

Future<ListSbomValidationResultsResponse> listSbomValidationResults({
  required String packageName,
  required String versionName,
  int? maxResults,
  String? nextToken,
  SbomValidationResult? validationResult,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (validationResult != null)
      'validationResult': [validationResult.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/packages/${Uri.encodeComponent(packageName)}/versions/${Uri.encodeComponent(versionName)}/sbom-validation-results',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSbomValidationResultsResponse.fromJson(response);
}