listTopicRuleDestinations method

Future<ListTopicRuleDestinationsResponse> listTopicRuleDestinations({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all the topic rule destinations in your Amazon Web Services account.

Requires permission to access the ListTopicRuleDestinations action.

May throw InternalException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw UnauthorizedException.

Parameter maxResults : The maximum number of results to return at one time.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListTopicRuleDestinationsResponse> listTopicRuleDestinations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/destinations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTopicRuleDestinationsResponse.fromJson(response);
}