registerCertificateWithoutCA method
Future<RegisterCertificateWithoutCAResponse>
registerCertificateWithoutCA({
- required String certificatePem,
- CertificateStatus? status,
Register a certificate that does not have a certificate authority (CA). For supported certificates, consult Certificate signing algorithms supported by IoT.
May throw CertificateStateException.
May throw CertificateValidationException.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceAlreadyExistsException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter certificatePem :
The certificate data, in PEM format.
Parameter status :
The status of the register certificate request.
Implementation
Future<RegisterCertificateWithoutCAResponse> registerCertificateWithoutCA({
required String certificatePem,
CertificateStatus? status,
}) async {
final $payload = <String, dynamic>{
'certificatePem': certificatePem,
if (status != null) 'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/certificate/register-no-ca',
exceptionFnMap: _exceptionFns,
);
return RegisterCertificateWithoutCAResponse.fromJson(response);
}