removeThingFromBillingGroup method
Removes the given thing from the billing group.
Requires permission to access the RemoveThingFromBillingGroup action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter billingGroupArn :
The ARN of the billing group.
Parameter billingGroupName :
The name of the billing group.
Parameter thingArn :
The ARN of the thing to be removed from the billing group.
Parameter thingName :
The name of the thing to be removed from the billing group.
Implementation
Future<void> removeThingFromBillingGroup({
String? billingGroupArn,
String? billingGroupName,
String? thingArn,
String? thingName,
}) async {
final $payload = <String, dynamic>{
if (billingGroupArn != null) 'billingGroupArn': billingGroupArn,
if (billingGroupName != null) 'billingGroupName': billingGroupName,
if (thingArn != null) 'thingArn': thingArn,
if (thingName != null) 'thingName': thingName,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/billing-groups/removeThingFromBillingGroup',
exceptionFnMap: _exceptionFns,
);
}