replaceTopicRule method
Future<void>
replaceTopicRule({
- required String ruleName,
- required TopicRulePayload topicRulePayload,
Replaces the rule. You must specify all parameters for the new rule. Creating rules is an administrator-level action. Any user who has permission to create rules will be able to access data processed by the rule.
Requires permission to access the ReplaceTopicRule action.
May throw ConflictingResourceUpdateException.
May throw InternalException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw SqlParseException.
May throw UnauthorizedException.
Parameter ruleName :
The name of the rule.
Parameter topicRulePayload :
The rule payload.
Implementation
Future<void> replaceTopicRule({
required String ruleName,
required TopicRulePayload topicRulePayload,
}) async {
await _protocol.send(
payload: topicRulePayload,
method: 'PATCH',
requestUri: '/rules/${Uri.encodeComponent(ruleName)}',
exceptionFnMap: _exceptionFns,
);
}