tagResource method
Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource.
Requires permission to access the TagResource action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resourceArn :
The ARN of the resource.
Parameter tags :
The new or modified tags for the resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final $payload = <String, dynamic>{
'resourceArn': resourceArn,
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags',
exceptionFnMap: _exceptionFns,
);
}