updatePackageConfiguration method

Future<void> updatePackageConfiguration({
  1. String? clientToken,
  2. VersionUpdateByJobsConfig? versionUpdateByJobsConfig,
})

Updates the software package configuration.

Requires permission to access the UpdatePackageConfiguration and iam:PassRole actions.

May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Parameter versionUpdateByJobsConfig : Configuration to manage job's package version reporting. This updates the thing's reserved named shadow that the job targets.

Implementation

Future<void> updatePackageConfiguration({
  String? clientToken,
  VersionUpdateByJobsConfig? versionUpdateByJobsConfig,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final $payload = <String, dynamic>{
    if (versionUpdateByJobsConfig != null)
      'versionUpdateByJobsConfig': versionUpdateByJobsConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/package-configuration',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}