IoTDataPlane class

IoT data enables secure, bi-directional communication between Internet-connected things (such as sensors, actuators, embedded devices, or smart appliances) and the Amazon Web Services cloud. It implements a broker for applications and things to publish messages over HTTP (Publish) and retrieve, update, and delete shadows. A shadow is a persistent representation of your things and their state in the Amazon Web Services cloud.

Constructors

IoTDataPlane({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteConnection({required String clientId, bool? cleanSession, bool? preventWillMessage}) Future<void>
Disconnects a connected MQTT client from Amazon Web Services IoT Core. When you disconnect a client, Amazon Web Services IoT Core closes the client's network connection and optionally cleans the session state.
deleteThingShadow({required String thingName, String? shadowName}) Future<DeleteThingShadowResponse>
Deletes the shadow for the specified thing.
getConnection({required String clientId, bool? includeSocketInformation}) Future<GetConnectionResponse>
Retrieves connection information for the specified MQTT client.
getRetainedMessage({required String topic}) Future<GetRetainedMessageResponse>
Gets the details of a single retained message for the specified topic.
getThingShadow({required String thingName, String? shadowName}) Future<GetThingShadowResponse>
Gets the shadow for the specified thing.
listNamedShadowsForThing({required String thingName, String? nextToken, int? pageSize}) Future<ListNamedShadowsForThingResponse>
Lists the shadows for the specified thing.
listRetainedMessages({int? maxResults, String? nextToken}) Future<ListRetainedMessagesResponse>
Lists summary information about the retained messages stored for the account.
listSubscriptions({required String clientId, int? maxResults, String? nextToken}) Future<ListSubscriptionsResponse>
Returns a list of all subscriptions for MQTT clients with active sessions, including offline clients with persistent sessions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish({required String topic, String? contentType, String? correlationData, int? messageExpiry, Uint8List? payload, PayloadFormatIndicator? payloadFormatIndicator, int? qos, String? responseTopic, bool? retain, Object? userProperties}) Future<void>
Publishes an MQTT message.
sendDirectMessage({required String clientId, required String topic, bool? confirmation, String? contentType, String? correlationData, Uint8List? payload, PayloadFormatIndicator? payloadFormatIndicator, String? responseTopic, int? timeout, Object? userProperties}) Future<SendDirectMessageResponse>
Sends an MQTT message directly to a specific client identified by its client ID.
toString() String
A string representation of this object.
inherited
updateThingShadow({required Uint8List payload, required String thingName, String? shadowName}) Future<UpdateThingShadowResponse>
Updates the shadow for the specified thing.

Operators

operator ==(Object other) bool
The equality operator.
inherited