publish method
Publishes an MQTT message.
Requires permission to access the Publish action.
For more information about MQTT messages, see MQTT Protocol in the IoT Developer Guide.
For more information about messaging costs, see Amazon Web Services IoT Core pricing - Messaging.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw MethodNotAllowedException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter topic :
The name of the MQTT topic.
Parameter contentType :
A UTF-8 encoded string that describes the content of the publishing
message.
Parameter correlationData :
The base64-encoded binary data used by the sender of the request message
to identify which request the response message is for when it's received.
correlationData is an HTTP header value in the API.
Parameter messageExpiry :
A user-defined integer value that represents the message expiry interval
in seconds. If absent, the message doesn't expire. For more information
about the limits of messageExpiry, see Amazon
Web Services IoT Core message broker and protocol limits and quotas
from the Amazon Web Services Reference Guide.
Parameter payload :
The message body. MQTT accepts text, binary, and empty (null) message
payloads.
Publishing an empty (null) payload with retain = true
deletes the retained message identified by topic from Amazon Web
Services IoT Core.
Parameter payloadFormatIndicator :
An Enum string value that indicates whether the payload is
formatted as UTF-8. payloadFormatIndicator is an HTTP header
value in the API.
Parameter qos :
The Quality of Service (QoS) level. The default QoS level is 0.
Parameter responseTopic :
A UTF-8 encoded string that's used as the topic name for a response
message. The response topic is used to describe the topic which the
receiver should publish to as part of the request-response flow. The topic
must not contain wildcard characters.
Parameter retain :
A Boolean value that determines whether to set the RETAIN flag when the
message is published.
Setting the RETAIN flag causes the message to be retained and sent to new subscribers to the topic.
Valid values: true | false
Default value: false
Parameter userProperties :
A JSON string that contains an array of JSON objects. If you don’t use
Amazon Web Services SDK or CLI, you must encode the JSON string to base64
format before adding it to the HTTP header. userProperties is
an HTTP header value in the API.
The following example userProperties parameter is a JSON
string which represents two User Properties. Note that it needs to be
base64-encoded:
[{"deviceName": "alpha"}, {"deviceCnt": "45"}]
Implementation
Future<void> publish({
required String topic,
String? contentType,
String? correlationData,
int? messageExpiry,
Uint8List? payload,
PayloadFormatIndicator? payloadFormatIndicator,
int? qos,
String? responseTopic,
bool? retain,
Object? userProperties,
}) async {
_s.validateNumRange(
'qos',
qos,
0,
1,
);
final headers = <String, String>{
if (correlationData != null)
'x-amz-mqtt5-correlation-data': correlationData.toString(),
if (payloadFormatIndicator != null)
'x-amz-mqtt5-payload-format-indicator': payloadFormatIndicator.value,
if (userProperties != null)
'x-amz-mqtt5-user-properties':
base64Encode(utf8.encode(jsonEncode(userProperties))),
};
final $query = <String, List<String>>{
if (contentType != null) 'contentType': [contentType],
if (messageExpiry != null) 'messageExpiry': [messageExpiry.toString()],
if (qos != null) 'qos': [qos.toString()],
if (responseTopic != null) 'responseTopic': [responseTopic],
if (retain != null) 'retain': [retain.toString()],
};
await _protocol.send(
payload: payload,
method: 'POST',
requestUri: '/topics/${Uri.encodeComponent(topic)}',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
}