IotDeviceAdvisor class
Amazon Web Services IoT Core Device Advisor is a cloud-based, fully managed test capability for validating IoT devices during device software development. Device Advisor provides pre-built tests that you can use to validate IoT devices for reliable and secure connectivity with Amazon Web Services IoT Core before deploying devices to production. By using Device Advisor, you can confirm that your devices can connect to Amazon Web Services IoT Core, follow security best practices and, if applicable, receive software updates from IoT Device Management. You can also download signed qualification reports to submit to the Amazon Web Services Partner Network to get your device qualified for the Amazon Web Services Partner Device Catalog without the need to send your device in and wait for it to be tested.
Constructors
- IotDeviceAdvisor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createSuiteDefinition(
{required SuiteDefinitionConfiguration suiteDefinitionConfiguration, String? clientToken, Map< String, String> ? tags}) → Future<CreateSuiteDefinitionResponse> - Creates a Device Advisor test suite.
-
deleteSuiteDefinition(
{required String suiteDefinitionId}) → Future< void> - Deletes a Device Advisor test suite.
-
getEndpoint(
{AuthenticationMethod? authenticationMethod, String? certificateArn, String? deviceRoleArn, String? thingArn}) → Future< GetEndpointResponse> - Gets information about an Device Advisor endpoint.
-
getSuiteDefinition(
{required String suiteDefinitionId, String? suiteDefinitionVersion}) → Future< GetSuiteDefinitionResponse> - Gets information about a Device Advisor test suite.
-
getSuiteRun(
{required String suiteDefinitionId, required String suiteRunId}) → Future< GetSuiteRunResponse> - Gets information about a Device Advisor test suite run.
-
getSuiteRunReport(
{required String suiteDefinitionId, required String suiteRunId}) → Future< GetSuiteRunReportResponse> - Gets a report download link for a successful Device Advisor qualifying test suite run.
-
listSuiteDefinitions(
{int? maxResults, String? nextToken}) → Future< ListSuiteDefinitionsResponse> - Lists the Device Advisor test suites you have created.
-
listSuiteRuns(
{int? maxResults, String? nextToken, String? suiteDefinitionId, String? suiteDefinitionVersion}) → Future< ListSuiteRunsResponse> - Lists runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags attached to an IoT Device Advisor resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startSuiteRun(
{required String suiteDefinitionId, required SuiteRunConfiguration suiteRunConfiguration, String? suiteDefinitionVersion, Map< String, String> ? tags}) → Future<StartSuiteRunResponse> - Starts a Device Advisor test suite run.
-
stopSuiteRun(
{required String suiteDefinitionId, required String suiteRunId}) → Future< void> - Stops a Device Advisor test suite run that is currently running.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds to and modifies existing tags of an IoT Device Advisor resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from an IoT Device Advisor resource.
-
updateSuiteDefinition(
{required SuiteDefinitionConfiguration suiteDefinitionConfiguration, required String suiteDefinitionId}) → Future< UpdateSuiteDefinitionResponse> - Updates a Device Advisor test suite.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited