batchDeleteDetector method

Future<BatchDeleteDetectorResponse> batchDeleteDetector({
  1. required List<DeleteDetectorRequest> detectors,
})

Deletes one or more detectors that were created. When a detector is deleted, its state will be cleared and the detector will be removed from the list of detectors. The deleted detector will no longer appear if referenced in the ListDetectors API call.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter detectors : The list of one or more detectors to be deleted.

Implementation

Future<BatchDeleteDetectorResponse> batchDeleteDetector({
  required List<DeleteDetectorRequest> detectors,
}) async {
  final $payload = <String, dynamic>{
    'detectors': detectors,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/detectors/delete',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeleteDetectorResponse.fromJson(response);
}