batchSnoozeAlarm method

Future<BatchSnoozeAlarmResponse> batchSnoozeAlarm({
  1. required List<SnoozeAlarmActionRequest> snoozeActionRequests,
})

Changes one or more alarms to the snooze mode. The alarms change to the SNOOZE_DISABLED state after you set them to the snooze mode.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter snoozeActionRequests : The list of snooze action requests. You can specify up to 10 requests per operation.

Implementation

Future<BatchSnoozeAlarmResponse> batchSnoozeAlarm({
  required List<SnoozeAlarmActionRequest> snoozeActionRequests,
}) async {
  final $payload = <String, dynamic>{
    'snoozeActionRequests': snoozeActionRequests,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/alarms/snooze',
    exceptionFnMap: _exceptionFns,
  );
  return BatchSnoozeAlarmResponse.fromJson(response);
}