iot_events_data_2018_10_23 library
Classes
- AwsClientCredentials
- AWS credentials.
- IoTEventsData
- IoT Events monitors your equipment or device fleets for failures or changes in operation, and triggers actions when such events occur. You can use IoT Events Data API commands to send inputs to detectors, list detectors, and view or update a detector's status.