iot_jobs_data_plane library

Classes

AwsClientCredentials
AWS credentials.
IoTJobsDataPlane
IoT Jobs is a service that allows you to define a set of jobs — remote operations that are sent to and executed on one or more devices connected to Amazon Web Services IoT Core. For example, you can define a job that instructs a set of devices to download and install application or firmware updates, reboot, rotate certificates, or perform remote troubleshooting operations.