IoTManagedIntegrations class

Managed integrations is a feature of AWS IoT Device Management that enables developers to quickly build innovative IoT solutions. Customers can use managed integrations to automate device setup workflows and support interoperability across many devices, regardless of device vendor or connectivity protocol. This allows developers to use a single user-interface to control, manage, and operate a range of devices.

Constructors

IoTManagedIntegrations({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAccountAssociation({required String connectorDestinationId, String? clientToken, String? description, GeneralAuthorizationName? generalAuthorization, String? name, Map<String, String>? tags}) Future<CreateAccountAssociationResponse>
Creates a new account association via the destination id.
createCloudConnector({required EndpointConfig endpointConfig, required String name, String? clientToken, String? description, EndpointType? endpointType}) Future<CreateCloudConnectorResponse>
Creates a C2C (cloud-to-cloud) connector.
createConnectorDestination({required AuthConfig authConfig, required String cloudConnectorId, AuthType? authType, String? clientToken, String? description, String? name, SecretsManager? secretsManager}) Future<CreateConnectorDestinationResponse>
Create a connector destination for connecting a cloud-to-cloud (C2C) connector to the customer's Amazon Web Services account.
createCredentialLocker({String? clientToken, String? name, Map<String, String>? tags}) Future<CreateCredentialLockerResponse>
Create a credential locker.
createDestination({required String deliveryDestinationArn, required DeliveryDestinationType deliveryDestinationType, required String name, required String roleArn, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateDestinationResponse>
Create a notification destination such as Kinesis Data Streams that receive events and notifications from Managed integrations. Managed integrations uses the destination to determine where to deliver notifications.
createEventLogConfiguration({required LogLevel eventLogLevel, required String resourceType, String? clientToken, String? resourceId}) Future<CreateEventLogConfigurationResponse>
Set the event log configuration for the account, resource type, or specific resource.
createManagedThing({required String authenticationMaterial, required AuthMaterialType authenticationMaterialType, required Role role, String? brand, String? capabilities, CapabilityReport? capabilityReport, List<CapabilitySchemaItem>? capabilitySchemas, String? classification, String? clientToken, String? credentialLockerId, Map<String, String>? metaData, String? model, String? name, String? owner, String? serialNumber, Map<String, String>? tags, WiFiSimpleSetupConfiguration? wiFiSimpleSetupConfiguration}) Future<CreateManagedThingResponse>
Creates a managed thing. A managed thing contains the device identifier, protocol supported, and capabilities of the device in a data model format defined by Managed integrations.
createNotificationConfiguration({required String destinationName, required EventType eventType, String? clientToken, Map<String, String>? tags}) Future<CreateNotificationConfigurationResponse>
Creates a notification configuration. A configuration is a connection between an event type and a destination that you have already created.
createOtaTask({required OtaType otaType, required String s3Url, String? clientToken, String? description, OtaMechanism? otaMechanism, OtaTaskSchedulingConfig? otaSchedulingConfig, String? otaTargetQueryString, OtaTaskExecutionRetryConfig? otaTaskExecutionRetryConfig, OtaProtocol? protocol, Map<String, String>? tags, List<String>? target, String? taskConfigurationId}) Future<CreateOtaTaskResponse>
Create an over-the-air (OTA) task to target a device.
createOtaTaskConfiguration({String? clientToken, String? description, String? name, PushConfig? pushConfig}) Future<CreateOtaTaskConfigurationResponse>
Create a configuraiton for the over-the-air (OTA) task.
createProvisioningProfile({required ProvisioningType provisioningType, String? caCertificate, String? claimCertificate, String? clientToken, String? name, Map<String, String>? tags}) Future<CreateProvisioningProfileResponse>
Create a provisioning profile for executing device provisioning flows. The provisioning profile is a document that defines the set of resources and policies applied to a device during the provisioning process.
deleteAccountAssociation({required String accountAssociationId}) Future<void>
Remove a third-party account association for an end user.
deleteCloudConnector({required String identifier}) Future<void>
Delete a cloud connector.
deleteConnectorDestination({required String identifier}) Future<void>
Delete a connector destination linked to a cloud-to-cloud (C2C) connector.
deleteCredentialLocker({required String identifier}) Future<void>
Delete a credential locker.
deleteDestination({required String name}) Future<void>
Deletes a notification destination specified by name.
deleteEventLogConfiguration({required String id}) Future<void>
Delete an event log configuration.
deleteManagedThing({required String identifier, bool? force}) Future<void>
Delete a managed thing. For direct-connected and hub-connected devices connecting with Managed integrations via a controller, all of the devices connected to it will have their status changed to PENDING. It is not possible to remove a cloud-to-cloud device.
deleteNotificationConfiguration({required EventType eventType}) Future<void>
Deletes a notification configuration.
deleteOtaTask({required String identifier}) Future<void>
Delete the over-the-air (OTA) task.
deleteOtaTaskConfiguration({required String identifier}) Future<void>
Delete the over-the-air (OTA) task configuration.
deleteProvisioningProfile({required String identifier}) Future<void>
Delete a provisioning profile.
deregisterAccountAssociation({required String accountAssociationId, required String managedThingId}) Future<void>
Deregister an account association from a managed thing.
getAccountAssociation({required String accountAssociationId}) Future<GetAccountAssociationResponse>
Get an account association for an Amazon Web Services account linked to a customer-managed destination.
getCloudConnector({required String identifier}) Future<GetCloudConnectorResponse>
Get configuration details for a cloud connector.
getConnectorDestination({required String identifier}) Future<GetConnectorDestinationResponse>
Get connector destination details linked to a cloud-to-cloud (C2C) connector.
getCredentialLocker({required String identifier}) Future<GetCredentialLockerResponse>
Get information on an existing credential locker
getCustomEndpoint() Future<GetCustomEndpointResponse>
Returns the IoT managed integrations custom endpoint.
getDefaultEncryptionConfiguration() Future<GetDefaultEncryptionConfigurationResponse>
Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified region. For more information, see Key management in the AWS IoT SiteWise User Guide.
getDestination({required String name}) Future<GetDestinationResponse>
Gets a destination by name.
getDeviceDiscovery({required String identifier}) Future<GetDeviceDiscoveryResponse>
Get the current state of a device discovery.
getEventLogConfiguration({required String id}) Future<GetEventLogConfigurationResponse>
Get an event log configuration.
getHubConfiguration() Future<GetHubConfigurationResponse>
Get a hub configuration.
getManagedThing({required String identifier}) Future<GetManagedThingResponse>
Get details of a managed thing including its attributes and capabilities.
getManagedThingCapabilities({required String identifier}) Future<GetManagedThingCapabilitiesResponse>
Get the capabilities for a managed thing using the device ID.
getManagedThingCertificate({required String identifier}) Future<GetManagedThingCertificateResponse>
Retrieves the certificate PEM for a managed IoT thing.
getManagedThingConnectivityData({required String identifier}) Future<GetManagedThingConnectivityDataResponse>
Get the connectivity status of a managed thing.
getManagedThingMetaData({required String identifier}) Future<GetManagedThingMetaDataResponse>
Get the metadata information for a managed thing.
getManagedThingState({required String managedThingId}) Future<GetManagedThingStateResponse>
Returns the managed thing state for the given device Id.
getNotificationConfiguration({required EventType eventType}) Future<GetNotificationConfigurationResponse>
Get a notification configuration for a specified event type.
getOtaTask({required String identifier}) Future<GetOtaTaskResponse>
Get details of the over-the-air (OTA) task by its task id.
getOtaTaskConfiguration({required String identifier}) Future<GetOtaTaskConfigurationResponse>
Get a configuraiton for the over-the-air (OTA) task.
getProvisioningProfile({required String identifier}) Future<GetProvisioningProfileResponse>
Get details of a provisioning profile.
getRuntimeLogConfiguration({required String managedThingId}) Future<GetRuntimeLogConfigurationResponse>
Get the runtime log configuration for a specific managed thing.
getSchemaVersion({required String schemaVersionedId, required SchemaVersionType type, SchemaVersionFormat? format}) Future<GetSchemaVersionResponse>
Gets a schema version with the provided information.
listAccountAssociations({String? connectorDestinationId, int? maxResults, String? nextToken}) Future<ListAccountAssociationsResponse>
Lists all account associations, with optional filtering by connector destination ID.
listCloudConnectors({String? lambdaArn, int? maxResults, String? nextToken, CloudConnectorType? type}) Future<ListCloudConnectorsResponse>
Returns a list of connectors filtered by its Lambda Amazon Resource Name (ARN) and type.
listConnectorDestinations({String? cloudConnectorId, int? maxResults, String? nextToken}) Future<ListConnectorDestinationsResponse>
Lists all connector destinations, with optional filtering by cloud connector ID.
listCredentialLockers({int? maxResults, String? nextToken}) Future<ListCredentialLockersResponse>
List information on an existing credential locker.
listDestinations({int? maxResults, String? nextToken}) Future<ListDestinationsResponse>
List all notification destinations.
listDeviceDiscoveries({int? maxResults, String? nextToken, DeviceDiscoveryStatus? statusFilter, DiscoveryType? typeFilter}) Future<ListDeviceDiscoveriesResponse>
Lists all device discovery tasks, with optional filtering by type and status.
listDiscoveredDevices({required String identifier, int? maxResults, String? nextToken}) Future<ListDiscoveredDevicesResponse>
Lists all devices discovered during a specific device discovery task.
listEventLogConfigurations({int? maxResults, String? nextToken}) Future<ListEventLogConfigurationsResponse>
List all event log configurations for an account.
listManagedThingAccountAssociations({String? accountAssociationId, String? managedThingId, int? maxResults, String? nextToken}) Future<ListManagedThingAccountAssociationsResponse>
Lists all account associations for a specific managed thing.
listManagedThings({String? connectorDestinationIdFilter, String? connectorDeviceIdFilter, String? connectorPolicyIdFilter, String? credentialLockerFilter, int? maxResults, String? nextToken, String? ownerFilter, String? parentControllerIdentifierFilter, ProvisioningStatus? provisioningStatusFilter, Role? roleFilter, String? serialNumberFilter}) Future<ListManagedThingsResponse>
Listing all managed things with provision for filters.
listManagedThingSchemas({required String identifier, String? capabilityIdFilter, String? endpointIdFilter, int? maxResults, String? nextToken}) Future<ListManagedThingSchemasResponse>
List schemas associated with a managed thing.
listNotificationConfigurations({int? maxResults, String? nextToken}) Future<ListNotificationConfigurationsResponse>
List all notification configurations.
listOtaTaskConfigurations({int? maxResults, String? nextToken}) Future<ListOtaTaskConfigurationsResponse>
List all of the over-the-air (OTA) task configurations.
listOtaTaskExecutions({required String identifier, int? maxResults, String? nextToken}) Future<ListOtaTaskExecutionsResponse>
List all of the over-the-air (OTA) task executions.
listOtaTasks({int? maxResults, String? nextToken}) Future<ListOtaTasksResponse>
List all of the over-the-air (OTA) tasks.
listProvisioningProfiles({int? maxResults, String? nextToken}) Future<ListProvisioningProfilesResponse>
List the provisioning profiles within the Amazon Web Services account.
listSchemaVersions({required SchemaVersionType type, int? maxResults, String? namespace, String? nextToken, String? schemaId, String? semanticVersion, SchemaVersionVisibility? visibility}) Future<ListSchemaVersionsResponse>
Lists schema versions with the provided information.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for a specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putDefaultEncryptionConfiguration({required EncryptionType encryptionType, String? kmsKeyArn}) Future<PutDefaultEncryptionConfigurationResponse>
Sets the default encryption configuration for the Amazon Web Services account. For more information, see Key management in the AWS IoT SiteWise User Guide.
putHubConfiguration({required int hubTokenTimerExpirySettingInSeconds}) Future<PutHubConfigurationResponse>
Update a hub configuration.
putRuntimeLogConfiguration({required String managedThingId, required RuntimeLogConfigurations runtimeLogConfigurations}) Future<void>
Set the runtime log configuration for a specific managed thing.
registerAccountAssociation({required String accountAssociationId, required String deviceDiscoveryId, required String managedThingId}) Future<RegisterAccountAssociationResponse>
Registers an account association with a managed thing, establishing a connection between a device and a third-party account.
registerCustomEndpoint() Future<RegisterCustomEndpointResponse>
Customers can request IoT managed integrations to manage the server trust for them or bring their own external server trusts for the custom domain. Returns an IoT managed integrations endpoint.
resetRuntimeLogConfiguration({required String managedThingId}) Future<void>
Reset a runtime log configuration for a specific managed thing.
sendConnectorEvent({required String connectorId, required ConnectorEventOperation operation, String? connectorDeviceId, String? deviceDiscoveryId, List<Device>? devices, MatterEndpoint? matterEndpoint, String? message, String? operationVersion, int? statusCode, String? traceId, String? userId}) Future<SendConnectorEventResponse>
Relays third-party device events for a connector such as a new device or a device state change event.
sendManagedThingCommand({required List<CommandEndpoint> endpoints, required String managedThingId, String? accountAssociationId, String? connectorAssociationId}) Future<SendManagedThingCommandResponse>
Send the command to the device represented by the managed thing.
startAccountAssociationRefresh({required String accountAssociationId}) Future<StartAccountAssociationRefreshResponse>
Initiates a refresh of an existing account association to update its authorization and connection status.
startDeviceDiscovery({required DiscoveryType discoveryType, String? accountAssociationId, String? authenticationMaterial, DiscoveryAuthMaterialType? authenticationMaterialType, String? clientToken, String? connectorAssociationIdentifier, List<String>? connectorDeviceIdList, String? controllerIdentifier, Map<String, String>? customProtocolDetail, String? endDeviceIdentifier, ProtocolType? protocol, Map<String, String>? tags}) Future<StartDeviceDiscoveryResponse>
This API is used to start device discovery for hub-connected and third-party-connected devices. The authentication material (install code) is delivered as a message to the controller instructing it to start the discovery.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to a specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a specified resource.
updateAccountAssociation({required String accountAssociationId, String? description, String? name}) Future<void>
Updates the properties of an existing account association.
updateCloudConnector({required String identifier, String? description, String? name}) Future<void>
Update an existing cloud connector.
updateConnectorDestination({required String identifier, AuthConfigUpdate? authConfig, AuthType? authType, String? description, String? name, SecretsManager? secretsManager}) Future<void>
Updates the properties of an existing connector destination.
updateDestination({required String name, String? deliveryDestinationArn, DeliveryDestinationType? deliveryDestinationType, String? description, String? roleArn}) Future<void>
Update a destination specified by name.
updateEventLogConfiguration({required LogLevel eventLogLevel, required String id}) Future<void>
Update an event log configuration by log configuration ID.
updateManagedThing({required String identifier, String? brand, String? capabilities, CapabilityReport? capabilityReport, List<CapabilitySchemaItem>? capabilitySchemas, String? classification, String? credentialLockerId, HubNetworkMode? hubNetworkMode, Map<String, String>? metaData, String? model, String? name, String? owner, String? serialNumber, WiFiSimpleSetupConfiguration? wiFiSimpleSetupConfiguration}) Future<void>
Update the attributes and capabilities associated with a managed thing.
updateNotificationConfiguration({required String destinationName, required EventType eventType}) Future<void>
Update a notification configuration.
updateOtaTask({required String identifier, String? description, String? taskConfigurationId}) Future<void>
Update an over-the-air (OTA) task.

Operators

operator ==(Object other) bool
The equality operator.
inherited