createConnectorDestination method
Create a connector destination for connecting a cloud-to-cloud (C2C) connector to the customer's Amazon Web Services account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter authConfig :
The authentication configuration details for the connector destination,
including OAuth settings and other authentication parameters.
Parameter cloudConnectorId :
The identifier of the C2C connector.
Parameter authType :
The authentication type used for the connector destination, which
determines how credentials and access are managed.
Parameter clientToken :
An idempotency token. If you retry a request that completed successfully
initially using the same client token and parameters, then the retry
attempt will succeed without performing any further actions.
Parameter description :
A description of the connector destination.
Parameter name :
The display name of the connector destination.
Parameter secretsManager :
The AWS Secrets Manager configuration used to securely store and manage
sensitive information for the connector destination.
Implementation
Future<CreateConnectorDestinationResponse> createConnectorDestination({
required AuthConfig authConfig,
required String cloudConnectorId,
AuthType? authType,
String? clientToken,
String? description,
String? name,
SecretsManager? secretsManager,
}) async {
final $payload = <String, dynamic>{
'AuthConfig': authConfig,
'CloudConnectorId': cloudConnectorId,
if (authType != null) 'AuthType': authType.value,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (name != null) 'Name': name,
if (secretsManager != null) 'SecretsManager': secretsManager,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/connector-destinations',
exceptionFnMap: _exceptionFns,
);
return CreateConnectorDestinationResponse.fromJson(response);
}