getDefaultEncryptionConfiguration method
Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified region. For more information, see Key management in the AWS IoT SiteWise User Guide.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Implementation
Future<GetDefaultEncryptionConfigurationResponse>
getDefaultEncryptionConfiguration() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/configuration/account/encryption',
exceptionFnMap: _exceptionFns,
);
return GetDefaultEncryptionConfigurationResponse.fromJson(response);
}