getNotificationConfiguration method

Future<GetNotificationConfigurationResponse> getNotificationConfiguration({
  1. required EventType eventType,
})

Get a notification configuration for a specified event type.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter eventType : The type of event triggering a device notification to the customer-managed destination.

Implementation

Future<GetNotificationConfigurationResponse> getNotificationConfiguration({
  required EventType eventType,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/notification-configurations/${Uri.encodeComponent(eventType.value)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetNotificationConfigurationResponse.fromJson(response);
}