listCloudConnectors method

Future<ListCloudConnectorsResponse> listCloudConnectors({
  1. String? lambdaArn,
  2. int? maxResults,
  3. String? nextToken,
  4. CloudConnectorType? type,
})

Returns a list of connectors filtered by its Lambda Amazon Resource Name (ARN) and type.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter lambdaArn : The Amazon Resource Name (ARN) of the Lambda function to filter cloud connectors by.

Parameter maxResults : The maximum number of results to return at one time.

Parameter nextToken : A token that can be used to retrieve the next set of results.

Parameter type : The type of cloud connectors to filter by when listing available connectors.

Implementation

Future<ListCloudConnectorsResponse> listCloudConnectors({
  String? lambdaArn,
  int? maxResults,
  String? nextToken,
  CloudConnectorType? type,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (lambdaArn != null) 'LambdaArn': [lambdaArn],
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
    if (type != null) 'Type': [type.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cloud-connectors',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListCloudConnectorsResponse.fromJson(response);
}