listOtaTaskExecutions method
List all of the over-the-air (OTA) task executions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The over-the-air (OTA) task id.
Parameter maxResults :
The maximum number of results to return at one time.
Parameter nextToken :
A token that can be used to retrieve the next set of results.
Implementation
Future<ListOtaTaskExecutionsResponse> listOtaTaskExecutions({
required String identifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/ota-tasks/${Uri.encodeComponent(identifier)}/devices',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListOtaTaskExecutionsResponse.fromJson(response);
}