listProvisioningProfiles method
List the provisioning profiles within the Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return at one time.
Parameter nextToken :
A token that can be used to retrieve the next set of results.
Implementation
Future<ListProvisioningProfilesResponse> listProvisioningProfiles({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/provisioning-profiles',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListProvisioningProfilesResponse.fromJson(response);
}