registerCustomEndpoint method

Future<RegisterCustomEndpointResponse> registerCustomEndpoint()

Customers can request IoT managed integrations to manage the server trust for them or bring their own external server trusts for the custom domain. Returns an IoT managed integrations endpoint.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Implementation

Future<RegisterCustomEndpointResponse> registerCustomEndpoint() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/custom-endpoint',
    exceptionFnMap: _exceptionFns,
  );
  return RegisterCustomEndpointResponse.fromJson(response);
}