startAccountAssociationRefresh method

Future<StartAccountAssociationRefreshResponse> startAccountAssociationRefresh({
  1. required String accountAssociationId,
})

Initiates a refresh of an existing account association to update its authorization and connection status.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw ValidationException.

Parameter accountAssociationId : The unique identifier of the account association to refresh.

Implementation

Future<StartAccountAssociationRefreshResponse>
    startAccountAssociationRefresh({
  required String accountAssociationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/account-associations/${Uri.encodeComponent(accountAssociationId)}/refresh',
    exceptionFnMap: _exceptionFns,
  );
  return StartAccountAssociationRefreshResponse.fromJson(response);
}