updateAccountAssociation method
Updates the properties of an existing account association.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountAssociationId :
The unique identifier of the account association to update.
Parameter description :
The new description to assign to the account association.
Parameter name :
The new name to assign to the account association.
Implementation
Future<void> updateAccountAssociation({
required String accountAssociationId,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'Description': description,
if (name != null) 'Name': name,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/account-associations/${Uri.encodeComponent(accountAssociationId)}',
exceptionFnMap: _exceptionFns,
);
}