updateConnectorDestination method

Future<void> updateConnectorDestination({
  1. required String identifier,
  2. AuthConfigUpdate? authConfig,
  3. AuthType? authType,
  4. String? description,
  5. String? name,
  6. SecretsManager? secretsManager,
})

Updates the properties of an existing connector destination.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : The unique identifier of the connector destination to update.

Parameter authConfig : The updated authentication configuration details for the connector destination.

Parameter authType : The new authentication type to use for the connector destination.

Parameter description : The new description to assign to the connector destination.

Parameter name : The new display name to assign to the connector destination.

Parameter secretsManager : The updated AWS Secrets Manager configuration for the connector destination.

Implementation

Future<void> updateConnectorDestination({
  required String identifier,
  AuthConfigUpdate? authConfig,
  AuthType? authType,
  String? description,
  String? name,
  SecretsManager? secretsManager,
}) async {
  final $payload = <String, dynamic>{
    if (authConfig != null) 'AuthConfig': authConfig,
    if (authType != null) 'AuthType': authType.value,
    if (description != null) 'Description': description,
    if (name != null) 'Name': name,
    if (secretsManager != null) 'SecretsManager': secretsManager,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/connector-destinations/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}