updateEventLogConfiguration method

Future<void> updateEventLogConfiguration({
  1. required LogLevel eventLogLevel,
  2. required String id,
})

Update an event log configuration by log configuration ID.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter eventLogLevel : The log level for the event in terms of severity.

Parameter id : The log configuration id.

Implementation

Future<void> updateEventLogConfiguration({
  required LogLevel eventLogLevel,
  required String id,
}) async {
  final $payload = <String, dynamic>{
    'EventLogLevel': eventLogLevel.value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/event-log-configurations/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}