IoTSecureTunneling class

IoT Secure Tunneling creates remote connections to devices deployed in the field.

Constructors

IoTSecureTunneling({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
closeTunnel({required String tunnelId, bool? delete}) Future<void>
Closes a tunnel identified by the unique tunnel id. When a CloseTunnel request is received, we close the WebSocket connections between the client and proxy server so no data can be transmitted.
describeTunnel({required String tunnelId}) Future<DescribeTunnelResponse>
Gets information about a tunnel identified by the unique tunnel id.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for the specified resource.
listTunnels({int? maxResults, String? nextToken, String? thingName}) Future<ListTunnelsResponse>
List all tunnels for an Amazon Web Services account. Tunnels are listed by creation time in descending order, newer tunnels will be listed before older tunnels.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTunnel({String? description, DestinationConfig? destinationConfig, List<Tag>? tags, TimeoutConfig? timeoutConfig}) Future<OpenTunnelResponse>
Creates a new tunnel, and returns two client access tokens for clients to use to connect to the IoT Secure Tunneling proxy server.
rotateTunnelAccessToken({required ClientMode clientMode, required String tunnelId, DestinationConfig? destinationConfig}) Future<RotateTunnelAccessTokenResponse>
Revokes the current client access token (CAT) and returns new CAT for clients to use when reconnecting to secure tunneling to access the same tunnel.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
A resource tag.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag from a resource.

Operators

operator ==(Object other) bool
The equality operator.
inherited