IoTSiteWise class
Welcome to the IoT SiteWise API Reference. IoT SiteWise is an Amazon Web Services service that connects Industrial Internet of Things (IIoT) devices to the power of the Amazon Web Services Cloud. For more information, see the IoT SiteWise User Guide. For information about IoT SiteWise quotas, see Quotas in the IoT SiteWise User Guide.
Constructors
- IoTSiteWise({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateAssets(
{required String assetId, required String childAssetId, required String hierarchyId, String? clientToken}) → Future< void> - Associates a child asset with the given parent asset through a hierarchy defined in the parent asset's model. For more information, see Associating assets in the IoT SiteWise User Guide.
-
associateTimeSeriesToAssetProperty(
{required String alias, required String assetId, required String propertyId, String? clientToken}) → Future< void> - Associates a time series (data stream) with an asset property.
-
batchAssociateProjectAssets(
{required List< String> assetIds, required String projectId, String? clientToken}) → Future<BatchAssociateProjectAssetsResponse> - Associates a group (batch) of assets with an IoT SiteWise Monitor project.
-
batchDisassociateProjectAssets(
{required List< String> assetIds, required String projectId, String? clientToken}) → Future<BatchDisassociateProjectAssetsResponse> - Disassociates a group (batch) of assets from an IoT SiteWise Monitor project.
-
batchGetAssetPropertyAggregates(
{required List< BatchGetAssetPropertyAggregatesEntry> entries, int? maxResults, String? nextToken}) → Future<BatchGetAssetPropertyAggregatesResponse> - Gets aggregated values (for example, average, minimum, and maximum) for one or more asset properties. For more information, see Querying aggregates in the IoT SiteWise User Guide.
-
batchGetAssetPropertyValue(
{required List< BatchGetAssetPropertyValueEntry> entries, String? nextToken}) → Future<BatchGetAssetPropertyValueResponse> - Gets the current value for one or more asset properties. For more information, see Querying current values in the IoT SiteWise User Guide.
-
batchGetAssetPropertyValueHistory(
{required List< BatchGetAssetPropertyValueHistoryEntry> entries, int? maxResults, String? nextToken}) → Future<BatchGetAssetPropertyValueHistoryResponse> - Gets the historical values for one or more asset properties. For more information, see Querying historical values in the IoT SiteWise User Guide.
-
batchPutAssetPropertyValue(
{required List< PutAssetPropertyValueEntry> entries, bool? enablePartialEntryProcessing}) → Future<BatchPutAssetPropertyValueResponse> - Sends a list of asset property values to IoT SiteWise. Each value is a timestamp-quality-value (TQV) data point. For more information, see Ingesting data using the API in the IoT SiteWise User Guide.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessPolicy(
{required Identity accessPolicyIdentity, required Permission accessPolicyPermission, required Resource accessPolicyResource, String? clientToken, Map< String, String> ? tags}) → Future<CreateAccessPolicyResponse> - Creates an access policy that grants the specified identity (IAM Identity Center user, IAM Identity Center group, or IAM user) access to the specified IoT SiteWise Monitor portal or project resource.
-
createAsset(
{required String assetModelId, required String assetName, String? assetDescription, String? assetExternalId, String? assetId, String? clientToken, Map< String, String> ? tags}) → Future<CreateAssetResponse> - Creates an asset from an existing asset model. For more information, see Creating assets in the IoT SiteWise User Guide.
-
createAssetModel(
{required String assetModelName, List< AssetModelCompositeModelDefinition> ? assetModelCompositeModels, String? assetModelDescription, String? assetModelExternalId, List<AssetModelHierarchyDefinition> ? assetModelHierarchies, String? assetModelId, List<AssetModelPropertyDefinition> ? assetModelProperties, AssetModelType? assetModelType, String? clientToken, Map<String, String> ? tags}) → Future<CreateAssetModelResponse> - Creates an asset model from specified property and hierarchy definitions. You create assets from asset models. With asset models, you can easily create assets of the same type that have standardized definitions. Each asset created from a model inherits the asset model's property and hierarchy definitions. For more information, see Defining asset models in the IoT SiteWise User Guide.
-
createAssetModelCompositeModel(
{required String assetModelCompositeModelName, required String assetModelCompositeModelType, required String assetModelId, String? assetModelCompositeModelDescription, String? assetModelCompositeModelExternalId, String? assetModelCompositeModelId, List< AssetModelPropertyDefinition> ? assetModelCompositeModelProperties, String? clientToken, String? composedAssetModelId, String? ifMatch, String? ifNoneMatch, AssetModelVersionType? matchForVersionType, String? parentAssetModelCompositeModelId}) → Future<CreateAssetModelCompositeModelResponse> -
Creates a custom composite model from specified property and hierarchy
definitions. There are two types of custom composite models,
inlineandcomponent-model-based. -
createBulkImportJob(
{required ErrorReportLocation errorReportLocation, required List< File> files, required JobConfiguration jobConfiguration, required String jobName, required String jobRoleArn, bool? adaptiveIngestion, bool? deleteFilesAfterImport}) → Future<CreateBulkImportJobResponse> - Defines a job to ingest data to IoT SiteWise from Amazon S3. For more information, see Create a bulk import job (CLI) in the Amazon Simple Storage Service User Guide.
-
createComputationModel(
{required ComputationModelConfiguration computationModelConfiguration, required Map< String, ComputationModelDataBindingValue> computationModelDataBinding, required String computationModelName, String? clientToken, String? computationModelDescription, Map<String, String> ? tags}) → Future<CreateComputationModelResponse> - Create a computation model with a configuration and data binding.
-
createDashboard(
{required String dashboardDefinition, required String dashboardName, required String projectId, String? clientToken, String? dashboardDescription, Map< String, String> ? tags}) → Future<CreateDashboardResponse> - Creates a dashboard in an IoT SiteWise Monitor project.
-
createDataset(
{required String datasetName, required DatasetSource datasetSource, String? clientToken, String? datasetDescription, String? datasetId, Map< String, String> ? tags}) → Future<CreateDatasetResponse> - Creates a dataset to connect an external datasource.
-
createGateway(
{required String gatewayName, required GatewayPlatform gatewayPlatform, String? gatewayVersion, Map< String, String> ? tags}) → Future<CreateGatewayResponse> - Creates a gateway, which is a virtual or edge device that delivers industrial data streams from local servers to IoT SiteWise. For more information, see Ingesting data using a gateway in the IoT SiteWise User Guide.
-
createPortal(
{required String portalContactEmail, required String portalName, required String roleArn, Alarms? alarms, String? clientToken, String? notificationSenderEmail, AuthMode? portalAuthMode, String? portalDescription, ImageFile? portalLogoImageFile, PortalType? portalType, Map< String, PortalTypeEntry> ? portalTypeConfiguration, Map<String, String> ? tags}) → Future<CreatePortalResponse> - Creates a portal, which can contain projects and dashboards. IoT SiteWise Monitor uses IAM Identity Center or IAM to authenticate portal users and manage user permissions.
-
createProject(
{required String portalId, required String projectName, String? clientToken, String? projectDescription, Map< String, String> ? tags}) → Future<CreateProjectResponse> - Creates a project in the specified portal.
-
deleteAccessPolicy(
{required String accessPolicyId, String? clientToken}) → Future< void> - Deletes an access policy that grants the specified identity access to the specified IoT SiteWise Monitor resource. You can use this operation to revoke access to an IoT SiteWise Monitor resource.
-
deleteAsset(
{required String assetId, String? clientToken}) → Future< DeleteAssetResponse> - Deletes an asset. This action can't be undone. For more information, see Deleting assets and models in the IoT SiteWise User Guide.
-
deleteAssetModel(
{required String assetModelId, String? clientToken, String? ifMatch, String? ifNoneMatch, AssetModelVersionType? matchForVersionType}) → Future< DeleteAssetModelResponse> - Deletes an asset model. This action can't be undone. You must delete all assets created from an asset model before you can delete the model. Also, you can't delete an asset model if a parent asset model exists that contains a property formula expression that depends on the asset model that you want to delete. For more information, see Deleting assets and models in the IoT SiteWise User Guide.
-
deleteAssetModelCompositeModel(
{required String assetModelCompositeModelId, required String assetModelId, String? clientToken, String? ifMatch, String? ifNoneMatch, AssetModelVersionType? matchForVersionType}) → Future< DeleteAssetModelCompositeModelResponse> - Deletes a composite model. This action can't be undone. You must delete all assets created from a composite model before you can delete the model. Also, you can't delete a composite model if a parent asset model exists that contains a property formula expression that depends on the asset model that you want to delete. For more information, see Deleting assets and models in the IoT SiteWise User Guide.
-
deleteAssetModelInterfaceRelationship(
{required String assetModelId, required String interfaceAssetModelId, String? clientToken}) → Future< DeleteAssetModelInterfaceRelationshipResponse> - Deletes an interface relationship between an asset model and an interface asset model.
-
deleteComputationModel(
{required String computationModelId, String? clientToken}) → Future< DeleteComputationModelResponse> - Deletes a computation model. This action can't be undone.
-
deleteDashboard(
{required String dashboardId, String? clientToken}) → Future< void> - Deletes a dashboard from IoT SiteWise Monitor.
-
deleteDataset(
{required String datasetId, String? clientToken}) → Future< DeleteDatasetResponse> - Deletes a dataset. This cannot be undone.
-
deleteGateway(
{required String gatewayId}) → Future< void> - Deletes a gateway from IoT SiteWise. When you delete a gateway, some of the gateway's files remain in your gateway's file system.
-
deletePortal(
{required String portalId, String? clientToken}) → Future< DeletePortalResponse> - Deletes a portal from IoT SiteWise Monitor.
-
deleteProject(
{required String projectId, String? clientToken}) → Future< void> - Deletes a project from IoT SiteWise Monitor.
-
deleteTimeSeries(
{String? alias, String? assetId, String? clientToken, String? propertyId}) → Future< void> - Deletes a time series (data stream). If you delete a time series that's associated with an asset property, the asset property still exists, but the time series will no longer be associated with this asset property.
-
describeAccessPolicy(
{required String accessPolicyId}) → Future< DescribeAccessPolicyResponse> - Describes an access policy, which specifies an identity's access to an IoT SiteWise Monitor portal or project.
-
describeAction(
{required String actionId}) → Future< DescribeActionResponse> - Retrieves information about an action.
-
describeAsset(
{required String assetId, bool? excludeProperties}) → Future< DescribeAssetResponse> - Retrieves information about an asset.
-
describeAssetCompositeModel(
{required String assetCompositeModelId, required String assetId}) → Future< DescribeAssetCompositeModelResponse> -
Retrieves information about an asset composite model (also known as an
asset component). An
AssetCompositeModelis an instance of anAssetModelCompositeModel. If you want to see information about the model this is based on, call DescribeAssetModelCompositeModel. -
describeAssetModel(
{required String assetModelId, String? assetModelVersion, bool? excludeProperties}) → Future< DescribeAssetModelResponse> - Retrieves information about an asset model. This includes details about the asset model's properties, hierarchies, composite models, and any interface relationships if the asset model implements interfaces.
-
describeAssetModelCompositeModel(
{required String assetModelCompositeModelId, required String assetModelId, String? assetModelVersion}) → Future< DescribeAssetModelCompositeModelResponse> - Retrieves information about an asset model composite model (also known as an asset model component). For more information, see Custom composite models (Components) in the IoT SiteWise User Guide.
-
describeAssetModelInterfaceRelationship(
{required String assetModelId, required String interfaceAssetModelId}) → Future< DescribeAssetModelInterfaceRelationshipResponse> - Retrieves information about an interface relationship between an asset model and an interface asset model.
-
describeAssetProperty(
{required String assetId, required String propertyId}) → Future< DescribeAssetPropertyResponse> - Retrieves information about an asset property. This operation doesn't return the value of the asset property. To get the value of an asset property, use GetAssetPropertyValue.
-
describeBulkImportJob(
{required String jobId}) → Future< DescribeBulkImportJobResponse> - Retrieves information about a bulk import job request. For more information, see Describe a bulk import job (CLI) in the Amazon Simple Storage Service User Guide.
-
describeComputationModel(
{required String computationModelId, String? computationModelVersion}) → Future< DescribeComputationModelResponse> - Retrieves information about a computation model.
-
describeComputationModelExecutionSummary(
{required String computationModelId, String? resolveToResourceId, ResolveToResourceType? resolveToResourceType}) → Future< DescribeComputationModelExecutionSummaryResponse> - Retrieves information about the execution summary of a computation model.
-
describeDashboard(
{required String dashboardId}) → Future< DescribeDashboardResponse> - Retrieves information about a dashboard.
-
describeDataset(
{required String datasetId}) → Future< DescribeDatasetResponse> - Retrieves information about a dataset.
-
describeDefaultEncryptionConfiguration(
) → Future< DescribeDefaultEncryptionConfigurationResponse> - Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified Region. For more information, see Key management in the IoT SiteWise User Guide.
-
describeExecution(
{required String executionId}) → Future< DescribeExecutionResponse> - Retrieves information about the execution.
-
describeGateway(
{required String gatewayId}) → Future< DescribeGatewayResponse> - Retrieves information about a gateway.
-
describeGatewayCapabilityConfiguration(
{required String capabilityNamespace, required String gatewayId}) → Future< DescribeGatewayCapabilityConfigurationResponse> - Each gateway capability defines data sources for a gateway. This is the namespace of the gateway capability.
-
describeLoggingOptions(
) → Future< DescribeLoggingOptionsResponse> - Retrieves the current IoT SiteWise logging options.
-
describePortal(
{required String portalId}) → Future< DescribePortalResponse> - Retrieves information about a portal.
-
describeProject(
{required String projectId}) → Future< DescribeProjectResponse> - Retrieves information about a project.
-
describeStorageConfiguration(
) → Future< DescribeStorageConfigurationResponse> - Retrieves information about the storage configuration for IoT SiteWise.
-
describeTimeSeries(
{String? alias, String? assetId, String? propertyId}) → Future< DescribeTimeSeriesResponse> - Retrieves information about a time series (data stream).
-
disassociateAssets(
{required String assetId, required String childAssetId, required String hierarchyId, String? clientToken}) → Future< void> - Disassociates a child asset from the given parent asset through a hierarchy defined in the parent asset's model.
-
disassociateTimeSeriesFromAssetProperty(
{required String alias, required String assetId, required String propertyId, String? clientToken}) → Future< void> - Disassociates a time series (data stream) from an asset property.
-
executeAction(
{required String actionDefinitionId, required ActionPayload actionPayload, required TargetResource targetResource, String? clientToken, ResolveTo? resolveTo}) → Future< ExecuteActionResponse> - Executes an action on a target resource.
-
executeQuery(
{required String queryStatement, String? clientToken, int? maxResults, String? nextToken}) → Future< ExecuteQueryResponse> - Run SQL queries to retrieve metadata and time-series data from asset models, assets, measurements, metrics, transforms, and aggregates.
-
getAssetPropertyAggregates(
{required List< AggregateType> aggregateTypes, required DateTime endDate, required String resolution, required DateTime startDate, String? assetId, int? maxResults, String? nextToken, String? propertyAlias, String? propertyId, List<Quality> ? qualities, TimeOrdering? timeOrdering}) → Future<GetAssetPropertyAggregatesResponse> - Gets aggregated values for an asset property. For more information, see Querying aggregates in the IoT SiteWise User Guide.
-
getAssetPropertyValue(
{String? assetId, String? propertyAlias, String? propertyId}) → Future< GetAssetPropertyValueResponse> - Gets an asset property's current value. For more information, see Querying current values in the IoT SiteWise User Guide.
-
getAssetPropertyValueHistory(
{String? assetId, DateTime? endDate, int? maxResults, String? nextToken, String? propertyAlias, String? propertyId, List< Quality> ? qualities, DateTime? startDate, TimeOrdering? timeOrdering}) → Future<GetAssetPropertyValueHistoryResponse> - Gets the history of an asset property's values. For more information, see Querying historical values in the IoT SiteWise User Guide.
-
getInterpolatedAssetPropertyValues(
{required int endTimeInSeconds, required int intervalInSeconds, required Quality quality, required int startTimeInSeconds, required String type, String? assetId, int? endTimeOffsetInNanos, int? intervalWindowInSeconds, int? maxResults, String? nextToken, String? propertyAlias, String? propertyId, int? startTimeOffsetInNanos}) → Future< GetInterpolatedAssetPropertyValuesResponse> - Get interpolated values for an asset property for a specified time interval, during a period of time. If your time series is missing data points during the specified time interval, you can use interpolation to estimate the missing data.
-
invokeAssistant(
{required String message, String? conversationId, bool? enableTrace}) → Future< InvokeAssistantResponse> - Invokes SiteWise Assistant to start or continue a conversation.
-
listAccessPolicies(
{String? iamArn, String? identityId, IdentityType? identityType, int? maxResults, String? nextToken, String? resourceId, ResourceType? resourceType}) → Future< ListAccessPoliciesResponse> - Retrieves a paginated list of access policies for an identity (an IAM Identity Center user, an IAM Identity Center group, or an IAM user) or an IoT SiteWise Monitor resource (a portal or project).
-
listActions(
{required String targetResourceId, required TargetResourceType targetResourceType, int? maxResults, String? nextToken, String? resolveToResourceId, ResolveToResourceType? resolveToResourceType}) → Future< ListActionsResponse> - Retrieves a paginated list of actions for a specific target resource.
-
listAssetModelCompositeModels(
{required String assetModelId, String? assetModelVersion, int? maxResults, String? nextToken}) → Future< ListAssetModelCompositeModelsResponse> - Retrieves a paginated list of composite models associated with the asset model
-
listAssetModelProperties(
{required String assetModelId, String? assetModelVersion, ListAssetModelPropertiesFilter? filter, int? maxResults, String? nextToken}) → Future< ListAssetModelPropertiesResponse> - Retrieves a paginated list of properties associated with an asset model. If you update properties associated with the model before you finish listing all the properties, you need to start all over again.
-
listAssetModels(
{List< AssetModelType> ? assetModelTypes, String? assetModelVersion, int? maxResults, String? nextToken}) → Future<ListAssetModelsResponse> - Retrieves a paginated list of summaries of all asset models.
-
listAssetProperties(
{required String assetId, ListAssetPropertiesFilter? filter, int? maxResults, String? nextToken}) → Future< ListAssetPropertiesResponse> - Retrieves a paginated list of properties associated with an asset. If you update properties associated with the model before you finish listing all the properties, you need to start all over again.
-
listAssetRelationships(
{required String assetId, required TraversalType traversalType, int? maxResults, String? nextToken}) → Future< ListAssetRelationshipsResponse> - Retrieves a paginated list of asset relationships for an asset. You can use this operation to identify an asset's root asset and all associated assets between that asset and its root.
-
listAssets(
{String? assetModelId, ListAssetsFilter? filter, int? maxResults, String? nextToken}) → Future< ListAssetsResponse> - Retrieves a paginated list of asset summaries.
-
listAssociatedAssets(
{required String assetId, String? hierarchyId, int? maxResults, String? nextToken, TraversalDirection? traversalDirection}) → Future< ListAssociatedAssetsResponse> - Retrieves a paginated list of associated assets.
-
listBulkImportJobs(
{ListBulkImportJobsFilter? filter, int? maxResults, String? nextToken}) → Future< ListBulkImportJobsResponse> - Retrieves a paginated list of bulk import job requests. For more information, see List bulk import jobs (CLI) in the IoT SiteWise User Guide.
-
listCompositionRelationships(
{required String assetModelId, int? maxResults, String? nextToken}) → Future< ListCompositionRelationshipsResponse> -
Retrieves a paginated list of composition relationships for an asset model
of type
COMPONENT_MODEL. -
listComputationModelDataBindingUsages(
{required DataBindingValueFilter dataBindingValueFilter, int? maxResults, String? nextToken}) → Future< ListComputationModelDataBindingUsagesResponse> - Lists all data binding usages for computation models. This allows to identify where specific data bindings are being utilized across the computation models. This track dependencies between data sources and computation models.
-
listComputationModelResolveToResources(
{required String computationModelId, int? maxResults, String? nextToken}) → Future< ListComputationModelResolveToResourcesResponse> - Lists all distinct resources that are resolved from the executed actions of the computation model.
-
listComputationModels(
{ComputationModelType? computationModelType, int? maxResults, String? nextToken}) → Future< ListComputationModelsResponse> - Retrieves a paginated list of summaries of all computation models.
-
listDashboards(
{required String projectId, int? maxResults, String? nextToken}) → Future< ListDashboardsResponse> - Retrieves a paginated list of dashboards for an IoT SiteWise Monitor project.
-
listDatasets(
{required DatasetSourceType sourceType, int? maxResults, String? nextToken}) → Future< ListDatasetsResponse> - Retrieves a paginated list of datasets for a specific target resource.
-
listExecutions(
{required String targetResourceId, required TargetResourceType targetResourceType, String? actionType, int? maxResults, String? nextToken, String? resolveToResourceId, ResolveToResourceType? resolveToResourceType}) → Future< ListExecutionsResponse> - Retrieves a paginated list of summaries of all executions.
-
listGateways(
{int? maxResults, String? nextToken}) → Future< ListGatewaysResponse> - Retrieves a paginated list of gateways.
-
listInterfaceRelationships(
{required String interfaceAssetModelId, int? maxResults, String? nextToken}) → Future< ListInterfaceRelationshipsResponse> - Retrieves a paginated list of asset models that have a specific interface asset model applied to them.
-
listPortals(
{int? maxResults, String? nextToken}) → Future< ListPortalsResponse> - Retrieves a paginated list of IoT SiteWise Monitor portals.
-
listProjectAssets(
{required String projectId, int? maxResults, String? nextToken}) → Future< ListProjectAssetsResponse> - Retrieves a paginated list of assets associated with an IoT SiteWise Monitor project.
-
listProjects(
{required String portalId, int? maxResults, String? nextToken}) → Future< ListProjectsResponse> - Retrieves a paginated list of projects for an IoT SiteWise Monitor portal.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Retrieves the list of tags for an IoT SiteWise resource.
-
listTimeSeries(
{String? aliasPrefix, String? assetId, int? maxResults, String? nextToken, ListTimeSeriesType? timeSeriesType}) → Future< ListTimeSeriesResponse> - Retrieves a paginated list of time series (data streams).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAssetModelInterfaceRelationship(
{required String assetModelId, required String interfaceAssetModelId, required PropertyMappingConfiguration propertyMappingConfiguration, String? clientToken}) → Future< PutAssetModelInterfaceRelationshipResponse> - Creates or updates an interface relationship between an asset model and an interface asset model. This operation applies an interface to an asset model.
-
putDefaultEncryptionConfiguration(
{required EncryptionType encryptionType, String? kmsKeyId}) → Future< PutDefaultEncryptionConfigurationResponse> - Sets the default encryption configuration for the Amazon Web Services account. For more information, see Key management in the IoT SiteWise User Guide.
-
putLoggingOptions(
{required LoggingOptions loggingOptions}) → Future< void> - Sets logging options for IoT SiteWise.
-
putStorageConfiguration(
{required StorageType storageType, bool? disallowIngestNullNaN, DisassociatedDataStorageState? disassociatedDataStorage, MultiLayerStorage? multiLayerStorage, RetentionPeriod? retentionPeriod, WarmTierState? warmTier, WarmTierRetentionPeriod? warmTierRetentionPeriod}) → Future< PutStorageConfigurationResponse> - Configures storage settings for IoT SiteWise.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds tags to an IoT SiteWise resource. If a tag already exists for the resource, this operation updates the tag's value.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from an IoT SiteWise resource.
-
updateAccessPolicy(
{required String accessPolicyId, required Identity accessPolicyIdentity, required Permission accessPolicyPermission, required Resource accessPolicyResource, String? clientToken}) → Future< void> - Updates an existing access policy that specifies an identity's access to an IoT SiteWise Monitor portal or project resource.
-
updateAsset(
{required String assetId, required String assetName, String? assetDescription, String? assetExternalId, String? clientToken}) → Future< UpdateAssetResponse> - Updates an asset's name. For more information, see Updating assets and models in the IoT SiteWise User Guide.
-
updateAssetModel(
{required String assetModelId, required String assetModelName, List< AssetModelCompositeModel> ? assetModelCompositeModels, String? assetModelDescription, String? assetModelExternalId, List<AssetModelHierarchy> ? assetModelHierarchies, List<AssetModelProperty> ? assetModelProperties, String? clientToken, String? ifMatch, String? ifNoneMatch, AssetModelVersionType? matchForVersionType}) → Future<UpdateAssetModelResponse> - Updates an asset model and all of the assets that were created from the model. Each asset created from the model inherits the updated asset model's property and hierarchy definitions. For more information, see Updating assets and models in the IoT SiteWise User Guide.
-
updateAssetModelCompositeModel(
{required String assetModelCompositeModelId, required String assetModelCompositeModelName, required String assetModelId, String? assetModelCompositeModelDescription, String? assetModelCompositeModelExternalId, List< AssetModelProperty> ? assetModelCompositeModelProperties, String? clientToken, String? ifMatch, String? ifNoneMatch, AssetModelVersionType? matchForVersionType}) → Future<UpdateAssetModelCompositeModelResponse> - Updates a composite model and all of the assets that were created from the model. Each asset created from the model inherits the updated asset model's property and hierarchy definitions. For more information, see Updating assets and models in the IoT SiteWise User Guide.
-
updateAssetProperty(
{required String assetId, required String propertyId, String? clientToken, String? propertyAlias, PropertyNotificationState? propertyNotificationState, String? propertyUnit}) → Future< void> - Updates an asset property's alias and notification state.
-
updateComputationModel(
{required ComputationModelConfiguration computationModelConfiguration, required Map< String, ComputationModelDataBindingValue> computationModelDataBinding, required String computationModelId, required String computationModelName, String? clientToken, String? computationModelDescription}) → Future<UpdateComputationModelResponse> - Updates the computation model.
-
updateDashboard(
{required String dashboardDefinition, required String dashboardId, required String dashboardName, String? clientToken, String? dashboardDescription}) → Future< void> - Updates an IoT SiteWise Monitor dashboard.
-
updateDataset(
{required String datasetId, required String datasetName, required DatasetSource datasetSource, String? clientToken, String? datasetDescription}) → Future< UpdateDatasetResponse> - Updates a dataset.
-
updateGateway(
{required String gatewayId, required String gatewayName}) → Future< void> - Updates a gateway's name.
-
updateGatewayCapabilityConfiguration(
{required String capabilityConfiguration, required String capabilityNamespace, required String gatewayId}) → Future< UpdateGatewayCapabilityConfigurationResponse> - Updates a gateway capability configuration or defines a new capability configuration. Each gateway capability defines data sources for a gateway.
-
updatePortal(
{required String portalContactEmail, required String portalId, required String portalName, required String roleArn, Alarms? alarms, String? clientToken, String? notificationSenderEmail, String? portalDescription, Image? portalLogoImage, PortalType? portalType, Map< String, PortalTypeEntry> ? portalTypeConfiguration}) → Future<UpdatePortalResponse> - Updates an IoT SiteWise Monitor portal.
-
updateProject(
{required String projectId, required String projectName, String? clientToken, String? projectDescription}) → Future< void> - Updates an IoT SiteWise Monitor project.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited