batchGetAssetPropertyValue method

Future<BatchGetAssetPropertyValueResponse> batchGetAssetPropertyValue({
  1. required List<BatchGetAssetPropertyValueEntry> entries,
  2. String? nextToken,
})

Gets the current value for one or more asset properties. For more information, see Querying current values in the IoT SiteWise User Guide.

May throw InternalFailureException. May throw InvalidRequestException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter entries : The list of asset property value entries for the batch get request. You can specify up to 128 entries per request.

Parameter nextToken : The token to be used for the next set of paginated results.

Implementation

Future<BatchGetAssetPropertyValueResponse> batchGetAssetPropertyValue({
  required List<BatchGetAssetPropertyValueEntry> entries,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'entries': entries,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/properties/batch/latest',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetAssetPropertyValueResponse.fromJson(response);
}