batchPutAssetPropertyValue method
Sends a list of asset property values to IoT SiteWise. Each value is a timestamp-quality-value (TQV) data point. For more information, see Ingesting data using the API in the IoT SiteWise User Guide.
To identify an asset property, you must specify one of the following:
-
The
assetIdandpropertyIdof an asset property. -
A
propertyAlias, which is a data stream alias (for example,/company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.
Implementation
Future<BatchPutAssetPropertyValueResponse> batchPutAssetPropertyValue({
required List<PutAssetPropertyValueEntry> entries,
bool? enablePartialEntryProcessing,
}) async {
final $payload = <String, dynamic>{
'entries': entries,
if (enablePartialEntryProcessing != null)
'enablePartialEntryProcessing': enablePartialEntryProcessing,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/properties',
exceptionFnMap: _exceptionFns,
);
return BatchPutAssetPropertyValueResponse.fromJson(response);
}