deleteComputationModel method

Future<DeleteComputationModelResponse> deleteComputationModel({
  1. required String computationModelId,
  2. String? clientToken,
})

Deletes a computation model. This action can't be undone.

May throw ConflictingOperationException. May throw InternalFailureException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter computationModelId : The ID of the computation model.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Implementation

Future<DeleteComputationModelResponse> deleteComputationModel({
  required String computationModelId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/computation-models/${Uri.encodeComponent(computationModelId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteComputationModelResponse.fromJson(response);
}