deleteDataset method

Future<DeleteDatasetResponse> deleteDataset({
  1. required String datasetId,
  2. String? clientToken,
})

Deletes a dataset. This cannot be undone.

May throw ConflictingOperationException. May throw InternalFailureException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter datasetId : The ID of the dataset.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Implementation

Future<DeleteDatasetResponse> deleteDataset({
  required String datasetId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/datasets/${Uri.encodeComponent(datasetId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDatasetResponse.fromJson(response);
}