deleteProject method

Future<void> deleteProject({
  1. required String projectId,
  2. String? clientToken,
})

Deletes a project from IoT SiteWise Monitor.

May throw InternalFailureException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter projectId : The ID of the project.

Parameter clientToken : A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

Implementation

Future<void> deleteProject({
  required String projectId,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/projects/${Uri.encodeComponent(projectId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}