describeDefaultEncryptionConfiguration method

Future<DescribeDefaultEncryptionConfigurationResponse> describeDefaultEncryptionConfiguration()

Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified Region. For more information, see Key management in the IoT SiteWise User Guide.

May throw InternalFailureException. May throw InvalidRequestException. May throw ThrottlingException.

Implementation

Future<DescribeDefaultEncryptionConfigurationResponse>
    describeDefaultEncryptionConfiguration() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/configuration/account/encryption',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDefaultEncryptionConfigurationResponse.fromJson(response);
}