listComputationModelResolveToResources method

Future<ListComputationModelResolveToResourcesResponse> listComputationModelResolveToResources({
  1. required String computationModelId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all distinct resources that are resolved from the executed actions of the computation model.

May throw InternalFailureException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter computationModelId : The ID of the computation model for which to list resolved resources.

Parameter maxResults : The maximum number of results returned for each paginated request.

Parameter nextToken : The token used for the next set of paginated results.

Implementation

Future<ListComputationModelResolveToResourcesResponse>
    listComputationModelResolveToResources({
  required String computationModelId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/computation-models/${Uri.encodeComponent(computationModelId)}/resolve-to-resources',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListComputationModelResolveToResourcesResponse.fromJson(response);
}