listComputationModels method
Retrieves a paginated list of summaries of all computation models.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter computationModelType :
The type of computation model. If a computationModelType is
not provided, all types of computation models are returned.
Parameter maxResults :
The maximum number of results to return for each paginated request.
Parameter nextToken :
The token to be used for the next set of paginated results.
Implementation
Future<ListComputationModelsResponse> listComputationModels({
ComputationModelType? computationModelType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (computationModelType != null)
'computationModelType': [computationModelType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/computation-models',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListComputationModelsResponse.fromJson(response);
}