deleteFlowTemplate method
Deletes a workflow. Any new system or deployment that contains this workflow will fail to update or deploy. Existing deployments that contain the workflow will continue to run (since they use a snapshot of the workflow taken at the time of deployment).
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ThrottlingException.
Parameter id :
The ID of the workflow to be deleted.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME
Implementation
Future<void> deleteFlowTemplate({
required String id,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'IotThingsGraphFrontEndService.DeleteFlowTemplate'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'id': id,
},
);
}