iot_things_graph_2018_09_06 library
Classes
- AwsClientCredentials
- AWS credentials.
- IoTThingsGraph
- AWS IoT Things Graph provides an integrated set of tools that enable developers to connect devices and services that use different standards, such as units of measure and communication protocols. AWS IoT Things Graph makes it possible to build IoT applications with little to no code by connecting devices and services and defining how they interact at an abstract level.