batchPutPropertyValues method

Future<BatchPutPropertyValuesResponse> batchPutPropertyValues({
  1. required List<PropertyValueEntry> entries,
  2. required String workspaceId,
})

Sets values for multiple time series properties.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter entries : An object that maps strings to the property value entries to set. Each string in the mapping must be unique to this object.

Parameter workspaceId : The ID of the workspace that contains the properties to set.

Implementation

Future<BatchPutPropertyValuesResponse> batchPutPropertyValues({
  required List<PropertyValueEntry> entries,
  required String workspaceId,
}) async {
  final $payload = <String, dynamic>{
    'entries': entries,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/entity-properties',
    exceptionFnMap: _exceptionFns,
  );
  return BatchPutPropertyValuesResponse.fromJson(response);
}