getPropertyValue method

Future<GetPropertyValueResponse> getPropertyValue({
  1. required List<String> selectedProperties,
  2. required String workspaceId,
  3. String? componentName,
  4. String? componentPath,
  5. String? componentTypeId,
  6. String? entityId,
  7. int? maxResults,
  8. String? nextToken,
  9. String? propertyGroupName,
  10. TabularConditions? tabularConditions,
})

Gets the property values for a component, component type, entity, or workspace.

You must specify a value for either componentName, componentTypeId, entityId, or workspaceId.

May throw AccessDeniedException. May throw ConnectorFailureException. May throw ConnectorTimeoutException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter selectedProperties : The properties whose values the operation returns.

Parameter workspaceId : The ID of the workspace whose values the operation returns.

Parameter componentName : The name of the component whose property values the operation returns.

Parameter componentPath : This string specifies the path to the composite component, starting from the top-level component.

Parameter componentTypeId : The ID of the component type whose property values the operation returns.

Parameter entityId : The ID of the entity whose property values the operation returns.

Parameter maxResults : The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Parameter nextToken : The string that specifies the next page of results.

Parameter propertyGroupName : The property group name.

Parameter tabularConditions : The tabular conditions.

Implementation

Future<GetPropertyValueResponse> getPropertyValue({
  required List<String> selectedProperties,
  required String workspaceId,
  String? componentName,
  String? componentPath,
  String? componentTypeId,
  String? entityId,
  int? maxResults,
  String? nextToken,
  String? propertyGroupName,
  TabularConditions? tabularConditions,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    200,
  );
  final $payload = <String, dynamic>{
    'selectedProperties': selectedProperties,
    if (componentName != null) 'componentName': componentName,
    if (componentPath != null) 'componentPath': componentPath,
    if (componentTypeId != null) 'componentTypeId': componentTypeId,
    if (entityId != null) 'entityId': entityId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (propertyGroupName != null) 'propertyGroupName': propertyGroupName,
    if (tabularConditions != null) 'tabularConditions': tabularConditions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/workspaces/${Uri.encodeComponent(workspaceId)}/entity-properties/value',
    exceptionFnMap: _exceptionFns,
  );
  return GetPropertyValueResponse.fromJson(response);
}