listMetadataTransferJobs method
Lists the metadata transfer jobs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter destinationType :
The metadata transfer job's destination type.
Parameter sourceType :
The metadata transfer job's source type.
Parameter filters :
An object that filters metadata transfer jobs.
Parameter maxResults :
The maximum number of results to return at one time.
Parameter nextToken :
The string that specifies the next page of results.
Implementation
Future<ListMetadataTransferJobsResponse> listMetadataTransferJobs({
required DestinationType destinationType,
required SourceType sourceType,
List<ListMetadataTransferJobsFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
200,
);
final $payload = <String, dynamic>{
'destinationType': destinationType.value,
'sourceType': sourceType.value,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/metadata-transfer-jobs-list',
exceptionFnMap: _exceptionFns,
);
return ListMetadataTransferJobsResponse.fromJson(response);
}