updateWorkspace method

Future<UpdateWorkspaceResponse> updateWorkspace({
  1. required String workspaceId,
  2. String? description,
  3. String? role,
  4. String? s3Location,
})

Updates a workspace.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter workspaceId : The ID of the workspace.

Parameter description : The description of the workspace.

Parameter role : The ARN of the execution role associated with the workspace.

Parameter s3Location : The ARN of the S3 bucket where resources associated with the workspace are stored.

Implementation

Future<UpdateWorkspaceResponse> updateWorkspace({
  required String workspaceId,
  String? description,
  String? role,
  String? s3Location,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (role != null) 'role': role,
    if (s3Location != null) 's3Location': s3Location,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/workspaces/${Uri.encodeComponent(workspaceId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateWorkspaceResponse.fromJson(response);
}