createServiceProfile method
Creates a new service profile.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clientRequestToken :
Each resource must have a unique client request token. The client token is
used to implement idempotency. It ensures that the request completes no
more than one time. If you retry a request with the same token and the
same parameters, the request will complete successfully. However, if you
try to create a new resource using the same token but different
parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs
will automatically generate a unique client request. For more information
about idempotency, see Ensuring
idempotency in Amazon EC2 API requests.
Parameter loRaWAN :
The service profile information to use to create the service profile.
Parameter name :
The name of the new resource.
Parameter tags :
The tags to attach to the new service profile. Tags are metadata that you
can use to manage a resource.
Implementation
Future<CreateServiceProfileResponse> createServiceProfile({
String? clientRequestToken,
LoRaWANServiceProfile? loRaWAN,
String? name,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (loRaWAN != null) 'LoRaWAN': loRaWAN,
if (name != null) 'Name': name,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/service-profiles',
exceptionFnMap: _exceptionFns,
);
return CreateServiceProfileResponse.fromJson(response);
}