deleteWirelessGateway method

Future<void> deleteWirelessGateway({
  1. required String id,
})

Deletes a wireless gateway.

  • If you specify a GatewayEui value that already exists.
  • If you used a ClientRequestToken with the same parameters within the last 10 minutes.
To avoid this error, make sure that you use unique identifiers and parameters for each request within the specified time period.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the resource to delete.

Implementation

Future<void> deleteWirelessGateway({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/wireless-gateways/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}