deregisterWirelessDevice method

Future<void> deregisterWirelessDevice({
  1. required String identifier,
  2. WirelessDeviceType? wirelessDeviceType,
})

Deregister a wireless device from AWS IoT Wireless.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : The identifier of the wireless device to deregister from AWS IoT Wireless.

Parameter wirelessDeviceType : The type of wireless device to deregister from AWS IoT Wireless, which can be LoRaWAN or Sidewalk.

Implementation

Future<void> deregisterWirelessDevice({
  required String identifier,
  WirelessDeviceType? wirelessDeviceType,
}) async {
  final $query = <String, List<String>>{
    if (wirelessDeviceType != null)
      'WirelessDeviceType': [wirelessDeviceType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'PATCH',
    requestUri:
        '/wireless-devices/${Uri.encodeComponent(identifier)}/deregister',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}