getResourceEventConfiguration method

Future<GetResourceEventConfigurationResponse> getResourceEventConfiguration({
  1. required String identifier,
  2. required IdentifierType identifierType,
  3. EventNotificationPartnerType? partnerType,
})

Get the event configuration for a particular resource identifier.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter identifier : Resource identifier to opt in for event messaging.

Parameter identifierType : Identifier type of the particular resource identifier for event configuration.

Parameter partnerType : Partner type of the resource if the identifier type is PartnerAccountId.

Implementation

Future<GetResourceEventConfigurationResponse> getResourceEventConfiguration({
  required String identifier,
  required IdentifierType identifierType,
  EventNotificationPartnerType? partnerType,
}) async {
  final $query = <String, List<String>>{
    'identifierType': [identifierType.value],
    if (partnerType != null) 'partnerType': [partnerType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/event-configurations/${Uri.encodeComponent(identifier)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetResourceEventConfigurationResponse.fromJson(response);
}