getServiceEndpoint method

Future<GetServiceEndpointResponse> getServiceEndpoint({
  1. WirelessGatewayServiceType? serviceType,
})

Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceType : The service type for which to get endpoint information about. Can be CUPS for the Configuration and Update Server endpoint, or LNS for the LoRaWAN Network Server endpoint.

Implementation

Future<GetServiceEndpointResponse> getServiceEndpoint({
  WirelessGatewayServiceType? serviceType,
}) async {
  final $query = <String, List<String>>{
    if (serviceType != null) 'serviceType': [serviceType.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/service-endpoint',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetServiceEndpointResponse.fromJson(response);
}