getWirelessDeviceImportTask method

Future<GetWirelessDeviceImportTaskResponse> getWirelessDeviceImportTask({
  1. required String id,
})

Get information about an import task and count of device onboarding summary information for the import task.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The identifier of the import task for which information is requested.

Implementation

Future<GetWirelessDeviceImportTaskResponse> getWirelessDeviceImportTask({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/wireless_device_import_task/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetWirelessDeviceImportTaskResponse.fromJson(response);
}