listDeviceProfiles method

Future<ListDeviceProfilesResponse> listDeviceProfiles({
  1. DeviceProfileType? deviceProfileType,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the device profiles registered to your AWS account.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter deviceProfileType : A filter to list only device profiles that use this type, which can be LoRaWAN or Sidewalk.

Parameter maxResults : The maximum number of results to return in this operation.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListDeviceProfilesResponse> listDeviceProfiles({
  DeviceProfileType? deviceProfileType,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    250,
  );
  final $query = <String, List<String>>{
    if (deviceProfileType != null)
      'deviceProfileType': [deviceProfileType.value],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/device-profiles',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDeviceProfilesResponse.fromJson(response);
}