listDevicesForWirelessDeviceImportTask method
List the Sidewalk devices in an import task and their onboarding status.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The identifier of the import task for which wireless devices are listed.
Parameter nextToken :
To retrieve the next set of results, the nextToken value from
a previous response; otherwise null to receive the first set
of results.
Parameter status :
The status of the devices in the import task.
Implementation
Future<ListDevicesForWirelessDeviceImportTaskResponse>
listDevicesForWirelessDeviceImportTask({
required String id,
int? maxResults,
String? nextToken,
OnboardStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
250,
);
final $query = <String, List<String>>{
'id': [id],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/wireless_device_import_task',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDevicesForWirelessDeviceImportTaskResponse.fromJson(response);
}