listMulticastGroups method

Future<ListMulticastGroupsResponse> listMulticastGroups({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the multicast groups registered to your AWS account.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListMulticastGroupsResponse> listMulticastGroups({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/multicast-groups',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListMulticastGroupsResponse.fromJson(response);
}