listMulticastGroupsByFuotaTask method

Future<ListMulticastGroupsByFuotaTaskResponse> listMulticastGroupsByFuotaTask({
  1. required String id,
  2. int? maxResults,
  3. String? nextToken,
})

List all multicast groups associated with a FUOTA task.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListMulticastGroupsByFuotaTaskResponse>
    listMulticastGroupsByFuotaTask({
  required String id,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/fuota-tasks/${Uri.encodeComponent(id)}/multicast-groups',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListMulticastGroupsByFuotaTaskResponse.fromJson(response);
}