listNetworkAnalyzerConfigurations method

Future<ListNetworkAnalyzerConfigurationsResponse> listNetworkAnalyzerConfigurations({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the network analyzer configurations.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListNetworkAnalyzerConfigurationsResponse>
    listNetworkAnalyzerConfigurations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/network-analyzer-configurations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListNetworkAnalyzerConfigurationsResponse.fromJson(response);
}