listWirelessDeviceImportTasks method

Future<ListWirelessDeviceImportTasksResponse> listWirelessDeviceImportTasks({
  1. int? maxResults,
  2. String? nextToken,
})

List of import tasks and summary information of onboarding status of devices in each import task.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nextToken : To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Implementation

Future<ListWirelessDeviceImportTasksResponse> listWirelessDeviceImportTasks({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    250,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/wireless_device_import_tasks',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListWirelessDeviceImportTasksResponse.fromJson(response);
}