putPositionConfiguration method
Put position configuration for a given resource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceIdentifier :
Resource identifier used to update the position configuration.
Parameter resourceType :
Resource type of the resource for which you want to update the position
configuration.
Parameter destination :
The position data destination that describes the AWS IoT rule that
processes the device's position data for use by AWS IoT Core for LoRaWAN.
Parameter solvers :
The positioning solvers used to update the position configuration of the
resource.
Implementation
Future<void> putPositionConfiguration({
required String resourceIdentifier,
required PositionResourceType resourceType,
String? destination,
PositionSolverConfigurations? solvers,
}) async {
final $query = <String, List<String>>{
'resourceType': [resourceType.value],
};
final $payload = <String, dynamic>{
if (destination != null) 'Destination': destination,
if (solvers != null) 'Solvers': solvers,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/position-configurations/${Uri.encodeComponent(resourceIdentifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}