resetResourceLogLevel method

Future<void> resetResourceLogLevel({
  1. required String resourceIdentifier,
  2. required String resourceType,
})

Removes the log-level override, if any, for a specific resource ID and resource type. It can be used for a wireless device, a wireless gateway, or a FUOTA task.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceType : The type of resource, which can be WirelessDevice, WirelessGateway, or FuotaTask.

Implementation

Future<void> resetResourceLogLevel({
  required String resourceIdentifier,
  required String resourceType,
}) async {
  final $query = <String, List<String>>{
    'resourceType': [resourceType],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/log-levels/${Uri.encodeComponent(resourceIdentifier)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}