startWirelessDeviceImportTask method

Future<StartWirelessDeviceImportTaskResponse> startWirelessDeviceImportTask({
  1. required String destinationName,
  2. required SidewalkStartImportInfo sidewalk,
  3. String? clientRequestToken,
  4. PositioningConfigStatus? positioning,
  5. List<Tag>? tags,
})

Start import task for provisioning Sidewalk devices in bulk using an S3 CSV file.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter destinationName : The name of the Sidewalk destination that describes the IoT rule to route messages from the devices in the import task that are onboarded to AWS IoT Wireless.

Parameter sidewalk : The Sidewalk-related parameters for importing wireless devices that need to be provisioned in bulk.

Parameter positioning : The integration status of the Device Location feature for Sidewalk devices.

Implementation

Future<StartWirelessDeviceImportTaskResponse> startWirelessDeviceImportTask({
  required String destinationName,
  required SidewalkStartImportInfo sidewalk,
  String? clientRequestToken,
  PositioningConfigStatus? positioning,
  List<Tag>? tags,
}) async {
  final $payload = <String, dynamic>{
    'DestinationName': destinationName,
    'Sidewalk': sidewalk,
    'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
    if (positioning != null) 'Positioning': positioning.value,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/wireless_device_import_task',
    exceptionFnMap: _exceptionFns,
  );
  return StartWirelessDeviceImportTaskResponse.fromJson(response);
}