updateNetworkAnalyzerConfiguration method

Future<void> updateNetworkAnalyzerConfiguration({
  1. required String configurationName,
  2. String? description,
  3. List<String>? multicastGroupsToAdd,
  4. List<String>? multicastGroupsToRemove,
  5. TraceContent? traceContent,
  6. List<String>? wirelessDevicesToAdd,
  7. List<String>? wirelessDevicesToRemove,
  8. List<String>? wirelessGatewaysToAdd,
  9. List<String>? wirelessGatewaysToRemove,
})

Update network analyzer configuration.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter multicastGroupsToAdd : Multicast group resources to add to the network analyzer configuration. Provide the MulticastGroupId of the resource to add in the input array.

Parameter multicastGroupsToRemove : Multicast group resources to remove from the network analyzer configuration. Provide the MulticastGroupId of the resources to remove in the input array.

Parameter wirelessDevicesToAdd : Wireless device resources to add to the network analyzer configuration. Provide the WirelessDeviceId of the resource to add in the input array.

Parameter wirelessDevicesToRemove : Wireless device resources to remove from the network analyzer configuration. Provide the WirelessDeviceId of the resources to remove in the input array.

Parameter wirelessGatewaysToAdd : Wireless gateway resources to add to the network analyzer configuration. Provide the WirelessGatewayId of the resource to add in the input array.

Parameter wirelessGatewaysToRemove : Wireless gateway resources to remove from the network analyzer configuration. Provide the WirelessGatewayId of the resources to remove in the input array.

Implementation

Future<void> updateNetworkAnalyzerConfiguration({
  required String configurationName,
  String? description,
  List<String>? multicastGroupsToAdd,
  List<String>? multicastGroupsToRemove,
  TraceContent? traceContent,
  List<String>? wirelessDevicesToAdd,
  List<String>? wirelessDevicesToRemove,
  List<String>? wirelessGatewaysToAdd,
  List<String>? wirelessGatewaysToRemove,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'Description': description,
    if (multicastGroupsToAdd != null)
      'MulticastGroupsToAdd': multicastGroupsToAdd,
    if (multicastGroupsToRemove != null)
      'MulticastGroupsToRemove': multicastGroupsToRemove,
    if (traceContent != null) 'TraceContent': traceContent,
    if (wirelessDevicesToAdd != null)
      'WirelessDevicesToAdd': wirelessDevicesToAdd,
    if (wirelessDevicesToRemove != null)
      'WirelessDevicesToRemove': wirelessDevicesToRemove,
    if (wirelessGatewaysToAdd != null)
      'WirelessGatewaysToAdd': wirelessGatewaysToAdd,
    if (wirelessGatewaysToRemove != null)
      'WirelessGatewaysToRemove': wirelessGatewaysToRemove,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/network-analyzer-configurations/${Uri.encodeComponent(configurationName)}',
    exceptionFnMap: _exceptionFns,
  );
}