updateWirelessDeviceImportTask method
Future<void>
updateWirelessDeviceImportTask({
- required String id,
- required SidewalkUpdateImportInfo sidewalk,
Update an import task to add more devices to the task.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The identifier of the import task to be updated.
Parameter sidewalk :
The Sidewalk-related parameters of the import task to be updated.
Implementation
Future<void> updateWirelessDeviceImportTask({
required String id,
required SidewalkUpdateImportInfo sidewalk,
}) async {
final $payload = <String, dynamic>{
'Sidewalk': sidewalk,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/wireless_device_import_task/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}