Ivs class

Introduction

The Amazon Interactive Video Service (IVS) API is REST compatible, using a standard HTTP API and an Amazon Web Services EventBridge event stream for responses. JSON is used for both requests and responses, including errors.

The API is an Amazon Web Services regional service. For a list of supported regions and Amazon IVS HTTPS service endpoints, see the Amazon IVS page in the Amazon Web Services General Reference.

All API request parameters and URLs are case sensitive.

For a summary of notable documentation changes in each release, see Document History.

Allowed Header Values

  • Accept: application/json
  • Accept-Encoding: gzip, deflate
  • Content-Type: application/json
Key Concepts
  • Channel — Stores configuration data related to your live stream. You first create a channel and then use the channel’s stream key to start your live stream.
  • Stream key — An identifier assigned by Amazon IVS when you create a channel, which is then used to authorize streaming. Treat the stream key like a secret, since it allows anyone to stream to the channel.
  • Playback key pair — Video playback may be restricted using playback-authorization tokens, which use public-key encryption. A playback key pair is the public-private pair of keys used to sign and validate the playback-authorization token.
  • Recording configuration — Stores configuration related to recording a live stream and where to store the recorded content. Multiple channels can reference the same recording configuration.
  • Playback restriction policy — Restricts playback by countries and/or origin sites.
For more information about your IVS live stream, also see Getting Started with IVS Low-Latency Streaming.

Tagging

A tag is a metadata label that you assign to an Amazon Web Services resource. A tag comprises a key and a value, both set by you. For example, you might set a tag as topic:nature to label a particular video category. See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.

Tags can help you identify and organize your Amazon Web Services resources. For example, you can use the same tag for different resources to indicate that they are related. You can also use tags to manage access (see Access Tags).

The Amazon IVS API has these tag-related operations: TagResource, UntagResource, and ListTagsForResource. The following resources support tagging: Channels, Stream Keys, Playback Key Pairs, and Recording Configurations.

At most 50 tags can be applied to a resource.

Authentication versus Authorization

Note the differences between these concepts:

  • Authentication is about verifying identity. You need to be authenticated to sign Amazon IVS API requests.
  • Authorization is about granting permissions. Your IAM roles need to have permissions for Amazon IVS API requests. In addition, authorization is needed to view Amazon IVS private channels. (Private channels are channels that are enabled for "playback authorization.")
Authentication

All Amazon IVS API requests must be authenticated with a signature. The Amazon Web Services Command-Line Interface (CLI) and Amazon IVS Player SDKs take care of signing the underlying API calls for you. However, if your application calls the Amazon IVS API directly, it’s your responsibility to sign the requests.

You generate a signature using valid Amazon Web Services credentials that have permission to perform the requested action. For example, you must sign PutMetadata requests with a signature generated from a user account that has the ivs:PutMetadata permission.

For more information:

Amazon Resource Names (ARNs)

ARNs uniquely identify AWS resources. An ARN is required when you need to specify a resource unambiguously across all of AWS, such as in IAM policies and API calls. For more information, see Amazon Resource Names in the AWS General Reference.

Constructors

Ivs({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetChannel({required List<String> arns}) Future<BatchGetChannelResponse>
Performs GetChannel on multiple ARNs simultaneously.
batchGetStreamKey({required List<String> arns}) Future<BatchGetStreamKeyResponse>
Performs GetStreamKey on multiple ARNs simultaneously.
batchStartViewerSessionRevocation({required List<BatchStartViewerSessionRevocationViewerSession> viewerSessions}) Future<BatchStartViewerSessionRevocationResponse>
Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAdConfiguration({required List<MediaTailorPlaybackConfiguration> mediaTailorPlaybackConfigurations, String? name, Map<String, String>? tags}) Future<CreateAdConfigurationResponse>
Creates a new ad configuration to be used for server-side ad insertion.
createChannel({String? adConfigurationArn, bool? authorized, ContainerFormat? containerFormat, bool? insecureIngest, ChannelLatencyMode? latencyMode, MultitrackInputConfiguration? multitrackInputConfiguration, String? name, String? playbackRestrictionPolicyArn, TranscodePreset? preset, String? recordingConfigurationArn, Map<String, String>? tags, ChannelType? type}) Future<CreateChannelResponse>
Creates a new channel and an associated stream key to start streaming.
createPlaybackRestrictionPolicy({List<String>? allowedCountries, List<String>? allowedOrigins, bool? enableStrictOriginEnforcement, String? name, Map<String, String>? tags}) Future<CreatePlaybackRestrictionPolicyResponse>
Creates a new playback restriction policy, for constraining playback by countries and/or origins.
createRecordingConfiguration({required DestinationConfiguration destinationConfiguration, String? name, int? recordingReconnectWindowSeconds, RenditionConfiguration? renditionConfiguration, Map<String, String>? tags, ThumbnailConfiguration? thumbnailConfiguration}) Future<CreateRecordingConfigurationResponse>
Creates a new recording configuration, used to enable recording to Amazon S3.
createStreamKey({required String channelArn, Map<String, String>? tags}) Future<CreateStreamKeyResponse>
Creates a stream key, used to initiate a stream, for the specified channel ARN.
deleteAdConfiguration({required String arn}) Future<void>
Deletes the specified ad configuration.
deleteChannel({required String arn}) Future<void>
Deletes the specified channel and its associated stream keys.
deletePlaybackKeyPair({required String arn}) Future<void>
Deletes a specified authorization key pair. This invalidates future viewer tokens generated using the key pair’s privateKey. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.
deletePlaybackRestrictionPolicy({required String arn}) Future<void>
Deletes the specified playback restriction policy.
deleteRecordingConfiguration({required String arn}) Future<void>
Deletes the recording configuration for the specified ARN.
deleteStreamKey({required String arn}) Future<void>
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
getAdConfiguration({required String arn}) Future<GetAdConfigurationResponse>
Gets the ad configuration represented by the specified ARN.
getChannel({required String arn}) Future<GetChannelResponse>
Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.
getPlaybackKeyPair({required String arn}) Future<GetPlaybackKeyPairResponse>
Gets a specified playback authorization key pair and returns the arn and fingerprint. The privateKey held by the caller can be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.
getPlaybackRestrictionPolicy({required String arn}) Future<GetPlaybackRestrictionPolicyResponse>
Gets the specified playback restriction policy.
getRecordingConfiguration({required String arn}) Future<GetRecordingConfigurationResponse>
Gets the recording configuration for the specified ARN.
getStream({required String channelArn}) Future<GetStreamResponse>
Gets information about the active (live) stream on a specified channel.
getStreamKey({required String arn}) Future<GetStreamKeyResponse>
Gets stream-key information for a specified ARN.
getStreamSession({required String channelArn, String? streamId}) Future<GetStreamSessionResponse>
Gets metadata on a specified stream.
importPlaybackKeyPair({required String publicKeyMaterial, String? name, Map<String, String>? tags}) Future<ImportPlaybackKeyPairResponse>
Imports the public portion of a new key pair and returns its arn and fingerprint. The privateKey can then be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.
insertAdBreak({required String channelArn, required int durationSeconds}) Future<InsertAdBreakResponse>
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
listAdConfigurations({int? maxResults, String? nextToken}) Future<ListAdConfigurationsResponse>
Gets summary information about all ad configurations in your account, in the AWS region where the API request is processed.
listChannels({String? filterByAdConfigurationArn, String? filterByName, String? filterByPlaybackRestrictionPolicyArn, String? filterByRecordingConfigurationArn, int? maxResults, String? nextToken}) Future<ListChannelsResponse>
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed. This list can be filtered to match a specified name or recording-configuration ARN. Filters are mutually exclusive and cannot be used together. If you try to use both filters, you will get an error (409 ConflictException).
listPlaybackKeyPairs({int? maxResults, String? nextToken}) Future<ListPlaybackKeyPairsResponse>
Gets summary information about playback key pairs. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.
listPlaybackRestrictionPolicies({int? maxResults, String? nextToken}) Future<ListPlaybackRestrictionPoliciesResponse>
Gets summary information about playback restriction policies.
listRecordingConfigurations({int? maxResults, String? nextToken}) Future<ListRecordingConfigurationsResponse>
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
listStreamKeys({required String channelArn, int? maxResults, String? nextToken}) Future<ListStreamKeysResponse>
Gets summary information about stream keys for the specified channel.
listStreams({StreamFilters? filterBy, int? maxResults, String? nextToken}) Future<ListStreamsResponse>
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
listStreamSessions({required String channelArn, int? maxResults, String? nextToken}) Future<ListStreamSessionsResponse>
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Gets information about Amazon Web Services tags for the specified ARN.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putMetadata({required String channelArn, required String metadata}) Future<void>
Inserts metadata into the active stream of the specified channel. At most 5 requests per second per channel are allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) At most 155 requests per second per account are allowed. Also see Embedding Metadata within a Video Stream in the Amazon IVS User Guide.
startViewerSessionRevocation({required String channelArn, required String viewerId, int? viewerSessionVersionsLessThanOrEqualTo}) Future<void>
Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID. Optionally, you can provide a version to revoke viewer sessions less than and including that version. For instructions on associating a viewer ID with a viewer session, see Setting Up Private Channels.
stopStream({required String channelArn}) Future<void>
Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction with DeleteStreamKey to prevent further streaming to a channel.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from the resource with the specified ARN.
updateAdConfiguration({required String arn, List<MediaTailorPlaybackConfiguration>? mediaTailorPlaybackConfigurations, String? name}) Future<UpdateAdConfigurationResponse>
Updates a specified ad configuration.
updateChannel({required String arn, String? adConfigurationArn, bool? authorized, ContainerFormat? containerFormat, bool? insecureIngest, ChannelLatencyMode? latencyMode, MultitrackInputConfiguration? multitrackInputConfiguration, String? name, String? playbackRestrictionPolicyArn, TranscodePreset? preset, String? recordingConfigurationArn, ChannelType? type}) Future<UpdateChannelResponse>
Updates a channel's configuration. Live channels cannot be updated. You must stop the ongoing stream, update the channel, and restart the stream for the changes to take effect.
updatePlaybackRestrictionPolicy({required String arn, List<String>? allowedCountries, List<String>? allowedOrigins, bool? enableStrictOriginEnforcement, String? name}) Future<UpdatePlaybackRestrictionPolicyResponse>
Updates a specified playback restriction policy.

Operators

operator ==(Object other) bool
The equality operator.
inherited