deletePlaybackKeyPair method

Future<void> deletePlaybackKeyPair({
  1. required String arn,
})

Deletes a specified authorization key pair. This invalidates future viewer tokens generated using the key pair’s privateKey. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

May throw AccessDeniedException. May throw PendingVerification. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : ARN of the key pair to be deleted.

Implementation

Future<void> deletePlaybackKeyPair({
  required String arn,
}) async {
  final $payload = <String, dynamic>{
    'arn': arn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeletePlaybackKeyPair',
    exceptionFnMap: _exceptionFns,
  );
}