deleteRecordingConfiguration method
Deletes the recording configuration for the specified ARN.
If you try to delete a recording configuration that is associated with a
channel, you will get an error (409 ConflictException). To avoid this, for
all channels that reference the recording configuration, first use
UpdateChannel to set the recordingConfigurationArn
field to an empty string, then use DeleteRecordingConfiguration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter arn :
ARN of the recording configuration to be deleted.
Implementation
Future<void> deleteRecordingConfiguration({
required String arn,
}) async {
final $payload = <String, dynamic>{
'arn': arn,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteRecordingConfiguration',
exceptionFnMap: _exceptionFns,
);
}