getChannel method

Future<GetChannelResponse> getChannel({
  1. required String arn,
})

Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : ARN of the channel for which the configuration is to be retrieved.

Implementation

Future<GetChannelResponse> getChannel({
  required String arn,
}) async {
  final $payload = <String, dynamic>{
    'arn': arn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetChannel',
    exceptionFnMap: _exceptionFns,
  );
  return GetChannelResponse.fromJson(response);
}