getPlaybackKeyPair method

Future<GetPlaybackKeyPairResponse> getPlaybackKeyPair({
  1. required String arn,
})

Gets a specified playback authorization key pair and returns the arn and fingerprint. The privateKey held by the caller can be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : ARN of the key pair to be returned.

Implementation

Future<GetPlaybackKeyPairResponse> getPlaybackKeyPair({
  required String arn,
}) async {
  final $payload = <String, dynamic>{
    'arn': arn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetPlaybackKeyPair',
    exceptionFnMap: _exceptionFns,
  );
  return GetPlaybackKeyPairResponse.fromJson(response);
}