listRecordingConfigurations method

Future<ListRecordingConfigurationsResponse> listRecordingConfigurations({
  1. int? maxResults,
  2. String? nextToken,
})

Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter maxResults : Maximum number of recording configurations to return. Default: your service quota or 100, whichever is smaller.

Parameter nextToken : The first recording configuration to retrieve. This is used for pagination; see the nextToken response field.

Implementation

Future<ListRecordingConfigurationsResponse> listRecordingConfigurations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListRecordingConfigurations',
    exceptionFnMap: _exceptionFns,
  );
  return ListRecordingConfigurationsResponse.fromJson(response);
}