putMetadata method

Future<void> putMetadata({
  1. required String channelArn,
  2. required String metadata,
})

Inserts metadata into the active stream of the specified channel. At most 5 requests per second per channel are allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) At most 155 requests per second per account are allowed. Also see Embedding Metadata within a Video Stream in the Amazon IVS User Guide.

May throw AccessDeniedException. May throw ChannelNotBroadcasting. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter channelArn : ARN of the channel into which metadata is inserted. This channel must have an active stream.

Parameter metadata : Metadata to insert into the stream. Maximum: 1 KB per request.

Implementation

Future<void> putMetadata({
  required String channelArn,
  required String metadata,
}) async {
  final $payload = <String, dynamic>{
    'channelArn': channelArn,
    'metadata': metadata,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/PutMetadata',
    exceptionFnMap: _exceptionFns,
  );
}