updateAdConfiguration method

Future<UpdateAdConfigurationResponse> updateAdConfiguration({
  1. required String arn,
  2. List<MediaTailorPlaybackConfiguration>? mediaTailorPlaybackConfigurations,
  3. String? name,
})

Updates a specified ad configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw PendingVerification. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : ARN of the ad configuration to be updated.

Parameter mediaTailorPlaybackConfigurations : List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see Generate and Sign IVS Playback Tokens.

Parameter name : Ad configuration name. The value does not need to be unique.

Implementation

Future<UpdateAdConfigurationResponse> updateAdConfiguration({
  required String arn,
  List<MediaTailorPlaybackConfiguration>? mediaTailorPlaybackConfigurations,
  String? name,
}) async {
  final $payload = <String, dynamic>{
    'arn': arn,
    if (mediaTailorPlaybackConfigurations != null)
      'mediaTailorPlaybackConfigurations': mediaTailorPlaybackConfigurations,
    if (name != null) 'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateAdConfiguration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateAdConfigurationResponse.fromJson(response);
}