createEncoderConfiguration method

Future<CreateEncoderConfigurationResponse> createEncoderConfiguration({
  1. String? name,
  2. Map<String, String>? tags,
  3. Video? video,
})

Creates an EncoderConfiguration object.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw PendingVerification. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ValidationException.

Parameter name : Optional name to identify the resource.

Parameter tags : Tags attached to the resource. Array of maps, each of the form string:string (key:value). See Best practices and strategies in Tagging AWS Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no constraints on tags beyond what is documented there.

Parameter video : Video configuration. Default: video resolution 1280x720, bitrate 2500 kbps, 30 fps.

Implementation

Future<CreateEncoderConfigurationResponse> createEncoderConfiguration({
  String? name,
  Map<String, String>? tags,
  Video? video,
}) async {
  final $payload = <String, dynamic>{
    if (name != null) 'name': name,
    if (tags != null) 'tags': tags,
    if (video != null) 'video': video,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CreateEncoderConfiguration',
    exceptionFnMap: _exceptionFns,
  );
  return CreateEncoderConfigurationResponse.fromJson(response);
}