deleteIngestConfiguration method

Future<void> deleteIngestConfiguration({
  1. required String arn,
  2. bool? force,
})

Deletes a specified IngestConfiguration, so it can no longer be used to broadcast. An IngestConfiguration cannot be deleted if the publisher is actively streaming to a stage, unless force is set to true.

May throw AccessDeniedException. May throw ConflictException. May throw PendingVerification. May throw ResourceNotFoundException. May throw ValidationException.

Parameter arn : ARN of the IngestConfiguration.

Parameter force : Optional field to force deletion of the IngestConfiguration. If this is set to true when a participant is actively publishing, the participant is disconnected from the stage, followed by deletion of the IngestConfiguration. Default: false.

Implementation

Future<void> deleteIngestConfiguration({
  required String arn,
  bool? force,
}) async {
  final $payload = <String, dynamic>{
    'arn': arn,
    if (force != null) 'force': force,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteIngestConfiguration',
    exceptionFnMap: _exceptionFns,
  );
}