deleteStorageConfiguration method
Deletes the storage configuration for the specified ARN.
If you try to delete a storage configuration that is used by a Composition, you will get an error (409 ConflictException). To avoid this, for all Compositions that reference the storage configuration, first use StopComposition and wait for it to complete, then use DeleteStorageConfiguration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter arn :
ARN of the storage configuration to be deleted.
Implementation
Future<void> deleteStorageConfiguration({
required String arn,
}) async {
final $payload = <String, dynamic>{
'arn': arn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteStorageConfiguration',
exceptionFnMap: _exceptionFns,
);
}