listCompositions method
Gets summary information about all Compositions in your account, in the AWS region where the API request is processed.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter filterByEncoderConfigurationArn :
Filters the Composition list to match the specified EncoderConfiguration
attached to at least one of its output.
Parameter filterByStageArn :
Filters the Composition list to match the specified Stage ARN.
Parameter maxResults :
Maximum number of results to return. Default: 100.
Parameter nextToken :
The first Composition to retrieve. This is used for pagination; see the
nextToken response field.
Implementation
Future<ListCompositionsResponse> listCompositions({
String? filterByEncoderConfigurationArn,
String? filterByStageArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filterByEncoderConfigurationArn != null)
'filterByEncoderConfigurationArn': filterByEncoderConfigurationArn,
if (filterByStageArn != null) 'filterByStageArn': filterByStageArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListCompositions',
exceptionFnMap: _exceptionFns,
);
return ListCompositionsResponse.fromJson(response);
}