listIngestConfigurations method

Future<ListIngestConfigurationsResponse> listIngestConfigurations({
  1. String? filterByStageArn,
  2. IngestConfigurationState? filterByState,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all IngestConfigurations in your account, in the AWS region where the API request is processed.

May throw AccessDeniedException. May throw ValidationException.

Parameter filterByStageArn : Filters the response list to match the specified stage ARN. Only one filter (by stage ARN or by state) can be used at a time.

Parameter filterByState : Filters the response list to match the specified state. Only one filter (by stage ARN or by state) can be used at a time.

Parameter maxResults : Maximum number of results to return. Default: 50.

Parameter nextToken : The first IngestConfiguration to retrieve. This is used for pagination; see the nextToken response field.

Implementation

Future<ListIngestConfigurationsResponse> listIngestConfigurations({
  String? filterByStageArn,
  IngestConfigurationState? filterByState,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (filterByStageArn != null) 'filterByStageArn': filterByStageArn,
    if (filterByState != null) 'filterByState': filterByState.value,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListIngestConfigurations',
    exceptionFnMap: _exceptionFns,
  );
  return ListIngestConfigurationsResponse.fromJson(response);
}