tagResource method
Adds or updates tags for the AWS resource with the specified ARN.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the resource to be tagged. The ARN must be URL-encoded.
Parameter tags :
Array of tags to be added or updated. Array of maps, each of the form
string:string (key:value). See Best
practices and strategies in Tagging Amazon Web Services Resources
and Tag Editor for details, including restrictions that apply to tags
and "Tag naming limits and requirements"; Amazon IVS Chat has no
constraints beyond what is documented there.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}