untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Removes tags from the resource with the specified ARN.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter resourceArn : The ARN of the resource to be untagged. The ARN must be URL-encoded.

Parameter tagKeys : Array of tags to be removed. Array of maps, each of the form string:string (key:value). See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS Chat has no constraints beyond what is documented there.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}