updateLoggingConfiguration method

Future<UpdateLoggingConfigurationResponse> updateLoggingConfiguration({
  1. required String identifier,
  2. DestinationConfiguration? destinationConfiguration,
  3. String? name,
})

Updates a specified logging configuration.

May throw AccessDeniedException. May throw ConflictException. May throw PendingVerification. May throw ResourceNotFoundException. May throw ValidationException.

Parameter identifier : Identifier of the logging configuration to be updated.

Parameter destinationConfiguration : A complex type that contains a destination configuration for where chat content will be logged. There can be only one type of destination (cloudWatchLogs, firehose, or s3) in a destinationConfiguration.

Parameter name : Logging-configuration name. The value does not need to be unique.

Implementation

Future<UpdateLoggingConfigurationResponse> updateLoggingConfiguration({
  required String identifier,
  DestinationConfiguration? destinationConfiguration,
  String? name,
}) async {
  final $payload = <String, dynamic>{
    'identifier': identifier,
    if (destinationConfiguration != null)
      'destinationConfiguration': destinationConfiguration,
    if (name != null) 'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateLoggingConfiguration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateLoggingConfigurationResponse.fromJson(response);
}