Kafka class

The operations for managing an Amazon MSK cluster.

Constructors

Kafka({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchAssociateScramSecret({required String clusterArn, required List<String> secretArnList}) Future<BatchAssociateScramSecretResponse>
Associates one or more Scram Secrets with an Amazon MSK cluster.
batchDisassociateScramSecret({required String clusterArn, required List<String> secretArnList}) Future<BatchDisassociateScramSecretResponse>
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCluster({required BrokerNodeGroupInfo brokerNodeGroupInfo, required String clusterName, required String kafkaVersion, required int numberOfBrokerNodes, ClientAuthentication? clientAuthentication, ConfigurationInfo? configurationInfo, EncryptionInfo? encryptionInfo, EnhancedMonitoring? enhancedMonitoring, LoggingInfo? loggingInfo, OpenMonitoringInfo? openMonitoring, Rebalancing? rebalancing, StorageMode? storageMode, Map<String, String>? tags}) Future<CreateClusterResponse>
Creates a new MSK cluster.
createClusterV2({required String clusterName, ProvisionedRequest? provisioned, ServerlessRequest? serverless, Map<String, String>? tags}) Future<CreateClusterV2Response>
Creates a new MSK cluster.
createConfiguration({required String name, required Uint8List serverProperties, String? description, List<String>? kafkaVersions}) Future<CreateConfigurationResponse>
Creates a new MSK configuration.
createReplicator({required List<KafkaCluster> kafkaClusters, required List<ReplicationInfo> replicationInfoList, required String replicatorName, required String serviceExecutionRoleArn, String? description, LogDelivery? logDelivery, Map<String, String>? tags}) Future<CreateReplicatorResponse>
Creates the replicator.
createTopic({required String clusterArn, required int partitionCount, required int replicationFactor, required String topicName, String? configs}) Future<CreateTopicResponse>
Creates a topic in the specified MSK cluster.
createVpcConnection({required String authentication, required List<String> clientSubnets, required List<String> securityGroups, required String targetClusterArn, required String vpcId, Map<String, String>? tags}) Future<CreateVpcConnectionResponse>
Creates a new MSK VPC connection.
deleteCluster({required String clusterArn, String? currentVersion}) Future<DeleteClusterResponse>
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
deleteClusterPolicy({required String clusterArn}) Future<void>
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in the request.
deleteConfiguration({required String arn}) Future<DeleteConfigurationResponse>
Deletes an MSK Configuration.
deleteReplicator({required String replicatorArn, String? currentVersion}) Future<DeleteReplicatorResponse>
Deletes a replicator.
deleteTopic({required String clusterArn, required String topicName}) Future<DeleteTopicResponse>
Deletes a topic in the specified MSK cluster.
deleteVpcConnection({required String arn}) Future<DeleteVpcConnectionResponse>
Deletes a MSK VPC connection.
describeCluster({required String clusterArn}) Future<DescribeClusterResponse>
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
describeClusterOperation({required String clusterOperationArn}) Future<DescribeClusterOperationResponse>
Returns a description of the cluster operation specified by the ARN.
describeClusterOperationV2({required String clusterOperationArn}) Future<DescribeClusterOperationV2Response>
Returns a description of the cluster operation specified by the ARN.
describeClusterV2({required String clusterArn}) Future<DescribeClusterV2Response>
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
describeConfiguration({required String arn}) Future<DescribeConfigurationResponse>
Returns a description of this MSK configuration.
describeConfigurationRevision({required String arn, required int revision}) Future<DescribeConfigurationRevisionResponse>
Returns a description of this revision of the configuration.
describeReplicator({required String replicatorArn}) Future<DescribeReplicatorResponse>
Describes a replicator.
describeTopic({required String clusterArn, required String topicName}) Future<DescribeTopicResponse>
Returns topic details of this topic on a MSK cluster.
describeTopicPartitions({required String clusterArn, required String topicName, int? maxResults, String? nextToken}) Future<DescribeTopicPartitionsResponse>
Returns partition details of this topic on a MSK cluster.
describeVpcConnection({required String arn}) Future<DescribeVpcConnectionResponse>
Returns a description of this MSK VPC connection.
getBootstrapBrokers({required String clusterArn}) Future<GetBootstrapBrokersResponse>
A list of brokers that a client application can use to bootstrap. This list doesn't necessarily include all of the brokers in the cluster. The following Python 3.6 example shows how you can use the Amazon Resource Name (ARN) of a cluster to get its bootstrap brokers. If you don't know the ARN of your cluster, you can use the ListClusters operation to get the ARNs of all the clusters in this account and Region.
getClusterPolicy({required String clusterArn}) Future<GetClusterPolicyResponse>
Get the MSK cluster policy specified by the Amazon Resource Name (ARN) in the request.
getCompatibleKafkaVersions({String? clusterArn}) Future<GetCompatibleKafkaVersionsResponse>
Gets the Apache Kafka versions to which you can update the MSK cluster.
listClientVpcConnections({required String clusterArn, int? maxResults, String? nextToken}) Future<ListClientVpcConnectionsResponse>
Returns a list of all the VPC connections in this Region.
listClusterOperations({required String clusterArn, int? maxResults, String? nextToken}) Future<ListClusterOperationsResponse>
Returns a list of all the operations that have been performed on the specified MSK cluster.
listClusterOperationsV2({required String clusterArn, int? maxResults, String? nextToken}) Future<ListClusterOperationsV2Response>
Returns a list of all the operations that have been performed on the specified MSK cluster.
listClusters({String? clusterNameFilter, int? maxResults, String? nextToken}) Future<ListClustersResponse>
Returns a list of all the MSK clusters in the current Region.
listClustersV2({String? clusterNameFilter, String? clusterTypeFilter, int? maxResults, String? nextToken}) Future<ListClustersV2Response>
Returns a list of all the MSK clusters in the current Region.
listConfigurationRevisions({required String arn, int? maxResults, String? nextToken}) Future<ListConfigurationRevisionsResponse>
Returns a list of all the MSK configurations in this Region.
listConfigurations({int? maxResults, String? nextToken}) Future<ListConfigurationsResponse>
Returns a list of all the MSK configurations in this Region.
listKafkaVersions({int? maxResults, String? nextToken}) Future<ListKafkaVersionsResponse>
Returns a list of Apache Kafka versions.
listNodes({required String clusterArn, int? maxResults, String? nextToken}) Future<ListNodesResponse>
Returns a list of the broker nodes in the cluster.
listReplicators({int? maxResults, String? nextToken, String? replicatorNameFilter}) Future<ListReplicatorsResponse>
Lists the replicators.
listScramSecrets({required String clusterArn, int? maxResults, String? nextToken}) Future<ListScramSecretsResponse>
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of the tags associated with the specified resource.
listTopics({required String clusterArn, int? maxResults, String? nextToken, String? topicNameFilter}) Future<ListTopicsResponse>
List topics in a MSK cluster.
listVpcConnections({int? maxResults, String? nextToken}) Future<ListVpcConnectionsResponse>
Returns a list of all the VPC connections in this Region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putClusterPolicy({required String clusterArn, required String policy, String? currentVersion}) Future<PutClusterPolicyResponse>
Creates or updates the MSK cluster policy specified by the cluster Amazon Resource Name (ARN) in the request.
rebootBroker({required List<String> brokerIds, required String clusterArn}) Future<RebootBrokerResponse>
Reboots brokers.
rejectClientVpcConnection({required String clusterArn, required String vpcConnectionArn}) Future<void>
Returns empty response.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to the specified MSK resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the tags associated with the keys that are provided in the query.
updateBrokerCount({required String clusterArn, required String currentVersion, required int targetNumberOfBrokerNodes}) Future<UpdateBrokerCountResponse>
Updates the number of broker nodes in the cluster.
updateBrokerStorage({required String clusterArn, required String currentVersion, required List<BrokerEBSVolumeInfo> targetBrokerEBSVolumeInfo}) Future<UpdateBrokerStorageResponse>
Updates the EBS storage associated with MSK brokers.
updateBrokerType({required String clusterArn, required String currentVersion, required String targetInstanceType}) Future<UpdateBrokerTypeResponse>
Updates EC2 instance type.
updateClusterConfiguration({required String clusterArn, required ConfigurationInfo configurationInfo, required String currentVersion}) Future<UpdateClusterConfigurationResponse>
Updates the cluster with the configuration that is specified in the request body.
updateClusterKafkaVersion({required String clusterArn, required String currentVersion, required String targetKafkaVersion, ConfigurationInfo? configurationInfo}) Future<UpdateClusterKafkaVersionResponse>
Updates the Apache Kafka version for the cluster.
updateConfiguration({required String arn, required Uint8List serverProperties, String? description}) Future<UpdateConfigurationResponse>
Updates an MSK configuration.
updateConnectivity({required String clusterArn, required String currentVersion, ConnectivityInfo? connectivityInfo, ZookeeperAccess? zookeeperAccess}) Future<UpdateConnectivityResponse>
Updates the cluster's connectivity configuration.
updateMonitoring({required String clusterArn, required String currentVersion, EnhancedMonitoring? enhancedMonitoring, LoggingInfo? loggingInfo, OpenMonitoringInfo? openMonitoring}) Future<UpdateMonitoringResponse>
Updates the monitoring settings for the cluster. You can use this operation to specify which Apache Kafka metrics you want Amazon MSK to send to Amazon CloudWatch. You can also specify settings for open monitoring with Prometheus.
updateRebalancing({required String clusterArn, required String currentVersion, required Rebalancing rebalancing}) Future<UpdateRebalancingResponse>
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
updateReplicationInfo({required String currentVersion, required String replicatorArn, ConsumerGroupReplicationUpdate? consumerGroupReplication, LogDelivery? logDelivery, String? sourceKafkaClusterArn, String? sourceKafkaClusterId, String? targetKafkaClusterArn, String? targetKafkaClusterId, TopicReplicationUpdate? topicReplication}) Future<UpdateReplicationInfoResponse>
Updates replication info of a replicator.
updateSecurity({required String clusterArn, required String currentVersion, ClientAuthentication? clientAuthentication, EncryptionInfo? encryptionInfo}) Future<UpdateSecurityResponse>
Updates the security settings for the cluster. You can use this operation to specify encryption and authentication on existing clusters.
updateStorage({required String clusterArn, required String currentVersion, ProvisionedThroughput? provisionedThroughput, StorageMode? storageMode, int? volumeSizeGB}) Future<UpdateStorageResponse>
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
updateTopic({required String clusterArn, required String topicName, String? configs, int? partitionCount}) Future<UpdateTopicResponse>
Updates the configuration of the specified topic.

Operators

operator ==(Object other) bool
The equality operator.
inherited