describeTopic method

Future<DescribeTopicResponse> describeTopic({
  1. required String clusterArn,
  2. required String topicName,
})

Returns topic details of this topic on a MSK cluster.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw UnauthorizedException.

Parameter clusterArn : The Amazon Resource Name (ARN) that uniquely identifies the cluster.

Parameter topicName : The Kafka topic name that uniquely identifies the topic.

Implementation

Future<DescribeTopicResponse> describeTopic({
  required String clusterArn,
  required String topicName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/clusters/${Uri.encodeComponent(clusterArn)}/topics/${Uri.encodeComponent(topicName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeTopicResponse.fromJson(response);
}