listClientVpcConnections method

Future<ListClientVpcConnectionsResponse> listClientVpcConnections({
  1. required String clusterArn,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of all the VPC connections in this Region.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw ServiceUnavailableException. May throw UnauthorizedException.

Parameter clusterArn : The Amazon Resource Name (ARN) of the cluster.

Parameter maxResults : The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.

Parameter nextToken : The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request.

Implementation

Future<ListClientVpcConnectionsResponse> listClientVpcConnections({
  required String clusterArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/clusters/${Uri.encodeComponent(clusterArn)}/client-vpc-connections',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListClientVpcConnectionsResponse.fromJson(response);
}