listClusterOperationsV2 method

Future<ListClusterOperationsV2Response> listClusterOperationsV2({
  1. required String clusterArn,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of all the operations that have been performed on the specified MSK cluster.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException. May throw UnauthorizedException.

Parameter clusterArn : The arn of the cluster whose operations are being requested.

Parameter maxResults : The maxResults of the query.

Parameter nextToken : The nextToken of the query.

Implementation

Future<ListClusterOperationsV2Response> listClusterOperationsV2({
  required String clusterArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/api/v2/clusters/${Uri.encodeComponent(clusterArn)}/operations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListClusterOperationsV2Response.fromJson(response);
}