listConfigurations method

Future<ListConfigurationsResponse> listConfigurations({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of all the MSK configurations in this Region.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw ServiceUnavailableException. May throw UnauthorizedException.

Parameter maxResults : The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.

Parameter nextToken : The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request.

Implementation

Future<ListConfigurationsResponse> listConfigurations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/configurations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListConfigurationsResponse.fromJson(response);
}