updateRebalancing method

Future<UpdateRebalancingResponse> updateRebalancing({
  1. required String clusterArn,
  2. required String currentVersion,
  3. required Rebalancing rebalancing,
})

Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException. May throw UnauthorizedException.

Parameter clusterArn : The Amazon Resource Name (ARN) of the cluster.

Parameter currentVersion : The current version of the cluster.

Parameter rebalancing : Specifies if intelligent rebalancing should be turned on for your cluster. The default intelligent rebalancing status is ACTIVE for all new MSK Provisioned clusters that you create with Express brokers.

Implementation

Future<UpdateRebalancingResponse> updateRebalancing({
  required String clusterArn,
  required String currentVersion,
  required Rebalancing rebalancing,
}) async {
  final $payload = <String, dynamic>{
    'currentVersion': currentVersion,
    'rebalancing': rebalancing,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/v1/clusters/${Uri.encodeComponent(clusterArn)}/rebalancing',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRebalancingResponse.fromJson(response);
}