listConnectorOperations method

Future<ListConnectorOperationsResponse> listConnectorOperations({
  1. required String connectorArn,
  2. int? maxResults,
  3. String? nextToken,
})

Lists information about a connector's operation(s).

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException. May throw UnauthorizedException.

Parameter connectorArn : The Amazon Resource Name (ARN) of the connector for which to list operations.

Parameter maxResults : Maximum number of connector operations to fetch in one get request.

Parameter nextToken : If the response is truncated, it includes a NextToken. Send this NextToken in a subsequent request to continue listing from where it left off.

Implementation

Future<ListConnectorOperationsResponse> listConnectorOperations({
  required String connectorArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/connectors/${Uri.encodeComponent(connectorArn)}/operations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListConnectorOperationsResponse.fromJson(response);
}