Kendra class

Amazon Kendra is a service for indexing large document sets.

Constructors

Kendra({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateEntitiesToExperience({required List<EntityConfiguration> entityList, required String id, required String indexId}) Future<AssociateEntitiesToExperienceResponse>
Grants users or groups in your IAM Identity Center identity source access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
associatePersonasToEntities({required String id, required String indexId, required List<EntityPersonaConfiguration> personas}) Future<AssociatePersonasToEntitiesResponse>
Defines the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
batchDeleteDocument({required List<String> documentIdList, required String indexId, DataSourceSyncJobMetricTarget? dataSourceSyncJobMetricTarget}) Future<BatchDeleteDocumentResponse>
Removes one or more documents from an index. The documents must have been added with the BatchPutDocument API.
batchDeleteFeaturedResultsSet({required List<String> featuredResultsSetIds, required String indexId}) Future<BatchDeleteFeaturedResultsSetResponse>
Removes one or more sets of featured results. Features results are placed above all other results for certain queries. If there's an exact match of a query, then one or more specific documents are featured in the search results.
batchGetDocumentStatus({required List<DocumentInfo> documentInfoList, required String indexId}) Future<BatchGetDocumentStatusResponse>
Returns the indexing status for one or more documents submitted with the BatchPutDocument API.
batchPutDocument({required List<Document> documents, required String indexId, CustomDocumentEnrichmentConfiguration? customDocumentEnrichmentConfiguration, String? roleArn}) Future<BatchPutDocumentResponse>
Adds one or more documents to an index.
clearQuerySuggestions({required String indexId}) Future<void>
Clears existing query suggestions from an index.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAccessControlConfiguration({required String indexId, required String name, List<Principal>? accessControlList, String? clientToken, String? description, List<HierarchicalPrincipal>? hierarchicalAccessControlList}) Future<CreateAccessControlConfigurationResponse>
Creates an access configuration for your documents. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
createDataSource({required String indexId, required String name, required DataSourceType type, String? clientToken, DataSourceConfiguration? configuration, CustomDocumentEnrichmentConfiguration? customDocumentEnrichmentConfiguration, String? description, String? languageCode, String? roleArn, String? schedule, List<Tag>? tags, DataSourceVpcConfiguration? vpcConfiguration}) Future<CreateDataSourceResponse>
Creates a data source connector that you want to use with an Amazon Kendra index.
createExperience({required String indexId, required String name, String? clientToken, ExperienceConfiguration? configuration, String? description, String? roleArn}) Future<CreateExperienceResponse>
Creates an Amazon Kendra experience such as a search application. For more information on creating a search application experience, including using the Python and Java SDKs, see Building a search experience with no code.
createFaq({required String indexId, required String name, required String roleArn, required S3Path s3Path, String? clientToken, String? description, FaqFileFormat? fileFormat, String? languageCode, List<Tag>? tags}) Future<CreateFaqResponse>
Creates a set of frequently ask questions (FAQs) using a specified FAQ file stored in an Amazon S3 bucket.
createFeaturedResultsSet({required String featuredResultsSetName, required String indexId, String? clientToken, String? description, List<FeaturedDocument>? featuredDocuments, List<String>? queryTexts, FeaturedResultsSetStatus? status, List<Tag>? tags}) Future<CreateFeaturedResultsSetResponse>
Creates a set of featured results to display at the top of the search results page. Featured results are placed above all other results for certain queries. You map specific queries to specific documents for featuring in the results. If a query contains an exact match, then one or more specific documents are featured in the search results.
createIndex({required String name, required String roleArn, String? clientToken, String? description, IndexEdition? edition, ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration, List<Tag>? tags, UserContextPolicy? userContextPolicy, UserGroupResolutionConfiguration? userGroupResolutionConfiguration, List<UserTokenConfiguration>? userTokenConfigurations}) Future<CreateIndexResponse>
Creates an Amazon Kendra index. Index creation is an asynchronous API. To determine if index creation has completed, check the Status field returned from a call to DescribeIndex. The Status field is set to ACTIVE when the index is ready to use.
createQuerySuggestionsBlockList({required String indexId, required String name, required String roleArn, required S3Path sourceS3Path, String? clientToken, String? description, List<Tag>? tags}) Future<CreateQuerySuggestionsBlockListResponse>
Creates a block list to exlcude certain queries from suggestions.
createThesaurus({required String indexId, required String name, required String roleArn, required S3Path sourceS3Path, String? clientToken, String? description, List<Tag>? tags}) Future<CreateThesaurusResponse>
Creates a thesaurus for an index. The thesaurus contains a list of synonyms in Solr format.
deleteAccessControlConfiguration({required String id, required String indexId}) Future<void>
Deletes an access control configuration that you created for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
deleteDataSource({required String id, required String indexId}) Future<void>
Deletes an Amazon Kendra data source connector. An exception is not thrown if the data source is already being deleted. While the data source is being deleted, the Status field returned by a call to the DescribeDataSource API is set to DELETING. For more information, see Deleting Data Sources.
deleteExperience({required String id, required String indexId}) Future<void>
Deletes your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
deleteFaq({required String id, required String indexId}) Future<void>
Removes a FAQ from an index.
deleteIndex({required String id}) Future<void>
Deletes an Amazon Kendra index. An exception is not thrown if the index is already being deleted. While the index is being deleted, the Status field returned by a call to the DescribeIndex API is set to DELETING.
deletePrincipalMapping({required String groupId, required String indexId, String? dataSourceId, int? orderingId}) Future<void>
Deletes a group so that all users that belong to the group can no longer access documents only available to that group.
deleteQuerySuggestionsBlockList({required String id, required String indexId}) Future<void>
Deletes a block list used for query suggestions for an index.
deleteThesaurus({required String id, required String indexId}) Future<void>
Deletes an Amazon Kendra thesaurus.
describeAccessControlConfiguration({required String id, required String indexId}) Future<DescribeAccessControlConfigurationResponse>
Gets information about an access control configuration that you created for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
describeDataSource({required String id, required String indexId}) Future<DescribeDataSourceResponse>
Gets information about an Amazon Kendra data source connector.
describeExperience({required String id, required String indexId}) Future<DescribeExperienceResponse>
Gets information about your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
describeFaq({required String id, required String indexId}) Future<DescribeFaqResponse>
Gets information about a FAQ.
describeFeaturedResultsSet({required String featuredResultsSetId, required String indexId}) Future<DescribeFeaturedResultsSetResponse>
Gets information about a set of featured results. Features results are placed above all other results for certain queries. If there's an exact match of a query, then one or more specific documents are featured in the search results.
describeIndex({required String id}) Future<DescribeIndexResponse>
Gets information about an Amazon Kendra index.
describePrincipalMapping({required String groupId, required String indexId, String? dataSourceId}) Future<DescribePrincipalMappingResponse>
Describes the processing of PUT and DELETE actions for mapping users to their groups. This includes information on the status of actions currently processing or yet to be processed, when actions were last updated, when actions were received by Amazon Kendra, the latest action that should process and apply after other actions, and useful error messages if an action could not be processed.
describeQuerySuggestionsBlockList({required String id, required String indexId}) Future<DescribeQuerySuggestionsBlockListResponse>
Gets information about a block list used for query suggestions for an index.
describeQuerySuggestionsConfig({required String indexId}) Future<DescribeQuerySuggestionsConfigResponse>
Gets information on the settings of query suggestions for an index.
describeThesaurus({required String id, required String indexId}) Future<DescribeThesaurusResponse>
Gets information about an Amazon Kendra thesaurus.
disassociateEntitiesFromExperience({required List<EntityConfiguration> entityList, required String id, required String indexId}) Future<DisassociateEntitiesFromExperienceResponse>
Prevents users or groups in your IAM Identity Center identity source from accessing your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
disassociatePersonasFromEntities({required List<String> entityIds, required String id, required String indexId}) Future<DisassociatePersonasFromEntitiesResponse>
Removes the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
getQuerySuggestions({required String indexId, required String queryText, AttributeSuggestionsGetConfig? attributeSuggestionsConfig, int? maxSuggestionsCount, List<SuggestionType>? suggestionTypes}) Future<GetQuerySuggestionsResponse>
Fetches the queries that are suggested to your users.
getSnapshots({required String indexId, required Interval interval, required MetricType metricType, int? maxResults, String? nextToken}) Future<GetSnapshotsResponse>
Retrieves search metrics data. The data provides a snapshot of how your users interact with your search application and how effective the application is.
listAccessControlConfigurations({required String indexId, int? maxResults, String? nextToken}) Future<ListAccessControlConfigurationsResponse>
Lists one or more access control configurations for an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
listDataSources({required String indexId, int? maxResults, String? nextToken}) Future<ListDataSourcesResponse>
Lists the data source connectors that you have created.
listDataSourceSyncJobs({required String id, required String indexId, int? maxResults, String? nextToken, TimeRange? startTimeFilter, DataSourceSyncJobStatus? statusFilter}) Future<ListDataSourceSyncJobsResponse>
Gets statistics about synchronizing a data source connector.
listEntityPersonas({required String id, required String indexId, int? maxResults, String? nextToken}) Future<ListEntityPersonasResponse>
Lists specific permissions of users and groups with access to your Amazon Kendra experience.
listExperienceEntities({required String id, required String indexId, String? nextToken}) Future<ListExperienceEntitiesResponse>
Lists users or groups in your IAM Identity Center identity source that are granted access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
listExperiences({required String indexId, int? maxResults, String? nextToken}) Future<ListExperiencesResponse>
Lists one or more Amazon Kendra experiences. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
listFaqs({required String indexId, int? maxResults, String? nextToken}) Future<ListFaqsResponse>
Gets a list of FAQs associated with an index.
listFeaturedResultsSets({required String indexId, int? maxResults, String? nextToken}) Future<ListFeaturedResultsSetsResponse>
Lists all your sets of featured results for a given index. Features results are placed above all other results for certain queries. If there's an exact match of a query, then one or more specific documents are featured in the search results.
listGroupsOlderThanOrderingId({required String indexId, required int orderingId, String? dataSourceId, int? maxResults, String? nextToken}) Future<ListGroupsOlderThanOrderingIdResponse>
Provides a list of groups that are mapped to users before a given ordering or timestamp identifier.
listIndices({int? maxResults, String? nextToken}) Future<ListIndicesResponse>
Lists the Amazon Kendra indexes that you created.
listQuerySuggestionsBlockLists({required String indexId, int? maxResults, String? nextToken}) Future<ListQuerySuggestionsBlockListsResponse>
Lists the block lists used for query suggestions for an index.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
Gets a list of tags associated with a resource. Indexes, FAQs, data sources, and other resources can have tags associated with them.
listThesauri({required String indexId, int? maxResults, String? nextToken}) Future<ListThesauriResponse>
Lists the thesauri for an index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putPrincipalMapping({required String groupId, required GroupMembers groupMembers, required String indexId, String? dataSourceId, int? orderingId, String? roleArn}) Future<void>
Maps users to their groups so that you only need to provide the user ID when you issue the query.
query({required String indexId, AttributeFilter? attributeFilter, CollapseConfiguration? collapseConfiguration, List<DocumentRelevanceConfiguration>? documentRelevanceOverrideConfigurations, List<Facet>? facets, int? pageNumber, int? pageSize, QueryResultType? queryResultTypeFilter, String? queryText, List<String>? requestedDocumentAttributes, SortingConfiguration? sortingConfiguration, List<SortingConfiguration>? sortingConfigurations, SpellCorrectionConfiguration? spellCorrectionConfiguration, UserContext? userContext, String? visitorId}) Future<QueryResult>
Searches an index given an input query. You can configure boosting or relevance tuning at the query level to override boosting at the index level, filter based on document fields/attributes and faceted search, and filter based on the user or their group access to documents. You can also include certain fields in the response that might provide useful additional information.
retrieve({required String indexId, required String queryText, AttributeFilter? attributeFilter, List<DocumentRelevanceConfiguration>? documentRelevanceOverrideConfigurations, int? pageNumber, int? pageSize, List<String>? requestedDocumentAttributes, UserContext? userContext}) Future<RetrieveResult>
Retrieves relevant passages or text excerpts given an input query.
startDataSourceSyncJob({required String id, required String indexId}) Future<StartDataSourceSyncJobResponse>
Starts a synchronization job for a data source connector. If a synchronization job is already in progress, Amazon Kendra returns a ResourceInUseException exception.
stopDataSourceSyncJob({required String id, required String indexId}) Future<void>
Stops a synchronization job that is currently running. You can't stop a scheduled synchronization job.
submitFeedback({required String indexId, required String queryId, List<ClickFeedback>? clickFeedbackItems, List<RelevanceFeedback>? relevanceFeedbackItems}) Future<void>
Enables you to provide feedback to Amazon Kendra to improve the performance of your index.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Adds the specified tag to the specified index, FAQ, data source, or other resource. If the tag already exists, the existing value is replaced with the new value.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes a tag from an index, FAQ, data source, or other resource.
updateAccessControlConfiguration({required String id, required String indexId, List<Principal>? accessControlList, String? description, List<HierarchicalPrincipal>? hierarchicalAccessControlList, String? name}) Future<void>
Updates an access control configuration for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
updateDataSource({required String id, required String indexId, DataSourceConfiguration? configuration, CustomDocumentEnrichmentConfiguration? customDocumentEnrichmentConfiguration, String? description, String? languageCode, String? name, String? roleArn, String? schedule, DataSourceVpcConfiguration? vpcConfiguration}) Future<void>
Updates an Amazon Kendra data source connector.
updateExperience({required String id, required String indexId, ExperienceConfiguration? configuration, String? description, String? name, String? roleArn}) Future<void>
Updates your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
updateFeaturedResultsSet({required String featuredResultsSetId, required String indexId, String? description, List<FeaturedDocument>? featuredDocuments, String? featuredResultsSetName, List<String>? queryTexts, FeaturedResultsSetStatus? status}) Future<UpdateFeaturedResultsSetResponse>
Updates a set of featured results. Features results are placed above all other results for certain queries. You map specific queries to specific documents for featuring in the results. If a query contains an exact match of a query, then one or more specific documents are featured in the search results.
updateIndex({required String id, CapacityUnitsConfiguration? capacityUnits, String? description, List<DocumentMetadataConfiguration>? documentMetadataConfigurationUpdates, String? name, String? roleArn, UserContextPolicy? userContextPolicy, UserGroupResolutionConfiguration? userGroupResolutionConfiguration, List<UserTokenConfiguration>? userTokenConfigurations}) Future<void>
Updates an Amazon Kendra index.
updateQuerySuggestionsBlockList({required String id, required String indexId, String? description, String? name, String? roleArn, S3Path? sourceS3Path}) Future<void>
Updates a block list used for query suggestions for an index.
updateQuerySuggestionsConfig({required String indexId, AttributeSuggestionsUpdateConfig? attributeSuggestionsConfig, bool? includeQueriesWithoutUserInformation, int? minimumNumberOfQueryingUsers, int? minimumQueryCount, Mode? mode, int? queryLogLookBackWindowInDays}) Future<void>
Updates the settings of query suggestions for an index.
updateThesaurus({required String id, required String indexId, String? description, String? name, String? roleArn, S3Path? sourceS3Path}) Future<void>
Updates a thesaurus for an index.

Operators

operator ==(Object other) bool
The equality operator.
inherited