batchDeleteFeaturedResultsSet method

Future<BatchDeleteFeaturedResultsSetResponse> batchDeleteFeaturedResultsSet({
  1. required List<String> featuredResultsSetIds,
  2. required String indexId,
})

Removes one or more sets of featured results. Features results are placed above all other results for certain queries. If there's an exact match of a query, then one or more specific documents are featured in the search results.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter featuredResultsSetIds : The identifiers of the featured results sets that you want to delete.

Parameter indexId : The identifier of the index used for featuring results.

Implementation

Future<BatchDeleteFeaturedResultsSetResponse> batchDeleteFeaturedResultsSet({
  required List<String> featuredResultsSetIds,
  required String indexId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSKendraFrontendService.BatchDeleteFeaturedResultsSet'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'FeaturedResultsSetIds': featuredResultsSetIds,
      'IndexId': indexId,
    },
  );

  return BatchDeleteFeaturedResultsSetResponse.fromJson(jsonResponse.body);
}