createAccessControlConfiguration method
Creates an access configuration for your documents. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
You can use this to re-configure your existing document level access control without indexing all of your documents again. For example, your index contains top-secret company documents that only certain employees or users should access. One of these users leaves the company or switches to a team that should be blocked from accessing top-secret documents. The user still has access to top-secret documents because the user had access when your documents were previously indexed. You can create a specific access control configuration for the user with deny access. You can later update the access control configuration to allow access if the user returns to the company and re-joins the 'top-secret' team. You can re-configure access control for your documents as circumstances change.
To apply your access control configuration to certain documents, you call
the BatchPutDocument
API with the AccessControlConfigurationId included in the Document
object. If you use an S3 bucket as a data source, you update the
.metadata.json with the
AccessControlConfigurationId and synchronize your data
source. Amazon Kendra currently only supports access control configuration
for S3 data sources and documents indexed using the
BatchPutDocument API.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexId :
The identifier of the index to create an access control configuration for
your documents.
Parameter name :
A name for the access control configuration.
Parameter accessControlList :
Information on principals (users and/or groups) and which documents they
should have access to. This is useful for user context filtering, where
search results are filtered based on the user or their group access to
documents.
Parameter clientToken :
A token that you provide to identify the request to create an access
control configuration. Multiple calls to the
CreateAccessControlConfiguration API with the same client
token will create only one access control configuration.
Parameter description :
A description for the access control configuration.
Parameter hierarchicalAccessControlList :
The list of principal
lists that define the hierarchy for which documents users should have
access to.
Implementation
Future<CreateAccessControlConfigurationResponse>
createAccessControlConfiguration({
required String indexId,
required String name,
List<Principal>? accessControlList,
String? clientToken,
String? description,
List<HierarchicalPrincipal>? hierarchicalAccessControlList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSKendraFrontendService.CreateAccessControlConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IndexId': indexId,
'Name': name,
if (accessControlList != null) 'AccessControlList': accessControlList,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (hierarchicalAccessControlList != null)
'HierarchicalAccessControlList': hierarchicalAccessControlList,
},
);
return CreateAccessControlConfigurationResponse.fromJson(jsonResponse.body);
}