createDataSource method
- required String indexId,
- required String name,
- required DataSourceType type,
- String? clientToken,
- DataSourceConfiguration? configuration,
- CustomDocumentEnrichmentConfiguration? customDocumentEnrichmentConfiguration,
- String? description,
- String? languageCode,
- String? roleArn,
- String? schedule,
- List<
Tag> ? tags, - DataSourceVpcConfiguration? vpcConfiguration,
Creates a data source connector that you want to use with an Amazon Kendra index.
You specify a name, data source connector type and description for your data source. You also specify configuration information for the data source connector.
CreateDataSource is a synchronous operation. The operation
returns 200 if the data source was successfully created. Otherwise, an
exception is raised.
For an example of creating an index and data source using the Python SDK, see Getting started with Python SDK. For an example of creating an index and data source using the Java SDK, see Getting started with Java SDK.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceAlreadyExistException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexId :
The identifier of the index you want to use with the data source
connector.
Parameter name :
A name for the data source connector.
Parameter type :
The type of data source repository. For example, SHAREPOINT.
Parameter clientToken :
A token that you provide to identify the request to create a data source
connector. Multiple calls to the CreateDataSource API with
the same client token will create only one data source connector.
Parameter configuration :
Configuration information to connect to your data source repository.
You can't specify the Configuration parameter when the
Type parameter is set to CUSTOM. If you do, you
receive a ValidationException exception.
The Configuration parameter is required for all other data
sources.
Parameter customDocumentEnrichmentConfiguration :
Configuration information for altering document metadata and content
during the document ingestion process.
For more information on how to create, modify and delete document metadata, or make other content alterations when you ingest documents into Amazon Kendra, see Customizing document metadata during the ingestion process.
Parameter description :
A description for the data source connector.
Parameter languageCode :
The code for a language. This allows you to support a language for all
documents when creating the data source connector. English is supported by
default. For more information on supported languages, including their
codes, see Adding
documents in languages other than English.
Parameter roleArn :
The Amazon Resource Name (ARN) of an IAM role with permission to access
the data source and required resources. For more information, see IAM
access roles for Amazon Kendra..
You can't specify the RoleArn parameter when the
Type parameter is set to CUSTOM. If you do, you
receive a ValidationException exception.
The RoleArn parameter is required for all other data sources.
Parameter schedule :
Sets the frequency for Amazon Kendra to check the documents in your data
source repository and update the index. If you don't set a schedule Amazon
Kendra will not periodically update the index. You can call the
StartDataSourceSyncJob API to update the index.
Specify a cron- format schedule string or an empty string to
indicate that the index is updated on demand.
You can't specify the Schedule parameter when the
Type parameter is set to CUSTOM. If you do, you
receive a ValidationException exception.
Parameter tags :
A list of key-value pairs that identify or categorize the data source
connector. You can also use tags to help control access to the data source
connector. Tag keys and values can consist of Unicode letters, digits,
white space, and any of the following symbols: _ . : / = + - @.
Parameter vpcConfiguration :
Configuration information for an Amazon Virtual Private Cloud to connect
to your data source. For more information, see Configuring
a VPC.
Implementation
Future<CreateDataSourceResponse> createDataSource({
required String indexId,
required String name,
required DataSourceType type,
String? clientToken,
DataSourceConfiguration? configuration,
CustomDocumentEnrichmentConfiguration?
customDocumentEnrichmentConfiguration,
String? description,
String? languageCode,
String? roleArn,
String? schedule,
List<Tag>? tags,
DataSourceVpcConfiguration? vpcConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.CreateDataSource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IndexId': indexId,
'Name': name,
'Type': type.value,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (configuration != null) 'Configuration': configuration,
if (customDocumentEnrichmentConfiguration != null)
'CustomDocumentEnrichmentConfiguration':
customDocumentEnrichmentConfiguration,
if (description != null) 'Description': description,
if (languageCode != null) 'LanguageCode': languageCode,
if (roleArn != null) 'RoleArn': roleArn,
if (schedule != null) 'Schedule': schedule,
if (tags != null) 'Tags': tags,
if (vpcConfiguration != null) 'VpcConfiguration': vpcConfiguration,
},
);
return CreateDataSourceResponse.fromJson(jsonResponse.body);
}