describeAccessControlConfiguration method
Gets information about an access control configuration that you created for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The identifier of the access control configuration you want to get
information on.
Parameter indexId :
The identifier of the index for an access control configuration.
Implementation
Future<DescribeAccessControlConfigurationResponse>
describeAccessControlConfiguration({
required String id,
required String indexId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSKendraFrontendService.DescribeAccessControlConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'IndexId': indexId,
},
);
return DescribeAccessControlConfigurationResponse.fromJson(
jsonResponse.body);
}