describeExperience method

Future<DescribeExperienceResponse> describeExperience({
  1. required String id,
  2. required String indexId,
})

Gets information about your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The identifier of your Amazon Kendra experience you want to get information on.

Parameter indexId : The identifier of the index for your Amazon Kendra experience.

Implementation

Future<DescribeExperienceResponse> describeExperience({
  required String id,
  required String indexId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSKendraFrontendService.DescribeExperience'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'IndexId': indexId,
    },
  );

  return DescribeExperienceResponse.fromJson(jsonResponse.body);
}