describePrincipalMapping method

Future<DescribePrincipalMappingResponse> describePrincipalMapping({
  1. required String groupId,
  2. required String indexId,
  3. String? dataSourceId,
})

Describes the processing of PUT and DELETE actions for mapping users to their groups. This includes information on the status of actions currently processing or yet to be processed, when actions were last updated, when actions were received by Amazon Kendra, the latest action that should process and apply after other actions, and useful error messages if an action could not be processed.

DescribePrincipalMapping is currently not supported in the Amazon Web Services GovCloud (US-West) region.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter groupId : The identifier of the group required to check the processing of PUT and DELETE actions for mapping users to their groups.

Parameter indexId : The identifier of the index required to check the processing of PUT and DELETE actions for mapping users to their groups.

Parameter dataSourceId : The identifier of the data source to check the processing of PUT and DELETE actions for mapping users to their groups.

Implementation

Future<DescribePrincipalMappingResponse> describePrincipalMapping({
  required String groupId,
  required String indexId,
  String? dataSourceId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSKendraFrontendService.DescribePrincipalMapping'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GroupId': groupId,
      'IndexId': indexId,
      if (dataSourceId != null) 'DataSourceId': dataSourceId,
    },
  );

  return DescribePrincipalMappingResponse.fromJson(jsonResponse.body);
}