describeQuerySuggestionsBlockList method

Future<DescribeQuerySuggestionsBlockListResponse> describeQuerySuggestionsBlockList({
  1. required String id,
  2. required String indexId,
})

Gets information about a block list used for query suggestions for an index.

This is used to check the current settings that are applied to a block list.

DescribeQuerySuggestionsBlockList is currently not supported in the Amazon Web Services GovCloud (US-West) region.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The identifier of the block list you want to get information on.

Parameter indexId : The identifier of the index for the block list.

Implementation

Future<DescribeQuerySuggestionsBlockListResponse>
    describeQuerySuggestionsBlockList({
  required String id,
  required String indexId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSKendraFrontendService.DescribeQuerySuggestionsBlockList'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'IndexId': indexId,
    },
  );

  return DescribeQuerySuggestionsBlockListResponse.fromJson(
      jsonResponse.body);
}