disassociateEntitiesFromExperience method
Prevents users or groups in your IAM Identity Center identity source from accessing your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter entityList :
Lists users or groups in your IAM Identity Center identity source.
Parameter id :
The identifier of your Amazon Kendra experience.
Parameter indexId :
The identifier of the index for your Amazon Kendra experience.
Implementation
Future<DisassociateEntitiesFromExperienceResponse>
disassociateEntitiesFromExperience({
required List<EntityConfiguration> entityList,
required String id,
required String indexId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSKendraFrontendService.DisassociateEntitiesFromExperience'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EntityList': entityList,
'Id': id,
'IndexId': indexId,
},
);
return DisassociateEntitiesFromExperienceResponse.fromJson(
jsonResponse.body);
}