disassociatePersonasFromEntities method

Future<DisassociatePersonasFromEntitiesResponse> disassociatePersonasFromEntities({
  1. required List<String> entityIds,
  2. required String id,
  3. required String indexId,
})

Removes the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see Building a search experience with no code.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter entityIds : The identifiers of users or groups in your IAM Identity Center identity source. For example, user IDs could be user emails.

Parameter id : The identifier of your Amazon Kendra experience.

Parameter indexId : The identifier of the index for your Amazon Kendra experience.

Implementation

Future<DisassociatePersonasFromEntitiesResponse>
    disassociatePersonasFromEntities({
  required List<String> entityIds,
  required String id,
  required String indexId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSKendraFrontendService.DisassociatePersonasFromEntities'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EntityIds': entityIds,
      'Id': id,
      'IndexId': indexId,
    },
  );

  return DisassociatePersonasFromEntitiesResponse.fromJson(jsonResponse.body);
}