query method
- required String indexId,
- AttributeFilter? attributeFilter,
- CollapseConfiguration? collapseConfiguration,
- List<
DocumentRelevanceConfiguration> ? documentRelevanceOverrideConfigurations, - List<
Facet> ? facets, - int? pageNumber,
- int? pageSize,
- QueryResultType? queryResultTypeFilter,
- String? queryText,
- List<
String> ? requestedDocumentAttributes, - SortingConfiguration? sortingConfiguration,
- List<
SortingConfiguration> ? sortingConfigurations, - SpellCorrectionConfiguration? spellCorrectionConfiguration,
- UserContext? userContext,
- String? visitorId,
Searches an index given an input query. You can configure boosting or relevance tuning at the query level to override boosting at the index level, filter based on document fields/attributes and faceted search, and filter based on the user or their group access to documents. You can also include certain fields in the response that might provide useful additional information.
A query response contains three types of results.
- Relevant suggested answers. The answers can be either a text excerpt or table excerpt. The answer can be highlighted in the excerpt.
- Matching FAQs or questions-answer from your FAQ file.
- Relevant documents. This result type includes an excerpt of the document with the document title. The searched terms can be highlighted in the excerpt.
QueryResultTypeFilter parameter. Each query returns the 100
most relevant results. If you filter result type to only question-answers,
a maximum of four results are returned. If you filter result type to only
answers, a maximum of three results are returned.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexId :
The identifier of the index for the search.
Parameter attributeFilter :
Filters search results by document fields/attributes. You can only provide
one attribute filter; however, the AndAllFilters,
NotFilter, and OrAllFilters parameters contain a
list of other filters.
The AttributeFilter parameter means you can create a set of
filtering rules that a document must satisfy to be included in the query
results.
Parameter collapseConfiguration :
Provides configuration to determine how to group results by document
attribute value, and how to display them (collapsed or expanded) under a
designated primary document for each group.
Parameter documentRelevanceOverrideConfigurations :
Overrides relevance tuning configurations of fields/attributes set at the
index level.
If you use this API to override the relevance tuning configured at the index level, but there is no relevance tuning configured at the index level, then Amazon Kendra does not apply any relevance tuning.
If there is relevance tuning configured for fields at the index level, and you use this API to override only some of these fields, then for the fields you did not override, the importance is set to 1.
Parameter facets :
An array of documents fields/attributes for faceted search. Amazon Kendra
returns a count for each field key specified. This helps your users narrow
their search.
Parameter pageNumber :
Query results are returned in pages the size of the PageSize
parameter. By default, Amazon Kendra returns the first page of results.
Use this parameter to get result pages after the first one.
Parameter pageSize :
Sets the number of results that are returned in each page of results. The
default page size is 10. The maximum number of results returned is 100. If
you ask for more than 100 results, only 100 are returned.
Parameter queryResultTypeFilter :
Sets the type of query result or response. Only results for the specified
type are returned.
Parameter queryText :
The input query text for the search. Amazon Kendra truncates queries at 30
token words, which excludes punctuation and stop words. Truncation still
applies if you use Boolean or more advanced, complex queries. For example,
Timeoff AND October AND Category:HR is counted as 3 tokens:
timeoff, october, hr. For more
information, see Searching
with advanced query syntax in the Amazon Kendra Developer Guide.
Parameter requestedDocumentAttributes :
An array of document fields/attributes to include in the response. You can
limit the response to include certain document fields. By default, all
document attributes are included in the response.
Parameter sortingConfiguration :
Provides information that determines how the results of the query are
sorted. You can set the field that Amazon Kendra should sort the results
on, and specify whether the results should be sorted in ascending or
descending order. In the case of ties in sorting the results, the results
are sorted by relevance.
If you don't provide sorting configuration, the results are sorted by the relevance that Amazon Kendra determines for the result.
Parameter sortingConfigurations :
Provides configuration information to determine how the results of a query
are sorted.
You can set upto 3 fields that Amazon Kendra should sort the results on, and specify whether the results should be sorted in ascending or descending order. The sort field quota can be increased.
If you don't provide a sorting configuration, the results are sorted by the relevance that Amazon Kendra determines for the result. In the case of ties in sorting the results, the results are sorted by relevance.
Parameter spellCorrectionConfiguration :
Enables suggested spell corrections for queries.
Parameter userContext :
The user context token or user and group information.
Parameter visitorId :
Provides an identifier for a specific user. The VisitorId
should be a unique identifier, such as a GUID. Don't use personally
identifiable information, such as the user's email address, as the
VisitorId.
Implementation
Future<QueryResult> query({
required String indexId,
AttributeFilter? attributeFilter,
CollapseConfiguration? collapseConfiguration,
List<DocumentRelevanceConfiguration>?
documentRelevanceOverrideConfigurations,
List<Facet>? facets,
int? pageNumber,
int? pageSize,
QueryResultType? queryResultTypeFilter,
String? queryText,
List<String>? requestedDocumentAttributes,
SortingConfiguration? sortingConfiguration,
List<SortingConfiguration>? sortingConfigurations,
SpellCorrectionConfiguration? spellCorrectionConfiguration,
UserContext? userContext,
String? visitorId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.Query'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IndexId': indexId,
if (attributeFilter != null) 'AttributeFilter': attributeFilter,
if (collapseConfiguration != null)
'CollapseConfiguration': collapseConfiguration,
if (documentRelevanceOverrideConfigurations != null)
'DocumentRelevanceOverrideConfigurations':
documentRelevanceOverrideConfigurations,
if (facets != null) 'Facets': facets,
if (pageNumber != null) 'PageNumber': pageNumber,
if (pageSize != null) 'PageSize': pageSize,
if (queryResultTypeFilter != null)
'QueryResultTypeFilter': queryResultTypeFilter.value,
if (queryText != null) 'QueryText': queryText,
if (requestedDocumentAttributes != null)
'RequestedDocumentAttributes': requestedDocumentAttributes,
if (sortingConfiguration != null)
'SortingConfiguration': sortingConfiguration,
if (sortingConfigurations != null)
'SortingConfigurations': sortingConfigurations,
if (spellCorrectionConfiguration != null)
'SpellCorrectionConfiguration': spellCorrectionConfiguration,
if (userContext != null) 'UserContext': userContext,
if (visitorId != null) 'VisitorId': visitorId,
},
);
return QueryResult.fromJson(jsonResponse.body);
}