stopDataSourceSyncJob method

Future<void> stopDataSourceSyncJob({
  1. required String id,
  2. required String indexId,
})

Stops a synchronization job that is currently running. You can't stop a scheduled synchronization job.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The identifier of the data source connector for which to stop the synchronization jobs.

Parameter indexId : The identifier of the index used with the data source connector.

Implementation

Future<void> stopDataSourceSyncJob({
  required String id,
  required String indexId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSKendraFrontendService.StopDataSourceSyncJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'IndexId': indexId,
    },
  );
}