updateQuerySuggestionsConfig method
Updates the settings of query suggestions for an index.
Amazon Kendra supports partial updates, so you only need to provide the fields you want to update.
If an update is currently processing, you need to wait for the update to finish before making another update.
Updates to query suggestions settings might not take effect right away. The time for your updated settings to take effect depends on the updates made and the number of search queries in your index.
You can still enable/disable query suggestions at any time.
UpdateQuerySuggestionsConfig is currently not supported in
the Amazon Web Services GovCloud (US-West) region.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexId :
The identifier of the index with query suggestions you want to update.
Parameter attributeSuggestionsConfig :
Configuration information for the document fields/attributes that you want
to base query suggestions on.
Parameter includeQueriesWithoutUserInformation :
TRUE to include queries without user information (i.e. all
queries, irrespective of the user), otherwise FALSE to only
include queries with user information.
If you pass user information to Amazon Kendra along with the queries, you
can set this flag to FALSE and instruct Amazon Kendra to only
consider queries with user information.
If you set to FALSE, Amazon Kendra only considers queries
searched at least MinimumQueryCount times across
MinimumNumberOfQueryingUsers unique users for suggestions.
If you set to TRUE, Amazon Kendra ignores all user
information and learns from all queries.
Parameter minimumNumberOfQueryingUsers :
The minimum number of unique users who must search a query in order for
the query to be eligible to suggest to your users.
Increasing this number might decrease the number of suggestions. However, this ensures a query is searched by many users and is truly popular to suggest to users.
How you tune this setting depends on your specific needs.
Parameter minimumQueryCount :
The the minimum number of times a query must be searched in order to be
eligible to suggest to your users.
Decreasing this number increases the number of suggestions. However, this affects the quality of suggestions as it sets a low bar for a query to be considered popular to suggest to users.
How you tune this setting depends on your specific needs.
Parameter mode :
Set the mode to ENABLED or LEARN_ONLY.
By default, Amazon Kendra enables query suggestions.
LEARN_ONLY mode allows you to turn off query suggestions. You
can to update this at any time.
In LEARN_ONLY mode, Amazon Kendra continues to learn from new
queries to keep suggestions up to date for when you are ready to switch to
ENABLED mode again.
Parameter queryLogLookBackWindowInDays :
How recent your queries are in your query log time window.
The time window is the number of days from current day to past days.
By default, Amazon Kendra sets this to 180.
Implementation
Future<void> updateQuerySuggestionsConfig({
required String indexId,
AttributeSuggestionsUpdateConfig? attributeSuggestionsConfig,
bool? includeQueriesWithoutUserInformation,
int? minimumNumberOfQueryingUsers,
int? minimumQueryCount,
Mode? mode,
int? queryLogLookBackWindowInDays,
}) async {
_s.validateNumRange(
'minimumNumberOfQueryingUsers',
minimumNumberOfQueryingUsers,
1,
10000,
);
_s.validateNumRange(
'minimumQueryCount',
minimumQueryCount,
1,
10000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.UpdateQuerySuggestionsConfig'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IndexId': indexId,
if (attributeSuggestionsConfig != null)
'AttributeSuggestionsConfig': attributeSuggestionsConfig,
if (includeQueriesWithoutUserInformation != null)
'IncludeQueriesWithoutUserInformation':
includeQueriesWithoutUserInformation,
if (minimumNumberOfQueryingUsers != null)
'MinimumNumberOfQueryingUsers': minimumNumberOfQueryingUsers,
if (minimumQueryCount != null) 'MinimumQueryCount': minimumQueryCount,
if (mode != null) 'Mode': mode.value,
if (queryLogLookBackWindowInDays != null)
'QueryLogLookBackWindowInDays': queryLogLookBackWindowInDays,
},
);
}