getKeyspace method

Future<GetKeyspaceResponse> getKeyspace({
  1. required String keyspaceName,
})

Returns the name of the specified keyspace, the Amazon Resource Name (ARN), the replication strategy, the Amazon Web Services Regions of a multi-Region keyspace, and the status of newly added Regions after an UpdateKeyspace operation.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ValidationException.

Parameter keyspaceName : The name of the keyspace.

Implementation

Future<GetKeyspaceResponse> getKeyspace({
  required String keyspaceName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'KeyspacesService.GetKeyspace'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'keyspaceName': keyspaceName,
    },
  );

  return GetKeyspaceResponse.fromJson(jsonResponse.body);
}