untagResource method
Removes the association of tags from a Amazon Keyspaces resource.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Keyspaces resource that the tags will be removed from. This
value is an Amazon Resource Name (ARN).
Parameter tags :
A list of existing tags to be removed from the Amazon Keyspaces resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'KeyspacesService.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'resourceArn': resourceArn,
'tags': tags,
},
);
}