updateTable method
- required String keyspaceName,
- required String tableName,
- List<
ColumnDefinition> ? addColumns, - AutoScalingSpecification? autoScalingSpecification,
- CapacitySpecification? capacitySpecification,
- CdcSpecification? cdcSpecification,
- ClientSideTimestamps? clientSideTimestamps,
- int? defaultTimeToLive,
- EncryptionSpecification? encryptionSpecification,
- PointInTimeRecovery? pointInTimeRecovery,
- List<
ReplicaSpecification> ? replicaSpecifications, - TimeToLive? ttl,
- WarmThroughputSpecification? warmThroughputSpecification,
Adds new columns to the table or updates one of the table's settings, for example capacity mode, auto scaling, encryption, point-in-time recovery, or ttl settings. Note that you can only update one specific table setting per update operation.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter keyspaceName :
The name of the keyspace the specified table is stored in.
Parameter tableName :
The name of the table.
Parameter addColumns :
For each column to be added to the specified table:
-
name- The name of the column. -
type- An Amazon Keyspaces data type. For more information, see Data types in the Amazon Keyspaces Developer Guide.
Parameter autoScalingSpecification :
The optional auto scaling settings to update for a table in provisioned
capacity mode. Specifies if the service can manage throughput capacity of
a provisioned table automatically on your behalf. Amazon Keyspaces auto
scaling helps you provision throughput capacity for variable workloads
efficiently by increasing and decreasing your table's read and write
capacity automatically in response to application traffic.
If auto scaling is already enabled for the table, you can use
UpdateTable to update the minimum and maximum values or the
auto scaling policy settings independently.
For more information, see Managing throughput capacity automatically with Amazon Keyspaces auto scaling in the Amazon Keyspaces Developer Guide.
Parameter capacitySpecification :
Modifies the read/write throughput capacity mode for the table. The
options are:
-
throughputMode:PAY_PER_REQUESTand -
throughputMode:PROVISIONED- Provisioned capacity mode requiresreadCapacityUnitsandwriteCapacityUnitsas input.
throughput_mode:PAY_PER_REQUEST.
For more information, see Read/write capacity modes in the Amazon Keyspaces Developer Guide.
Parameter cdcSpecification :
The CDC stream settings of the table.
Parameter clientSideTimestamps :
Enables client-side timestamps for the table. By default, the setting is
disabled. You can enable client-side timestamps with the following option:
-
status: "enabled"
Parameter defaultTimeToLive :
The default Time to Live setting in seconds for the table.
For more information, see Setting the default TTL value for a table in the Amazon Keyspaces Developer Guide.
Parameter encryptionSpecification :
Modifies the encryption settings of the table. You can choose one of the
following KMS key (KMS key):
-
type:AWS_OWNED_KMS_KEY- This key is owned by Amazon Keyspaces. -
type:CUSTOMER_MANAGED_KMS_KEY- This key is stored in your account and is created, owned, and managed by you. This option requires thekms_key_identifierof the KMS key in Amazon Resource Name (ARN) format as input.
AWS_OWNED_KMS_KEY.
For more information, see Encryption at rest in the Amazon Keyspaces Developer Guide.
Parameter pointInTimeRecovery :
Modifies the pointInTimeRecovery settings of the table. The
options are:
-
status=ENABLED -
status=DISABLED
status=DISABLED.
For more information, see Point-in-time recovery in the Amazon Keyspaces Developer Guide.
Parameter replicaSpecifications :
The Region specific settings of a multi-Regional table.
Parameter ttl :
Modifies Time to Live custom settings for the table. The options are:
-
status:enabled -
status:disabled
status:disabled. After ttl is
enabled, you can't disable it for the table.
For more information, see Expiring data by using Amazon Keyspaces Time to Live (TTL) in the Amazon Keyspaces Developer Guide.
Parameter warmThroughputSpecification :
Modifies the warm throughput settings for the table. You can update the
read and write capacity units to adjust the pre-provisioned throughput.
Implementation
Future<UpdateTableResponse> updateTable({
required String keyspaceName,
required String tableName,
List<ColumnDefinition>? addColumns,
AutoScalingSpecification? autoScalingSpecification,
CapacitySpecification? capacitySpecification,
CdcSpecification? cdcSpecification,
ClientSideTimestamps? clientSideTimestamps,
int? defaultTimeToLive,
EncryptionSpecification? encryptionSpecification,
PointInTimeRecovery? pointInTimeRecovery,
List<ReplicaSpecification>? replicaSpecifications,
TimeToLive? ttl,
WarmThroughputSpecification? warmThroughputSpecification,
}) async {
_s.validateNumRange(
'defaultTimeToLive',
defaultTimeToLive,
0,
630720000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'KeyspacesService.UpdateTable'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'keyspaceName': keyspaceName,
'tableName': tableName,
if (addColumns != null) 'addColumns': addColumns,
if (autoScalingSpecification != null)
'autoScalingSpecification': autoScalingSpecification,
if (capacitySpecification != null)
'capacitySpecification': capacitySpecification,
if (cdcSpecification != null) 'cdcSpecification': cdcSpecification,
if (clientSideTimestamps != null)
'clientSideTimestamps': clientSideTimestamps,
if (defaultTimeToLive != null) 'defaultTimeToLive': defaultTimeToLive,
if (encryptionSpecification != null)
'encryptionSpecification': encryptionSpecification,
if (pointInTimeRecovery != null)
'pointInTimeRecovery': pointInTimeRecovery,
if (replicaSpecifications != null)
'replicaSpecifications': replicaSpecifications,
if (ttl != null) 'ttl': ttl,
if (warmThroughputSpecification != null)
'warmThroughputSpecification': warmThroughputSpecification,
},
);
return UpdateTableResponse.fromJson(jsonResponse.body);
}