keyspaces_streams_2024_09_09 library
Classes
- AwsClientCredentials
- AWS credentials.
- KeyspacesStreams
- Amazon Keyspaces (for Apache Cassandra) change data capture (CDC) records change events for Amazon Keyspaces tables. The change events captured in a stream are time-ordered and de-duplicated write operations. Using stream data you can build event driven applications that incorporate near-real time change events from Amazon Keyspaces tables.