createStream method
Creates a Kinesis data stream. A stream captures and transports data records that are continuously emitted from different data sources or producers. Scale-out within a stream is explicitly supported by means of shards, which are uniquely identified groups of data records in a stream.
You can create your data stream using either on-demand or provisioned capacity mode. Data streams with an on-demand mode require no capacity planning and automatically scale to handle gigabytes of write and read throughput per minute. With the on-demand mode, Kinesis Data Streams automatically manages the shards in order to provide the necessary throughput.
If you'd still like to proactively scale your on-demand data stream’s
capacity, you can unlock the warm throughput feature for on-demand data
streams by enabling MinimumThroughputBillingCommitment for
your account. Once your account has
MinimumThroughputBillingCommitment enabled, you can specify
the warm throughput in MiB per second that your stream can support in
writes.
For the data streams with a provisioned mode, you must specify the number of shards for the data stream. Each shard can support reads up to five transactions per second, up to a maximum data read total of 2 MiB per second. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MiB per second. If the amount of data input increases or decreases, you can add or remove shards.
The stream name identifies the stream. The name is scoped to the Amazon Web Services account used by the application. It is also scoped by Amazon Web Services Region. That is, two streams in two different accounts can have the same name, and two streams in the same account, but in two different Regions, can have the same name.
CreateStream is an asynchronous operation. Upon receiving a
CreateStream request, Kinesis Data Streams immediately
returns and sets the stream status to CREATING. After the
stream is created, Kinesis Data Streams sets the stream status to
ACTIVE. You should perform read and write operations only on
an ACTIVE stream.
You receive a LimitExceededException when making a
CreateStream request when you try to do one of the following:
-
Have more than five streams in the
CREATINGstate at any point in time. - Create more shards than are authorized for your account.
You can use DescribeStreamSummary to check the stream status, which
is returned in StreamStatus.
CreateStream has a limit of five transactions per second per account.
You can add tags to the stream when making a CreateStream
request by setting the Tags parameter. If you pass the
Tags parameter, in addition to having the
kinesis:CreateStream permission, you must also have the
kinesis:AddTagsToStream permission for the stream that will
be created. The kinesis:TagResource permission won’t work to
tag streams on creation. Tags will take effect from the
CREATING status of the stream, but you can't make any updates
to the tags until the stream is in ACTIVE state.
May throw InvalidArgumentException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ValidationException.
Parameter streamName :
A name to identify the stream. The stream name is scoped to the Amazon Web
Services account used by the application that creates the stream. It is
also scoped by Amazon Web Services Region. That is, two streams in two
different Amazon Web Services accounts can have the same name. Two streams
in the same Amazon Web Services account but in two different Regions can
also have the same name.
Parameter maxRecordSizeInKiB :
The maximum record size of a single record in kibibyte (KiB) that you can
write to, and read from a stream.
Parameter shardCount :
The number of shards that the stream will use. The throughput of the
stream is a function of the number of shards; more shards are required for
greater provisioned throughput.
Parameter streamModeDetails :
Indicates the capacity mode of the data stream. Currently, in Kinesis Data
Streams, you can choose between an on-demand capacity mode and a
provisioned capacity mode for your data streams.
Parameter tags :
A set of up to 50 key-value pairs to use to create the tags. A tag
consists of a required key and an optional value.
Parameter warmThroughputMiBps :
The target warm throughput in MB/s that the stream should be scaled to
handle. This represents the throughput capacity that will be immediately
available for write operations.
Implementation
Future<void> createStream({
required String streamName,
int? maxRecordSizeInKiB,
int? shardCount,
StreamModeDetails? streamModeDetails,
Map<String, String>? tags,
int? warmThroughputMiBps,
}) async {
_s.validateNumRange(
'maxRecordSizeInKiB',
maxRecordSizeInKiB,
1024,
10240,
);
_s.validateNumRange(
'shardCount',
shardCount,
1,
1152921504606846976,
);
_s.validateNumRange(
'warmThroughputMiBps',
warmThroughputMiBps,
0,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Kinesis_20131202.CreateStream'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'StreamName': streamName,
if (maxRecordSizeInKiB != null)
'MaxRecordSizeInKiB': maxRecordSizeInKiB,
if (shardCount != null) 'ShardCount': shardCount,
if (streamModeDetails != null) 'StreamModeDetails': streamModeDetails,
if (tags != null) 'Tags': tags,
if (warmThroughputMiBps != null)
'WarmThroughputMiBps': warmThroughputMiBps,
},
);
}