listShards method

Future<ListShardsOutput> listShards({
  1. String? exclusiveStartShardId,
  2. int? maxResults,
  3. String? nextToken,
  4. ShardFilter? shardFilter,
  5. String? streamARN,
  6. DateTime? streamCreationTimestamp,
  7. String? streamId,
  8. String? streamName,
})

Lists the shards in a stream and provides information about each shard. This operation has a limit of 1000 transactions per second per data stream. This action does not list expired shards. For information about expired shards, see Data Routing, Data Persistence, and Shard State after a Reshard.

May throw AccessDeniedException. May throw ExpiredNextTokenException. May throw InvalidArgumentException. May throw LimitExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter exclusiveStartShardId : Specify this parameter to indicate that you want to list the shards starting with the shard whose ID immediately follows ExclusiveStartShardId.

If you don't specify this parameter, the default behavior is for ListShards to list the shards starting with the first one in the stream.

You cannot specify this parameter if you specify NextToken.

Parameter maxResults : The maximum number of shards to return in a single call to ListShards. The maximum number of shards to return in a single call. The default value is 1000. If you specify a value greater than 1000, at most 1000 results are returned.

When the number of shards to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListShards to list the next set of shards.

Parameter nextToken : When the number of shards in the data stream is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of shards in the data stream, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListShards to list the next set of shards.

Don't specify StreamName or StreamCreationTimestamp if you specify NextToken because the latter unambiguously identifies the stream.

You can optionally specify a value for the MaxResults parameter when you specify NextToken. If you specify a MaxResults value that is less than the number of shards that the operation returns if you don't specify MaxResults, the response will contain a new NextToken value. You can use the new NextToken value in a subsequent call to the ListShards operation.

Parameter shardFilter : Enables you to filter out the response of the ListShards API. You can only specify one filter at a time.

If you use the ShardFilter parameter when invoking the ListShards API, the Type is the required property and must be specified. If you specify the AT_TRIM_HORIZON, FROM_TRIM_HORIZON, or AT_LATEST types, you do not need to specify either the ShardId or the Timestamp optional properties.

If you specify the AFTER_SHARD_ID type, you must also provide the value for the optional ShardId property. The ShardId property is identical in fuctionality to the ExclusiveStartShardId parameter of the ListShards API. When ShardId property is specified, the response includes the shards starting with the shard whose ID immediately follows the ShardId that you provided.

If you specify the AT_TIMESTAMP or FROM_TIMESTAMP_ID type, you must also provide the value for the optional Timestamp property. If you specify the AT_TIMESTAMP type, then all shards that were open at the provided timestamp are returned. If you specify the FROM_TIMESTAMP type, then all shards starting from the provided timestamp to TIP are returned.

Parameter streamARN : The ARN of the stream.

Parameter streamCreationTimestamp : Specify this input parameter to distinguish data streams that have the same name. For example, if you create a data stream and then delete it, and you later create another data stream with the same name, you can use this input parameter to specify which of the two streams you want to list the shards for.

You cannot specify this parameter if you specify the NextToken parameter.

Parameter streamId : Not Implemented. Reserved for future use.

Parameter streamName : The name of the data stream whose shards you want to list.

You cannot specify this parameter if you specify the NextToken parameter.

Implementation

Future<ListShardsOutput> listShards({
  String? exclusiveStartShardId,
  int? maxResults,
  String? nextToken,
  ShardFilter? shardFilter,
  String? streamARN,
  DateTime? streamCreationTimestamp,
  String? streamId,
  String? streamName,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    10000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Kinesis_20131202.ListShards'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (exclusiveStartShardId != null)
        'ExclusiveStartShardId': exclusiveStartShardId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (shardFilter != null) 'ShardFilter': shardFilter,
      if (streamARN != null) 'StreamARN': streamARN,
      if (streamCreationTimestamp != null)
        'StreamCreationTimestamp':
            unixTimestampToJson(streamCreationTimestamp),
      if (streamId != null) 'StreamId': streamId,
      if (streamName != null) 'StreamName': streamName,
    },
  );

  return ListShardsOutput.fromJson(jsonResponse.body);
}