listStreams method

Future<ListStreamsOutput> listStreams({
  1. String? exclusiveStartStreamName,
  2. int? limit,
  3. String? nextToken,
})

Lists your Kinesis data streams.

The number of streams may be too large to return from a single call to ListStreams. You can limit the number of returned streams using the Limit parameter. If you do not specify a value for the Limit parameter, Kinesis Data Streams uses the default limit, which is currently 100.

You can detect if there are more streams available to list by using the HasMoreStreams flag from the returned output. If there are more streams available, you can request more streams by using the name of the last stream returned by the ListStreams request in the ExclusiveStartStreamName parameter in a subsequent request to ListStreams. The group of stream names returned by the subsequent request is then added to the list. You can continue this process until all the stream names have been collected in the list.

ListStreams has a limit of five transactions per second per account.

May throw ExpiredNextTokenException. May throw InvalidArgumentException. May throw LimitExceededException.

Parameter exclusiveStartStreamName : The name of the stream to start the list with.

Parameter limit : The maximum number of streams to list. The default value is 100. If you specify a value greater than 100, at most 100 results are returned.

Parameter nextToken :

Implementation

Future<ListStreamsOutput> listStreams({
  String? exclusiveStartStreamName,
  int? limit,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    10000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Kinesis_20131202.ListStreams'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (exclusiveStartStreamName != null)
        'ExclusiveStartStreamName': exclusiveStartStreamName,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListStreamsOutput.fromJson(jsonResponse.body);
}