splitShard method
Splits a shard into two new shards in the Kinesis data stream, to increase
the stream's capacity to ingest and transport data.
SplitShard is called when there is a need to increase the
overall capacity of a stream because of an expected increase in the volume
of data records being ingested. This API is only supported for the data
streams with the provisioned capacity mode.
You can also use SplitShard when a shard appears to be
approaching its maximum utilization; for example, the producers sending
data into the specific shard are suddenly sending more than previously
anticipated. You can also call SplitShard to increase stream
capacity, so that more Kinesis Data Streams applications can
simultaneously read data from the stream for real-time processing.
You must specify the shard to be split and the new hash key, which is the position in the shard where the shard gets split in two. In many cases, the new hash key might be the average of the beginning and ending hash key, but it can be any hash key value in the range being mapped into the shard. For more information, see Split a Shard in the Amazon Kinesis Data Streams Developer Guide.
You can use DescribeStreamSummary and the ListShards APIs to
determine the shard ID and hash key values for the
ShardToSplit and NewStartingHashKey parameters
that are specified in the SplitShard request.
SplitShard is an asynchronous operation. Upon receiving a
SplitShard request, Kinesis Data Streams immediately returns
a response and sets the stream status to UPDATING. After the
operation is completed, Kinesis Data Streams sets the stream status to
ACTIVE. Read and write operations continue to work while the
stream is in the UPDATING state.
You can use DescribeStreamSummary to check the status of the
stream, which is returned in StreamStatus. If the stream is
in the ACTIVE state, you can call SplitShard.
If the specified stream does not exist, DescribeStreamSummary
returns a ResourceNotFoundException. If you try to create
more shards than are authorized for your account, you receive a
LimitExceededException.
For the default shard limit for an Amazon Web Services account, see Kinesis Data Streams Limits in the Amazon Kinesis Data Streams Developer Guide. To increase this limit, contact Amazon Web Services Support.
If you try to operate on too many streams simultaneously using
CreateStream, DeleteStream, MergeShards, and/or
SplitShard, you receive a LimitExceededException.
SplitShard has a limit of five transactions per second per
account.
May throw AccessDeniedException.
May throw InvalidArgumentException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter newStartingHashKey :
A hash key value for the starting hash key of one of the child shards
created by the split. The hash key range for a given shard constitutes a
set of ordered contiguous positive integers. The value for
NewStartingHashKey must be in the range of hash keys being
mapped into the shard. The NewStartingHashKey hash key value
and all higher hash key values in hash key range are distributed to one of
the child shards. All the lower hash key values in the range are
distributed to the other child shard.
Parameter shardToSplit :
The shard ID of the shard to split.
Parameter streamARN :
The ARN of the stream.
Parameter streamId :
Not Implemented. Reserved for future use.
Parameter streamName :
The name of the stream for the shard split.
Implementation
Future<void> splitShard({
required String newStartingHashKey,
required String shardToSplit,
String? streamARN,
String? streamId,
String? streamName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Kinesis_20131202.SplitShard'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'NewStartingHashKey': newStartingHashKey,
'ShardToSplit': shardToSplit,
if (streamARN != null) 'StreamARN': streamARN,
if (streamId != null) 'StreamId': streamId,
if (streamName != null) 'StreamName': streamName,
},
);
}