updateMaxRecordSize method

Future<void> updateMaxRecordSize({
  1. required int maxRecordSizeInKiB,
  2. String? streamARN,
  3. String? streamId,
})

This allows you to update the MaxRecordSize of a single record that you can write to, and read from a stream. You can ingest and digest single records up to 10240 KiB.

May throw AccessDeniedException. May throw InvalidArgumentException. May throw LimitExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter maxRecordSizeInKiB : The maximum record size of a single record in KiB that you can write to, and read from a stream. Specify a value between 1024 and 10240 KiB (1 to 10 MiB). If you specify a value that is out of this range, UpdateMaxRecordSize sends back an ValidationException message.

Parameter streamARN : The Amazon Resource Name (ARN) of the stream for the MaxRecordSize update.

Parameter streamId : Not Implemented. Reserved for future use.

Implementation

Future<void> updateMaxRecordSize({
  required int maxRecordSizeInKiB,
  String? streamARN,
  String? streamId,
}) async {
  _s.validateNumRange(
    'maxRecordSizeInKiB',
    maxRecordSizeInKiB,
    1024,
    10240,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Kinesis_20131202.UpdateMaxRecordSize'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MaxRecordSizeInKiB': maxRecordSizeInKiB,
      if (streamARN != null) 'StreamARN': streamARN,
      if (streamId != null) 'StreamId': streamId,
    },
  );
}