updateShardCount method
Updates the shard count of the specified stream to the specified number of
shards. This API is only supported for the data streams with the
provisioned capacity mode.
Updating the shard count is an asynchronous operation. Upon receiving the
request, Kinesis Data Streams returns immediately and sets the status of
the stream to UPDATING. After the update is complete, Kinesis
Data Streams sets the status of the stream back to ACTIVE.
Depending on the size of the stream, the scaling action could take a few
minutes to complete. You can continue to read and write data to your
stream while its status is UPDATING.
To update the shard count, Kinesis Data Streams performs splits or merges on individual shards. This can cause short-lived shards to be created, in addition to the final shards. These short-lived shards count towards your total shard limit for your account in the Region.
When using this operation, we recommend that you specify a target shard count that is a multiple of 25% (25%, 50%, 75%, 100%). You can specify any target value within your shard limit. However, if you specify a target that isn't a multiple of 25%, the scaling action might take longer to complete.
This operation has the following default limits. By default, you cannot do the following:
- Scale more than ten times per rolling 24-hour period per stream
- Scale up to more than double your current shard count for a stream
- Scale down below half your current shard count for a stream
- Scale up to more than 10000 shards in a stream
- Scale a stream with more than 10000 shards down unless the result is less than 10000 shards
- Scale up to more than the shard limit for your account
- Make over 10 TPS. TPS over 10 will trigger the LimitExceededException
May throw AccessDeniedException.
May throw InvalidArgumentException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter scalingType :
The scaling type. Uniform scaling creates shards of equal size.
Parameter targetShardCount :
The new number of shards. This value has the following default limits. By
default, you cannot do the following:
- Set this value to more than double your current shard count for a stream.
- Set this value below half your current shard count for a stream.
- Set this value to more than 10000 shards in a stream (the default limit for shard count per stream is 10000 per account per region), unless you request a limit increase.
- Scale a stream with more than 10000 shards down unless you set this value to less than 10000 shards.
Parameter streamARN :
The ARN of the stream.
Parameter streamId :
Not Implemented. Reserved for future use.
Parameter streamName :
The name of the stream.
Implementation
Future<UpdateShardCountOutput> updateShardCount({
required ScalingType scalingType,
required int targetShardCount,
String? streamARN,
String? streamId,
String? streamName,
}) async {
_s.validateNumRange(
'targetShardCount',
targetShardCount,
1,
1152921504606846976,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Kinesis_20131202.UpdateShardCount'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ScalingType': scalingType.value,
'TargetShardCount': targetShardCount,
if (streamARN != null) 'StreamARN': streamARN,
if (streamId != null) 'StreamId': streamId,
if (streamName != null) 'StreamName': streamName,
},
);
return UpdateShardCountOutput.fromJson(jsonResponse.body);
}