addApplicationInput method
You can add a streaming source either when you create an application or you can use this operation to add a streaming source after you create an application. For more information, see CreateApplication.
Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.
This operation requires permissions to perform the
kinesisanalytics:AddApplicationInput action.
May throw CodeValidationException.
May throw ConcurrentModificationException.
May throw InvalidArgumentException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw UnsupportedOperationException.
Parameter applicationName :
Name of your existing Amazon Kinesis Analytics application to which you
want to add the streaming source.
Parameter currentApplicationVersionId :
Current version of your Amazon Kinesis Analytics application. You can use
the DescribeApplication
operation to find the current application version.
Parameter input :
The Input
to add.
Implementation
Future<void> addApplicationInput({
required String applicationName,
required int currentApplicationVersionId,
required Input input,
}) async {
_s.validateNumRange(
'currentApplicationVersionId',
currentApplicationVersionId,
1,
999999999,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'KinesisAnalytics_20150814.AddApplicationInput'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationName': applicationName,
'CurrentApplicationVersionId': currentApplicationVersionId,
'Input': input,
},
);
}