deleteApplicationInputProcessingConfiguration method
Deletes an InputProcessingConfiguration
from an input.
May throw ConcurrentModificationException.
May throw InvalidArgumentException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw UnsupportedOperationException.
Parameter applicationName :
The Kinesis Analytics application name.
Parameter currentApplicationVersionId :
The version ID of the Kinesis Analytics application.
Parameter inputId :
The ID of the input configuration from which to delete the input
processing configuration. You can get a list of the input IDs for an
application by using the DescribeApplication
operation.
Implementation
Future<void> deleteApplicationInputProcessingConfiguration({
required String applicationName,
required int currentApplicationVersionId,
required String inputId,
}) async {
_s.validateNumRange(
'currentApplicationVersionId',
currentApplicationVersionId,
1,
999999999,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'KinesisAnalytics_20150814.DeleteApplicationInputProcessingConfiguration'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationName': applicationName,
'CurrentApplicationVersionId': currentApplicationVersionId,
'InputId': inputId,
},
);
}