KinesisAnalyticsV2 class

Amazon Managed Service for Apache Flink is a fully managed service that you can use to process and analyze streaming data using Java, Python, SQL, or Scala. The service enables you to quickly author and run Java, SQL, or Scala code against streaming sources to perform time series analytics, feed real-time dashboards, and create real-time metrics.

Constructors

KinesisAnalyticsV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addApplicationCloudWatchLoggingOption({required String applicationName, required CloudWatchLoggingOption cloudWatchLoggingOption, String? conditionalToken, int? currentApplicationVersionId}) Future<AddApplicationCloudWatchLoggingOptionResponse>
Adds an Amazon CloudWatch log stream to monitor application configuration errors.
addApplicationInput({required String applicationName, required int currentApplicationVersionId, required Input input}) Future<AddApplicationInputResponse>
Adds a streaming source to your SQL-based Kinesis Data Analytics application.
addApplicationInputProcessingConfiguration({required String applicationName, required int currentApplicationVersionId, required String inputId, required InputProcessingConfiguration inputProcessingConfiguration}) Future<AddApplicationInputProcessingConfigurationResponse>
Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application. An input processor pre-processes records on the input stream before the application's SQL code executes. Currently, the only input processor available is Amazon Lambda.
addApplicationOutput({required String applicationName, required int currentApplicationVersionId, required Output output}) Future<AddApplicationOutputResponse>
Adds an external destination to your SQL-based Kinesis Data Analytics application.
addApplicationReferenceDataSource({required String applicationName, required int currentApplicationVersionId, required ReferenceDataSource referenceDataSource}) Future<AddApplicationReferenceDataSourceResponse>
Adds a reference data source to an existing SQL-based Kinesis Data Analytics application.
addApplicationVpcConfiguration({required String applicationName, required VpcConfiguration vpcConfiguration, String? conditionalToken, int? currentApplicationVersionId}) Future<AddApplicationVpcConfigurationResponse>
Adds a Virtual Private Cloud (VPC) configuration to the application. Applications can use VPCs to store and access resources securely.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApplication({required String applicationName, required RuntimeEnvironment runtimeEnvironment, required String serviceExecutionRole, ApplicationConfiguration? applicationConfiguration, String? applicationDescription, ApplicationMode? applicationMode, List<CloudWatchLoggingOption>? cloudWatchLoggingOptions, List<Tag>? tags}) Future<CreateApplicationResponse>
Creates a Managed Service for Apache Flink application. For information about creating a Managed Service for Apache Flink application, see Creating an Application.
createApplicationPresignedUrl({required String applicationName, required UrlType urlType, int? sessionExpirationDurationInSeconds}) Future<CreateApplicationPresignedUrlResponse>
Creates and returns a URL that you can use to connect to an application's extension.
createApplicationSnapshot({required String applicationName, required String snapshotName}) Future<void>
Creates a snapshot of the application's state data.
deleteApplication({required String applicationName, required DateTime createTimestamp}) Future<void>
Deletes the specified application. Managed Service for Apache Flink halts application execution and deletes the application.
deleteApplicationCloudWatchLoggingOption({required String applicationName, required String cloudWatchLoggingOptionId, String? conditionalToken, int? currentApplicationVersionId}) Future<DeleteApplicationCloudWatchLoggingOptionResponse>
Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application.
deleteApplicationInputProcessingConfiguration({required String applicationName, required int currentApplicationVersionId, required String inputId}) Future<DeleteApplicationInputProcessingConfigurationResponse>
Deletes an InputProcessingConfiguration from an input.
deleteApplicationOutput({required String applicationName, required int currentApplicationVersionId, required String outputId}) Future<DeleteApplicationOutputResponse>
Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application's configuration. Kinesis Data Analytics will no longer write data from the corresponding in-application stream to the external output destination.
deleteApplicationReferenceDataSource({required String applicationName, required int currentApplicationVersionId, required String referenceId}) Future<DeleteApplicationReferenceDataSourceResponse>
Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application's configuration.
deleteApplicationSnapshot({required String applicationName, required DateTime snapshotCreationTimestamp, required String snapshotName}) Future<void>
Deletes a snapshot of application state.
deleteApplicationVpcConfiguration({required String applicationName, required String vpcConfigurationId, String? conditionalToken, int? currentApplicationVersionId}) Future<DeleteApplicationVpcConfigurationResponse>
Removes a VPC configuration from a Managed Service for Apache Flink application.
describeApplication({required String applicationName, bool? includeAdditionalDetails}) Future<DescribeApplicationResponse>
Returns information about a specific Managed Service for Apache Flink application.
describeApplicationOperation({required String applicationName, required String operationId}) Future<DescribeApplicationOperationResponse>
Provides a detailed description of a specified application operation. To see a list of all the operations of an application, invoke the ListApplicationOperations operation.
describeApplicationSnapshot({required String applicationName, required String snapshotName}) Future<DescribeApplicationSnapshotResponse>
Returns information about a snapshot of application state data.
describeApplicationVersion({required String applicationName, required int applicationVersionId}) Future<DescribeApplicationVersionResponse>
Provides a detailed description of a specified version of the application. To see a list of all the versions of an application, invoke the ListApplicationVersions operation.
discoverInputSchema({required String serviceExecutionRole, InputProcessingConfiguration? inputProcessingConfiguration, InputStartingPositionConfiguration? inputStartingPositionConfiguration, String? resourceARN, S3Configuration? s3Configuration}) Future<DiscoverInputSchemaResponse>
Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object. In the response, the operation returns the inferred schema and also the sample records that the operation used to infer the schema.
listApplicationOperations({required String applicationName, int? limit, String? nextToken, String? operation, OperationStatus? operationStatus}) Future<ListApplicationOperationsResponse>
Lists all the operations performed for the specified application such as UpdateApplication, StartApplication etc. The response also includes a summary of the operation.
listApplications({int? limit, String? nextToken}) Future<ListApplicationsResponse>
Returns a list of Managed Service for Apache Flink applications in your account. For each application, the response includes the application name, Amazon Resource Name (ARN), and status.
listApplicationSnapshots({required String applicationName, int? limit, String? nextToken}) Future<ListApplicationSnapshotsResponse>
Lists information about the current application snapshots.
listApplicationVersions({required String applicationName, int? limit, String? nextToken}) Future<ListApplicationVersionsResponse>
Lists all the versions for the specified application, including versions that were rolled back. The response also includes a summary of the configuration associated with each version.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
Retrieves the list of key-value tags assigned to the application. For more information, see Using Tagging.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rollbackApplication({required String applicationName, required int currentApplicationVersionId}) Future<RollbackApplicationResponse>
Reverts the application to the previous running version. You can roll back an application if you suspect it is stuck in a transient status or in the running status.
startApplication({required String applicationName, RunConfiguration? runConfiguration}) Future<StartApplicationResponse>
Starts the specified Managed Service for Apache Flink application. After creating an application, you must exclusively call this operation to start your application.
stopApplication({required String applicationName, bool? force}) Future<StopApplicationResponse>
Stops the application from processing data. You can stop an application only if it is in the running status, unless you set the Force parameter to true.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Adds one or more key-value tags to a Managed Service for Apache Flink application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50. For more information, see Using Tagging.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes one or more tags from a Managed Service for Apache Flink application. For more information, see Using Tagging.
updateApplication({required String applicationName, ApplicationConfigurationUpdate? applicationConfigurationUpdate, List<CloudWatchLoggingOptionUpdate>? cloudWatchLoggingOptionUpdates, String? conditionalToken, int? currentApplicationVersionId, RunConfigurationUpdate? runConfigurationUpdate, RuntimeEnvironment? runtimeEnvironmentUpdate, String? serviceExecutionRoleUpdate}) Future<UpdateApplicationResponse>
Updates an existing Managed Service for Apache Flink application. Using this operation, you can update application code, input configuration, and output configuration.
updateApplicationMaintenanceConfiguration({required ApplicationMaintenanceConfigurationUpdate applicationMaintenanceConfigurationUpdate, required String applicationName}) Future<UpdateApplicationMaintenanceConfigurationResponse>
Updates the maintenance configuration of the Managed Service for Apache Flink application.

Operators

operator ==(Object other) bool
The equality operator.
inherited