deleteApplicationInputProcessingConfiguration method
Deletes an InputProcessingConfiguration from an input.
May throw ConcurrentModificationException.
May throw InvalidArgumentException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter applicationName :
The name of the application.
Parameter currentApplicationVersionId :
The application version. You can use the DescribeApplication
operation to get the current application version. If the version specified
is not the current version, the
ConcurrentModificationException is returned.
Parameter inputId :
The ID of the input configuration from which to delete the input
processing configuration. You can get a list of the input IDs for an
application by using the DescribeApplication operation.
Implementation
Future<DeleteApplicationInputProcessingConfigurationResponse>
deleteApplicationInputProcessingConfiguration({
required String applicationName,
required int currentApplicationVersionId,
required String inputId,
}) async {
_s.validateNumRange(
'currentApplicationVersionId',
currentApplicationVersionId,
1,
999999999,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'KinesisAnalytics_20180523.DeleteApplicationInputProcessingConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationName': applicationName,
'CurrentApplicationVersionId': currentApplicationVersionId,
'InputId': inputId,
},
);
return DeleteApplicationInputProcessingConfigurationResponse.fromJson(
jsonResponse.body);
}