deleteApplicationVpcConfiguration method
Removes a VPC configuration from a Managed Service for Apache Flink application.
May throw ConcurrentModificationException.
May throw InvalidApplicationConfigurationException.
May throw InvalidArgumentException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter applicationName :
The name of an existing application.
Parameter vpcConfigurationId :
The ID of the VPC configuration to delete.
Parameter conditionalToken :
A value you use to implement strong concurrency for application updates.
You must provide the CurrentApplicationVersionId or the
ConditionalToken. You get the application's current
ConditionalToken using DescribeApplication. For better
concurrency support, use the ConditionalToken parameter
instead of CurrentApplicationVersionId.
Parameter currentApplicationVersionId :
The current application version ID. You must provide the
CurrentApplicationVersionId or the
ConditionalToken. You can retrieve the application version ID
using DescribeApplication. For better concurrency support, use the
ConditionalToken parameter instead of
CurrentApplicationVersionId.
Implementation
Future<DeleteApplicationVpcConfigurationResponse>
deleteApplicationVpcConfiguration({
required String applicationName,
required String vpcConfigurationId,
String? conditionalToken,
int? currentApplicationVersionId,
}) async {
_s.validateNumRange(
'currentApplicationVersionId',
currentApplicationVersionId,
1,
999999999,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'KinesisAnalytics_20180523.DeleteApplicationVpcConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationName': applicationName,
'VpcConfigurationId': vpcConfigurationId,
if (conditionalToken != null) 'ConditionalToken': conditionalToken,
if (currentApplicationVersionId != null)
'CurrentApplicationVersionId': currentApplicationVersionId,
},
);
return DeleteApplicationVpcConfigurationResponse.fromJson(
jsonResponse.body);
}