describeApplicationOperation method
Provides a detailed description of a specified application operation. To see a list of all the operations of an application, invoke the ListApplicationOperations operation.
May throw InvalidArgumentException.
May throw ResourceNotFoundException.
May throw UnsupportedOperationException.
Implementation
Future<DescribeApplicationOperationResponse> describeApplicationOperation({
required String applicationName,
required String operationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'KinesisAnalytics_20180523.DescribeApplicationOperation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationName': applicationName,
'OperationId': operationId,
},
);
return DescribeApplicationOperationResponse.fromJson(jsonResponse.body);
}