describeApplicationVersion method

Future<DescribeApplicationVersionResponse> describeApplicationVersion({
  1. required String applicationName,
  2. required int applicationVersionId,
})

Provides a detailed description of a specified version of the application. To see a list of all the versions of an application, invoke the ListApplicationVersions operation.

May throw InvalidArgumentException. May throw ResourceNotFoundException. May throw UnsupportedOperationException.

Parameter applicationName : The name of the application for which you want to get the version description.

Parameter applicationVersionId : The ID of the application version for which you want to get the description.

Implementation

Future<DescribeApplicationVersionResponse> describeApplicationVersion({
  required String applicationName,
  required int applicationVersionId,
}) async {
  _s.validateNumRange(
    'applicationVersionId',
    applicationVersionId,
    1,
    999999999,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'KinesisAnalytics_20180523.DescribeApplicationVersion'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationName': applicationName,
      'ApplicationVersionId': applicationVersionId,
    },
  );

  return DescribeApplicationVersionResponse.fromJson(jsonResponse.body);
}