KinesisVideo class

Constructors

KinesisVideo({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createSignalingChannel({required String channelName, ChannelType? channelType, SingleMasterConfiguration? singleMasterConfiguration, List<Tag>? tags}) Future<CreateSignalingChannelOutput>
Creates a signaling channel.
createStream({required String streamName, int? dataRetentionInHours, String? deviceName, String? kmsKeyId, String? mediaType, StreamStorageConfiguration? streamStorageConfiguration, Map<String, String>? tags}) Future<CreateStreamOutput>
Creates a new Kinesis video stream.
deleteEdgeConfiguration({String? streamARN, String? streamName}) Future<void>
An asynchronous API that deletes a stream’s existing edge configuration, as well as the corresponding media from the Edge Agent.
deleteSignalingChannel({required String channelARN, String? currentVersion}) Future<void>
Deletes a specified signaling channel. DeleteSignalingChannel is an asynchronous operation. If you don't specify the channel's current version, the most recent version is deleted.
deleteStream({required String streamARN, String? currentVersion}) Future<void>
Deletes a Kinesis video stream and the data contained in the stream.
describeEdgeConfiguration({String? streamARN, String? streamName}) Future<DescribeEdgeConfigurationOutput>
Describes a stream’s edge configuration that was set using the StartEdgeConfigurationUpdate API and the latest status of the edge agent's recorder and uploader jobs. Use this API to get the status of the configuration to determine if the configuration is in sync with the Edge Agent. Use this API to evaluate the health of the Edge Agent.
describeImageGenerationConfiguration({String? streamARN, String? streamName}) Future<DescribeImageGenerationConfigurationOutput>
Gets the ImageGenerationConfiguration for a given Kinesis video stream.
describeMappedResourceConfiguration({int? maxResults, String? nextToken, String? streamARN, String? streamName}) Future<DescribeMappedResourceConfigurationOutput>
Returns the most current information about the stream. The streamName or streamARN should be provided in the input.
describeMediaStorageConfiguration({String? channelARN, String? channelName}) Future<DescribeMediaStorageConfigurationOutput>
Returns the most current information about the channel. Specify the ChannelName or ChannelARN in the input.
describeNotificationConfiguration({String? streamARN, String? streamName}) Future<DescribeNotificationConfigurationOutput>
Gets the NotificationConfiguration for a given Kinesis video stream.
describeSignalingChannel({String? channelARN, String? channelName}) Future<DescribeSignalingChannelOutput>
Returns the most current information about the signaling channel. You must specify either the name or the Amazon Resource Name (ARN) of the channel that you want to describe.
describeStream({String? streamARN, String? streamName}) Future<DescribeStreamOutput>
Returns the most current information about the specified stream. You must specify either the StreamName or the StreamARN.
describeStreamStorageConfiguration({String? streamARN, String? streamName}) Future<DescribeStreamStorageConfigurationOutput>
Retrieves the current storage configuration for the specified Kinesis video stream.
getDataEndpoint({required APIName aPIName, String? streamARN, String? streamName}) Future<GetDataEndpointOutput>
Gets an endpoint for a specified stream for either reading or writing. Use this endpoint in your application to read from the specified stream (using the GetMedia or GetMediaForFragmentList operations) or write to it (using the PutMedia operation). In the request, specify the stream either by StreamName or StreamARN.
getSignalingChannelEndpoint({required String channelARN, SingleMasterChannelEndpointConfiguration? singleMasterChannelEndpointConfiguration}) Future<GetSignalingChannelEndpointOutput>
Provides an endpoint for the specified signaling channel to send and receive messages. This API uses the SingleMasterChannelEndpointConfiguration input parameter, which consists of the Protocols and Role properties.
listEdgeAgentConfigurations({required String hubDeviceArn, int? maxResults, String? nextToken}) Future<ListEdgeAgentConfigurationsOutput>
Returns an array of edge configurations associated with the specified Edge Agent.
listSignalingChannels({ChannelNameCondition? channelNameCondition, int? maxResults, String? nextToken}) Future<ListSignalingChannelsOutput>
Returns an array of ChannelInfo objects. Each object describes a signaling channel. To retrieve only those channels that satisfy a specific condition, you can specify a ChannelNameCondition.
listStreams({int? maxResults, String? nextToken, StreamNameCondition? streamNameCondition}) Future<ListStreamsOutput>
Returns an array of StreamInfo objects. Each object describes a stream. To retrieve only streams that satisfy a specific condition, you can specify a StreamNameCondition.
listTagsForResource({required String resourceARN, String? nextToken}) Future<ListTagsForResourceOutput>
Returns a list of tags associated with the specified signaling channel.
listTagsForStream({String? nextToken, String? streamARN, String? streamName}) Future<ListTagsForStreamOutput>
Returns a list of tags associated with the specified stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startEdgeConfigurationUpdate({required EdgeConfig edgeConfig, String? streamARN, String? streamName}) Future<StartEdgeConfigurationUpdateOutput>
An asynchronous API that updates a stream’s existing edge configuration. The Kinesis Video Stream will sync the stream’s edge configuration with the Edge Agent IoT Greengrass component that runs on an IoT Hub Device, setup at your premise. The time to sync can vary and depends on the connectivity of the Hub Device. The SyncStatus will be updated as the edge configuration is acknowledged, and synced with the Edge Agent.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Adds one or more tags to a signaling channel. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the Billing and Cost Management and Cost Management User Guide.
tagStream({required Map<String, String> tags, String? streamARN, String? streamName}) Future<void>
Adds one or more tags to a stream. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the Billing and Cost Management and Cost Management User Guide.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeyList}) Future<void>
Removes one or more tags from a signaling channel. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored.
untagStream({required List<String> tagKeyList, String? streamARN, String? streamName}) Future<void>
Removes one or more tags from a stream. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored.
updateDataRetention({required String currentVersion, required int dataRetentionChangeInHours, required UpdateDataRetentionOperation operation, String? streamARN, String? streamName}) Future<void>
Increases or decreases the stream's data retention period by the value that you specify. To indicate whether you want to increase or decrease the data retention period, specify the Operation parameter in the request body. In the request, you must specify either the StreamName or the StreamARN.
updateImageGenerationConfiguration({ImageGenerationConfiguration? imageGenerationConfiguration, String? streamARN, String? streamName}) Future<void>
Updates the StreamInfo and ImageProcessingConfiguration fields.
updateMediaStorageConfiguration({required String channelARN, required MediaStorageConfiguration mediaStorageConfiguration}) Future<void>
Associates a SignalingChannel to a stream to store the media. There are two signaling modes that you can specify :
updateNotificationConfiguration({NotificationConfiguration? notificationConfiguration, String? streamARN, String? streamName}) Future<void>
Updates the notification information for a stream.
updateSignalingChannel({required String channelARN, required String currentVersion, SingleMasterConfiguration? singleMasterConfiguration}) Future<void>
Updates the existing signaling channel. This is an asynchronous operation and takes time to complete.
updateStream({required String currentVersion, String? deviceName, String? mediaType, String? streamARN, String? streamName}) Future<void>
Updates stream metadata, such as the device name and media type.
updateStreamStorageConfiguration({required String currentVersion, required StreamStorageConfiguration streamStorageConfiguration, String? streamARN, String? streamName}) Future<void>
Updates the storage configuration for an existing Kinesis video stream.

Operators

operator ==(Object other) bool
The equality operator.
inherited