describeNotificationConfiguration method

Future<DescribeNotificationConfigurationOutput> describeNotificationConfiguration({
  1. String? streamARN,
  2. String? streamName,
})

Gets the NotificationConfiguration for a given Kinesis video stream.

May throw AccessDeniedException. May throw ClientLimitExceededException. May throw InvalidArgumentException. May throw ResourceNotFoundException.

Parameter streamARN : The Amazon Resource Name (ARN) of the Kinesis video stream from where you want to retrieve the notification configuration. You must specify either the StreamName or the StreamARN.

Parameter streamName : The name of the stream from which to retrieve the notification configuration. You must specify either the StreamName or the StreamARN.

Implementation

Future<DescribeNotificationConfigurationOutput>
    describeNotificationConfiguration({
  String? streamARN,
  String? streamName,
}) async {
  final $payload = <String, dynamic>{
    if (streamARN != null) 'StreamARN': streamARN,
    if (streamName != null) 'StreamName': streamName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/describeNotificationConfiguration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeNotificationConfigurationOutput.fromJson(response);
}