describeStreamStorageConfiguration method

Future<DescribeStreamStorageConfigurationOutput> describeStreamStorageConfiguration({
  1. String? streamARN,
  2. String? streamName,
})

Retrieves the current storage configuration for the specified Kinesis video stream.

In the request, you must specify either the StreamName or the StreamARN.

You must have permissions for the KinesisVideo:DescribeStreamStorageConfiguration action.

May throw AccessDeniedException. May throw ClientLimitExceededException. May throw InvalidArgumentException. May throw ResourceNotFoundException.

Parameter streamARN : The Amazon Resource Name (ARN) of the stream for which you want to retrieve the storage configuration.

Parameter streamName : The name of the stream for which you want to retrieve the storage configuration.

Implementation

Future<DescribeStreamStorageConfigurationOutput>
    describeStreamStorageConfiguration({
  String? streamARN,
  String? streamName,
}) async {
  final $payload = <String, dynamic>{
    if (streamARN != null) 'StreamARN': streamARN,
    if (streamName != null) 'StreamName': streamName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/describeStreamStorageConfiguration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeStreamStorageConfigurationOutput.fromJson(response);
}