listSignalingChannels method
Returns an array of ChannelInfo objects. Each object
describes a signaling channel. To retrieve only those channels that
satisfy a specific condition, you can specify a
ChannelNameCondition.
May throw AccessDeniedException.
May throw ClientLimitExceededException.
May throw InvalidArgumentException.
Parameter channelNameCondition :
Optional: Returns only the channels that satisfy a specific condition.
Parameter maxResults :
The maximum number of channels to return in the response. The default is
500.
Parameter nextToken :
If you specify this parameter, when the result of a
ListSignalingChannels operation is truncated, the call
returns the NextToken in the response. To get another batch
of channels, provide this token in your next request.
Implementation
Future<ListSignalingChannelsOutput> listSignalingChannels({
ChannelNameCondition? channelNameCondition,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
10000,
);
final $payload = <String, dynamic>{
if (channelNameCondition != null)
'ChannelNameCondition': channelNameCondition,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listSignalingChannels',
exceptionFnMap: _exceptionFns,
);
return ListSignalingChannelsOutput.fromJson(response);
}