updateImageGenerationConfiguration method

Future<void> updateImageGenerationConfiguration({
  1. ImageGenerationConfiguration? imageGenerationConfiguration,
  2. String? streamARN,
  3. String? streamName,
})

Updates the StreamInfo and ImageProcessingConfiguration fields.

May throw AccessDeniedException. May throw ClientLimitExceededException. May throw InvalidArgumentException. May throw NoDataRetentionException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter imageGenerationConfiguration : The structure that contains the information required for the KVS images delivery. If the structure is null, the configuration will be deleted from the stream.

Parameter streamARN : The Amazon Resource Name (ARN) of the Kinesis video stream from where you want to update the image generation configuration. You must specify either the StreamName or the StreamARN.

Parameter streamName : The name of the stream from which to update the image generation configuration. You must specify either the StreamName or the StreamARN.

Implementation

Future<void> updateImageGenerationConfiguration({
  ImageGenerationConfiguration? imageGenerationConfiguration,
  String? streamARN,
  String? streamName,
}) async {
  final $payload = <String, dynamic>{
    if (imageGenerationConfiguration != null)
      'ImageGenerationConfiguration': imageGenerationConfiguration,
    if (streamARN != null) 'StreamARN': streamARN,
    if (streamName != null) 'StreamName': streamName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/updateImageGenerationConfiguration',
    exceptionFnMap: _exceptionFns,
  );
}