updateSignalingChannel method

Future<void> updateSignalingChannel({
  1. required String channelARN,
  2. required String currentVersion,
  3. SingleMasterConfiguration? singleMasterConfiguration,
})

Updates the existing signaling channel. This is an asynchronous operation and takes time to complete.

If the MessageTtlSeconds value is updated (either increased or reduced), it only applies to new messages sent via this channel after it's been updated. Existing messages are still expired as per the previous MessageTtlSeconds value.

May throw AccessDeniedException. May throw ClientLimitExceededException. May throw InvalidArgumentException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw VersionMismatchException.

Parameter channelARN : The Amazon Resource Name (ARN) of the signaling channel that you want to update.

Parameter currentVersion : The current version of the signaling channel that you want to update.

Parameter singleMasterConfiguration : The structure containing the configuration for the SINGLE_MASTER type of the signaling channel that you want to update. This parameter and the channel message's time-to-live are required for channels with the SINGLE_MASTER channel type.

Implementation

Future<void> updateSignalingChannel({
  required String channelARN,
  required String currentVersion,
  SingleMasterConfiguration? singleMasterConfiguration,
}) async {
  final $payload = <String, dynamic>{
    'ChannelARN': channelARN,
    'CurrentVersion': currentVersion,
    if (singleMasterConfiguration != null)
      'SingleMasterConfiguration': singleMasterConfiguration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/updateSignalingChannel',
    exceptionFnMap: _exceptionFns,
  );
}