createGrant method
Adds a grant to a KMS key.
A grant is a policy instrument that allows Amazon Web Services principals to use KMS keys in cryptographic operations. It also can allow them to view a KMS key (DescribeKey) and create and manage grants. When authorizing access to a KMS key, grants are considered along with key policies and IAM policies. Grants are often used for temporary permissions because you can create one, use its permissions, and delete it without changing your key policies or IAM policies.
You can create a grant for an Amazon Web Services principal (IAM user, IAM
role, or Amazon Web Services account) by specifying the
GranteePrincipal parameter. You can also create a grant for
an Amazon Web Services service principal by specifying the
GranteeServicePrincipal parameter.
For detailed information about grants, including grant terminology, see Grants in KMS in the Key Management Service Developer Guide . For examples of creating grants in several programming languages, see Use CreateGrant with an Amazon Web Services SDK or CLI.
The CreateGrant operation returns a GrantToken
and a GrantId.
-
When you create, retire, or revoke a grant, there might be a brief delay,
usually less than five minutes, until the grant is available throughout
KMS. This state is known as eventual consistency. Once the grant
has achieved eventual consistency, the grantee principal can use the
permissions in the grant without identifying the grant.
However, to use the permissions in the grant immediately, use the
GrantTokenthatCreateGrantreturns. For details, see Using a grant token in the Key Management Service Developer Guide . -
The
CreateGrantoperation also returns aGrantId. You can use theGrantIdand a key identifier to identify the grant in the RetireGrant and RevokeGrant operations. To find the grant ID, use the ListGrants or ListRetirableGrants operations.
Cross-account use: Yes. To perform this operation on a KMS key in a
different Amazon Web Services account, specify the key ARN in the value of
the KeyId parameter.
Required permissions: kms:CreateGrant (key policy)
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw DisabledException.
May throw DryRunOperationException.
May throw InvalidArnException.
May throw InvalidGrantTokenException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter keyId :
Identifies the KMS key for the grant. The grant gives principals
permission to use this KMS key.
Specify the key ID or key ARN of the KMS key. To specify a KMS key in a different Amazon Web Services account, you must use the key ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Parameter operations :
A list of operations that the grant permits.
This list must include only operations that are permitted in a grant.
Also, the operation must be supported on the KMS key. For example, you
cannot create a grant for a symmetric encryption KMS key that allows the
Sign operation, or a grant for an asymmetric KMS key that allows
the GenerateDataKey operation. If you try, KMS returns a
ValidationError exception. For details, see Grant
operations in the Key Management Service Developer Guide.
Parameter constraints :
Specifies a grant constraint.
KMS supports the following grant constraints.
-
EncryptionContextEqualsandEncryptionContextSubset— These encryption context grant constraints allow the permissions in the grant only when the encryption context in the request matches (EncryptionContextEquals) or includes (EncryptionContextSubset) the encryption context specified in the constraint.Encryption context grant constraints are supported only on grant operations that include an
EncryptionContextparameter, such as cryptographic operations on symmetric encryption KMS keys. You cannot use an encryption context grant constraint for cryptographic operations with asymmetric KMS keys or HMAC KMS keys. Operations with these keys don't support an encryption context. Grants with encryption context grant constraints can include the DescribeKey and RetireGrant operations, but the constraint doesn't apply to these operations. If a grant with an encryption context grant constraint includes theCreateGrantoperation, the constraint requires that any grants created with theCreateGrantpermission have an equally strict or stricter encryption context constraint.Each constraint value can include up to 8 encryption context pairs. The encryption context value in each constraint cannot exceed 384 characters. For more information about encryption context, see Encryption context in the Key Management Service Developer Guide .
-
SourceArn— This grant constraint allows the permissions in the grant only when the request is made on behalf of a specific Amazon Web Services resource, identified by its Amazon Resource Name (ARN). This is effectively the same as having the aws:SourceArn global condition key in the grant. The SourceArn constraint is supported on grants for all types of KMS keys and can also be applied to the DescribeKey operation when specified in the request. However, it does not apply to RetireGrant operation.
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Parameter granteePrincipal :
The identity that gets the permissions specified in the grant.
To specify the grantee principal, use the Amazon Resource Name (ARN) of an Amazon Web Services principal. Valid principals include Amazon Web Services accounts, IAM users, IAM roles, federated users, and assumed role users. For help with the ARN syntax for a principal, see IAM ARNs in the Identity and Access Management User Guide .
You must specify either GranteePrincipal or
GranteeServicePrincipal, but not both.
Parameter granteeServicePrincipal :
The Amazon Web Services service
principal that gets the permissions specified in the grant.
When you specify a GranteeServicePrincipal, you must also
specify a SourceArn grant constraint. In addition, you must
specify either a RetiringPrincipal or a
RetiringServicePrincipal.
You must specify either GranteePrincipal or
GranteeServicePrincipal, but not both.
Parameter name :
A friendly name for the grant. Use this value to prevent the unintended
creation of duplicate grants when retrying this request.
When this value is absent, all CreateGrant requests result in
a new grant with a unique GrantId even if all the supplied
parameters are identical. This can result in unintended duplicates when
you retry the CreateGrant request.
When this value is present, you can retry a CreateGrant
request with identical parameters; if the grant already exists, the
original GrantId is returned without creating a new grant.
Note that the returned grant token is unique with every
CreateGrant request, even when a duplicate
GrantId is returned. All grant tokens for the same grant ID
can be used interchangeably.
Parameter retiringPrincipal :
The principal that has permission to use the RetireGrant operation
to retire the grant.
To specify the principal, use the Amazon Resource Name (ARN) of an Amazon Web Services principal. Valid principals include Amazon Web Services accounts, IAM users, IAM roles, federated users, and assumed role users. For help with the ARN syntax for a principal, see IAM ARNs in the Identity and Access Management User Guide .
The grant determines the retiring principal. Other principals might have permission to retire the grant or revoke the grant. For details, see RevokeGrant and Retiring and revoking grants in the Key Management Service Developer Guide.
You can specify either RetiringPrincipal or
RetiringServicePrincipal, but not both.
Parameter retiringServicePrincipal :
The Amazon Web Services service
principal that has permission to use the RetireGrant operation
to retire the grant.
You can specify either RetiringPrincipal or
RetiringServicePrincipal, but not both.
Implementation
Future<CreateGrantResponse> createGrant({
required String keyId,
required List<GrantOperation> operations,
GrantConstraints? constraints,
bool? dryRun,
List<String>? grantTokens,
String? granteePrincipal,
String? granteeServicePrincipal,
String? name,
String? retiringPrincipal,
String? retiringServicePrincipal,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.CreateGrant'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'Operations': operations.map((e) => e.value).toList(),
if (constraints != null) 'Constraints': constraints,
if (dryRun != null) 'DryRun': dryRun,
if (grantTokens != null) 'GrantTokens': grantTokens,
if (granteePrincipal != null) 'GranteePrincipal': granteePrincipal,
if (granteeServicePrincipal != null)
'GranteeServicePrincipal': granteeServicePrincipal,
if (name != null) 'Name': name,
if (retiringPrincipal != null) 'RetiringPrincipal': retiringPrincipal,
if (retiringServicePrincipal != null)
'RetiringServicePrincipal': retiringServicePrincipal,
},
);
return CreateGrantResponse.fromJson(jsonResponse.body);
}