disconnectCustomKeyStore method
Disconnects the custom key store from its backing key store. This operation disconnects an CloudHSM key store from its associated CloudHSM cluster or disconnects an external key store from the external key store proxy that communicates with your external key manager.
This operation is part of the custom key stores feature in KMS, which combines the convenience and extensive integration of KMS with the isolation and control of a key store that you own and manage.
While a custom key store is disconnected, you can manage the custom key
store and its KMS keys, but you cannot create or use its KMS keys. You can
reconnect the custom key store at any time.
When you disconnect a custom key store, its ConnectionState
changes to Disconnected. To find the connection state of a
custom key store, use the DescribeCustomKeyStores operation. To
reconnect a custom key store, use the ConnectCustomKeyStore
operation.
If the operation succeeds, it returns a JSON object with no properties.
Cross-account use: No. You cannot perform this operation on a custom key store in a different Amazon Web Services account.
Required permissions: kms:DisconnectCustomKeyStore (IAM policy)
Related operations:
- ConnectCustomKeyStore
- CreateCustomKeyStore
- DeleteCustomKeyStore
- DescribeCustomKeyStores
- UpdateCustomKeyStore
May throw CustomKeyStoreInvalidStateException.
May throw CustomKeyStoreNotFoundException.
May throw KMSInternalException.
Parameter customKeyStoreId :
Enter the ID of the custom key store you want to disconnect. To find the
ID of a custom key store, use the DescribeCustomKeyStores
operation.
Implementation
Future<void> disconnectCustomKeyStore({
required String customKeyStoreId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.DisconnectCustomKeyStore'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CustomKeyStoreId': customKeyStoreId,
},
);
}