enableKeyRotation method
Enables automatic rotation of the key material of the specified symmetric encryption KMS key.
By default, when you enable automatic rotation of a customer
managed KMS key, KMS rotates the key material of the KMS key one year
(approximately 365 days) from the enable date and every year thereafter.
You can use the optional RotationPeriodInDays parameter to
specify a custom rotation period when you enable key rotation, or you can
use RotationPeriodInDays to modify the rotation period of a
key that you previously enabled automatic key rotation on.
You can monitor rotation of the key material for your KMS keys in CloudTrail and Amazon CloudWatch. To disable rotation of the key material in a customer managed KMS key, use the DisableKeyRotation operation. You can use the GetKeyRotationStatus operation to identify any in progress rotations. You can use the ListKeyRotations operation to view the details of completed rotations.
Automatic key rotation is supported only on symmetric encryption KMS keys. You cannot enable automatic rotation of asymmetric KMS keys, HMAC KMS keys, KMS keys with imported key material, or KMS keys in a custom key store. To enable or disable automatic rotation of a set of related multi-Region keys, set the property on the primary key.
You cannot enable or disable automatic rotation of Amazon Web Services managed KMS keys. KMS always rotates the key material of Amazon Web Services managed keys every year. Rotation of Amazon Web Services owned KMS keys is managed by the Amazon Web Services service that owns the key.
New Amazon Web Services managed keys are automatically rotated one year after they are created, and approximately every year thereafter.
Existing Amazon Web Services managed keys are automatically rotated one year after their most recent rotation, and every year thereafter. The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: No. You cannot perform this operation on a KMS key in a different Amazon Web Services account.
Required permissions: kms:EnableKeyRotation (key policy)
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw DisabledException.
May throw InvalidArnException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
May throw UnsupportedOperationException.
Parameter keyId :
Identifies a symmetric encryption KMS key. You cannot enable automatic
rotation of asymmetric
KMS keys, HMAC
KMS keys, KMS keys with imported
key material, or KMS keys in a custom
key store. To enable or disable automatic rotation of a set of related
multi-Region
keys, set the property on the primary key.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Parameter rotationPeriodInDays :
Use this parameter to specify a custom period of time between each
rotation date. If no value is specified, the default value is 365 days.
The rotation period defines the number of days after you enable automatic key rotation that KMS will rotate your key material, and the number of days between each automatic rotation thereafter.
You can use the
kms:RotationPeriodInDays condition key to further
constrain the values that principals can specify in the
RotationPeriodInDays parameter.
Implementation
Future<void> enableKeyRotation({
required String keyId,
int? rotationPeriodInDays,
}) async {
_s.validateNumRange(
'rotationPeriodInDays',
rotationPeriodInDays,
90,
2560,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.EnableKeyRotation'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
if (rotationPeriodInDays != null)
'RotationPeriodInDays': rotationPeriodInDays,
},
);
}