generateDataKey method
Returns a unique symmetric data key for use outside of KMS. This operation returns a plaintext copy of the data key and a copy that is encrypted under a symmetric encryption KMS key that you specify. The bytes in the plaintext key are random; they are not related to the caller or the KMS key. You can use the plaintext key to encrypt your data outside of KMS and store the encrypted data key with the encrypted data.
To generate a data key, specify the symmetric encryption KMS key that will be used to encrypt the data key. You cannot use an asymmetric KMS key to encrypt data keys. To get the type of your KMS key, use the DescribeKey operation.
You must also specify the length of the data key. Use either the
KeySpec or NumberOfBytes parameters (but not
both). For 128-bit and 256-bit data keys, use the KeySpec
parameter.
To generate a 128-bit SM4 data key (China Regions only), specify a
KeySpec value of AES_128 or a
NumberOfBytes value of 16. The symmetric
encryption key used in China Regions to encrypt your data key is an SM4
encryption key.
To get only an encrypted copy of the data key, use GenerateDataKeyWithoutPlaintext. To generate an asymmetric data key pair, use the GenerateDataKeyPair or GenerateDataKeyPairWithoutPlaintext operation. To get a cryptographically secure random byte string, use GenerateRandom.
You can use an optional encryption context to add additional security to
the encryption operation. If you specify an
EncryptionContext, you must specify the same encryption
context (a case-sensitive exact match) when decrypting the encrypted data
key. Otherwise, the request to decrypt fails with an
InvalidCiphertextException. For more information, see Encryption
Context in the Key Management Service Developer Guide.
GenerateDataKey also supports Amazon
Web Services Nitro Enclaves, which provide an isolated compute
environment in Amazon EC2. To call GenerateDataKey for an
Amazon Web Services Nitro enclave or NitroTPM, use the Amazon
Web Services Nitro Enclaves SDK or any Amazon Web Services SDK. Use
the Recipient parameter to provide the attestation document
for the attested environment. GenerateDataKey returns a copy
of the data key encrypted under the specified KMS key, as usual. But
instead of a plaintext copy of the data key, the response includes a copy
of the data key encrypted under the public key from the attestation
document (CiphertextForRecipient). For information about the
interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon
Web Services NitroTPM, see Cryptographic
attestation support in KMS in the Key Management Service Developer
Guide.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
How to use your data key
We recommend that you use the following pattern to encrypt data locally in your application. You can write your own code or use a client-side encryption library, such as the Amazon Web Services Encryption SDK, the Amazon DynamoDB Encryption Client, or Amazon S3 client-side encryption to do these tasks for you.
To encrypt data outside of KMS:
-
Use the
GenerateDataKeyoperation to get a data key. -
Use the plaintext data key (in the
Plaintextfield of the response) to encrypt your data outside of KMS. Then erase the plaintext data key from memory. -
Store the encrypted data key (in the
CiphertextBlobfield of the response) with the encrypted data.
- Use the Decrypt operation to decrypt the encrypted data key. The operation returns a plaintext copy of the data key.
- Use the plaintext data key to decrypt data outside of KMS, then erase the plaintext data key from memory.
KeyId parameter.
Required permissions: kms:GenerateDataKey (key policy)
Related operations:
- Decrypt
- Encrypt
- GenerateDataKeyPair
- GenerateDataKeyPairWithoutPlaintext
- GenerateDataKeyWithoutPlaintext
May throw DependencyTimeoutException.
May throw DisabledException.
May throw DryRunOperationException.
May throw InvalidGrantTokenException.
May throw InvalidKeyUsageException.
May throw KeyUnavailableException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
Parameter keyId :
Specifies the symmetric encryption KMS key that encrypts the data key. You
cannot specify an asymmetric KMS key or a KMS key in a custom key store.
To get the type and origin of your KMS key, use the DescribeKey
operation.
To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN.
When using an alias name, prefix it with "alias/". To specify
a KMS key in a different Amazon Web Services account, you must use the key
ARN or alias ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias ARN:
arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter encryptionContext :
Specifies the encryption context that will be used when encrypting the
data key.
An encryption context is a collection of non-secret key-value pairs
that represent additional authenticated data. When you use an encryption
context to encrypt data, you must specify the same (an exact
case-sensitive match) encryption context to decrypt the data. An
encryption context is supported only on operations with symmetric
encryption KMS keys. On operations with symmetric encryption KMS keys, an
encryption context is optional, but it is strongly recommended.
For more information, see Encryption context in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Parameter keySpec :
Specifies the length of the data key. Use AES_128 to generate
a 128-bit symmetric key, or AES_256 to generate a 256-bit
symmetric key.
You must specify either the KeySpec or the
NumberOfBytes parameter (but not both) in every
GenerateDataKey request.
Parameter numberOfBytes :
Specifies the length of the data key in bytes. For example, use the value
64 to generate a 512-bit data key (64 bytes is 512 bits). For 128-bit
(16-byte) and 256-bit (32-byte) data keys, use the KeySpec
parameter.
You must specify either the KeySpec or the
NumberOfBytes parameter (but not both) in every
GenerateDataKey request.
Parameter recipient :
A signed attestation
document from an Amazon Web Services Nitro enclave or NitroTPM, and
the encryption algorithm to use with the public key in the attestation
document. The only valid encryption algorithm is
RSAES_OAEP_SHA_256.
This parameter supports the Amazon Web Services Nitro Enclaves SDK or any Amazon Web Services SDK for Amazon Web Services Nitro Enclaves. It supports any Amazon Web Services SDK for Amazon Web Services NitroTPM.
When you use this parameter, instead of returning the plaintext data key,
KMS encrypts the plaintext data key under the public key in the
attestation document, and returns the resulting ciphertext in the
CiphertextForRecipient field in the response. This ciphertext
can be decrypted only with the private key in the enclave. The
CiphertextBlob field in the response contains a copy of the
data key encrypted under the KMS key specified by the KeyId
parameter. The Plaintext field in the response is null or
empty.
For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide.
Implementation
Future<GenerateDataKeyResponse> generateDataKey({
required String keyId,
bool? dryRun,
Map<String, String>? encryptionContext,
List<String>? grantTokens,
DataKeySpec? keySpec,
int? numberOfBytes,
RecipientInfo? recipient,
}) async {
_s.validateNumRange(
'numberOfBytes',
numberOfBytes,
1,
1024,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.GenerateDataKey'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
if (dryRun != null) 'DryRun': dryRun,
if (encryptionContext != null) 'EncryptionContext': encryptionContext,
if (grantTokens != null) 'GrantTokens': grantTokens,
if (keySpec != null) 'KeySpec': keySpec.value,
if (numberOfBytes != null) 'NumberOfBytes': numberOfBytes,
if (recipient != null) 'Recipient': recipient,
},
);
return GenerateDataKeyResponse.fromJson(jsonResponse.body);
}