generateDataKeyPair method
Returns a unique asymmetric data key pair for use outside of KMS. This operation returns a plaintext public key, a plaintext private key, and a copy of the private key that is encrypted under the symmetric encryption KMS key you specify. You can use the data key pair to perform asymmetric cryptography and implement digital signatures outside of KMS. The bytes in the keys are random; they are not related to the caller or to the KMS key that is used to encrypt the private key.
You can use the public key that GenerateDataKeyPair returns
to encrypt data or verify a signature outside of KMS. Then, store the
encrypted private key with the data. When you are ready to decrypt data or
sign a message, you can use the Decrypt operation to decrypt the
encrypted private key.
To generate a data key pair, you must specify a symmetric encryption KMS key to encrypt the private key in a data key pair. You cannot use an asymmetric KMS key or a KMS key in a custom key store. To get the type and origin of your KMS key, use the DescribeKey operation.
Use the KeyPairSpec parameter to choose an RSA or Elliptic
Curve (ECC) data key pair. In China Regions, you can also choose an SM2
data key pair. KMS recommends that you use ECC key pairs for signing, and
use RSA and SM2 key pairs for either encryption or signing, but not both.
However, KMS cannot enforce any restrictions on the use of data key pairs
outside of KMS.
If you are using the data key pair to encrypt data, or for any operation
where you don't immediately need a private key, consider using the
GenerateDataKeyPairWithoutPlaintext operation.
GenerateDataKeyPairWithoutPlaintext returns a plaintext
public key and an encrypted private key, but omits the plaintext private
key that you need only to decrypt ciphertext or sign a message. Later,
when you need to decrypt the data or sign a message, use the
Decrypt operation to decrypt the encrypted private key in the data
key pair.
GenerateDataKeyPair returns a unique data key pair for each
request. The bytes in the keys are random; they are not related to the
caller or the KMS key that is used to encrypt the private key. The public
key is a DER-encoded X.509 SubjectPublicKeyInfo, as specified in RFC 5280. The private key
is a DER-encoded PKCS8 PrivateKeyInfo, as specified in RFC 5958.
GenerateDataKeyPair also supports Amazon
Web Services Nitro Enclaves, which provide an isolated compute
environment in Amazon EC2. To call GenerateDataKeyPair for an
Amazon Web Services Nitro enclave or NitroTPM, use the Amazon
Web Services Nitro Enclaves SDK or any Amazon Web Services SDK. Use
the Recipient parameter to provide the attestation document
for the attested environment. GenerateDataKeyPair returns the
public data key and a copy of the private data key encrypted under the
specified KMS key, as usual. But instead of a plaintext copy of the
private data key (PrivateKeyPlaintext), the response includes
a copy of the private data key encrypted under the public key from the
attestation document (CiphertextForRecipient). For
information about the interaction between KMS and Amazon Web Services
Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic
attestation support in KMS in the Key Management Service Developer
Guide.
You can use an optional encryption context to add additional security to
the encryption operation. If you specify an
EncryptionContext, you must specify the same encryption
context (a case-sensitive exact match) when decrypting the encrypted data
key. Otherwise, the request to decrypt fails with an
InvalidCiphertextException. For more information, see Encryption
Context in the Key Management Service Developer Guide.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: Yes. To perform this operation with a KMS key in
a different Amazon Web Services account, specify the key ARN or alias ARN
in the value of the KeyId parameter.
Required permissions: kms:GenerateDataKeyPair (key policy)
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw DisabledException.
May throw DryRunOperationException.
May throw InvalidGrantTokenException.
May throw InvalidKeyUsageException.
May throw KeyUnavailableException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
May throw UnsupportedOperationException.
Parameter keyId :
Specifies the symmetric encryption KMS key that encrypts the private key
in the data key pair. You cannot specify an asymmetric KMS key or a KMS
key in a custom key store. To get the type and origin of your KMS key, use
the DescribeKey operation.
To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN.
When using an alias name, prefix it with "alias/". To specify
a KMS key in a different Amazon Web Services account, you must use the key
ARN or alias ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias ARN:
arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias
Parameter keyPairSpec :
Determines the type of data key pair that is generated.
The KMS rule that restricts the use of asymmetric RSA and SM2 KMS keys to encrypt and decrypt or to sign and verify (but not both), the rule that permits you to use ECC KMS keys only to sign and verify, and the rule that permits you to use ML-DSA key pairs to sign and verify only are not effective on data key pairs, which are used outside of KMS. The SM2 key spec is only available in China Regions.
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter encryptionContext :
Specifies the encryption context that will be used when encrypting the
private key in the data key pair.
An encryption context is a collection of non-secret key-value pairs
that represent additional authenticated data. When you use an encryption
context to encrypt data, you must specify the same (an exact
case-sensitive match) encryption context to decrypt the data. An
encryption context is supported only on operations with symmetric
encryption KMS keys. On operations with symmetric encryption KMS keys, an
encryption context is optional, but it is strongly recommended.
For more information, see Encryption context in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Parameter recipient :
A signed attestation
document from an Amazon Web Services Nitro enclave or NitroTPM, and
the encryption algorithm to use with the public key in the attestation
document. The only valid encryption algorithm is
RSAES_OAEP_SHA_256.
This parameter only supports attestation documents for Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM. To call GenerateDataKeyPair generate an attestation document use either Amazon Web Services Nitro Enclaves SDK for an Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM tools for Amazon Web Services NitroTPM. Then use the Recipient parameter from any Amazon Web Services SDK to provide the attestation document for the attested environment.
When you use this parameter, instead of returning a plaintext copy of the
private data key, KMS encrypts the plaintext private data key under the
public key in the attestation document, and returns the resulting
ciphertext in the CiphertextForRecipient field in the
response. This ciphertext can be decrypted only with the private key in
the attested environment. The CiphertextBlob field in the
response contains a copy of the private data key encrypted under the KMS
key specified by the KeyId parameter. The
PrivateKeyPlaintext field in the response is null or empty.
For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide.
Implementation
Future<GenerateDataKeyPairResponse> generateDataKeyPair({
required String keyId,
required DataKeyPairSpec keyPairSpec,
bool? dryRun,
Map<String, String>? encryptionContext,
List<String>? grantTokens,
RecipientInfo? recipient,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.GenerateDataKeyPair'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'KeyPairSpec': keyPairSpec.value,
if (dryRun != null) 'DryRun': dryRun,
if (encryptionContext != null) 'EncryptionContext': encryptionContext,
if (grantTokens != null) 'GrantTokens': grantTokens,
if (recipient != null) 'Recipient': recipient,
},
);
return GenerateDataKeyPairResponse.fromJson(jsonResponse.body);
}