generateMac method
Generates a hash-based message authentication code (HMAC) for a message using an HMAC KMS key and a MAC algorithm that the key supports. HMAC KMS keys and the HMAC algorithms that KMS uses conform to industry standards defined in RFC 2104.
You can use value that GenerateMac returns in the VerifyMac operation to demonstrate that the original message has not changed. Also, because a secret key is used to create the hash, you can verify that the party that generated the hash has the required secret key. You can also use the raw result to implement HMAC-based algorithms such as key derivation functions. This operation is part of KMS support for HMAC KMS keys. For details, see HMAC keys in KMS in the Key Management Service Developer Guide . The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: Yes. To perform this operation with a KMS key in
a different Amazon Web Services account, specify the key ARN or alias ARN
in the value of the KeyId parameter.
Required permissions: kms:GenerateMac (key policy)
Related operations: VerifyMac
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.
May throw DisabledException.
May throw DryRunOperationException.
May throw InvalidGrantTokenException.
May throw InvalidKeyUsageException.
May throw KeyUnavailableException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
Parameter keyId :
The HMAC KMS key to use in the operation. The MAC algorithm computes the
HMAC for the message and the key as described in RFC 2104.
To identify an HMAC KMS key, use the DescribeKey operation and see
the KeySpec field in the response.
Parameter macAlgorithm :
The MAC algorithm used in the operation.
The algorithm must be compatible with the HMAC KMS key that you specify.
To find the MAC algorithms that your HMAC KMS key supports, use the
DescribeKey operation and see the MacAlgorithms field
in the DescribeKey response.
Parameter message :
The message to be hashed. Specify a message of up to 4,096 bytes.
GenerateMac and VerifyMac do not provide special
handling for message digests. If you generate an HMAC for a hash digest of
a message, you must verify the HMAC of the same hash digest.
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Implementation
Future<GenerateMacResponse> generateMac({
required String keyId,
required MacAlgorithmSpec macAlgorithm,
required Uint8List message,
bool? dryRun,
List<String>? grantTokens,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.GenerateMac'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'MacAlgorithm': macAlgorithm.value,
'Message': base64Encode(message),
if (dryRun != null) 'DryRun': dryRun,
if (grantTokens != null) 'GrantTokens': grantTokens,
},
);
return GenerateMacResponse.fromJson(jsonResponse.body);
}