importKeyMaterial method
Imports or reimports key material into an existing KMS key that was created without key material. You can also use this operation to set or update the expiration model and expiration date of the imported key material.
By default, KMS creates KMS keys with key material that it generates. You can also generate and import your own key material. For more information about importing key material, see Importing key material.
For asymmetric and HMAC keys, you cannot change the key material after the
initial import. You can import multiple key materials into symmetric
encryption keys and rotate the key material on demand using
RotateKeyOnDemand.
You can import new key materials into multi-Region symmetric encryption keys. To do so, you must import the new key material into the primary Region key. Then you can import the same key materials into the replica Region keys. You cannot directly import new key material into the replica Region keys.
To import new key material for a multi-Region symmetric key, you’ll need to complete the following:
-
Call
ImportKeyMaterialon the primary Region key with theImportTypeset toNEW_KEY_MATERIAL. -
Call
ImportKeyMaterialon the replica Region key with theImportTypeset toEXISTING_KEY_MATERIALusing the same key material imported to the primary Region key. You must do this for every replica Region key before you can perform the RotateKeyOnDemand operation on the primary Region key.
ImportType parameter to indicate whether you are importing
new key material or re-importing previously imported key material. You
might reimport key material to replace key material that expired or key
material that you deleted. You might also reimport key material to change
the expiration model or expiration date of the key material.
Each time you import key material into KMS, you can determine whether
(ExpirationModel) and when (ValidTo) the key
material expires. To change the expiration of your key material, you must
import it again, either by calling ImportKeyMaterial or using
the import
features of the KMS console.
Before you call ImportKeyMaterial, complete these steps:
-
Create or identify a KMS key with
EXTERNALorigin, which indicates that the KMS key is designed for imported key material.To create a new KMS key for imported key material, call the CreateKey operation with an
Originvalue ofEXTERNAL. You can create a symmetric encryption KMS key, HMAC KMS key, asymmetric encryption KMS key, asymmetric key agreement key, or asymmetric signing KMS key. You can also import key material into a multi-Region key of any supported type. However, you can't import key material into a KMS key in a custom key store. - Call the GetParametersForImport operation to get a public key and import token set for importing key material.
- Use the public key in the GetParametersForImport response to encrypt your key material.
ImportKeyMaterial request, you submit your
encrypted key material and import token. When calling this operation, you
must specify the following values:
-
The key ID or key ARN of the KMS key to associate with the imported key
material. Its
Originmust beEXTERNALand itsKeyStatemust bePendingImportorEnabled. You cannot perform this operation on a KMS key in a custom key store, or on a KMS key in a different Amazon Web Services account. To get theOriginandKeyStateof a KMS key, call DescribeKey. - The encrypted key material.
-
The import token that GetParametersForImport returned. You must use
a public key and token from the same
GetParametersForImportresponse. -
Whether the key material expires (
ExpirationModel) and, if so, when (ValidTo). For help with this choice, see Setting an expiration time in the Key Management Service Developer Guide.If you set an expiration date, KMS deletes the key material from the KMS key on the specified date, making the KMS key unusable. To use the KMS key in cryptographic operations again, you must reimport the same key material. However, you can delete and reimport the key material at any time, including before the key material expires. Each time you reimport, you can eliminate or reset the expiration time.
Enabled, and you can use the KMS key in cryptographic
operations. For symmetric encryption keys, you will need to import all of
the key materials associated with the KMS key to change its state to
Enabled. Use the ListKeyRotations operation to
list the ID and import state of each key material associated with a KMS
key.
If this operation fails, use the exception to help determine the problem. If the error is related to the key material, the import token, or wrapping key, use GetParametersForImport to get a new public key and import token for the KMS key and repeat the import procedure. For help, see Create a KMS key with imported key material in the Key Management Service Developer Guide.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: No. You cannot perform this operation on a KMS key in a different Amazon Web Services account.
Required permissions: kms:ImportKeyMaterial (key policy)
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw ExpiredImportTokenException.
May throw IncorrectKeyMaterialException.
May throw InvalidArnException.
May throw InvalidCiphertextException.
May throw InvalidImportTokenException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
May throw UnsupportedOperationException.
Parameter encryptedKeyMaterial :
The encrypted key material to import. The key material must be encrypted
under the public wrapping key that GetParametersForImport returned,
using the wrapping algorithm that you specified in the same
GetParametersForImport request.
Parameter importToken :
The import token that you received in the response to a previous
GetParametersForImport request. It must be from the same response
that contained the public key that you used to encrypt the key material.
Parameter keyId :
The identifier of the KMS key that will be associated with the imported
key material. This must be the same KMS key specified in the
KeyID parameter of the corresponding
GetParametersForImport request. The Origin of the KMS
key must be EXTERNAL and its KeyState must be
PendingImport.
The KMS key can be a symmetric encryption KMS key, HMAC KMS key, asymmetric encryption KMS key, or asymmetric signing KMS key, including a multi-Region key of any supported type. You cannot perform this operation on a KMS key in a custom key store, or on a KMS key in a different Amazon Web Services account.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Parameter expirationModel :
Specifies whether the key material expires. The default is
KEY_MATERIAL_EXPIRES. For help with this choice, see Setting
an expiration time in the Key Management Service Developer
Guide.
When the value of ExpirationModel is
KEY_MATERIAL_EXPIRES, you must specify a value for the
ValidTo parameter. When value is
KEY_MATERIAL_DOES_NOT_EXPIRE, you must omit the
ValidTo parameter.
You cannot change the ExpirationModel or ValidTo
values for the current import after the request completes. To change
either value, you must reimport the key material.
Parameter importType :
Indicates whether the key material being imported is previously associated
with this KMS key or not. This parameter is optional and only usable with
symmetric encryption keys. If no key material has ever been imported into
the KMS key, and this parameter is omitted, the parameter defaults to
NEW_KEY_MATERIAL. After the first key material is imported,
if this parameter is omitted then the parameter defaults to
EXISTING_KEY_MATERIAL.
For multi-Region keys, you must first import new key material into the
primary Region key. You should use the NEW_KEY_MATERIAL
import type when importing key material into the primary Region key. Then,
you can import the same key material into the replica Region key. The
import type for the replica Region key should be
EXISTING_KEY_MATERIAL.
Parameter keyMaterialDescription :
Description for the key material being imported. This parameter is
optional and only usable with symmetric encryption keys. If you do not
specify a key material description, KMS retains the value you specified
when you last imported the same key material into this KMS key.
Parameter keyMaterialId :
Identifies the key material being imported. This parameter is optional and
only usable with symmetric encryption keys. You cannot specify a key
material ID with ImportType set to
NEW_KEY_MATERIAL. Whenever you import key material into a
symmetric encryption key, KMS assigns a unique identifier to the key
material based on the KMS key ID and the imported key material. When you
re-import key material with a specified key material ID, KMS:
- Computes the identifier for the key material
- Matches the computed identifier against the specified key material ID
- Verifies that the key material ID is already associated with the KMS key
Parameter validTo :
The date and time when the imported key material expires. This parameter
is required when the value of the ExpirationModel parameter
is KEY_MATERIAL_EXPIRES. Otherwise it is not valid.
The value of this parameter must be a future date and time. The maximum value is 365 days from the request date.
When the key material expires, KMS deletes the key material from the KMS key. Without its key material, the KMS key is unusable. To use the KMS key in cryptographic operations, you must reimport the same key material.
You cannot change the ExpirationModel or ValidTo
values for the current import after the request completes. To change
either value, you must delete (DeleteImportedKeyMaterial) and
reimport the key material.
Implementation
Future<ImportKeyMaterialResponse> importKeyMaterial({
required Uint8List encryptedKeyMaterial,
required Uint8List importToken,
required String keyId,
ExpirationModelType? expirationModel,
ImportType? importType,
String? keyMaterialDescription,
String? keyMaterialId,
DateTime? validTo,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.ImportKeyMaterial'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EncryptedKeyMaterial': base64Encode(encryptedKeyMaterial),
'ImportToken': base64Encode(importToken),
'KeyId': keyId,
if (expirationModel != null) 'ExpirationModel': expirationModel.value,
if (importType != null) 'ImportType': importType.value,
if (keyMaterialDescription != null)
'KeyMaterialDescription': keyMaterialDescription,
if (keyMaterialId != null) 'KeyMaterialId': keyMaterialId,
if (validTo != null) 'ValidTo': unixTimestampToJson(validTo),
},
);
return ImportKeyMaterialResponse.fromJson(jsonResponse.body);
}