listGrants method

Future<ListGrantsResponse> listGrants({
  1. required String keyId,
  2. String? grantId,
  3. String? granteePrincipal,
  4. String? granteeServicePrincipal,
  5. int? limit,
  6. String? marker,
})

Gets a list of all grants for the specified KMS key.

You must specify the KMS key in all requests. You can filter the grant list by grant ID, grantee principal, or grantee service principal.

For detailed information about grants, including grant terminology, see Grants in KMS in the Key Management Service Developer Guide . For examples of creating grants in several programming languages, see Use CreateGrant with an Amazon Web Services SDK or CLI.

When a grant is created with the GranteeServicePrincipal field, the ListGrants response always includes a GranteeServicePrincipal that indicates the grantee is actually an Amazon Web Services service principal. Cross-account use: Yes. To perform this operation on a KMS key in a different Amazon Web Services account, specify the key ARN in the value of the KeyId parameter.

Required permissions: kms:ListGrants (key policy)

Related operations:

Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.

May throw DependencyTimeoutException. May throw InvalidArnException. May throw InvalidGrantIdException. May throw InvalidMarkerException. May throw KMSInternalException. May throw KMSInvalidStateException. May throw NotFoundException.

Parameter keyId : Returns only grants for the specified KMS key. This parameter is required.

Specify the key ID or key ARN of the KMS key. To specify a KMS key in a different Amazon Web Services account, you must use the key ARN.

For example:

  • Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab
  • Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey.

Parameter grantId : Returns only the grant with the specified grant ID. The grant ID uniquely identifies the grant.

Parameter granteePrincipal : Returns only grants where the specified principal is the grantee principal for the grant.

You can specify either GranteePrincipal or GranteeServicePrincipal, but not both.

Parameter granteeServicePrincipal : Returns only grants where the specified Amazon Web Services service principal is the grantee service principal for the grant. This filter is only usable by callers in a service principal.

You can specify either GranteePrincipal or GranteeServicePrincipal, but not both.

Parameter limit : Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer.

This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50.

Parameter marker : Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received.

Implementation

Future<ListGrantsResponse> listGrants({
  required String keyId,
  String? grantId,
  String? granteePrincipal,
  String? granteeServicePrincipal,
  int? limit,
  String? marker,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TrentService.ListGrants'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'KeyId': keyId,
      if (grantId != null) 'GrantId': grantId,
      if (granteePrincipal != null) 'GranteePrincipal': granteePrincipal,
      if (granteeServicePrincipal != null)
        'GranteeServicePrincipal': granteeServicePrincipal,
      if (limit != null) 'Limit': limit,
      if (marker != null) 'Marker': marker,
    },
  );

  return ListGrantsResponse.fromJson(jsonResponse.body);
}