reEncrypt method
- required String destinationKeyId,
- Uint8List? ciphertextBlob,
- EncryptionAlgorithmSpec? destinationEncryptionAlgorithm,
- Map<
String, String> ? destinationEncryptionContext, - bool? dryRun,
- List<
DryRunModifierType> ? dryRunModifiers, - List<
String> ? grantTokens, - EncryptionAlgorithmSpec? sourceEncryptionAlgorithm,
- Map<
String, String> ? sourceEncryptionContext, - String? sourceKeyId,
Decrypts ciphertext and then reencrypts it entirely within KMS. You can use this operation to change the KMS key under which data is encrypted, such as when you manually rotate a KMS key or change the KMS key that protects a ciphertext. You can also use it to reencrypt ciphertext under the same KMS key, such as to change the encryption context of a ciphertext.
The ReEncrypt operation can decrypt ciphertext that was
encrypted by using a KMS key in an KMS operation, such as Encrypt
or GenerateDataKey. It can also decrypt ciphertext that was
encrypted by using the public key of an asymmetric
KMS key outside of KMS. However, it cannot decrypt ciphertext produced
by other libraries, such as the Amazon
Web Services Encryption SDK or Amazon
S3 client-side encryption. These libraries return a ciphertext format
that is incompatible with KMS.
When you use the ReEncrypt operation, you need to provide
information for the decrypt operation and the subsequent encrypt
operation.
-
If your ciphertext was encrypted under an asymmetric KMS key, you must use
the
SourceKeyIdparameter to identify the KMS key that encrypted the ciphertext. You must also supply the encryption algorithm that was used. This information is required to decrypt the data. -
If your ciphertext was encrypted under a symmetric encryption KMS key, the
SourceKeyIdparameter is optional. KMS can get this information from metadata that it adds to the symmetric ciphertext blob. This feature adds durability to your implementation by ensuring that authorized users can decrypt ciphertext decades after it was encrypted, even if they've lost track of the key ID. However, specifying the source KMS key is always recommended as a best practice. When you use theSourceKeyIdparameter to specify a KMS key, KMS uses only the KMS key you specify. If the ciphertext was encrypted under a different KMS key, theReEncryptoperation fails. This practice ensures that you use the KMS key that you intend. -
To reencrypt the data, you must use the
DestinationKeyIdparameter to specify the KMS key that re-encrypts the data after it is decrypted. If the destination KMS key is an asymmetric KMS key, you must also provide the encryption algorithm. The algorithm that you choose must be compatible with the KMS key.
Required permissions:
- kms:ReEncryptFrom permission on the source KMS key (key policy)
- kms:ReEncryptTo permission on the destination KMS key (key policy)
"kms:ReEncrypt*" permission in your key
policy. This permission is automatically included in the key policy
when you use the console to create a KMS key. But you must include it
manually when you create a KMS key programmatically or when you use the
PutKeyPolicy operation to set a key policy.
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw DisabledException.
May throw DryRunOperationException.
May throw IncorrectKeyException.
May throw InvalidCiphertextException.
May throw InvalidGrantTokenException.
May throw InvalidKeyUsageException.
May throw KeyUnavailableException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
Parameter destinationKeyId :
A unique identifier for the KMS key that is used to reencrypt the data.
Specify a symmetric encryption KMS key or an asymmetric KMS key with a
KeyUsage value of ENCRYPT_DECRYPT. To find the
KeyUsage value of a KMS key, use the DescribeKey
operation.
To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN.
When using an alias name, prefix it with "alias/". To specify
a KMS key in a different Amazon Web Services account, you must use the key
ARN or alias ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias ARN:
arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias
Parameter ciphertextBlob :
Ciphertext of the data to reencrypt.
This parameter is required in all cases except when DryRun is
true and DryRunModifiers is set to
IGNORE_CIPHERTEXT.
Parameter destinationEncryptionAlgorithm :
Specifies the encryption algorithm that KMS will use to reecrypt the data
after it has decrypted it. The default value,
SYMMETRIC_DEFAULT, represents the encryption algorithm used
for symmetric encryption KMS keys.
This parameter is required only when the destination KMS key is an asymmetric KMS key.
Parameter destinationEncryptionContext :
Specifies that encryption context to use when the reencrypting the data.
A destination encryption context is valid only when the destination KMS
key is a symmetric encryption KMS key. The standard ciphertext format for
asymmetric KMS keys does not include fields for metadata.
An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is supported only on operations with symmetric encryption KMS keys. On operations with symmetric encryption KMS keys, an encryption context is optional, but it is strongly recommended.
For more information, see Encryption context in the Key Management Service Developer Guide.
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter dryRunModifiers :
Specifies the modifiers to apply to the dry run operation.
DryRunModifiers is an optional parameter that only applies
when DryRun is set to true.
When set to IGNORE_CIPHERTEXT, KMS performs only
authorization validation without ciphertext validation. This allows you to
test permissions without requiring a valid ciphertext blob.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Parameter sourceEncryptionAlgorithm :
Specifies the encryption algorithm that KMS will use to decrypt the
ciphertext before it is reencrypted. The default value,
SYMMETRIC_DEFAULT, represents the algorithm used for
symmetric encryption KMS keys.
Specify the same algorithm that was used to encrypt the ciphertext. If you specify a different algorithm, the decrypt attempt fails.
This parameter is required only when the ciphertext was encrypted under an asymmetric KMS key.
Parameter sourceEncryptionContext :
Specifies the encryption context to use to decrypt the ciphertext. Enter
the same encryption context that was used to encrypt the ciphertext.
An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is supported only on operations with symmetric encryption KMS keys. On operations with symmetric encryption KMS keys, an encryption context is optional, but it is strongly recommended.
For more information, see Encryption context in the Key Management Service Developer Guide.
Parameter sourceKeyId :
Specifies the KMS key that KMS will use to decrypt the ciphertext before
it is re-encrypted.
Enter a key ID of the KMS key that was used to encrypt the ciphertext. If
you identify a different KMS key, the ReEncrypt operation
throws an IncorrectKeyException.
This parameter is required only when the ciphertext was encrypted under an
asymmetric KMS key or when DryRun is true and
DryRunModifiers is set to IGNORE_CIPHERTEXT. If
you used a symmetric encryption KMS key, KMS can get the KMS key from
metadata that it adds to the symmetric ciphertext blob. However, it is
always recommended as a best practice. This practice ensures that you use
the KMS key that you intend.
To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN.
When using an alias name, prefix it with "alias/". To specify
a KMS key in a different Amazon Web Services account, you should use the
key ARN or alias ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias ARN:
arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias
Implementation
Future<ReEncryptResponse> reEncrypt({
required String destinationKeyId,
Uint8List? ciphertextBlob,
EncryptionAlgorithmSpec? destinationEncryptionAlgorithm,
Map<String, String>? destinationEncryptionContext,
bool? dryRun,
List<DryRunModifierType>? dryRunModifiers,
List<String>? grantTokens,
EncryptionAlgorithmSpec? sourceEncryptionAlgorithm,
Map<String, String>? sourceEncryptionContext,
String? sourceKeyId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.ReEncrypt'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DestinationKeyId': destinationKeyId,
if (ciphertextBlob != null)
'CiphertextBlob': base64Encode(ciphertextBlob),
if (destinationEncryptionAlgorithm != null)
'DestinationEncryptionAlgorithm':
destinationEncryptionAlgorithm.value,
if (destinationEncryptionContext != null)
'DestinationEncryptionContext': destinationEncryptionContext,
if (dryRun != null) 'DryRun': dryRun,
if (dryRunModifiers != null)
'DryRunModifiers': dryRunModifiers.map((e) => e.value).toList(),
if (grantTokens != null) 'GrantTokens': grantTokens,
if (sourceEncryptionAlgorithm != null)
'SourceEncryptionAlgorithm': sourceEncryptionAlgorithm.value,
if (sourceEncryptionContext != null)
'SourceEncryptionContext': sourceEncryptionContext,
if (sourceKeyId != null) 'SourceKeyId': sourceKeyId,
},
);
return ReEncryptResponse.fromJson(jsonResponse.body);
}