rotateKeyOnDemand method
Immediately initiates rotation of the key material of the specified symmetric encryption KMS key.
You can perform on-demand rotation of the key material in customer managed KMS keys, regardless of whether or not automatic key rotation is enabled. On-demand rotations do not change existing automatic rotation schedules. For example, consider a KMS key that has automatic key rotation enabled with a rotation period of 730 days. If the key is scheduled to automatically rotate on April 14, 2024, and you perform an on-demand rotation on April 10, 2024, the key will automatically rotate, as scheduled, on April 14, 2024 and every 730 days thereafter. You can use GetKeyRotationStatus to identify any in progress on-demand rotations. You can use ListKeyRotations to identify the date that completed on-demand rotations were performed. You can monitor rotation of the key material for your KMS keys in CloudTrail and Amazon CloudWatch.
On-demand key rotation is supported only on symmetric encryption KMS keys.
You cannot perform on-demand rotation of asymmetric
KMS keys, HMAC
KMS keys, or KMS keys in a custom
key store. When you initiate on-demand key rotation on a symmetric
encryption KMS key with imported key material, you must have already
imported new
key material and that key material's state should be
PENDING_ROTATION. Use the ListKeyRotations
operation to check the state of all key materials associated with a KMS
key. To perform on-demand rotation of a set of related multi-Region
keys, import new key material in the primary Region key, import the
same key material in each replica Region key, and invoke the on-demand
rotation on the primary Region key.
You cannot initiate on-demand rotation of Amazon Web Services managed KMS keys. KMS always rotates the key material of Amazon Web Services managed keys every year. Rotation of Amazon Web Services owned KMS keys is managed by the Amazon Web Services service that owns the key.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: No. You cannot perform this operation on a KMS key in a different Amazon Web Services account.
Required permissions: kms:RotateKeyOnDemand (key policy)
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw ConflictException.
May throw DependencyTimeoutException.
May throw DisabledException.
May throw InvalidArnException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw LimitExceededException.
May throw NotFoundException.
May throw UnsupportedOperationException.
Parameter keyId :
Identifies a symmetric encryption KMS key. You cannot perform on-demand
rotation of asymmetric
KMS keys, HMAC
KMS keys, multi-Region KMS keys with imported
key material, or KMS keys in a custom
key store. To perform on-demand rotation of a set of related multi-Region
keys, invoke the on-demand rotation on the primary key.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Implementation
Future<RotateKeyOnDemandResponse> rotateKeyOnDemand({
required String keyId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.RotateKeyOnDemand'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
},
);
return RotateKeyOnDemandResponse.fromJson(jsonResponse.body);
}