tagResource method
Adds or edits tags on a customer managed key. Each tag consists of a tag key and a tag value, both of which are case-sensitive strings. The tag value can be an empty (null) string. To add a tag, specify a new tag key and a tag value. To edit a tag, specify an existing tag key and a new tag value.
You can use this operation to tag a customer managed key, but you cannot tag an Amazon Web Services managed key, an Amazon Web Services owned key, a custom key store, or an alias.
You can also add tags to a KMS key while creating it (CreateKey) or replicating it (ReplicateKey).
For information about using tags in KMS, see Tagging keys. For general information about tags, including the format and syntax, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: No. You cannot perform this operation on a KMS key in a different Amazon Web Services account.
Required permissions: kms:TagResource (key policy)
Related operations
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw InvalidArnException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw LimitExceededException.
May throw NotFoundException.
May throw TagException.
Parameter keyId :
Identifies a customer managed key in the account and Region.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Parameter tags :
One or more tags. Each tag consists of a tag key and a tag value. The tag
value can be an empty (null) string.
You cannot have more than one tag on a KMS key with the same tag key. If
you specify an existing tag key with a different tag value, KMS replaces
the current tag value with the specified one.
Implementation
Future<void> tagResource({
required String keyId,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'Tags': tags,
},
);
}