untagResource method
Deletes tags from a customer
managed key. To delete a tag, specify the tag key and the KMS key.
When it succeeds, the UntagResource operation doesn't return
any output. Also, if the specified tag key isn't found on the KMS key, it
doesn't throw an exception or return a response. To confirm that the
operation worked, use the ListResourceTags operation.
For information about using tags in KMS, see Tagging keys. For general information about tags, including the format and syntax, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: No. You cannot perform this operation on a KMS key in a different Amazon Web Services account.
Required permissions: kms:UntagResource (key policy)
Related operations
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw InvalidArnException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
May throw TagException.
Parameter keyId :
Identifies the KMS key from which you are removing tags.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
Parameter tagKeys :
One or more tag keys. Specify only the tag keys, not the tag values.
Implementation
Future<void> untagResource({
required String keyId,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'TagKeys': tagKeys,
},
);
}