verifyMac method
Verifies the hash-based message authentication code (HMAC) for a specified
message, HMAC KMS key, and MAC algorithm. To verify the HMAC,
VerifyMac computes an HMAC using the message, HMAC KMS key,
and MAC algorithm that you specify, and compares the computed HMAC to the
HMAC that you specify. If the HMACs are identical, the verification
succeeds; otherwise, it fails. Verification indicates that the message
hasn't changed since the HMAC was calculated, and the specified key was
used to generate and verify the HMAC.
HMAC KMS keys and the HMAC algorithms that KMS uses conform to industry standards defined in RFC 2104.
This operation is part of KMS support for HMAC KMS keys. For details, see HMAC keys in KMS in the Key Management Service Developer Guide.
The KMS key that you use for this operation must be in a compatible key state. For details, see Key states of KMS keys in the Key Management Service Developer Guide.
Cross-account use: Yes. To perform this operation with a KMS key in
a different Amazon Web Services account, specify the key ARN or alias ARN
in the value of the KeyId parameter.
Required permissions: kms:VerifyMac (key policy)
Related operations: GenerateMac
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.
May throw DisabledException.
May throw DryRunOperationException.
May throw InvalidGrantTokenException.
May throw InvalidKeyUsageException.
May throw KeyUnavailableException.
May throw KMSInternalException.
May throw KMSInvalidMacException.
May throw KMSInvalidStateException.
May throw NotFoundException.
Parameter keyId :
The KMS key that will be used in the verification.
Enter a key ID of the KMS key that was used to generate the HMAC. If you
identify a different KMS key, the VerifyMac operation fails.
Parameter mac :
The HMAC to verify. Enter the HMAC that was generated by the
GenerateMac operation when you specified the same message, HMAC KMS
key, and MAC algorithm as the values specified in this request.
Parameter macAlgorithm :
The MAC algorithm that will be used in the verification. Enter the same
MAC algorithm that was used to compute the HMAC. This algorithm must be
supported by the HMAC KMS key identified by the KeyId
parameter.
Parameter message :
The message that will be used in the verification. Enter the same message
that was used to generate the HMAC.
GenerateMac and VerifyMac do not provide special
handling for message digests. If you generated an HMAC for a hash digest
of a message, you must verify the HMAC for the same hash digest.
Parameter dryRun :
Checks if your request will succeed. DryRun is an optional
parameter.
To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide.
Parameter grantTokens :
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide.
Implementation
Future<VerifyMacResponse> verifyMac({
required String keyId,
required Uint8List mac,
required MacAlgorithmSpec macAlgorithm,
required Uint8List message,
bool? dryRun,
List<String>? grantTokens,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.VerifyMac'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyId': keyId,
'Mac': base64Encode(mac),
'MacAlgorithm': macAlgorithm.value,
'Message': base64Encode(message),
if (dryRun != null) 'DryRun': dryRun,
if (grantTokens != null) 'GrantTokens': grantTokens,
},
);
return VerifyMacResponse.fromJson(jsonResponse.body);
}