batchGrantPermissions method
Batch operation to grant permissions to the principal.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter entries :
A list of up to 20 entries for resource permissions to be granted by batch
operation to the principal.
Parameter catalogId :
The identifier for the Data Catalog. By default, the account ID. The Data
Catalog is the persistent metadata store. It contains database
definitions, table definitions, and other control information to manage
your Lake Formation environment.
Implementation
Future<BatchGrantPermissionsResponse> batchGrantPermissions({
required List<BatchPermissionsRequestEntry> entries,
String? catalogId,
}) async {
final $payload = <String, dynamic>{
'Entries': entries,
if (catalogId != null) 'CatalogId': catalogId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchGrantPermissions',
exceptionFnMap: _exceptionFns,
);
return BatchGrantPermissionsResponse.fromJson(response);
}