commitTransaction method

Future<CommitTransactionResponse> commitTransaction({
  1. required String transactionId,
})

Attempts to commit the specified transaction. Returns an exception if the transaction was previously aborted. This API action is idempotent if called multiple times for the same transaction.

May throw ConcurrentModificationException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException. May throw TransactionCanceledException.

Parameter transactionId : The transaction to commit.

Implementation

Future<CommitTransactionResponse> commitTransaction({
  required String transactionId,
}) async {
  final $payload = <String, dynamic>{
    'TransactionId': transactionId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CommitTransaction',
    exceptionFnMap: _exceptionFns,
  );
  return CommitTransactionResponse.fromJson(response);
}