deleteLakeFormationIdentityCenterConfiguration method

Future<void> deleteLakeFormationIdentityCenterConfiguration({
  1. String? catalogId,
})

Deletes an IAM Identity Center connection with Lake Formation.

May throw AccessDeniedException. May throw ConcurrentModificationException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter catalogId : The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, view definition, and other control information to manage your Lake Formation environment.

Implementation

Future<void> deleteLakeFormationIdentityCenterConfiguration({
  String? catalogId,
}) async {
  final $payload = <String, dynamic>{
    if (catalogId != null) 'CatalogId': catalogId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteLakeFormationIdentityCenterConfiguration',
    exceptionFnMap: _exceptionFns,
  );
}