extendTransaction method

Future<void> extendTransaction({
  1. String? transactionId,
})

Indicates to the service that the specified transaction is still active and should not be treated as idle and aborted.

Write transactions that remain idle for a long period are automatically aborted unless explicitly extended.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException. May throw TransactionCanceledException. May throw TransactionCommitInProgressException. May throw TransactionCommittedException.

Parameter transactionId : The transaction to extend.

Implementation

Future<void> extendTransaction({
  String? transactionId,
}) async {
  final $payload = <String, dynamic>{
    if (transactionId != null) 'TransactionId': transactionId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ExtendTransaction',
    exceptionFnMap: _exceptionFns,
  );
}