getDataLakeSettings method

Future<GetDataLakeSettingsResponse> getDataLakeSettings({
  1. String? catalogId,
})

Retrieves the list of the data lake administrators of a Lake Formation-managed data lake.

May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException.

Parameter catalogId : The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

Implementation

Future<GetDataLakeSettingsResponse> getDataLakeSettings({
  String? catalogId,
}) async {
  final $payload = <String, dynamic>{
    if (catalogId != null) 'CatalogId': catalogId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetDataLakeSettings',
    exceptionFnMap: _exceptionFns,
  );
  return GetDataLakeSettingsResponse.fromJson(response);
}