getQueryState method

Future<GetQueryStateResponse> getQueryState({
  1. required String queryId,
})

Returns the state of a query previously submitted. Clients are expected to poll GetQueryState to monitor the current state of the planning before retrieving the work units. A query state is only visible to the principal that made the initial call to StartQueryPlanning.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidInputException.

Parameter queryId : The ID of the plan query operation.

Implementation

Future<GetQueryStateResponse> getQueryState({
  required String queryId,
}) async {
  final $payload = <String, dynamic>{
    'QueryId': queryId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetQueryState',
    exceptionFnMap: _exceptionFns,
  );
  return GetQueryStateResponse.fromJson(response);
}