getTableObjects method
Returns the set of Amazon S3 objects that make up the specified governed table. A transaction ID or timestamp can be specified for time-travel queries.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
May throw ResourceNotReadyException.
May throw TransactionCanceledException.
May throw TransactionCommittedException.
Parameter databaseName :
The database containing the governed table.
Parameter tableName :
The governed table for which to retrieve objects.
Parameter catalogId :
The catalog containing the governed table. Defaults to the caller’s
account.
Parameter maxResults :
Specifies how many values to return in a page.
Parameter nextToken :
A continuation token if this is not the first call to retrieve these
objects.
Parameter partitionPredicate :
A predicate to filter the objects returned based on the partition keys
defined in the governed table.
- The comparison operators supported are: =, >, <, >=, <=
- The logical operators supported are: AND
- The data types supported are integer, long, date(yyyy-MM-dd), timestamp(yyyy-MM-dd HH:mm:ssXXX or yyyy-MM-dd HH:mm:ss"), string and decimal.
Parameter queryAsOfTime :
The time as of when to read the governed table contents. If not set, the
most recent transaction commit time is used. Cannot be specified along
with TransactionId.
Parameter transactionId :
The transaction ID at which to read the governed table contents. If this
transaction has aborted, an error is returned. If not set, defaults to the
most recent committed transaction. Cannot be specified along with
QueryAsOfTime.
Implementation
Future<GetTableObjectsResponse> getTableObjects({
required String databaseName,
required String tableName,
String? catalogId,
int? maxResults,
String? nextToken,
String? partitionPredicate,
DateTime? queryAsOfTime,
String? transactionId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'DatabaseName': databaseName,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (partitionPredicate != null) 'PartitionPredicate': partitionPredicate,
if (queryAsOfTime != null)
'QueryAsOfTime': unixTimestampToJson(queryAsOfTime),
if (transactionId != null) 'TransactionId': transactionId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetTableObjects',
exceptionFnMap: _exceptionFns,
);
return GetTableObjectsResponse.fromJson(response);
}