listLakeFormationOptIns method

Future<ListLakeFormationOptInsResponse> listLakeFormationOptIns({
  1. int? maxResults,
  2. String? nextToken,
  3. DataLakePrincipal? principal,
  4. Resource? resource,
})

Retrieve the current list of resources and principals that are opt in to enforce Lake Formation permissions.

May throw AccessDeniedException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : A continuation token, if this is not the first call to retrieve this list.

Parameter resource : A structure for the resource.

Implementation

Future<ListLakeFormationOptInsResponse> listLakeFormationOptIns({
  int? maxResults,
  String? nextToken,
  DataLakePrincipal? principal,
  Resource? resource,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (principal != null) 'Principal': principal,
    if (resource != null) 'Resource': resource,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListLakeFormationOptIns',
    exceptionFnMap: _exceptionFns,
  );
  return ListLakeFormationOptInsResponse.fromJson(response);
}