listResources method

Future<ListResourcesResponse> listResources({
  1. List<FilterCondition>? filterConditionList,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the resources registered to be managed by the Data Catalog.

May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException.

Parameter filterConditionList : Any applicable row-level and/or column-level filtering conditions for the resources.

Parameter maxResults : The maximum number of resource results.

Parameter nextToken : A continuation token, if this is not the first call to retrieve these resources.

Implementation

Future<ListResourcesResponse> listResources({
  List<FilterCondition>? filterConditionList,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (filterConditionList != null)
      'FilterConditionList': filterConditionList,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListResources',
    exceptionFnMap: _exceptionFns,
  );
  return ListResourcesResponse.fromJson(response);
}