updateLakeFormationIdentityCenterConfiguration method
Updates the IAM Identity Center connection parameters.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter applicationStatus :
Allows to enable or disable the IAM Identity Center connection.
Parameter catalogId :
The identifier for the Data Catalog. By default, the account ID. The Data
Catalog is the persistent metadata store. It contains database
definitions, table definitions, view definitions, and other control
information to manage your Lake Formation environment.
Parameter externalFiltering :
A list of the account IDs of Amazon Web Services accounts of third-party
applications that are allowed to access data managed by Lake Formation.
Parameter serviceIntegrations :
A list of service integrations for enabling trusted identity propagation
with external services such as Redshift.
Parameter shareRecipients :
A list of Amazon Web Services account IDs or Amazon Web Services
organization/organizational unit ARNs that are allowed to access to access
data managed by Lake Formation.
If the ShareRecipients list includes valid values, then the
resource share is updated with the principals you want to have access to
the resources.
If the ShareRecipients value is null, both the list of share
recipients and the resource share remain unchanged.
If the ShareRecipients value is an empty list, then the
existing share recipients list will be cleared, and the resource share
will be deleted.
Implementation
Future<void> updateLakeFormationIdentityCenterConfiguration({
ApplicationStatus? applicationStatus,
String? catalogId,
ExternalFilteringConfiguration? externalFiltering,
List<ServiceIntegrationUnion>? serviceIntegrations,
List<DataLakePrincipal>? shareRecipients,
}) async {
final $payload = <String, dynamic>{
if (applicationStatus != null)
'ApplicationStatus': applicationStatus.value,
if (catalogId != null) 'CatalogId': catalogId,
if (externalFiltering != null) 'ExternalFiltering': externalFiltering,
if (serviceIntegrations != null)
'ServiceIntegrations': serviceIntegrations,
if (shareRecipients != null) 'ShareRecipients': shareRecipients,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateLakeFormationIdentityCenterConfiguration',
exceptionFnMap: _exceptionFns,
);
}