updateResource method
Updates the data access role used for vending access to the given (registered) resource in Lake Formation.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter resourceArn :
The resource ARN.
Parameter roleArn :
The new role to use for the given resource registered in Lake Formation.
Parameter expectedResourceOwnerAccount :
The Amazon Web Services account that owns the Glue tables associated with
specific Amazon S3 locations.
Parameter hybridAccessEnabled :
Specifies whether the data access of tables pointing to the location can
be managed by both Lake Formation permissions as well as Amazon S3 bucket
policies.
Parameter withFederation :
Whether or not the resource is a federated resource.
Implementation
Future<void> updateResource({
required String resourceArn,
required String roleArn,
String? expectedResourceOwnerAccount,
bool? hybridAccessEnabled,
bool? withFederation,
}) async {
final $payload = <String, dynamic>{
'ResourceArn': resourceArn,
'RoleArn': roleArn,
if (expectedResourceOwnerAccount != null)
'ExpectedResourceOwnerAccount': expectedResourceOwnerAccount,
if (hybridAccessEnabled != null)
'HybridAccessEnabled': hybridAccessEnabled,
if (withFederation != null) 'WithFederation': withFederation,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateResource',
exceptionFnMap: _exceptionFns,
);
}