updateTableObjects method

Future<void> updateTableObjects({
  1. required String databaseName,
  2. required String tableName,
  3. required List<WriteOperation> writeOperations,
  4. String? catalogId,
  5. String? transactionId,
})

Updates the manifest of Amazon S3 objects that make up the specified governed table.

May throw ConcurrentModificationException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException. May throw OperationTimeoutException. May throw ResourceNotReadyException. May throw TransactionCanceledException. May throw TransactionCommitInProgressException. May throw TransactionCommittedException.

Parameter databaseName : The database containing the governed table to update.

Parameter tableName : The governed table to update.

Parameter writeOperations : A list of WriteOperation objects that define an object to add to or delete from the manifest for a governed table.

Parameter catalogId : The catalog containing the governed table to update. Defaults to the caller’s account ID.

Parameter transactionId : The transaction at which to do the write.

Implementation

Future<void> updateTableObjects({
  required String databaseName,
  required String tableName,
  required List<WriteOperation> writeOperations,
  String? catalogId,
  String? transactionId,
}) async {
  final $payload = <String, dynamic>{
    'DatabaseName': databaseName,
    'TableName': tableName,
    'WriteOperations': writeOperations,
    if (catalogId != null) 'CatalogId': catalogId,
    if (transactionId != null) 'TransactionId': transactionId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateTableObjects',
    exceptionFnMap: _exceptionFns,
  );
}