updateTableStorageOptimizer method

Future<UpdateTableStorageOptimizerResponse> updateTableStorageOptimizer({
  1. required String databaseName,
  2. required Map<OptimizerType, Map<String, String>> storageOptimizerConfig,
  3. required String tableName,
  4. String? catalogId,
})

Updates the configuration of the storage optimizers for a table.

May throw AccessDeniedException. May throw EntityNotFoundException. May throw InternalServiceException. May throw InvalidInputException.

Parameter databaseName : Name of the database where the table is present.

Parameter storageOptimizerConfig : Name of the configuration for the storage optimizer.

Parameter tableName : Name of the table for which to enable the storage optimizer.

Parameter catalogId : The Catalog ID of the table.

Implementation

Future<UpdateTableStorageOptimizerResponse> updateTableStorageOptimizer({
  required String databaseName,
  required Map<OptimizerType, Map<String, String>> storageOptimizerConfig,
  required String tableName,
  String? catalogId,
}) async {
  final $payload = <String, dynamic>{
    'DatabaseName': databaseName,
    'StorageOptimizerConfig':
        storageOptimizerConfig.map((k, e) => MapEntry(k.value, e)),
    'TableName': tableName,
    if (catalogId != null) 'CatalogId': catalogId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateTableStorageOptimizer',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateTableStorageOptimizerResponse.fromJson(response);
}