Lambda class

Lambda is a compute service that lets you run code without provisioning or managing servers. Lambda runs your code on a high-availability compute infrastructure and performs all of the administration of the compute resources, including server and operating system maintenance, capacity provisioning and automatic scaling, code monitoring and logging. With Lambda, you can run code for virtually any type of application or backend service. For more information about the Lambda service, see What is Lambda in the Lambda Developer Guide.

Constructors

Lambda({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLayerVersionPermission({required String action, required String layerName, required String principal, required String statementId, required int versionNumber, String? organizationId, String? revisionId}) Future<AddLayerVersionPermissionResponse>
Adds permissions to the resource-based policy of a version of an Lambda layer. Use this action to grant layer usage permission to other accounts. You can grant permission to a single account, all accounts in an organization, or all Amazon Web Services accounts.
addPermission({required String action, required String functionName, required String principal, required String statementId, String? eventSourceToken, FunctionUrlAuthType? functionUrlAuthType, bool? invokedViaFunctionUrl, String? principalOrgID, String? qualifier, String? revisionId, String? sourceAccount, String? sourceArn}) Future<AddPermissionResponse>
Grants a principal permission to use a function. You can apply the policy at the function level, or specify a qualifier to restrict access to a single version or alias. If you use a qualifier, the invoker must use the full Amazon Resource Name (ARN) of that version or alias to invoke the function. Note: Lambda does not support adding policies to version $LATEST.
checkpointDurableExecution({required String checkpointToken, required String durableExecutionArn, String? clientToken, List<OperationUpdate>? updates}) Future<CheckpointDurableExecutionResponse>
Saves the progress of a durable function execution during runtime. This API is used by the Lambda durable functions SDK to checkpoint completed steps and schedule asynchronous operations. You typically don't need to call this API directly as the SDK handles checkpointing automatically.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAlias({required String functionName, required String functionVersion, required String name, String? description, AliasRoutingConfiguration? routingConfig}) Future<AliasConfiguration>
Creates an alias for a Lambda function version. Use aliases to provide clients with a function identifier that you can update to invoke a different version.
createCapacityProvider({required String capacityProviderName, required CapacityProviderPermissionsConfig permissionsConfig, required CapacityProviderVpcConfig vpcConfig, CapacityProviderScalingConfig? capacityProviderScalingConfig, InstanceRequirements? instanceRequirements, String? kmsKeyArn, PropagateTags? propagateTags, Map<String, String>? tags}) Future<CreateCapacityProviderResponse>
Creates a capacity provider that manages compute resources for Lambda functions
createCodeSigningConfig({required AllowedPublishers allowedPublishers, CodeSigningPolicies? codeSigningPolicies, String? description, Map<String, String>? tags}) Future<CreateCodeSigningConfigResponse>
Creates a code signing configuration. A code signing configuration defines a list of allowed signing profiles and defines the code-signing validation policy (action to be taken if deployment validation checks fail).
createEventSourceMapping({required String functionName, AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig, int? batchSize, bool? bisectBatchOnFunctionError, DestinationConfig? destinationConfig, DocumentDBEventSourceConfig? documentDBEventSourceConfig, bool? enabled, String? eventSourceArn, FilterCriteria? filterCriteria, List<FunctionResponseType>? functionResponseTypes, String? kMSKeyArn, EventSourceMappingLoggingConfig? loggingConfig, int? maximumBatchingWindowInSeconds, int? maximumRecordAgeInSeconds, int? maximumRetryAttempts, EventSourceMappingMetricsConfig? metricsConfig, int? parallelizationFactor, ProvisionedPollerConfig? provisionedPollerConfig, List<String>? queues, ScalingConfig? scalingConfig, SelfManagedEventSource? selfManagedEventSource, SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig, List<SourceAccessConfiguration>? sourceAccessConfigurations, EventSourcePosition? startingPosition, DateTime? startingPositionTimestamp, Map<String, String>? tags, List<String>? topics, int? tumblingWindowInSeconds}) Future<EventSourceMappingConfiguration>
Creates a mapping between an event source and an Lambda function. Lambda reads items from the event source and invokes the function.
createFunction({required FunctionCode code, required String functionName, required String role, List<Architecture>? architectures, CapacityProviderConfig? capacityProviderConfig, String? codeSigningConfigArn, DeadLetterConfig? deadLetterConfig, String? description, DurableConfig? durableConfig, Environment? environment, EphemeralStorage? ephemeralStorage, List<FileSystemConfig>? fileSystemConfigs, String? handler, ImageConfig? imageConfig, String? kMSKeyArn, List<String>? layers, LoggingConfig? loggingConfig, int? memorySize, PackageType? packageType, bool? publish, FunctionVersionLatestPublished? publishTo, Runtime? runtime, SnapStart? snapStart, Map<String, String>? tags, TenancyConfig? tenancyConfig, int? timeout, TracingConfig? tracingConfig, VpcConfig? vpcConfig}) Future<FunctionConfiguration>
Creates a Lambda function. To create a function, you need a deployment package and an execution role. The deployment package is a .zip file archive or container image that contains your function code. The execution role grants the function permission to use Amazon Web Services services, such as Amazon CloudWatch Logs for log streaming and X-Ray for request tracing.
createFunctionUrlConfig({required FunctionUrlAuthType authType, required String functionName, Cors? cors, InvokeMode? invokeMode, String? qualifier}) Future<CreateFunctionUrlConfigResponse>
Creates a Lambda function URL with the specified configuration parameters. A function URL is a dedicated HTTP(S) endpoint that you can use to invoke your function.
deleteAlias({required String functionName, required String name}) Future<void>
Deletes a Lambda function alias.
deleteCapacityProvider({required String capacityProviderName}) Future<DeleteCapacityProviderResponse>
Deletes a capacity provider. You cannot delete a capacity provider that is currently being used by Lambda functions.
deleteCodeSigningConfig({required String codeSigningConfigArn}) Future<void>
Deletes the code signing configuration. You can delete the code signing configuration only if no function is using it.
deleteEventSourceMapping({required String uuid}) Future<EventSourceMappingConfiguration>
Deletes an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings.
deleteFunction({required String functionName, String? qualifier}) Future<DeleteFunctionResponse>
Deletes a Lambda function. To delete a specific function version, use the Qualifier parameter. Otherwise, all versions and aliases are deleted. This doesn't require the user to have explicit permissions for DeleteAlias. To delete Lambda event source mappings that invoke a function, use DeleteEventSourceMapping. For Amazon Web Services services and resources that invoke your function directly, delete the trigger in the service where you originally configured it.
deleteFunctionCodeSigningConfig({required String functionName}) Future<void>
Removes the code signing configuration from the function.
deleteFunctionConcurrency({required String functionName}) Future<void>
Removes a concurrent execution limit from a function.
deleteFunctionEventInvokeConfig({required String functionName, String? qualifier}) Future<void>
Deletes the configuration for asynchronous invocation for a function, version, or alias.
deleteFunctionUrlConfig({required String functionName, String? qualifier}) Future<void>
Deletes a Lambda function URL. When you delete a function URL, you can't recover it. Creating a new function URL results in a different URL address.
deleteLayerVersion({required String layerName, required int versionNumber}) Future<void>
Deletes a version of an Lambda layer. Deleted versions can no longer be viewed or added to functions. To avoid breaking functions, a copy of the version remains in Lambda until no functions refer to it.
deleteProvisionedConcurrencyConfig({required String functionName, required String qualifier}) Future<void>
Deletes the provisioned concurrency configuration for a function.
getAccountSettings() Future<GetAccountSettingsResponse>
Retrieves details about your account's limits and usage in an Amazon Web Services Region.
getAlias({required String functionName, required String name}) Future<AliasConfiguration>
Returns details about a Lambda function alias.
getCapacityProvider({required String capacityProviderName}) Future<GetCapacityProviderResponse>
Retrieves information about a specific capacity provider, including its configuration, state, and associated resources.
getCodeSigningConfig({required String codeSigningConfigArn}) Future<GetCodeSigningConfigResponse>
Returns information about the specified code signing configuration.
getDurableExecution({required String durableExecutionArn}) Future<GetDurableExecutionResponse>
Retrieves detailed information about a specific durable execution, including its current status, input payload, result or error information, and execution metadata such as start time and usage statistics.
getDurableExecutionHistory({required String durableExecutionArn, bool? includeExecutionData, String? marker, int? maxItems, bool? reverseOrder}) Future<GetDurableExecutionHistoryResponse>
Retrieves the execution history for a durable execution, showing all the steps, callbacks, and events that occurred during the execution. This provides a detailed audit trail of the execution's progress over time.
getDurableExecutionState({required String checkpointToken, required String durableExecutionArn, String? marker, int? maxItems}) Future<GetDurableExecutionStateResponse>
Retrieves the current execution state required for the replay process during durable function execution. This API is used by the Lambda durable functions SDK to get state information needed for replay. You typically don't need to call this API directly as the SDK handles state management automatically.
getEventSourceMapping({required String uuid}) Future<EventSourceMappingConfiguration>
Returns details about an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings.
getFunction({required String functionName, String? qualifier}) Future<GetFunctionResponse>
Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes. If you specify a function version, only details that are specific to that version are returned.
getFunctionCodeSigningConfig({required String functionName}) Future<GetFunctionCodeSigningConfigResponse>
Returns the code signing configuration for the specified function.
getFunctionConcurrency({required String functionName}) Future<GetFunctionConcurrencyResponse>
Returns details about the reserved concurrency configuration for a function. To set a concurrency limit for a function, use PutFunctionConcurrency.
getFunctionConfiguration({required String functionName, String? qualifier}) Future<FunctionConfiguration>
Returns the version-specific settings of a Lambda function or version. The output includes only options that can vary between versions of a function. To modify these settings, use UpdateFunctionConfiguration.
getFunctionEventInvokeConfig({required String functionName, String? qualifier}) Future<FunctionEventInvokeConfig>
Retrieves the configuration for asynchronous invocation for a function, version, or alias.
getFunctionRecursionConfig({required String functionName}) Future<GetFunctionRecursionConfigResponse>
Returns your function's recursive loop detection configuration.
getFunctionScalingConfig({required String functionName, required String qualifier}) Future<GetFunctionScalingConfigResponse>
Retrieves the scaling configuration for a Lambda Managed Instances function.
getFunctionUrlConfig({required String functionName, String? qualifier}) Future<GetFunctionUrlConfigResponse>
Returns details about a Lambda function URL.
getLayerVersion({required String layerName, required int versionNumber}) Future<GetLayerVersionResponse>
Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes.
getLayerVersionByArn({required String arn}) Future<GetLayerVersionResponse>
Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes.
getLayerVersionPolicy({required String layerName, required int versionNumber}) Future<GetLayerVersionPolicyResponse>
Returns the permission policy for a version of an Lambda layer. For more information, see AddLayerVersionPermission.
getPolicy({required String functionName, String? qualifier}) Future<GetPolicyResponse>
Returns the resource-based IAM policy for a function, version, or alias.
getProvisionedConcurrencyConfig({required String functionName, required String qualifier}) Future<GetProvisionedConcurrencyConfigResponse>
Retrieves the provisioned concurrency configuration for a function's alias or version.
getRuntimeManagementConfig({required String functionName, String? qualifier}) Future<GetRuntimeManagementConfigResponse>
Retrieves the runtime management configuration for a function's version. If the runtime update mode is Manual, this includes the ARN of the runtime version and the runtime update mode. If the runtime update mode is Auto or Function update, this includes the runtime update mode and null is returned for the ARN. For more information, see Runtime updates.
invoke({required String functionName, String? clientContext, String? durableExecutionName, InvocationType? invocationType, LogType? logType, Uint8List? payload, String? qualifier, String? tenantId}) Future<InvocationResponse>
Invokes a Lambda function. You can invoke a function synchronously (and wait for the response), or asynchronously. By default, Lambda invokes your function synchronously (i.e. theInvocationType is RequestResponse). To invoke a function asynchronously, set InvocationType to Event. Lambda passes the ClientContext object to your function for synchronous invocations only.
invokeAsync({required String functionName, required Uint8List invokeArgs}) Future<InvokeAsyncResponse>
May throw InvalidRequestContentException. May throw InvalidRuntimeException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException.
invokeWithResponseStream({required String functionName, String? clientContext, ResponseStreamingInvocationType? invocationType, LogType? logType, Uint8List? payload, String? qualifier, String? tenantId}) Future<InvokeWithResponseStreamResponse>
Configure your Lambda functions to stream response payloads back to clients. For more information, see Configuring a Lambda function to stream responses.
listAliases({required String functionName, String? functionVersion, String? marker, int? maxItems}) Future<ListAliasesResponse>
Returns a list of aliases for a Lambda function.
listCapacityProviders({String? marker, int? maxItems, CapacityProviderState? state}) Future<ListCapacityProvidersResponse>
Returns a list of capacity providers in your account.
listCodeSigningConfigs({String? marker, int? maxItems}) Future<ListCodeSigningConfigsResponse>
Returns a list of code signing configurations. A request returns up to 10,000 configurations per call. You can use the MaxItems parameter to return fewer configurations per call.
listDurableExecutionsByFunction({required String functionName, String? durableExecutionName, String? marker, int? maxItems, String? qualifier, bool? reverseOrder, DateTime? startedAfter, DateTime? startedBefore, List<ExecutionStatus>? statuses}) Future<ListDurableExecutionsByFunctionResponse>
Returns a list of durable executions for a specified Lambda function. You can filter the results by execution name, status, and start time range. This API supports pagination for large result sets.
listEventSourceMappings({String? eventSourceArn, String? functionName, String? marker, int? maxItems}) Future<ListEventSourceMappingsResponse>
Lists event source mappings. Specify an EventSourceArn to show only event source mappings for a single event source.
listFunctionEventInvokeConfigs({required String functionName, String? marker, int? maxItems}) Future<ListFunctionEventInvokeConfigsResponse>
Retrieves a list of configurations for asynchronous invocation for a function.
listFunctions({FunctionVersion? functionVersion, String? marker, String? masterRegion, int? maxItems}) Future<ListFunctionsResponse>
Returns a list of Lambda functions, with the version-specific configuration of each. Lambda returns up to 50 functions per call.
listFunctionsByCodeSigningConfig({required String codeSigningConfigArn, String? marker, int? maxItems}) Future<ListFunctionsByCodeSigningConfigResponse>
List the functions that use the specified code signing configuration. You can use this method prior to deleting a code signing configuration, to verify that no functions are using it.
listFunctionUrlConfigs({required String functionName, String? marker, int? maxItems}) Future<ListFunctionUrlConfigsResponse>
Returns a list of Lambda function URLs for the specified function.
listFunctionVersionsByCapacityProvider({required String capacityProviderName, String? marker, int? maxItems}) Future<ListFunctionVersionsByCapacityProviderResponse>
Returns a list of function versions that are configured to use a specific capacity provider.
listLayers({Architecture? compatibleArchitecture, Runtime? compatibleRuntime, String? marker, int? maxItems}) Future<ListLayersResponse>
Lists Lambda layers and shows information about the latest version of each. Specify a runtime identifier to list only layers that indicate that they're compatible with that runtime. Specify a compatible architecture to include only layers that are compatible with that instruction set architecture.
listLayerVersions({required String layerName, Architecture? compatibleArchitecture, Runtime? compatibleRuntime, String? marker, int? maxItems}) Future<ListLayerVersionsResponse>
Lists the versions of an Lambda layer. Versions that have been deleted aren't listed. Specify a runtime identifier to list only versions that indicate that they're compatible with that runtime. Specify a compatible architecture to include only layer versions that are compatible with that architecture.
listProvisionedConcurrencyConfigs({required String functionName, String? marker, int? maxItems}) Future<ListProvisionedConcurrencyConfigsResponse>
Retrieves a list of provisioned concurrency configurations for a function.
listTags({required String resource}) Future<ListTagsResponse>
Returns a function, event source mapping, or code signing configuration's tags. You can also view function tags with GetFunction.
listVersionsByFunction({required String functionName, String? marker, int? maxItems}) Future<ListVersionsByFunctionResponse>
Returns a list of versions, with the version-specific configuration of each. Lambda returns up to 50 versions per call.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publishLayerVersion({required LayerVersionContentInput content, required String layerName, List<Architecture>? compatibleArchitectures, List<Runtime>? compatibleRuntimes, String? description, String? licenseInfo}) Future<PublishLayerVersionResponse>
Creates an Lambda layer from a ZIP archive. Each time you call PublishLayerVersion with the same layer name, a new version is created.
publishVersion({required String functionName, String? codeSha256, String? description, FunctionVersionLatestPublished? publishTo, String? revisionId}) Future<FunctionConfiguration>
Creates a version from the current code and configuration of a function. Use versions to create a snapshot of your function code and configuration that doesn't change.
putFunctionCodeSigningConfig({required String codeSigningConfigArn, required String functionName}) Future<PutFunctionCodeSigningConfigResponse>
Update the code signing configuration for the function. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.
putFunctionConcurrency({required String functionName, required int reservedConcurrentExecutions}) Future<Concurrency>
Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.
putFunctionEventInvokeConfig({required String functionName, DestinationConfig? destinationConfig, int? maximumEventAgeInSeconds, int? maximumRetryAttempts, String? qualifier}) Future<FunctionEventInvokeConfig>
Configures options for asynchronous invocation on a function, version, or alias. If a configuration already exists for a function, version, or alias, this operation overwrites it. If you exclude any settings, they are removed. To set one option without affecting existing settings for other options, use UpdateFunctionEventInvokeConfig.
putFunctionRecursionConfig({required String functionName, required RecursiveLoop recursiveLoop}) Future<PutFunctionRecursionConfigResponse>
Sets your function's recursive loop detection configuration.
putFunctionScalingConfig({required String functionName, required String qualifier, FunctionScalingConfig? functionScalingConfig}) Future<PutFunctionScalingConfigResponse>
Sets the scaling configuration for a Lambda Managed Instances function. The scaling configuration defines the minimum and maximum number of execution environments that can be provisioned for the function, allowing you to control scaling behavior and resource allocation.
putProvisionedConcurrencyConfig({required String functionName, required int provisionedConcurrentExecutions, required String qualifier}) Future<PutProvisionedConcurrencyConfigResponse>
Adds a provisioned concurrency configuration to a function's alias or version.
putRuntimeManagementConfig({required String functionName, required UpdateRuntimeOn updateRuntimeOn, String? qualifier, String? runtimeVersionArn}) Future<PutRuntimeManagementConfigResponse>
Sets the runtime management configuration for a function's version. For more information, see Runtime updates.
removeLayerVersionPermission({required String layerName, required String statementId, required int versionNumber, String? revisionId}) Future<void>
Removes a statement from the permissions policy for a version of an Lambda layer. For more information, see AddLayerVersionPermission.
removePermission({required String functionName, required String statementId, String? qualifier, String? revisionId}) Future<void>
Revokes function-use permission from an Amazon Web Services service or another Amazon Web Services account. You can get the ID of the statement from the output of GetPolicy.
sendDurableExecutionCallbackFailure({required String callbackId, ErrorObject? error}) Future<void>
Sends a failure response for a callback operation in a durable execution. Use this API when an external system cannot complete a callback operation successfully.
sendDurableExecutionCallbackHeartbeat({required String callbackId}) Future<void>
Sends a heartbeat signal for a long-running callback operation to prevent timeout. Use this API to extend the callback timeout period while the external operation is still in progress.
sendDurableExecutionCallbackSuccess({required String callbackId, Uint8List? result}) Future<void>
Sends a successful completion response for a callback operation in a durable execution. Use this API when an external system has successfully completed a callback operation.
stopDurableExecution({required String durableExecutionArn, ErrorObject? error}) Future<StopDurableExecutionResponse>
Stops a running durable execution. The execution transitions to STOPPED status and cannot be resumed. Any in-progress operations are terminated.
tagResource({required String resource, required Map<String, String> tags}) Future<void>
Adds tags to a function, event source mapping, or code signing configuration.
toString() String
A string representation of this object.
inherited
untagResource({required String resource, required List<String> tagKeys}) Future<void>
Removes tags from a function, event source mapping, or code signing configuration.
updateAlias({required String functionName, required String name, String? description, String? functionVersion, String? revisionId, AliasRoutingConfiguration? routingConfig}) Future<AliasConfiguration>
Updates the configuration of a Lambda function alias.
updateCapacityProvider({required String capacityProviderName, CapacityProviderScalingConfig? capacityProviderScalingConfig, PropagateTags? propagateTags}) Future<UpdateCapacityProviderResponse>
Updates the configuration of an existing capacity provider.
updateCodeSigningConfig({required String codeSigningConfigArn, AllowedPublishers? allowedPublishers, CodeSigningPolicies? codeSigningPolicies, String? description}) Future<UpdateCodeSigningConfigResponse>
Update the code signing configuration. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.
updateEventSourceMapping({required String uuid, AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig, int? batchSize, bool? bisectBatchOnFunctionError, DestinationConfig? destinationConfig, DocumentDBEventSourceConfig? documentDBEventSourceConfig, bool? enabled, FilterCriteria? filterCriteria, String? functionName, List<FunctionResponseType>? functionResponseTypes, String? kMSKeyArn, EventSourceMappingLoggingConfig? loggingConfig, int? maximumBatchingWindowInSeconds, int? maximumRecordAgeInSeconds, int? maximumRetryAttempts, EventSourceMappingMetricsConfig? metricsConfig, int? parallelizationFactor, ProvisionedPollerConfig? provisionedPollerConfig, ScalingConfig? scalingConfig, SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig, List<SourceAccessConfiguration>? sourceAccessConfigurations, int? tumblingWindowInSeconds}) Future<EventSourceMappingConfiguration>
Updates an event source mapping. You can change the function that Lambda invokes, or pause invocation and resume later from the same location.
updateFunctionCode({required String functionName, List<Architecture>? architectures, bool? dryRun, String? imageUri, bool? publish, FunctionVersionLatestPublished? publishTo, String? revisionId, String? s3Bucket, String? s3Key, String? s3ObjectVersion, String? sourceKMSKeyArn, Uint8List? zipFile}) Future<FunctionConfiguration>
Updates a Lambda function's code. If code signing is enabled for the function, the code package must be signed by a trusted publisher. For more information, see Configuring code signing for Lambda.
updateFunctionConfiguration({required String functionName, CapacityProviderConfig? capacityProviderConfig, DeadLetterConfig? deadLetterConfig, String? description, DurableConfig? durableConfig, Environment? environment, EphemeralStorage? ephemeralStorage, List<FileSystemConfig>? fileSystemConfigs, String? handler, ImageConfig? imageConfig, String? kMSKeyArn, List<String>? layers, LoggingConfig? loggingConfig, int? memorySize, String? revisionId, String? role, Runtime? runtime, SnapStart? snapStart, int? timeout, TracingConfig? tracingConfig, VpcConfig? vpcConfig}) Future<FunctionConfiguration>
Modify the version-specific settings of a Lambda function.
updateFunctionEventInvokeConfig({required String functionName, DestinationConfig? destinationConfig, int? maximumEventAgeInSeconds, int? maximumRetryAttempts, String? qualifier}) Future<FunctionEventInvokeConfig>
Updates the configuration for asynchronous invocation for a function, version, or alias.
updateFunctionUrlConfig({required String functionName, FunctionUrlAuthType? authType, Cors? cors, InvokeMode? invokeMode, String? qualifier}) Future<UpdateFunctionUrlConfigResponse>
Updates the configuration for a Lambda function URL.

Operators

operator ==(Object other) bool
The equality operator.
inherited