addPermission method

Future<AddPermissionResponse> addPermission({
  1. required String action,
  2. required String functionName,
  3. required String principal,
  4. required String statementId,
  5. String? eventSourceToken,
  6. FunctionUrlAuthType? functionUrlAuthType,
  7. bool? invokedViaFunctionUrl,
  8. String? principalOrgID,
  9. String? qualifier,
  10. String? revisionId,
  11. String? sourceAccount,
  12. String? sourceArn,
})

Grants a principal permission to use a function. You can apply the policy at the function level, or specify a qualifier to restrict access to a single version or alias. If you use a qualifier, the invoker must use the full Amazon Resource Name (ARN) of that version or alias to invoke the function. Note: Lambda does not support adding policies to version $LATEST.

To grant permission to another account, specify the account ID as the Principal. To grant permission to an organization defined in Organizations, specify the organization ID as the PrincipalOrgID. For Amazon Web Services services, the principal is a domain-style identifier that the service defines, such as s3.amazonaws.com or sns.amazonaws.com. For Amazon Web Services services, you can also specify the ARN of the associated resource as the SourceArn. If you grant permission to a service principal without specifying the source, other accounts could potentially configure resources in their account to invoke your Lambda function.

This operation adds a statement to a resource-based permissions policy for the function. For more information about function policies, see Using resource-based policies for Lambda.

May throw InvalidParameterValueException. May throw PolicyLengthExceededException. May throw PreconditionFailedException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter action : The action that the principal can use on the function. For example, lambda:InvokeFunction or lambda:GetFunction.

Parameter functionName : The name or ARN of the Lambda function, version, or alias.

Name formats

  • Function namemy-function (name-only), my-function:v1 (with alias).
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter principal : The Amazon Web Services service, Amazon Web Services account, IAM user, or IAM role that invokes the function. If you specify a service, use SourceArn or SourceAccount to limit who can invoke the function through that service.

Parameter statementId : A statement identifier that differentiates the statement from others in the same policy.

Parameter eventSourceToken : For Alexa Smart Home functions, a token that the invoker must supply.

Parameter functionUrlAuthType : The type of authentication that your function URL uses. Set to AWS_IAM if you want to restrict access to authenticated users only. Set to NONE if you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.

Parameter invokedViaFunctionUrl : Indicates whether the permission applies when the function is invoked through a function URL.

Parameter principalOrgID : The identifier for your organization in Organizations. Use this to grant permissions to all the Amazon Web Services accounts under this organization.

Parameter qualifier : Specify a version or alias to add permissions to a published version of the function.

Parameter revisionId : Update the policy only if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.

Parameter sourceAccount : For Amazon Web Services service, the ID of the Amazon Web Services account that owns the resource. Use this together with SourceArn to ensure that the specified account owns the resource. It is possible for an Amazon S3 bucket to be deleted by its owner and recreated by another account.

Parameter sourceArn : For Amazon Web Services services, the ARN of the Amazon Web Services resource that invokes the function. For example, an Amazon S3 bucket or Amazon SNS topic.

Note that Lambda configures the comparison using the StringLike operator.

Implementation

Future<AddPermissionResponse> addPermission({
  required String action,
  required String functionName,
  required String principal,
  required String statementId,
  String? eventSourceToken,
  FunctionUrlAuthType? functionUrlAuthType,
  bool? invokedViaFunctionUrl,
  String? principalOrgID,
  String? qualifier,
  String? revisionId,
  String? sourceAccount,
  String? sourceArn,
}) async {
  final $query = <String, List<String>>{
    if (qualifier != null) 'Qualifier': [qualifier],
  };
  final $payload = <String, dynamic>{
    'Action': action,
    'Principal': principal,
    'StatementId': statementId,
    if (eventSourceToken != null) 'EventSourceToken': eventSourceToken,
    if (functionUrlAuthType != null)
      'FunctionUrlAuthType': functionUrlAuthType.value,
    if (invokedViaFunctionUrl != null)
      'InvokedViaFunctionUrl': invokedViaFunctionUrl,
    if (principalOrgID != null) 'PrincipalOrgID': principalOrgID,
    if (revisionId != null) 'RevisionId': revisionId,
    if (sourceAccount != null) 'SourceAccount': sourceAccount,
    if (sourceArn != null) 'SourceArn': sourceArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/2015-03-31/functions/${Uri.encodeComponent(functionName)}/policy',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return AddPermissionResponse.fromJson(response);
}