createEventSourceMapping method

Future<EventSourceMappingConfiguration> createEventSourceMapping({
  1. required String functionName,
  2. AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig,
  3. int? batchSize,
  4. bool? bisectBatchOnFunctionError,
  5. DestinationConfig? destinationConfig,
  6. DocumentDBEventSourceConfig? documentDBEventSourceConfig,
  7. bool? enabled,
  8. String? eventSourceArn,
  9. FilterCriteria? filterCriteria,
  10. List<FunctionResponseType>? functionResponseTypes,
  11. String? kMSKeyArn,
  12. EventSourceMappingLoggingConfig? loggingConfig,
  13. int? maximumBatchingWindowInSeconds,
  14. int? maximumRecordAgeInSeconds,
  15. int? maximumRetryAttempts,
  16. EventSourceMappingMetricsConfig? metricsConfig,
  17. int? parallelizationFactor,
  18. ProvisionedPollerConfig? provisionedPollerConfig,
  19. List<String>? queues,
  20. ScalingConfig? scalingConfig,
  21. SelfManagedEventSource? selfManagedEventSource,
  22. SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig,
  23. List<SourceAccessConfiguration>? sourceAccessConfigurations,
  24. EventSourcePosition? startingPosition,
  25. DateTime? startingPositionTimestamp,
  26. Map<String, String>? tags,
  27. List<String>? topics,
  28. int? tumblingWindowInSeconds,
})

Creates a mapping between an event source and an Lambda function. Lambda reads items from the event source and invokes the function.

For details about how to configure different event sources, see the following topics.

The following error handling options are available for stream sources (DynamoDB, Kinesis, Amazon MSK, and self-managed Apache Kafka):
  • BisectBatchOnFunctionError – If the function returns an error, split the batch in two and retry.
  • MaximumRecordAgeInSeconds – Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires
  • MaximumRetryAttempts – Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
  • OnFailure – Send discarded records to an Amazon SQS queue, Amazon SNS topic, Kafka topic, or Amazon S3 bucket. For more information, see Adding a destination.
The following option is available only for DynamoDB and Kinesis event sources:
  • ParallelizationFactor – Process multiple batches from each shard concurrently.
For information about which configuration parameters apply to each event source, see the following topics.

May throw InvalidParameterValueException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function nameMyFunction.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:MyFunction.
  • Version or Alias ARNarn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD.
  • Partial ARN123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length.

Parameter amazonManagedKafkaEventSourceConfig : Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.

Parameter batchSize : The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).

  • Amazon Kinesis – Default 100. Max 10,000.
  • Amazon DynamoDB Streams – Default 100. Max 10,000.
  • Amazon Simple Queue Service – Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.
  • Amazon Managed Streaming for Apache Kafka – Default 100. Max 10,000.
  • Self-managed Apache Kafka – Default 100. Max 10,000.
  • Amazon MQ (ActiveMQ and RabbitMQ) – Default 100. Max 10,000.
  • DocumentDB – Default 100. Max 10,000.

Parameter bisectBatchOnFunctionError : (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) If the function returns an error, split the batch in two and retry.

Parameter destinationConfig : (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.

Parameter documentDBEventSourceConfig : Specific configuration settings for a DocumentDB event source.

Parameter enabled : When true, the event source mapping is active. When false, Lambda pauses polling and invocation.

Default: True

Parameter eventSourceArn : The Amazon Resource Name (ARN) of the event source.

  • Amazon Kinesis – The ARN of the data stream or a stream consumer.
  • Amazon DynamoDB Streams – The ARN of the stream.
  • Amazon Simple Queue Service – The ARN of the queue.
  • Amazon Managed Streaming for Apache Kafka – The ARN of the cluster or the ARN of the VPC connection (for cross-account event source mappings).
  • Amazon MQ – The ARN of the broker.
  • Amazon DocumentDB – The ARN of the DocumentDB change stream.

Parameter filterCriteria : An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see Lambda event filtering.

Parameter functionResponseTypes : (Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and Amazon SQS) A list of current response type enums applied to the event source mapping.

Parameter kMSKeyArn : The ARN of the Key Management Service (KMS) customer managed key that Lambda uses to encrypt your function's filter criteria. By default, Lambda does not encrypt your filter criteria object. Specify this property to encrypt data using your own customer managed key.

Parameter loggingConfig : (Amazon MSK, and self-managed Apache Kafka only) The logging configuration for your event source. For more information, see Event source mapping logging.

Parameter maximumBatchingWindowInSeconds : The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function. You can configure MaximumBatchingWindowInSeconds to any value from 0 seconds to 300 seconds in increments of seconds.

For Kinesis, DynamoDB, and Amazon SQS event sources, the default batching window is 0 seconds. For Amazon MSK, Self-managed Apache Kafka, Amazon MQ, and DocumentDB event sources, the default batching window is 500 ms. Note that because you can only change MaximumBatchingWindowInSeconds in increments of seconds, you cannot revert back to the 500 ms default batching window after you have changed it. To restore the default batching window, you must create a new event source mapping.

Related setting: For Kinesis, DynamoDB, and Amazon SQS event sources, when you set BatchSize to a value greater than 10, you must set MaximumBatchingWindowInSeconds to at least 1.

Parameter maximumRecordAgeInSeconds : (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) Discard records older than the specified age. The default value is infinite (-1).

Parameter maximumRetryAttempts : (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.

Parameter metricsConfig : The metrics configuration for your event source. For more information, see Event source mapping metrics.

Parameter parallelizationFactor : (Kinesis and DynamoDB Streams only) The number of batches to process from each shard concurrently.

Parameter provisionedPollerConfig : (Amazon SQS, Amazon MSK, and self-managed Apache Kafka only) The provisioned mode configuration for the event source. For more information, see provisioned mode.

Parameter queues : (MQ) The name of the Amazon MQ broker destination queue to consume.

Parameter scalingConfig : (Amazon SQS only) The scaling configuration for the event source. For more information, see Configuring maximum concurrency for Amazon SQS event sources.

Parameter selfManagedEventSource : The self-managed Apache Kafka cluster to receive records from.

Parameter selfManagedKafkaEventSourceConfig : Specific configuration settings for a self-managed Apache Kafka event source.

Parameter sourceAccessConfigurations : An array of authentication protocols or VPC components required to secure your event source.

Parameter startingPosition : The position in a stream from which to start reading. Required for Amazon Kinesis and Amazon DynamoDB Stream event sources. AT_TIMESTAMP is supported only for Amazon Kinesis streams, Amazon DocumentDB, Amazon MSK, and self-managed Apache Kafka.

Parameter startingPositionTimestamp : With StartingPosition set to AT_TIMESTAMP, the time from which to start reading. StartingPositionTimestamp cannot be in the future.

Parameter tags : A list of tags to apply to the event source mapping.

Parameter topics : The name of the Kafka topic.

Parameter tumblingWindowInSeconds : (Kinesis and DynamoDB Streams only) The duration in seconds of a processing window for DynamoDB and Kinesis Streams event sources. A value of 0 seconds indicates no tumbling window.

Implementation

Future<EventSourceMappingConfiguration> createEventSourceMapping({
  required String functionName,
  AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig,
  int? batchSize,
  bool? bisectBatchOnFunctionError,
  DestinationConfig? destinationConfig,
  DocumentDBEventSourceConfig? documentDBEventSourceConfig,
  bool? enabled,
  String? eventSourceArn,
  FilterCriteria? filterCriteria,
  List<FunctionResponseType>? functionResponseTypes,
  String? kMSKeyArn,
  EventSourceMappingLoggingConfig? loggingConfig,
  int? maximumBatchingWindowInSeconds,
  int? maximumRecordAgeInSeconds,
  int? maximumRetryAttempts,
  EventSourceMappingMetricsConfig? metricsConfig,
  int? parallelizationFactor,
  ProvisionedPollerConfig? provisionedPollerConfig,
  List<String>? queues,
  ScalingConfig? scalingConfig,
  SelfManagedEventSource? selfManagedEventSource,
  SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig,
  List<SourceAccessConfiguration>? sourceAccessConfigurations,
  EventSourcePosition? startingPosition,
  DateTime? startingPositionTimestamp,
  Map<String, String>? tags,
  List<String>? topics,
  int? tumblingWindowInSeconds,
}) async {
  _s.validateNumRange(
    'batchSize',
    batchSize,
    1,
    10000,
  );
  _s.validateNumRange(
    'maximumBatchingWindowInSeconds',
    maximumBatchingWindowInSeconds,
    0,
    300,
  );
  _s.validateNumRange(
    'maximumRecordAgeInSeconds',
    maximumRecordAgeInSeconds,
    -1,
    604800,
  );
  _s.validateNumRange(
    'maximumRetryAttempts',
    maximumRetryAttempts,
    -1,
    10000,
  );
  _s.validateNumRange(
    'parallelizationFactor',
    parallelizationFactor,
    1,
    10,
  );
  _s.validateNumRange(
    'tumblingWindowInSeconds',
    tumblingWindowInSeconds,
    0,
    900,
  );
  final $payload = <String, dynamic>{
    'FunctionName': functionName,
    if (amazonManagedKafkaEventSourceConfig != null)
      'AmazonManagedKafkaEventSourceConfig':
          amazonManagedKafkaEventSourceConfig,
    if (batchSize != null) 'BatchSize': batchSize,
    if (bisectBatchOnFunctionError != null)
      'BisectBatchOnFunctionError': bisectBatchOnFunctionError,
    if (destinationConfig != null) 'DestinationConfig': destinationConfig,
    if (documentDBEventSourceConfig != null)
      'DocumentDBEventSourceConfig': documentDBEventSourceConfig,
    if (enabled != null) 'Enabled': enabled,
    if (eventSourceArn != null) 'EventSourceArn': eventSourceArn,
    if (filterCriteria != null) 'FilterCriteria': filterCriteria,
    if (functionResponseTypes != null)
      'FunctionResponseTypes':
          functionResponseTypes.map((e) => e.value).toList(),
    if (kMSKeyArn != null) 'KMSKeyArn': kMSKeyArn,
    if (loggingConfig != null) 'LoggingConfig': loggingConfig,
    if (maximumBatchingWindowInSeconds != null)
      'MaximumBatchingWindowInSeconds': maximumBatchingWindowInSeconds,
    if (maximumRecordAgeInSeconds != null)
      'MaximumRecordAgeInSeconds': maximumRecordAgeInSeconds,
    if (maximumRetryAttempts != null)
      'MaximumRetryAttempts': maximumRetryAttempts,
    if (metricsConfig != null) 'MetricsConfig': metricsConfig,
    if (parallelizationFactor != null)
      'ParallelizationFactor': parallelizationFactor,
    if (provisionedPollerConfig != null)
      'ProvisionedPollerConfig': provisionedPollerConfig,
    if (queues != null) 'Queues': queues,
    if (scalingConfig != null) 'ScalingConfig': scalingConfig,
    if (selfManagedEventSource != null)
      'SelfManagedEventSource': selfManagedEventSource,
    if (selfManagedKafkaEventSourceConfig != null)
      'SelfManagedKafkaEventSourceConfig': selfManagedKafkaEventSourceConfig,
    if (sourceAccessConfigurations != null)
      'SourceAccessConfigurations': sourceAccessConfigurations,
    if (startingPosition != null) 'StartingPosition': startingPosition.value,
    if (startingPositionTimestamp != null)
      'StartingPositionTimestamp':
          unixTimestampToJson(startingPositionTimestamp),
    if (tags != null) 'Tags': tags,
    if (topics != null) 'Topics': topics,
    if (tumblingWindowInSeconds != null)
      'TumblingWindowInSeconds': tumblingWindowInSeconds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2015-03-31/event-source-mappings',
    exceptionFnMap: _exceptionFns,
  );
  return EventSourceMappingConfiguration.fromJson(response);
}