createFunction method
- required FunctionCode code,
- required String functionName,
- required String role,
- List<
Architecture> ? architectures, - CapacityProviderConfig? capacityProviderConfig,
- String? codeSigningConfigArn,
- DeadLetterConfig? deadLetterConfig,
- String? description,
- DurableConfig? durableConfig,
- Environment? environment,
- EphemeralStorage? ephemeralStorage,
- List<
FileSystemConfig> ? fileSystemConfigs, - String? handler,
- ImageConfig? imageConfig,
- String? kMSKeyArn,
- List<
String> ? layers, - LoggingConfig? loggingConfig,
- int? memorySize,
- PackageType? packageType,
- bool? publish,
- FunctionVersionLatestPublished? publishTo,
- Runtime? runtime,
- SnapStart? snapStart,
- Map<
String, String> ? tags, - TenancyConfig? tenancyConfig,
- int? timeout,
- TracingConfig? tracingConfig,
- VpcConfig? vpcConfig,
Creates a Lambda function. To create a function, you need a deployment package and an execution role. The deployment package is a .zip file archive or container image that contains your function code. The execution role grants the function permission to use Amazon Web Services services, such as Amazon CloudWatch Logs for log streaming and X-Ray for request tracing.
If the deployment package is a container
image, then you set the package type to Image. For a
container image, the code property must include the URI of a container
image in the Amazon ECR registry. You do not need to specify the handler
and runtime properties.
If the deployment package is a .zip
file archive, then you set the package type to Zip. For a
.zip file archive, the code property specifies the location of the .zip
file. You must also specify the handler and runtime properties. The code
in the deployment package must be compatible with the target instruction
set architecture of the function (x86-64 or
arm64). If you do not specify the architecture, then the
default value is x86-64.
When you create a function, Lambda provisions an instance of the function
and its supporting resources. If your function connects to a VPC, this
process can take a minute or so. During this time, you can't invoke or
modify the function. The State, StateReason, and
StateReasonCode fields in the response from
GetFunctionConfiguration indicate when the function is ready to
invoke. For more information, see Lambda
function states.
A function has an unpublished version, and can have published versions and
aliases. The unpublished version changes when you update your function's
code and configuration. A published version is a snapshot of your function
code and configuration that can't be changed. An alias is a named resource
that maps to a version, and can be changed to map to a different version.
Use the Publish parameter to create version 1 of
your function from its initial configuration.
The other parameters let you configure version-specific and function-level settings. You can modify version-specific settings later with UpdateFunctionConfiguration. Function-level settings apply to both the unpublished and published versions of the function, and include tags (TagResource) and per-function concurrency limits (PutFunctionConcurrency).
You can use code signing if your deployment package is a .zip file archive. To enable code signing for this function, specify the ARN of a code-signing configuration. When a user attempts to deploy a code package with UpdateFunctionCode, Lambda checks that the code package has a valid signature from a trusted publisher. The code-signing configuration includes set of signing profiles, which define the trusted publishers for this function.
If another Amazon Web Services account or an Amazon Web Services service invokes your function, use AddPermission to grant permission by creating a resource-based Identity and Access Management (IAM) policy. You can grant permissions at the function level, on a version, or on an alias.
To invoke your function directly, use Invoke. To invoke your function in response to events in other Amazon Web Services services, create an event source mapping (CreateEventSourceMapping), or configure a function trigger in the other service. For more information, see Invoking Lambda functions.
May throw CodeSigningConfigNotFoundException.
May throw CodeStorageExceededException.
May throw CodeVerificationFailedException.
May throw FunctionVersionsPerCapacityProviderLimitExceededException.
May throw InvalidCodeSignatureException.
May throw InvalidParameterValueException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter code :
The code for the function.
Parameter functionName :
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
Parameter role :
The Amazon Resource Name (ARN) of the function's execution role.
Parameter architectures :
The instruction set architecture that the function supports. Enter a
string array with one of the valid values (arm64 or x86_64). The default
value is x86_64.
Parameter capacityProviderConfig :
Configuration for the capacity provider that manages compute resources for
Lambda functions.
Parameter codeSigningConfigArn :
To enable code signing for this function, specify the ARN of a
code-signing configuration. A code-signing configuration includes a set of
signing profiles, which define the trusted publishers for this function.
Parameter deadLetterConfig :
A dead-letter queue configuration that specifies the queue or topic where
Lambda sends asynchronous events when they fail processing. For more
information, see Dead-letter
queues.
Parameter description :
A description of the function.
Parameter durableConfig :
Configuration settings for durable functions. Enables creating functions
with durability that can remember their state and continue execution even
after interruptions.
Parameter environment :
Environment variables that are accessible from function code during
execution.
Parameter ephemeralStorage :
The size of the function's /tmp directory in MB. The default
value is 512, but can be any whole number between 512 and 10,240 MB. For
more information, see Configuring
ephemeral storage (console).
Parameter fileSystemConfigs :
Connection settings for an Amazon EFS file system or an Amazon S3 Files
file system.
Parameter handler :
The name of the method within your code that Lambda calls to run your
function. Handler is required if the deployment package is a .zip file
archive. The format includes the file name. It can also include namespaces
and other qualifiers, depending on the runtime. For more information, see
Lambda
programming model.
Parameter imageConfig :
Container image configuration
values that override the values in the container image Dockerfile.
Parameter kMSKeyArn :
The ARN of the Key Management Service (KMS) customer managed key that's
used to encrypt the following resources:
- The function's environment variables.
- The function's Lambda SnapStart snapshots.
-
When used with
SourceKMSKeyArn, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see Specifying a customer managed key for Lambda. - The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see Function lifecycle.
Parameter layers :
A list of function
layers to add to the function's execution environment. Specify each
layer by its ARN, including the version.
Parameter loggingConfig :
The function's Amazon CloudWatch Logs configuration settings.
Parameter memorySize :
The amount of memory
available to the function at runtime. Increasing the function memory
also increases its CPU allocation. The default value is 128 MB. The value
can be any multiple of 1 MB.
Parameter packageType :
The type of deployment package. Set to Image for container
image and set to Zip for .zip file archive.
Parameter publish :
Set to true to publish the first version of the function during creation.
Parameter publishTo :
Specifies where to publish the function version or configuration.
Parameter runtime :
The identifier of the function's
runtime. Runtime is required if the deployment package is a .zip file
archive. Specifying a runtime results in an error if you're deploying a
function using a container image.
The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
Parameter snapStart :
The function's SnapStart
setting.
Parameter tags :
A list of tags
to apply to the function.
Parameter tenancyConfig :
Configuration for multi-tenant applications that use Lambda functions.
Defines tenant isolation settings and resource allocations. Required for
functions supporting multiple tenants.
Parameter timeout :
The amount of time (in seconds) that Lambda allows a function to run
before stopping it. The default is 3 seconds. The maximum allowed value is
900 seconds. For more information, see Lambda
execution environment.
Parameter tracingConfig :
Set Mode to Active to sample and trace a subset
of incoming requests with X-Ray.
Parameter vpcConfig :
For network connectivity to Amazon Web Services resources in a VPC,
specify a list of security groups and subnets in the VPC. When you connect
a function to a VPC, it can access resources and the internet only through
that VPC. For more information, see Configuring
a Lambda function to access resources in a VPC.
Implementation
Future<FunctionConfiguration> createFunction({
required FunctionCode code,
required String functionName,
required String role,
List<Architecture>? architectures,
CapacityProviderConfig? capacityProviderConfig,
String? codeSigningConfigArn,
DeadLetterConfig? deadLetterConfig,
String? description,
DurableConfig? durableConfig,
Environment? environment,
EphemeralStorage? ephemeralStorage,
List<FileSystemConfig>? fileSystemConfigs,
String? handler,
ImageConfig? imageConfig,
String? kMSKeyArn,
List<String>? layers,
LoggingConfig? loggingConfig,
int? memorySize,
PackageType? packageType,
bool? publish,
FunctionVersionLatestPublished? publishTo,
Runtime? runtime,
SnapStart? snapStart,
Map<String, String>? tags,
TenancyConfig? tenancyConfig,
int? timeout,
TracingConfig? tracingConfig,
VpcConfig? vpcConfig,
}) async {
_s.validateNumRange(
'memorySize',
memorySize,
128,
32768,
);
_s.validateNumRange(
'timeout',
timeout,
1,
1152921504606846976,
);
final $payload = <String, dynamic>{
'Code': code,
'FunctionName': functionName,
'Role': role,
if (architectures != null)
'Architectures': architectures.map((e) => e.value).toList(),
if (capacityProviderConfig != null)
'CapacityProviderConfig': capacityProviderConfig,
if (codeSigningConfigArn != null)
'CodeSigningConfigArn': codeSigningConfigArn,
if (deadLetterConfig != null) 'DeadLetterConfig': deadLetterConfig,
if (description != null) 'Description': description,
if (durableConfig != null) 'DurableConfig': durableConfig,
if (environment != null) 'Environment': environment,
if (ephemeralStorage != null) 'EphemeralStorage': ephemeralStorage,
if (fileSystemConfigs != null) 'FileSystemConfigs': fileSystemConfigs,
if (handler != null) 'Handler': handler,
if (imageConfig != null) 'ImageConfig': imageConfig,
if (kMSKeyArn != null) 'KMSKeyArn': kMSKeyArn,
if (layers != null) 'Layers': layers,
if (loggingConfig != null) 'LoggingConfig': loggingConfig,
if (memorySize != null) 'MemorySize': memorySize,
if (packageType != null) 'PackageType': packageType.value,
if (publish != null) 'Publish': publish,
if (publishTo != null) 'PublishTo': publishTo.value,
if (runtime != null) 'Runtime': runtime.value,
if (snapStart != null) 'SnapStart': snapStart,
if (tags != null) 'Tags': tags,
if (tenancyConfig != null) 'TenancyConfig': tenancyConfig,
if (timeout != null) 'Timeout': timeout,
if (tracingConfig != null) 'TracingConfig': tracingConfig,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2015-03-31/functions',
exceptionFnMap: _exceptionFns,
);
return FunctionConfiguration.fromJson(response);
}