deleteEventSourceMapping method
Deletes an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings.
When you delete an event source mapping, it enters a Deleting
state and might not be completely deleted for several seconds.
May throw InvalidParameterValueException.
May throw ResourceConflictException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter uuid :
The identifier of the event source mapping.
Implementation
Future<EventSourceMappingConfiguration> deleteEventSourceMapping({
required String uuid,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/2015-03-31/event-source-mappings/${Uri.encodeComponent(uuid)}',
exceptionFnMap: _exceptionFns,
);
return EventSourceMappingConfiguration.fromJson(response);
}