deleteFunctionConcurrency method

Future<void> deleteFunctionConcurrency({
  1. required String functionName,
})

Removes a concurrent execution limit from a function.

May throw InvalidParameterValueException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Implementation

Future<void> deleteFunctionConcurrency({
  required String functionName,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2017-10-31/functions/${Uri.encodeComponent(functionName)}/concurrency',
    exceptionFnMap: _exceptionFns,
  );
}