deleteFunctionUrlConfig method

Future<void> deleteFunctionUrlConfig({
  1. required String functionName,
  2. String? qualifier,
})

Deletes a Lambda function URL. When you delete a function URL, you can't recover it. Creating a new function URL results in a different URL address.

May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter qualifier : The alias name.

Implementation

Future<void> deleteFunctionUrlConfig({
  required String functionName,
  String? qualifier,
}) async {
  final $query = <String, List<String>>{
    if (qualifier != null) 'Qualifier': [qualifier],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2021-10-31/functions/${Uri.encodeComponent(functionName)}/url',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}