deleteProvisionedConcurrencyConfig method

Future<void> deleteProvisionedConcurrencyConfig({
  1. required String functionName,
  2. required String qualifier,
})

Deletes the provisioned concurrency configuration for a function.

May throw InvalidParameterValueException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter qualifier : The version number or alias name.

Implementation

Future<void> deleteProvisionedConcurrencyConfig({
  required String functionName,
  required String qualifier,
}) async {
  final $query = <String, List<String>>{
    'Qualifier': [qualifier],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2019-09-30/functions/${Uri.encodeComponent(functionName)}/provisioned-concurrency',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}