getDurableExecution method

Future<GetDurableExecutionResponse> getDurableExecution({
  1. required String durableExecutionArn,
})

Retrieves detailed information about a specific durable execution, including its current status, input payload, result or error information, and execution metadata such as start time and usage statistics.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter durableExecutionArn : The Amazon Resource Name (ARN) of the durable execution.

Implementation

Future<GetDurableExecutionResponse> getDurableExecution({
  required String durableExecutionArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2025-12-01/durable-executions/${Uri.encodeComponent(durableExecutionArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDurableExecutionResponse.fromJson(response);
}