getFunction method

Future<GetFunctionResponse> getFunction({
  1. required String functionName,
  2. String? qualifier,
})

Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes. If you specify a function version, only details that are specific to that version are returned.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function, version, or alias.

Name formats

  • Function namemy-function (name-only), my-function:v1 (with alias).
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter qualifier : Specify a version or alias to get details about a published version of the function.

Implementation

Future<GetFunctionResponse> getFunction({
  required String functionName,
  String? qualifier,
}) async {
  final $query = <String, List<String>>{
    if (qualifier != null) 'Qualifier': [qualifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2015-03-31/functions/${Uri.encodeComponent(functionName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetFunctionResponse.fromJson(response);
}