getFunctionConfiguration method

Future<FunctionConfiguration> getFunctionConfiguration({
  1. required String functionName,
  2. String? qualifier,
})

Returns the version-specific settings of a Lambda function or version. The output includes only options that can vary between versions of a function. To modify these settings, use UpdateFunctionConfiguration.

To get all of a function's details, including function-level settings, use GetFunction.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function, version, or alias.

Name formats

  • Function namemy-function (name-only), my-function:v1 (with alias).
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter qualifier : Specify a version or alias to get details about a published version of the function.

Implementation

Future<FunctionConfiguration> getFunctionConfiguration({
  required String functionName,
  String? qualifier,
}) async {
  final $query = <String, List<String>>{
    if (qualifier != null) 'Qualifier': [qualifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2015-03-31/functions/${Uri.encodeComponent(functionName)}/configuration',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return FunctionConfiguration.fromJson(response);
}