getFunctionScalingConfig method
Retrieves the scaling configuration for a Lambda Managed Instances function.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter functionName :
The name or ARN of the Lambda function.
Parameter qualifier :
Specify a version or alias to get the scaling configuration for a
published version of the function.
Implementation
Future<GetFunctionScalingConfigResponse> getFunctionScalingConfig({
required String functionName,
required String qualifier,
}) async {
final $query = <String, List<String>>{
'Qualifier': [qualifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2025-11-30/functions/${Uri.encodeComponent(functionName)}/function-scaling-config',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetFunctionScalingConfigResponse.fromJson(response);
}