getLayerVersionByArn method

Future<GetLayerVersionResponse> getLayerVersionByArn({
  1. required String arn,
})

Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter arn : The ARN of the layer version.

Implementation

Future<GetLayerVersionResponse> getLayerVersionByArn({
  required String arn,
}) async {
  final $query = <String, List<String>>{
    'Arn': [arn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2018-10-31/layers?find=LayerVersion',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetLayerVersionResponse.fromJson(response);
}