getRuntimeManagementConfig method
Retrieves the runtime management configuration for a function's version.
If the runtime update mode is Manual, this includes the ARN of the
runtime version and the runtime update mode. If the runtime update mode is
Auto or Function update, this includes the runtime update
mode and null is returned for the ARN. For more information,
see Runtime
updates.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter functionName :
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
Parameter qualifier :
Specify a version of the function. This can be $LATEST or a
published version number. If no value is specified, the configuration for
the $LATEST version is returned.
Implementation
Future<GetRuntimeManagementConfigResponse> getRuntimeManagementConfig({
required String functionName,
String? qualifier,
}) async {
final $query = <String, List<String>>{
if (qualifier != null) 'Qualifier': [qualifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-07-20/functions/${Uri.encodeComponent(functionName)}/runtime-management-config',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetRuntimeManagementConfigResponse.fromJson(response);
}