listFunctionUrlConfigs method

Future<ListFunctionUrlConfigsResponse> listFunctionUrlConfigs({
  1. required String functionName,
  2. String? marker,
  3. int? maxItems,
})

Returns a list of Lambda function URLs for the specified function.

May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter marker : Specify the pagination token that's returned by a previous request to retrieve the next page of results.

Parameter maxItems : The maximum number of function URLs to return in the response. Note that ListFunctionUrlConfigs returns a maximum of 50 items in each response, even if you set the number higher.

Implementation

Future<ListFunctionUrlConfigsResponse> listFunctionUrlConfigs({
  required String functionName,
  String? marker,
  int? maxItems,
}) async {
  _s.validateNumRange(
    'maxItems',
    maxItems,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2021-10-31/functions/${Uri.encodeComponent(functionName)}/urls',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListFunctionUrlConfigsResponse.fromJson(response);
}