listLayers method

Future<ListLayersResponse> listLayers({
  1. Architecture? compatibleArchitecture,
  2. Runtime? compatibleRuntime,
  3. String? marker,
  4. int? maxItems,
})

Lists Lambda layers and shows information about the latest version of each. Specify a runtime identifier to list only layers that indicate that they're compatible with that runtime. Specify a compatible architecture to include only layers that are compatible with that instruction set architecture.

May throw InvalidParameterValueException. May throw ServiceException. May throw TooManyRequestsException.

Parameter compatibleArchitecture : The compatible instruction set architecture.

Parameter compatibleRuntime : A runtime identifier.

The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.

For a list of all currently supported runtimes, see Supported runtimes.

Parameter marker : A pagination token returned by a previous call.

Parameter maxItems : The maximum number of layers to return.

Implementation

Future<ListLayersResponse> listLayers({
  Architecture? compatibleArchitecture,
  Runtime? compatibleRuntime,
  String? marker,
  int? maxItems,
}) async {
  _s.validateNumRange(
    'maxItems',
    maxItems,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (compatibleArchitecture != null)
      'CompatibleArchitecture': [compatibleArchitecture.value],
    if (compatibleRuntime != null)
      'CompatibleRuntime': [compatibleRuntime.value],
    if (marker != null) 'Marker': [marker],
    if (maxItems != null) 'MaxItems': [maxItems.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2018-10-31/layers',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListLayersResponse.fromJson(response);
}