putRuntimeManagementConfig method
Sets the runtime management configuration for a function's version. For more information, see Runtime updates.
May throw InvalidParameterValueException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter functionName :
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
Parameter updateRuntimeOn :
Specify the runtime update mode.
- Auto (default) - Automatically update to the most recent and secure runtime version using a Two-phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.
- Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
- Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.
Parameter qualifier :
Specify a version of the function. This can be $LATEST or a
published version number. If no value is specified, the configuration for
the $LATEST version is returned.
Parameter runtimeVersionArn :
The ARN of the runtime version you want the function to use.
Implementation
Future<PutRuntimeManagementConfigResponse> putRuntimeManagementConfig({
required String functionName,
required UpdateRuntimeOn updateRuntimeOn,
String? qualifier,
String? runtimeVersionArn,
}) async {
final $query = <String, List<String>>{
if (qualifier != null) 'Qualifier': [qualifier],
};
final $payload = <String, dynamic>{
'UpdateRuntimeOn': updateRuntimeOn.value,
if (runtimeVersionArn != null) 'RuntimeVersionArn': runtimeVersionArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/2021-07-20/functions/${Uri.encodeComponent(functionName)}/runtime-management-config',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return PutRuntimeManagementConfigResponse.fromJson(response);
}