sendDurableExecutionCallbackSuccess method

Future<void> sendDurableExecutionCallbackSuccess({
  1. required String callbackId,
  2. Uint8List? result,
})

Sends a successful completion response for a callback operation in a durable execution. Use this API when an external system has successfully completed a callback operation.

May throw CallbackTimeoutException. May throw InvalidParameterValueException. May throw ServiceException. May throw TooManyRequestsException.

Parameter callbackId : The unique identifier for the callback operation.

Parameter result : The result data from the successful callback operation. Maximum size is 256 KB.

Implementation

Future<void> sendDurableExecutionCallbackSuccess({
  required String callbackId,
  Uint8List? result,
}) async {
  final response = await _protocol.send(
    payload: result,
    method: 'POST',
    requestUri:
        '/2025-12-01/durable-execution-callbacks/${Uri.encodeComponent(callbackId)}/succeed',
    exceptionFnMap: _exceptionFns,
  );
}