tagResource method
Adds tags to a function, event source mapping, or code signing configuration.
May throw InvalidParameterValueException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter resource :
The resource's Amazon Resource Name (ARN).
Parameter tags :
A list of tags to apply to the resource.
Implementation
Future<void> tagResource({
required String resource,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2017-03-31/tags/${Uri.encodeComponent(resource)}',
exceptionFnMap: _exceptionFns,
);
}