untagResource method

Future<void> untagResource({
  1. required String resource,
  2. required List<String> tagKeys,
})

Removes tags from a function, event source mapping, or code signing configuration.

May throw InvalidParameterValueException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter resource : The resource's Amazon Resource Name (ARN).

Parameter tagKeys : A list of tag keys to remove from the resource.

Implementation

Future<void> untagResource({
  required String resource,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/2017-03-31/tags/${Uri.encodeComponent(resource)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}