updateEventSourceMapping method
- required String uuid,
- AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig,
- int? batchSize,
- bool? bisectBatchOnFunctionError,
- DestinationConfig? destinationConfig,
- DocumentDBEventSourceConfig? documentDBEventSourceConfig,
- bool? enabled,
- FilterCriteria? filterCriteria,
- String? functionName,
- List<
FunctionResponseType> ? functionResponseTypes, - String? kMSKeyArn,
- EventSourceMappingLoggingConfig? loggingConfig,
- int? maximumBatchingWindowInSeconds,
- int? maximumRecordAgeInSeconds,
- int? maximumRetryAttempts,
- EventSourceMappingMetricsConfig? metricsConfig,
- int? parallelizationFactor,
- ProvisionedPollerConfig? provisionedPollerConfig,
- ScalingConfig? scalingConfig,
- SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig,
- List<
SourceAccessConfiguration> ? sourceAccessConfigurations, - int? tumblingWindowInSeconds,
Updates an event source mapping. You can change the function that Lambda invokes, or pause invocation and resume later from the same location.
For details about how to configure different event sources, see the following topics.
- Amazon DynamoDB Streams
- Amazon Kinesis
- Amazon SQS
- Amazon MQ and RabbitMQ
- Amazon MSK
- Apache Kafka
- Amazon DocumentDB
-
BisectBatchOnFunctionError– If the function returns an error, split the batch in two and retry. -
MaximumRecordAgeInSeconds– Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires -
MaximumRetryAttempts– Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires. -
OnFailure– Send discarded records to an Amazon SQS queue, Amazon SNS topic, Kafka topic, or Amazon S3 bucket. For more information, see Adding a destination.
-
ParallelizationFactor– Process multiple batches from each shard concurrently.
- Amazon DynamoDB Streams
- Amazon Kinesis
- Amazon SQS
- Amazon MQ and RabbitMQ
- Amazon MSK
- Apache Kafka
- Amazon DocumentDB
May throw InvalidParameterValueException.
May throw ResourceConflictException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter uuid :
The identifier of the event source mapping.
Parameter batchSize :
The maximum number of records in each batch that Lambda pulls from your
stream or queue and sends to your function. Lambda passes all of the
records in the batch to the function in a single call, up to the payload
limit for synchronous invocation (6 MB).
- Amazon Kinesis – Default 100. Max 10,000.
- Amazon DynamoDB Streams – Default 100. Max 10,000.
- Amazon Simple Queue Service – Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.
- Amazon Managed Streaming for Apache Kafka – Default 100. Max 10,000.
- Self-managed Apache Kafka – Default 100. Max 10,000.
- Amazon MQ (ActiveMQ and RabbitMQ) – Default 100. Max 10,000.
- DocumentDB – Default 100. Max 10,000.
Parameter bisectBatchOnFunctionError :
(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) If
the function returns an error, split the batch in two and retry.
Parameter destinationConfig :
(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A
configuration object that specifies the destination of an event after
Lambda processes it.
Parameter documentDBEventSourceConfig :
Specific configuration settings for a DocumentDB event source.
Parameter enabled :
When true, the event source mapping is active. When false, Lambda pauses
polling and invocation.
Default: True
Parameter filterCriteria :
An object that defines the filter criteria that determine whether Lambda
should process an event. For more information, see Lambda
event filtering.
Parameter functionName :
The name or ARN of the Lambda function.
Name formats
-
Function name –
MyFunction. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Version or Alias ARN –
arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD. -
Partial ARN –
123456789012:function:MyFunction.
Parameter functionResponseTypes :
(Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and
Amazon SQS) A list of current response type enums applied to the event
source mapping.
Parameter kMSKeyArn :
The ARN of the Key Management Service (KMS) customer managed key that
Lambda uses to encrypt your function's filter
criteria. By default, Lambda does not encrypt your filter criteria
object. Specify this property to encrypt data using your own customer
managed key.
Parameter maximumBatchingWindowInSeconds :
The maximum amount of time, in seconds, that Lambda spends gathering
records before invoking the function. You can configure
MaximumBatchingWindowInSeconds to any value from 0 seconds to
300 seconds in increments of seconds.
For Kinesis, DynamoDB, and Amazon SQS event sources, the default batching
window is 0 seconds. For Amazon MSK, Self-managed Apache Kafka, Amazon MQ,
and DocumentDB event sources, the default batching window is 500 ms. Note
that because you can only change
MaximumBatchingWindowInSeconds in increments of seconds, you
cannot revert back to the 500 ms default batching window after you have
changed it. To restore the default batching window, you must create a new
event source mapping.
Related setting: For Kinesis, DynamoDB, and Amazon SQS event sources, when
you set BatchSize to a value greater than 10, you must set
MaximumBatchingWindowInSeconds to at least 1.
Parameter maximumRecordAgeInSeconds :
(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka)
Discard records older than the specified age. The default value is
infinite (-1).
Parameter maximumRetryAttempts :
(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka)
Discard records after the specified number of retries. The default value
is infinite (-1). When set to infinite (-1), failed records are retried
until the record expires.
Parameter metricsConfig :
The metrics configuration for your event source. For more information, see
Event
source mapping metrics.
Parameter parallelizationFactor :
(Kinesis and DynamoDB Streams only) The number of batches to process from
each shard concurrently.
Parameter provisionedPollerConfig :
(Amazon SQS, Amazon MSK, and self-managed Apache Kafka only) The
provisioned mode configuration for the event source. For more information,
see provisioned
mode.
Parameter scalingConfig :
(Amazon SQS only) The scaling configuration for the event source. For more
information, see Configuring
maximum concurrency for Amazon SQS event sources.
Parameter sourceAccessConfigurations :
An array of authentication protocols or VPC components required to secure
your event source.
Parameter tumblingWindowInSeconds :
(Kinesis and DynamoDB Streams only) The duration in seconds of a
processing window for DynamoDB and Kinesis Streams event sources. A value
of 0 seconds indicates no tumbling window.
Implementation
Future<EventSourceMappingConfiguration> updateEventSourceMapping({
required String uuid,
AmazonManagedKafkaEventSourceConfig? amazonManagedKafkaEventSourceConfig,
int? batchSize,
bool? bisectBatchOnFunctionError,
DestinationConfig? destinationConfig,
DocumentDBEventSourceConfig? documentDBEventSourceConfig,
bool? enabled,
FilterCriteria? filterCriteria,
String? functionName,
List<FunctionResponseType>? functionResponseTypes,
String? kMSKeyArn,
EventSourceMappingLoggingConfig? loggingConfig,
int? maximumBatchingWindowInSeconds,
int? maximumRecordAgeInSeconds,
int? maximumRetryAttempts,
EventSourceMappingMetricsConfig? metricsConfig,
int? parallelizationFactor,
ProvisionedPollerConfig? provisionedPollerConfig,
ScalingConfig? scalingConfig,
SelfManagedKafkaEventSourceConfig? selfManagedKafkaEventSourceConfig,
List<SourceAccessConfiguration>? sourceAccessConfigurations,
int? tumblingWindowInSeconds,
}) async {
_s.validateNumRange(
'batchSize',
batchSize,
1,
10000,
);
_s.validateNumRange(
'maximumBatchingWindowInSeconds',
maximumBatchingWindowInSeconds,
0,
300,
);
_s.validateNumRange(
'maximumRecordAgeInSeconds',
maximumRecordAgeInSeconds,
-1,
604800,
);
_s.validateNumRange(
'maximumRetryAttempts',
maximumRetryAttempts,
-1,
10000,
);
_s.validateNumRange(
'parallelizationFactor',
parallelizationFactor,
1,
10,
);
_s.validateNumRange(
'tumblingWindowInSeconds',
tumblingWindowInSeconds,
0,
900,
);
final $payload = <String, dynamic>{
if (amazonManagedKafkaEventSourceConfig != null)
'AmazonManagedKafkaEventSourceConfig':
amazonManagedKafkaEventSourceConfig,
if (batchSize != null) 'BatchSize': batchSize,
if (bisectBatchOnFunctionError != null)
'BisectBatchOnFunctionError': bisectBatchOnFunctionError,
if (destinationConfig != null) 'DestinationConfig': destinationConfig,
if (documentDBEventSourceConfig != null)
'DocumentDBEventSourceConfig': documentDBEventSourceConfig,
if (enabled != null) 'Enabled': enabled,
if (filterCriteria != null) 'FilterCriteria': filterCriteria,
if (functionName != null) 'FunctionName': functionName,
if (functionResponseTypes != null)
'FunctionResponseTypes':
functionResponseTypes.map((e) => e.value).toList(),
if (kMSKeyArn != null) 'KMSKeyArn': kMSKeyArn,
if (loggingConfig != null) 'LoggingConfig': loggingConfig,
if (maximumBatchingWindowInSeconds != null)
'MaximumBatchingWindowInSeconds': maximumBatchingWindowInSeconds,
if (maximumRecordAgeInSeconds != null)
'MaximumRecordAgeInSeconds': maximumRecordAgeInSeconds,
if (maximumRetryAttempts != null)
'MaximumRetryAttempts': maximumRetryAttempts,
if (metricsConfig != null) 'MetricsConfig': metricsConfig,
if (parallelizationFactor != null)
'ParallelizationFactor': parallelizationFactor,
if (provisionedPollerConfig != null)
'ProvisionedPollerConfig': provisionedPollerConfig,
if (scalingConfig != null) 'ScalingConfig': scalingConfig,
if (selfManagedKafkaEventSourceConfig != null)
'SelfManagedKafkaEventSourceConfig': selfManagedKafkaEventSourceConfig,
if (sourceAccessConfigurations != null)
'SourceAccessConfigurations': sourceAccessConfigurations,
if (tumblingWindowInSeconds != null)
'TumblingWindowInSeconds': tumblingWindowInSeconds,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/2015-03-31/event-source-mappings/${Uri.encodeComponent(uuid)}',
exceptionFnMap: _exceptionFns,
);
return EventSourceMappingConfiguration.fromJson(response);
}