updateFunctionConfiguration method

Future<FunctionConfiguration> updateFunctionConfiguration({
  1. required String functionName,
  2. CapacityProviderConfig? capacityProviderConfig,
  3. DeadLetterConfig? deadLetterConfig,
  4. String? description,
  5. DurableConfig? durableConfig,
  6. Environment? environment,
  7. EphemeralStorage? ephemeralStorage,
  8. List<FileSystemConfig>? fileSystemConfigs,
  9. String? handler,
  10. ImageConfig? imageConfig,
  11. String? kMSKeyArn,
  12. List<String>? layers,
  13. LoggingConfig? loggingConfig,
  14. int? memorySize,
  15. String? revisionId,
  16. String? role,
  17. Runtime? runtime,
  18. SnapStart? snapStart,
  19. int? timeout,
  20. TracingConfig? tracingConfig,
  21. VpcConfig? vpcConfig,
})

Modify the version-specific settings of a Lambda function.

When you update a function, Lambda provisions an instance of the function and its supporting resources. If your function connects to a VPC, this process can take a minute. During this time, you can't modify the function, but you can still invoke it. The LastUpdateStatus, LastUpdateStatusReason, and LastUpdateStatusReasonCode fields in the response from GetFunctionConfiguration indicate when the update is complete and the function is processing events with the new configuration. For more information, see Lambda function states.

These settings can vary between versions of a function and are locked when you publish a version. You can't modify the configuration of a published version, only the unpublished version.

To configure function concurrency, use PutFunctionConcurrency. To grant invoke permissions to an Amazon Web Services account or Amazon Web Services service, use AddPermission.

May throw CodeSigningConfigNotFoundException. May throw CodeVerificationFailedException. May throw InvalidCodeSignatureException. May throw InvalidParameterValueException. May throw PreconditionFailedException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter capacityProviderConfig : Configuration for the capacity provider that manages compute resources for Lambda functions.

Parameter deadLetterConfig : A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead-letter queues.

Parameter description : A description of the function.

Parameter durableConfig : Configuration settings for durable functions. Allows updating execution timeout and retention period for functions with durability enabled.

Parameter environment : Environment variables that are accessible from function code during execution.

Parameter ephemeralStorage : The size of the function's /tmp directory in MB. The default value is 512, but can be any whole number between 512 and 10,240 MB. For more information, see Configuring ephemeral storage (console).

Parameter fileSystemConfigs : Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.

Parameter handler : The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Lambda programming model.

Parameter imageConfig : Container image configuration values that override the values in the container image Docker file.

Parameter kMSKeyArn : The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:

  • The function's environment variables.
  • The function's Lambda SnapStart snapshots.
  • When used with SourceKMSKeyArn, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see Specifying a customer managed key for Lambda.
  • The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see Function lifecycle.
If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key or an Amazon Web Services managed key.

Parameter layers : A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version.

Parameter loggingConfig : The function's Amazon CloudWatch Logs configuration settings.

Parameter memorySize : The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB.

Parameter revisionId : Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.

Parameter role : The Amazon Resource Name (ARN) of the function's execution role.

Parameter runtime : The identifier of the function's runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you're deploying a function using a container image.

The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation.

For a list of all currently supported runtimes, see Supported runtimes.

Parameter snapStart : The function's SnapStart setting.

Parameter timeout : The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see Lambda execution environment.

Parameter tracingConfig : Set Mode to Active to sample and trace a subset of incoming requests with X-Ray.

Parameter vpcConfig : For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see Configuring a Lambda function to access resources in a VPC.

Implementation

Future<FunctionConfiguration> updateFunctionConfiguration({
  required String functionName,
  CapacityProviderConfig? capacityProviderConfig,
  DeadLetterConfig? deadLetterConfig,
  String? description,
  DurableConfig? durableConfig,
  Environment? environment,
  EphemeralStorage? ephemeralStorage,
  List<FileSystemConfig>? fileSystemConfigs,
  String? handler,
  ImageConfig? imageConfig,
  String? kMSKeyArn,
  List<String>? layers,
  LoggingConfig? loggingConfig,
  int? memorySize,
  String? revisionId,
  String? role,
  Runtime? runtime,
  SnapStart? snapStart,
  int? timeout,
  TracingConfig? tracingConfig,
  VpcConfig? vpcConfig,
}) async {
  _s.validateNumRange(
    'memorySize',
    memorySize,
    128,
    32768,
  );
  _s.validateNumRange(
    'timeout',
    timeout,
    1,
    1152921504606846976,
  );
  final $payload = <String, dynamic>{
    if (capacityProviderConfig != null)
      'CapacityProviderConfig': capacityProviderConfig,
    if (deadLetterConfig != null) 'DeadLetterConfig': deadLetterConfig,
    if (description != null) 'Description': description,
    if (durableConfig != null) 'DurableConfig': durableConfig,
    if (environment != null) 'Environment': environment,
    if (ephemeralStorage != null) 'EphemeralStorage': ephemeralStorage,
    if (fileSystemConfigs != null) 'FileSystemConfigs': fileSystemConfigs,
    if (handler != null) 'Handler': handler,
    if (imageConfig != null) 'ImageConfig': imageConfig,
    if (kMSKeyArn != null) 'KMSKeyArn': kMSKeyArn,
    if (layers != null) 'Layers': layers,
    if (loggingConfig != null) 'LoggingConfig': loggingConfig,
    if (memorySize != null) 'MemorySize': memorySize,
    if (revisionId != null) 'RevisionId': revisionId,
    if (role != null) 'Role': role,
    if (runtime != null) 'Runtime': runtime.value,
    if (snapStart != null) 'SnapStart': snapStart,
    if (timeout != null) 'Timeout': timeout,
    if (tracingConfig != null) 'TracingConfig': tracingConfig,
    if (vpcConfig != null) 'VpcConfig': vpcConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/2015-03-31/functions/${Uri.encodeComponent(functionName)}/configuration',
    exceptionFnMap: _exceptionFns,
  );
  return FunctionConfiguration.fromJson(response);
}