LaunchWizard class

Launch Wizard offers a guided way of sizing, configuring, and deploying Amazon Web Services resources for third party applications, such as Microsoft SQL Server Always On and HANA based SAP systems, without the need to manually identify and provision individual Amazon Web Services resources.

Constructors

LaunchWizard({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createDeployment({required String deploymentPatternName, required String name, required Map<String, String> specifications, required String workloadName, bool? dryRun, Map<String, String>? tags}) Future<CreateDeploymentOutput>
Creates a deployment for the given workload. Deployments created by this operation are not available in the Launch Wizard console to use the Clone deployment action on.
deleteDeployment({required String deploymentId}) Future<DeleteDeploymentOutput>
Deletes a deployment.
getDeployment({required String deploymentId}) Future<GetDeploymentOutput>
Returns information about the deployment.
getDeploymentPatternVersion({required String deploymentPatternName, required String deploymentPatternVersionName, required String workloadName}) Future<GetDeploymentPatternVersionOutput>
Returns information about a deployment pattern version.
getWorkload({required String workloadName}) Future<GetWorkloadOutput>
Returns information about a workload.
getWorkloadDeploymentPattern({required String deploymentPatternName, required String workloadName}) Future<GetWorkloadDeploymentPatternOutput>
Returns details for a given workload and deployment pattern, including the available specifications. You can use the ListWorkloads operation to discover the available workload names and the ListWorkloadDeploymentPatterns operation to discover the available deployment pattern names of a given workload.
listDeploymentEvents({required String deploymentId, int? maxResults, String? nextToken}) Future<ListDeploymentEventsOutput>
Lists the events of a deployment.
listDeploymentPatternVersions({required String deploymentPatternName, required String workloadName, List<DeploymentPatternVersionFilter>? filters, int? maxResults, String? nextToken}) Future<ListDeploymentPatternVersionsOutput>
Lists the deployment pattern versions.
listDeployments({List<DeploymentFilter>? filters, int? maxResults, String? nextToken}) Future<ListDeploymentsOutput>
Lists the deployments that have been created.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists the tags associated with a specified resource.
listWorkloadDeploymentPatterns({required String workloadName, int? maxResults, String? nextToken}) Future<ListWorkloadDeploymentPatternsOutput>
Lists the workload deployment patterns for a given workload name. You can use the ListWorkloads operation to discover the available workload names.
listWorkloads({int? maxResults, String? nextToken}) Future<ListWorkloadsOutput>
Lists the available workload names. You can use the ListWorkloadDeploymentPatterns operation to discover the available deployment patterns for a given workload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds the specified tags to the given resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified tags from the given resource.
updateDeployment({required String deploymentId, required Map<String, String> specifications, String? deploymentPatternVersionName, bool? dryRun, bool? force, String? workloadVersionName}) Future<UpdateDeploymentOutput>
Updates a deployment.

Operators

operator ==(Object other) bool
The equality operator.
inherited