getDeploymentPatternVersion method

Future<GetDeploymentPatternVersionOutput> getDeploymentPatternVersion({
  1. required String deploymentPatternName,
  2. required String deploymentPatternVersionName,
  3. required String workloadName,
})

Returns information about a deployment pattern version.

May throw InternalServerException. May throw ResourceNotFoundException.

Parameter deploymentPatternName : The name of the deployment pattern. You can use the ListWorkloadDeploymentPatterns operation to discover supported values for this parameter.

Parameter deploymentPatternVersionName : The name of the deployment pattern version.

Parameter workloadName : The name of the workload. You can use the ListWorkloads operation to discover supported values for this parameter.

Implementation

Future<GetDeploymentPatternVersionOutput> getDeploymentPatternVersion({
  required String deploymentPatternName,
  required String deploymentPatternVersionName,
  required String workloadName,
}) async {
  final $payload = <String, dynamic>{
    'deploymentPatternName': deploymentPatternName,
    'deploymentPatternVersionName': deploymentPatternVersionName,
    'workloadName': workloadName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/getDeploymentPatternVersion',
    exceptionFnMap: _exceptionFns,
  );
  return GetDeploymentPatternVersionOutput.fromJson(response);
}