listDeployments method
Lists the deployments that have been created.
May throw InternalServerException.
May throw ValidationException.
Parameter filters :
Filters to scope the results. The following filters are supported:
-
WORKLOAD_NAME- The name used in deployments. -
DEPLOYMENT_STATUS-COMPLETED|CREATING|DELETE_IN_PROGRESS|DELETE_INITIATING|DELETE_FAILED|DELETED|FAILED|IN_PROGRESS|VALIDATING
Parameter maxResults :
The maximum number of items to return for this request. To get the next
page of items, make another request with the token returned in the output.
Parameter nextToken :
The token returned from a previous paginated request. Pagination continues
from the end of the items returned by the previous request.
Implementation
Future<ListDeploymentsOutput> listDeployments({
List<DeploymentFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listDeployments',
exceptionFnMap: _exceptionFns,
);
return ListDeploymentsOutput.fromJson(response);
}