listWorkloadDeploymentPatterns method
Lists the workload deployment patterns for a given workload name. You can use the ListWorkloads operation to discover the available workload names.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter workloadName :
The name of the workload.
Parameter maxResults :
The maximum number of items to return for this request. To get the next
page of items, make another request with the token returned in the output.
Parameter nextToken :
The token returned from a previous paginated request. Pagination continues
from the end of the items returned by the previous request.
Implementation
Future<ListWorkloadDeploymentPatternsOutput> listWorkloadDeploymentPatterns({
required String workloadName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'workloadName': workloadName,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listWorkloadDeploymentPatterns',
exceptionFnMap: _exceptionFns,
);
return ListWorkloadDeploymentPatternsOutput.fromJson(response);
}