listWorkloads method

Future<ListWorkloadsOutput> listWorkloads({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the available workload names. You can use the ListWorkloadDeploymentPatterns operation to discover the available deployment patterns for a given workload.

May throw InternalServerException. May throw ValidationException.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Implementation

Future<ListWorkloadsOutput> listWorkloads({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/listWorkloads',
    exceptionFnMap: _exceptionFns,
  );
  return ListWorkloadsOutput.fromJson(response);
}