deleteBotChannelAssociation method

Future<void> deleteBotChannelAssociation({
  1. required String botAlias,
  2. required String botName,
  3. required String name,
})

Deletes the association between an Amazon Lex bot and a messaging platform.

This operation requires permission for the lex:DeleteBotChannelAssociation action.

May throw BadRequestException. May throw ConflictException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter botAlias : An alias that points to the specific version of the Amazon Lex bot to which this association is being made.

Parameter botName : The name of the Amazon Lex bot.

Parameter name : The name of the association. The name is case sensitive.

Implementation

Future<void> deleteBotChannelAssociation({
  required String botAlias,
  required String botName,
  required String name,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/bots/${Uri.encodeComponent(botName)}/aliases/${Uri.encodeComponent(botAlias)}/channels/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
}