getBotChannelAssociation method

Future<GetBotChannelAssociationResponse> getBotChannelAssociation({
  1. required String botAlias,
  2. required String botName,
  3. required String name,
})

Returns information about the association between an Amazon Lex bot and a messaging platform.

This operation requires permissions for the lex:GetBotChannelAssociation action.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter botAlias : An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.

Parameter botName : The name of the Amazon Lex bot.

Parameter name : The name of the association between the bot and the channel. The name is case sensitive.

Implementation

Future<GetBotChannelAssociationResponse> getBotChannelAssociation({
  required String botAlias,
  required String botName,
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/bots/${Uri.encodeComponent(botName)}/aliases/${Uri.encodeComponent(botAlias)}/channels/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetBotChannelAssociationResponse.fromJson(response);
}