getBotVersions method

Future<GetBotVersionsResponse> getBotVersions({
  1. required String name,
  2. int? maxResults,
  3. String? nextToken,
})

Gets information about all of the versions of a bot.

The GetBotVersions operation returns a BotMetadata object for each version of a bot. For example, if a bot has three numbered versions, the GetBotVersions operation returns four BotMetadata objects in the response, one for each numbered version and one for the $LATEST version.

The GetBotVersions operation always returns at least one version, the $LATEST version.

This operation requires permissions for the lex:GetBotVersions action.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter name : The name of the bot for which versions should be returned.

Parameter maxResults : The maximum number of bot versions to return in the response. The default is 10.

Parameter nextToken : A pagination token for fetching the next page of bot versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request.

Implementation

Future<GetBotVersionsResponse> getBotVersions({
  required String name,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/bots/${Uri.encodeComponent(name)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetBotVersionsResponse.fromJson(response);
}