getImport method
Gets information about an import job started with the
StartImport operation.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter importId :
The identifier of the import job information to return.
Implementation
Future<GetImportResponse> getImport({
required String importId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/imports/${Uri.encodeComponent(importId)}',
exceptionFnMap: _exceptionFns,
);
return GetImportResponse.fromJson(response);
}