getMigration method

Future<GetMigrationResponse> getMigration({
  1. required String migrationId,
})

Provides details about an ongoing or complete migration from an Amazon Lex V1 bot to an Amazon Lex V2 bot. Use this operation to view the migration alerts and warnings related to the migration.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter migrationId : The unique identifier of the migration to view. The migrationID is returned by the operation.

Implementation

Future<GetMigrationResponse> getMigration({
  required String migrationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/migrations/${Uri.encodeComponent(migrationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMigrationResponse.fromJson(response);
}