lex_model_building_service_2017_04_19 library

Classes

AwsClientCredentials
AWS credentials.
LexModelBuilding
Amazon Lex is an AWS service for building conversational voice and text interfaces. Use these actions to create, update, and delete conversational bots for new and existing client applications.