LexModelsV2 class

Amazon Lex Model Building Service provides APIs for creating, managing, and deploying conversational bots and their components.

Constructors

LexModelsV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchCreateCustomVocabularyItem({required String botId, required String botVersion, required List<NewCustomVocabularyItem> customVocabularyItemList, required String localeId}) Future<BatchCreateCustomVocabularyItemResponse>
Create a batch of custom vocabulary items for a given bot locale's custom vocabulary.
batchDeleteCustomVocabularyItem({required String botId, required String botVersion, required List<CustomVocabularyEntryId> customVocabularyItemList, required String localeId}) Future<BatchDeleteCustomVocabularyItemResponse>
Delete a batch of custom vocabulary items for a given bot locale's custom vocabulary.
batchUpdateCustomVocabularyItem({required String botId, required String botVersion, required List<CustomVocabularyItem> customVocabularyItemList, required String localeId}) Future<BatchUpdateCustomVocabularyItemResponse>
Update a batch of custom vocabulary items for a given bot locale's custom vocabulary.
buildBotLocale({required String botId, required String botVersion, required String localeId}) Future<BuildBotLocaleResponse>
Builds a bot, its intents, and its slot types into a specific locale. A bot can be built into multiple locales. At runtime the locale is used to choose a specific build of the bot.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createBot({required String botName, required DataPrivacy dataPrivacy, required int idleSessionTTLInSeconds, required String roleArn, List<BotMember>? botMembers, Map<String, String>? botTags, BotType? botType, String? description, ErrorLogSettings? errorLogSettings, Map<String, String>? testBotAliasTags}) Future<CreateBotResponse>
Creates an Amazon Lex conversational bot.
createBotAlias({required String botAliasName, required String botId, Map<String, BotAliasLocaleSettings>? botAliasLocaleSettings, String? botVersion, ConversationLogSettings? conversationLogSettings, String? description, SentimentAnalysisSettings? sentimentAnalysisSettings, Map<String, String>? tags}) Future<CreateBotAliasResponse>
Creates an alias for the specified version of a bot. Use an alias to enable you to change the version of a bot without updating applications that use the bot.
createBotLocale({required String botId, required String botVersion, required String localeId, required double nluIntentConfidenceThreshold, AudioFillerSettings? audioFillerSettings, String? description, GenerativeAISettings? generativeAISettings, SpeechDetectionSensitivity? speechDetectionSensitivity, SpeechRecognitionSettings? speechRecognitionSettings, UnifiedSpeechSettings? unifiedSpeechSettings, VoiceSettings? voiceSettings}) Future<CreateBotLocaleResponse>
Creates a locale in the bot. The locale contains the intents and slot types that the bot uses in conversations with users in the specified language and locale. You must add a locale to a bot before you can add intents and slot types to the bot.
createBotReplica({required String botId, required String replicaRegion}) Future<CreateBotReplicaResponse>
Action to create a replication of the source bot in the secondary region.
createBotVersion({required String botId, required Map<String, BotVersionLocaleDetails> botVersionLocaleSpecification, String? description}) Future<CreateBotVersionResponse>
Creates an immutable version of the bot. When you create the first version of a bot, Amazon Lex sets the version number to 1. Subsequent bot versions increase in an increment of 1. The version number will always represent the total number of versions created of the bot, not the current number of versions. If a bot version is deleted, that bot version number will not be reused.
createExport({required ImportExportFileFormat fileFormat, required ExportResourceSpecification resourceSpecification, String? filePassword}) Future<CreateExportResponse>
Creates a zip archive containing the contents of a bot or a bot locale. The archive contains a directory structure that contains JSON files that define the bot.
createIntent({required String botId, required String botVersion, required String intentName, required String localeId, String? description, DialogCodeHookSettings? dialogCodeHook, FulfillmentCodeHookSettings? fulfillmentCodeHook, InitialResponseSetting? initialResponseSetting, List<InputContext>? inputContexts, IntentClosingSetting? intentClosingSetting, IntentConfirmationSetting? intentConfirmationSetting, String? intentDisplayName, KendraConfiguration? kendraConfiguration, List<OutputContext>? outputContexts, String? parentIntentSignature, QInConnectIntentConfiguration? qInConnectIntentConfiguration, QnAIntentConfiguration? qnAIntentConfiguration, List<SampleUtterance>? sampleUtterances}) Future<CreateIntentResponse>
Creates an intent.
createResourcePolicy({required String policy, required String resourceArn}) Future<CreateResourcePolicyResponse>
Creates a new resource policy with the specified policy statements.
createResourcePolicyStatement({required List<String> action, required Effect effect, required List<Principal> principal, required String resourceArn, required String statementId, Map<String, Map<String, String>>? condition, String? expectedRevisionId}) Future<CreateResourcePolicyStatementResponse>
Adds a new resource policy statement to a bot or bot alias. If a resource policy exists, the statement is added to the current resource policy. If a policy doesn't exist, a new policy is created.
createSlot({required String botId, required String botVersion, required String intentId, required String localeId, required String slotName, required SlotValueElicitationSetting valueElicitationSetting, String? description, MultipleValuesSetting? multipleValuesSetting, ObfuscationSetting? obfuscationSetting, String? slotTypeId, SubSlotSetting? subSlotSetting}) Future<CreateSlotResponse>
Creates a slot in an intent. A slot is a variable needed to fulfill an intent. For example, an OrderPizza intent might need slots for size, crust, and number of pizzas. For each slot, you define one or more utterances that Amazon Lex uses to elicit a response from the user.
createSlotType({required String botId, required String botVersion, required String localeId, required String slotTypeName, CompositeSlotTypeSetting? compositeSlotTypeSetting, String? description, ExternalSourceSetting? externalSourceSetting, String? parentSlotTypeSignature, List<SlotTypeValue>? slotTypeValues, SlotValueSelectionSetting? valueSelectionSetting}) Future<CreateSlotTypeResponse>
Creates a custom slot type
createTestSetDiscrepancyReport({required TestSetDiscrepancyReportResourceTarget target, required String testSetId}) Future<CreateTestSetDiscrepancyReportResponse>
Create a report that describes the differences between the bot and the test set.
createUploadUrl() Future<CreateUploadUrlResponse>
Gets a pre-signed S3 write URL that you use to upload the zip archive when importing a bot or a bot locale.
deleteBot({required String botId, bool? skipResourceInUseCheck}) Future<DeleteBotResponse>
Deletes all versions of a bot, including the Draft version. To delete a specific version, use the DeleteBotVersion operation.
deleteBotAlias({required String botAliasId, required String botId, bool? skipResourceInUseCheck}) Future<DeleteBotAliasResponse>
Deletes the specified bot alias.
deleteBotAnalyzerRecommendation({required String botAnalyzerRequestId, required String botId}) Future<void>
Permanently deletes the recommendations and analysis results for a specific bot analysis request. This operation is provided for GDPR compliance and cannot be undone.
deleteBotLocale({required String botId, required String botVersion, required String localeId}) Future<DeleteBotLocaleResponse>
Removes a locale from a bot.
deleteBotReplica({required String botId, required String replicaRegion}) Future<DeleteBotReplicaResponse>
The action to delete the replicated bot in the secondary region.
deleteBotVersion({required String botId, required String botVersion, bool? skipResourceInUseCheck}) Future<DeleteBotVersionResponse>
Deletes a specific version of a bot. To delete all versions of a bot, use the DeleteBot operation.
deleteCustomVocabulary({required String botId, required String botVersion, required String localeId}) Future<DeleteCustomVocabularyResponse>
Removes a custom vocabulary from the specified locale in the specified bot.
deleteExport({required String exportId}) Future<DeleteExportResponse>
Removes a previous export and the associated files stored in an S3 bucket.
deleteImport({required String importId}) Future<DeleteImportResponse>
Removes a previous import and the associated file stored in an S3 bucket.
deleteIntent({required String botId, required String botVersion, required String intentId, required String localeId}) Future<void>
Removes the specified intent.
deleteResourcePolicy({required String resourceArn, String? expectedRevisionId}) Future<DeleteResourcePolicyResponse>
Removes an existing policy from a bot or bot alias. If the resource doesn't have a policy attached, Amazon Lex returns an exception.
deleteResourcePolicyStatement({required String resourceArn, required String statementId, String? expectedRevisionId}) Future<DeleteResourcePolicyStatementResponse>
Deletes a policy statement from a resource policy. If you delete the last statement from a policy, the policy is deleted. If you specify a statement ID that doesn't exist in the policy, or if the bot or bot alias doesn't have a policy attached, Amazon Lex returns an exception.
deleteSlot({required String botId, required String botVersion, required String intentId, required String localeId, required String slotId}) Future<void>
Deletes the specified slot from an intent.
deleteSlotType({required String botId, required String botVersion, required String localeId, required String slotTypeId, bool? skipResourceInUseCheck}) Future<void>
Deletes a slot type from a bot locale.
deleteTestSet({required String testSetId}) Future<void>
The action to delete the selected test set.
deleteUtterances({required String botId, String? localeId, String? sessionId}) Future<void>
Deletes stored utterances.
describeBot({required String botId}) Future<DescribeBotResponse>
Provides metadata information about a bot.
describeBotAlias({required String botAliasId, required String botId}) Future<DescribeBotAliasResponse>
Get information about a specific bot alias.
describeBotAnalyzerRecommendation({required String botAnalyzerRequestId, required String botId, int? maxResults, String? nextToken}) Future<DescribeBotAnalyzerRecommendationResponse>
Retrieves the analysis results and recommendations for bot optimization. The analysis must be in Available status before recommendations can be retrieved.
describeBotLocale({required String botId, required String botVersion, required String localeId}) Future<DescribeBotLocaleResponse>
Describes the settings that a bot has for a specific locale.
describeBotRecommendation({required String botId, required String botRecommendationId, required String botVersion, required String localeId}) Future<DescribeBotRecommendationResponse>
Provides metadata information about a bot recommendation. This information will enable you to get a description on the request inputs, to download associated transcripts after processing is complete, and to download intents and slot-types generated by the bot recommendation.
describeBotReplica({required String botId, required String replicaRegion}) Future<DescribeBotReplicaResponse>
Monitors the bot replication status through the UI console.
describeBotResourceGeneration({required String botId, required String botVersion, required String generationId, required String localeId}) Future<DescribeBotResourceGenerationResponse>
Returns information about a request to generate a bot through natural language description, made through the StartBotResource API. Use the generatedBotLocaleUrl to retrieve the Amazon S3 object containing the bot locale configuration. You can then modify and import this configuration.
describeBotVersion({required String botId, required String botVersion}) Future<DescribeBotVersionResponse>
Provides metadata about a version of a bot.
describeCustomVocabularyMetadata({required String botId, required String botVersion, required String localeId}) Future<DescribeCustomVocabularyMetadataResponse>
Provides metadata information about a custom vocabulary.
describeExport({required String exportId}) Future<DescribeExportResponse>
Gets information about a specific export.
describeImport({required String importId}) Future<DescribeImportResponse>
Gets information about a specific import.
describeIntent({required String botId, required String botVersion, required String intentId, required String localeId}) Future<DescribeIntentResponse>
Returns metadata about an intent.
describeResourcePolicy({required String resourceArn}) Future<DescribeResourcePolicyResponse>
Gets the resource policy and policy revision for a bot or bot alias.
describeSlot({required String botId, required String botVersion, required String intentId, required String localeId, required String slotId}) Future<DescribeSlotResponse>
Gets metadata information about a slot.
describeSlotType({required String botId, required String botVersion, required String localeId, required String slotTypeId}) Future<DescribeSlotTypeResponse>
Gets metadata information about a slot type.
describeTestExecution({required String testExecutionId}) Future<DescribeTestExecutionResponse>
Gets metadata information about the test execution.
describeTestSet({required String testSetId}) Future<DescribeTestSetResponse>
Gets metadata information about the test set.
describeTestSetDiscrepancyReport({required String testSetDiscrepancyReportId}) Future<DescribeTestSetDiscrepancyReportResponse>
Gets metadata information about the test set discrepancy report.
describeTestSetGeneration({required String testSetGenerationId}) Future<DescribeTestSetGenerationResponse>
Gets metadata information about the test set generation.
generateBotElement({required String botId, required String botVersion, required String intentId, required String localeId}) Future<GenerateBotElementResponse>
Generates sample utterances for an intent.
getTestExecutionArtifactsUrl({required String testExecutionId}) Future<GetTestExecutionArtifactsUrlResponse>
The pre-signed Amazon S3 URL to download the test execution result artifacts.
listAggregatedUtterances({required UtteranceAggregationDuration aggregationDuration, required String botId, required String localeId, String? botAliasId, String? botVersion, List<AggregatedUtterancesFilter>? filters, int? maxResults, String? nextToken, AggregatedUtterancesSortBy? sortBy}) Future<ListAggregatedUtterancesResponse>
Provides a list of utterances that users have sent to the bot.
listBotAliases({required String botId, int? maxResults, String? nextToken}) Future<ListBotAliasesResponse>
Gets a list of aliases for the specified bot.
listBotAliasReplicas({required String botId, required String replicaRegion, int? maxResults, String? nextToken}) Future<ListBotAliasReplicasResponse>
The action to list the replicated bots created from the source bot alias.
listBotAnalyzerHistory({required String botId, String? botVersion, String? localeId, int? maxResults, String? nextToken}) Future<ListBotAnalyzerHistoryResponse>
Retrieves a list of historical bot analysis executions for a specific bot. You can filter the results by locale and bot version.
listBotLocales({required String botId, required String botVersion, List<BotLocaleFilter>? filters, int? maxResults, String? nextToken, BotLocaleSortBy? sortBy}) Future<ListBotLocalesResponse>
Gets a list of locales for the specified bot.
listBotRecommendations({required String botId, required String botVersion, required String localeId, int? maxResults, String? nextToken}) Future<ListBotRecommendationsResponse>
Get a list of bot recommendations that meet the specified criteria.
listBotReplicas({required String botId}) Future<ListBotReplicasResponse>
The action to list the replicated bots.
listBotResourceGenerations({required String botId, required String botVersion, required String localeId, int? maxResults, String? nextToken, GenerationSortBy? sortBy}) Future<ListBotResourceGenerationsResponse>
Lists the generation requests made for a bot locale.
listBots({List<BotFilter>? filters, int? maxResults, String? nextToken, BotSortBy? sortBy}) Future<ListBotsResponse>
Gets a list of available bots.
listBotVersionReplicas({required String botId, required String replicaRegion, int? maxResults, String? nextToken, BotVersionReplicaSortBy? sortBy}) Future<ListBotVersionReplicasResponse>
Contains information about all the versions replication statuses applicable for Global Resiliency.
listBotVersions({required String botId, int? maxResults, String? nextToken, BotVersionSortBy? sortBy}) Future<ListBotVersionsResponse>
Gets information about all of the versions of a bot.
listBuiltInIntents({required String localeId, int? maxResults, String? nextToken, BuiltInIntentSortBy? sortBy}) Future<ListBuiltInIntentsResponse>
Gets a list of built-in intents provided by Amazon Lex that you can use in your bot.
listBuiltInSlotTypes({required String localeId, int? maxResults, String? nextToken, BuiltInSlotTypeSortBy? sortBy}) Future<ListBuiltInSlotTypesResponse>
Gets a list of built-in slot types that meet the specified criteria.
listCustomVocabularyItems({required String botId, required String botVersion, required String localeId, int? maxResults, String? nextToken}) Future<ListCustomVocabularyItemsResponse>
Paginated list of custom vocabulary items for a given bot locale's custom vocabulary.
listExports({String? botId, String? botVersion, List<ExportFilter>? filters, String? localeId, int? maxResults, String? nextToken, ExportSortBy? sortBy}) Future<ListExportsResponse>
Lists the exports for a bot, bot locale, or custom vocabulary. Exports are kept in the list for 7 days.
listImports({String? botId, String? botVersion, List<ImportFilter>? filters, String? localeId, int? maxResults, String? nextToken, ImportSortBy? sortBy}) Future<ListImportsResponse>
Lists the imports for a bot, bot locale, or custom vocabulary. Imports are kept in the list for 7 days.
listIntentMetrics({required String botId, required DateTime endDateTime, required List<AnalyticsIntentMetric> metrics, required DateTime startDateTime, List<AnalyticsBinBySpecification>? binBy, List<AnalyticsIntentFilter>? filters, List<AnalyticsIntentGroupBySpecification>? groupBy, int? maxResults, String? nextToken}) Future<ListIntentMetricsResponse>
Retrieves summary metrics for the intents in your bot. The following fields are required:
listIntentPaths({required String botId, required DateTime endDateTime, required String intentPath, required DateTime startDateTime, List<AnalyticsPathFilter>? filters}) Future<ListIntentPathsResponse>
Retrieves summary statistics for a path of intents that users take over sessions with your bot. The following fields are required:
listIntents({required String botId, required String botVersion, required String localeId, List<IntentFilter>? filters, int? maxResults, String? nextToken, IntentSortBy? sortBy}) Future<ListIntentsResponse>
Get a list of intents that meet the specified criteria.
listIntentStageMetrics({required String botId, required DateTime endDateTime, required List<AnalyticsIntentStageMetric> metrics, required DateTime startDateTime, List<AnalyticsBinBySpecification>? binBy, List<AnalyticsIntentStageFilter>? filters, List<AnalyticsIntentStageGroupBySpecification>? groupBy, int? maxResults, String? nextToken}) Future<ListIntentStageMetricsResponse>
Retrieves summary metrics for the stages within intents in your bot. The following fields are required:
listRecommendedIntents({required String botId, required String botRecommendationId, required String botVersion, required String localeId, int? maxResults, String? nextToken}) Future<ListRecommendedIntentsResponse>
Gets a list of recommended intents provided by the bot recommendation that you can use in your bot. Intents in the response are ordered by relevance.
listSessionAnalyticsData({required String botId, required DateTime endDateTime, required DateTime startDateTime, List<AnalyticsSessionFilter>? filters, int? maxResults, String? nextToken, SessionDataSortBy? sortBy}) Future<ListSessionAnalyticsDataResponse>
Retrieves a list of metadata for individual user sessions with your bot. The startDateTime and endDateTime fields are required. These fields define a time range for which you want to retrieve results. Of the optional fields, you can organize the results in the following ways:
listSessionMetrics({required String botId, required DateTime endDateTime, required List<AnalyticsSessionMetric> metrics, required DateTime startDateTime, List<AnalyticsBinBySpecification>? binBy, List<AnalyticsSessionFilter>? filters, List<AnalyticsSessionGroupBySpecification>? groupBy, int? maxResults, String? nextToken}) Future<ListSessionMetricsResponse>
Retrieves summary metrics for the user sessions with your bot. The following fields are required:
listSlots({required String botId, required String botVersion, required String intentId, required String localeId, List<SlotFilter>? filters, int? maxResults, String? nextToken, SlotSortBy? sortBy}) Future<ListSlotsResponse>
Gets a list of slots that match the specified criteria.
listSlotTypes({required String botId, required String botVersion, required String localeId, List<SlotTypeFilter>? filters, int? maxResults, String? nextToken, SlotTypeSortBy? sortBy}) Future<ListSlotTypesResponse>
Gets a list of slot types that match the specified criteria.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResponse>
Gets a list of tags associated with a resource. Only bots, bot aliases, and bot channels can have tags associated with them.
listTestExecutionResultItems({required TestExecutionResultFilterBy resultFilterBy, required String testExecutionId, int? maxResults, String? nextToken}) Future<ListTestExecutionResultItemsResponse>
Gets a list of test execution result items.
listTestExecutions({int? maxResults, String? nextToken, TestExecutionSortBy? sortBy}) Future<ListTestExecutionsResponse>
The list of test set executions.
listTestSetRecords({required String testSetId, int? maxResults, String? nextToken}) Future<ListTestSetRecordsResponse>
The list of test set records.
listTestSets({int? maxResults, String? nextToken, TestSetSortBy? sortBy}) Future<ListTestSetsResponse>
The list of the test sets
listUtteranceAnalyticsData({required String botId, required DateTime endDateTime, required DateTime startDateTime, List<AnalyticsUtteranceFilter>? filters, int? maxResults, String? nextToken, UtteranceDataSortBy? sortBy}) Future<ListUtteranceAnalyticsDataResponse>
  • startDateTime and endDateTime – Define a time range for which you want to retrieve results.
  • listUtteranceMetrics({required String botId, required DateTime endDateTime, required List<AnalyticsUtteranceMetric> metrics, required DateTime startDateTime, List<AnalyticsUtteranceAttribute>? attributes, List<AnalyticsBinBySpecification>? binBy, List<AnalyticsUtteranceFilter>? filters, List<AnalyticsUtteranceGroupBySpecification>? groupBy, int? maxResults, String? nextToken}) Future<ListUtteranceMetricsResponse>
  • metrics – A list of AnalyticsUtteranceMetric objects. In each object, use the name field to specify the metric to calculate, the statistic field to specify whether to calculate the Sum, Average, or Max number, and the order field to specify whether to sort the results in Ascending or Descending order.
  • startDateTime and endDateTime – Define a time range for which you want to retrieve results.
  • noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    searchAssociatedTranscripts({required String botId, required String botRecommendationId, required String botVersion, required List<AssociatedTranscriptFilter> filters, required String localeId, int? maxResults, int? nextIndex, SearchOrder? searchOrder}) Future<SearchAssociatedTranscriptsResponse>
    Search for associated transcripts that meet the specified criteria.
    startBotAnalyzer({required AnalysisScope analysisScope, required String botId, String? botVersion, String? localeId}) Future<StartBotAnalyzerResponse>
    Initiates an asynchronous analysis of your bot configuration using AI-powered analysis to identify potential issues and recommend improvements based on AWS best practices.
    startBotRecommendation({required String botId, required String botVersion, required String localeId, required TranscriptSourceSetting transcriptSourceSetting, EncryptionSetting? encryptionSetting}) Future<StartBotRecommendationResponse>
    Use this to provide your transcript data, and to start the bot recommendation process.
    startBotResourceGeneration({required String botId, required String botVersion, required String generationInputPrompt, required String localeId}) Future<StartBotResourceGenerationResponse>
    Starts a request for the descriptive bot builder to generate a bot locale configuration based on the prompt you provide it. After you make this call, use the DescribeBotResourceGeneration operation to check on the status of the generation and for the generatedBotLocaleUrl when the generation is complete. Use that value to retrieve the Amazon S3 object containing the bot locale configuration. You can then modify and import this configuration.
    startImport({required String importId, required MergeStrategy mergeStrategy, required ImportResourceSpecification resourceSpecification, String? filePassword}) Future<StartImportResponse>
    Starts importing a bot, bot locale, or custom vocabulary from a zip archive that you uploaded to an S3 bucket.
    startTestExecution({required TestExecutionApiMode apiMode, required TestExecutionTarget target, required String testSetId, TestExecutionModality? testExecutionModality}) Future<StartTestExecutionResponse>
    The action to start test set execution.
    startTestSetGeneration({required TestSetGenerationDataSource generationDataSource, required String roleArn, required TestSetStorageLocation storageLocation, required String testSetName, String? description, Map<String, String>? testSetTags}) Future<StartTestSetGenerationResponse>
    The action to start the generation of test set.
    stopBotAnalyzer({required String botAnalyzerRequestId, required String botId}) Future<StopBotAnalyzerResponse>
    Cancels an ongoing bot analysis execution. Once stopped, the analysis cannot be resumed and no recommendations will be generated.
    stopBotRecommendation({required String botId, required String botRecommendationId, required String botVersion, required String localeId}) Future<StopBotRecommendationResponse>
    Stop an already running Bot Recommendation request.
    tagResource({required String resourceARN, required Map<String, String> tags}) Future<void>
    Adds the specified tags to the specified resource. If a tag key already exists, the existing value is replaced with the new value.
    toString() String
    A string representation of this object.
    inherited
    untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
    Removes tags from a bot, bot alias, or bot channel.
    updateBot({required String botId, required String botName, required DataPrivacy dataPrivacy, required int idleSessionTTLInSeconds, required String roleArn, List<BotMember>? botMembers, BotType? botType, String? description, ErrorLogSettings? errorLogSettings}) Future<UpdateBotResponse>
    Updates the configuration of an existing bot.
    updateBotAlias({required String botAliasId, required String botAliasName, required String botId, Map<String, BotAliasLocaleSettings>? botAliasLocaleSettings, String? botVersion, ConversationLogSettings? conversationLogSettings, String? description, SentimentAnalysisSettings? sentimentAnalysisSettings}) Future<UpdateBotAliasResponse>
    Updates the configuration of an existing bot alias.
    updateBotLocale({required String botId, required String botVersion, required String localeId, required double nluIntentConfidenceThreshold, AudioFillerSettings? audioFillerSettings, String? description, GenerativeAISettings? generativeAISettings, SpeechDetectionSensitivity? speechDetectionSensitivity, SpeechRecognitionSettings? speechRecognitionSettings, UnifiedSpeechSettings? unifiedSpeechSettings, VoiceSettings? voiceSettings}) Future<UpdateBotLocaleResponse>
    Updates the settings that a bot has for a specific locale.
    updateBotRecommendation({required String botId, required String botRecommendationId, required String botVersion, required EncryptionSetting encryptionSetting, required String localeId}) Future<UpdateBotRecommendationResponse>
    Updates an existing bot recommendation request.
    updateExport({required String exportId, String? filePassword}) Future<UpdateExportResponse>
    Updates the password used to protect an export zip archive.
    updateIntent({required String botId, required String botVersion, required String intentId, required String intentName, required String localeId, String? description, DialogCodeHookSettings? dialogCodeHook, FulfillmentCodeHookSettings? fulfillmentCodeHook, InitialResponseSetting? initialResponseSetting, List<InputContext>? inputContexts, IntentClosingSetting? intentClosingSetting, IntentConfirmationSetting? intentConfirmationSetting, String? intentDisplayName, KendraConfiguration? kendraConfiguration, List<OutputContext>? outputContexts, String? parentIntentSignature, QInConnectIntentConfiguration? qInConnectIntentConfiguration, QnAIntentConfiguration? qnAIntentConfiguration, List<SampleUtterance>? sampleUtterances, List<SlotPriority>? slotPriorities}) Future<UpdateIntentResponse>
    Updates the settings for an intent.
    updateResourcePolicy({required String policy, required String resourceArn, String? expectedRevisionId}) Future<UpdateResourcePolicyResponse>
    Replaces the existing resource policy for a bot or bot alias with a new one. If the policy doesn't exist, Amazon Lex returns an exception.
    updateSlot({required String botId, required String botVersion, required String intentId, required String localeId, required String slotId, required String slotName, required SlotValueElicitationSetting valueElicitationSetting, String? description, MultipleValuesSetting? multipleValuesSetting, ObfuscationSetting? obfuscationSetting, String? slotTypeId, SubSlotSetting? subSlotSetting}) Future<UpdateSlotResponse>
    Updates the settings for a slot.
    updateSlotType({required String botId, required String botVersion, required String localeId, required String slotTypeId, required String slotTypeName, CompositeSlotTypeSetting? compositeSlotTypeSetting, String? description, ExternalSourceSetting? externalSourceSetting, String? parentSlotTypeSignature, List<SlotTypeValue>? slotTypeValues, SlotValueSelectionSetting? valueSelectionSetting}) Future<UpdateSlotTypeResponse>
    Updates the configuration of an existing slot type.
    updateTestSet({required String testSetId, required String testSetName, String? description}) Future<UpdateTestSetResponse>
    The action to update the test set.

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited