createBotReplica method

Future<CreateBotReplicaResponse> createBotReplica({
  1. required String botId,
  2. required String replicaRegion,
})

Action to create a replication of the source bot in the secondary region.

May throw ConflictException. May throw InternalServerException. May throw PreconditionFailedException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The request for the unique bot ID of the source bot to be replicated in the secondary region.

Parameter replicaRegion : The request for the secondary region that will be used in the replication of the source bot.

Implementation

Future<CreateBotReplicaResponse> createBotReplica({
  required String botId,
  required String replicaRegion,
}) async {
  final $payload = <String, dynamic>{
    'replicaRegion': replicaRegion,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/bots/${Uri.encodeComponent(botId)}/replicas',
    exceptionFnMap: _exceptionFns,
  );
  return CreateBotReplicaResponse.fromJson(response);
}