createTestSetDiscrepancyReport method

Future<CreateTestSetDiscrepancyReportResponse> createTestSetDiscrepancyReport({
  1. required TestSetDiscrepancyReportResourceTarget target,
  2. required String testSetId,
})

Create a report that describes the differences between the bot and the test set.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter target : The target bot for the test set discrepancy report.

Parameter testSetId : The test set Id for the test set discrepancy report.

Implementation

Future<CreateTestSetDiscrepancyReportResponse>
    createTestSetDiscrepancyReport({
  required TestSetDiscrepancyReportResourceTarget target,
  required String testSetId,
}) async {
  final $payload = <String, dynamic>{
    'target': target,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/testsets/${Uri.encodeComponent(testSetId)}/testsetdiscrepancy',
    exceptionFnMap: _exceptionFns,
  );
  return CreateTestSetDiscrepancyReportResponse.fromJson(response);
}