createUploadUrl method

Future<CreateUploadUrlResponse> createUploadUrl()

Gets a pre-signed S3 write URL that you use to upload the zip archive when importing a bot or a bot locale.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<CreateUploadUrlResponse> createUploadUrl() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/createuploadurl',
    exceptionFnMap: _exceptionFns,
  );
  return CreateUploadUrlResponse.fromJson(response);
}