deleteBotAnalyzerRecommendation method

Future<void> deleteBotAnalyzerRecommendation({
  1. required String botAnalyzerRequestId,
  2. required String botId,
})

Permanently deletes the recommendations and analysis results for a specific bot analysis request. This operation is provided for GDPR compliance and cannot be undone.

After deletion, the analysis results cannot be retrieved. The analysis request ID will still appear in the history list, but attempting to describe the recommendations will return a ResourceNotFoundException.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botAnalyzerRequestId : The unique identifier of the analysis request whose recommendations should be deleted.

Parameter botId : The unique identifier of the bot.

Implementation

Future<void> deleteBotAnalyzerRecommendation({
  required String botAnalyzerRequestId,
  required String botId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botanalyzer/${Uri.encodeComponent(botAnalyzerRequestId)}',
    exceptionFnMap: _exceptionFns,
  );
}