deleteCustomVocabulary method

Future<DeleteCustomVocabularyResponse> deleteCustomVocabulary({
  1. required String botId,
  2. required String botVersion,
  3. required String localeId,
})

Removes a custom vocabulary from the specified locale in the specified bot.

May throw ConflictException. May throw InternalServerException. May throw PreconditionFailedException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The unique identifier of the bot to remove the custom vocabulary from.

Parameter botVersion : The version of the bot to remove the custom vocabulary from.

Parameter localeId : The locale identifier for the locale that contains the custom vocabulary to remove.

Implementation

Future<DeleteCustomVocabularyResponse> deleteCustomVocabulary({
  required String botId,
  required String botVersion,
  required String localeId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/customvocabulary',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteCustomVocabularyResponse.fromJson(response);
}