deleteIntent method
Removes the specified intent.
Deleting an intent also deletes the slots associated with the intent.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot associated with the intent.
Parameter botVersion :
The version of the bot associated with the intent.
Parameter intentId :
The unique identifier of the intent to delete.
Parameter localeId :
The identifier of the language and locale where the bot will be deleted.
The string must match one of the supported locales. For more information,
see Supported
languages.
Implementation
Future<void> deleteIntent({
required String botId,
required String botVersion,
required String intentId,
required String localeId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/intents/${Uri.encodeComponent(intentId)}',
exceptionFnMap: _exceptionFns,
);
}