describeBotRecommendation method

Future<DescribeBotRecommendationResponse> describeBotRecommendation({
  1. required String botId,
  2. required String botRecommendationId,
  3. required String botVersion,
  4. required String localeId,
})

Provides metadata information about a bot recommendation. This information will enable you to get a description on the request inputs, to download associated transcripts after processing is complete, and to download intents and slot-types generated by the bot recommendation.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The unique identifier of the bot associated with the bot recommendation.

Parameter botRecommendationId : The identifier of the bot recommendation to describe.

Parameter botVersion : The version of the bot associated with the bot recommendation.

Parameter localeId : The identifier of the language and locale of the bot recommendation to describe. The string must match one of the supported locales. For more information, see Supported languages.

Implementation

Future<DescribeBotRecommendationResponse> describeBotRecommendation({
  required String botId,
  required String botRecommendationId,
  required String botVersion,
  required String localeId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/botrecommendations/${Uri.encodeComponent(botRecommendationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeBotRecommendationResponse.fromJson(response);
}