describeBotResourceGeneration method

Future<DescribeBotResourceGenerationResponse> describeBotResourceGeneration({
  1. required String botId,
  2. required String botVersion,
  3. required String generationId,
  4. required String localeId,
})

Returns information about a request to generate a bot through natural language description, made through the StartBotResource API. Use the generatedBotLocaleUrl to retrieve the Amazon S3 object containing the bot locale configuration. You can then modify and import this configuration.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The unique identifier of the bot for which to return the generation details.

Parameter botVersion : The version of the bot for which to return the generation details.

Parameter generationId : The unique identifier of the generation request for which to return the generation details.

Parameter localeId : The locale of the bot for which to return the generation details.

Implementation

Future<DescribeBotResourceGenerationResponse> describeBotResourceGeneration({
  required String botId,
  required String botVersion,
  required String generationId,
  required String localeId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/generations/${Uri.encodeComponent(generationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeBotResourceGenerationResponse.fromJson(response);
}