describeBotVersion method

Future<DescribeBotVersionResponse> describeBotVersion({
  1. required String botId,
  2. required String botVersion,
})

Provides metadata about a version of a bot.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The identifier of the bot containing the version to return metadata for.

Parameter botVersion : The version of the bot to return metadata for.

Implementation

Future<DescribeBotVersionResponse> describeBotVersion({
  required String botId,
  required String botVersion,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeBotVersionResponse.fromJson(response);
}