describeCustomVocabularyMetadata method

Future<DescribeCustomVocabularyMetadataResponse> describeCustomVocabularyMetadata({
  1. required String botId,
  2. required String botVersion,
  3. required String localeId,
})

Provides metadata information about a custom vocabulary.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The unique identifier of the bot that contains the custom vocabulary.

Parameter botVersion : The bot version of the bot to return metadata for.

Parameter localeId : The locale to return the custom vocabulary information for. The locale must be en_GB.

Implementation

Future<DescribeCustomVocabularyMetadataResponse>
    describeCustomVocabularyMetadata({
  required String botId,
  required String botVersion,
  required String localeId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/customvocabulary/DEFAULT/metadata',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeCustomVocabularyMetadataResponse.fromJson(response);
}