listBotRecommendations method

Future<ListBotRecommendationsResponse> listBotRecommendations({
  1. required String botId,
  2. required String botVersion,
  3. required String localeId,
  4. int? maxResults,
  5. String? nextToken,
})

Get a list of bot recommendations that meet the specified criteria.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botId : The unique identifier of the bot that contains the bot recommendation list.

Parameter botVersion : The version of the bot that contains the bot recommendation list.

Parameter localeId : The identifier of the language and locale of the bot recommendation list.

Parameter maxResults : The maximum number of bot recommendations to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Parameter nextToken : If the response from the ListBotRecommendation operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Implementation

Future<ListBotRecommendationsResponse> listBotRecommendations({
  required String botId,
  required String botVersion,
  required String localeId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/botrecommendations',
    exceptionFnMap: _exceptionFns,
  );
  return ListBotRecommendationsResponse.fromJson(response);
}