listBotVersionReplicas method
Contains information about all the versions replication statuses applicable for Global Resiliency.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The request for the unique ID in the list of replicated bots.
Parameter replicaRegion :
The request for the region used in the list of replicated bots.
Parameter maxResults :
The maximum results given in the list of replicated bots.
Parameter nextToken :
The next token given in the list of replicated bots.
Parameter sortBy :
The requested sort category for the list of replicated bots.
Implementation
Future<ListBotVersionReplicasResponse> listBotVersionReplicas({
required String botId,
required String replicaRegion,
int? maxResults,
String? nextToken,
BotVersionReplicaSortBy? sortBy,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (sortBy != null) 'sortBy': sortBy,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/replicas/${Uri.encodeComponent(replicaRegion)}/botversions',
exceptionFnMap: _exceptionFns,
);
return ListBotVersionReplicasResponse.fromJson(response);
}