listTestExecutionResultItems method
Gets a list of test execution result items.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resultFilterBy :
The filter for the list of results from the test set execution.
Parameter testExecutionId :
The unique identifier of the test execution to list the result items.
Parameter maxResults :
The maximum number of test execution result items to return in each page.
If there are fewer results than the max page size, only the actual number
of results are returned.
Parameter nextToken :
If the response from the ListTestExecutionResultItems
operation contains more results than specified in the
maxResults parameter, a token is returned in the response.
Use that token in the nextToken parameter to return the next
page of results.
Implementation
Future<ListTestExecutionResultItemsResponse> listTestExecutionResultItems({
required TestExecutionResultFilterBy resultFilterBy,
required String testExecutionId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'resultFilterBy': resultFilterBy,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/testexecutions/${Uri.encodeComponent(testExecutionId)}/results',
exceptionFnMap: _exceptionFns,
);
return ListTestExecutionResultItemsResponse.fromJson(response);
}