listTestExecutions method

Future<ListTestExecutionsResponse> listTestExecutions({
  1. int? maxResults,
  2. String? nextToken,
  3. TestExecutionSortBy? sortBy,
})

The list of test set executions.

May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of test executions to return in each page. If there are fewer results than the max page size, only the actual number of results are returned.

Parameter nextToken : If the response from the ListTestExecutions operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Parameter sortBy : The sort order of the test set executions.

Implementation

Future<ListTestExecutionsResponse> listTestExecutions({
  int? maxResults,
  String? nextToken,
  TestExecutionSortBy? sortBy,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (sortBy != null) 'sortBy': sortBy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/testexecutions',
    exceptionFnMap: _exceptionFns,
  );
  return ListTestExecutionsResponse.fromJson(response);
}