startTestSetGeneration method

Future<StartTestSetGenerationResponse> startTestSetGeneration({
  1. required TestSetGenerationDataSource generationDataSource,
  2. required String roleArn,
  3. required TestSetStorageLocation storageLocation,
  4. required String testSetName,
  5. String? description,
  6. Map<String, String>? testSetTags,
})

The action to start the generation of test set.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter generationDataSource : The data source for the test set generation.

Parameter roleArn : The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.

Parameter storageLocation : The Amazon S3 storage location for the test set generation.

Parameter testSetName : The test set name for the test set generation request.

Parameter description : The test set description for the test set generation request.

Parameter testSetTags : A list of tags to add to the test set. You can only add tags when you import/generate a new test set. You can't use the UpdateTestSet operation to update tags. To update tags, use the TagResource operation.

Implementation

Future<StartTestSetGenerationResponse> startTestSetGeneration({
  required TestSetGenerationDataSource generationDataSource,
  required String roleArn,
  required TestSetStorageLocation storageLocation,
  required String testSetName,
  String? description,
  Map<String, String>? testSetTags,
}) async {
  final $payload = <String, dynamic>{
    'generationDataSource': generationDataSource,
    'roleArn': roleArn,
    'storageLocation': storageLocation,
    'testSetName': testSetName,
    if (description != null) 'description': description,
    if (testSetTags != null) 'testSetTags': testSetTags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/testsetgenerations',
    exceptionFnMap: _exceptionFns,
  );
  return StartTestSetGenerationResponse.fromJson(response);
}