stopBotAnalyzer method

Future<StopBotAnalyzerResponse> stopBotAnalyzer({
  1. required String botAnalyzerRequestId,
  2. required String botId,
})

Cancels an ongoing bot analysis execution. Once stopped, the analysis cannot be resumed and no recommendations will be generated.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botAnalyzerRequestId : The unique identifier of the analysis request to stop.

Parameter botId : The unique identifier of the bot.

Implementation

Future<StopBotAnalyzerResponse> stopBotAnalyzer({
  required String botAnalyzerRequestId,
  required String botId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botanalyzer/${Uri.encodeComponent(botAnalyzerRequestId)}/stop',
    exceptionFnMap: _exceptionFns,
  );
  return StopBotAnalyzerResponse.fromJson(response);
}