updateExport method

Future<UpdateExportResponse> updateExport({
  1. required String exportId,
  2. String? filePassword,
})

Updates the password used to protect an export zip archive.

The password is not required. If you don't supply a password, Amazon Lex generates a zip file that is not protected by a password. This is the archive that is available at the pre-signed S3 URL provided by the DescribeExport operation.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter exportId : The unique identifier Amazon Lex assigned to the export.

Parameter filePassword : The new password to use to encrypt the export zip archive.

Implementation

Future<UpdateExportResponse> updateExport({
  required String exportId,
  String? filePassword,
}) async {
  final $payload = <String, dynamic>{
    if (filePassword != null) 'filePassword': filePassword,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/exports/${Uri.encodeComponent(exportId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateExportResponse.fromJson(response);
}