LexRuntimeV2 class

This section contains documentation for the Amazon Lex V2 Runtime V2 API operations.

Constructors

LexRuntimeV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteSession({required String botAliasId, required String botId, required String localeId, required String sessionId}) Future<DeleteSessionResponse>
Removes session information for a specified bot, alias, and user ID.
getSession({required String botAliasId, required String botId, required String localeId, required String sessionId}) Future<GetSessionResponse>
Returns session information for a specified bot, alias, and user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putSession({required String botAliasId, required String botId, required String localeId, required String sessionId, required SessionState sessionState, List<Message>? messages, Map<String, String>? requestAttributes, String? responseContentType}) Future<PutSessionResponse>
Creates a new session or modifies an existing session with an Amazon Lex V2 bot. Use this operation to enable your application to set the state of the bot.
recognizeText({required String botAliasId, required String botId, required String localeId, required String sessionId, required String text, Map<String, String>? requestAttributes, SessionState? sessionState}) Future<RecognizeTextResponse>
Sends user input to Amazon Lex V2. Client applications use this API to send requests to Amazon Lex V2 at runtime. Amazon Lex V2 then interprets the user input using the machine learning model that it build for the bot.
recognizeUtterance({required String botAliasId, required String botId, required String localeId, required String requestContentType, required String sessionId, Uint8List? inputStream, String? requestAttributes, String? responseContentType, String? sessionState}) Future<RecognizeUtteranceResponse>
Sends user input to Amazon Lex V2. You can send text or speech. Clients use this API to send text and audio requests to Amazon Lex V2 at runtime. Amazon Lex V2 interprets the user input using the machine learning model built for the bot.
startConversation({required String botAliasId, required String botId, required String localeId, required StartConversationRequestEventStream requestEventStream, required String sessionId, ConversationMode? conversationMode}) Future<StartConversationResponse>
Starts an HTTP/2 bidirectional event stream that enables you to send audio, text, or DTMF input in real time. After your application starts a conversation, users send input to Amazon Lex V2 as a stream of events. Amazon Lex V2 processes the incoming events and responds with streaming text or audio events.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited