recognizeText method

Future<RecognizeTextResponse> recognizeText({
  1. required String botAliasId,
  2. required String botId,
  3. required String localeId,
  4. required String sessionId,
  5. required String text,
  6. Map<String, String>? requestAttributes,
  7. SessionState? sessionState,
})

Sends user input to Amazon Lex V2. Client applications use this API to send requests to Amazon Lex V2 at runtime. Amazon Lex V2 then interprets the user input using the machine learning model that it build for the bot.

In response, Amazon Lex V2 returns the next message to convey to the user and an optional response card to display.

If the optional post-fulfillment response is specified, the messages are returned as follows. For more information, see PostFulfillmentStatusSpecification.

  • Success message - Returned if the Lambda function completes successfully and the intent state is fulfilled or ready fulfillment if the message is present.
  • Failed message - The failed message is returned if the Lambda function throws an exception or if the Lambda function returns a failed intent state without a message.
  • Timeout message - If you don't configure a timeout message and a timeout, and the Lambda function doesn't return within 30 seconds, the timeout message is returned. If you configure a timeout, the timeout message is returned when the period times out.
For more information, see Completion message.

May throw AccessDeniedException. May throw BadGatewayException. May throw ConflictException. May throw DependencyFailedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter botAliasId : The alias identifier in use for the bot that processes the request.

Parameter botId : The identifier of the bot that processes the request.

Parameter localeId : The locale where the session is in use.

Parameter sessionId : The identifier of the user session that is having the conversation.

Parameter text : The text that the user entered. Amazon Lex V2 interprets this text.

Parameter requestAttributes : Request-specific information passed between the client application and Amazon Lex V2

The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:.

Parameter sessionState : The current state of the dialog between the user and the bot.

Implementation

Future<RecognizeTextResponse> recognizeText({
  required String botAliasId,
  required String botId,
  required String localeId,
  required String sessionId,
  required String text,
  Map<String, String>? requestAttributes,
  SessionState? sessionState,
}) async {
  final $payload = <String, dynamic>{
    'text': text,
    if (requestAttributes != null) 'requestAttributes': requestAttributes,
    if (sessionState != null) 'sessionState': sessionState,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/bots/${Uri.encodeComponent(botId)}/botAliases/${Uri.encodeComponent(botAliasId)}/botLocales/${Uri.encodeComponent(localeId)}/sessions/${Uri.encodeComponent(sessionId)}/text',
    exceptionFnMap: _exceptionFns,
  );
  return RecognizeTextResponse.fromJson(response);
}