recognizeUtterance method
Sends user input to Amazon Lex V2. You can send text or speech. Clients use this API to send text and audio requests to Amazon Lex V2 at runtime. Amazon Lex V2 interprets the user input using the machine learning model built for the bot.
The following request fields must be compressed with gzip and then base64 encoded before you send them to Amazon Lex V2.
- requestAttributes
- sessionState
- inputTranscript
- interpretations
- messages
- requestAttributes
- sessionState
If the optional post-fulfillment response is specified, the messages are returned as follows. For more information, see PostFulfillmentStatusSpecification.
- Success message - Returned if the Lambda function completes successfully and the intent state is fulfilled or ready fulfillment if the message is present.
- Failed message - The failed message is returned if the Lambda function throws an exception or if the Lambda function returns a failed intent state without a message.
- Timeout message - If you don't configure a timeout message and a timeout, and the Lambda function doesn't return within 30 seconds, the timeout message is returned. If you configure a timeout, the timeout message is returned when the period times out.
May throw AccessDeniedException.
May throw BadGatewayException.
May throw ConflictException.
May throw DependencyFailedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botAliasId :
The alias identifier in use for the bot that should receive the request.
Parameter botId :
The identifier of the bot that should receive the request.
Parameter localeId :
The locale where the session is in use.
Parameter requestContentType :
Indicates the format for audio input or that the content is text. The
header must start with one of the following prefixes:
-
PCM format, audio data must be in little-endian byte order.
- audio/l16; rate=16000; channels=1
- audio/x-l16; sample-rate=16000; channel-count=1
- audio/lpcm; sample-rate=8000; sample-size-bits=16; channel-count=1; is-big-endian=false
-
Opus format
- audio/x-cbr-opus-with-preamble;preamble-size=0;bit-rate=256000;frame-size-milliseconds=4
-
Text format
- text/plain; charset=utf-8
Parameter sessionId :
The identifier of the session in use.
Parameter inputStream :
User input in PCM or Opus audio format or text format as described in the
requestContentType parameter.
Parameter requestAttributes :
Request-specific information passed between the client application and
Amazon Lex V2
The namespace x-amz-lex: is reserved for special attributes.
Don't create any request attributes for prefix x-amz-lex:.
The requestAttributes field must be compressed using gzip and
then base64 encoded before sending to Amazon Lex V2.
Parameter responseContentType :
The message that Amazon Lex V2 returns in the response can be either text
or speech based on the responseContentType value.
-
If the value is
text/plain;charset=utf-8, Amazon Lex V2 returns text in the response. -
If the value begins with
audio/, Amazon Lex V2 returns speech in the response. Amazon Lex V2 uses Amazon Polly to generate the speech using the configuration that you specified in theresponseContentTypeparameter. For example, if you specifyaudio/mpegas the value, Amazon Lex V2 returns speech in the MPEG format. -
If the value is
audio/pcm, the speech returned isaudio/pcmat 16 KHz in 16-bit, little-endian format. -
The following are the accepted values:
- audio/mpeg
- audio/ogg
- audio/pcm (16 KHz)
- audio/* (defaults to mpeg)
- text/plain; charset=utf-8
Parameter sessionState :
Sets the state of the session with the user. You can use this to set the
current intent, attributes, context, and dialog action. Use the dialog
action to determine the next step that Amazon Lex V2 should use in the
conversation with the user.
The sessionState field must be compressed using gzip and then
base64 encoded before sending to Amazon Lex V2.
Implementation
Future<RecognizeUtteranceResponse> recognizeUtterance({
required String botAliasId,
required String botId,
required String localeId,
required String requestContentType,
required String sessionId,
Uint8List? inputStream,
String? requestAttributes,
String? responseContentType,
String? sessionState,
}) async {
final headers = <String, String>{
'Content-Type': requestContentType.toString(),
if (requestAttributes != null)
'x-amz-lex-request-attributes': requestAttributes.toString(),
if (responseContentType != null)
'Response-Content-Type': responseContentType.toString(),
if (sessionState != null)
'x-amz-lex-session-state': sessionState.toString(),
};
final response = await _protocol.sendRaw(
payload: inputStream,
method: 'POST',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botAliases/${Uri.encodeComponent(botAliasId)}/botLocales/${Uri.encodeComponent(localeId)}/sessions/${Uri.encodeComponent(sessionId)}/utterance',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return RecognizeUtteranceResponse(
audioStream: await response.stream.toBytes(),
contentType:
_s.extractHeaderStringValue(response.headers, 'Content-Type'),
inputMode:
_s.extractHeaderStringValue(response.headers, 'x-amz-lex-input-mode'),
inputTranscript: _s.extractHeaderStringValue(
response.headers, 'x-amz-lex-input-transcript'),
interpretations: _s.extractHeaderStringValue(
response.headers, 'x-amz-lex-interpretations'),
messages:
_s.extractHeaderStringValue(response.headers, 'x-amz-lex-messages'),
recognizedBotMember: _s.extractHeaderStringValue(
response.headers, 'x-amz-lex-recognized-bot-member'),
requestAttributes: _s.extractHeaderStringValue(
response.headers, 'x-amz-lex-request-attributes'),
sessionId:
_s.extractHeaderStringValue(response.headers, 'x-amz-lex-session-id'),
sessionState: _s.extractHeaderStringValue(
response.headers, 'x-amz-lex-session-state'),
);
}