LicenseManager class

License Manager makes it easier to manage licenses from software vendors across multiple Amazon Web Services accounts and on-premises servers.

Constructors

LicenseManager({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptGrant({required String grantArn}) Future<AcceptGrantResponse>
Accepts the specified grant.
checkInLicense({required String licenseConsumptionToken, String? beneficiary}) Future<void>
Checks in the specified license. Check in a license when it is no longer in use.
checkoutBorrowLicense({required String clientToken, required DigitalSignatureMethod digitalSignatureMethod, required List<EntitlementData> entitlements, required String licenseArn, List<Metadata>? checkoutMetadata, String? nodeId}) Future<CheckoutBorrowLicenseResponse>
Checks out the specified license for offline use.
checkoutLicense({required CheckoutType checkoutType, required String clientToken, required List<EntitlementData> entitlements, required String keyFingerprint, required String productSKU, String? beneficiary, String? nodeId}) Future<CheckoutLicenseResponse>
Checks out the specified license.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createGrant({required List<AllowedOperation> allowedOperations, required String clientToken, required String grantName, required String homeRegion, required String licenseArn, required List<String> principals, List<Tag>? tags}) Future<CreateGrantResponse>
Creates a grant for the specified license. A grant shares the use of license entitlements with a specific Amazon Web Services account, an organization, or an organizational unit (OU). For more information, see Granted licenses in License Manager in the License Manager User Guide.
createGrantVersion({required String clientToken, required String grantArn, List<AllowedOperation>? allowedOperations, String? grantName, Options? options, String? sourceVersion, GrantStatus? status, String? statusReason}) Future<CreateGrantVersionResponse>
Creates a new version of the specified grant. For more information, see Granted licenses in License Manager in the License Manager User Guide.
createLicense({required String beneficiary, required String clientToken, required ConsumptionConfiguration consumptionConfiguration, required List<Entitlement> entitlements, required String homeRegion, required Issuer issuer, required String licenseName, required String productName, required String productSKU, required DatetimeRange validity, List<Metadata>? licenseMetadata, List<Tag>? tags}) Future<CreateLicenseResponse>
Creates a license.
createLicenseAssetGroup({required List<String> associatedLicenseAssetRulesetARNs, required String clientToken, required List<LicenseAssetGroupConfiguration> licenseAssetGroupConfigurations, required String name, String? description, List<LicenseAssetGroupProperty>? properties, List<Tag>? tags}) Future<CreateLicenseAssetGroupResponse>
Creates a license asset group.
createLicenseAssetRuleset({required String clientToken, required String name, required List<LicenseAssetRule> rules, String? description, List<Tag>? tags}) Future<CreateLicenseAssetRulesetResponse>
Creates a license asset ruleset.
createLicenseConfiguration({required LicenseCountingType licenseCountingType, required String name, String? description, bool? disassociateWhenNotFound, int? licenseCount, bool? licenseCountHardLimit, int? licenseExpiry, List<String>? licenseRules, List<ProductInformation>? productInformationList, List<Tag>? tags}) Future<CreateLicenseConfigurationResponse>
Creates a license configuration.
createLicenseConversionTaskForResource({required LicenseConversionContext destinationLicenseContext, required String resourceArn, required LicenseConversionContext sourceLicenseContext}) Future<CreateLicenseConversionTaskForResourceResponse>
Creates a new license conversion task.
createLicenseManagerReportGenerator({required String clientToken, required ReportContext reportContext, required ReportFrequency reportFrequency, required String reportGeneratorName, required List<ReportType> type, String? description, List<Tag>? tags}) Future<CreateLicenseManagerReportGeneratorResponse>
Creates a report generator.
createLicenseVersion({required String clientToken, required ConsumptionConfiguration consumptionConfiguration, required List<Entitlement> entitlements, required String homeRegion, required Issuer issuer, required String licenseArn, required String licenseName, required String productName, required LicenseStatus status, required DatetimeRange validity, List<Metadata>? licenseMetadata, String? sourceVersion}) Future<CreateLicenseVersionResponse>
Creates a new version of the specified license.
createToken({required String clientToken, required String licenseArn, int? expirationInDays, List<String>? roleArns, List<String>? tokenProperties}) Future<CreateTokenResponse>
Creates a long-lived token.
deleteGrant({required String grantArn, required String version, String? statusReason}) Future<DeleteGrantResponse>
Deletes the specified grant.
deleteLicense({required String licenseArn, required String sourceVersion}) Future<DeleteLicenseResponse>
Deletes the specified license.
deleteLicenseAssetGroup({required String licenseAssetGroupArn}) Future<DeleteLicenseAssetGroupResponse>
Deletes a license asset group.
deleteLicenseAssetRuleset({required String licenseAssetRulesetArn}) Future<void>
Deletes a license asset ruleset.
deleteLicenseConfiguration({required String licenseConfigurationArn}) Future<void>
Deletes the specified license configuration.
deleteLicenseManagerReportGenerator({required String licenseManagerReportGeneratorArn}) Future<void>
Deletes the specified report generator.
deleteToken({required String tokenId}) Future<void>
Deletes the specified token. Must be called in the license home Region.
extendLicenseConsumption({required String licenseConsumptionToken, bool? dryRun}) Future<ExtendLicenseConsumptionResponse>
Extends the expiration date for license consumption.
getAccessToken({required String token, List<String>? tokenProperties}) Future<GetAccessTokenResponse>
Gets a temporary access token to use with AssumeRoleWithWebIdentity. Access tokens are valid for one hour.
getGrant({required String grantArn, String? version}) Future<GetGrantResponse>
Gets detailed information about the specified grant.
getLicense({required String licenseArn, String? version}) Future<GetLicenseResponse>
Gets detailed information about the specified license.
getLicenseAssetGroup({required String licenseAssetGroupArn}) Future<GetLicenseAssetGroupResponse>
Gets a license asset group.
getLicenseAssetRuleset({required String licenseAssetRulesetArn}) Future<GetLicenseAssetRulesetResponse>
Gets a license asset ruleset.
getLicenseConfiguration({required String licenseConfigurationArn}) Future<GetLicenseConfigurationResponse>
Gets detailed information about the specified license configuration.
getLicenseConversionTask({required String licenseConversionTaskId}) Future<GetLicenseConversionTaskResponse>
Gets information about the specified license type conversion task.
getLicenseManagerReportGenerator({required String licenseManagerReportGeneratorArn}) Future<GetLicenseManagerReportGeneratorResponse>
Gets information about the specified report generator.
getLicenseUsage({required String licenseArn}) Future<GetLicenseUsageResponse>
Gets detailed information about the usage of the specified license.
getServiceSettings() Future<GetServiceSettingsResponse>
Gets the License Manager settings for the current Region.
listAssetsForLicenseAssetGroup({required String assetType, required String licenseAssetGroupArn, int? maxResults, String? nextToken}) Future<ListAssetsForLicenseAssetGroupResponse>
Lists assets for a license asset group.
listAssociationsForLicenseConfiguration({required String licenseConfigurationArn, int? maxResults, String? nextToken}) Future<ListAssociationsForLicenseConfigurationResponse>
Lists the resource associations for the specified license configuration.
listDistributedGrants({List<Filter>? filters, List<String>? grantArns, int? maxResults, String? nextToken}) Future<ListDistributedGrantsResponse>
Lists the grants distributed for the specified license.
listFailuresForLicenseConfigurationOperations({required String licenseConfigurationArn, int? maxResults, String? nextToken}) Future<ListFailuresForLicenseConfigurationOperationsResponse>
Lists the license configuration operations that failed.
listLicenseAssetGroups({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListLicenseAssetGroupsResponse>
Lists license asset groups.
listLicenseAssetRulesets({List<Filter>? filters, int? maxResults, String? nextToken, bool? showAWSManagedLicenseAssetRulesets}) Future<ListLicenseAssetRulesetsResponse>
Lists license asset rulesets.
listLicenseConfigurations({List<Filter>? filters, List<String>? licenseConfigurationArns, int? maxResults, String? nextToken}) Future<ListLicenseConfigurationsResponse>
Lists the license configurations for your account.
listLicenseConfigurationsForOrganization({List<Filter>? filters, List<String>? licenseConfigurationArns, int? maxResults, String? nextToken}) Future<ListLicenseConfigurationsForOrganizationResponse>
Lists license configurations for an organization.
listLicenseConversionTasks({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListLicenseConversionTasksResponse>
Lists the license type conversion tasks for your account.
listLicenseManagerReportGenerators({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListLicenseManagerReportGeneratorsResponse>
Lists the report generators for your account.
listLicenses({List<Filter>? filters, List<String>? licenseArns, int? maxResults, String? nextToken}) Future<ListLicensesResponse>
Lists the licenses for your account.
listLicenseSpecificationsForResource({required String resourceArn, int? maxResults, String? nextToken}) Future<ListLicenseSpecificationsForResourceResponse>
Describes the license configurations for the specified resource.
listLicenseVersions({required String licenseArn, int? maxResults, String? nextToken}) Future<ListLicenseVersionsResponse>
Lists all versions of the specified license.
listReceivedGrants({List<Filter>? filters, List<String>? grantArns, int? maxResults, String? nextToken}) Future<ListReceivedGrantsResponse>
Lists grants that are received. Received grants are grants created while specifying the recipient as this Amazon Web Services account, your organization, or an organizational unit (OU) to which this member account belongs.
listReceivedGrantsForOrganization({required String licenseArn, List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListReceivedGrantsForOrganizationResponse>
Lists the grants received for all accounts in the organization.
listReceivedLicenses({List<Filter>? filters, List<String>? licenseArns, int? maxResults, String? nextToken}) Future<ListReceivedLicensesResponse>
Lists received licenses.
listReceivedLicensesForOrganization({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListReceivedLicensesForOrganizationResponse>
Lists the licenses received for all accounts in the organization.
listResourceInventory({List<InventoryFilter>? filters, int? maxResults, String? nextToken}) Future<ListResourceInventoryResponse>
Lists resources managed using Systems Manager inventory.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for the specified resource. For more information about tagging support in License Manager, see the TagResource operation.
listTokens({List<Filter>? filters, int? maxResults, String? nextToken, List<String>? tokenIds}) Future<ListTokensResponse>
Lists your tokens.
listUsageForLicenseConfiguration({required String licenseConfigurationArn, List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListUsageForLicenseConfigurationResponse>
Lists all license usage records for a license configuration, displaying license consumption details by resource at a selected point in time. Use this action to audit the current license consumption for any license inventory and configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectGrant({required String grantArn}) Future<RejectGrantResponse>
Rejects the specified grant.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Adds the specified tags to the specified resource. The following resources support tagging in License Manager:
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified resource.
updateLicenseAssetGroup({required List<String> associatedLicenseAssetRulesetARNs, required String clientToken, required String licenseAssetGroupArn, String? description, List<LicenseAssetGroupConfiguration>? licenseAssetGroupConfigurations, String? name, List<LicenseAssetGroupProperty>? properties, LicenseAssetGroupStatus? status}) Future<UpdateLicenseAssetGroupResponse>
Updates a license asset group.
updateLicenseAssetRuleset({required String clientToken, required String licenseAssetRulesetArn, required List<LicenseAssetRule> rules, String? description, String? name}) Future<UpdateLicenseAssetRulesetResponse>
Updates a license asset ruleset.
updateLicenseConfiguration({required String licenseConfigurationArn, String? description, bool? disassociateWhenNotFound, LicenseConfigurationStatus? licenseConfigurationStatus, int? licenseCount, bool? licenseCountHardLimit, int? licenseExpiry, List<String>? licenseRules, String? name, List<ProductInformation>? productInformationList}) Future<void>
Modifies the attributes of an existing license configuration.
updateLicenseManagerReportGenerator({required String clientToken, required String licenseManagerReportGeneratorArn, required ReportContext reportContext, required ReportFrequency reportFrequency, required String reportGeneratorName, required List<ReportType> type, String? description}) Future<void>
Updates a report generator.
updateLicenseSpecificationsForResource({required String resourceArn, List<LicenseSpecification>? addLicenseSpecifications, List<LicenseSpecification>? removeLicenseSpecifications}) Future<void>
Adds or removes the specified license configurations for the specified Amazon Web Services resource.
updateServiceSettings({bool? enableCrossAccountsDiscovery, List<String>? enabledDiscoverySourceRegions, OrganizationConfiguration? organizationConfiguration, String? s3BucketArn, String? snsTopicArn}) Future<void>
Updates License Manager settings for the current Region.

Operators

operator ==(Object other) bool
The equality operator.
inherited