deleteLicenseManagerReportGenerator method

Future<void> deleteLicenseManagerReportGenerator({
  1. required String licenseManagerReportGeneratorArn,
})

Deletes the specified report generator.

This action deletes the report generator, which stops it from generating future reports. The action cannot be reversed. It has no effect on the previous reports from this generator.

May throw AccessDeniedException. May throw AuthorizationException. May throw InvalidParameterValueException. May throw RateLimitExceededException. May throw ResourceLimitExceededException. May throw ResourceNotFoundException. May throw ServerInternalException. May throw ValidationException.

Parameter licenseManagerReportGeneratorArn : Amazon Resource Name (ARN) of the report generator to be deleted.

Implementation

Future<void> deleteLicenseManagerReportGenerator({
  required String licenseManagerReportGeneratorArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSLicenseManager.DeleteLicenseManagerReportGenerator'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LicenseManagerReportGeneratorArn': licenseManagerReportGeneratorArn,
    },
  );
}