listLicenseConfigurations method
Lists the license configurations for your account.
May throw AccessDeniedException.
May throw AuthorizationException.
May throw FilterLimitExceededException.
May throw InvalidParameterValueException.
May throw RateLimitExceededException.
May throw ServerInternalException.
Parameter filters :
Filters to scope the results. The following filters and logical operators
are supported:
-
licenseCountingType- The dimension for which licenses are counted. Possible values arevCPU|Instance|Core|Socket. -
enforceLicenseCount- A Boolean value that indicates whether hard license enforcement is used. -
usagelimitExceeded- A Boolean value that indicates whether the available licenses have been exceeded.
Parameter licenseConfigurationArns :
Amazon Resource Names (ARN) of the license configurations.
Parameter maxResults :
Maximum number of results to return in a single call.
Parameter nextToken :
Token for the next set of results.
Implementation
Future<ListLicenseConfigurationsResponse> listLicenseConfigurations({
List<Filter>? filters,
List<String>? licenseConfigurationArns,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSLicenseManager.ListLicenseConfigurations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (licenseConfigurationArns != null)
'LicenseConfigurationArns': licenseConfigurationArns,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListLicenseConfigurationsResponse.fromJson(jsonResponse.body);
}