listReceivedLicensesForOrganization method

Future<ListReceivedLicensesForOrganizationResponse> listReceivedLicensesForOrganization({
  1. List<Filter>? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the licenses received for all accounts in the organization.

May throw AccessDeniedException. May throw AuthorizationException. May throw InvalidParameterValueException. May throw RateLimitExceededException. May throw ResourceLimitExceededException. May throw ServerInternalException. May throw ValidationException.

Parameter filters : Filters to scope the results. The following filters are supported:

  • Beneficiary
  • ProductSKU

Parameter maxResults : Maximum number of results to return in a single call.

Parameter nextToken : Token for the next set of results.

Implementation

Future<ListReceivedLicensesForOrganizationResponse>
    listReceivedLicensesForOrganization({
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSLicenseManager.ListReceivedLicensesForOrganization'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListReceivedLicensesForOrganizationResponse.fromJson(
      jsonResponse.body);
}