updateLicenseConfiguration method

Future<void> updateLicenseConfiguration({
  1. required String licenseConfigurationArn,
  2. String? description,
  3. bool? disassociateWhenNotFound,
  4. LicenseConfigurationStatus? licenseConfigurationStatus,
  5. int? licenseCount,
  6. bool? licenseCountHardLimit,
  7. int? licenseExpiry,
  8. List<String>? licenseRules,
  9. String? name,
  10. List<ProductInformation>? productInformationList,
})

Modifies the attributes of an existing license configuration.

May throw AccessDeniedException. May throw AuthorizationException. May throw ConflictException. May throw InvalidParameterValueException. May throw RateLimitExceededException. May throw ResourceLimitExceededException. May throw ServerInternalException.

Parameter licenseConfigurationArn : Amazon Resource Name (ARN) of the license configuration.

Parameter description : New description of the license configuration.

Parameter disassociateWhenNotFound : When true, disassociates a resource when software is uninstalled.

Parameter licenseConfigurationStatus : New status of the license configuration.

Parameter licenseCount : New number of licenses managed by the license configuration.

Parameter licenseCountHardLimit : New hard limit of the number of available licenses.

Parameter licenseExpiry : License configuration expiry time.

Parameter licenseRules : New license rule. The only rule that you can add after you create a license configuration is licenseAffinityToHost.

Parameter name : New name of the license configuration.

Parameter productInformationList : New product information.

Implementation

Future<void> updateLicenseConfiguration({
  required String licenseConfigurationArn,
  String? description,
  bool? disassociateWhenNotFound,
  LicenseConfigurationStatus? licenseConfigurationStatus,
  int? licenseCount,
  bool? licenseCountHardLimit,
  int? licenseExpiry,
  List<String>? licenseRules,
  String? name,
  List<ProductInformation>? productInformationList,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSLicenseManager.UpdateLicenseConfiguration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LicenseConfigurationArn': licenseConfigurationArn,
      if (description != null) 'Description': description,
      if (disassociateWhenNotFound != null)
        'DisassociateWhenNotFound': disassociateWhenNotFound,
      if (licenseConfigurationStatus != null)
        'LicenseConfigurationStatus': licenseConfigurationStatus.value,
      if (licenseCount != null) 'LicenseCount': licenseCount,
      if (licenseCountHardLimit != null)
        'LicenseCountHardLimit': licenseCountHardLimit,
      if (licenseExpiry != null) 'LicenseExpiry': licenseExpiry,
      if (licenseRules != null) 'LicenseRules': licenseRules,
      if (name != null) 'Name': name,
      if (productInformationList != null)
        'ProductInformationList': productInformationList,
    },
  );
}