listLinuxSubscriptions method

Future<ListLinuxSubscriptionsResponse> listLinuxSubscriptions({
  1. List<Filter>? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the Linux subscriptions that have been discovered. If you have linked your organization, the returned results will include data aggregated across your accounts in Organizations.

May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter filters : An array of structures that you can use to filter the results to those that match one or more sets of key-value pairs that you specify. For example, you can filter by the name of Subscription with an optional operator to see subscriptions that match, partially match, or don't match a certain subscription's name.

The valid names for this filter are:

  • Subscription
The valid Operators for this filter are:
  • contains
  • equals
  • Notequal

Parameter maxResults : The maximum items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListLinuxSubscriptionsResponse> listLinuxSubscriptions({
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (filters != null) 'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/subscription/ListLinuxSubscriptions',
    exceptionFnMap: _exceptionFns,
  );
  return ListLinuxSubscriptionsResponse.fromJson(response);
}