LicenseManagerUserSubscriptions class

With License Manager, you can create user-based subscriptions to utilize licensed software with a per user subscription fee on Amazon EC2 instances.

Constructors

LicenseManagerUserSubscriptions({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateUser({required IdentityProvider identityProvider, required String instanceId, required String username, String? domain, Map<String, String>? tags}) Future<AssociateUserResponse>
Associates the user to an EC2 instance to utilize user-based subscriptions.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createLicenseServerEndpoint({required String identityProviderArn, required LicenseServerSettings licenseServerSettings, Map<String, String>? tags}) Future<CreateLicenseServerEndpointResponse>
Creates a network endpoint for the Remote Desktop Services (RDS) license server.
deleteLicenseServerEndpoint({required String licenseServerEndpointArn, required ServerType serverType}) Future<DeleteLicenseServerEndpointResponse>
Deletes a LicenseServerEndpoint resource.
deregisterIdentityProvider({IdentityProvider? identityProvider, String? identityProviderArn, String? product}) Future<DeregisterIdentityProviderResponse>
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
disassociateUser({String? domain, IdentityProvider? identityProvider, String? instanceId, String? instanceUserArn, String? username}) Future<DisassociateUserResponse>
Disassociates the user from an EC2 instance providing user-based subscriptions.
listIdentityProviders({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListIdentityProvidersResponse>
Lists the Active Directory identity providers for user-based subscriptions.
listInstances({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListInstancesResponse>
Lists the EC2 instances providing user-based subscriptions.
listLicenseServerEndpoints({List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListLicenseServerEndpointsResponse>
List the Remote Desktop Services (RDS) License Server endpoints
listProductSubscriptions({required IdentityProvider identityProvider, List<Filter>? filters, int? maxResults, String? nextToken, String? product}) Future<ListProductSubscriptionsResponse>
Lists the user-based subscription products available from an identity provider.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns the list of tags for the specified resource.
listUserAssociations({required IdentityProvider identityProvider, required String instanceId, List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListUserAssociationsResponse>
Lists user associations for an identity provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerIdentityProvider({required IdentityProvider identityProvider, required String product, Settings? settings, Map<String, String>? tags}) Future<RegisterIdentityProviderResponse>
Registers an identity provider for user-based subscriptions.
startProductSubscription({required IdentityProvider identityProvider, required String product, required String username, String? domain, Map<String, String>? tags}) Future<StartProductSubscriptionResponse>
Starts a product subscription for a user with the specified identity provider.
stopProductSubscription({String? domain, IdentityProvider? identityProvider, String? product, String? productUserArn, String? username}) Future<StopProductSubscriptionResponse>
Stops a product subscription for a user with the specified identity provider.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a resource.
updateIdentityProviderSettings({required UpdateSettings updateSettings, IdentityProvider? identityProvider, String? identityProviderArn, String? product}) Future<UpdateIdentityProviderSettingsResponse>
Updates additional product configuration settings for the registered identity provider.

Operators

operator ==(Object other) bool
The equality operator.
inherited