createLicenseServerEndpoint method

Future<CreateLicenseServerEndpointResponse> createLicenseServerEndpoint({
  1. required String identityProviderArn,
  2. required LicenseServerSettings licenseServerSettings,
  3. Map<String, String>? tags,
})

Creates a network endpoint for the Remote Desktop Services (RDS) license server.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter identityProviderArn : The Amazon Resource Name (ARN) that identifies the IdentityProvider resource that contains details about a registered identity provider. In the case of Active Directory, that can be a self-managed Active Directory or an Amazon Web Services Managed Active Directory that contains user identity details.

Parameter licenseServerSettings : The LicenseServerSettings resource to create for the endpoint. The settings include the type of license server and the Secrets Manager secret that enables administrators to add or remove users associated with the license server.

Parameter tags : The tags that apply for the license server endpoint.

Implementation

Future<CreateLicenseServerEndpointResponse> createLicenseServerEndpoint({
  required String identityProviderArn,
  required LicenseServerSettings licenseServerSettings,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'IdentityProviderArn': identityProviderArn,
    'LicenseServerSettings': licenseServerSettings,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/license-server/CreateLicenseServerEndpoint',
    exceptionFnMap: _exceptionFns,
  );
  return CreateLicenseServerEndpointResponse.fromJson(response);
}