deregisterIdentityProvider method
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identityProvider :
An object that specifies details for the Active Directory identity
provider.
Parameter identityProviderArn :
The Amazon Resource Name (ARN) that identifies the identity provider to
deregister.
Parameter product :
The name of the user-based subscription product.
Valid values: VISUAL_STUDIO_ENTERPRISE |
VISUAL_STUDIO_PROFESSIONAL |
OFFICE_PROFESSIONAL_PLUS |
REMOTE_DESKTOP_SERVICES
Implementation
Future<DeregisterIdentityProviderResponse> deregisterIdentityProvider({
IdentityProvider? identityProvider,
String? identityProviderArn,
String? product,
}) async {
final $payload = <String, dynamic>{
if (identityProvider != null) 'IdentityProvider': identityProvider,
if (identityProviderArn != null)
'IdentityProviderArn': identityProviderArn,
if (product != null) 'Product': product,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/identity-provider/DeregisterIdentityProvider',
exceptionFnMap: _exceptionFns,
);
return DeregisterIdentityProviderResponse.fromJson(response);
}