listLicenseServerEndpoints method
List the Remote Desktop Services (RDS) License Server endpoints
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filters :
You can use the following filters to streamline results:
- IdentityProviderArn
Parameter maxResults :
The maximum number of results to return from a single request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListLicenseServerEndpointsResponse> listLicenseServerEndpoints({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/license-server/ListLicenseServerEndpoints',
exceptionFnMap: _exceptionFns,
);
return ListLicenseServerEndpointsResponse.fromJson(response);
}