registerIdentityProvider method

Future<RegisterIdentityProviderResponse> registerIdentityProvider({
  1. required IdentityProvider identityProvider,
  2. required String product,
  3. Settings? settings,
  4. Map<String, String>? tags,
})

Registers an identity provider for user-based subscriptions.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter identityProvider : An object that specifies details for the identity provider to register.

Parameter product : The name of the user-based subscription product.

Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL | OFFICE_PROFESSIONAL_PLUS | REMOTE_DESKTOP_SERVICES

Parameter settings : The registered identity provider’s product related configuration settings such as the subnets to provision VPC endpoints.

Parameter tags : The tags that apply to the identity provider's registration.

Implementation

Future<RegisterIdentityProviderResponse> registerIdentityProvider({
  required IdentityProvider identityProvider,
  required String product,
  Settings? settings,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'IdentityProvider': identityProvider,
    'Product': product,
    if (settings != null) 'Settings': settings,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/identity-provider/RegisterIdentityProvider',
    exceptionFnMap: _exceptionFns,
  );
  return RegisterIdentityProviderResponse.fromJson(response);
}