updateIdentityProviderSettings method

Future<UpdateIdentityProviderSettingsResponse> updateIdentityProviderSettings({
  1. required UpdateSettings updateSettings,
  2. IdentityProvider? identityProvider,
  3. String? identityProviderArn,
  4. String? product,
})

Updates additional product configuration settings for the registered identity provider.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter updateSettings : Updates the registered identity provider’s product related configuration settings. You can update any combination of settings in a single operation such as the:

  • Subnets which you want to add to provision VPC endpoints.
  • Subnets which you want to remove the VPC endpoints from.
  • Security group ID which permits traffic to the VPC endpoints.

Parameter identityProviderArn : The Amazon Resource Name (ARN) of the identity provider to update.

Parameter product : The name of the user-based subscription product.

Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL | OFFICE_PROFESSIONAL_PLUS | REMOTE_DESKTOP_SERVICES

Implementation

Future<UpdateIdentityProviderSettingsResponse>
    updateIdentityProviderSettings({
  required UpdateSettings updateSettings,
  IdentityProvider? identityProvider,
  String? identityProviderArn,
  String? product,
}) async {
  final $payload = <String, dynamic>{
    'UpdateSettings': updateSettings,
    if (identityProvider != null) 'IdentityProvider': identityProvider,
    if (identityProviderArn != null)
      'IdentityProviderArn': identityProviderArn,
    if (product != null) 'Product': product,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/identity-provider/UpdateIdentityProviderSettings',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateIdentityProviderSettingsResponse.fromJson(response);
}