closeInstancePublicPorts method
Future<CloseInstancePublicPortsResult>
closeInstancePublicPorts({
- required String instanceName,
- required PortInfo portInfo,
Closes ports for a specific Amazon Lightsail instance.
The CloseInstancePublicPorts action supports tag-based access
control via resource tags applied to the resource identified by
instanceName. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instanceName :
The name of the instance for which to close ports.
Parameter portInfo :
An object to describe the ports to close for the specified instance.
Implementation
Future<CloseInstancePublicPortsResult> closeInstancePublicPorts({
required String instanceName,
required PortInfo portInfo,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.CloseInstancePublicPorts'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instanceName': instanceName,
'portInfo': portInfo,
},
);
return CloseInstancePublicPortsResult.fromJson(jsonResponse.body);
}