createInstancesFromSnapshot method
- required String availabilityZone,
- required String bundleId,
- required List<
String> instanceNames, - List<
AddOnRequest> ? addOns, - Map<
String, List< ? attachedDiskMapping,DiskMap> > - String? instanceSnapshotName,
- IpAddressType? ipAddressType,
- String? keyPairName,
- String? restoreDate,
- String? sourceInstanceName,
- List<
Tag> ? tags, - bool? useLatestRestorableAutoSnapshot,
- String? userData,
Creates one or more new instances from a manual or automatic snapshot of an instance.
The create instances from snapshot operation supports
tag-based access control via request tags and resource tags applied to the
resource identified by instance snapshot name. For more
information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter availabilityZone :
The Availability Zone where you want to create your instances. Use the
following formatting: us-east-2a (case sensitive). You can
get a list of Availability Zones by using the get
regions operation. Be sure to add the include Availability
Zones parameter to your request.
Parameter bundleId :
The bundle of specification information for your virtual private server
(or instance), including the pricing plan (micro_x_x).
Parameter instanceNames :
The names for your new instances.
Parameter addOns :
An array of objects representing the add-ons to enable for the new
instance.
Parameter attachedDiskMapping :
An object containing information about one or more disk mappings.
Parameter instanceSnapshotName :
The name of the instance snapshot on which you are basing your new
instances. Use the get instance snapshots operation to return information
about your existing snapshots.
Constraint:
-
This parameter cannot be defined together with the
source instance nameparameter. Theinstance snapshot nameandsource instance nameparameters are mutually exclusive.
Parameter ipAddressType :
The IP address type for the instance.
The possible values are ipv4 for IPv4 only, ipv6
for IPv6 only, and dualstack for IPv4 and IPv6.
The default value is dualstack.
Parameter keyPairName :
The name for your key pair.
Parameter restoreDate :
The date of the automatic snapshot to use for the new instance. Use the
get auto snapshots operation to identify the dates of the
available automatic snapshots.
Constraints:
-
Must be specified in
YYYY-MM-DDformat. -
This parameter cannot be defined together with the
use latest restorable auto snapshotparameter. Therestore dateanduse latest restorable auto snapshotparameters are mutually exclusive. - Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.
Parameter sourceInstanceName :
The name of the source instance from which the source automatic snapshot
was created.
Constraints:
-
This parameter cannot be defined together with the
instance snapshot nameparameter. Thesource instance nameandinstance snapshot nameparameters are mutually exclusive. - Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.
Parameter tags :
The tag keys and optional values to add to the resource during create.
Use the TagResource action to tag a resource after it's
created.
Parameter useLatestRestorableAutoSnapshot :
A Boolean value to indicate whether to use the latest available automatic
snapshot.
Constraints:
-
This parameter cannot be defined together with the
restore dateparameter. Theuse latest restorable auto snapshotandrestore dateparameters are mutually exclusive. - Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.
Parameter userData :
You can create a launch script that configures a server with additional
user data. For example, apt-get -y update.
Implementation
Future<CreateInstancesFromSnapshotResult> createInstancesFromSnapshot({
required String availabilityZone,
required String bundleId,
required List<String> instanceNames,
List<AddOnRequest>? addOns,
Map<String, List<DiskMap>>? attachedDiskMapping,
String? instanceSnapshotName,
IpAddressType? ipAddressType,
String? keyPairName,
String? restoreDate,
String? sourceInstanceName,
List<Tag>? tags,
bool? useLatestRestorableAutoSnapshot,
String? userData,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.CreateInstancesFromSnapshot'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'availabilityZone': availabilityZone,
'bundleId': bundleId,
'instanceNames': instanceNames,
if (addOns != null) 'addOns': addOns,
if (attachedDiskMapping != null)
'attachedDiskMapping': attachedDiskMapping,
if (instanceSnapshotName != null)
'instanceSnapshotName': instanceSnapshotName,
if (ipAddressType != null) 'ipAddressType': ipAddressType.value,
if (keyPairName != null) 'keyPairName': keyPairName,
if (restoreDate != null) 'restoreDate': restoreDate,
if (sourceInstanceName != null)
'sourceInstanceName': sourceInstanceName,
if (tags != null) 'tags': tags,
if (useLatestRestorableAutoSnapshot != null)
'useLatestRestorableAutoSnapshot': useLatestRestorableAutoSnapshot,
if (userData != null) 'userData': userData,
},
);
return CreateInstancesFromSnapshotResult.fromJson(jsonResponse.body);
}