downloadDefaultKeyPair method
Downloads the regional Amazon Lightsail default key pair.
This action also creates a Lightsail default key pair if a default key pair does not currently exist in the Amazon Web Services Region.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Implementation
Future<DownloadDefaultKeyPairResult> downloadDefaultKeyPair() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.DownloadDefaultKeyPair'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return DownloadDefaultKeyPairResult.fromJson(jsonResponse.body);
}