getBucketBundles method

Future<GetBucketBundlesResult> getBucketBundles({
  1. bool? includeInactive,
})

Returns the bundles that you can apply to a Amazon Lightsail bucket.

The bucket bundle specifies the monthly cost, storage quota, and data transfer quota for a bucket.

Use the UpdateBucketBundle action to update the bundle for a bucket.

May throw AccessDeniedException. May throw InvalidInputException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter includeInactive : A Boolean value that indicates whether to include inactive (unavailable) bundles in the response of your request.

Implementation

Future<GetBucketBundlesResult> getBucketBundles({
  bool? includeInactive,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetBucketBundles'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (includeInactive != null) 'includeInactive': includeInactive,
    },
  );

  return GetBucketBundlesResult.fromJson(jsonResponse.body);
}