getBucketMetricData method

Future<GetBucketMetricDataResult> getBucketMetricData({
  1. required String bucketName,
  2. required DateTime endTime,
  3. required BucketMetricName metricName,
  4. required int period,
  5. required DateTime startTime,
  6. required List<MetricStatistic> statistics,
  7. required MetricUnit unit,
})

Returns the data points of a specific metric for an Amazon Lightsail bucket.

Metrics report the utilization of a bucket. View and collect metric data regularly to monitor the number of objects stored in a bucket (including object versions) and the storage space used by those objects.

May throw AccessDeniedException. May throw InvalidInputException. May throw NotFoundException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter bucketName : The name of the bucket for which to get metric data.

Parameter endTime : The timestamp indicating the latest data to be returned.

Parameter metricName : The metric for which you want to return information.

Valid bucket metric names are listed below, along with the most useful statistics to include in your request, and the published unit value.

  • BucketSizeBytes - The amount of data in bytes stored in a bucket. This value is calculated by summing the size of all objects in the bucket (including object versions), including the size of all parts for all incomplete multipart uploads to the bucket.

    Statistics: The most useful statistic is Maximum.

    Unit: The published unit is Bytes.

  • NumberOfObjects - The total number of objects stored in a bucket. This value is calculated by counting all objects in the bucket (including object versions) and the total number of parts for all incomplete multipart uploads to the bucket.

    Statistics: The most useful statistic is Average.

    Unit: The published unit is Count.

Parameter period : The granularity, in seconds, of the returned data points.

Parameter startTime : The timestamp indicating the earliest data to be returned.

Parameter statistics : The statistic for the metric.

The following statistics are available:

  • Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.
  • Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.
  • Sum - The sum of all values submitted for the matching metric. You can use this statistic to determine the total volume of a metric.
  • Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.
  • SampleCount - The count, or number, of data points used for the statistical calculation.

Parameter unit : The unit for the metric data request.

Valid units depend on the metric data being requested. For the valid units with each available metric, see the metricName parameter.

Implementation

Future<GetBucketMetricDataResult> getBucketMetricData({
  required String bucketName,
  required DateTime endTime,
  required BucketMetricName metricName,
  required int period,
  required DateTime startTime,
  required List<MetricStatistic> statistics,
  required MetricUnit unit,
}) async {
  _s.validateNumRange(
    'period',
    period,
    60,
    86400,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetBucketMetricData'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'bucketName': bucketName,
      'endTime': unixTimestampToJson(endTime),
      'metricName': metricName.value,
      'period': period,
      'startTime': unixTimestampToJson(startTime),
      'statistics': statistics.map((e) => e.value).toList(),
      'unit': unit.value,
    },
  );

  return GetBucketMetricDataResult.fromJson(jsonResponse.body);
}