getContainerImages method

Future<GetContainerImagesResult> getContainerImages({
  1. required String serviceName,
})

Returns the container images that are registered to your Amazon Lightsail container service.

May throw AccessDeniedException. May throw InvalidInputException. May throw NotFoundException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter serviceName : The name of the container service for which to return registered container images.

Implementation

Future<GetContainerImagesResult> getContainerImages({
  required String serviceName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetContainerImages'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceName': serviceName,
    },
  );

  return GetContainerImagesResult.fromJson(jsonResponse.body);
}