getContainerServicePowers method
Returns the list of powers that can be specified for your Amazon Lightsail container services.
The power specifies the amount of memory, the number of vCPUs, and the base price of the container service.
May throw AccessDeniedException.
May throw InvalidInputException.
May throw NotFoundException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Implementation
Future<GetContainerServicePowersResult> getContainerServicePowers() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetContainerServicePowers'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetContainerServicePowersResult.fromJson(jsonResponse.body);
}