getDistributionBundles method
Returns the bundles that can be applied to your Amazon Lightsail content delivery network (CDN) distributions.
A distribution bundle specifies the monthly network transfer quota and monthly cost of your distribution.
May throw AccessDeniedException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw ServiceException.
May throw UnauthenticatedException.
Implementation
Future<GetDistributionBundlesResult> getDistributionBundles() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetDistributionBundles'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetDistributionBundlesResult.fromJson(jsonResponse.body);
}