getInstanceAccessDetails method
Future<GetInstanceAccessDetailsResult>
getInstanceAccessDetails({
- required String instanceName,
- InstanceAccessProtocol? protocol,
Returns temporary SSH keys you can use to connect to a specific virtual private server, or instance.
The get instance access details operation supports tag-based
access control via resource tags applied to the resource identified by
instance name. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instanceName :
The name of the instance to access.
Parameter protocol :
The protocol to use to connect to your instance. Defaults to
ssh.
Implementation
Future<GetInstanceAccessDetailsResult> getInstanceAccessDetails({
required String instanceName,
InstanceAccessProtocol? protocol,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetInstanceAccessDetails'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instanceName': instanceName,
if (protocol != null) 'protocol': protocol.value,
},
);
return GetInstanceAccessDetailsResult.fromJson(jsonResponse.body);
}