getLoadBalancerTlsPolicies method

Future<GetLoadBalancerTlsPoliciesResult> getLoadBalancerTlsPolicies({
  1. String? pageToken,
})

Returns a list of TLS security policies that you can apply to Lightsail load balancers.

For more information about load balancer TLS security policies, see Configuring TLS security policies on your Amazon Lightsail load balancers in the Amazon Lightsail Developer Guide.

May throw AccessDeniedException. May throw AccountSetupInProgressException. May throw InvalidInputException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter pageToken : The token to advance to the next page of results from your request.

To get a page token, perform an initial GetLoadBalancerTlsPolicies request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request.

Implementation

Future<GetLoadBalancerTlsPoliciesResult> getLoadBalancerTlsPolicies({
  String? pageToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetLoadBalancerTlsPolicies'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (pageToken != null) 'pageToken': pageToken,
    },
  );

  return GetLoadBalancerTlsPoliciesResult.fromJson(jsonResponse.body);
}