getRelationalDatabase method
Future<GetRelationalDatabaseResult>
getRelationalDatabase({
- required String relationalDatabaseName,
Returns information about a specific database in Amazon Lightsail.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter relationalDatabaseName :
The name of the database that you are looking up.
Implementation
Future<GetRelationalDatabaseResult> getRelationalDatabase({
required String relationalDatabaseName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetRelationalDatabase'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'relationalDatabaseName': relationalDatabaseName,
},
);
return GetRelationalDatabaseResult.fromJson(jsonResponse.body);
}