getRelationalDatabaseBundles method
Returns the list of bundles that are available in Amazon Lightsail. A bundle describes the performance specifications for a database.
You can use a bundle ID to create a new database with explicit performance specifications.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter includeInactive :
A Boolean value that indicates whether to include inactive (unavailable)
bundles in the response of your request.
Parameter pageToken :
The token to advance to the next page of results from your request.
To get a page token, perform an initial
GetRelationalDatabaseBundles request. If your results are
paginated, the response will return a next page token that you can specify
as the page token in a subsequent request.
Implementation
Future<GetRelationalDatabaseBundlesResult> getRelationalDatabaseBundles({
bool? includeInactive,
String? pageToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetRelationalDatabaseBundles'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (includeInactive != null) 'includeInactive': includeInactive,
if (pageToken != null) 'pageToken': pageToken,
},
);
return GetRelationalDatabaseBundlesResult.fromJson(jsonResponse.body);
}