getRelationalDatabaseLogStreams method
Future<GetRelationalDatabaseLogStreamsResult>
getRelationalDatabaseLogStreams({
- required String relationalDatabaseName,
Returns a list of available log streams for a specific database in Amazon Lightsail.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter relationalDatabaseName :
The name of your database for which to get log streams.
Implementation
Future<GetRelationalDatabaseLogStreamsResult>
getRelationalDatabaseLogStreams({
required String relationalDatabaseName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetRelationalDatabaseLogStreams'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'relationalDatabaseName': relationalDatabaseName,
},
);
return GetRelationalDatabaseLogStreamsResult.fromJson(jsonResponse.body);
}