getRelationalDatabaseSnapshot method

Future<GetRelationalDatabaseSnapshotResult> getRelationalDatabaseSnapshot({
  1. required String relationalDatabaseSnapshotName,
})

Returns information about a specific database snapshot in Amazon Lightsail.

May throw AccessDeniedException. May throw AccountSetupInProgressException. May throw InvalidInputException. May throw NotFoundException. May throw OperationFailureException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter relationalDatabaseSnapshotName : The name of the database snapshot for which to get information.

Implementation

Future<GetRelationalDatabaseSnapshotResult> getRelationalDatabaseSnapshot({
  required String relationalDatabaseSnapshotName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetRelationalDatabaseSnapshot'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'relationalDatabaseSnapshotName': relationalDatabaseSnapshotName,
    },
  );

  return GetRelationalDatabaseSnapshotResult.fromJson(jsonResponse.body);
}