getSetupHistory method

Future<GetSetupHistoryResult> getSetupHistory({
  1. required String resourceName,
  2. String? pageToken,
})

Returns detailed information for five of the most recent SetupInstanceHttps requests that were ran on the target instance.

May throw AccessDeniedException. May throw InvalidInputException. May throw NotFoundException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter resourceName : The name of the resource for which you are requesting information.

Parameter pageToken : The token to advance to the next page of results from your request.

To get a page token, perform an initial GetSetupHistory request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request.

Implementation

Future<GetSetupHistoryResult> getSetupHistory({
  required String resourceName,
  String? pageToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.GetSetupHistory'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'resourceName': resourceName,
      if (pageToken != null) 'pageToken': pageToken,
    },
  );

  return GetSetupHistoryResult.fromJson(jsonResponse.body);
}