putInstancePublicPorts method
Opens ports for a specific Amazon Lightsail instance, and specifies the IP
addresses allowed to connect to the instance through the ports, and the
protocol. This action also closes all currently open ports that are not
included in the request. Include all of the ports and the protocols you
want to open in your PutInstancePublicPortsrequest. Or use
the OpenInstancePublicPorts action to open ports without
closing currently open ports.
The PutInstancePublicPorts action supports tag-based access
control via resource tags applied to the resource identified by
instanceName. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instanceName :
The name of the instance for which to open ports.
Parameter portInfos :
An array of objects to describe the ports to open for the specified
instance.
Implementation
Future<PutInstancePublicPortsResult> putInstancePublicPorts({
required String instanceName,
required List<PortInfo> portInfos,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.PutInstancePublicPorts'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instanceName': instanceName,
'portInfos': portInfos,
},
);
return PutInstancePublicPortsResult.fromJson(jsonResponse.body);
}