rebootRelationalDatabase method

Future<RebootRelationalDatabaseResult> rebootRelationalDatabase({
  1. required String relationalDatabaseName,
})

Restarts a specific database in Amazon Lightsail.

The reboot relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

May throw AccessDeniedException. May throw AccountSetupInProgressException. May throw InvalidInputException. May throw NotFoundException. May throw OperationFailureException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter relationalDatabaseName : The name of your database to reboot.

Implementation

Future<RebootRelationalDatabaseResult> rebootRelationalDatabase({
  required String relationalDatabaseName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.RebootRelationalDatabase'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'relationalDatabaseName': relationalDatabaseName,
    },
  );

  return RebootRelationalDatabaseResult.fromJson(jsonResponse.body);
}