updateInstanceMetadataOptions method

Future<UpdateInstanceMetadataOptionsResult> updateInstanceMetadataOptions({
  1. required String instanceName,
  2. HttpEndpoint? httpEndpoint,
  3. HttpProtocolIpv6? httpProtocolIpv6,
  4. int? httpPutResponseHopLimit,
  5. HttpTokens? httpTokens,
})

Modifies the Amazon Lightsail instance metadata parameters on a running or stopped instance. When you modify the parameters on a running instance, the GetInstance or GetInstances API operation initially responds with a state of pending. After the parameter modifications are successfully applied, the state changes to applied in subsequent GetInstance or GetInstances API calls. For more information, see Use IMDSv2 with an Amazon Lightsail instance in the Amazon Lightsail Developer Guide.

May throw AccessDeniedException. May throw AccountSetupInProgressException. May throw InvalidInputException. May throw NotFoundException. May throw OperationFailureException. May throw RegionSetupInProgressException. May throw ServiceException. May throw UnauthenticatedException.

Parameter instanceName : The name of the instance for which to update metadata parameters.

Parameter httpEndpoint : Enables or disables the HTTP metadata endpoint on your instances. If this parameter is not specified, the existing state is maintained.

If you specify a value of disabled, you cannot access your instance metadata.

Parameter httpProtocolIpv6 : Enables or disables the IPv6 endpoint for the instance metadata service. This setting applies only when the HTTP metadata endpoint is enabled.

Parameter httpPutResponseHopLimit : The desired HTTP PUT response hop limit for instance metadata requests. A larger number means that the instance metadata requests can travel farther. If no parameter is specified, the existing state is maintained.

Parameter httpTokens : The state of token usage for your instance metadata requests. If the parameter is not specified in the request, the default state is optional.

If the state is optional, you can choose whether to retrieve instance metadata with a signed token header on your request. If you retrieve the IAM role credentials without a token, the version 1.0 role credentials are returned. If you retrieve the IAM role credentials by using a valid signed token, the version 2.0 role credentials are returned.

If the state is required, you must send a signed token header with all instance metadata retrieval requests. In this state, retrieving the IAM role credential always returns the version 2.0 credentials. The version 1.0 credentials are not available.

Implementation

Future<UpdateInstanceMetadataOptionsResult> updateInstanceMetadataOptions({
  required String instanceName,
  HttpEndpoint? httpEndpoint,
  HttpProtocolIpv6? httpProtocolIpv6,
  int? httpPutResponseHopLimit,
  HttpTokens? httpTokens,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Lightsail_20161128.UpdateInstanceMetadataOptions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'instanceName': instanceName,
      if (httpEndpoint != null) 'httpEndpoint': httpEndpoint.value,
      if (httpProtocolIpv6 != null)
        'httpProtocolIpv6': httpProtocolIpv6.value,
      if (httpPutResponseHopLimit != null)
        'httpPutResponseHopLimit': httpPutResponseHopLimit,
      if (httpTokens != null) 'httpTokens': httpTokens.value,
    },
  );

  return UpdateInstanceMetadataOptionsResult.fromJson(jsonResponse.body);
}