Location class
"Suite of geospatial services including Maps, Places, Routes, Tracking, and Geofencing"
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateTrackerConsumer(
{required String consumerArn, required String trackerName}) → Future< void> - Creates an association between a geofence collection and a tracker resource. This allows the tracker resource to communicate location data to the linked geofence collection.
-
batchDeleteDevicePositionHistory(
{required List< String> deviceIds, required String trackerName}) → Future<BatchDeleteDevicePositionHistoryResponse> - Deletes the position history of one or more devices from a tracker resource.
-
batchDeleteGeofence(
{required String collectionName, required List< String> geofenceIds}) → Future<BatchDeleteGeofenceResponse> - Deletes a batch of geofences from a geofence collection.
-
batchEvaluateGeofences(
{required String collectionName, required List< DevicePositionUpdate> devicePositionUpdates}) → Future<BatchEvaluateGeofencesResponse> - Evaluates device positions against the geofence geometries from a given geofence collection.
-
batchGetDevicePosition(
{required List< String> deviceIds, required String trackerName}) → Future<BatchGetDevicePositionResponse> - Lists the latest device positions for requested devices.
-
batchPutGeofence(
{required String collectionName, required List< BatchPutGeofenceRequestEntry> entries}) → Future<BatchPutGeofenceResponse> - A batch request for storing geofence geometries into a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request.
-
batchUpdateDevicePosition(
{required String trackerName, required List< DevicePositionUpdate> updates}) → Future<BatchUpdateDevicePositionResponse> - Uploads position update data for one or more devices to a tracker resource (up to 10 devices per batch). Amazon Location uses the data when it reports the last known device position and position history. Amazon Location retains location data for 30 days.
-
calculateRoute(
{required String calculatorName, required List< double> departurePosition, required List<double> destinationPosition, DateTime? arrivalTime, CalculateRouteCarModeOptions? carModeOptions, bool? departNow, DateTime? departureTime, DistanceUnit? distanceUnit, bool? includeLegGeometry, String? key, OptimizationMode? optimizeFor, TravelMode? travelMode, CalculateRouteTruckModeOptions? truckModeOptions, List<List< ? waypointPositions}) → Future<double> >CalculateRouteResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to
CalculateRoutesorCalculateIsolinesunless you require Grab data.-
CalculateRouteis part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
CalculateRoutesoperation gives better results for point-to-point routing, while the version 2CalculateIsolinesoperation adds support for calculating service areas and travel time envelopes. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
-
-
calculateRouteMatrix(
{required String calculatorName, required List< List< departurePositions, required List<double> >List< destinationPositions, CalculateRouteCarModeOptions? carModeOptions, bool? departNow, DateTime? departureTime, DistanceUnit? distanceUnit, String? key, TravelMode? travelMode, CalculateRouteTruckModeOptions? truckModeOptions}) → Future<double> >CalculateRouteMatrixResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the V2
CalculateRouteMatrixunless you require Grab data.-
This version of
CalculateRouteMatrixis part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
CalculateRouteMatrixoperation gives better results for matrix routing calculations. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
This version of
-
cancelJob(
{required String jobId}) → Future< CancelJobResponse> -
CancelJobcancels a job that is currently running or pending. If the job is already in a terminal state (Completed,Failed, orCancelled), the operation returns successfully with the current status. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createGeofenceCollection(
{required String collectionName, String? description, String? kmsKeyId, PricingPlan? pricingPlan, String? pricingPlanDataSource, Map< String, String> ? tags}) → Future<CreateGeofenceCollectionResponse> - Creates a geofence collection, which manages and stores geofences.
-
createKey(
{required String keyName, required ApiKeyRestrictions restrictions, String? description, DateTime? expireTime, bool? noExpiry, Map< String, String> ? tags}) → Future<CreateKeyResponse> - Creates an API key resource in your Amazon Web Services account, which lets you grant actions for Amazon Location resources to the API key bearer.
-
createMap(
{required MapConfiguration configuration, required String mapName, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreateMapResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to the Maps API V2 unless you require
Grabdata.-
CreateMapis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Maps API version 2 has a simplified interface that can be used without creating or managing map resources.
-
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
createPlaceIndex(
{required String dataSource, required String indexName, DataSourceConfiguration? dataSourceConfiguration, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreatePlaceIndexResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Places API V2 unless you require Grab
data.
-
CreatePlaceIndexis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Places API version 2 has a simplified interface that can be used without creating or managing place index resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
-
createRouteCalculator(
{required String calculatorName, required String dataSource, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreateRouteCalculatorResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Routes API V2 unless you require Grab
data.
-
CreateRouteCalculatoris part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Routes API version 2 has a simplified interface that can be used without creating or managing route calculator resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
-
createTracker(
{required String trackerName, String? description, bool? eventBridgeEnabled, bool? kmsKeyEnableGeospatialQueries, String? kmsKeyId, PositionFiltering? positionFiltering, PricingPlan? pricingPlan, String? pricingPlanDataSource, Map< String, String> ? tags}) → Future<CreateTrackerResponse> - Creates a tracker resource in your Amazon Web Services account, which lets you retrieve current and historical location of devices.
-
deleteGeofenceCollection(
{required String collectionName}) → Future< void> - Deletes a geofence collection from your Amazon Web Services account.
-
deleteKey(
{required String keyName, bool? forceDelete}) → Future< void> - Deletes the specified API key. The API key must have been deactivated more than 90 days previously.
-
deleteMap(
{required String mapName}) → Future< void> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to the Maps API V2 unless you require
Grabdata.-
DeleteMapis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Maps API version 2 has a simplified interface that can be used without creating or managing map resources.
-
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
deletePlaceIndex(
{required String indexName}) → Future< void> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Places API V2 unless you require Grab
data.
-
DeletePlaceIndexis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Places API version 2 has a simplified interface that can be used without creating or managing place index resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
-
deleteRouteCalculator(
{required String calculatorName}) → Future< void> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Routes API V2 unless you require Grab
data.
-
DeleteRouteCalculatoris part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Routes API version 2 has a simplified interface that can be used without creating or managing route calculator resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
-
deleteTracker(
{required String trackerName}) → Future< void> - Deletes a tracker resource from your Amazon Web Services account.
-
describeGeofenceCollection(
{required String collectionName}) → Future< DescribeGeofenceCollectionResponse> - Retrieves the geofence collection details.
-
describeKey(
{required String keyName}) → Future< DescribeKeyResponse> - Retrieves the API key resource details.
-
describeMap(
{required String mapName}) → Future< DescribeMapResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to the Maps API V2 unless you require
Grabdata.-
DescribeMapis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Maps API version 2 has a simplified interface that can be used without creating or managing map resources.
-
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
describePlaceIndex(
{required String indexName}) → Future< DescribePlaceIndexResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Places API V2 unless you require Grab
data.
-
DescribePlaceIndexis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Places API version 2 has a simplified interface that can be used without creating or managing place index resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
-
describeRouteCalculator(
{required String calculatorName}) → Future< DescribeRouteCalculatorResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Routes API V2 unless you require Grab
data.
-
DescribeRouteCalculatoris part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Routes API version 2 has a simplified interface that can be used without creating or managing route calculator resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
-
describeTracker(
{required String trackerName}) → Future< DescribeTrackerResponse> - Retrieves the tracker resource details.
-
disassociateTrackerConsumer(
{required String consumerArn, required String trackerName}) → Future< void> - Removes the association between a tracker resource and a geofence collection.
-
forecastGeofenceEvents(
{required String collectionName, required ForecastGeofenceEventsDeviceState deviceState, DistanceUnit? distanceUnit, int? maxResults, String? nextToken, SpeedUnit? speedUnit, double? timeHorizonMinutes}) → Future< ForecastGeofenceEventsResponse> - This action forecasts future geofence events that are likely to occur within a specified time horizon if a device continues moving at its current speed. Each forecasted event is associated with a geofence from a provided geofence collection. A forecast event can have one of the following states:
-
getDevicePosition(
{required String deviceId, required String trackerName}) → Future< GetDevicePositionResponse> - Retrieves a device's most recent position according to its sample time.
-
getDevicePositionHistory(
{required String deviceId, required String trackerName, DateTime? endTimeExclusive, int? maxResults, String? nextToken, DateTime? startTimeInclusive}) → Future< GetDevicePositionHistoryResponse> - Retrieves the device position history from a tracker resource within a specified range of time.
-
getGeofence(
{required String collectionName, required String geofenceId}) → Future< GetGeofenceResponse> - Retrieves the geofence details from a geofence collection.
-
getJob(
{required String jobId}) → Future< GetJobResponse> -
GetJobretrieves detailed information about a specific job, including its current status, configuration, and error information if the job failed. -
getMapGlyphs(
{required String fontStack, required String fontUnicodeRange, required String mapName, String? key}) → Future< GetMapGlyphsResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to
GetGlyphsunless you requireGrabdata.-
GetMapGlyphsis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
GetGlyphsoperation gives a better user experience and is compatible with the remainder of the V2 Maps API. -
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
getMapSprites(
{required String fileName, required String mapName, String? key}) → Future< GetMapSpritesResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to
GetSpritesunless you requireGrabdata.-
GetMapSpritesis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
GetSpritesoperation gives a better user experience and is compatible with the remainder of the V2 Maps API. -
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
getMapStyleDescriptor(
{required String mapName, String? key}) → Future< GetMapStyleDescriptorResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to
GetStyleDescriptorunless you requireGrabdata.-
GetMapStyleDescriptoris part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
GetStyleDescriptoroperation gives a better user experience and is compatible with the remainder of the V2 Maps API. -
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
getMapTile(
{required String mapName, required String x, required String y, required String z, String? key}) → Future< GetMapTileResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to
GetTileunless you requireGrabdata.-
GetMapTileis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
GetTileoperation gives a better user experience and is compatible with the remainder of the V2 Maps API. -
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
getPlace(
{required String indexName, required String placeId, String? key, String? language}) → Future< GetPlaceResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the V2
GetPlaceoperation unless you require Grab data.-
This version of
GetPlaceis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
Version 2 of the
GetPlaceoperation interoperates with the rest of the Places V2 API, while this version does not. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
This version of
-
listDevicePositions(
{required String trackerName, TrackingFilterGeometry? filterGeometry, int? maxResults, String? nextToken}) → Future< ListDevicePositionsResponse> - A batch request to retrieve all device positions.
-
listGeofenceCollections(
{int? maxResults, String? nextToken}) → Future< ListGeofenceCollectionsResponse> - Lists geofence collections in your Amazon Web Services account.
-
listGeofences(
{required String collectionName, int? maxResults, String? nextToken}) → Future< ListGeofencesResponse> - Lists geofences stored in a given geofence collection.
-
listJobs(
{JobsFilter? filter, int? maxResults, String? nextToken}) → Future< ListJobsResponse> -
ListJobsretrieves a list of jobs with optional filtering and pagination support. -
listKeys(
{ApiKeyFilter? filter, int? maxResults, String? nextToken}) → Future< ListKeysResponse> - Lists API key resources in your Amazon Web Services account.
-
listMaps(
{int? maxResults, String? nextToken}) → Future< ListMapsResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to the Maps API V2 unless you require
Grabdata.-
ListMapsis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Maps API version 2 has a simplified interface that can be used without creating or managing map resources.
-
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
listPlaceIndexes(
{int? maxResults, String? nextToken}) → Future< ListPlaceIndexesResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Places API V2 unless you require Grab
data.
-
ListPlaceIndexesis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Places API version 2 has a simplified interface that can be used without creating or managing place index resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
-
listRouteCalculators(
{int? maxResults, String? nextToken}) → Future< ListRouteCalculatorsResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Routes API V2 unless you require Grab
data.
-
ListRouteCalculatorsis part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Routes API version 2 has a simplified interface that can be used without creating or managing route calculator resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags that are applied to the specified Amazon Location resource.
-
listTrackerConsumers(
{required String trackerName, int? maxResults, String? nextToken}) → Future< ListTrackerConsumersResponse> - Lists geofence collections currently associated to the given tracker resource.
-
listTrackers(
{int? maxResults, String? nextToken}) → Future< ListTrackersResponse> - Lists tracker resources in your Amazon Web Services account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putGeofence(
{required String collectionName, required String geofenceId, required GeofenceGeometry geometry, Map< String, String> ? geofenceProperties}) → Future<PutGeofenceResponse> - Stores a geofence geometry in a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request.
-
searchPlaceIndexForPosition(
{required String indexName, required List< double> position, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForPositionResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to
ReverseGeocodeorSearchNearbyunless you require Grab data.-
SearchPlaceIndexForPositionis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
ReverseGeocodeoperation gives better results in the address reverse-geocoding use case, while the version 2SearchNearbyoperation gives better results when searching for businesses and points of interest near a specific location. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
-
-
searchPlaceIndexForSuggestions(
{required String indexName, required String text, List< double> ? biasPosition, List<double> ? filterBBox, List<String> ? filterCategories, List<String> ? filterCountries, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForSuggestionsResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to
SuggestorAutocompleteunless you require Grab data.-
SearchPlaceIndexForSuggestionsis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
Suggestoperation gives better results for typeahead place search suggestions with fuzzy matching, while the version 2Autocompleteoperation gives better results for address completion based on partial input. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
-
-
searchPlaceIndexForText(
{required String indexName, required String text, List< double> ? biasPosition, List<double> ? filterBBox, List<String> ? filterCategories, List<String> ? filterCountries, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForTextResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to
GeocodeorSearchTextunless you require Grab data.-
SearchPlaceIndexForTextis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). -
The version 2
Geocodeoperation gives better results in the address geocoding use case, while the version 2SearchTextoperation gives better results when searching for businesses and points of interest. -
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
-
-
startJob(
{required JobAction action, required String executionRoleArn, required JobInputOptions inputOptions, required JobOutputOptions outputOptions, JobActionOptions? actionOptions, String? clientToken, String? name, Map< String, String> ? tags}) → Future<StartJobResponse> -
StartJobstarts a new asynchronous bulk processing job. You specify the input data location in Amazon S3, the action to perform, and the output location where results are written. -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified Amazon Location Service resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from the specified Amazon Location resource.
-
updateGeofenceCollection(
{required String collectionName, String? description, PricingPlan? pricingPlan, String? pricingPlanDataSource}) → Future< UpdateGeofenceCollectionResponse> - Updates the specified properties of a given geofence collection.
-
updateKey(
{required String keyName, String? description, DateTime? expireTime, bool? forceUpdate, bool? noExpiry, ApiKeyRestrictions? restrictions}) → Future< UpdateKeyResponse> - Updates the specified properties of a given API key resource.
-
updateMap(
{required String mapName, MapConfigurationUpdate? configurationUpdate, String? description, PricingPlan? pricingPlan}) → Future< UpdateMapResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend upgrading to the Maps API V2 unless you require
Grabdata.-
UpdateMapis part of a previous Amazon Location Service Maps API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Maps API version 2 has a simplified interface that can be used without creating or managing map resources.
-
If you are using an AWS SDK or the AWS CLI, note that the Maps API version
2 is found under
geo-mapsorgeo_maps, not underlocation. -
Since
Grabis not yet fully supported in Maps API version 2, we recommend you continue using API version 1 when usingGrab. - Start your version 2 API journey with the Maps V2 API Reference or the Developer Guide.
-
-
updatePlaceIndex(
{required String indexName, DataSourceConfiguration? dataSourceConfiguration, String? description, PricingPlan? pricingPlan}) → Future< UpdatePlaceIndexResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Places API V2 unless you require Grab
data.
-
UpdatePlaceIndexis part of a previous Amazon Location Service Places API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Places API version 2 has a simplified interface that can be used without creating or managing place index resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Places API version 2 is found under
geo-placesorgeo_places, not underlocation. - Since Grab is not yet fully supported in Places API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Places V2 API Reference or the Developer Guide.
-
-
updateRouteCalculator(
{required String calculatorName, String? description, PricingPlan? pricingPlan}) → Future< UpdateRouteCalculatorResponse> -
This operation is no longer current and may be deprecated in the future.
We recommend you upgrade to the Routes API V2 unless you require Grab
data.
-
UpdateRouteCalculatoris part of a previous Amazon Location Service Routes API (version 1) which has been superseded by a more intuitive, powerful, and complete API (version 2). - The Routes API version 2 has a simplified interface that can be used without creating or managing route calculator resources.
-
If you are using an Amazon Web Services SDK or the Amazon Web Services
CLI, note that the Routes API version 2 is found under
geo-routesorgeo_routes, not underlocation. - Since Grab is not yet fully supported in Routes API version 2, we recommend you continue using API version 1 when using Grab.
- Start your version 2 API journey with the Routes V2 API Reference or the Developer Guide.
-
-
updateTracker(
{required String trackerName, String? description, bool? eventBridgeEnabled, bool? kmsKeyEnableGeospatialQueries, PositionFiltering? positionFiltering, PricingPlan? pricingPlan, String? pricingPlanDataSource}) → Future< UpdateTrackerResponse> - Updates the specified properties of a given tracker resource.
-
verifyDevicePosition(
{required DeviceState deviceState, required String trackerName, DistanceUnit? distanceUnit}) → Future< VerifyDevicePositionResponse> - Verifies the integrity of the device's position by determining if it was reported behind a proxy, and by comparing it to an inferred position estimated based on the device's state.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited