batchDeleteGeofence method

Future<BatchDeleteGeofenceResponse> batchDeleteGeofence({
  1. required String collectionName,
  2. required List<String> geofenceIds,
})

Deletes a batch of geofences from a geofence collection.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter collectionName : The geofence collection storing the geofences to be deleted.

Parameter geofenceIds : The batch of geofences to be deleted.

Implementation

Future<BatchDeleteGeofenceResponse> batchDeleteGeofence({
  required String collectionName,
  required List<String> geofenceIds,
}) async {
  final $payload = <String, dynamic>{
    'GeofenceIds': geofenceIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/geofencing/v0/collections/${Uri.encodeComponent(collectionName)}/delete-geofences',
    hostPrefix: 'geofencing.',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeleteGeofenceResponse.fromJson(response);
}