cancelJob method

Future<CancelJobResponse> cancelJob({
  1. required String jobId,
})

CancelJob cancels a job that is currently running or pending. If the job is already in a terminal state (Completed, Failed, or Cancelled), the operation returns successfully with the current status.

For more information, see Job concepts in the Amazon Location Service Developer Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter jobId : The unique identifier of the job to cancel.

Implementation

Future<CancelJobResponse> cancelJob({
  required String jobId,
}) async {
  final $payload = <String, dynamic>{
    'JobId': jobId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/metadata/v0/jobs/cancel-job',
    exceptionFnMap: _exceptionFns,
  );
  return CancelJobResponse.fromJson(response);
}