createTracker method

Future<CreateTrackerResponse> createTracker({
  1. required String trackerName,
  2. String? description,
  3. bool? eventBridgeEnabled,
  4. bool? kmsKeyEnableGeospatialQueries,
  5. String? kmsKeyId,
  6. PositionFiltering? positionFiltering,
  7. PricingPlan? pricingPlan,
  8. String? pricingPlanDataSource,
  9. Map<String, String>? tags,
})

Creates a tracker resource in your Amazon Web Services account, which lets you retrieve current and historical location of devices.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter trackerName : The name for the tracker resource.

Requirements:

  • Contain only alphanumeric characters (A-Z, a-z, 0-9) , hyphens (-), periods (.), and underscores (_).
  • Must be a unique tracker resource name.
  • No spaces allowed. For example, ExampleTracker.

Parameter description : An optional description for the tracker resource.

Parameter eventBridgeEnabled : Whether to enable position UPDATE events from this tracker to be sent to EventBridge.

Parameter kmsKeyEnableGeospatialQueries : Enables GeospatialQueries for a tracker that uses a Amazon Web Services KMS customer managed key.

This parameter is only used if you are using a KMS customer managed key.

You can choose to opt-in to the Bounding Polygon Quseries feature. This is done by setting the KmsKeyEnableGeospatialQueries parameter to true when creating or updating a Tracker.

Parameter kmsKeyId : A key identifier for an Amazon Web Services KMS customer managed key. Enter a key ID, key ARN, alias name, or alias ARN.

Parameter positionFiltering : Specifies the position filtering for the tracker resource.

Valid values:

  • TimeBased - Location updates are evaluated against linked geofence collections, but not every location update is stored. If your update frequency is more often than 30 seconds, only one update per 30 seconds is stored for each unique device ID.
  • DistanceBased - If the device has moved less than 30 m (98.4 ft), location updates are ignored. Location updates within this area are neither evaluated against linked geofence collections, nor stored. This helps control costs by reducing the number of geofence evaluations and historical device positions to paginate through. Distance-based filtering can also reduce the effects of GPS noise when displaying device trajectories on a map.
  • AccuracyBased - If the device has moved less than the measured accuracy, location updates are ignored. For example, if two consecutive updates from a device have a horizontal accuracy of 5 m and 10 m, the second update is ignored if the device has moved less than 15 m. Ignored location updates are neither evaluated against linked geofence collections, nor stored. This can reduce the effects of GPS noise when displaying device trajectories on a map, and can help control your costs by reducing the number of geofence evaluations.
This field is optional. If not specified, the default value is TimeBased.

Parameter pricingPlan : No longer used. If included, the only allowed value is RequestBasedUsage.

Parameter pricingPlanDataSource : This parameter is no longer used.

Parameter tags : Applies one or more tags to the tracker resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.

Format: "key" : "value"

Restrictions:

  • Maximum 50 tags per resource
  • Each resource tag must be unique with a maximum of one value.
  • Maximum key length: 128 Unicode characters in UTF-8
  • Maximum value length: 256 Unicode characters in UTF-8
  • Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
  • Cannot use "aws:" as a prefix for a key.

Implementation

Future<CreateTrackerResponse> createTracker({
  required String trackerName,
  String? description,
  bool? eventBridgeEnabled,
  bool? kmsKeyEnableGeospatialQueries,
  String? kmsKeyId,
  PositionFiltering? positionFiltering,
  PricingPlan? pricingPlan,
  String? pricingPlanDataSource,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'TrackerName': trackerName,
    if (description != null) 'Description': description,
    if (eventBridgeEnabled != null) 'EventBridgeEnabled': eventBridgeEnabled,
    if (kmsKeyEnableGeospatialQueries != null)
      'KmsKeyEnableGeospatialQueries': kmsKeyEnableGeospatialQueries,
    if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
    if (positionFiltering != null)
      'PositionFiltering': positionFiltering.value,
    if (pricingPlan != null) 'PricingPlan': pricingPlan.value,
    if (pricingPlanDataSource != null)
      'PricingPlanDataSource': pricingPlanDataSource,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/tracking/v0/trackers',
    exceptionFnMap: _exceptionFns,
  );
  return CreateTrackerResponse.fromJson(response);
}