deleteGeofenceCollection method

Future<void> deleteGeofenceCollection({
  1. required String collectionName,
})

Deletes a geofence collection from your Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter collectionName : The name of the geofence collection to be deleted.

Implementation

Future<void> deleteGeofenceCollection({
  required String collectionName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/geofencing/v0/collections/${Uri.encodeComponent(collectionName)}',
    hostPrefix: 'cp.geofencing.',
    exceptionFnMap: _exceptionFns,
  );
}