deleteMap method

Future<void> deleteMap({
  1. required String mapName,
})
Deletes a map resource from your Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter mapName : The name of the map resource to be deleted.

Implementation

Future<void> deleteMap({
  required String mapName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/maps/v0/maps/${Uri.encodeComponent(mapName)}',
    exceptionFnMap: _exceptionFns,
  );
}