deletePlaceIndex method

Future<void> deletePlaceIndex({
  1. required String indexName,
})
Deletes a place index resource from your Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter indexName : The name of the place index resource to be deleted.

Implementation

Future<void> deletePlaceIndex({
  required String indexName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/places/v0/indexes/${Uri.encodeComponent(indexName)}',
    exceptionFnMap: _exceptionFns,
  );
}