deleteTracker method
Deletes a tracker resource from your Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter trackerName :
The name of the tracker resource to be deleted.
Implementation
Future<void> deleteTracker({
required String trackerName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tracking/v0/trackers/${Uri.encodeComponent(trackerName)}',
hostPrefix: 'cp.tracking.',
exceptionFnMap: _exceptionFns,
);
}