getJob method
GetJob retrieves detailed information about a specific job,
including its current status, configuration, and error information if the
job failed.
For more information, see Job concepts in the Amazon Location Service Developer Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter jobId :
The unique identifier of the job to retrieve.
Implementation
Future<GetJobResponse> getJob({
required String jobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/metadata/v0/jobs/${Uri.encodeComponent(jobId)}',
exceptionFnMap: _exceptionFns,
);
return GetJobResponse.fromJson(response);
}