getPlace method

Future<GetPlaceResponse> getPlace({
  1. required String indexName,
  2. required String placeId,
  3. String? key,
  4. String? language,
})
Finds a place by its unique ID. A PlaceId is returned by other search operations.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter indexName : The name of the place index resource that you want to use for the search.

Parameter placeId : The identifier of the place to find.

Parameter key : The optional API key to authorize the request.

Parameter language : The preferred language used to return results. The value must be a valid BCP 47 language tag, for example, en for English.

This setting affects the languages used in the results, but not the results themselves. If no language is specified, or not supported for a particular result, the partner automatically chooses a language for the result.

For an example, we'll use the Greek language. You search for a location around Athens, Greece, with the language parameter set to en. The city in the results will most likely be returned as Athens.

If you set the language parameter to el, for Greek, then the city in the results will more likely be returned as Αθήνα.

If the data provider does not have a value for Greek, the result will be in a language that the provider does support.

Implementation

Future<GetPlaceResponse> getPlace({
  required String indexName,
  required String placeId,
  String? key,
  String? language,
}) async {
  final $query = <String, List<String>>{
    if (key != null) 'key': [key],
    if (language != null) 'language': [language],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/places/v0/indexes/${Uri.encodeComponent(indexName)}/places/${Uri.encodeComponent(placeId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetPlaceResponse.fromJson(response);
}