listJobs method
ListJobs retrieves a list of jobs with optional filtering and
pagination support.
For more information, see Job concepts in the Amazon Location Service Developer Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
An optional structure containing criteria by which to filter job results.
Parameter maxResults :
Maximum number of jobs to return.
Parameter nextToken :
The pagination token specifying which page of results to return in the
response. If no token is provided, the default page is the first page.
Implementation
Future<ListJobsResponse> listJobs({
JobsFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/metadata/v0/jobs/list-jobs',
exceptionFnMap: _exceptionFns,
);
return ListJobsResponse.fromJson(response);
}