listMaps method

Future<ListMapsResponse> listMaps({
  1. int? maxResults,
  2. String? nextToken,
})
Lists map resources in your Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : An optional limit for the number of resources returned in a single call.

Default value: 100

Parameter nextToken : The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Implementation

Future<ListMapsResponse> listMaps({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/maps/v0/list-maps',
    exceptionFnMap: _exceptionFns,
  );
  return ListMapsResponse.fromJson(response);
}