listRouteCalculators method
Lists route calculator resources in your Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
An optional maximum number of results returned in a single call.
Default Value: 100
Parameter nextToken :
The pagination token specifying which page of results to return in the
response. If no token is provided, the default page is the first page.
Default Value: null
Implementation
Future<ListRouteCalculatorsResponse> listRouteCalculators({
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/routes/v0/list-calculators',
hostPrefix: 'cp.routes.',
exceptionFnMap: _exceptionFns,
);
return ListRouteCalculatorsResponse.fromJson(response);
}