listTrackerConsumers method

Future<ListTrackerConsumersResponse> listTrackerConsumers({
  1. required String trackerName,
  2. int? maxResults,
  3. String? nextToken,
})

Lists geofence collections currently associated to the given tracker resource.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter trackerName : The tracker resource whose associated geofence collections you want to list.

Parameter maxResults : An optional limit for the number of resources returned in a single call.

Default value: 100

Parameter nextToken : The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Implementation

Future<ListTrackerConsumersResponse> listTrackerConsumers({
  required String trackerName,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/tracking/v0/trackers/${Uri.encodeComponent(trackerName)}/list-consumers',
    hostPrefix: 'cp.tracking.',
    exceptionFnMap: _exceptionFns,
  );
  return ListTrackerConsumersResponse.fromJson(response);
}