searchPlaceIndexForPosition method
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexName :
The name of the place index resource you want to use for the search.
Parameter position :
Specifies the longitude and latitude of the position to query.
This parameter must contain a pair of numbers. The first number represents the X coordinate, or longitude; the second number represents the Y coordinate, or latitude.
For example, [-123.1174, 49.2847] represents a position
with longitude -123.1174 and latitude 49.2847.
Parameter key :
The optional API
key to authorize the request.
Parameter language :
The preferred language used to return results. The value must be a valid
BCP 47 language tag, for
example, en for English.
This setting affects the languages used in the results, but not the results themselves. If no language is specified, or not supported for a particular result, the partner automatically chooses a language for the result.
For an example, we'll use the Greek language. You search for a location
around Athens, Greece, with the language parameter set to
en. The city in the results will most likely be
returned as Athens.
If you set the language parameter to el, for
Greek, then the city in the results will more likely be
returned as Αθήνα.
If the data provider does not have a value for Greek, the result will be in a language that the provider does support.
Parameter maxResults :
An optional parameter. The maximum number of results returned per request.
Default value: 50
Implementation
Future<SearchPlaceIndexForPositionResponse> searchPlaceIndexForPosition({
required String indexName,
required List<double> position,
String? key,
String? language,
int? maxResults,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (key != null) 'key': [key],
};
final $payload = <String, dynamic>{
'Position': position,
if (language != null) 'Language': language,
if (maxResults != null) 'MaxResults': maxResults,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/places/v0/indexes/${Uri.encodeComponent(indexName)}/search/position',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return SearchPlaceIndexForPositionResponse.fromJson(response);
}