searchPlaceIndexForSuggestions method
Optional parameters let you narrow your search results by bounding box or country, or bias your search toward a specific position on the globe.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexName :
The name of the place index resource you want to use for the search.
Parameter text :
The free-form partial text to use to generate place suggestions. For
example, eiffel tow.
Parameter biasPosition :
An optional parameter that indicates a preference for place suggestions
that are closer to a specified position.
If provided, this parameter must contain a pair of numbers. The first number represents the X coordinate, or longitude; the second number represents the Y coordinate, or latitude.
For example, [-123.1174, 49.2847] represents the position
with longitude -123.1174 and latitude 49.2847.
Parameter filterBBox :
An optional parameter that limits the search results by returning only
suggestions within a specified bounding box.
If provided, this parameter must contain a total of four consecutive numbers in two pairs. The first pair of numbers represents the X and Y coordinates (longitude and latitude, respectively) of the southwest corner of the bounding box; the second pair of numbers represents the X and Y coordinates (longitude and latitude, respectively) of the northeast corner of the bounding box.
For example, [-12.7935, -37.4835, -12.0684, -36.9542]
represents a bounding box where the southwest corner has longitude
-12.7935 and latitude -37.4835, and the
northeast corner has longitude -12.0684 and latitude
-36.9542.
Parameter filterCategories :
A list of one or more Amazon Location categories to filter the returned
places. If you include more than one category, the results will include
results that match any of the categories listed.
For more information about using categories, including a list of Amazon Location categories, see Categories and filtering, in the Amazon Location Service developer guide.
Parameter filterCountries :
An optional parameter that limits the search results by returning only
suggestions within the provided list of countries.
-
Use the ISO
3166 3-digit country code. For example, Australia uses three
upper-case characters:
AUS.
Parameter key :
The optional API
key to authorize the request.
Parameter language :
The preferred language used to return results. The value must be a valid
BCP 47 language tag, for
example, en for English.
This setting affects the languages used in the results. If no language is specified, or not supported for a particular result, the partner automatically chooses a language for the result.
For an example, we'll use the Greek language. You search for Athens,
Gr to get suggestions with the language parameter set
to en. The results found will most likely be returned as
Athens, Greece.
If you set the language parameter to el, for
Greek, then the result found will more likely be returned as Αθήνα,
Ελλάδα.
If the data provider does not have a value for Greek, the result will be in a language that the provider does support.
Parameter maxResults :
An optional parameter. The maximum number of results returned per request.
The default: 5
Implementation
Future<SearchPlaceIndexForSuggestionsResponse>
searchPlaceIndexForSuggestions({
required String indexName,
required String text,
List<double>? biasPosition,
List<double>? filterBBox,
List<String>? filterCategories,
List<String>? filterCountries,
String? key,
String? language,
int? maxResults,
}) async {
final $query = <String, List<String>>{
if (key != null) 'key': [key],
};
final $payload = <String, dynamic>{
'Text': text,
if (biasPosition != null) 'BiasPosition': biasPosition,
if (filterBBox != null) 'FilterBBox': filterBBox,
if (filterCategories != null) 'FilterCategories': filterCategories,
if (filterCountries != null) 'FilterCountries': filterCountries,
if (language != null) 'Language': language,
if (maxResults != null) 'MaxResults': maxResults,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/places/v0/indexes/${Uri.encodeComponent(indexName)}/search/suggestions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return SearchPlaceIndexForSuggestionsResponse.fromJson(response);
}