tagResource method
Assigns one or more tags (key-value pairs) to the specified Amazon Location Service resource.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values.
You can use the TagResource operation with an Amazon Location
Service resource that already has tags. If you specify a new tag key for
the resource, this tag is appended to the tags already associated with the
resource. If you specify a tag key that's already associated with the
resource, the new tag value that you specify replaces the previous value
for that tag.
You can associate up to 50 tags with a resource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource whose tags you want to
update.
-
Format example:
arn:aws:geo:region:account-id:resourcetype/ExampleResource
Parameter tags :
Applies one or more tags to specific resource. A tag is a key-value pair
that helps you manage, identify, search, and filter your resources.
Format: "key" : "value"
Restrictions:
- Maximum 50 tags per resource.
- Each tag key must be unique and must have exactly one associated value.
- Maximum key length: 128 Unicode characters in UTF-8.
- Maximum value length: 256 Unicode characters in UTF-8.
- Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @
- Cannot use "aws:" as a prefix for a key.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}