M2 class
Amazon Web Services Mainframe Modernization provides tools and resources to help you plan and implement migration and modernization from mainframes to Amazon Web Services managed runtime environments. It provides tools for analyzing existing mainframe applications, developing or updating mainframe applications using COBOL or PL/I, and implementing an automated pipeline for continuous integration and continuous delivery (CI/CD) of the applications.
Constructors
- M2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelBatchJobExecution(
{required String applicationId, required String executionId, String? authSecretsManagerArn}) → Future< void> - Cancels the running of a specific batch job execution.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createApplication(
{required Definition definition, required EngineType engineType, required String name, String? clientToken, String? description, String? kmsKeyId, String? roleArn, Map< String, String> ? tags}) → Future<CreateApplicationResponse> - Creates a new application with given parameters. Requires an existing runtime environment and application definition file.
-
createDataSetExportTask(
{required String applicationId, required DataSetExportConfig exportConfig, String? clientToken, String? kmsKeyId}) → Future< CreateDataSetExportTaskResponse> - Starts a data set export task for a specific application.
-
createDataSetImportTask(
{required String applicationId, required DataSetImportConfig importConfig, String? clientToken}) → Future< CreateDataSetImportTaskResponse> - Starts a data set import task for a specific application.
-
createDeployment(
{required String applicationId, required int applicationVersion, required String environmentId, String? clientToken}) → Future< CreateDeploymentResponse> - Creates and starts a deployment to deploy an application into a runtime environment.
-
createEnvironment(
{required EngineType engineType, required String instanceType, required String name, String? clientToken, String? description, String? engineVersion, HighAvailabilityConfig? highAvailabilityConfig, String? kmsKeyId, NetworkType? networkType, String? preferredMaintenanceWindow, bool? publiclyAccessible, List< String> ? securityGroupIds, List<StorageConfiguration> ? storageConfigurations, List<String> ? subnetIds, Map<String, String> ? tags}) → Future<CreateEnvironmentResponse> - Creates a runtime environment for a given runtime engine.
-
deleteApplication(
{required String applicationId}) → Future< void> - Deletes a specific application. You cannot delete a running application.
-
deleteApplicationFromEnvironment(
{required String applicationId, required String environmentId}) → Future< void> - Deletes a specific application from the specific runtime environment where it was previously deployed. You cannot delete a runtime environment using DeleteEnvironment if any application has ever been deployed to it. This API removes the association of the application with the runtime environment so you can delete the environment smoothly.
-
deleteEnvironment(
{required String environmentId}) → Future< void> - Deletes a specific runtime environment. The environment cannot contain deployed applications. If it does, you must delete those applications before you delete the environment.
-
getApplication(
{required String applicationId}) → Future< GetApplicationResponse> - Describes the details of a specific application.
-
getApplicationVersion(
{required String applicationId, required int applicationVersion}) → Future< GetApplicationVersionResponse> - Returns details about a specific version of a specific application.
-
getBatchJobExecution(
{required String applicationId, required String executionId}) → Future< GetBatchJobExecutionResponse> - Gets the details of a specific batch job execution for a specific application.
-
getDataSetDetails(
{required String applicationId, required String dataSetName}) → Future< GetDataSetDetailsResponse> - Gets the details of a specific data set.
-
getDataSetExportTask(
{required String applicationId, required String taskId}) → Future< GetDataSetExportTaskResponse> - Gets the status of a data set import task initiated with the CreateDataSetExportTask operation.
-
getDataSetImportTask(
{required String applicationId, required String taskId}) → Future< GetDataSetImportTaskResponse> - Gets the status of a data set import task initiated with the CreateDataSetImportTask operation.
-
getDeployment(
{required String applicationId, required String deploymentId}) → Future< GetDeploymentResponse> - Gets details of a specific deployment with a given deployment identifier.
-
getEnvironment(
{required String environmentId}) → Future< GetEnvironmentResponse> - Describes a specific runtime environment.
-
getSignedBluinsightsUrl(
) → Future< GetSignedBluinsightsUrlResponse> - Gets a single sign-on URL that can be used to connect to AWS Blu Insights.
-
listApplications(
{String? environmentId, int? maxResults, List< String> ? names, String? nextToken}) → Future<ListApplicationsResponse> - Lists the applications associated with a specific Amazon Web Services account. You can provide the unique identifier of a specific runtime environment in a query parameter to see all applications associated with that environment.
-
listApplicationVersions(
{required String applicationId, int? maxResults, String? nextToken}) → Future< ListApplicationVersionsResponse> - Returns a list of the application versions for a specific application.
-
listBatchJobDefinitions(
{required String applicationId, int? maxResults, String? nextToken, String? prefix}) → Future< ListBatchJobDefinitionsResponse> - Lists all the available batch job definitions based on the batch job resources uploaded during the application creation. You can use the batch job definitions in the list to start a batch job.
-
listBatchJobExecutions(
{required String applicationId, List< String> ? executionIds, String? jobName, int? maxResults, String? nextToken, DateTime? startedAfter, DateTime? startedBefore, BatchJobExecutionStatus? status}) → Future<ListBatchJobExecutionsResponse> - Lists historical, current, and scheduled batch job executions for a specific application.
-
listBatchJobRestartPoints(
{required String applicationId, required String executionId, String? authSecretsManagerArn}) → Future< ListBatchJobRestartPointsResponse> - Lists all the job steps for a JCL file to restart a batch job. This is only applicable for Micro Focus engine with versions 8.0.6 and above.
-
listDataSetExportHistory(
{required String applicationId, int? maxResults, String? nextToken}) → Future< ListDataSetExportHistoryResponse> - Lists the data set exports for the specified application.
-
listDataSetImportHistory(
{required String applicationId, int? maxResults, String? nextToken}) → Future< ListDataSetImportHistoryResponse> - Lists the data set imports for the specified application.
-
listDataSets(
{required String applicationId, int? maxResults, String? nameFilter, String? nextToken, String? prefix}) → Future< ListDataSetsResponse> - Lists the data sets imported for a specific application. In Amazon Web Services Mainframe Modernization, data sets are associated with applications deployed on runtime environments. This is known as importing data sets. Currently, Amazon Web Services Mainframe Modernization can import data sets into catalogs using CreateDataSetImportTask.
-
listDeployments(
{required String applicationId, int? maxResults, String? nextToken}) → Future< ListDeploymentsResponse> - Returns a list of all deployments of a specific application. A deployment is a combination of a specific application and a specific version of that application. Each deployment is mapped to a particular application version.
-
listEngineVersions(
{EngineType? engineType, int? maxResults, String? nextToken}) → Future< ListEngineVersionsResponse> - Lists the available engine versions.
-
listEnvironments(
{EngineType? engineType, int? maxResults, List< String> ? names, String? nextToken}) → Future<ListEnvironmentsResponse> - Lists the runtime environments.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for the specified resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startApplication(
{required String applicationId}) → Future< void> - Starts an application that is currently stopped.
-
startBatchJob(
{required String applicationId, required BatchJobIdentifier batchJobIdentifier, String? authSecretsManagerArn, Map< String, String> ? jobParams}) → Future<StartBatchJobResponse> - Starts a batch job and returns the unique identifier of this execution of the batch job. The associated application must be running in order to start the batch job.
-
stopApplication(
{required String applicationId, bool? forceStop}) → Future< void> - Stops a running application.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds one or more tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from the specified resource.
-
updateApplication(
{required String applicationId, required int currentApplicationVersion, Definition? definition, String? description}) → Future< UpdateApplicationResponse> - Updates an application and creates a new version.
-
updateEnvironment(
{required String environmentId, bool? applyDuringMaintenanceWindow, int? desiredCapacity, String? engineVersion, bool? forceUpdate, String? instanceType, String? preferredMaintenanceWindow}) → Future< UpdateEnvironmentResponse> - Updates the configuration details for a specific runtime environment.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited