cancelBatchJobExecution method
Cancels the running of a specific batch job execution.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the application.
Parameter executionId :
The unique identifier of the batch job execution.
Parameter authSecretsManagerArn :
The Amazon Web Services Secrets Manager containing user's credentials for
authentication and authorization for Cancel Batch Job Execution operation.
Implementation
Future<void> cancelBatchJobExecution({
required String applicationId,
required String executionId,
String? authSecretsManagerArn,
}) async {
final $payload = <String, dynamic>{
if (authSecretsManagerArn != null)
'authSecretsManagerArn': authSecretsManagerArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/batch-job-executions/${Uri.encodeComponent(executionId)}/cancel',
exceptionFnMap: _exceptionFns,
);
}