deleteEnvironment method

Future<void> deleteEnvironment({
  1. required String environmentId,
})

Deletes a specific runtime environment. The environment cannot contain deployed applications. If it does, you must delete those applications before you delete the environment.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : The unique identifier of the runtime environment you want to delete.

Implementation

Future<void> deleteEnvironment({
  required String environmentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/environments/${Uri.encodeComponent(environmentId)}',
    exceptionFnMap: _exceptionFns,
  );
}