listApplicationVersions method
Returns a list of the application versions for a specific application.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the application.
Parameter maxResults :
The maximum number of application versions to return.
Parameter nextToken :
A pagination token returned from a previous call to this operation. This
specifies the next item to return. To return to the beginning of the list,
exclude this parameter.
Implementation
Future<ListApplicationVersionsResponse> listApplicationVersions({
required String applicationId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/versions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListApplicationVersionsResponse.fromJson(response);
}