listApplications method

Future<ListApplicationsResponse> listApplications({
  1. String? environmentId,
  2. int? maxResults,
  3. List<String>? names,
  4. String? nextToken,
})

Lists the applications associated with a specific Amazon Web Services account. You can provide the unique identifier of a specific runtime environment in a query parameter to see all applications associated with that environment.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentId : The unique identifier of the runtime environment where the applications are deployed.

Parameter maxResults : The maximum number of applications to return.

Parameter names : The names of the applications.

Parameter nextToken : A pagination token to control the number of applications displayed in the list.

Implementation

Future<ListApplicationsResponse> listApplications({
  String? environmentId,
  int? maxResults,
  List<String>? names,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    2000,
  );
  final $query = <String, List<String>>{
    if (environmentId != null) 'environmentId': [environmentId],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (names != null) 'names': names,
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListApplicationsResponse.fromJson(response);
}