listBatchJobRestartPoints method
Lists all the job steps for a JCL file to restart a batch job. This is only applicable for Micro Focus engine with versions 8.0.6 and above.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the application.
Parameter executionId :
The unique identifier of the batch job execution.
Parameter authSecretsManagerArn :
The Amazon Web Services Secrets Manager containing user's credentials for
authentication and authorization for List Batch Job Restart Points
operation.
Implementation
Future<ListBatchJobRestartPointsResponse> listBatchJobRestartPoints({
required String applicationId,
required String executionId,
String? authSecretsManagerArn,
}) async {
final $query = <String, List<String>>{
if (authSecretsManagerArn != null)
'authSecretsManagerArn': [authSecretsManagerArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/batch-job-executions/${Uri.encodeComponent(executionId)}/steps',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListBatchJobRestartPointsResponse.fromJson(response);
}