listDataSets method
Lists the data sets imported for a specific application. In Amazon Web Services Mainframe Modernization, data sets are associated with applications deployed on runtime environments. This is known as importing data sets. Currently, Amazon Web Services Mainframe Modernization can import data sets into catalogs using CreateDataSetImportTask.
May throw AccessDeniedException.
May throw ConflictException.
May throw ExecutionTimeoutException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the application for which you want to list the
associated data sets.
Parameter maxResults :
The maximum number of objects to return.
Parameter nameFilter :
Filter dataset name matching the specified pattern. Can use * and % as
wild cards.
Parameter nextToken :
A pagination token returned from a previous call to this operation. This
specifies the next item to return. To return to the beginning of the list,
exclude this parameter.
Parameter prefix :
The prefix of the data set name, which you can use to filter the list of
data sets.
Implementation
Future<ListDataSetsResponse> listDataSets({
required String applicationId,
int? maxResults,
String? nameFilter,
String? nextToken,
String? prefix,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nameFilter != null) 'nameFilter': [nameFilter],
if (nextToken != null) 'nextToken': [nextToken],
if (prefix != null) 'prefix': [prefix],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/datasets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataSetsResponse.fromJson(response);
}