stopApplication method

Future<void> stopApplication({
  1. required String applicationId,
  2. bool? forceStop,
})

Stops a running application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The unique identifier of the application you want to stop.

Parameter forceStop : Stopping an application process can take a long time. Setting this parameter to true lets you force stop the application so you don't need to wait until the process finishes to apply another action on the application. The default value is false.

Implementation

Future<void> stopApplication({
  required String applicationId,
  bool? forceStop,
}) async {
  final $payload = <String, dynamic>{
    if (forceStop != null) 'forceStop': forceStop,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/applications/${Uri.encodeComponent(applicationId)}/stop',
    exceptionFnMap: _exceptionFns,
  );
}