updateEnvironment method
Updates the configuration details for a specific runtime environment.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter environmentId :
The unique identifier of the runtime environment that you want to update.
Parameter applyDuringMaintenanceWindow :
Indicates whether to update the runtime environment during the maintenance
window. The default is false. Currently, Amazon Web Services Mainframe
Modernization accepts the engineVersion parameter only if
applyDuringMaintenanceWindow is true. If any parameter other
than engineVersion is provided in
UpdateEnvironmentRequest, it will fail if
applyDuringMaintenanceWindow is set to true.
Parameter desiredCapacity :
The desired capacity for the runtime environment to update. The minimum
possible value is 0 and the maximum is 100.
Parameter engineVersion :
The version of the runtime engine for the runtime environment.
Parameter forceUpdate :
Forces the updates on the environment. This option is needed if the
applications in the environment are not stopped or if there are ongoing
application-related activities in the environment.
If you use this option, be aware that it could lead to data corruption in the applications, and that you might need to perform repair and recovery procedures for the applications.
This option is not needed if the attribute being updated is
preferredMaintenanceWindow.
Parameter instanceType :
The instance type for the runtime environment to update.
Parameter preferredMaintenanceWindow :
Configures the maintenance window that you want for the runtime
environment. The maintenance window must have the format
ddd:hh24:mi-ddd:hh24:mi and must be less than 24 hours. The
following two examples are valid maintenance windows:
sun:23:45-mon:00:15 or sat:01:00-sat:03:00.
If you do not provide a value, a random system-generated value will be assigned.
Implementation
Future<UpdateEnvironmentResponse> updateEnvironment({
required String environmentId,
bool? applyDuringMaintenanceWindow,
int? desiredCapacity,
String? engineVersion,
bool? forceUpdate,
String? instanceType,
String? preferredMaintenanceWindow,
}) async {
final $payload = <String, dynamic>{
if (applyDuringMaintenanceWindow != null)
'applyDuringMaintenanceWindow': applyDuringMaintenanceWindow,
if (desiredCapacity != null) 'desiredCapacity': desiredCapacity,
if (engineVersion != null) 'engineVersion': engineVersion,
if (forceUpdate != null) 'forceUpdate': forceUpdate,
if (instanceType != null) 'instanceType': instanceType,
if (preferredMaintenanceWindow != null)
'preferredMaintenanceWindow': preferredMaintenanceWindow,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/environments/${Uri.encodeComponent(environmentId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateEnvironmentResponse.fromJson(response);
}