Macie2 class

Amazon Macie

Constructors

Macie2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation({required String invitationId, String? administratorAccountId, String? masterAccount}) Future<void>
Accepts an Amazon Macie membership invitation that was received from a specific account.
batchGetCustomDataIdentifiers({List<String>? ids}) Future<BatchGetCustomDataIdentifiersResponse>
Retrieves information about one or more custom data identifiers.
batchUpdateAutomatedDiscoveryAccounts({List<AutomatedDiscoveryAccountUpdate>? accounts}) Future<BatchUpdateAutomatedDiscoveryAccountsResponse>
Changes the status of automated sensitive data discovery for one or more accounts.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAllowList({required AllowListCriteria criteria, required String name, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateAllowListResponse>
Creates and defines the settings for an allow list.
createClassificationJob({required JobType jobType, required String name, required S3JobDefinition s3JobDefinition, List<String>? allowListIds, String? clientToken, List<String>? customDataIdentifierIds, String? description, bool? initialRun, List<String>? managedDataIdentifierIds, ManagedDataIdentifierSelector? managedDataIdentifierSelector, int? samplingPercentage, JobScheduleFrequency? scheduleFrequency, Map<String, String>? tags}) Future<CreateClassificationJobResponse>
Creates and defines the settings for a classification job.
createCustomDataIdentifier({required String name, required String regex, String? clientToken, String? description, List<String>? ignoreWords, List<String>? keywords, int? maximumMatchDistance, List<SeverityLevel>? severityLevels, Map<String, String>? tags}) Future<CreateCustomDataIdentifierResponse>
Creates and defines the criteria and other settings for a custom data identifier.
createFindingsFilter({required FindingsFilterAction action, required FindingCriteria findingCriteria, required String name, String? clientToken, String? description, int? position, Map<String, String>? tags}) Future<CreateFindingsFilterResponse>
Creates and defines the criteria and other settings for a findings filter.
createInvitations({required List<String> accountIds, bool? disableEmailNotification, String? message}) Future<CreateInvitationsResponse>
Sends an Amazon Macie membership invitation to one or more accounts.
createMember({required AccountDetail account, Map<String, String>? tags}) Future<CreateMemberResponse>
Associates an account with an Amazon Macie administrator account.
createSampleFindings({List<FindingType>? findingTypes}) Future<void>
Creates sample findings.
declineInvitations({required List<String> accountIds}) Future<DeclineInvitationsResponse>
Declines Amazon Macie membership invitations that were received from specific accounts.
deleteAllowList({required String id, String? ignoreJobChecks}) Future<void>
Deletes an allow list.
deleteCustomDataIdentifier({required String id}) Future<void>
Soft deletes a custom data identifier.
deleteFindingsFilter({required String id}) Future<void>
Deletes a findings filter.
deleteInvitations({required List<String> accountIds}) Future<DeleteInvitationsResponse>
Deletes Amazon Macie membership invitations that were received from specific accounts.
deleteMember({required String id}) Future<void>
Deletes the association between an Amazon Macie administrator account and an account.
describeBuckets({Map<String, BucketCriteriaAdditionalProperties>? criteria, int? maxResults, String? nextToken, BucketSortCriteria? sortCriteria}) Future<DescribeBucketsResponse>
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
describeClassificationJob({required String jobId}) Future<DescribeClassificationJobResponse>
Retrieves the status and settings for a classification job.
describeOrganizationConfiguration() Future<DescribeOrganizationConfigurationResponse>
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
disableMacie() Future<void>
Disables Amazon Macie and deletes all settings and resources for a Macie account.
disableOrganizationAdminAccount({required String adminAccountId}) Future<void>
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
disassociateFromAdministratorAccount() Future<void>
Disassociates a member account from its Amazon Macie administrator account.
disassociateFromMasterAccount() Future<void>
(Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the DisassociateFromAdministratorAccount operation.
disassociateMember({required String id}) Future<void>
Disassociates an Amazon Macie administrator account from a member account.
enableMacie({String? clientToken, FindingPublishingFrequency? findingPublishingFrequency, MacieStatus? status}) Future<void>
Enables Amazon Macie and specifies the configuration settings for a Macie account.
enableOrganizationAdminAccount({required String adminAccountId, String? clientToken}) Future<void>
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
getAdministratorAccount() Future<GetAdministratorAccountResponse>
Retrieves information about the Amazon Macie administrator account for an account.
getAllowList({required String id}) Future<GetAllowListResponse>
Retrieves the settings and status of an allow list.
getAutomatedDiscoveryConfiguration() Future<GetAutomatedDiscoveryConfigurationResponse>
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
getBucketStatistics({String? accountId}) Future<GetBucketStatisticsResponse>
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
getClassificationExportConfiguration() Future<GetClassificationExportConfigurationResponse>
Retrieves the configuration settings for storing data classification results.
getClassificationScope({required String id}) Future<GetClassificationScopeResponse>
Retrieves the classification scope settings for an account.
getCustomDataIdentifier({required String id}) Future<GetCustomDataIdentifierResponse>
Retrieves the criteria and other settings for a custom data identifier.
getFindings({required List<String> findingIds, SortCriteria? sortCriteria}) Future<GetFindingsResponse>
Retrieves the details of one or more findings.
getFindingsFilter({required String id}) Future<GetFindingsFilterResponse>
Retrieves the criteria and other settings for a findings filter.
getFindingsPublicationConfiguration() Future<GetFindingsPublicationConfigurationResponse>
Retrieves the configuration settings for publishing findings to Security Hub.
getFindingStatistics({required GroupBy groupBy, FindingCriteria? findingCriteria, int? size, FindingStatisticsSortCriteria? sortCriteria}) Future<GetFindingStatisticsResponse>
Retrieves (queries) aggregated statistical data about findings.
getInvitationsCount() Future<GetInvitationsCountResponse>
Retrieves the count of Amazon Macie membership invitations that were received by an account.
getMacieSession() Future<GetMacieSessionResponse>
Retrieves the status and configuration settings for an Amazon Macie account.
getMasterAccount() Future<GetMasterAccountResponse>
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account. This operation has been replaced by the GetAdministratorAccount operation.
getMember({required String id}) Future<GetMemberResponse>
Retrieves information about an account that's associated with an Amazon Macie administrator account.
getResourceProfile({required String resourceArn}) Future<GetResourceProfileResponse>
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
getRevealConfiguration() Future<GetRevealConfigurationResponse>
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
getSensitiveDataOccurrences({required String findingId}) Future<GetSensitiveDataOccurrencesResponse>
Retrieves occurrences of sensitive data reported by a finding.
getSensitiveDataOccurrencesAvailability({required String findingId}) Future<GetSensitiveDataOccurrencesAvailabilityResponse>
Checks whether occurrences of sensitive data can be retrieved for a finding.
getSensitivityInspectionTemplate({required String id}) Future<GetSensitivityInspectionTemplateResponse>
Retrieves the settings for the sensitivity inspection template for an account.
getUsageStatistics({List<UsageStatisticsFilter>? filterBy, int? maxResults, String? nextToken, UsageStatisticsSortBy? sortBy, TimeRange? timeRange}) Future<GetUsageStatisticsResponse>
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
getUsageTotals({String? timeRange}) Future<GetUsageTotalsResponse>
Retrieves (queries) aggregated usage data for an account.
listAllowLists({int? maxResults, String? nextToken}) Future<ListAllowListsResponse>
Retrieves a subset of information about all the allow lists for an account.
listAutomatedDiscoveryAccounts({List<String>? accountIds, int? maxResults, String? nextToken}) Future<ListAutomatedDiscoveryAccountsResponse>
Retrieves the status of automated sensitive data discovery for one or more accounts.
listClassificationJobs({ListJobsFilterCriteria? filterCriteria, int? maxResults, String? nextToken, ListJobsSortCriteria? sortCriteria}) Future<ListClassificationJobsResponse>
Retrieves a subset of information about one or more classification jobs.
listClassificationScopes({String? name, String? nextToken}) Future<ListClassificationScopesResponse>
Retrieves a subset of information about the classification scope for an account.
listCustomDataIdentifiers({int? maxResults, String? nextToken}) Future<ListCustomDataIdentifiersResponse>
Retrieves a subset of information about the custom data identifiers for an account.
listFindings({FindingCriteria? findingCriteria, int? maxResults, String? nextToken, SortCriteria? sortCriteria}) Future<ListFindingsResponse>
Retrieves a subset of information about one or more findings.
listFindingsFilters({int? maxResults, String? nextToken}) Future<ListFindingsFiltersResponse>
Retrieves a subset of information about all the findings filters for an account.
listInvitations({int? maxResults, String? nextToken}) Future<ListInvitationsResponse>
Retrieves information about Amazon Macie membership invitations that were received by an account.
listManagedDataIdentifiers({String? nextToken}) Future<ListManagedDataIdentifiersResponse>
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
listMembers({int? maxResults, String? nextToken, String? onlyAssociated}) Future<ListMembersResponse>
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
listOrganizationAdminAccounts({int? maxResults, String? nextToken}) Future<ListOrganizationAdminAccountsResponse>
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
listResourceProfileArtifacts({required String resourceArn, String? nextToken}) Future<ListResourceProfileArtifactsResponse>
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
listResourceProfileDetections({required String resourceArn, int? maxResults, String? nextToken}) Future<ListResourceProfileDetectionsResponse>
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
listSensitivityInspectionTemplates({int? maxResults, String? nextToken}) Future<ListSensitivityInspectionTemplatesResponse>
Retrieves a subset of information about the sensitivity inspection template for an account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putClassificationExportConfiguration({required ClassificationExportConfiguration configuration}) Future<PutClassificationExportConfigurationResponse>
Adds or updates the configuration settings for storing data classification results.
putFindingsPublicationConfiguration({String? clientToken, SecurityHubConfiguration? securityHubConfiguration}) Future<void>
Updates the configuration settings for publishing findings to Security Hub.
searchResources({SearchResourcesBucketCriteria? bucketCriteria, int? maxResults, String? nextToken, SearchResourcesSortCriteria? sortCriteria}) Future<SearchResourcesResponse>
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
testCustomDataIdentifier({required String regex, required String sampleText, List<String>? ignoreWords, List<String>? keywords, int? maximumMatchDistance}) Future<TestCustomDataIdentifierResponse>
Tests criteria for a custom data identifier.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags (keys and values) from an Amazon Macie resource.
updateAllowList({required AllowListCriteria criteria, required String id, required String name, String? description}) Future<UpdateAllowListResponse>
Updates the settings for an allow list.
updateAutomatedDiscoveryConfiguration({required AutomatedDiscoveryStatus status, AutoEnableMode? autoEnableOrganizationMembers}) Future<void>
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
updateClassificationJob({required String jobId, required JobStatus jobStatus}) Future<void>
Changes the status of a classification job.
updateClassificationScope({required String id, S3ClassificationScopeUpdate? s3}) Future<void>
Updates the classification scope settings for an account.
updateFindingsFilter({required String id, FindingsFilterAction? action, String? clientToken, String? description, FindingCriteria? findingCriteria, String? name, int? position}) Future<UpdateFindingsFilterResponse>
Updates the criteria and other settings for a findings filter.
updateMacieSession({FindingPublishingFrequency? findingPublishingFrequency, MacieStatus? status}) Future<void>
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
updateMemberSession({required String id, required MacieStatus status}) Future<void>
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
updateOrganizationConfiguration({required bool autoEnable}) Future<void>
Updates the Amazon Macie configuration settings for an organization in Organizations.
updateResourceProfile({required String resourceArn, int? sensitivityScoreOverride}) Future<void>
Updates the sensitivity score for an S3 bucket.
updateResourceProfileDetections({required String resourceArn, List<SuppressDataIdentifier>? suppressDataIdentifiers}) Future<void>
Updates the sensitivity scoring settings for an S3 bucket.
updateRevealConfiguration({required RevealConfiguration configuration, UpdateRetrievalConfiguration? retrievalConfiguration}) Future<UpdateRevealConfigurationResponse>
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
updateSensitivityInspectionTemplate({required String id, String? description, SensitivityInspectionTemplateExcludes? excludes, SensitivityInspectionTemplateIncludes? includes}) Future<void>
Updates the settings for the sensitivity inspection template for an account.

Operators

operator ==(Object other) bool
The equality operator.
inherited