acceptInvitation method

Future<void> acceptInvitation({
  1. required String invitationId,
  2. String? administratorAccountId,
  3. String? masterAccount,
})

Accepts an Amazon Macie membership invitation that was received from a specific account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter invitationId : The unique identifier for the invitation to accept.

Parameter administratorAccountId : The Amazon Web Services account ID for the account that sent the invitation.

Parameter masterAccount : (Deprecated) The Amazon Web Services account ID for the account that sent the invitation. This property has been replaced by the administratorAccountId property and is retained only for backward compatibility.

Implementation

Future<void> acceptInvitation({
  required String invitationId,
  String? administratorAccountId,
  String? masterAccount,
}) async {
  final $payload = <String, dynamic>{
    'invitationId': invitationId,
    if (administratorAccountId != null)
      'administratorAccountId': administratorAccountId,
    if (masterAccount != null) 'masterAccount': masterAccount,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/invitations/accept',
    exceptionFnMap: _exceptionFns,
  );
}