batchGetCustomDataIdentifiers method

Future<BatchGetCustomDataIdentifiersResponse> batchGetCustomDataIdentifiers({
  1. List<String>? ids,
})

Retrieves information about one or more custom data identifiers.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter ids : An array of custom data identifier IDs, one for each custom data identifier to retrieve information about.

Implementation

Future<BatchGetCustomDataIdentifiersResponse> batchGetCustomDataIdentifiers({
  List<String>? ids,
}) async {
  final $payload = <String, dynamic>{
    if (ids != null) 'ids': ids,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/custom-data-identifiers/get',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetCustomDataIdentifiersResponse.fromJson(response);
}