batchUpdateAutomatedDiscoveryAccounts method

Future<BatchUpdateAutomatedDiscoveryAccountsResponse> batchUpdateAutomatedDiscoveryAccounts({
  1. List<AutomatedDiscoveryAccountUpdate>? accounts,
})

Changes the status of automated sensitive data discovery for one or more accounts.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter accounts : An array of objects, one for each account to change the status of automated sensitive data discovery for. Each object specifies the Amazon Web Services account ID for an account and a new status for that account.

Implementation

Future<BatchUpdateAutomatedDiscoveryAccountsResponse>
    batchUpdateAutomatedDiscoveryAccounts({
  List<AutomatedDiscoveryAccountUpdate>? accounts,
}) async {
  final $payload = <String, dynamic>{
    if (accounts != null) 'accounts': accounts,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/automated-discovery/accounts',
    exceptionFnMap: _exceptionFns,
  );
  return BatchUpdateAutomatedDiscoveryAccountsResponse.fromJson(response);
}