createMember method
Associates an account with an Amazon Macie administrator account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter account :
The details of the account to associate with the administrator account.
Parameter tags :
A map of key-value pairs that specifies the tags to associate with the
account in Amazon Macie.
An account can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.
Implementation
Future<CreateMemberResponse> createMember({
required AccountDetail account,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'account': account,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/members',
exceptionFnMap: _exceptionFns,
);
return CreateMemberResponse.fromJson(response);
}