deleteMember method

Future<void> deleteMember({
  1. required String id,
})

Deletes the association between an Amazon Macie administrator account and an account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The unique identifier for the Amazon Macie resource that the request applies to.

Implementation

Future<void> deleteMember({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/members/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}