describeBuckets method

Future<DescribeBucketsResponse> describeBuckets({
  1. Map<String, BucketCriteriaAdditionalProperties>? criteria,
  2. int? maxResults,
  3. String? nextToken,
  4. BucketSortCriteria? sortCriteria,
})

Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter criteria : The criteria to use to filter the query results.

Parameter maxResults : The maximum number of items to include in each page of the response. The default value is 50.

Parameter nextToken : The nextToken string that specifies which page of results to return in a paginated response.

Parameter sortCriteria : The criteria to use to sort the query results.

Implementation

Future<DescribeBucketsResponse> describeBuckets({
  Map<String, BucketCriteriaAdditionalProperties>? criteria,
  int? maxResults,
  String? nextToken,
  BucketSortCriteria? sortCriteria,
}) async {
  final $payload = <String, dynamic>{
    if (criteria != null) 'criteria': criteria,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (sortCriteria != null) 'sortCriteria': sortCriteria,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/datasources/s3',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeBucketsResponse.fromJson(response);
}