enableMacie method

Future<void> enableMacie({
  1. String? clientToken,
  2. FindingPublishingFrequency? findingPublishingFrequency,
  3. MacieStatus? status,
})

Enables Amazon Macie and specifies the configuration settings for a Macie account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter clientToken : A unique, case-sensitive token that you provide to ensure the idempotency of the request.

Parameter findingPublishingFrequency : Specifies how often to publish updates to policy findings for the account. This includes publishing updates to Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events).

Parameter status : Specifies the new status for the account. To enable Amazon Macie and start all Macie activities for the account, set this value to ENABLED.

Implementation

Future<void> enableMacie({
  String? clientToken,
  FindingPublishingFrequency? findingPublishingFrequency,
  MacieStatus? status,
}) async {
  final $payload = <String, dynamic>{
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (findingPublishingFrequency != null)
      'findingPublishingFrequency': findingPublishingFrequency.value,
    if (status != null) 'status': status.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/macie',
    exceptionFnMap: _exceptionFns,
  );
}