getAutomatedDiscoveryConfiguration method

Future<GetAutomatedDiscoveryConfigurationResponse> getAutomatedDiscoveryConfiguration()

Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<GetAutomatedDiscoveryConfigurationResponse>
    getAutomatedDiscoveryConfiguration() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/automated-discovery/configuration',
    exceptionFnMap: _exceptionFns,
  );
  return GetAutomatedDiscoveryConfigurationResponse.fromJson(response);
}