getCustomDataIdentifier method

Future<GetCustomDataIdentifierResponse> getCustomDataIdentifier({
  1. required String id,
})

Retrieves the criteria and other settings for a custom data identifier.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The unique identifier for the Amazon Macie resource that the request applies to.

Implementation

Future<GetCustomDataIdentifierResponse> getCustomDataIdentifier({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/custom-data-identifiers/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetCustomDataIdentifierResponse.fromJson(response);
}