getFindingsFilter method

Future<GetFindingsFilterResponse> getFindingsFilter({
  1. required String id,
})

Retrieves the criteria and other settings for a findings filter.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The unique identifier for the Amazon Macie resource that the request applies to.

Implementation

Future<GetFindingsFilterResponse> getFindingsFilter({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/findingsfilters/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetFindingsFilterResponse.fromJson(response);
}