listCustomDataIdentifiers method

Future<ListCustomDataIdentifiersResponse> listCustomDataIdentifiers({
  1. int? maxResults,
  2. String? nextToken,
})

Retrieves a subset of information about the custom data identifiers for an account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of items to include in each page of the response.

Parameter nextToken : The nextToken string that specifies which page of results to return in a paginated response.

Implementation

Future<ListCustomDataIdentifiersResponse> listCustomDataIdentifiers({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/custom-data-identifiers/list',
    exceptionFnMap: _exceptionFns,
  );
  return ListCustomDataIdentifiersResponse.fromJson(response);
}