listSensitivityInspectionTemplates method
Retrieves a subset of information about the sensitivity inspection template for an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of items to include in each page of a paginated
response.
Parameter nextToken :
The nextToken string that specifies which page of results to return in a
paginated response.
Implementation
Future<ListSensitivityInspectionTemplatesResponse>
listSensitivityInspectionTemplates({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/templates/sensitivity-inspections',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSensitivityInspectionTemplatesResponse.fromJson(response);
}