testCustomDataIdentifier method

Future<TestCustomDataIdentifierResponse> testCustomDataIdentifier({
  1. required String regex,
  2. required String sampleText,
  3. List<String>? ignoreWords,
  4. List<String>? keywords,
  5. int? maximumMatchDistance,
})

Tests criteria for a custom data identifier.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter regex : The regular expression (regex) that defines the pattern to match. The expression can contain as many as 512 characters.

Parameter sampleText : The sample text to inspect by using the custom data identifier. The text can contain as many as 1,000 characters.

Parameter ignoreWords : An array that lists specific character sequences (ignore words) to exclude from the results. If the text matched by the regular expression contains any string in this array, Amazon Macie ignores it. The array can contain as many as 10 ignore words. Each ignore word can contain 4-90 UTF-8 characters. Ignore words are case sensitive.

Parameter keywords : An array that lists specific character sequences (keywords), one of which must precede and be within proximity (maximumMatchDistance) of the regular expression to match. The array can contain as many as 50 keywords. Each keyword can contain 3-90 UTF-8 characters. Keywords aren't case sensitive.

Parameter maximumMatchDistance : The maximum number of characters that can exist between the end of at least one complete character sequence specified by the keywords array and the end of the text that matches the regex pattern. If a complete keyword precedes all the text that matches the pattern and the keyword is within the specified distance, Amazon Macie includes the result. The distance can be 1-300 characters. The default value is 50.

Implementation

Future<TestCustomDataIdentifierResponse> testCustomDataIdentifier({
  required String regex,
  required String sampleText,
  List<String>? ignoreWords,
  List<String>? keywords,
  int? maximumMatchDistance,
}) async {
  final $payload = <String, dynamic>{
    'regex': regex,
    'sampleText': sampleText,
    if (ignoreWords != null) 'ignoreWords': ignoreWords,
    if (keywords != null) 'keywords': keywords,
    if (maximumMatchDistance != null)
      'maximumMatchDistance': maximumMatchDistance,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/custom-data-identifiers/test',
    exceptionFnMap: _exceptionFns,
  );
  return TestCustomDataIdentifierResponse.fromJson(response);
}