updateClassificationScope method

Future<void> updateClassificationScope({
  1. required String id,
  2. S3ClassificationScopeUpdate? s3,
})

Updates the classification scope settings for an account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The unique identifier for the Amazon Macie resource that the request applies to.

Parameter s3 : The S3 buckets to add or remove from the exclusion list defined by the classification scope.

Implementation

Future<void> updateClassificationScope({
  required String id,
  S3ClassificationScopeUpdate? s3,
}) async {
  final $payload = <String, dynamic>{
    if (s3 != null) 's3': s3,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/classification-scopes/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}