updateOrganizationConfiguration method

Future<void> updateOrganizationConfiguration({
  1. required bool autoEnable,
})

Updates the Amazon Macie configuration settings for an organization in Organizations.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter autoEnable : Specifies whether to enable Amazon Macie automatically for accounts that are added to the organization in Organizations.

Implementation

Future<void> updateOrganizationConfiguration({
  required bool autoEnable,
}) async {
  final $payload = <String, dynamic>{
    'autoEnable': autoEnable,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/admin/configuration',
    exceptionFnMap: _exceptionFns,
  );
}