updateRevealConfiguration method

Future<UpdateRevealConfigurationResponse> updateRevealConfiguration({
  1. required RevealConfiguration configuration,
  2. UpdateRetrievalConfiguration? retrievalConfiguration,
})

Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter configuration : The KMS key to use to encrypt the sensitive data, and the status of the configuration for the Amazon Macie account.

Parameter retrievalConfiguration : The access method and settings to use when retrieving the sensitive data.

Implementation

Future<UpdateRevealConfigurationResponse> updateRevealConfiguration({
  required RevealConfiguration configuration,
  UpdateRetrievalConfiguration? retrievalConfiguration,
}) async {
  final $payload = <String, dynamic>{
    'configuration': configuration,
    if (retrievalConfiguration != null)
      'retrievalConfiguration': retrievalConfiguration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/reveal-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRevealConfigurationResponse.fromJson(response);
}