updateSensitivityInspectionTemplate method
Updates the settings for the sensitivity inspection template for an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The unique identifier for the Amazon Macie resource that the request
applies to.
Parameter description :
A custom description of the template. The description can contain as many
as 200 characters.
Parameter excludes :
The managed data identifiers to explicitly exclude (not use) when
performing automated sensitive data discovery.
To exclude an allow list or custom data identifier that's currently included by the template, update the values for the SensitivityInspectionTemplateIncludes.allowListIds and SensitivityInspectionTemplateIncludes.customDataIdentifierIds properties, respectively.
Parameter includes :
The allow lists, custom data identifiers, and managed data identifiers to
explicitly include (use) when performing automated sensitive data
discovery.
Implementation
Future<void> updateSensitivityInspectionTemplate({
required String id,
String? description,
SensitivityInspectionTemplateExcludes? excludes,
SensitivityInspectionTemplateIncludes? includes,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (excludes != null) 'excludes': excludes,
if (includes != null) 'includes': includes,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/templates/sensitivity-inspections/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}