mail_manager library

Classes

AwsClientCredentials
AWS credentials.
MailManager
The Amazon SES Mail Manager API contains operations and data types that comprise the Mail Manager feature of Amazon Simple Email Service (SES).