MailManager class

The Amazon SES Mail Manager API contains operations and data types that comprise the Mail Manager feature of Amazon Simple Email Service (SES).

Constructors

MailManager({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAddonInstance({required String addonSubscriptionId, String? clientToken, List<Tag>? tags}) Future<CreateAddonInstanceResponse>
Creates an Add On instance for the subscription indicated in the request. The resulting Amazon Resource Name (ARN) can be used in a conditional statement for a rule set or traffic policy.
createAddonSubscription({required String addonName, String? clientToken, List<Tag>? tags}) Future<CreateAddonSubscriptionResponse>
Creates a subscription for an Add On representing the acceptance of its terms of use and additional pricing. The subscription can then be used to create an instance for use in rule sets or traffic policies.
createAddressList({required String addressListName, String? clientToken, List<Tag>? tags}) Future<CreateAddressListResponse>
Creates a new address list.
createAddressListImportJob({required String addressListId, required ImportDataFormat importDataFormat, required String name, String? clientToken}) Future<CreateAddressListImportJobResponse>
Creates an import job for an address list.
createArchive({required String archiveName, String? clientToken, String? kmsKeyArn, ArchiveRetention? retention, List<Tag>? tags}) Future<CreateArchiveResponse>
Creates a new email archive resource for storing and retaining emails.
createIngressPoint({required String ingressPointName, required String ruleSetId, required String trafficPolicyId, required IngressPointType type, String? clientToken, IngressPointConfiguration? ingressPointConfiguration, NetworkConfiguration? networkConfiguration, List<Tag>? tags, TlsPolicy? tlsPolicy}) Future<CreateIngressPointResponse>
Provision a new ingress endpoint resource.
createRelay({required RelayAuthentication authentication, required String relayName, required String serverName, required int serverPort, String? clientToken, List<Tag>? tags}) Future<CreateRelayResponse>
Creates a relay resource which can be used in rules to relay incoming emails to defined relay destinations.
createRuleSet({required String ruleSetName, required List<Rule> rules, String? clientToken, List<Tag>? tags}) Future<CreateRuleSetResponse>
Provision a new rule set.
createTrafficPolicy({required AcceptAction defaultAction, required List<PolicyStatement> policyStatements, required String trafficPolicyName, String? clientToken, int? maxMessageSizeBytes, List<Tag>? tags}) Future<CreateTrafficPolicyResponse>
Provision a new traffic policy resource.
deleteAddonInstance({required String addonInstanceId}) Future<void>
Deletes an Add On instance.
deleteAddonSubscription({required String addonSubscriptionId}) Future<void>
Deletes an Add On subscription.
deleteAddressList({required String addressListId}) Future<void>
Deletes an address list.
deleteArchive({required String archiveId}) Future<void>
Initiates deletion of an email archive. This changes the archive state to pending deletion. In this state, no new emails can be added, and existing archived emails become inaccessible (search, export, download). The archive and all of its contents will be permanently deleted 30 days after entering the pending deletion state, regardless of the configured retention period.
deleteIngressPoint({required String ingressPointId}) Future<void>
Delete an ingress endpoint resource.
deleteRelay({required String relayId}) Future<void>
Deletes an existing relay resource.
deleteRuleSet({required String ruleSetId}) Future<void>
Delete a rule set.
deleteTrafficPolicy({required String trafficPolicyId}) Future<void>
Delete a traffic policy resource.
deregisterMemberFromAddressList({required String address, required String addressListId}) Future<void>
Removes a member from an address list.
getAddonInstance({required String addonInstanceId}) Future<GetAddonInstanceResponse>
Gets detailed information about an Add On instance.
getAddonSubscription({required String addonSubscriptionId}) Future<GetAddonSubscriptionResponse>
Gets detailed information about an Add On subscription.
getAddressList({required String addressListId}) Future<GetAddressListResponse>
Fetch attributes of an address list.
getAddressListImportJob({required String jobId}) Future<GetAddressListImportJobResponse>
Fetch attributes of an import job.
getArchive({required String archiveId}) Future<GetArchiveResponse>
Retrieves the full details and current state of a specified email archive.
getArchiveExport({required String exportId}) Future<GetArchiveExportResponse>
Retrieves the details and current status of a specific email archive export job.
getArchiveMessage({required String archivedMessageId}) Future<GetArchiveMessageResponse>
Returns a pre-signed URL that provides temporary download access to the specific email message stored in the archive.
getArchiveMessageContent({required String archivedMessageId}) Future<GetArchiveMessageContentResponse>
Returns the textual content of a specific email message stored in the archive. Attachments are not included.
getArchiveSearch({required String searchId}) Future<GetArchiveSearchResponse>
Retrieves the details and current status of a specific email archive search job.
getArchiveSearchResults({required String searchId}) Future<GetArchiveSearchResultsResponse>
Returns the results of a completed email archive search job.
getIngressPoint({required String ingressPointId, TrustStoreResponseOption? includeTrustStoreContents}) Future<GetIngressPointResponse>
Fetch ingress endpoint resource attributes.
getMemberOfAddressList({required String address, required String addressListId}) Future<GetMemberOfAddressListResponse>
Fetch attributes of a member in an address list.
getRelay({required String relayId}) Future<GetRelayResponse>
Fetch the relay resource and it's attributes.
getRuleSet({required String ruleSetId}) Future<GetRuleSetResponse>
Fetch attributes of a rule set.
getTrafficPolicy({required String trafficPolicyId}) Future<GetTrafficPolicyResponse>
Fetch attributes of a traffic policy resource.
listAddonInstances({String? nextToken, int? pageSize}) Future<ListAddonInstancesResponse>
Lists all Add On instances in your account.
listAddonSubscriptions({String? nextToken, int? pageSize}) Future<ListAddonSubscriptionsResponse>
Lists all Add On subscriptions in your account.
listAddressListImportJobs({required String addressListId, String? nextToken, int? pageSize}) Future<ListAddressListImportJobsResponse>
Lists jobs for an address list.
listAddressLists({String? nextToken, int? pageSize}) Future<ListAddressListsResponse>
Lists address lists for this account.
listArchiveExports({required String archiveId, String? nextToken, int? pageSize}) Future<ListArchiveExportsResponse>
Returns a list of email archive export jobs.
listArchives({String? nextToken, int? pageSize}) Future<ListArchivesResponse>
Returns a list of all email archives in your account.
listArchiveSearches({required String archiveId, String? nextToken, int? pageSize}) Future<ListArchiveSearchesResponse>
Returns a list of email archive search jobs.
listIngressPoints({String? nextToken, int? pageSize}) Future<ListIngressPointsResponse>
List all ingress endpoint resources.
listMembersOfAddressList({required String addressListId, AddressFilter? filter, String? nextToken, int? pageSize}) Future<ListMembersOfAddressListResponse>
Lists members of an address list.
listRelays({String? nextToken, int? pageSize}) Future<ListRelaysResponse>
Lists all the existing relay resources.
listRuleSets({String? nextToken, int? pageSize}) Future<ListRuleSetsResponse>
List rule sets for this account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Retrieves the list of tags (keys and values) assigned to the resource.
listTrafficPolicies({String? nextToken, int? pageSize}) Future<ListTrafficPoliciesResponse>
List traffic policy resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerMemberToAddressList({required String address, required String addressListId}) Future<void>
Adds a member to an address list.
startAddressListImportJob({required String jobId}) Future<void>
Starts an import job for an address list.
startArchiveExport({required String archiveId, required ExportDestinationConfiguration exportDestinationConfiguration, required DateTime fromTimestamp, required DateTime toTimestamp, ArchiveFilters? filters, bool? includeMetadata, int? maxResults}) Future<StartArchiveExportResponse>
Initiates an export of emails from the specified archive.
startArchiveSearch({required String archiveId, required DateTime fromTimestamp, required int maxResults, required DateTime toTimestamp, ArchiveFilters? filters}) Future<StartArchiveSearchResponse>
Initiates a search across emails in the specified archive.
stopAddressListImportJob({required String jobId}) Future<void>
Stops an ongoing import job for an address list.
stopArchiveExport({required String exportId}) Future<void>
Stops an in-progress export of emails from an archive.
stopArchiveSearch({required String searchId}) Future<void>
Stops an in-progress archive search job.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Adds one or more tags (keys and values) to a specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Remove one or more tags (keys and values) from a specified resource.
updateArchive({required String archiveId, String? archiveName, ArchiveRetention? retention}) Future<void>
Updates the attributes of an existing email archive.
updateIngressPoint({required String ingressPointId, IngressPointConfiguration? ingressPointConfiguration, String? ingressPointName, String? ruleSetId, IngressPointStatusToUpdate? statusToUpdate, TlsPolicy? tlsPolicy, String? trafficPolicyId}) Future<void>
Update attributes of a provisioned ingress endpoint resource.
updateRelay({required String relayId, RelayAuthentication? authentication, String? relayName, String? serverName, int? serverPort}) Future<void>
Updates the attributes of an existing relay resource.
updateRuleSet({required String ruleSetId, String? ruleSetName, List<Rule>? rules}) Future<void>
Update attributes of an already provisioned rule set.
updateTrafficPolicy({required String trafficPolicyId, AcceptAction? defaultAction, int? maxMessageSizeBytes, List<PolicyStatement>? policyStatements, String? trafficPolicyName}) Future<void>
Update attributes of an already provisioned traffic policy resource.

Operators

operator ==(Object other) bool
The equality operator.
inherited