deregisterMemberFromAddressList method
Removes a member from an address list.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter address :
The address to be removed from the address list.
Parameter addressListId :
The unique identifier of the address list to remove the address from.
Implementation
Future<void> deregisterMemberFromAddressList({
required String address,
required String addressListId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'MailManagerSvc.DeregisterMemberFromAddressList'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Address': address,
'AddressListId': addressListId,
},
);
}