getArchiveExport method

Future<GetArchiveExportResponse> getArchiveExport({
  1. required String exportId,
})

Retrieves the details and current status of a specific email archive export job.

May throw AccessDeniedException. May throw ThrottlingException. May throw ValidationException.

Parameter exportId : The identifier of the export job to get details for.

Implementation

Future<GetArchiveExportResponse> getArchiveExport({
  required String exportId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'MailManagerSvc.GetArchiveExport'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ExportId': exportId,
    },
  );

  return GetArchiveExportResponse.fromJson(jsonResponse.body);
}