getArchiveSearch method

Future<GetArchiveSearchResponse> getArchiveSearch({
  1. required String searchId,
})

Retrieves the details and current status of a specific email archive search job.

May throw AccessDeniedException. May throw ThrottlingException. May throw ValidationException.

Parameter searchId : The identifier of the search job to get details for.

Implementation

Future<GetArchiveSearchResponse> getArchiveSearch({
  required String searchId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'MailManagerSvc.GetArchiveSearch'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'SearchId': searchId,
    },
  );

  return GetArchiveSearchResponse.fromJson(jsonResponse.body);
}