getMemberOfAddressList method
Fetch attributes of a member in an address list.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter address :
The address to be retrieved from the address list.
Parameter addressListId :
The unique identifier of the address list to retrieve the address from.
Implementation
Future<GetMemberOfAddressListResponse> getMemberOfAddressList({
required String address,
required String addressListId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'MailManagerSvc.GetMemberOfAddressList'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Address': address,
'AddressListId': addressListId,
},
);
return GetMemberOfAddressListResponse.fromJson(jsonResponse.body);
}