registerMemberToAddressList method
Adds a member to an address list.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter address :
The address to be added to the address list.
Parameter addressListId :
The unique identifier of the address list where the address should be
added.
Implementation
Future<void> registerMemberToAddressList({
required String address,
required String addressListId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'MailManagerSvc.RegisterMemberToAddressList'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Address': address,
'AddressListId': addressListId,
},
);
}