updateIngressPoint method

Future<void> updateIngressPoint({
  1. required String ingressPointId,
  2. IngressPointConfiguration? ingressPointConfiguration,
  3. String? ingressPointName,
  4. String? ruleSetId,
  5. IngressPointStatusToUpdate? statusToUpdate,
  6. TlsPolicy? tlsPolicy,
  7. String? trafficPolicyId,
})

Update attributes of a provisioned ingress endpoint resource.

May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter ingressPointId : The identifier for the ingress endpoint you want to update.

Parameter ingressPointConfiguration : If you choose an Authenticated ingress endpoint, you must configure either an SMTP password or a secret ARN.

Parameter ingressPointName : A user friendly name for the ingress endpoint resource.

Parameter ruleSetId : The identifier of an existing rule set that you attach to an ingress endpoint resource.

Parameter statusToUpdate : The update status of an ingress endpoint.

Parameter tlsPolicy : The Transport Layer Security (TLS) policy for the ingress point. Valid values are REQUIRED, OPTIONAL. Only ingress endpoints using REQUIRED or OPTIONAL as TlsPolicy can be updated.

Parameter trafficPolicyId : The identifier of an existing traffic policy that you attach to an ingress endpoint resource.

Implementation

Future<void> updateIngressPoint({
  required String ingressPointId,
  IngressPointConfiguration? ingressPointConfiguration,
  String? ingressPointName,
  String? ruleSetId,
  IngressPointStatusToUpdate? statusToUpdate,
  TlsPolicy? tlsPolicy,
  String? trafficPolicyId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'MailManagerSvc.UpdateIngressPoint'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'IngressPointId': ingressPointId,
      if (ingressPointConfiguration != null)
        'IngressPointConfiguration': ingressPointConfiguration,
      if (ingressPointName != null) 'IngressPointName': ingressPointName,
      if (ruleSetId != null) 'RuleSetId': ruleSetId,
      if (statusToUpdate != null) 'StatusToUpdate': statusToUpdate.value,
      if (tlsPolicy != null) 'TlsPolicy': tlsPolicy.value,
      if (trafficPolicyId != null) 'TrafficPolicyId': trafficPolicyId,
    },
  );
}