updateRuleSet method

Future<void> updateRuleSet({
  1. required String ruleSetId,
  2. String? ruleSetName,
  3. List<Rule>? rules,
})

Update attributes of an already provisioned rule set.

May throw ConflictException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter ruleSetId : The identifier of a rule set you want to update.

Parameter ruleSetName : A user-friendly name for the rule set resource.

Parameter rules : A new set of rules to replace the current rules of the rule set—these rules will override all the rules of the rule set.

Implementation

Future<void> updateRuleSet({
  required String ruleSetId,
  String? ruleSetName,
  List<Rule>? rules,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'MailManagerSvc.UpdateRuleSet'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RuleSetId': ruleSetId,
      if (ruleSetName != null) 'RuleSetName': ruleSetName,
      if (rules != null) 'Rules': rules,
    },
  );
}