managed_blockchain library
Classes
- AwsClientCredentials
- AWS credentials.
- ManagedBlockchain
- Amazon Managed Blockchain is a fully managed service for creating and managing blockchain networks using open-source frameworks. Blockchain allows you to build applications where multiple parties can securely and transparently run transactions and share data without the need for a trusted, central authority.