ManagedBlockchain class
Amazon Managed Blockchain is a fully managed service for creating and managing blockchain networks using open-source frameworks. Blockchain allows you to build applications where multiple parties can securely and transparently run transactions and share data without the need for a trusted, central authority.
Managed Blockchain supports the Hyperledger Fabric and Ethereum open-source
frameworks. Because of fundamental differences between the frameworks, some
API actions or data types may only apply in the context of one framework and
not the other. For example, actions related to Hyperledger Fabric network
members such as CreateMember and DeleteMember
don't apply to Ethereum.
The description for each action indicates the framework or frameworks to which it applies. Data types and properties that apply only in the context of a particular framework are similarly indicated.
Constructors
- ManagedBlockchain({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessor(
{required AccessorType accessorType, String? clientRequestToken, AccessorNetworkType? networkType, Map< String, String> ? tags}) → Future<CreateAccessorOutput> - Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access. The accessor contains information required for token based access.
-
createMember(
{required String invitationId, required MemberConfiguration memberConfiguration, required String networkId, String? clientRequestToken}) → Future< CreateMemberOutput> - Creates a member within a Managed Blockchain network.
-
createNetwork(
{required Framework framework, required String frameworkVersion, required MemberConfiguration memberConfiguration, required String name, required VotingPolicy votingPolicy, String? clientRequestToken, String? description, NetworkFrameworkConfiguration? frameworkConfiguration, Map< String, String> ? tags}) → Future<CreateNetworkOutput> - Creates a new blockchain network using Amazon Managed Blockchain.
-
createNode(
{required String networkId, required NodeConfiguration nodeConfiguration, String? clientRequestToken, String? memberId, Map< String, String> ? tags}) → Future<CreateNodeOutput> - Creates a node on the specified blockchain network.
-
createProposal(
{required ProposalActions actions, required String memberId, required String networkId, String? clientRequestToken, String? description, Map< String, String> ? tags}) → Future<CreateProposalOutput> - Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network. Any member can create a proposal.
-
deleteAccessor(
{required String accessorId}) → Future< void> -
Deletes an accessor that your Amazon Web Services account owns. An
accessor object is a container that has the information required for token
based access to your Ethereum nodes including, the
BILLING_TOKEN. After an accessor is deleted, the status of the accessor changes fromAVAILABLEtoPENDING_DELETION. An accessor in thePENDING_DELETIONstate can’t be used for new WebSocket requests or HTTP requests. However, WebSocket connections that were initiated while the accessor was in theAVAILABLEstate remain open until they expire (up to 2 hours). -
deleteMember(
{required String memberId, required String networkId}) → Future< void> -
Deletes a member. Deleting a member removes the member and all associated
resources from the network.
DeleteMembercan only be called for a specifiedMemberIdif the principal performing the action is associated with the Amazon Web Services account that owns the member. In all other cases, theDeleteMemberaction is carried out as the result of an approved proposal to remove a member. IfMemberIdis the last member in a network specified by the last Amazon Web Services account, the network is deleted also. -
deleteNode(
{required String networkId, required String nodeId, String? memberId}) → Future< void> - Deletes a node that your Amazon Web Services account owns. All data on the node is lost and cannot be recovered.
-
getAccessor(
{required String accessorId}) → Future< GetAccessorOutput> - Returns detailed information about an accessor. An accessor object is a container that has the information required for token based access to your Ethereum nodes.
-
getMember(
{required String memberId, required String networkId}) → Future< GetMemberOutput> - Returns detailed information about a member.
-
getNetwork(
{required String networkId}) → Future< GetNetworkOutput> - Returns detailed information about a network.
-
getNode(
{required String networkId, required String nodeId, String? memberId}) → Future< GetNodeOutput> - Returns detailed information about a node.
-
getProposal(
{required String networkId, required String proposalId}) → Future< GetProposalOutput> - Returns detailed information about a proposal.
-
listAccessors(
{int? maxResults, AccessorNetworkType? networkType, String? nextToken}) → Future< ListAccessorsOutput> - Returns a list of the accessors and their properties. Accessor objects are containers that have the information required for token based access to your Ethereum nodes.
-
listInvitations(
{int? maxResults, String? nextToken}) → Future< ListInvitationsOutput> - Returns a list of all invitations for the current Amazon Web Services account.
-
listMembers(
{required String networkId, bool? isOwned, int? maxResults, String? name, String? nextToken, MemberStatus? status}) → Future< ListMembersOutput> - Returns a list of the members in a network and properties of their configurations.
-
listNetworks(
{Framework? framework, int? maxResults, String? name, String? nextToken, NetworkStatus? status}) → Future< ListNetworksOutput> - Returns information about the networks in which the current Amazon Web Services account participates.
-
listNodes(
{required String networkId, int? maxResults, String? memberId, String? nextToken, NodeStatus? status}) → Future< ListNodesOutput> - Returns information about the nodes within a network.
-
listProposals(
{required String networkId, int? maxResults, String? nextToken}) → Future< ListProposalsOutput> - Returns a list of proposals for the network.
-
listProposalVotes(
{required String networkId, required String proposalId, int? maxResults, String? nextToken}) → Future< ListProposalVotesOutput> - Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags for the specified resource. Each tag consists of a key and optional value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rejectInvitation(
{required String invitationId}) → Future< void> - Rejects an invitation to join a network. This action can be called by a principal in an Amazon Web Services account that has received an invitation to create a member and join a network.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the Amazon Managed Blockchain resource.
-
updateMember(
{required String memberId, required String networkId, MemberLogPublishingConfiguration? logPublishingConfiguration}) → Future< void> - Updates a member configuration with new parameters.
-
updateNode(
{required String networkId, required String nodeId, NodeLogPublishingConfiguration? logPublishingConfiguration, String? memberId}) → Future< void> - Updates a node configuration with new parameters.
-
voteOnProposal(
{required String networkId, required String proposalId, required VoteValue vote, required String voterMemberId}) → Future< void> -
Casts a vote for a specified
ProposalIdon behalf of a member. The member to vote as, specified byVoterMemberId, must be in the same Amazon Web Services account as the principal that calls the action.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited