deleteAccessor method

Future<void> deleteAccessor({
  1. required String accessorId,
})

Deletes an accessor that your Amazon Web Services account owns. An accessor object is a container that has the information required for token based access to your Ethereum nodes including, the BILLING_TOKEN. After an accessor is deleted, the status of the accessor changes from AVAILABLE to PENDING_DELETION. An accessor in the PENDING_DELETION state can’t be used for new WebSocket requests or HTTP requests. However, WebSocket connections that were initiated while the accessor was in the AVAILABLE state remain open until they expire (up to 2 hours).

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter accessorId : The unique identifier of the accessor.

Implementation

Future<void> deleteAccessor({
  required String accessorId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/accessors/${Uri.encodeComponent(accessorId)}',
    exceptionFnMap: _exceptionFns,
  );
}