listInvitations method
Returns a list of all invitations for the current Amazon Web Services account.
Applies only to Hyperledger Fabric.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceLimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of invitations to return.
Parameter nextToken :
The pagination token that indicates the next set of results to retrieve.
Implementation
Future<ListInvitationsOutput> listInvitations({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/invitations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListInvitationsOutput.fromJson(response);
}