rejectInvitation method

Future<void> rejectInvitation({
  1. required String invitationId,
})

Rejects an invitation to join a network. This action can be called by a principal in an Amazon Web Services account that has received an invitation to create a member and join a network.

Applies only to Hyperledger Fabric.

May throw AccessDeniedException. May throw IllegalActionException. May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter invitationId : The unique identifier of the invitation to reject.

Implementation

Future<void> rejectInvitation({
  required String invitationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/invitations/${Uri.encodeComponent(invitationId)}',
    exceptionFnMap: _exceptionFns,
  );
}