tagResource method
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value.
When you specify a tag key that already exists, the tag value is
overwritten with the new value. Use UntagResource to remove
tag keys.
A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error.
For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ResourceNotReadyException.
May throw TooManyTagsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource. For more information about
ARNs and their format, see Amazon
Resource Names (ARNs) in the Amazon Web Services General
Reference.
Parameter tags :
The tags to assign to the specified resource. Tag values can be empty, for
example, "MyTagKey" : "". You can specify multiple key-value
pairs in a single request, with an overall maximum of 50 tags added to
each resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}