updateNode method

Future<void> updateNode({
  1. required String networkId,
  2. required String nodeId,
  3. NodeLogPublishingConfiguration? logPublishingConfiguration,
  4. String? memberId,
})

Updates a node configuration with new parameters.

Applies only to Hyperledger Fabric.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter networkId : The unique identifier of the network that the node is on.

Parameter nodeId : The unique identifier of the node.

Parameter logPublishingConfiguration : Configuration properties for publishing to Amazon CloudWatch Logs.

Parameter memberId : The unique identifier of the member that owns the node.

Applies only to Hyperledger Fabric.

Implementation

Future<void> updateNode({
  required String networkId,
  required String nodeId,
  NodeLogPublishingConfiguration? logPublishingConfiguration,
  String? memberId,
}) async {
  final $payload = <String, dynamic>{
    if (logPublishingConfiguration != null)
      'LogPublishingConfiguration': logPublishingConfiguration,
    if (memberId != null) 'MemberId': memberId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/nodes/${Uri.encodeComponent(nodeId)}',
    exceptionFnMap: _exceptionFns,
  );
}