ManagedBlockchainQuery class

Amazon Managed Blockchain (AMB) Query provides you with convenient access to multi-blockchain network data, which makes it easier for you to extract contextual data related to blockchain activity. You can use AMB Query to read data from public blockchain networks, such as Bitcoin Mainnet and Ethereum Mainnet. You can also get information such as the current and historical balances of addresses, or you can get a list of blockchain transactions for a given time period. Additionally, you can get details of a given transaction, such as transaction events, which you can further analyze or use in business logic for your applications.

Constructors

ManagedBlockchainQuery({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetTokenBalance({List<BatchGetTokenBalanceInputItem>? getTokenBalanceInputs}) Future<BatchGetTokenBalanceOutput>
Gets the token balance for a batch of tokens by using the BatchGetTokenBalance action for every token in the request.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getAssetContract({required ContractIdentifier contractIdentifier}) Future<GetAssetContractOutput>
Gets the information about a specific contract deployed on the blockchain.
getTokenBalance({required OwnerIdentifier ownerIdentifier, required TokenIdentifier tokenIdentifier, BlockchainInstant? atBlockchainInstant}) Future<GetTokenBalanceOutput>
Gets the balance of a specific token, including native tokens, for a given address (wallet or contract) on the blockchain.
getTransaction({required QueryNetwork network, String? transactionHash, String? transactionId}) Future<GetTransactionOutput>
Gets the details of a transaction.
listAssetContracts({required ContractFilter contractFilter, int? maxResults, String? nextToken}) Future<ListAssetContractsOutput>
Lists all the contracts for a given contract type deployed by an address (either a contract address or a wallet address).
listFilteredTransactionEvents({required AddressIdentifierFilter addressIdentifierFilter, required String network, ConfirmationStatusFilter? confirmationStatusFilter, int? maxResults, String? nextToken, ListFilteredTransactionEventsSort? sort, TimeFilter? timeFilter, VoutFilter? voutFilter}) Future<ListFilteredTransactionEventsOutput>
Lists all the transaction events for an address on the blockchain.
listTokenBalances({required TokenFilter tokenFilter, int? maxResults, String? nextToken, OwnerFilter? ownerFilter}) Future<ListTokenBalancesOutput>
This action returns the following for a given blockchain network:
listTransactionEvents({required QueryNetwork network, int? maxResults, String? nextToken, String? transactionHash, String? transactionId}) Future<ListTransactionEventsOutput>
Lists all the transaction events for a transaction
listTransactions({required String address, required QueryNetwork network, ConfirmationStatusFilter? confirmationStatusFilter, BlockchainInstant? fromBlockchainInstant, int? maxResults, String? nextToken, ListTransactionsSort? sort, BlockchainInstant? toBlockchainInstant}) Future<ListTransactionsOutput>
Lists all the transaction events for a transaction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited