listTransactionEvents method

Future<ListTransactionEventsOutput> listTransactionEvents({
  1. required QueryNetwork network,
  2. int? maxResults,
  3. String? nextToken,
  4. String? transactionHash,
  5. String? transactionId,
})

Lists all the transaction events for a transaction

May throw AccessDeniedException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter network : The blockchain network where the transaction events occurred.

Parameter maxResults : The maximum number of transaction events to list.

Default: 100

To retrieve the next set of results, make another request with the returned nextToken value. The value of nextToken is null when there are no more results to return

Parameter nextToken : The pagination token that indicates the next set of results to retrieve.

Parameter transactionHash : The hash of a transaction. It is generated when a transaction is created.

Parameter transactionId : The identifier of a Bitcoin transaction. It is generated when a transaction is created.

Implementation

Future<ListTransactionEventsOutput> listTransactionEvents({
  required QueryNetwork network,
  int? maxResults,
  String? nextToken,
  String? transactionHash,
  String? transactionId,
}) async {
  final $payload = <String, dynamic>{
    'network': network.value,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (transactionHash != null) 'transactionHash': transactionHash,
    if (transactionId != null) 'transactionId': transactionId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-transaction-events',
    exceptionFnMap: _exceptionFns,
  );
  return ListTransactionEventsOutput.fromJson(response);
}