MediaConnect class

Welcome to the Elemental MediaConnect API reference.

MediaConnect is a service that lets you ingest live video content into the cloud and distribute it to destinations all over the world, both inside and outside the Amazon Web Services cloud. This API reference provides descriptions, syntax, and usage examples for each of the actions and data types that are supported by MediaConnect.

Use the following links to get started with the MediaConnect API:

  • Actions: An alphabetical list of all MediaConnect API operations.
  • Data types: An alphabetical list of all MediaConnect data types.
  • Common parameters: Parameters that all operations can use.
  • Common errors: Client and server errors that all operations can return.

Constructors

MediaConnect({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBridgeOutputs({required String bridgeArn, required List<AddBridgeOutputRequest> outputs}) Future<AddBridgeOutputsResponse>
Adds outputs to an existing bridge.
addBridgeSources({required String bridgeArn, required List<AddBridgeSourceRequest> sources}) Future<AddBridgeSourcesResponse>
Adds sources to an existing bridge.
addFlowMediaStreams({required String flowArn, required List<AddMediaStreamRequest> mediaStreams}) Future<AddFlowMediaStreamsResponse>
Adds media streams to an existing flow. After you add a media stream to a flow, you can associate it with a source and/or an output that uses the ST 2110 JPEG XS or CDI protocol.
addFlowOutputs({required String flowArn, required List<AddOutputRequest> outputs}) Future<AddFlowOutputsResponse>
Adds outputs to an existing flow. You can create up to 50 outputs per flow.
addFlowSources({required String flowArn, required List<SetSourceRequest> sources}) Future<AddFlowSourcesResponse>
Adds sources to a flow.
addFlowVpcInterfaces({required String flowArn, required List<VpcInterfaceRequest> vpcInterfaces}) Future<AddFlowVpcInterfacesResponse>
Adds VPC interfaces to a flow.
batchGetRouterInput({required List<String> arns}) Future<BatchGetRouterInputResponse>
Retrieves information about multiple router inputs in AWS Elemental MediaConnect.
batchGetRouterNetworkInterface({required List<String> arns}) Future<BatchGetRouterNetworkInterfaceResponse>
Retrieves information about multiple router network interfaces in AWS Elemental MediaConnect.
batchGetRouterOutput({required List<String> arns}) Future<BatchGetRouterOutputResponse>
Retrieves information about multiple router outputs in AWS Elemental MediaConnect.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createBridge({required String name, required String placementArn, required List<AddBridgeSourceRequest> sources, AddEgressGatewayBridgeRequest? egressGatewayBridge, AddIngressGatewayBridgeRequest? ingressGatewayBridge, List<AddBridgeOutputRequest>? outputs, FailoverConfig? sourceFailoverConfig}) Future<CreateBridgeResponse>
Creates a new bridge. The request must include one source.
createFlow({required String name, String? availabilityZone, EncodingConfig? encodingConfig, List<GrantEntitlementRequest>? entitlements, FlowSize? flowSize, Map<String, String>? flowTags, AddMaintenance? maintenance, List<AddMediaStreamRequest>? mediaStreams, NdiConfig? ndiConfig, List<AddOutputRequest>? outputs, SetSourceRequest? source, FailoverConfig? sourceFailoverConfig, MonitoringConfig? sourceMonitoringConfig, List<SetSourceRequest>? sources, List<VpcInterfaceRequest>? vpcInterfaces}) Future<CreateFlowResponse>
Creates a new flow. The request must include one source. The request optionally can include outputs (up to 50) and entitlements (up to 50).
createGateway({required List<String> egressCidrBlocks, required String name, required List<GatewayNetwork> networks}) Future<CreateGatewayResponse>
Creates a new gateway. The request must include at least one network (up to four).
createRouterInput({required RouterInputConfiguration configuration, required int maximumBitrate, required String name, required RoutingScope routingScope, required RouterInputTier tier, String? availabilityZone, String? clientToken, MaintenanceConfiguration? maintenanceConfiguration, String? regionName, Map<String, String>? tags, RouterInputTransitEncryption? transitEncryption}) Future<CreateRouterInputResponse>
Creates a new router input in AWS Elemental MediaConnect.
createRouterNetworkInterface({required RouterNetworkInterfaceConfiguration configuration, required String name, String? clientToken, String? regionName, Map<String, String>? tags}) Future<CreateRouterNetworkInterfaceResponse>
Creates a new router network interface in AWS Elemental MediaConnect.
createRouterOutput({required RouterOutputConfiguration configuration, required int maximumBitrate, required String name, required RoutingScope routingScope, required RouterOutputTier tier, String? availabilityZone, String? clientToken, MaintenanceConfiguration? maintenanceConfiguration, String? regionName, Map<String, String>? tags}) Future<CreateRouterOutputResponse>
Creates a new router output in AWS Elemental MediaConnect.
deleteBridge({required String bridgeArn}) Future<DeleteBridgeResponse>
Deletes a bridge. Before you can delete a bridge, you must stop the bridge.
deleteFlow({required String flowArn}) Future<DeleteFlowResponse>
Deletes a flow. Before you can delete a flow, you must stop the flow.
deleteGateway({required String gatewayArn}) Future<DeleteGatewayResponse>
Deletes a gateway. Before you can delete a gateway, you must deregister its instances and delete its bridges.
deleteRouterInput({required String arn}) Future<DeleteRouterInputResponse>
Deletes a router input from AWS Elemental MediaConnect.
deleteRouterNetworkInterface({required String arn}) Future<DeleteRouterNetworkInterfaceResponse>
Deletes a router network interface from AWS Elemental MediaConnect.
deleteRouterOutput({required String arn}) Future<DeleteRouterOutputResponse>
Deletes a router output from AWS Elemental MediaConnect.
deregisterGatewayInstance({required String gatewayInstanceArn, bool? force}) Future<DeregisterGatewayInstanceResponse>
Deregisters an instance. Before you deregister an instance, all bridges running on the instance must be stopped. If you want to deregister an instance without stopping the bridges, you must use the --force option.
describeBridge({required String bridgeArn}) Future<DescribeBridgeResponse>
Displays the details of a bridge.
describeFlow({required String flowArn}) Future<DescribeFlowResponse>
Displays the details of a flow. The response includes the flow Amazon Resource Name (ARN), name, and Availability Zone, as well as details about the source, outputs, and entitlements.
describeFlowSourceMetadata({required String flowArn}) Future<DescribeFlowSourceMetadataResponse>
The DescribeFlowSourceMetadata API is used to view information about the flow's source transport stream and programs. This API displays status messages about the flow's source as well as details about the program's video, audio, and other data.
describeFlowSourceThumbnail({required String flowArn}) Future<DescribeFlowSourceThumbnailResponse>
Describes the thumbnail for the flow source.
describeGateway({required String gatewayArn}) Future<DescribeGatewayResponse>
Displays the details of a gateway. The response includes the gateway Amazon Resource Name (ARN), name, and CIDR blocks, as well as details about the networks.
describeGatewayInstance({required String gatewayInstanceArn}) Future<DescribeGatewayInstanceResponse>
Displays the details of an instance.
describeOffering({required String offeringArn}) Future<DescribeOfferingResponse>
Displays the details of an offering. The response includes the offering description, duration, outbound bandwidth, price, and Amazon Resource Name (ARN).
describeReservation({required String reservationArn}) Future<DescribeReservationResponse>
Displays the details of a reservation. The response includes the reservation name, state, start date and time, and the details of the offering that make up the rest of the reservation (such as price, duration, and outbound bandwidth).
getRouterInput({required String arn}) Future<GetRouterInputResponse>
Retrieves information about a specific router input in AWS Elemental MediaConnect.
getRouterInputSourceMetadata({required String arn}) Future<GetRouterInputSourceMetadataResponse>
Retrieves detailed metadata information about a specific router input source, including stream details and connection state.
getRouterInputThumbnail({required String arn}) Future<GetRouterInputThumbnailResponse>
Retrieves the thumbnail for a router input in AWS Elemental MediaConnect.
getRouterNetworkInterface({required String arn}) Future<GetRouterNetworkInterfaceResponse>
Retrieves information about a specific router network interface in AWS Elemental MediaConnect.
getRouterOutput({required String arn}) Future<GetRouterOutputResponse>
Retrieves information about a specific router output in AWS Elemental MediaConnect.
grantFlowEntitlements({required List<GrantEntitlementRequest> entitlements, required String flowArn}) Future<GrantFlowEntitlementsResponse>
Grants entitlements to an existing flow.
listBridges({String? filterArn, int? maxResults, String? nextToken}) Future<ListBridgesResponse>
Displays a list of bridges that are associated with this account and an optionally specified Amazon Resource Name (ARN). This request returns a paginated result.
listEntitlements({int? maxResults, String? nextToken}) Future<ListEntitlementsResponse>
Displays a list of all entitlements that have been granted to this account. This request returns 20 results per page.
listFlows({int? maxResults, String? nextToken}) Future<ListFlowsResponse>
Displays a list of flows that are associated with this account. This request returns a paginated result.
listGatewayInstances({String? filterArn, int? maxResults, String? nextToken}) Future<ListGatewayInstancesResponse>
Displays a list of instances associated with the Amazon Web Services account. This request returns a paginated result. You can use the filterArn property to display only the instances associated with the selected Gateway Amazon Resource Name (ARN).
listGateways({int? maxResults, String? nextToken}) Future<ListGatewaysResponse>
Displays a list of gateways that are associated with this account. This request returns a paginated result.
listOfferings({int? maxResults, String? nextToken}) Future<ListOfferingsResponse>
Displays a list of all offerings that are available to this account in the current Amazon Web Services Region. If you have an active reservation (which means you've purchased an offering that has already started and hasn't expired yet), your account isn't eligible for other offerings.
listReservations({int? maxResults, String? nextToken}) Future<ListReservationsResponse>
Displays a list of all reservations that have been purchased by this account in the current Amazon Web Services Region. This list includes all reservations in all states (such as active and expired).
listRouterInputs({List<RouterInputFilter>? filters, int? maxResults, String? nextToken}) Future<ListRouterInputsResponse>
Retrieves a list of router inputs in AWS Elemental MediaConnect.
listRouterNetworkInterfaces({List<RouterNetworkInterfaceFilter>? filters, int? maxResults, String? nextToken}) Future<ListRouterNetworkInterfacesResponse>
Retrieves a list of router network interfaces in AWS Elemental MediaConnect.
listRouterOutputs({List<RouterOutputFilter>? filters, int? maxResults, String? nextToken}) Future<ListRouterOutputsResponse>
Retrieves a list of router outputs in AWS Elemental MediaConnect.
listTagsForGlobalResource({required String resourceArn}) Future<ListTagsForGlobalResourceResponse>
Lists the tags associated with a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List all tags on a MediaConnect resource in the current region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchaseOffering({required String offeringArn, required String reservationName, required String start}) Future<PurchaseOfferingResponse>
Submits a request to purchase an offering. If you already have an active reservation, you can't purchase another offering.
removeBridgeOutput({required String bridgeArn, required String outputName}) Future<RemoveBridgeOutputResponse>
Removes an output from a bridge.
removeBridgeSource({required String bridgeArn, required String sourceName}) Future<RemoveBridgeSourceResponse>
Removes a source from a bridge.
removeFlowMediaStream({required String flowArn, required String mediaStreamName}) Future<RemoveFlowMediaStreamResponse>
Removes a media stream from a flow. This action is only available if the media stream is not associated with a source or output.
removeFlowOutput({required String flowArn, required String outputArn}) Future<RemoveFlowOutputResponse>
Removes an output from an existing flow. This request can be made only on an output that does not have an entitlement associated with it. If the output has an entitlement, you must revoke the entitlement instead. When an entitlement is revoked from a flow, the service automatically removes the associated output.
removeFlowSource({required String flowArn, required String sourceArn}) Future<RemoveFlowSourceResponse>
Removes a source from an existing flow. This request can be made only if there is more than one source on the flow.
removeFlowVpcInterface({required String flowArn, required String vpcInterfaceName}) Future<RemoveFlowVpcInterfaceResponse>
Removes a VPC Interface from an existing flow. This request can be made only on a VPC interface that does not have a Source or Output associated with it. If the VPC interface is referenced by a Source or Output, you must first delete or update the Source or Output to no longer reference the VPC interface.
restartRouterInput({required String arn}) Future<RestartRouterInputResponse>
Restarts a router input. This operation can be used to recover from errors or refresh the input state.
restartRouterOutput({required String arn}) Future<RestartRouterOutputResponse>
Restarts a router output. This operation can be used to recover from errors or refresh the output state.
revokeFlowEntitlement({required String entitlementArn, required String flowArn}) Future<RevokeFlowEntitlementResponse>
Revokes an entitlement from a flow. Once an entitlement is revoked, the content becomes unavailable to the subscriber and the associated output is removed.
startFlow({required String flowArn}) Future<StartFlowResponse>
Starts a flow.
startRouterInput({required String arn}) Future<StartRouterInputResponse>
Starts a router input in AWS Elemental MediaConnect.
startRouterOutput({required String arn}) Future<StartRouterOutputResponse>
Starts a router output in AWS Elemental MediaConnect.
stopFlow({required String flowArn}) Future<StopFlowResponse>
Stops a flow.
stopRouterInput({required String arn}) Future<StopRouterInputResponse>
Stops a router input in AWS Elemental MediaConnect.
stopRouterOutput({required String arn}) Future<StopRouterOutputResponse>
Stops a router output in AWS Elemental MediaConnect.
tagGlobalResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Associates the specified tags to a resource with the specified resourceArn in the current region. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well.
takeRouterInput({required String routerOutputArn, String? routerInputArn}) Future<TakeRouterInputResponse>
Associates a router input with a router output in AWS Elemental MediaConnect.
toString() String
A string representation of this object.
inherited
untagGlobalResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes specified tags from a resource in the current region.
updateBridge({required String bridgeArn, UpdateEgressGatewayBridgeRequest? egressGatewayBridge, UpdateIngressGatewayBridgeRequest? ingressGatewayBridge, UpdateFailoverConfig? sourceFailoverConfig}) Future<UpdateBridgeResponse>
Updates the bridge.
updateBridgeOutput({required String bridgeArn, required String outputName, UpdateBridgeNetworkOutputRequest? networkOutput}) Future<UpdateBridgeOutputResponse>
Updates an existing bridge output.
updateBridgeSource({required String bridgeArn, required String sourceName, UpdateBridgeFlowSourceRequest? flowSource, UpdateBridgeNetworkSourceRequest? networkSource}) Future<UpdateBridgeSourceResponse>
Updates an existing bridge source.
updateBridgeState({required String bridgeArn, required DesiredState desiredState}) Future<UpdateBridgeStateResponse>
Updates the bridge state.
updateFlow({required String flowArn, EncodingConfig? encodingConfig, FlowSize? flowSize, UpdateMaintenance? maintenance, NdiConfig? ndiConfig, UpdateFailoverConfig? sourceFailoverConfig, MonitoringConfig? sourceMonitoringConfig}) Future<UpdateFlowResponse>
Updates an existing flow.
updateFlowEntitlement({required String entitlementArn, required String flowArn, String? description, UpdateEncryption? encryption, EntitlementStatus? entitlementStatus, List<String>? subscribers}) Future<UpdateFlowEntitlementResponse>
Updates an entitlement. You can change an entitlement's description, subscribers, and encryption. If you change the subscribers, the service will remove the outputs that are are used by the subscribers that are removed.
updateFlowMediaStream({required String flowArn, required String mediaStreamName, MediaStreamAttributesRequest? attributes, int? clockRate, String? description, MediaStreamType? mediaStreamType, String? videoFormat}) Future<UpdateFlowMediaStreamResponse>
Updates an existing media stream.
updateFlowOutput({required String flowArn, required String outputArn, List<String>? cidrAllowList, String? description, String? destination, UpdateEncryption? encryption, int? maxLatency, List<MediaStreamOutputConfigurationRequest>? mediaStreamOutputConfigurations, int? minLatency, NdiOutputTimecodeSource? ndiOutputTimecodeSource, String? ndiProgramName, int? ndiSpeedHqQuality, OutputStatus? outputStatus, int? port, Protocol? protocol, String? remoteId, State? routerIntegrationState, FlowTransitEncryption? routerIntegrationTransitEncryption, int? senderControlPort, String? senderIpAddress, int? smoothingLatency, String? streamId, VpcInterfaceAttachment? vpcInterfaceAttachment}) Future<UpdateFlowOutputResponse>
Updates an existing flow output.
updateFlowSource({required String flowArn, required String sourceArn, UpdateEncryption? decryption, String? description, String? entitlementArn, UpdateGatewayBridgeSourceRequest? gatewayBridgeSource, int? ingestPort, int? maxBitrate, int? maxLatency, int? maxSyncBuffer, List<MediaStreamSourceConfigurationRequest>? mediaStreamSourceConfigurations, int? minLatency, NdiSourceSettings? ndiSourceSettings, Protocol? protocol, State? routerIntegrationState, FlowTransitEncryption? routerIntegrationTransitDecryption, int? senderControlPort, String? senderIpAddress, String? sourceListenerAddress, int? sourceListenerPort, String? streamId, String? vpcInterfaceName, String? whitelistCidr}) Future<UpdateFlowSourceResponse>
Updates the source of a flow.
updateGatewayInstance({required String gatewayInstanceArn, BridgePlacement? bridgePlacement}) Future<UpdateGatewayInstanceResponse>
Updates an existing gateway instance.
updateRouterInput({required String arn, RouterInputConfiguration? configuration, MaintenanceConfiguration? maintenanceConfiguration, int? maximumBitrate, String? name, RoutingScope? routingScope, RouterInputTier? tier, RouterInputTransitEncryption? transitEncryption}) Future<UpdateRouterInputResponse>
Updates the configuration of an existing router input in AWS Elemental MediaConnect.
updateRouterNetworkInterface({required String arn, RouterNetworkInterfaceConfiguration? configuration, String? name}) Future<UpdateRouterNetworkInterfaceResponse>
Updates the configuration of an existing router network interface in AWS Elemental MediaConnect.
updateRouterOutput({required String arn, RouterOutputConfiguration? configuration, MaintenanceConfiguration? maintenanceConfiguration, int? maximumBitrate, String? name, RoutingScope? routingScope, RouterOutputTier? tier}) Future<UpdateRouterOutputResponse>
Updates the configuration of an existing router output in AWS Elemental MediaConnect.

Operators

operator ==(Object other) bool
The equality operator.
inherited