addFlowMediaStreams method
Adds media streams to an existing flow. After you add a media stream to a flow, you can associate it with a source and/or an output that uses the ST 2110 JPEG XS or CDI protocol.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter flowArn :
The Amazon Resource Name (ARN) of the flow.
Parameter mediaStreams :
The media streams that you want to add to the flow.
Implementation
Future<AddFlowMediaStreamsResponse> addFlowMediaStreams({
required String flowArn,
required List<AddMediaStreamRequest> mediaStreams,
}) async {
final $payload = <String, dynamic>{
'mediaStreams': mediaStreams,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/flows/${Uri.encodeComponent(flowArn)}/mediaStreams',
exceptionFnMap: _exceptionFns,
);
return AddFlowMediaStreamsResponse.fromJson(response);
}