addFlowOutputs method
Adds outputs to an existing flow. You can create up to 50 outputs per flow.
May throw AddFlowOutputs420Exception.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter flowArn :
The Amazon Resource Name (ARN) of the flow that you want to add outputs
to.
Parameter outputs :
A list of outputs that you want to add to the flow.
Implementation
Future<AddFlowOutputsResponse> addFlowOutputs({
required String flowArn,
required List<AddOutputRequest> outputs,
}) async {
final $payload = <String, dynamic>{
'outputs': outputs,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/flows/${Uri.encodeComponent(flowArn)}/outputs',
exceptionFnMap: _exceptionFns,
);
return AddFlowOutputsResponse.fromJson(response);
}