batchGetRouterNetworkInterface method

Future<BatchGetRouterNetworkInterfaceResponse> batchGetRouterNetworkInterface({
  1. required List<String> arns,
})

Retrieves information about multiple router network interfaces in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ConflictException. May throw InternalServerErrorException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arns : The Amazon Resource Names (ARNs) of the router network interfaces you want to retrieve information about.

Implementation

Future<BatchGetRouterNetworkInterfaceResponse>
    batchGetRouterNetworkInterface({
  required List<String> arns,
}) async {
  final $query = <String, List<String>>{
    'arns': arns,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/routerNetworkInterfaces',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetRouterNetworkInterfaceResponse.fromJson(response);
}