describeFlowSourceMetadata method

Future<DescribeFlowSourceMetadataResponse> describeFlowSourceMetadata({
  1. required String flowArn,
})

The DescribeFlowSourceMetadata API is used to view information about the flow's source transport stream and programs. This API displays status messages about the flow's source as well as details about the program's video, audio, and other data.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter flowArn : The Amazon Resource Name (ARN) of the flow.

Implementation

Future<DescribeFlowSourceMetadataResponse> describeFlowSourceMetadata({
  required String flowArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/flows/${Uri.encodeComponent(flowArn)}/source-metadata',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeFlowSourceMetadataResponse.fromJson(response);
}