describeGateway method
Displays the details of a gateway. The response includes the gateway Amazon Resource Name (ARN), name, and CIDR blocks, as well as details about the networks.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter gatewayArn :
The ARN of the gateway that you want to describe.
Implementation
Future<DescribeGatewayResponse> describeGateway({
required String gatewayArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/gateways/${Uri.encodeComponent(gatewayArn)}',
exceptionFnMap: _exceptionFns,
);
return DescribeGatewayResponse.fromJson(response);
}