describeReservation method

Future<DescribeReservationResponse> describeReservation({
  1. required String reservationArn,
})

Displays the details of a reservation. The response includes the reservation name, state, start date and time, and the details of the offering that make up the rest of the reservation (such as price, duration, and outbound bandwidth).

May throw BadRequestException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter reservationArn : The Amazon Resource Name (ARN) of the offering.

Implementation

Future<DescribeReservationResponse> describeReservation({
  required String reservationArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/reservations/${Uri.encodeComponent(reservationArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeReservationResponse.fromJson(response);
}