getRouterInputThumbnail method

Future<GetRouterInputThumbnailResponse> getRouterInputThumbnail({
  1. required String arn,
})

Retrieves the thumbnail for a router input in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arn : The Amazon Resource Name (ARN) of the router input that you want to see a thumbnail of.

Implementation

Future<GetRouterInputThumbnailResponse> getRouterInputThumbnail({
  required String arn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/routerInput/${Uri.encodeComponent(arn)}/thumbnail',
    exceptionFnMap: _exceptionFns,
  );
  return GetRouterInputThumbnailResponse.fromJson(response);
}