getRouterNetworkInterface method

Future<GetRouterNetworkInterfaceResponse> getRouterNetworkInterface({
  1. required String arn,
})

Retrieves information about a specific router network interface in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arn : The Amazon Resource Name (ARN) of the router network interface that you want to retrieve information about.

Implementation

Future<GetRouterNetworkInterfaceResponse> getRouterNetworkInterface({
  required String arn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/routerNetworkInterface/${Uri.encodeComponent(arn)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRouterNetworkInterfaceResponse.fromJson(response);
}