listRouterNetworkInterfaces method
Retrieves a list of router network interfaces in AWS Elemental MediaConnect.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerErrorException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter filters :
The filters to apply when retrieving the list of router network
interfaces.
Parameter maxResults :
The maximum number of router network interfaces to return in the response.
Parameter nextToken :
A token used to retrieve the next page of results.
Implementation
Future<ListRouterNetworkInterfacesResponse> listRouterNetworkInterfaces({
List<RouterNetworkInterfaceFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/routerNetworkInterfaces',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRouterNetworkInterfacesResponse.fromJson(response);
}