removeFlowMediaStream method

Future<RemoveFlowMediaStreamResponse> removeFlowMediaStream({
  1. required String flowArn,
  2. required String mediaStreamName,
})

Removes a media stream from a flow. This action is only available if the media stream is not associated with a source or output.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter flowArn : The Amazon Resource Name (ARN) of the flow that you want to update.

Parameter mediaStreamName : The name of the media stream that you want to remove.

Implementation

Future<RemoveFlowMediaStreamResponse> removeFlowMediaStream({
  required String flowArn,
  required String mediaStreamName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v1/flows/${Uri.encodeComponent(flowArn)}/mediaStreams/${Uri.encodeComponent(mediaStreamName)}',
    exceptionFnMap: _exceptionFns,
  );
  return RemoveFlowMediaStreamResponse.fromJson(response);
}