removeFlowSource method
Removes a source from an existing flow. This request can be made only if there is more than one source on the flow.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter flowArn :
The Amazon Resource Name (ARN) of the flow that you want to remove a
source from.
Parameter sourceArn :
The ARN of the source that you want to remove.
Implementation
Future<RemoveFlowSourceResponse> removeFlowSource({
required String flowArn,
required String sourceArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v1/flows/${Uri.encodeComponent(flowArn)}/source/${Uri.encodeComponent(sourceArn)}',
exceptionFnMap: _exceptionFns,
);
return RemoveFlowSourceResponse.fromJson(response);
}