restartRouterInput method

Future<RestartRouterInputResponse> restartRouterInput({
  1. required String arn,
})

Restarts a router input. This operation can be used to recover from errors or refresh the input state.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arn : The Amazon Resource Name (ARN) of the router input that you want to restart.

Implementation

Future<RestartRouterInputResponse> restartRouterInput({
  required String arn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/v1/routerInput/restart/${Uri.encodeComponent(arn)}',
    exceptionFnMap: _exceptionFns,
  );
  return RestartRouterInputResponse.fromJson(response);
}