takeRouterInput method

Future<TakeRouterInputResponse> takeRouterInput({
  1. required String routerOutputArn,
  2. String? routerInputArn,
})

Associates a router input with a router output in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter routerOutputArn : The Amazon Resource Name (ARN) of the router output that you want to associate with a router input.

Parameter routerInputArn : The Amazon Resource Name (ARN) of the router input that you want to associate with a router output.

Implementation

Future<TakeRouterInputResponse> takeRouterInput({
  required String routerOutputArn,
  String? routerInputArn,
}) async {
  final $payload = <String, dynamic>{
    if (routerInputArn != null) 'routerInputArn': routerInputArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v1/routerOutput/takeRouterInput/${Uri.encodeComponent(routerOutputArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return TakeRouterInputResponse.fromJson(response);
}