updateRouterInput method

Future<UpdateRouterInputResponse> updateRouterInput({
  1. required String arn,
  2. RouterInputConfiguration? configuration,
  3. MaintenanceConfiguration? maintenanceConfiguration,
  4. int? maximumBitrate,
  5. String? name,
  6. RoutingScope? routingScope,
  7. RouterInputTier? tier,
  8. RouterInputTransitEncryption? transitEncryption,
})

Updates the configuration of an existing router input in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arn : The Amazon Resource Name (ARN) of the router input that you want to update.

Parameter configuration : The updated configuration settings for the router input. Changing the type of the configuration is not supported.

Parameter maintenanceConfiguration : The updated maintenance configuration settings for the router input, including any changes to preferred maintenance windows and schedules.

Parameter maximumBitrate : The updated maximum bitrate for the router input.

Parameter name : The updated name for the router input.

Parameter routingScope : Specifies whether the router input can be assigned to outputs in different Regions. REGIONAL (default) - can be assigned only to outputs in the same Region. GLOBAL - can be assigned to outputs in any Region.

Parameter tier : The updated tier level for the router input.

Parameter transitEncryption : The updated transit encryption settings for the router input.

Implementation

Future<UpdateRouterInputResponse> updateRouterInput({
  required String arn,
  RouterInputConfiguration? configuration,
  MaintenanceConfiguration? maintenanceConfiguration,
  int? maximumBitrate,
  String? name,
  RoutingScope? routingScope,
  RouterInputTier? tier,
  RouterInputTransitEncryption? transitEncryption,
}) async {
  final $payload = <String, dynamic>{
    if (configuration != null) 'configuration': configuration,
    if (maintenanceConfiguration != null)
      'maintenanceConfiguration': maintenanceConfiguration,
    if (maximumBitrate != null) 'maximumBitrate': maximumBitrate,
    if (name != null) 'name': name,
    if (routingScope != null) 'routingScope': routingScope.value,
    if (tier != null) 'tier': tier.value,
    if (transitEncryption != null) 'transitEncryption': transitEncryption,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/v1/routerInput/${Uri.encodeComponent(arn)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRouterInputResponse.fromJson(response);
}