updateRouterNetworkInterface method
Updates the configuration of an existing router network interface in AWS Elemental MediaConnect.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter arn :
The Amazon Resource Name (ARN) of the router network interface that you
want to update.
Parameter configuration :
The updated configuration settings for the router network interface.
Changing the type of the configuration is not supported.
Parameter name :
The updated name for the router network interface.
Implementation
Future<UpdateRouterNetworkInterfaceResponse> updateRouterNetworkInterface({
required String arn,
RouterNetworkInterfaceConfiguration? configuration,
String? name,
}) async {
final $payload = <String, dynamic>{
if (configuration != null) 'configuration': configuration,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/v1/routerNetworkInterface/${Uri.encodeComponent(arn)}',
exceptionFnMap: _exceptionFns,
);
return UpdateRouterNetworkInterfaceResponse.fromJson(response);
}