updateRouterOutput method

Future<UpdateRouterOutputResponse> updateRouterOutput({
  1. required String arn,
  2. RouterOutputConfiguration? configuration,
  3. MaintenanceConfiguration? maintenanceConfiguration,
  4. int? maximumBitrate,
  5. String? name,
  6. RoutingScope? routingScope,
  7. RouterOutputTier? tier,
})

Updates the configuration of an existing router output in AWS Elemental MediaConnect.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceUnavailableException. May throw TooManyRequestsException.

Parameter arn : The Amazon Resource Name (ARN) of the router output that you want to update.

Parameter configuration : The updated configuration settings for the router output. Changing the type of the configuration is not supported.

Parameter maintenanceConfiguration : The updated maintenance configuration settings for the router output, including any changes to preferred maintenance windows and schedules.

Parameter maximumBitrate : The updated maximum bitrate for the router output.

Parameter name : The updated name for the router output.

Parameter routingScope : Specifies whether the router output can take inputs that are in different Regions. REGIONAL (default) - can only take inputs from same Region. GLOBAL - can take inputs from any Region.

Parameter tier : The updated tier level for the router output.

Implementation

Future<UpdateRouterOutputResponse> updateRouterOutput({
  required String arn,
  RouterOutputConfiguration? configuration,
  MaintenanceConfiguration? maintenanceConfiguration,
  int? maximumBitrate,
  String? name,
  RoutingScope? routingScope,
  RouterOutputTier? tier,
}) async {
  final $payload = <String, dynamic>{
    if (configuration != null) 'configuration': configuration,
    if (maintenanceConfiguration != null)
      'maintenanceConfiguration': maintenanceConfiguration,
    if (maximumBitrate != null) 'maximumBitrate': maximumBitrate,
    if (name != null) 'name': name,
    if (routingScope != null) 'routingScope': routingScope.value,
    if (tier != null) 'tier': tier.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/v1/routerOutput/${Uri.encodeComponent(arn)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRouterOutputResponse.fromJson(response);
}