MediaConvert class

AWS Elemental MediaConvert

Constructors

MediaConvert({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateCertificate({required String arn}) Future<void>
Associates an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS Elemental MediaConvert.
cancelJob({required String id}) Future<void>
Permanently cancel a job. Once you have canceled a job, you can't start it again.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createJob({required String role, required JobSettings settings, AccelerationSettings? accelerationSettings, BillingTagsSource? billingTagsSource, String? clientRequestToken, List<HopDestination>? hopDestinations, String? jobEngineVersion, String? jobTemplate, int? priority, String? queue, SimulateReservedQueue? simulateReservedQueue, StatusUpdateInterval? statusUpdateInterval, Map<String, String>? tags, Map<String, String>? userMetadata}) Future<CreateJobResponse>
Create a new transcoding job. For information about jobs and job settings, see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
createJobTemplate({required String name, required JobTemplateSettings settings, AccelerationSettings? accelerationSettings, String? category, String? description, List<HopDestination>? hopDestinations, int? priority, String? queue, StatusUpdateInterval? statusUpdateInterval, Map<String, String>? tags}) Future<CreateJobTemplateResponse>
Create a new job template. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
createPreset({required String name, required PresetSettings settings, String? category, String? description, Map<String, String>? tags}) Future<CreatePresetResponse>
Create a new preset. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
createQueue({required String name, int? concurrentJobs, String? description, int? maximumConcurrentFeeds, PricingPlan? pricingPlan, ReservationPlanSettings? reservationPlanSettings, QueueStatus? status, Map<String, String>? tags}) Future<CreateQueueResponse>
Create a new transcoding queue. For information about queues, see Working With Queues in the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html
createResourceShare({required String jobId, required String supportCaseId}) Future<void>
Create a new resource share request for MediaConvert resources with AWS Support.
deleteJobTemplate({required String name}) Future<void>
Permanently delete a job template you have created.
deletePolicy() Future<void>
Permanently delete a policy that you created.
deletePreset({required String name}) Future<void>
Permanently delete a preset you have created.
deleteQueue({required String name}) Future<void>
Permanently delete a queue you have created.
describeEndpoints({int? maxResults, DescribeEndpointsMode? mode, String? nextToken}) Future<DescribeEndpointsResponse>
Send a request with an empty body to the regional API endpoint to get your account API endpoint. Note that DescribeEndpoints is no longer required. We recommend that you send your requests directly to the regional endpoint instead.
disassociateCertificate({required String arn}) Future<void>
Removes an association between the Amazon Resource Name (ARN) of an AWS Certificate Manager (ACM) certificate and an AWS Elemental MediaConvert resource.
getJob({required String id}) Future<GetJobResponse>
Retrieve the JSON for a specific transcoding job.
getJobsQueryResults({required String id}) Future<GetJobsQueryResultsResponse>
Retrieve a JSON array of up to twenty of your most recent jobs matched by a jobs query.
getJobTemplate({required String name}) Future<GetJobTemplateResponse>
Retrieve the JSON for a specific job template.
getPolicy() Future<GetPolicyResponse>
Retrieve the JSON for your policy.
getPreset({required String name}) Future<GetPresetResponse>
Retrieve the JSON for a specific preset.
getQueue({required String name}) Future<GetQueueResponse>
Retrieve the JSON for a specific queue.
listJobs({int? maxResults, String? nextToken, Order? order, String? queue, JobStatus? status}) Future<ListJobsResponse>
Retrieve a JSON array of up to twenty of your most recently created jobs. This array includes in-process, completed, and errored jobs. This will return the jobs themselves, not just a list of the jobs. To retrieve the twenty next most recent jobs, use the nextToken string returned with the array.
listJobTemplates({String? category, JobTemplateListBy? listBy, int? maxResults, String? nextToken, Order? order}) Future<ListJobTemplatesResponse>
Retrieve a JSON array of up to twenty of your job templates. This will return the templates themselves, not just a list of them. To retrieve the next twenty templates, use the nextToken string returned with the array
listPresets({String? category, PresetListBy? listBy, int? maxResults, String? nextToken, Order? order}) Future<ListPresetsResponse>
Retrieve a JSON array of up to twenty of your presets. This will return the presets themselves, not just a list of them. To retrieve the next twenty presets, use the nextToken string returned with the array.
listQueues({QueueListBy? listBy, int? maxResults, String? nextToken, Order? order}) Future<ListQueuesResponse>
Retrieve a JSON array of up to twenty of your queues. This will return the queues themselves, not just a list of them. To retrieve the next twenty queues, use the nextToken string returned with the array.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Retrieve the tags for a MediaConvert resource.
listVersions({int? maxResults, String? nextToken}) Future<ListVersionsResponse>
Retrieve a JSON array of all available Job engine versions and the date they expire.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
probe({List<ProbeInputFile>? inputFiles}) Future<ProbeResponse>
Use Probe to obtain detailed information about your input media files. Probe returns a JSON that includes container, codec, frame rate, resolution, track count, audio layout, captions, and more. You can use this information to learn more about your media files, or to help make decisions while automating your transcoding workflow.
putPolicy({required Policy policy}) Future<PutPolicyResponse>
Create or change your policy. For more information about policies, see the user guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
searchJobs({String? inputFile, int? maxResults, String? nextToken, Order? order, String? queue, JobStatus? status}) Future<SearchJobsResponse>
Retrieve a JSON array that includes job details for up to twenty of your most recent jobs. Optionally filter results further according to input file, queue, or status. To retrieve the twenty next most recent jobs, use the nextToken string returned with the array.
startJobsQuery({List<JobsQueryFilter>? filterList, int? maxResults, String? nextToken, Order? order}) Future<StartJobsQueryResponse>
Start an asynchronous jobs query using the provided filters. To receive the list of jobs that match your query, call the GetJobsQueryResults API using the query ID returned by this API.
tagResource({required String arn, required Map<String, String> tags}) Future<void>
Add tags to a MediaConvert queue, preset, job, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-mediaconvert-resources.html.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, List<String>? tagKeys}) Future<void>
Remove tags from a MediaConvert queue, preset, job, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-mediaconvert-resources.html.
updateJobTemplate({required String name, AccelerationSettings? accelerationSettings, String? category, String? description, List<HopDestination>? hopDestinations, int? priority, String? queue, JobTemplateSettings? settings, StatusUpdateInterval? statusUpdateInterval}) Future<UpdateJobTemplateResponse>
Modify one of your existing job templates.
updatePreset({required String name, String? category, String? description, PresetSettings? settings}) Future<UpdatePresetResponse>
Modify one of your existing presets.
updateQueue({required String name, int? concurrentJobs, String? description, int? maximumConcurrentFeeds, ReservationPlanSettings? reservationPlanSettings, QueueStatus? status}) Future<UpdateQueueResponse>
Modify one of your existing queues.

Operators

operator ==(Object other) bool
The equality operator.
inherited