createJob method

Future<CreateJobResponse> createJob({
  1. required String role,
  2. required JobSettings settings,
  3. AccelerationSettings? accelerationSettings,
  4. BillingTagsSource? billingTagsSource,
  5. String? clientRequestToken,
  6. List<HopDestination>? hopDestinations,
  7. String? jobEngineVersion,
  8. String? jobTemplate,
  9. int? priority,
  10. String? queue,
  11. SimulateReservedQueue? simulateReservedQueue,
  12. StatusUpdateInterval? statusUpdateInterval,
  13. Map<String, String>? tags,
  14. Map<String, String>? userMetadata,
})

Create a new transcoding job. For information about jobs and job settings, see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceQuotaExceededException. May throw TooManyRequestsException.

Parameter role : Required. The IAM role you use for creating this job. For details about permissions, see the User Guide topic at the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/iam-role.html.

Parameter settings : JobSettings contains all the transcode settings for a job.

Parameter accelerationSettings : Optional. Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide.

Parameter billingTagsSource : Optionally choose a Billing tags source that AWS Billing and Cost Management will use to display tags for individual output costs on any billing report that you set up. Leave blank to use the default value, Job.

Parameter clientRequestToken : Prevent duplicate jobs from being created and ensure idempotency for your requests. A client request token can be any string that includes up to 64 ASCII characters. If you reuse a client request token within one minute of a successful request, the API returns the job details of the original request instead. For more information see https://docs.aws.amazon.com/mediaconvert/latest/apireference/idempotency.html.

Parameter hopDestinations : Optional. Use queue hopping to avoid overly long waits in the backlog of the queue that you submit your job to. Specify an alternate queue and the maximum time that your job will wait in the initial queue before hopping. For more information about this feature, see the AWS Elemental MediaConvert User Guide.

Parameter jobEngineVersion : Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions represent periodically grouped MediaConvert releases with new features, updates, improvements, and fixes. Job engine versions are in a YYYY-MM-DD format. Note that the Job engine version feature is not publicly available at this time. To request access, contact AWS support.

Parameter jobTemplate : Optional. When you create a job, you can either specify a job template or specify the transcoding settings individually.

Parameter priority : Optional. Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don't specify a priority, the service uses the default value 0.

Parameter queue : Optional. When you create a job, you can specify a queue to send it to. If you don't specify, the job will go to the default queue. For more about queues, see the User Guide topic at https://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html.

Parameter simulateReservedQueue : Optional. Enable this setting when you run a test job to estimate how many reserved transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your job from an on-demand queue with similar performance to what you will see with one RTS in a reserved queue. This setting is disabled by default.

Parameter statusUpdateInterval : Optional. Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.

Parameter tags : Optional. The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key. Use standard AWS tags on your job for automatic integration with AWS services and for custom integrations and workflows.

Parameter userMetadata : Optional. User-defined metadata that you want to associate with an MediaConvert job. You specify metadata in key/value pairs. Use only for existing integrations or workflows that rely on job metadata tags. Otherwise, we recommend that you use standard AWS tags.

Implementation

Future<CreateJobResponse> createJob({
  required String role,
  required JobSettings settings,
  AccelerationSettings? accelerationSettings,
  BillingTagsSource? billingTagsSource,
  String? clientRequestToken,
  List<HopDestination>? hopDestinations,
  String? jobEngineVersion,
  String? jobTemplate,
  int? priority,
  String? queue,
  SimulateReservedQueue? simulateReservedQueue,
  StatusUpdateInterval? statusUpdateInterval,
  Map<String, String>? tags,
  Map<String, String>? userMetadata,
}) async {
  _s.validateNumRange(
    'priority',
    priority,
    -50,
    50,
  );
  final $payload = <String, dynamic>{
    'role': role,
    'settings': settings,
    if (accelerationSettings != null)
      'accelerationSettings': accelerationSettings,
    if (billingTagsSource != null)
      'billingTagsSource': billingTagsSource.value,
    'clientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
    if (hopDestinations != null) 'hopDestinations': hopDestinations,
    if (jobEngineVersion != null) 'jobEngineVersion': jobEngineVersion,
    if (jobTemplate != null) 'jobTemplate': jobTemplate,
    if (priority != null) 'priority': priority,
    if (queue != null) 'queue': queue,
    if (simulateReservedQueue != null)
      'simulateReservedQueue': simulateReservedQueue.value,
    if (statusUpdateInterval != null)
      'statusUpdateInterval': statusUpdateInterval.value,
    if (tags != null) 'tags': tags,
    if (userMetadata != null) 'userMetadata': userMetadata,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2017-08-29/jobs',
    exceptionFnMap: _exceptionFns,
  );
  return CreateJobResponse.fromJson(response);
}