listVersions method
Retrieve a JSON array of all available Job engine versions and the date they expire.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
Parameter maxResults :
Optional. Number of valid Job engine versions, up to twenty, that will be
returned at one time.
Parameter nextToken :
Optional. Use this string, provided with the response to a previous
request, to request the next batch of Job engine versions.
Implementation
Future<ListVersionsResponse> listVersions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2017-08-29/versions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListVersionsResponse.fromJson(response);
}