probe method
Use Probe to obtain detailed information about your input media files. Probe returns a JSON that includes container, codec, frame rate, resolution, track count, audio layout, captions, and more. You can use this information to learn more about your media files, or to help make decisions while automating your transcoding workflow.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
Parameter inputFiles :
Specify a media file to probe.
Implementation
Future<ProbeResponse> probe({
List<ProbeInputFile>? inputFiles,
}) async {
final $payload = <String, dynamic>{
if (inputFiles != null) 'inputFiles': inputFiles,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2017-08-29/probe',
exceptionFnMap: _exceptionFns,
);
return ProbeResponse.fromJson(response);
}