putPolicy method

Future<PutPolicyResponse> putPolicy({
  1. required Policy policy,
})

Create or change your policy. For more information about policies, see the user guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw ServiceQuotaExceededException. May throw TooManyRequestsException.

Parameter policy : A policy configures behavior that you allow or disallow for your account. For information about MediaConvert policies, see the user guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

Implementation

Future<PutPolicyResponse> putPolicy({
  required Policy policy,
}) async {
  final $payload = <String, dynamic>{
    'policy': policy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/2017-08-29/policy',
    exceptionFnMap: _exceptionFns,
  );
  return PutPolicyResponse.fromJson(response);
}