untagResource method
Remove tags from a MediaConvert queue, preset, job, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-mediaconvert-resources.html.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
Parameter arn :
The Amazon Resource Name (ARN) of the resource that you want to remove
tags from. To get the ARN, send a GET request with the resource name.
Parameter tagKeys :
The keys of the tags that you want to remove from the resource.
Implementation
Future<void> untagResource({
required String arn,
List<String>? tagKeys,
}) async {
final $payload = <String, dynamic>{
if (tagKeys != null) 'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/2017-08-29/tags/${Uri.encodeComponent(arn)}',
exceptionFnMap: _exceptionFns,
);
}