updatePreset method
Modify one of your existing presets.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
Parameter name :
The name of the preset you are modifying.
Parameter category :
The new category for the preset, if you are changing it.
Parameter description :
The new description for the preset, if you are changing it.
Parameter settings :
Settings for preset
Implementation
Future<UpdatePresetResponse> updatePreset({
required String name,
String? category,
String? description,
PresetSettings? settings,
}) async {
final $payload = <String, dynamic>{
if (category != null) 'category': category,
if (description != null) 'description': description,
if (settings != null) 'settings': settings,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/2017-08-29/presets/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return UpdatePresetResponse.fromJson(response);
}