MediaLive class

API for AWS Elemental MediaLive

Constructors

MediaLive({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInputDeviceTransfer({required String inputDeviceId}) Future<void>
Accept an incoming input device transfer. The ownership of the device will transfer to your AWS account.
batchDelete({List<String>? channelIds, List<String>? inputIds, List<String>? inputSecurityGroupIds, List<String>? multiplexIds}) Future<BatchDeleteResponse>
Starts delete of resources.
batchStart({List<String>? channelIds, List<String>? multiplexIds}) Future<BatchStartResponse>
Starts existing resources
batchStop({List<String>? channelIds, List<String>? multiplexIds}) Future<BatchStopResponse>
Stops running resources
batchUpdateSchedule({required String channelId, BatchScheduleActionCreateRequest? creates, BatchScheduleActionDeleteRequest? deletes}) Future<BatchUpdateScheduleResponse>
Update a channel schedule
cancelInputDeviceTransfer({required String inputDeviceId}) Future<void>
Cancel an input device transfer that you have requested.
claimDevice({String? id}) Future<void>
Send a request to claim an AWS Elemental device that you have purchased from a third-party vendor. After the request succeeds, you will own the device.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createChannel({AnywhereSettings? anywhereSettings, CdiInputSpecification? cdiInputSpecification, ChannelClass? channelClass, ChannelEngineVersionRequest? channelEngineVersion, List<String>? channelSecurityGroups, List<OutputDestination>? destinations, bool? dryRun, EncoderSettings? encoderSettings, InferenceSettings? inferenceSettings, List<InputAttachment>? inputAttachments, InputSpecification? inputSpecification, LinkedChannelSettings? linkedChannelSettings, LogLevel? logLevel, MaintenanceCreateSettings? maintenance, String? name, String? requestId, String? reserved, String? roleArn, Map<String, String>? tags, VpcOutputSettings? vpc}) Future<CreateChannelResponse>
Creates a new channel
createChannelPlacementGroup({required String clusterId, String? name, List<String>? nodes, String? requestId, Map<String, String>? tags}) Future<CreateChannelPlacementGroupResponse>
Create a ChannelPlacementGroup in the specified Cluster. As part of the create operation, you specify the Nodes to attach the group to.After you create a ChannelPlacementGroup, you add Channels to the group (you do this by modifying the Channels to add them to a specific group). You now have an association of Channels to ChannelPlacementGroup, and ChannelPlacementGroup to Nodes. This association means that all the Channels in the group are able to run on any of the Nodes associated with the group.
createCloudWatchAlarmTemplate({required CloudWatchAlarmTemplateComparisonOperator comparisonOperator, required int evaluationPeriods, required String groupIdentifier, required String metricName, required String name, required int period, required CloudWatchAlarmTemplateStatistic statistic, required CloudWatchAlarmTemplateTargetResourceType targetResourceType, required double threshold, required CloudWatchAlarmTemplateTreatMissingData treatMissingData, int? datapointsToAlarm, String? description, String? requestId, Map<String, String>? tags}) Future<CreateCloudWatchAlarmTemplateResponse>
Creates a cloudwatch alarm template to dynamically generate cloudwatch metric alarms on targeted resource types.
createCloudWatchAlarmTemplateGroup({required String name, String? description, String? requestId, Map<String, String>? tags}) Future<CreateCloudWatchAlarmTemplateGroupResponse>
Creates a cloudwatch alarm template group to group your cloudwatch alarm templates and to attach to signal maps for dynamically creating alarms.
createCluster({ClusterType? clusterType, String? instanceRoleArn, String? name, ClusterNetworkSettingsCreateRequest? networkSettings, String? requestId, Map<String, String>? tags}) Future<CreateClusterResponse>
Create a new Cluster.
createEventBridgeRuleTemplate({required EventBridgeRuleTemplateEventType eventType, required String groupIdentifier, required String name, String? description, List<EventBridgeRuleTemplateTarget>? eventTargets, String? requestId, Map<String, String>? tags}) Future<CreateEventBridgeRuleTemplateResponse>
Creates an eventbridge rule template to monitor events and send notifications to your targeted resources.
createEventBridgeRuleTemplateGroup({required String name, String? description, String? requestId, Map<String, String>? tags}) Future<CreateEventBridgeRuleTemplateGroupResponse>
Creates an eventbridge rule template group to group your eventbridge rule templates and to attach to signal maps for dynamically creating notification rules.
createInput({List<InputDestinationRequest>? destinations, List<InputDeviceSettings>? inputDevices, InputNetworkLocation? inputNetworkLocation, List<String>? inputSecurityGroups, List<MediaConnectFlowRequest>? mediaConnectFlows, MulticastSettingsCreateRequest? multicastSettings, String? name, String? requestId, String? roleArn, RouterSettings? routerSettings, List<String>? sdiSources, Smpte2110ReceiverGroupSettings? smpte2110ReceiverGroupSettings, List<InputSourceRequest>? sources, SrtSettingsRequest? srtSettings, Map<String, String>? tags, InputType? type, InputVpcRequest? vpc}) Future<CreateInputResponse>
Create an input
createInputSecurityGroup({Map<String, String>? tags, List<InputWhitelistRuleCidr>? whitelistRules}) Future<CreateInputSecurityGroupResponse>
Creates a Input Security Group
createMultiplex({required List<String> availabilityZones, required MultiplexSettings multiplexSettings, required String name, String? requestId, Map<String, String>? tags}) Future<CreateMultiplexResponse>
Create a new multiplex.
createMultiplexProgram({required String multiplexId, required MultiplexProgramSettings multiplexProgramSettings, required String programName, String? requestId}) Future<CreateMultiplexProgramResponse>
Create a new program in the multiplex.
createNetwork({List<IpPoolCreateRequest>? ipPools, String? name, String? requestId, List<RouteCreateRequest>? routes, Map<String, String>? tags}) Future<CreateNetworkResponse>
Create as many Networks as you need. You will associate one or more Clusters with each Network.Each Network provides MediaLive Anywhere with required information about the network in your organization that you are using for video encoding using MediaLive.
createNode({required String clusterId, String? name, List<NodeInterfaceMappingCreateRequest>? nodeInterfaceMappings, String? requestId, NodeRole? role, Map<String, String>? tags}) Future<CreateNodeResponse>
Create a Node in the specified Cluster. You can also create Nodes using the CreateNodeRegistrationScript. Note that you can't move a Node to another Cluster.
createNodeRegistrationScript({required String clusterId, String? id, String? name, List<NodeInterfaceMapping>? nodeInterfaceMappings, String? requestId, NodeRole? role}) Future<CreateNodeRegistrationScriptResponse>
Create the Register Node script for all the nodes intended for a specific Cluster. You will then run the script on each hardware unit that is intended for that Cluster. The script creates a Node in the specified Cluster. It then binds the Node to this hardware unit, and activates the node hardware for use with MediaLive Anywhere.
createPartnerInput({required String inputId, String? requestId, Map<String, String>? tags}) Future<CreatePartnerInputResponse>
Create a partner input
createSdiSource({SdiSourceMode? mode, String? name, String? requestId, Map<String, String>? tags, SdiSourceType? type}) Future<CreateSdiSourceResponse>
Create an SdiSource for each video source that uses the SDI protocol. You will reference the SdiSource when you create an SDI input in MediaLive. You will also reference it in an SdiSourceMapping, in order to create a connection between the logical SdiSource and the physical SDI card and port that the physical SDI source uses.
createSignalMap({required String discoveryEntryPointArn, required String name, List<String>? cloudWatchAlarmTemplateGroupIdentifiers, String? description, List<String>? eventBridgeRuleTemplateGroupIdentifiers, String? requestId, Map<String, String>? tags}) Future<CreateSignalMapResponse>
Initiates the creation of a new signal map. Will discover a new mediaResourceMap based on the provided discoveryEntryPointArn.
createTags({required String resourceArn, Map<String, String>? tags}) Future<void>
Create tags for a resource
deleteChannel({required String channelId}) Future<DeleteChannelResponse>
Starts deletion of channel. The associated outputs are also deleted.
deleteChannelPlacementGroup({required String channelPlacementGroupId, required String clusterId}) Future<DeleteChannelPlacementGroupResponse>
Delete the specified ChannelPlacementGroup that exists in the specified Cluster.
deleteCloudWatchAlarmTemplate({required String identifier}) Future<void>
Deletes a cloudwatch alarm template.
deleteCloudWatchAlarmTemplateGroup({required String identifier}) Future<void>
Deletes a cloudwatch alarm template group. You must detach this group from all signal maps and ensure its existing templates are moved to another group or deleted.
deleteCluster({required String clusterId}) Future<DeleteClusterResponse>
Delete a Cluster. The Cluster must be idle.
deleteEventBridgeRuleTemplate({required String identifier}) Future<void>
Deletes an eventbridge rule template.
deleteEventBridgeRuleTemplateGroup({required String identifier}) Future<void>
Deletes an eventbridge rule template group. You must detach this group from all signal maps and ensure its existing templates are moved to another group or deleted.
deleteInput({required String inputId}) Future<void>
Deletes the input end point
deleteInputSecurityGroup({required String inputSecurityGroupId}) Future<void>
Deletes an Input Security Group
deleteMultiplex({required String multiplexId}) Future<DeleteMultiplexResponse>
Delete a multiplex. The multiplex must be idle.
deleteMultiplexProgram({required String multiplexId, required String programName}) Future<DeleteMultiplexProgramResponse>
Delete a program from a multiplex.
deleteNetwork({required String networkId}) Future<DeleteNetworkResponse>
Delete a Network. The Network must have no resources associated with it.
deleteNode({required String clusterId, required String nodeId}) Future<DeleteNodeResponse>
Delete a Node. The Node must be IDLE.
deleteReservation({required String reservationId}) Future<DeleteReservationResponse>
Delete an expired reservation.
deleteSchedule({required String channelId}) Future<void>
Delete all schedule actions on a channel.
deleteSdiSource({required String sdiSourceId}) Future<DeleteSdiSourceResponse>
Delete an SdiSource. The SdiSource must not be part of any SidSourceMapping and must not be attached to any input.
deleteSignalMap({required String identifier}) Future<void>
Deletes the specified signal map.
deleteTags({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags for a resource
describeAccountConfiguration() Future<DescribeAccountConfigurationResponse>
Describe account configuration
describeChannel({required String channelId}) Future<DescribeChannelResponse>
Gets details about a channel
describeChannelPlacementGroup({required String channelPlacementGroupId, required String clusterId}) Future<DescribeChannelPlacementGroupResponse>
Get details about a ChannelPlacementGroup.
describeCluster({required String clusterId}) Future<DescribeClusterResponse>
Get details about a Cluster.
describeInput({required String inputId}) Future<DescribeInputResponse>
Produces details about an input
describeInputDevice({required String inputDeviceId}) Future<DescribeInputDeviceResponse>
Gets the details for the input device
describeInputDeviceThumbnail({required AcceptHeader accept, required String inputDeviceId}) Future<DescribeInputDeviceThumbnailResponse>
Get the latest thumbnail data for the input device.
describeInputSecurityGroup({required String inputSecurityGroupId}) Future<DescribeInputSecurityGroupResponse>
Produces a summary of an Input Security Group
describeMultiplex({required String multiplexId}) Future<DescribeMultiplexResponse>
Gets details about a multiplex.
describeMultiplexProgram({required String multiplexId, required String programName}) Future<DescribeMultiplexProgramResponse>
Get the details for a program in a multiplex.
describeNetwork({required String networkId}) Future<DescribeNetworkResponse>
Get details about a Network.
describeNode({required String clusterId, required String nodeId}) Future<DescribeNodeResponse>
Get details about a Node in the specified Cluster.
describeOffering({required String offeringId}) Future<DescribeOfferingResponse>
Get details for an offering.
describeReservation({required String reservationId}) Future<DescribeReservationResponse>
Get details for a reservation.
describeSchedule({required String channelId, int? maxResults, String? nextToken}) Future<DescribeScheduleResponse>
Get a channel schedule
describeSdiSource({required String sdiSourceId}) Future<DescribeSdiSourceResponse>
Gets details about a SdiSource.
describeThumbnails({required String channelId, required String pipelineId, required String thumbnailType}) Future<DescribeThumbnailsResponse>
Describe the latest thumbnails data.
getCloudWatchAlarmTemplate({required String identifier}) Future<GetCloudWatchAlarmTemplateResponse>
Retrieves the specified cloudwatch alarm template.
getCloudWatchAlarmTemplateGroup({required String identifier}) Future<GetCloudWatchAlarmTemplateGroupResponse>
Retrieves the specified cloudwatch alarm template group.
getEventBridgeRuleTemplate({required String identifier}) Future<GetEventBridgeRuleTemplateResponse>
Retrieves the specified eventbridge rule template.
getEventBridgeRuleTemplateGroup({required String identifier}) Future<GetEventBridgeRuleTemplateGroupResponse>
Retrieves the specified eventbridge rule template group.
getSignalMap({required String identifier}) Future<GetSignalMapResponse>
Retrieves the specified signal map.
listAlerts({required String channelId, int? maxResults, String? nextToken, String? stateFilter}) Future<ListAlertsResponse>
List the alerts for a channel with optional filtering based on alert state.
listChannelPlacementGroups({required String clusterId, int? maxResults, String? nextToken}) Future<ListChannelPlacementGroupsResponse>
Retrieve the list of ChannelPlacementGroups in the specified Cluster.
listChannels({int? maxResults, String? nextToken}) Future<ListChannelsResponse>
Produces list of channels that have been created
listCloudWatchAlarmTemplateGroups({int? maxResults, String? nextToken, String? scope, String? signalMapIdentifier}) Future<ListCloudWatchAlarmTemplateGroupsResponse>
Lists cloudwatch alarm template groups.
listCloudWatchAlarmTemplates({String? groupIdentifier, int? maxResults, String? nextToken, String? scope, String? signalMapIdentifier}) Future<ListCloudWatchAlarmTemplatesResponse>
Lists cloudwatch alarm templates.
listClusterAlerts({required String clusterId, int? maxResults, String? nextToken, String? stateFilter}) Future<ListClusterAlertsResponse>
List the alerts for a cluster with optional filtering based on alert state.
listClusters({int? maxResults, String? nextToken}) Future<ListClustersResponse>
Retrieve the list of Clusters.
listEventBridgeRuleTemplateGroups({int? maxResults, String? nextToken, String? signalMapIdentifier}) Future<ListEventBridgeRuleTemplateGroupsResponse>
Lists eventbridge rule template groups.
listEventBridgeRuleTemplates({String? groupIdentifier, int? maxResults, String? nextToken, String? signalMapIdentifier}) Future<ListEventBridgeRuleTemplatesResponse>
Lists eventbridge rule templates.
listInputDevices({int? maxResults, String? nextToken}) Future<ListInputDevicesResponse>
List input devices
listInputDeviceTransfers({required String transferType, int? maxResults, String? nextToken}) Future<ListInputDeviceTransfersResponse>
List input devices that are currently being transferred. List input devices that you are transferring from your AWS account or input devices that another AWS account is transferring to you.
listInputs({int? maxResults, String? nextToken}) Future<ListInputsResponse>
Produces list of inputs that have been created
listInputSecurityGroups({int? maxResults, String? nextToken}) Future<ListInputSecurityGroupsResponse>
Produces a list of Input Security Groups for an account
listMultiplexAlerts({required String multiplexId, int? maxResults, String? nextToken, String? stateFilter}) Future<ListMultiplexAlertsResponse>
List the alerts for a multiplex with optional filtering based on alert state.
listMultiplexes({int? maxResults, String? nextToken}) Future<ListMultiplexesResponse>
Retrieve a list of the existing multiplexes.
listMultiplexPrograms({required String multiplexId, int? maxResults, String? nextToken}) Future<ListMultiplexProgramsResponse>
List the programs that currently exist for a specific multiplex.
listNetworks({int? maxResults, String? nextToken}) Future<ListNetworksResponse>
Retrieve the list of Networks.
listNodes({required String clusterId, int? maxResults, String? nextToken}) Future<ListNodesResponse>
Retrieve the list of Nodes.
listOfferings({String? channelClass, String? channelConfiguration, String? codec, String? duration, int? maxResults, String? maximumBitrate, String? maximumFramerate, String? nextToken, String? resolution, String? resourceType, String? specialFeature, String? videoQuality}) Future<ListOfferingsResponse>
List offerings available for purchase.
listReservations({String? channelClass, String? codec, int? maxResults, String? maximumBitrate, String? maximumFramerate, String? nextToken, String? resolution, String? resourceType, String? specialFeature, String? videoQuality}) Future<ListReservationsResponse>
List purchased reservations.
listSdiSources({int? maxResults, String? nextToken}) Future<ListSdiSourcesResponse>
List all the SdiSources in the AWS account.
listSignalMaps({String? cloudWatchAlarmTemplateGroupIdentifier, String? eventBridgeRuleTemplateGroupIdentifier, int? maxResults, String? nextToken}) Future<ListSignalMapsResponse>
Lists signal maps.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Produces list of tags that have been created for a resource
listVersions() Future<ListVersionsResponse>
Retrieves an array of all the encoder engine versions that are available in this AWS account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchaseOffering({required int count, required String offeringId, String? name, RenewalSettings? renewalSettings, String? requestId, String? start, Map<String, String>? tags}) Future<PurchaseOfferingResponse>
Purchase an offering and create a reservation.
rebootInputDevice({required String inputDeviceId, RebootInputDeviceForce? force}) Future<void>
Send a reboot command to the specified input device. The device will begin rebooting within a few seconds of sending the command. When the reboot is complete, the device’s connection status will change to connected.
rejectInputDeviceTransfer({required String inputDeviceId}) Future<void>
Reject the transfer of the specified input device to your AWS account.
restartChannelPipelines({required String channelId, List<ChannelPipelineIdToRestart>? pipelineIds}) Future<RestartChannelPipelinesResponse>
Restart pipelines in one channel that is currently running.
startChannel({required String channelId}) Future<StartChannelResponse>
Starts an existing channel
startDeleteMonitorDeployment({required String identifier}) Future<StartDeleteMonitorDeploymentResponse>
Initiates a deployment to delete the monitor of the specified signal map.
startInputDevice({required String inputDeviceId}) Future<void>
Start an input device that is attached to a MediaConnect flow. (There is no need to start a device that is attached to a MediaLive input; MediaLive starts the device when the channel starts.)
startInputDeviceMaintenanceWindow({required String inputDeviceId}) Future<void>
Start a maintenance window for the specified input device. Starting a maintenance window will give the device up to two hours to install software. If the device was streaming prior to the maintenance, it will resume streaming when the software is fully installed. Devices automatically install updates while they are powered on and their MediaLive channels are stopped. A maintenance window allows you to update a device without having to stop MediaLive channels that use the device. The device must remain powered on and connected to the internet for the duration of the maintenance.
startMonitorDeployment({required String identifier, bool? dryRun}) Future<StartMonitorDeploymentResponse>
Initiates a deployment to deploy the latest monitor of the specified signal map.
startMultiplex({required String multiplexId}) Future<StartMultiplexResponse>
Start (run) the multiplex. Starting the multiplex does not start the channels. You must explicitly start each channel.
startUpdateSignalMap({required String identifier, List<String>? cloudWatchAlarmTemplateGroupIdentifiers, String? description, String? discoveryEntryPointArn, List<String>? eventBridgeRuleTemplateGroupIdentifiers, bool? forceRediscovery, String? name}) Future<StartUpdateSignalMapResponse>
Initiates an update for the specified signal map. Will discover a new signal map if a changed discoveryEntryPointArn is provided.
stopChannel({required String channelId}) Future<StopChannelResponse>
Stops a running channel
stopInputDevice({required String inputDeviceId}) Future<void>
Stop an input device that is attached to a MediaConnect flow. (There is no need to stop a device that is attached to a MediaLive input; MediaLive automatically stops the device when the channel stops.)
stopMultiplex({required String multiplexId}) Future<StopMultiplexResponse>
Stops a running multiplex. If the multiplex isn't running, this action has no effect.
toString() String
A string representation of this object.
inherited
transferInputDevice({required String inputDeviceId, String? targetCustomerId, String? targetRegion, String? transferMessage}) Future<void>
Start an input device transfer to another AWS account. After you make the request, the other account must accept or reject the transfer.
updateAccountConfiguration({AccountConfiguration? accountConfiguration}) Future<UpdateAccountConfigurationResponse>
Update account configuration
updateChannel({required String channelId, AnywhereSettings? anywhereSettings, CdiInputSpecification? cdiInputSpecification, ChannelEngineVersionRequest? channelEngineVersion, List<String>? channelSecurityGroups, List<OutputDestination>? destinations, bool? dryRun, EncoderSettings? encoderSettings, InferenceSettings? inferenceSettings, List<InputAttachment>? inputAttachments, InputSpecification? inputSpecification, LinkedChannelSettings? linkedChannelSettings, LogLevel? logLevel, MaintenanceUpdateSettings? maintenance, String? name, String? roleArn, SpecialRouterSettings? specialRouterSettings}) Future<UpdateChannelResponse>
Updates a channel.
updateChannelClass({required ChannelClass channelClass, required String channelId, List<OutputDestination>? destinations}) Future<UpdateChannelClassResponse>
Changes the class of the channel.
updateChannelPlacementGroup({required String channelPlacementGroupId, required String clusterId, String? name, List<String>? nodes}) Future<UpdateChannelPlacementGroupResponse>
Change the settings for a ChannelPlacementGroup.
updateCloudWatchAlarmTemplate({required String identifier, CloudWatchAlarmTemplateComparisonOperator? comparisonOperator, int? datapointsToAlarm, String? description, int? evaluationPeriods, String? groupIdentifier, String? metricName, String? name, int? period, CloudWatchAlarmTemplateStatistic? statistic, CloudWatchAlarmTemplateTargetResourceType? targetResourceType, double? threshold, CloudWatchAlarmTemplateTreatMissingData? treatMissingData}) Future<UpdateCloudWatchAlarmTemplateResponse>
Updates the specified cloudwatch alarm template.
updateCloudWatchAlarmTemplateGroup({required String identifier, String? description}) Future<UpdateCloudWatchAlarmTemplateGroupResponse>
Updates the specified cloudwatch alarm template group.
updateCluster({required String clusterId, String? name, ClusterNetworkSettingsUpdateRequest? networkSettings}) Future<UpdateClusterResponse>
Change the settings for a Cluster.
updateEventBridgeRuleTemplate({required String identifier, String? description, List<EventBridgeRuleTemplateTarget>? eventTargets, EventBridgeRuleTemplateEventType? eventType, String? groupIdentifier, String? name}) Future<UpdateEventBridgeRuleTemplateResponse>
Updates the specified eventbridge rule template.
updateEventBridgeRuleTemplateGroup({required String identifier, String? description}) Future<UpdateEventBridgeRuleTemplateGroupResponse>
Updates the specified eventbridge rule template group.
updateInput({required String inputId, List<InputDestinationRequest>? destinations, List<InputDeviceRequest>? inputDevices, List<String>? inputSecurityGroups, List<MediaConnectFlowRequest>? mediaConnectFlows, MulticastSettingsUpdateRequest? multicastSettings, String? name, String? roleArn, List<String>? sdiSources, Smpte2110ReceiverGroupSettings? smpte2110ReceiverGroupSettings, List<InputSourceRequest>? sources, SpecialRouterSettings? specialRouterSettings, SrtSettingsRequest? srtSettings}) Future<UpdateInputResponse>
Updates an input.
updateInputDevice({required String inputDeviceId, String? availabilityZone, InputDeviceConfigurableSettings? hdDeviceSettings, String? name, InputDeviceConfigurableSettings? uhdDeviceSettings}) Future<UpdateInputDeviceResponse>
Updates the parameters for the input device.
updateInputSecurityGroup({required String inputSecurityGroupId, Map<String, String>? tags, List<InputWhitelistRuleCidr>? whitelistRules}) Future<UpdateInputSecurityGroupResponse>
Update an Input Security Group's Whilelists.
updateMultiplex({required String multiplexId, MultiplexSettings? multiplexSettings, String? name, Map<String, MultiplexProgramPacketIdentifiersMap>? packetIdentifiersMapping}) Future<UpdateMultiplexResponse>
Updates a multiplex.
updateMultiplexProgram({required String multiplexId, required String programName, MultiplexProgramSettings? multiplexProgramSettings}) Future<UpdateMultiplexProgramResponse>
Update a program in a multiplex.
updateNetwork({required String networkId, List<IpPoolUpdateRequest>? ipPools, String? name, List<RouteUpdateRequest>? routes}) Future<UpdateNetworkResponse>
Change the settings for a Network.
updateNode({required String clusterId, required String nodeId, String? name, NodeRole? role, List<SdiSourceMappingUpdateRequest>? sdiSourceMappings}) Future<UpdateNodeResponse>
Change the settings for a Node.
updateNodeState({required String clusterId, required String nodeId, UpdateNodeStateShape? state}) Future<UpdateNodeStateResponse>
Update the state of a node.
updateReservation({required String reservationId, String? name, RenewalSettings? renewalSettings}) Future<UpdateReservationResponse>
Update reservation.
updateSdiSource({required String sdiSourceId, SdiSourceMode? mode, String? name, SdiSourceType? type}) Future<UpdateSdiSourceResponse>
Change some of the settings in an SdiSource.

Operators

operator ==(Object other) bool
The equality operator.
inherited