createNetwork method
Create as many Networks as you need. You will associate one or more Clusters with each Network.Each Network provides MediaLive Anywhere with required information about the network in your organization that you are using for video encoding using MediaLive.
May throw BadGatewayException.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw TooManyRequestsException.
Parameter ipPools :
An array of IpPoolCreateRequests that identify a collection of IP
addresses in your network that you want to reserve for use in MediaLive
Anywhere. MediaLiveAnywhere uses these IP addresses for Push inputs (in
both Bridge and NATnetworks) and for output destinations (only in Bridge
networks). EachIpPoolUpdateRequest specifies one CIDR block.
Parameter name :
Specify a name that is unique in the AWS account. We recommend that you
assign a name that hints at the type of traffic on the network. Names are
case-sensitive.
Parameter requestId :
An ID that you assign to a create request. This ID ensures idempotency
when creating resources.
Parameter routes :
An array of routes that MediaLive Anywhere needs to know about in order to
route encoding traffic.
Parameter tags :
A collection of key-value pairs.
Implementation
Future<CreateNetworkResponse> createNetwork({
List<IpPoolCreateRequest>? ipPools,
String? name,
String? requestId,
List<RouteCreateRequest>? routes,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
if (ipPools != null) 'ipPools': ipPools,
if (name != null) 'name': name,
'requestId': requestId ?? _s.generateIdempotencyToken(),
if (routes != null) 'routes': routes,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/prod/networks',
exceptionFnMap: _exceptionFns,
);
return CreateNetworkResponse.fromJson(response);
}