createPartnerInput method

Future<CreatePartnerInputResponse> createPartnerInput({
  1. required String inputId,
  2. String? requestId,
  3. Map<String, String>? tags,
})

Create a partner input

May throw BadGatewayException. May throw BadRequestException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw TooManyRequestsException.

Parameter inputId : Unique ID of the input.

Parameter requestId : Unique identifier of the request to ensure the request is handled exactly once in case of retries.

Parameter tags : A collection of key-value pairs.

Implementation

Future<CreatePartnerInputResponse> createPartnerInput({
  required String inputId,
  String? requestId,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'requestId': requestId ?? _s.generateIdempotencyToken(),
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/prod/inputs/${Uri.encodeComponent(inputId)}/partners',
    exceptionFnMap: _exceptionFns,
  );
  return CreatePartnerInputResponse.fromJson(response);
}