createSdiSource method

Future<CreateSdiSourceResponse> createSdiSource({
  1. SdiSourceMode? mode,
  2. String? name,
  3. String? requestId,
  4. Map<String, String>? tags,
  5. SdiSourceType? type,
})

Create an SdiSource for each video source that uses the SDI protocol. You will reference the SdiSource when you create an SDI input in MediaLive. You will also reference it in an SdiSourceMapping, in order to create a connection between the logical SdiSource and the physical SDI card and port that the physical SDI source uses.

May throw BadGatewayException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw TooManyRequestsException.

Parameter mode : Applies only if the type is QUAD. Specify the mode for handling the quad-link signal: QUADRANT or INTERLEAVE.

Parameter name : Specify a name that is unique in the AWS account. We recommend you assign a name that describes the source, for example curling-cameraA. Names are case-sensitive.

Parameter requestId : An ID that you assign to a create request. This ID ensures idempotency when creating resources.

Parameter tags : A collection of key-value pairs.

Parameter type : Specify the type of the SDI source: SINGLE: The source is a single-link source. QUAD: The source is one part of a quad-link source.

Implementation

Future<CreateSdiSourceResponse> createSdiSource({
  SdiSourceMode? mode,
  String? name,
  String? requestId,
  Map<String, String>? tags,
  SdiSourceType? type,
}) async {
  final $payload = <String, dynamic>{
    if (mode != null) 'mode': mode.value,
    if (name != null) 'name': name,
    'requestId': requestId ?? _s.generateIdempotencyToken(),
    if (tags != null) 'tags': tags,
    if (type != null) 'type': type.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/prod/sdiSources',
    exceptionFnMap: _exceptionFns,
  );
  return CreateSdiSourceResponse.fromJson(response);
}