deleteEventBridgeRuleTemplateGroup method

Future<void> deleteEventBridgeRuleTemplateGroup({
  1. required String identifier,
})

Deletes an eventbridge rule template group. You must detach this group from all signal maps and ensure its existing templates are moved to another group or deleted.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter identifier : An eventbridge rule template group's identifier. Can be either be its id or current name.

Implementation

Future<void> deleteEventBridgeRuleTemplateGroup({
  required String identifier,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/prod/eventbridge-rule-template-groups/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
}