describeMultiplexProgram method
Get the details for a program in a multiplex.
May throw BadGatewayException.
May throw BadRequestException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter multiplexId :
The ID of the multiplex that the program belongs to.
Parameter programName :
The name of the program.
Implementation
Future<DescribeMultiplexProgramResponse> describeMultiplexProgram({
required String multiplexId,
required String programName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/prod/multiplexes/${Uri.encodeComponent(multiplexId)}/programs/${Uri.encodeComponent(programName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeMultiplexProgramResponse.fromJson(response);
}