listSignalMaps method

Future<ListSignalMapsResponse> listSignalMaps({
  1. String? cloudWatchAlarmTemplateGroupIdentifier,
  2. String? eventBridgeRuleTemplateGroupIdentifier,
  3. int? maxResults,
  4. String? nextToken,
})

Lists signal maps.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter cloudWatchAlarmTemplateGroupIdentifier : A cloudwatch alarm template group's identifier. Can be either be its id or current name.

Parameter eventBridgeRuleTemplateGroupIdentifier : An eventbridge rule template group's identifier. Can be either be its id or current name.

Parameter nextToken : A token used to retrieve the next set of results in paginated list responses.

Implementation

Future<ListSignalMapsResponse> listSignalMaps({
  String? cloudWatchAlarmTemplateGroupIdentifier,
  String? eventBridgeRuleTemplateGroupIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (cloudWatchAlarmTemplateGroupIdentifier != null)
      'cloudWatchAlarmTemplateGroupIdentifier': [
        cloudWatchAlarmTemplateGroupIdentifier
      ],
    if (eventBridgeRuleTemplateGroupIdentifier != null)
      'eventBridgeRuleTemplateGroupIdentifier': [
        eventBridgeRuleTemplateGroupIdentifier
      ],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/prod/signal-maps',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSignalMapsResponse.fromJson(response);
}