startDeleteMonitorDeployment method

Future<StartDeleteMonitorDeploymentResponse> startDeleteMonitorDeployment({
  1. required String identifier,
})

Initiates a deployment to delete the monitor of the specified signal map.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter identifier : A signal map's identifier. Can be either be its id or current name.

Implementation

Future<StartDeleteMonitorDeploymentResponse> startDeleteMonitorDeployment({
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/prod/signal-maps/${Uri.encodeComponent(identifier)}/monitor-deployment',
    exceptionFnMap: _exceptionFns,
  );
  return StartDeleteMonitorDeploymentResponse.fromJson(response);
}