startInputDevice method
Start an input device that is attached to a MediaConnect flow. (There is no need to start a device that is attached to a MediaLive input; MediaLive starts the device when the channel starts.)
May throw BadGatewayException.
May throw BadRequestException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnprocessableEntityException.
Parameter inputDeviceId :
The unique ID of the input device to start. For example,
hd-123456789abcdef.
Implementation
Future<void> startInputDevice({
required String inputDeviceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/prod/inputDevices/${Uri.encodeComponent(inputDeviceId)}/start',
exceptionFnMap: _exceptionFns,
);
}