startInputDeviceMaintenanceWindow method
Start a maintenance window for the specified input device. Starting a maintenance window will give the device up to two hours to install software. If the device was streaming prior to the maintenance, it will resume streaming when the software is fully installed. Devices automatically install updates while they are powered on and their MediaLive channels are stopped. A maintenance window allows you to update a device without having to stop MediaLive channels that use the device. The device must remain powered on and connected to the internet for the duration of the maintenance.
May throw BadGatewayException.
May throw BadRequestException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnprocessableEntityException.
Parameter inputDeviceId :
The unique ID of the input device to start a maintenance window for. For
example, hd-123456789abcdef.
Implementation
Future<void> startInputDeviceMaintenanceWindow({
required String inputDeviceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/prod/inputDevices/${Uri.encodeComponent(inputDeviceId)}/startInputDeviceMaintenanceWindow',
exceptionFnMap: _exceptionFns,
);
}