startMonitorDeployment method

Future<StartMonitorDeploymentResponse> startMonitorDeployment({
  1. required String identifier,
  2. bool? dryRun,
})

Initiates a deployment to deploy the latest monitor of the specified signal map.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter identifier : A signal map's identifier. Can be either be its id or current name.

Implementation

Future<StartMonitorDeploymentResponse> startMonitorDeployment({
  required String identifier,
  bool? dryRun,
}) async {
  final $payload = <String, dynamic>{
    if (dryRun != null) 'dryRun': dryRun,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/prod/signal-maps/${Uri.encodeComponent(identifier)}/monitor-deployment',
    exceptionFnMap: _exceptionFns,
  );
  return StartMonitorDeploymentResponse.fromJson(response);
}