startUpdateSignalMap method

Future<StartUpdateSignalMapResponse> startUpdateSignalMap({
  1. required String identifier,
  2. List<String>? cloudWatchAlarmTemplateGroupIdentifiers,
  3. String? description,
  4. String? discoveryEntryPointArn,
  5. List<String>? eventBridgeRuleTemplateGroupIdentifiers,
  6. bool? forceRediscovery,
  7. String? name,
})

Initiates an update for the specified signal map. Will discover a new signal map if a changed discoveryEntryPointArn is provided.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter identifier : A signal map's identifier. Can be either be its id or current name.

Parameter description : A resource's optional description.

Parameter discoveryEntryPointArn : A top-level supported AWS resource ARN to discovery a signal map from.

Parameter forceRediscovery : If true, will force a rediscovery of a signal map if an unchanged discoveryEntryPointArn is provided.

Parameter name : A resource's name. Names must be unique within the scope of a resource type in a specific region.

Implementation

Future<StartUpdateSignalMapResponse> startUpdateSignalMap({
  required String identifier,
  List<String>? cloudWatchAlarmTemplateGroupIdentifiers,
  String? description,
  String? discoveryEntryPointArn,
  List<String>? eventBridgeRuleTemplateGroupIdentifiers,
  bool? forceRediscovery,
  String? name,
}) async {
  final $payload = <String, dynamic>{
    if (cloudWatchAlarmTemplateGroupIdentifiers != null)
      'cloudWatchAlarmTemplateGroupIdentifiers':
          cloudWatchAlarmTemplateGroupIdentifiers,
    if (description != null) 'description': description,
    if (discoveryEntryPointArn != null)
      'discoveryEntryPointArn': discoveryEntryPointArn,
    if (eventBridgeRuleTemplateGroupIdentifiers != null)
      'eventBridgeRuleTemplateGroupIdentifiers':
          eventBridgeRuleTemplateGroupIdentifiers,
    if (forceRediscovery != null) 'forceRediscovery': forceRediscovery,
    if (name != null) 'name': name,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/prod/signal-maps/${Uri.encodeComponent(identifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return StartUpdateSignalMapResponse.fromJson(response);
}