stopInputDevice method

Future<void> stopInputDevice({
  1. required String inputDeviceId,
})

Stop an input device that is attached to a MediaConnect flow. (There is no need to stop a device that is attached to a MediaLive input; MediaLive automatically stops the device when the channel stops.)

May throw BadGatewayException. May throw BadRequestException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException. May throw UnprocessableEntityException.

Parameter inputDeviceId : The unique ID of the input device to stop. For example, hd-123456789abcdef.

Implementation

Future<void> stopInputDevice({
  required String inputDeviceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/prod/inputDevices/${Uri.encodeComponent(inputDeviceId)}/stop',
    exceptionFnMap: _exceptionFns,
  );
}