updateChannelPlacementGroup method

Future<UpdateChannelPlacementGroupResponse> updateChannelPlacementGroup({
  1. required String channelPlacementGroupId,
  2. required String clusterId,
  3. String? name,
  4. List<String>? nodes,
})

Change the settings for a ChannelPlacementGroup.

May throw BadGatewayException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw TooManyRequestsException. May throw UnprocessableEntityException.

Parameter channelPlacementGroupId : The ID of the channel placement group.

Parameter clusterId : The ID of the cluster.

Parameter name : Include this parameter only if you want to change the current name of the ChannelPlacementGroup. Specify a name that is unique in the Cluster. You can't change the name. Names are case-sensitive.

Parameter nodes : Include this parameter only if you want to change the list of Nodes that are associated with the ChannelPlacementGroup.

Implementation

Future<UpdateChannelPlacementGroupResponse> updateChannelPlacementGroup({
  required String channelPlacementGroupId,
  required String clusterId,
  String? name,
  List<String>? nodes,
}) async {
  final $payload = <String, dynamic>{
    if (name != null) 'name': name,
    if (nodes != null) 'nodes': nodes,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/prod/clusters/${Uri.encodeComponent(clusterId)}/channelplacementgroups/${Uri.encodeComponent(channelPlacementGroupId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateChannelPlacementGroupResponse.fromJson(response);
}