updateCluster method

Future<UpdateClusterResponse> updateCluster({
  1. required String clusterId,
  2. String? name,
  3. ClusterNetworkSettingsUpdateRequest? networkSettings,
})

Change the settings for a Cluster.

May throw BadGatewayException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw TooManyRequestsException.

Parameter clusterId : The ID of the cluster

Parameter name : Include this parameter only if you want to change the current name of the Cluster. Specify a name that is unique in the AWS account. You can't change the name. Names are case-sensitive.

Parameter networkSettings : Include this property only if you want to change the current connections between the Nodes in the Cluster and the Networks the Cluster is associated with.

Implementation

Future<UpdateClusterResponse> updateCluster({
  required String clusterId,
  String? name,
  ClusterNetworkSettingsUpdateRequest? networkSettings,
}) async {
  final $payload = <String, dynamic>{
    if (name != null) 'name': name,
    if (networkSettings != null) 'networkSettings': networkSettings,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/prod/clusters/${Uri.encodeComponent(clusterId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateClusterResponse.fromJson(response);
}