updateInputDevice method

Future<UpdateInputDeviceResponse> updateInputDevice({
  1. required String inputDeviceId,
  2. String? availabilityZone,
  3. InputDeviceConfigurableSettings? hdDeviceSettings,
  4. String? name,
  5. InputDeviceConfigurableSettings? uhdDeviceSettings,
})

Updates the parameters for the input device.

May throw BadGatewayException. May throw BadRequestException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException. May throw UnprocessableEntityException.

Parameter inputDeviceId : The unique ID of the input device. For example, hd-123456789abcdef.

Parameter availabilityZone : The Availability Zone you want associated with this input device.

Parameter hdDeviceSettings : The settings that you want to apply to the HD input device.

Parameter name : The name that you assigned to this input device (not the unique ID).

Parameter uhdDeviceSettings : The settings that you want to apply to the UHD input device.

Implementation

Future<UpdateInputDeviceResponse> updateInputDevice({
  required String inputDeviceId,
  String? availabilityZone,
  InputDeviceConfigurableSettings? hdDeviceSettings,
  String? name,
  InputDeviceConfigurableSettings? uhdDeviceSettings,
}) async {
  final $payload = <String, dynamic>{
    if (availabilityZone != null) 'availabilityZone': availabilityZone,
    if (hdDeviceSettings != null) 'hdDeviceSettings': hdDeviceSettings,
    if (name != null) 'name': name,
    if (uhdDeviceSettings != null) 'uhdDeviceSettings': uhdDeviceSettings,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/prod/inputDevices/${Uri.encodeComponent(inputDeviceId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateInputDeviceResponse.fromJson(response);
}