updateSdiSource method

Future<UpdateSdiSourceResponse> updateSdiSource({
  1. required String sdiSourceId,
  2. SdiSourceMode? mode,
  3. String? name,
  4. SdiSourceType? type,
})

Change some of the settings in an SdiSource.

May throw BadGatewayException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw GatewayTimeoutException. May throw InternalServerErrorException. May throw TooManyRequestsException.

Parameter sdiSourceId : The ID of the SdiSource

Parameter mode : Include this parameter only if you want to change the name of the SdiSource. Specify a name that is unique in the AWS account. We recommend you assign a name that describes the source, for example curling-cameraA. Names are case-sensitive.

Parameter name : Include this parameter only if you want to change the name of the SdiSource. Specify a name that is unique in the AWS account. We recommend you assign a name that describes the source, for example curling-cameraA. Names are case-sensitive.

Parameter type : Include this parameter only if you want to change the mode. Specify the type of the SDI source: SINGLE: The source is a single-link source. QUAD: The source is one part of a quad-link source.

Implementation

Future<UpdateSdiSourceResponse> updateSdiSource({
  required String sdiSourceId,
  SdiSourceMode? mode,
  String? name,
  SdiSourceType? type,
}) async {
  final $payload = <String, dynamic>{
    if (mode != null) 'mode': mode.value,
    if (name != null) 'name': name,
    if (type != null) 'type': type.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/prod/sdiSources/${Uri.encodeComponent(sdiSourceId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSdiSourceResponse.fromJson(response);
}