MediaPackage class

AWS Elemental MediaPackage

Constructors

MediaPackage({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
configureLogs({required String id, EgressAccessLogs? egressAccessLogs, IngressAccessLogs? ingressAccessLogs}) → Future<ConfigureLogsResponse>
Changes the Channel's properities to configure log subscription
createChannel({required String id, String? description, Map<String, String>? tags}) → Future<CreateChannelResponse>
Creates a new Channel.
createHarvestJob({required String endTime, required String id, required String originEndpointId, required S3Destination s3Destination, required String startTime}) → Future<CreateHarvestJobResponse>
Creates a new HarvestJob record.
createOriginEndpoint({required String channelId, required String id, Authorization? authorization, CmafPackageCreateOrUpdateParameters? cmafPackage, DashPackage? dashPackage, String? description, HlsPackage? hlsPackage, String? manifestName, MssPackage? mssPackage, Origination? origination, int? startoverWindowSeconds, Map<String, String>? tags, int? timeDelaySeconds, List<String>? whitelist}) → Future<CreateOriginEndpointResponse>
Creates a new OriginEndpoint record.
deleteChannel({required String id}) → Future<void>
Deletes an existing Channel.
deleteOriginEndpoint({required String id}) → Future<void>
Deletes an existing OriginEndpoint.
describeChannel({required String id}) → Future<DescribeChannelResponse>
Gets details about a Channel.
describeHarvestJob({required String id}) → Future<DescribeHarvestJobResponse>
Gets details about an existing HarvestJob.
describeOriginEndpoint({required String id}) → Future<DescribeOriginEndpointResponse>
Gets details about an existing OriginEndpoint.
listChannels({int? maxResults, String? nextToken}) → Future<ListChannelsResponse>
Returns a collection of Channels.
listHarvestJobs({String? includeChannelId, String? includeStatus, int? maxResults, String? nextToken}) → Future<ListHarvestJobsResponse>
Returns a collection of HarvestJob records.
listOriginEndpoints({String? channelId, int? maxResults, String? nextToken}) → Future<ListOriginEndpointsResponse>
Returns a collection of OriginEndpoint records.
listTagsForResource({required String resourceArn}) → Future<ListTagsForResourceResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateChannelCredentials({required String id}) → Future<RotateChannelCredentialsResponse>
Changes the Channel's first IngestEndpoint's username and password. WARNING - This API is deprecated. Please use RotateIngestEndpointCredentials instead
rotateIngestEndpointCredentials({required String id, required String ingestEndpointId}) → Future<RotateIngestEndpointCredentialsResponse>
Rotate the IngestEndpoint's username and password, as specified by the IngestEndpoint's id.
tagResource({required String resourceArn, required Map<String, String> tags}) → Future<void>
toString() → String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) → Future<void>
Parameter tagKeys : The key(s) of tag to be deleted
updateChannel({required String id, String? description}) → Future<UpdateChannelResponse>
Updates an existing Channel.
updateOriginEndpoint({required String id, Authorization? authorization, CmafPackageCreateOrUpdateParameters? cmafPackage, DashPackage? dashPackage, String? description, HlsPackage? hlsPackage, String? manifestName, MssPackage? mssPackage, Origination? origination, int? startoverWindowSeconds, int? timeDelaySeconds, List<String>? whitelist}) → Future<UpdateOriginEndpointResponse>
Updates an existing OriginEndpoint.

Operators

operator ==(Object other) → bool
The equality operator.
inherited