MediaPackageV2 class

Constructors

MediaPackageV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelHarvestJob({required String channelGroupName, required String channelName, required String harvestJobName, required String originEndpointName, String? eTag}) Future<void>
Cancels an in-progress harvest job.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createChannel({required String channelGroupName, required String channelName, String? clientToken, String? description, InputSwitchConfiguration? inputSwitchConfiguration, InputType? inputType, OutputHeaderConfiguration? outputHeaderConfiguration, Map<String, String>? tags}) Future<CreateChannelResponse>
Create a channel to start receiving content streams. The channel represents the input to MediaPackage for incoming live content from an encoder such as AWS Elemental MediaLive. The channel receives content, and after packaging it, outputs it through an origin endpoint to downstream devices (such as video players or CDNs) that request the content. You can create only one channel with each request. We recommend that you spread out channels between channel groups, such as putting redundant channels in the same AWS Region in different channel groups.
createChannelGroup({required String channelGroupName, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateChannelGroupResponse>
Create a channel group to group your channels and origin endpoints. A channel group is the top-level resource that consists of channels and origin endpoints that are associated with it and that provides predictable URLs for stream delivery. All channels and origin endpoints within the channel group are guaranteed to share the DNS. You can create only one channel group with each request.
createHarvestJob({required String channelGroupName, required String channelName, required Destination destination, required HarvestedManifests harvestedManifests, required String originEndpointName, required HarvesterScheduleConfiguration scheduleConfiguration, String? clientToken, String? description, String? harvestJobName, Map<String, String>? tags}) Future<CreateHarvestJobResponse>
Creates a new harvest job to export content from a MediaPackage v2 channel to an S3 bucket.
createOriginEndpoint({required String channelGroupName, required String channelName, required ContainerType containerType, required String originEndpointName, String? clientToken, List<CreateDashManifestConfiguration>? dashManifests, String? description, ForceEndpointErrorConfiguration? forceEndpointErrorConfiguration, List<CreateHlsManifestConfiguration>? hlsManifests, List<CreateLowLatencyHlsManifestConfiguration>? lowLatencyHlsManifests, List<CreateMssManifestConfiguration>? mssManifests, Segment? segment, int? startoverWindowSeconds, Map<String, String>? tags, UriSeparator? uriSeparator}) Future<CreateOriginEndpointResponse>
The endpoint is attached to a channel, and represents the output of the live content. You can associate multiple endpoints to a single channel. Each endpoint gives players and downstream CDNs (such as Amazon CloudFront) access to the content for playback. Content can't be served from a channel until it has an endpoint. You can create only one endpoint with each request.
deleteChannel({required String channelGroupName, required String channelName}) Future<void>
Delete a channel to stop AWS Elemental MediaPackage from receiving further content. You must delete the channel's origin endpoints before you can delete the channel.
deleteChannelGroup({required String channelGroupName}) Future<void>
Delete a channel group. You must delete the channel group's channels and origin endpoints before you can delete the channel group. If you delete a channel group, you'll lose access to the egress domain and will have to create a new channel group to replace it.
deleteChannelPolicy({required String channelGroupName, required String channelName}) Future<void>
Delete a channel policy.
deleteOriginEndpoint({required String channelGroupName, required String channelName, required String originEndpointName}) Future<void>
Origin endpoints can serve content until they're deleted. Delete the endpoint if it should no longer respond to playback requests. You must delete all endpoints from a channel before you can delete the channel.
deleteOriginEndpointPolicy({required String channelGroupName, required String channelName, required String originEndpointName}) Future<void>
Delete an origin endpoint policy.
getChannel({required String channelGroupName, required String channelName}) Future<GetChannelResponse>
Retrieves the specified channel that's configured in AWS Elemental MediaPackage.
getChannelGroup({required String channelGroupName}) Future<GetChannelGroupResponse>
Retrieves the specified channel group that's configured in AWS Elemental MediaPackage.
getChannelPolicy({required String channelGroupName, required String channelName}) Future<GetChannelPolicyResponse>
Retrieves the specified channel policy that's configured in AWS Elemental MediaPackage. With policies, you can specify who has access to AWS resources and what actions they can perform on those resources.
getHarvestJob({required String channelGroupName, required String channelName, required String harvestJobName, required String originEndpointName}) Future<GetHarvestJobResponse>
Retrieves the details of a specific harvest job.
getOriginEndpoint({required String channelGroupName, required String channelName, required String originEndpointName}) Future<GetOriginEndpointResponse>
Retrieves the specified origin endpoint that's configured in AWS Elemental MediaPackage to obtain its playback URL and to view the packaging settings that it's currently using.
getOriginEndpointPolicy({required String channelGroupName, required String channelName, required String originEndpointName}) Future<GetOriginEndpointPolicyResponse>
Retrieves the specified origin endpoint policy that's configured in AWS Elemental MediaPackage.
listChannelGroups({int? maxResults, String? nextToken}) Future<ListChannelGroupsResponse>
Retrieves all channel groups that are configured in Elemental MediaPackage.
listChannels({required String channelGroupName, int? maxResults, String? nextToken}) Future<ListChannelsResponse>
Retrieves all channels in a specific channel group that are configured in AWS Elemental MediaPackage.
listHarvestJobs({required String channelGroupName, String? channelName, int? maxResults, String? nextToken, String? originEndpointName, HarvestJobStatus? status}) Future<ListHarvestJobsResponse>
Retrieves a list of harvest jobs that match the specified criteria.
listOriginEndpoints({required String channelGroupName, required String channelName, int? maxResults, String? nextToken}) Future<ListOriginEndpointsResponse>
Retrieves all origin endpoints in a specific channel that are configured in AWS Elemental MediaPackage.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags assigned to a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putChannelPolicy({required String channelGroupName, required String channelName, required String policy}) Future<void>
Attaches an IAM policy to the specified channel. With policies, you can specify who has access to AWS resources and what actions they can perform on those resources. You can attach only one policy with each request.
putOriginEndpointPolicy({required String channelGroupName, required String channelName, required String originEndpointName, required String policy, CdnAuthConfiguration? cdnAuthConfiguration}) Future<void>
Attaches an IAM policy to the specified origin endpoint. You can attach only one policy with each request.
resetChannelState({required String channelGroupName, required String channelName}) Future<ResetChannelStateResponse>
Resetting the channel can help to clear errors from misconfigurations in the encoder. A reset refreshes the ingest stream and removes previous content.
resetOriginEndpointState({required String channelGroupName, required String channelName, required String originEndpointName}) Future<ResetOriginEndpointStateResponse>
Resetting the origin endpoint can help to resolve unexpected behavior and other content packaging issues. It also helps to preserve special events when you don't want the previous content to be available for viewing. A reset clears out all previous content from the origin endpoint.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one of more tags (key-value pairs) to the specified MediaPackage resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from the specified resource.
updateChannel({required String channelGroupName, required String channelName, String? description, String? eTag, InputSwitchConfiguration? inputSwitchConfiguration, OutputHeaderConfiguration? outputHeaderConfiguration}) Future<UpdateChannelResponse>
Update the specified channel. You can edit if MediaPackage sends ingest or egress access logs to the CloudWatch log group, if content will be encrypted, the description on a channel, and your channel's policy settings. You can't edit the name of the channel or CloudFront distribution details.
updateChannelGroup({required String channelGroupName, String? description, String? eTag}) Future<UpdateChannelGroupResponse>
Update the specified channel group. You can edit the description on a channel group for easier identification later from the AWS Elemental MediaPackage console. You can't edit the name of the channel group.
updateOriginEndpoint({required String channelGroupName, required String channelName, required ContainerType containerType, required String originEndpointName, List<CreateDashManifestConfiguration>? dashManifests, String? description, String? eTag, ForceEndpointErrorConfiguration? forceEndpointErrorConfiguration, List<CreateHlsManifestConfiguration>? hlsManifests, List<CreateLowLatencyHlsManifestConfiguration>? lowLatencyHlsManifests, List<CreateMssManifestConfiguration>? mssManifests, Segment? segment, int? startoverWindowSeconds, UriSeparator? uriSeparator}) Future<UpdateOriginEndpointResponse>
Update the specified origin endpoint. Edit the packaging preferences on an endpoint to optimize the viewing experience. You can't edit the name of the endpoint.

Operators

operator ==(Object other) bool
The equality operator.
inherited