deleteChannelGroup method

Future<void> deleteChannelGroup({
  1. required String channelGroupName,
})

Delete a channel group. You must delete the channel group's channels and origin endpoints before you can delete the channel group. If you delete a channel group, you'll lose access to the egress domain and will have to create a new channel group to replace it.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter channelGroupName : The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Implementation

Future<void> deleteChannelGroup({
  required String channelGroupName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/channelGroup/${Uri.encodeComponent(channelGroupName)}',
    exceptionFnMap: _exceptionFns,
  );
}