deleteOriginEndpointPolicy method
Delete an origin endpoint policy.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelGroupName :
The name that describes the channel group. The name is the primary
identifier for the channel group, and must be unique for your account in
the AWS Region.
Parameter channelName :
The name that describes the channel. The name is the primary identifier
for the channel, and must be unique for your account in the AWS Region and
channel group.
Parameter originEndpointName :
The name that describes the origin endpoint. The name is the primary
identifier for the origin endpoint, and and must be unique for your
account in the AWS Region and channel.
Implementation
Future<void> deleteOriginEndpointPolicy({
required String channelGroupName,
required String channelName,
required String originEndpointName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/channelGroup/${Uri.encodeComponent(channelGroupName)}/channel/${Uri.encodeComponent(channelName)}/originEndpoint/${Uri.encodeComponent(originEndpointName)}/policy',
exceptionFnMap: _exceptionFns,
);
}