getChannelGroup method

Future<GetChannelGroupResponse> getChannelGroup({
  1. required String channelGroupName,
})

Retrieves the specified channel group that's configured in AWS Elemental MediaPackage.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter channelGroupName : The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Implementation

Future<GetChannelGroupResponse> getChannelGroup({
  required String channelGroupName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/channelGroup/${Uri.encodeComponent(channelGroupName)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetChannelGroupResponse.fromJson(response);
}