listChannelGroups method

Future<ListChannelGroupsResponse> listChannelGroups({
  1. int? maxResults,
  2. String? nextToken,
})

Retrieves all channel groups that are configured in Elemental MediaPackage.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return in the response.

Parameter nextToken : The pagination token from the GET list request. Use the token to fetch the next page of results.

Implementation

Future<ListChannelGroupsResponse> listChannelGroups({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/channelGroup',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListChannelGroupsResponse.fromJson(response);
}