listOriginEndpoints method

Future<ListOriginEndpointsResponse> listOriginEndpoints({
  1. required String channelGroupName,
  2. required String channelName,
  3. int? maxResults,
  4. String? nextToken,
})

Retrieves all origin endpoints in a specific channel that are configured in AWS Elemental MediaPackage.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter channelGroupName : The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Parameter channelName : The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Parameter maxResults : The maximum number of results to return in the response.

Parameter nextToken : The pagination token from the GET list request. Use the token to fetch the next page of results.

Implementation

Future<ListOriginEndpointsResponse> listOriginEndpoints({
  required String channelGroupName,
  required String channelName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/channelGroup/${Uri.encodeComponent(channelGroupName)}/channel/${Uri.encodeComponent(channelName)}/originEndpoint',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListOriginEndpointsResponse.fromJson(response);
}