resetChannelState method
Resetting the channel can help to clear errors from misconfigurations in the encoder. A reset refreshes the ingest stream and removes previous content.
Be sure to stop the encoder before you reset the channel, and wait at least 30 seconds before you restart the encoder.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelGroupName :
The name of the channel group that contains the channel that you are
resetting.
Parameter channelName :
The name of the channel that you are resetting.
Implementation
Future<ResetChannelStateResponse> resetChannelState({
required String channelGroupName,
required String channelName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/channelGroup/${Uri.encodeComponent(channelGroupName)}/channel/${Uri.encodeComponent(channelName)}/reset',
exceptionFnMap: _exceptionFns,
);
return ResetChannelStateResponse.fromJson(response);
}