resetOriginEndpointState method
Resetting the origin endpoint can help to resolve unexpected behavior and other content packaging issues. It also helps to preserve special events when you don't want the previous content to be available for viewing. A reset clears out all previous content from the origin endpoint.
MediaPackage might return old content from this endpoint in the first 30 seconds after the endpoint reset. For best results, when possible, wait 30 seconds from endpoint reset to send playback requests to this endpoint.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelGroupName :
The name of the channel group that contains the channel with the origin
endpoint that you are resetting.
Parameter channelName :
The name of the channel with the origin endpoint that you are resetting.
Parameter originEndpointName :
The name of the origin endpoint that you are resetting.
Implementation
Future<ResetOriginEndpointStateResponse> resetOriginEndpointState({
required String channelGroupName,
required String channelName,
required String originEndpointName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/channelGroup/${Uri.encodeComponent(channelGroupName)}/channel/${Uri.encodeComponent(channelName)}/originEndpoint/${Uri.encodeComponent(originEndpointName)}/reset',
exceptionFnMap: _exceptionFns,
);
return ResetOriginEndpointStateResponse.fromJson(response);
}