updateChannelGroup method

Future<UpdateChannelGroupResponse> updateChannelGroup({
  1. required String channelGroupName,
  2. String? description,
  3. String? eTag,
})

Update the specified channel group. You can edit the description on a channel group for easier identification later from the AWS Elemental MediaPackage console. You can't edit the name of the channel group.

Any edits you make that impact the video output may not be reflected for a few minutes.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter channelGroupName : The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Parameter description : Any descriptive information that you want to add to the channel group for future identification purposes.

Parameter eTag : The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource's current entity tag, the update request will be rejected.

Implementation

Future<UpdateChannelGroupResponse> updateChannelGroup({
  required String channelGroupName,
  String? description,
  String? eTag,
}) async {
  final headers = <String, String>{
    if (eTag != null) 'x-amzn-update-if-match': eTag.toString(),
  };
  final $payload = <String, dynamic>{
    if (description != null) 'Description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/channelGroup/${Uri.encodeComponent(channelGroupName)}',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateChannelGroupResponse.fromJson(response);
}