deleteContainerPolicy method
Deletes the access policy that is associated with the specified container.
May throw ContainerInUseException.
May throw ContainerNotFoundException.
May throw InternalServerError.
May throw PolicyNotFoundException.
Parameter containerName :
The name of the container that holds the policy.
Implementation
Future<void> deleteContainerPolicy({
required String containerName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'MediaStore_20170901.DeleteContainerPolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ContainerName': containerName,
},
);
}