listItems method
Provides a list of metadata entries about folders and objects in the specified folder.
May throw ContainerNotFoundException.
May throw InternalServerError.
Parameter maxResults :
The maximum number of results to return per API request. For example, you
submit a ListItems request with MaxResults set
at 500. Although 2,000 items match your request, the service returns no
more than the first 500 items. (The service also returns a
NextToken value that you can use to fetch the next batch of
results.) The service might return fewer results than the
MaxResults value.
If MaxResults is not included in the request, the service
defaults to pagination with a maximum of 1,000 results per page.
Parameter nextToken :
The token that identifies which batch of results that you want to see. For
example, you submit a ListItems request with
MaxResults set at 500. The service returns the first batch of
results (up to 500) and a NextToken value. To see the next
batch of results, you can submit the ListItems request a
second time and specify the NextToken value.
Tokens expire after 15 minutes.
Parameter path :
The path in the container from which to retrieve items. Format:
Implementation
Future<ListItemsResponse> listItems({
int? maxResults,
String? nextToken,
String? path,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
if (path != null) 'Path': [path],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListItemsResponse.fromJson(response);
}