MediaTailor class
Use the AWS Elemental MediaTailor SDKs and CLI to configure scalable ad insertion and linear channels. With MediaTailor, you can assemble existing content into a linear stream and serve targeted ads to viewers while maintaining broadcast quality in over-the-top (OTT) video applications. For information about using the service, including detailed information about the settings covered in this guide, see the AWS Elemental MediaTailor User Guide.
Through the SDKs and the CLI you manage AWS Elemental MediaTailor configurations and channels the same as you do through the console. For example, you specify ad insertion behavior and mapping information for the origin server and the ad decision server (ADS).
Constructors
- MediaTailor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
configureLogsForChannel(
{required String channelName, required List< LogType> logTypes}) → Future<ConfigureLogsForChannelResponse> - Configures Amazon CloudWatch log settings for a channel.
-
configureLogsForPlaybackConfiguration(
{required int percentEnabled, required String playbackConfigurationName, AdsInteractionLog? adsInteractionLog, List< LoggingStrategy> ? enabledLoggingStrategies, ManifestServiceInteractionLog? manifestServiceInteractionLog}) → Future<ConfigureLogsForPlaybackConfigurationResponse> - Defines where AWS Elemental MediaTailor sends logs for the playback configuration.
-
createChannel(
{required String channelName, required List< RequestOutputItem> outputs, required PlaybackMode playbackMode, List<String> ? audiences, SlateSource? fillerSlate, Map<String, String> ? tags, Tier? tier, TimeShiftConfiguration? timeShiftConfiguration}) → Future<CreateChannelResponse> - Creates a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
createLiveSource(
{required List< HttpPackageConfiguration> httpPackageConfigurations, required String liveSourceName, required String sourceLocationName, Map<String, String> ? tags}) → Future<CreateLiveSourceResponse> - The live source configuration.
-
createPrefetchSchedule(
{required String name, required String playbackConfigurationName, PrefetchConsumption? consumption, RecurringPrefetchConfiguration? recurringPrefetchConfiguration, PrefetchRetrieval? retrieval, PrefetchScheduleType? scheduleType, String? streamId, Map< String, String> ? tags}) → Future<CreatePrefetchScheduleResponse> - Creates a prefetch schedule for a playback configuration. A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see Using ad prefetching in the MediaTailor User Guide.
-
createProgram(
{required String channelName, required String programName, required ScheduleConfiguration scheduleConfiguration, required String sourceLocationName, List< AdBreak> ? adBreaks, List<AudienceMedia> ? audienceMedia, String? liveSourceName, Map<String, String> ? tags, String? vodSourceName}) → Future<CreateProgramResponse> - Creates a program within a channel. For information about programs, see Working with programs in the MediaTailor User Guide.
-
createSourceLocation(
{required HttpConfiguration httpConfiguration, required String sourceLocationName, AccessConfiguration? accessConfiguration, DefaultSegmentDeliveryConfiguration? defaultSegmentDeliveryConfiguration, List< SegmentDeliveryConfiguration> ? segmentDeliveryConfigurations, Map<String, String> ? tags}) → Future<CreateSourceLocationResponse> - Creates a source location. A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
-
createVodSource(
{required List< HttpPackageConfiguration> httpPackageConfigurations, required String sourceLocationName, required String vodSourceName, Map<String, String> ? tags}) → Future<CreateVodSourceResponse> - The VOD source configuration parameters.
-
deleteChannel(
{required String channelName}) → Future< void> - Deletes a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
deleteChannelPolicy(
{required String channelName}) → Future< void> - The channel policy to delete.
-
deleteFunction(
{required String functionId}) → Future< void> - Deletes a function. MediaTailor prevents deletion of a function that is still referenced by a playback configuration or by another function. Remove all references before deleting. For more information about functions, see Working with functions in the MediaTailor User Guide.
-
deleteLiveSource(
{required String liveSourceName, required String sourceLocationName}) → Future< void> - The live source to delete.
-
deletePlaybackConfiguration(
{required String name}) → Future< void> - Deletes a playback configuration. For information about MediaTailor configurations, see Working with configurations in AWS Elemental MediaTailor.
-
deletePrefetchSchedule(
{required String name, required String playbackConfigurationName}) → Future< void> -
Deletes a prefetch schedule for a specific playback configuration. If you
call
DeletePrefetchScheduleon an expired prefetch schedule, MediaTailor returns an HTTP 404 status code. For more information about ad prefetching, see Using ad prefetching in the MediaTailor User Guide. -
deleteProgram(
{required String channelName, required String programName}) → Future< void> - Deletes a program within a channel. For information about programs, see Working with programs in the MediaTailor User Guide.
-
deleteSourceLocation(
{required String sourceLocationName}) → Future< void> - Deletes a source location. A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
-
deleteVodSource(
{required String sourceLocationName, required String vodSourceName}) → Future< void> - The video on demand (VOD) source to delete.
-
describeChannel(
{required String channelName}) → Future< DescribeChannelResponse> - Describes a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
describeLiveSource(
{required String liveSourceName, required String sourceLocationName}) → Future< DescribeLiveSourceResponse> - The live source to describe.
-
describeProgram(
{required String channelName, required String programName}) → Future< DescribeProgramResponse> - Describes a program within a channel. For information about programs, see Working with programs in the MediaTailor User Guide.
-
describeSourceLocation(
{required String sourceLocationName}) → Future< DescribeSourceLocationResponse> - Describes a source location. A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
-
describeVodSource(
{required String sourceLocationName, required String vodSourceName}) → Future< DescribeVodSourceResponse> - Provides details about a specific video on demand (VOD) source in a specific source location.
-
getChannelPolicy(
{required String channelName}) → Future< GetChannelPolicyResponse> - Returns the channel's IAM policy. IAM policies are used to control access to your channel.
-
getChannelSchedule(
{required String channelName, String? audience, String? durationMinutes, int? maxResults, String? nextToken}) → Future< GetChannelScheduleResponse> - Retrieves information about your channel's schedule.
-
getFunction(
{required String functionId}) → Future< GetFunctionResponse> - Retrieves the configuration and metadata for a function. For more information about functions, see Working with functions in the MediaTailor User Guide.
-
getPlaybackConfiguration(
{required String name}) → Future< GetPlaybackConfigurationResponse> - Retrieves a playback configuration. For information about MediaTailor configurations, see Working with configurations in AWS Elemental MediaTailor.
-
getPrefetchSchedule(
{required String name, required String playbackConfigurationName}) → Future< GetPrefetchScheduleResponse> - Retrieves a prefetch schedule for a playback configuration. A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see Using ad prefetching in the MediaTailor User Guide.
-
listAlerts(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListAlertsResponse> - Lists the alerts that are associated with a MediaTailor channel assembly resource.
-
listChannels(
{int? maxResults, String? nextToken}) → Future< ListChannelsResponse> - Retrieves information about the channels that are associated with the current AWS account.
-
listFunctions(
{int? maxResults, String? nextToken}) → Future< ListFunctionsResponse> - Retrieves all functions associated with your AWS account in the current Region. For more information about functions, see Working with functions in the MediaTailor User Guide.
-
listLiveSources(
{required String sourceLocationName, int? maxResults, String? nextToken}) → Future< ListLiveSourcesResponse> - Lists the live sources contained in a source location. A source represents a piece of content.
-
listPlaybackConfigurations(
{int? maxResults, String? nextToken}) → Future< ListPlaybackConfigurationsResponse> - Retrieves existing playback configurations. For information about MediaTailor configurations, see Working with Configurations in AWS Elemental MediaTailor.
-
listPrefetchSchedules(
{required String playbackConfigurationName, int? maxResults, String? nextToken, ListPrefetchScheduleType? scheduleType, String? streamId}) → Future< ListPrefetchSchedulesResponse> - Lists the prefetch schedules for a playback configuration.
-
listSourceLocations(
{int? maxResults, String? nextToken}) → Future< ListSourceLocationsResponse> - Lists the source locations for a channel. A source location defines the host server URL, and contains a list of sources.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - A list of tags that are associated with this resource. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
-
listVodSources(
{required String sourceLocationName, int? maxResults, String? nextToken}) → Future< ListVodSourcesResponse> - Lists the VOD sources contained in a source location. A source represents a piece of content.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putChannelPolicy(
{required String channelName, required String policy}) → Future< void> - Creates an IAM policy for the channel. IAM policies are used to control access to your channel.
-
putFunction(
{required String functionId, required FunctionType functionType, CustomOutputConfiguration? customOutputConfiguration, String? description, HttpRequestConfiguration? httpRequestConfiguration, SequentialExecutorConfiguration? sequentialExecutorConfiguration, Map< String, String> ? tags}) → Future<PutFunctionResponse> - Creates or updates a function. A function defines reusable logic that MediaTailor executes at lifecycle hooks during ad insertion. For more information about functions, see Working with functions in the MediaTailor User Guide.
-
putPlaybackConfiguration(
{required String name, AdConditioningConfiguration? adConditioningConfiguration, AdDecisionServerConfiguration? adDecisionServerConfiguration, String? adDecisionServerUrl, AvailSuppression? availSuppression, Bumper? bumper, CdnConfiguration? cdnConfiguration, Map< String, Map< ? configurationAliases, DashConfigurationForPut? dashConfiguration, Map<String, String> >EventName, String> ? functionMapping, InsertionMode? insertionMode, LivePreRollConfiguration? livePreRollConfiguration, ManifestProcessingRules? manifestProcessingRules, int? personalizationThresholdSeconds, String? slateAdUrl, Map<String, String> ? tags, String? transcodeProfileName, String? videoContentSourceUrl}) → Future<PutPlaybackConfigurationResponse> - Creates a playback configuration. For information about MediaTailor configurations, see Working with configurations in AWS Elemental MediaTailor.
-
startChannel(
{required String channelName}) → Future< void> - Starts a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
stopChannel(
{required String channelName}) → Future< void> - Stops a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - The resource to tag. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - The resource to untag.
-
updateChannel(
{required String channelName, required List< RequestOutputItem> outputs, List<String> ? audiences, SlateSource? fillerSlate, TimeShiftConfiguration? timeShiftConfiguration}) → Future<UpdateChannelResponse> - Updates a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
-
updateLiveSource(
{required List< HttpPackageConfiguration> httpPackageConfigurations, required String liveSourceName, required String sourceLocationName}) → Future<UpdateLiveSourceResponse> - Updates a live source's configuration.
-
updateProgram(
{required String channelName, required String programName, required UpdateProgramScheduleConfiguration scheduleConfiguration, List< AdBreak> ? adBreaks, List<AudienceMedia> ? audienceMedia}) → Future<UpdateProgramResponse> - Updates a program within a channel.
-
updateSourceLocation(
{required HttpConfiguration httpConfiguration, required String sourceLocationName, AccessConfiguration? accessConfiguration, DefaultSegmentDeliveryConfiguration? defaultSegmentDeliveryConfiguration, List< SegmentDeliveryConfiguration> ? segmentDeliveryConfigurations}) → Future<UpdateSourceLocationResponse> - Updates a source location. A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
-
updateVodSource(
{required List< HttpPackageConfiguration> httpPackageConfigurations, required String sourceLocationName, required String vodSourceName}) → Future<UpdateVodSourceResponse> - Updates a VOD source's configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited