createLiveSource method

Future<CreateLiveSourceResponse> createLiveSource({
  1. required List<HttpPackageConfiguration> httpPackageConfigurations,
  2. required String liveSourceName,
  3. required String sourceLocationName,
  4. Map<String, String>? tags,
})

The live source configuration.

Parameter httpPackageConfigurations : A list of HTTP package configuration parameters for this live source.

Parameter liveSourceName : The name of the live source.

Parameter sourceLocationName : The name of the source location.

Parameter tags : The tags to assign to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Implementation

Future<CreateLiveSourceResponse> createLiveSource({
  required List<HttpPackageConfiguration> httpPackageConfigurations,
  required String liveSourceName,
  required String sourceLocationName,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'HttpPackageConfigurations': httpPackageConfigurations,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/sourceLocation/${Uri.encodeComponent(sourceLocationName)}/liveSource/${Uri.encodeComponent(liveSourceName)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateLiveSourceResponse.fromJson(response);
}