createVodSource method

Future<CreateVodSourceResponse> createVodSource({
  1. required List<HttpPackageConfiguration> httpPackageConfigurations,
  2. required String sourceLocationName,
  3. required String vodSourceName,
  4. Map<String, String>? tags,
})

The VOD source configuration parameters.

Parameter httpPackageConfigurations : A list of HTTP package configuration parameters for this VOD source.

Parameter sourceLocationName : The name of the source location for this VOD source.

Parameter vodSourceName : The name associated with the VOD source.>

Parameter tags : The tags to assign to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Implementation

Future<CreateVodSourceResponse> createVodSource({
  required List<HttpPackageConfiguration> httpPackageConfigurations,
  required String sourceLocationName,
  required String vodSourceName,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'HttpPackageConfigurations': httpPackageConfigurations,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/sourceLocation/${Uri.encodeComponent(sourceLocationName)}/vodSource/${Uri.encodeComponent(vodSourceName)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateVodSourceResponse.fromJson(response);
}