updateLiveSource method
Updates a live source's configuration.
Parameter httpPackageConfigurations :
A list of HTTP package configurations for the live source on this account.
Parameter liveSourceName :
The name of the live source.
Parameter sourceLocationName :
The name of the source location associated with this Live Source.
Implementation
Future<UpdateLiveSourceResponse> updateLiveSource({
required List<HttpPackageConfiguration> httpPackageConfigurations,
required String liveSourceName,
required String sourceLocationName,
}) async {
final $payload = <String, dynamic>{
'HttpPackageConfigurations': httpPackageConfigurations,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/sourceLocation/${Uri.encodeComponent(sourceLocationName)}/liveSource/${Uri.encodeComponent(liveSourceName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateLiveSourceResponse.fromJson(response);
}