MedicalImaging class

This is the AWS HealthImaging API Reference. For an introduction to the service, see What is AWS HealthImaging? in the AWS HealthImaging Developer Guide.

Constructors

MedicalImaging({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
copyImageSet({required CopyImageSetInformation copyImageSetInformation, required String datastoreId, required String sourceImageSetId, bool? force, bool? promoteToPrimary}) Future<CopyImageSetResponse>
Copy an image set.
createDatastore({String? clientToken, String? datastoreName, String? kmsKeyArn, String? lambdaAuthorizerArn, LosslessStorageFormat? losslessStorageFormat, Map<String, String>? tags}) Future<CreateDatastoreResponse>
Create a data store.
deleteDatastore({required String datastoreId}) Future<DeleteDatastoreResponse>
Delete a data store.
deleteImageSet({required String datastoreId, required String imageSetId}) Future<DeleteImageSetResponse>
Delete an image set.
getDatastore({required String datastoreId}) Future<GetDatastoreResponse>
Get data store properties.
getDICOMImportJob({required String datastoreId, required String jobId}) Future<GetDICOMImportJobResponse>
Get the import job properties to learn more about the job or job progress.
getImageFrame({required String datastoreId, required ImageFrameInformation imageFrameInformation, required String imageSetId}) Future<GetImageFrameResponse>
Get an image frame (pixel data) for an image set.
getImageSet({required String datastoreId, required String imageSetId, String? versionId}) Future<GetImageSetResponse>
Get image set properties.
getImageSetMetadata({required String datastoreId, required String imageSetId, String? versionId}) Future<GetImageSetMetadataResponse>
Get metadata attributes for an image set.
listDatastores({DatastoreStatus? datastoreStatus, int? maxResults, String? nextToken}) Future<ListDatastoresResponse>
List data stores.
listDICOMImportJobs({required String datastoreId, JobStatus? jobStatus, int? maxResults, String? nextToken}) Future<ListDICOMImportJobsResponse>
List import jobs created for a specific data store.
listImageSetVersions({required String datastoreId, required String imageSetId, int? maxResults, String? nextToken}) Future<ListImageSetVersionsResponse>
List image set versions.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists all tags associated with a medical imaging resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchImageSets({required String datastoreId, int? maxResults, String? nextToken, SearchCriteria? searchCriteria}) Future<SearchImageSetsResponse>
Search image sets based on defined input attributes.
startDICOMImportJob({required String dataAccessRoleArn, required String datastoreId, required String inputS3Uri, required String outputS3Uri, String? clientToken, ImportConfiguration? importConfiguration, String? inputOwnerAccountId, String? jobName}) Future<StartDICOMImportJobResponse>
Start importing bulk data into an ACTIVE data store. The import job imports DICOM P10 files or enhances existing DICOM files with JSON metadata. The importConfiguration parameter specifies the import type. The data is found in the S3 prefix specified by the inputS3Uri parameter. The import job stores processing results in the file specified by the outputS3Uri parameter.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds a user-specifed key and value tag to a medical imaging resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a medical imaging resource.
updateImageSetMetadata({required String datastoreId, required String imageSetId, required String latestVersionId, required MetadataUpdates updateImageSetMetadataUpdates, bool? force, bool? includeStudyImageSets}) Future<UpdateImageSetMetadataResponse>
Update image set metadata attributes.

Operators

operator ==(Object other) bool
The equality operator.
inherited