startDICOMImportJob method

Future<StartDICOMImportJobResponse> startDICOMImportJob({
  1. required String dataAccessRoleArn,
  2. required String datastoreId,
  3. required String inputS3Uri,
  4. required String outputS3Uri,
  5. String? clientToken,
  6. ImportConfiguration? importConfiguration,
  7. String? inputOwnerAccountId,
  8. String? jobName,
})

Start importing bulk data into an ACTIVE data store. The import job imports DICOM P10 files or enhances existing DICOM files with JSON metadata. The importConfiguration parameter specifies the import type. The data is found in the S3 prefix specified by the inputS3Uri parameter. The import job stores processing results in the file specified by the outputS3Uri parameter.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter dataAccessRoleArn : The Amazon Resource Name (ARN) of the IAM role that grants permission to access medical imaging resources.

Parameter datastoreId : The data store identifier.

Parameter inputS3Uri : The input prefix path for the S3 bucket that contains the DICOM files to be imported.

Parameter outputS3Uri : The output prefix of the S3 bucket to upload the results of the DICOM import job.

Parameter clientToken : A unique identifier for API idempotency.

Parameter importConfiguration : The import configuration for the import job.

Parameter inputOwnerAccountId : The account ID of the source S3 bucket owner.

Parameter jobName : The import job name.

Implementation

Future<StartDICOMImportJobResponse> startDICOMImportJob({
  required String dataAccessRoleArn,
  required String datastoreId,
  required String inputS3Uri,
  required String outputS3Uri,
  String? clientToken,
  ImportConfiguration? importConfiguration,
  String? inputOwnerAccountId,
  String? jobName,
}) async {
  final $payload = <String, dynamic>{
    'dataAccessRoleArn': dataAccessRoleArn,
    'inputS3Uri': inputS3Uri,
    'outputS3Uri': outputS3Uri,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (importConfiguration != null)
      'importConfiguration': importConfiguration,
    if (inputOwnerAccountId != null)
      'inputOwnerAccountId': inputOwnerAccountId,
    if (jobName != null) 'jobName': jobName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/startDICOMImportJob/datastore/${Uri.encodeComponent(datastoreId)}',
    exceptionFnMap: _exceptionFns,
  );
  return StartDICOMImportJobResponse.fromJson(response);
}