updateImageSetMetadata method

Future<UpdateImageSetMetadataResponse> updateImageSetMetadata({
  1. required String datastoreId,
  2. required String imageSetId,
  3. required String latestVersionId,
  4. required MetadataUpdates updateImageSetMetadataUpdates,
  5. bool? force,
  6. bool? includeStudyImageSets,
})

Update image set metadata attributes.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter datastoreId : The data store identifier.

Parameter imageSetId : The image set identifier.

Parameter latestVersionId : The latest image set version identifier.

Parameter updateImageSetMetadataUpdates : Update image set metadata updates.

Parameter force : Setting this flag will force the UpdateImageSetMetadata operation for the following attributes:

  • Tag.StudyInstanceUID, Tag.SeriesInstanceUID, Tag.SOPInstanceUID, and Tag.StudyID
  • Adding, removing, or updating private tags for an individual SOP Instance

Parameter includeStudyImageSets : Flag to apply the metadata updates to all image sets in the same Study as the requested image set ID.

Implementation

Future<UpdateImageSetMetadataResponse> updateImageSetMetadata({
  required String datastoreId,
  required String imageSetId,
  required String latestVersionId,
  required MetadataUpdates updateImageSetMetadataUpdates,
  bool? force,
  bool? includeStudyImageSets,
}) async {
  final $query = <String, List<String>>{
    'latestVersion': [latestVersionId],
    if (force != null) 'force': [force.toString()],
    if (includeStudyImageSets != null)
      'includeStudyImageSets': [includeStudyImageSets.toString()],
  };
  final response = await _protocol.send(
    payload: updateImageSetMetadataUpdates,
    method: 'POST',
    requestUri:
        '/datastore/${Uri.encodeComponent(datastoreId)}/imageSet/${Uri.encodeComponent(imageSetId)}/updateImageSetMetadata',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateImageSetMetadataResponse.fromJson(response);
}