createParameterGroup method
Creates a new MemoryDB parameter group. A parameter group is a collection of parameters and their values that are applied to all of the nodes in any cluster. For more information, see Configuring engine parameters using parameter groups.
May throw InvalidParameterCombinationException.
May throw InvalidParameterGroupStateFault.
May throw InvalidParameterValueException.
May throw ParameterGroupAlreadyExistsFault.
May throw ParameterGroupQuotaExceededFault.
May throw ServiceLinkedRoleNotFoundFault.
May throw TagQuotaPerResourceExceeded.
Parameter family :
The name of the parameter group family that the parameter group can be
used with.
Parameter parameterGroupName :
The name of the parameter group.
Parameter description :
An optional description of the parameter group.
Parameter tags :
A list of tags to be added to this resource. A tag is a key-value pair. A
tag key must be accompanied by a tag value, although null is accepted.
Implementation
Future<CreateParameterGroupResponse> createParameterGroup({
required String family,
required String parameterGroupName,
String? description,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.CreateParameterGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Family': family,
'ParameterGroupName': parameterGroupName,
if (description != null) 'Description': description,
if (tags != null) 'Tags': tags,
},
);
return CreateParameterGroupResponse.fromJson(jsonResponse.body);
}