deleteParameterGroup method

Future<DeleteParameterGroupResponse> deleteParameterGroup({
  1. required String parameterGroupName,
})

Deletes the specified parameter group. You cannot delete a parameter group if it is associated with any clusters. You cannot delete the default parameter groups in your account.

May throw InvalidParameterCombinationException. May throw InvalidParameterGroupStateFault. May throw InvalidParameterValueException. May throw ParameterGroupNotFoundFault. May throw ServiceLinkedRoleNotFoundFault.

Parameter parameterGroupName : The name of the parameter group to delete.

Implementation

Future<DeleteParameterGroupResponse> deleteParameterGroup({
  required String parameterGroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonMemoryDB.DeleteParameterGroup'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ParameterGroupName': parameterGroupName,
    },
  );

  return DeleteParameterGroupResponse.fromJson(jsonResponse.body);
}