describeParameters method

Future<DescribeParametersResponse> describeParameters({
  1. required String parameterGroupName,
  2. int? maxResults,
  3. String? nextToken,
})

Returns the detailed parameter list for a particular parameter group.

May throw InvalidParameterCombinationException. May throw InvalidParameterValueException. May throw ParameterGroupNotFoundFault. May throw ServiceLinkedRoleNotFoundFault.

Parameter parameterGroupName : he name of a specific parameter group to return details for.

Parameter maxResults : The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Implementation

Future<DescribeParametersResponse> describeParameters({
  required String parameterGroupName,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonMemoryDB.DescribeParameters'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ParameterGroupName': parameterGroupName,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeParametersResponse.fromJson(jsonResponse.body);
}