describeReservedNodes method

Future<DescribeReservedNodesResponse> describeReservedNodes({
  1. String? duration,
  2. int? maxResults,
  3. String? nextToken,
  4. String? nodeType,
  5. String? offeringType,
  6. String? reservationId,
  7. String? reservedNodesOfferingId,
})

Returns information about reserved nodes for this account, or about a specified reserved node.

May throw InvalidParameterCombinationException. May throw InvalidParameterValueException. May throw ReservedNodeNotFoundFault. May throw ServiceLinkedRoleNotFoundFault.

Parameter duration : The duration filter value, specified in years or seconds. Use this parameter to show only reservations for this duration.

Parameter maxResults : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter nodeType : The node type filter value. Use this parameter to show only those reservations matching the specified node type. For more information, see Supported node types.

Parameter offeringType : The offering type filter value. Use this parameter to show only the available offerings matching the specified offering type. Valid values: "All Upfront"|"Partial Upfront"| "No Upfront"

Parameter reservationId : The reserved node identifier filter value. Use this parameter to show only the reservation that matches the specified reservation ID.

Parameter reservedNodesOfferingId : The offering identifier filter value. Use this parameter to show only purchased reservations matching the specified offering identifier.

Implementation

Future<DescribeReservedNodesResponse> describeReservedNodes({
  String? duration,
  int? maxResults,
  String? nextToken,
  String? nodeType,
  String? offeringType,
  String? reservationId,
  String? reservedNodesOfferingId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonMemoryDB.DescribeReservedNodes'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (duration != null) 'Duration': duration,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (nodeType != null) 'NodeType': nodeType,
      if (offeringType != null) 'OfferingType': offeringType,
      if (reservationId != null) 'ReservationId': reservationId,
      if (reservedNodesOfferingId != null)
        'ReservedNodesOfferingId': reservedNodesOfferingId,
    },
  );

  return DescribeReservedNodesResponse.fromJson(jsonResponse.body);
}