describeSubnetGroups method

Future<DescribeSubnetGroupsResponse> describeSubnetGroups({
  1. int? maxResults,
  2. String? nextToken,
  3. String? subnetGroupName,
})

Returns a list of subnet group descriptions. If a subnet group name is specified, the list contains only the description of that group.

May throw ServiceLinkedRoleNotFoundFault. May throw SubnetGroupNotFoundFault.

Parameter maxResults : The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Parameter nextToken : An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Parameter subnetGroupName : The name of the subnet group to return details for.

Implementation

Future<DescribeSubnetGroupsResponse> describeSubnetGroups({
  int? maxResults,
  String? nextToken,
  String? subnetGroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonMemoryDB.DescribeSubnetGroups'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (subnetGroupName != null) 'SubnetGroupName': subnetGroupName,
    },
  );

  return DescribeSubnetGroupsResponse.fromJson(jsonResponse.body);
}