updateParameterGroup method

Future<UpdateParameterGroupResponse> updateParameterGroup({
  1. required String parameterGroupName,
  2. required List<ParameterNameValue> parameterNameValues,
})

Updates the parameters of a parameter group. You can modify up to 20 parameters in a single request by submitting a list parameter name and value pairs.

May throw InvalidParameterCombinationException. May throw InvalidParameterGroupStateFault. May throw InvalidParameterValueException. May throw ParameterGroupNotFoundFault. May throw ServiceLinkedRoleNotFoundFault.

Parameter parameterGroupName : The name of the parameter group to update.

Parameter parameterNameValues : An array of parameter names and values for the parameter update. You must supply at least one parameter name and value; subsequent arguments are optional. A maximum of 20 parameters may be updated per request.

Implementation

Future<UpdateParameterGroupResponse> updateParameterGroup({
  required String parameterGroupName,
  required List<ParameterNameValue> parameterNameValues,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonMemoryDB.UpdateParameterGroup'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ParameterGroupName': parameterGroupName,
      'ParameterNameValues': parameterNameValues,
    },
  );

  return UpdateParameterGroupResponse.fromJson(jsonResponse.body);
}