describeJobs method
Returns a list of Jobs. Use the JobsID and fromDate and toData filters to limit which jobs are returned. The response is sorted by creationDataTime
- latest date first. Jobs are normally created by the StartTest, StartCutover, and TerminateTargetInstances APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter accountID :
Request to describe job log items by Account ID.
Parameter filters :
Request to describe Job log filters.
Parameter maxResults :
Request to describe job log items by max results.
Parameter nextToken :
Request to describe job log items by next token.
Implementation
Future<DescribeJobsResponse> describeJobs({
String? accountID,
DescribeJobsRequestFilters? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (accountID != null) 'accountID': accountID,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DescribeJobs',
exceptionFnMap: _exceptionFns,
);
return DescribeJobsResponse.fromJson(response);
}