listImportFileEnrichments method

Future<ListImportFileEnrichmentsResponse> listImportFileEnrichments({
  1. ListImportFileEnrichmentsFilters? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists import file enrichment jobs with optional filtering by job IDs.

May throw ValidationException.

Parameter filters : Filters to apply when listing import file enrichment jobs.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListImportFileEnrichmentsResponse> listImportFileEnrichments({
  ListImportFileEnrichmentsFilters? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/network-migration/ListImportFileEnrichments',
    exceptionFnMap: _exceptionFns,
  );
  return ListImportFileEnrichmentsResponse.fromJson(response);
}