listNetworkMigrationDefinitions method

Future<ListNetworkMigrationDefinitionsResponse> listNetworkMigrationDefinitions({
  1. ListNetworkMigrationDefinitionsRequestFilters? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all network migration definitions in the account, with optional filtering.

May throw AccessDeniedException.

Parameter filters : Filters to apply when listing network migration definitions.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListNetworkMigrationDefinitionsResponse>
    listNetworkMigrationDefinitions({
  ListNetworkMigrationDefinitionsRequestFilters? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/network-migration/ListNetworkMigrationDefinitions',
    exceptionFnMap: _exceptionFns,
  );
  return ListNetworkMigrationDefinitionsResponse.fromJson(response);
}