listNetworkMigrationMapperSegmentConstructs method

Future<ListNetworkMigrationMapperSegmentConstructsResponse> listNetworkMigrationMapperSegmentConstructs({
  1. required String networkMigrationDefinitionID,
  2. required String networkMigrationExecutionID,
  3. required String segmentID,
  4. ListNetworkMigrationMapperSegmentConstructsFilters? filters,
  5. int? maxResults,
  6. String? nextToken,
})

Lists constructs within a mapper segment, representing individual infrastructure components like VPCs, subnets, or security groups.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter networkMigrationDefinitionID : The unique identifier of the network migration definition.

Parameter networkMigrationExecutionID : The unique identifier of the network migration execution.

Parameter segmentID : The unique identifier of the segment to list constructs for.

Parameter filters : Filters to apply when listing constructs, such as construct type or ID.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListNetworkMigrationMapperSegmentConstructsResponse>
    listNetworkMigrationMapperSegmentConstructs({
  required String networkMigrationDefinitionID,
  required String networkMigrationExecutionID,
  required String segmentID,
  ListNetworkMigrationMapperSegmentConstructsFilters? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $payload = <String, dynamic>{
    'networkMigrationDefinitionID': networkMigrationDefinitionID,
    'networkMigrationExecutionID': networkMigrationExecutionID,
    'segmentID': segmentID,
    if (filters != null) 'filters': filters,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/network-migration/ListNetworkMigrationMapperSegmentConstructs',
    exceptionFnMap: _exceptionFns,
  );
  return ListNetworkMigrationMapperSegmentConstructsResponse.fromJson(
      response);
}