listNetworkMigrationMappings method
Lists network migration mapping jobs, which analyze and create relationships between source and target network resources.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition.
Parameter networkMigrationExecutionID :
The unique identifier of the network migration execution.
Parameter filters :
Filters to apply when listing mapping jobs.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListNetworkMigrationMappingsResponse> listNetworkMigrationMappings({
required String networkMigrationDefinitionID,
required String networkMigrationExecutionID,
ListNetworkMigrationMappingsFilters? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'networkMigrationDefinitionID': networkMigrationDefinitionID,
'networkMigrationExecutionID': networkMigrationExecutionID,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/ListNetworkMigrationMappings',
exceptionFnMap: _exceptionFns,
);
return ListNetworkMigrationMappingsResponse.fromJson(response);
}