listTemplateActions method
List template post migration custom actions.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
Parameter launchConfigurationTemplateID :
Launch configuration template ID.
Parameter filters :
Filters to apply when listing template post migration custom actions.
Parameter maxResults :
Maximum amount of items to return when listing template post migration
custom actions.
Parameter nextToken :
Next token to use when listing template post migration custom actions.
Implementation
Future<ListTemplateActionsResponse> listTemplateActions({
required String launchConfigurationTemplateID,
TemplateActionsRequestFilters? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'launchConfigurationTemplateID': launchConfigurationTemplateID,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListTemplateActions',
exceptionFnMap: _exceptionFns,
);
return ListTemplateActionsResponse.fromJson(response);
}