retryDataReplication method
Causes the data replication initiation sequence to begin immediately upon next Handshake for specified SourceServer IDs, regardless of when the previous initiation started. This command will not work if the SourceServer is not stalled or is in a DISCONNECTED or STOPPED state.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter sourceServerID :
Retry data replication for Source Server ID.
Parameter accountID :
Retry data replication for Account ID.
Implementation
Future<SourceServer> retryDataReplication({
required String sourceServerID,
String? accountID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
if (accountID != null) 'accountID': accountID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/RetryDataReplication',
exceptionFnMap: _exceptionFns,
);
return SourceServer.fromJson(response);
}