startImportFileEnrichment method
- required EnrichmentSourceS3Configuration s3BucketSource,
- required EnrichmentTargetS3Configuration s3BucketTarget,
- String? clientToken,
- IpAssignmentStrategy? ipAssignmentStrategy,
Starts an import file enrichment job to process and enrich network migration import files with additional metadata and IP assignment strategies.
May throw AccessDeniedException.
May throw ConflictException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter s3BucketSource :
The S3 configuration specifying the source location of the import file to
be enriched.
Parameter s3BucketTarget :
The S3 configuration specifying the target location where the enriched
import file will be stored.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Parameter ipAssignmentStrategy :
The IP assignment strategy to use when enriching the import file. Can be
STATIC or DYNAMIC.
Implementation
Future<StartImportFileEnrichmentResponse> startImportFileEnrichment({
required EnrichmentSourceS3Configuration s3BucketSource,
required EnrichmentTargetS3Configuration s3BucketTarget,
String? clientToken,
IpAssignmentStrategy? ipAssignmentStrategy,
}) async {
final $payload = <String, dynamic>{
's3BucketSource': s3BucketSource,
's3BucketTarget': s3BucketTarget,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (ipAssignmentStrategy != null)
'ipAssignmentStrategy': ipAssignmentStrategy.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/StartImportFileEnrichment',
exceptionFnMap: _exceptionFns,
);
return StartImportFileEnrichmentResponse.fromJson(response);
}