startReplication method

Future<SourceServer> startReplication({
  1. required String sourceServerID,
  2. String? accountID,
})

Start replication for source server irrespective of its replication type.

May throw ConflictException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw UninitializedAccountException. May throw ValidationException.

Parameter sourceServerID : ID of source server on which to start replication.

Parameter accountID : Account ID on which to start replication.

Implementation

Future<SourceServer> startReplication({
  required String sourceServerID,
  String? accountID,
}) async {
  final $payload = <String, dynamic>{
    'sourceServerID': sourceServerID,
    if (accountID != null) 'accountID': accountID,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/StartReplication',
    exceptionFnMap: _exceptionFns,
  );
  return SourceServer.fromJson(response);
}