updateNetworkMigrationDefinition method

Future<NetworkMigrationDefinition> updateNetworkMigrationDefinition({
  1. required String networkMigrationDefinitionID,
  2. String? description,
  3. String? name,
  4. Map<String, String>? scopeTags,
  5. List<SourceConfiguration>? sourceConfigurations,
  6. TargetDeployment? targetDeployment,
  7. TargetNetworkUpdate? targetNetwork,
  8. TargetS3ConfigurationUpdate? targetS3Configuration,
})

Updates an existing network migration definition with new source or target configurations.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter networkMigrationDefinitionID : The unique identifier of the network migration definition to update.

Parameter description : The updated description of the network migration definition.

Parameter name : The updated name of the network migration definition.

Parameter scopeTags : The updated scope tags for the network migration definition.

Parameter sourceConfigurations : The updated list of source configurations.

Parameter targetDeployment : The updated target deployment configuration.

Parameter targetNetwork : The updated target network configuration.

Parameter targetS3Configuration : The updated S3 configuration for storing the target network artifacts.

Implementation

Future<NetworkMigrationDefinition> updateNetworkMigrationDefinition({
  required String networkMigrationDefinitionID,
  String? description,
  String? name,
  Map<String, String>? scopeTags,
  List<SourceConfiguration>? sourceConfigurations,
  TargetDeployment? targetDeployment,
  TargetNetworkUpdate? targetNetwork,
  TargetS3ConfigurationUpdate? targetS3Configuration,
}) async {
  final $payload = <String, dynamic>{
    'networkMigrationDefinitionID': networkMigrationDefinitionID,
    if (description != null) 'description': description,
    if (name != null) 'name': name,
    if (scopeTags != null) 'scopeTags': scopeTags,
    if (sourceConfigurations != null)
      'sourceConfigurations': sourceConfigurations,
    if (targetDeployment != null) 'targetDeployment': targetDeployment.value,
    if (targetNetwork != null) 'targetNetwork': targetNetwork,
    if (targetS3Configuration != null)
      'targetS3Configuration': targetS3Configuration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/network-migration/UpdateNetworkMigrationDefinition',
    exceptionFnMap: _exceptionFns,
  );
  return NetworkMigrationDefinition.fromJson(response);
}