listProgressUpdateStreams method
Lists progress update streams associated with the user account making this call.
May throw AccessDeniedException.
May throw HomeRegionNotSetException.
May throw InternalServerError.
May throw InvalidInputException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter maxResults :
Filter to limit the maximum number of results to list per page.
Parameter nextToken :
If a NextToken was returned by a previous call, there are
more results available. To retrieve the next page of results, make the
call again using the returned token in NextToken.
Implementation
Future<ListProgressUpdateStreamsResult> listProgressUpdateStreams({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSMigrationHub.ListProgressUpdateStreams'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListProgressUpdateStreamsResult.fromJson(jsonResponse.body);
}