deleteHomeRegionControl method
This operation deletes the home region configuration for the calling account. The operation does not delete discovery or migration tracking data in the home region.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidInputException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter controlId :
A unique identifier that's generated for each home region control. It's
always a string that begins with "hrc-" followed by 12 lowercase letters
and numbers.
Implementation
Future<void> deleteHomeRegionControl({
required String controlId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSMigrationHubMultiAccountService.DeleteHomeRegionControl'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ControlId': controlId,
},
);
}