MigrationHubOrchestrator class

This API reference provides descriptions, syntax, and other details about each of the actions and data types for AWS Migration Hub Orchestrator. The topic for each action shows the API request parameters and responses. Alternatively, you can use one of the AWS SDKs to access an API that is tailored to the programming language or platform that you're using.

Constructors

MigrationHubOrchestrator({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createTemplate({required String templateName, required TemplateSource templateSource, String? clientToken, Map<String, String>? tags, String? templateDescription}) Future<CreateTemplateResponse>
Creates a migration workflow template.
createWorkflow({required Map<String, StepInput> inputParameters, required String name, required String templateId, String? applicationConfigurationId, String? description, List<String>? stepTargets, Map<String, String>? tags}) Future<CreateMigrationWorkflowResponse>
Create a workflow to orchestrate your migrations.
createWorkflowStep({required String name, required StepActionType stepActionType, required String stepGroupId, required String workflowId, String? description, List<String>? next, List<WorkflowStepOutput>? outputs, List<String>? previous, List<String>? stepTarget, WorkflowStepAutomationConfiguration? workflowStepAutomationConfiguration}) Future<CreateWorkflowStepResponse>
Create a step in the migration workflow.
createWorkflowStepGroup({required String name, required String workflowId, String? description, List<String>? next, List<String>? previous}) Future<CreateWorkflowStepGroupResponse>
Create a step group in a migration workflow.
deleteTemplate({required String id}) Future<void>
Deletes a migration workflow template.
deleteWorkflow({required String id}) Future<DeleteMigrationWorkflowResponse>
Delete a migration workflow. You must pause a running workflow in Migration Hub Orchestrator console to delete it.
deleteWorkflowStep({required String id, required String stepGroupId, required String workflowId}) Future<void>
Delete a step in a migration workflow. Pause the workflow to delete a running step.
deleteWorkflowStepGroup({required String id, required String workflowId}) Future<void>
Delete a step group in a migration workflow.
getTemplate({required String id}) Future<GetMigrationWorkflowTemplateResponse>
Get the template you want to use for creating a migration workflow.
getTemplateStep({required String id, required String stepGroupId, required String templateId}) Future<GetTemplateStepResponse>
Get a specific step in a template.
getTemplateStepGroup({required String id, required String templateId}) Future<GetTemplateStepGroupResponse>
Get a step group in a template.
getWorkflow({required String id}) Future<GetMigrationWorkflowResponse>
Get migration workflow.
getWorkflowStep({required String id, required String stepGroupId, required String workflowId}) Future<GetWorkflowStepResponse>
Get a step in the migration workflow.
getWorkflowStepGroup({required String id, required String workflowId}) Future<GetWorkflowStepGroupResponse>
Get the step group of a migration workflow.
listPlugins({int? maxResults, String? nextToken}) Future<ListPluginsResponse>
List AWS Migration Hub Orchestrator plugins.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
List the tags added to a resource.
listTemplates({int? maxResults, String? name, String? nextToken}) Future<ListMigrationWorkflowTemplatesResponse>
List the templates available in Migration Hub Orchestrator to create a migration workflow.
listTemplateStepGroups({required String templateId, int? maxResults, String? nextToken}) Future<ListTemplateStepGroupsResponse>
List the step groups in a template.
listTemplateSteps({required String stepGroupId, required String templateId, int? maxResults, String? nextToken}) Future<ListTemplateStepsResponse>
List the steps in a template.
listWorkflows({String? adsApplicationConfigurationName, int? maxResults, String? name, String? nextToken, MigrationWorkflowStatusEnum? status, String? templateId}) Future<ListMigrationWorkflowsResponse>
List the migration workflows.
listWorkflowStepGroups({required String workflowId, int? maxResults, String? nextToken}) Future<ListWorkflowStepGroupsResponse>
List the step groups in a migration workflow.
listWorkflowSteps({required String stepGroupId, required String workflowId, int? maxResults, String? nextToken}) Future<ListWorkflowStepsResponse>
List the steps in a workflow.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryWorkflowStep({required String id, required String stepGroupId, required String workflowId}) Future<RetryWorkflowStepResponse>
Retry a failed step in a migration workflow.
startWorkflow({required String id}) Future<StartMigrationWorkflowResponse>
Start a migration workflow.
stopWorkflow({required String id}) Future<StopMigrationWorkflowResponse>
Stop an ongoing migration workflow.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Tag a resource by specifying its Amazon Resource Name (ARN).
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Deletes the tags for a resource.
updateTemplate({required String id, String? clientToken, String? templateDescription, String? templateName}) Future<UpdateTemplateResponse>
Updates a migration workflow template.
updateWorkflow({required String id, String? description, Map<String, StepInput>? inputParameters, String? name, List<String>? stepTargets}) Future<UpdateMigrationWorkflowResponse>
Update a migration workflow.
updateWorkflowStep({required String id, required String stepGroupId, required String workflowId, String? description, String? name, List<String>? next, List<WorkflowStepOutput>? outputs, List<String>? previous, StepStatus? status, StepActionType? stepActionType, List<String>? stepTarget, WorkflowStepAutomationConfiguration? workflowStepAutomationConfiguration}) Future<UpdateWorkflowStepResponse>
Update a step in a migration workflow.
updateWorkflowStepGroup({required String id, required String workflowId, String? description, String? name, List<String>? next, List<String>? previous}) Future<UpdateWorkflowStepGroupResponse>
Update the step group in a migration workflow.

Operators

operator ==(Object other) bool
The equality operator.
inherited