updateWorkflow method

Future<UpdateMigrationWorkflowResponse> updateWorkflow({
  1. required String id,
  2. String? description,
  3. Map<String, StepInput>? inputParameters,
  4. String? name,
  5. List<String>? stepTargets,
})

Update a migration workflow.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the migration workflow.

Parameter description : The description of the migration workflow.

Parameter inputParameters : The input parameters required to update a migration workflow.

Parameter name : The name of the migration workflow.

Parameter stepTargets : The servers on which a step will be run.

Implementation

Future<UpdateMigrationWorkflowResponse> updateWorkflow({
  required String id,
  String? description,
  Map<String, StepInput>? inputParameters,
  String? name,
  List<String>? stepTargets,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (inputParameters != null) 'inputParameters': inputParameters,
    if (name != null) 'name': name,
    if (stepTargets != null) 'stepTargets': stepTargets,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/migrationworkflow/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateMigrationWorkflowResponse.fromJson(response);
}