updateWorkflowStep method

Future<UpdateWorkflowStepResponse> updateWorkflowStep({
  1. required String id,
  2. required String stepGroupId,
  3. required String workflowId,
  4. String? description,
  5. String? name,
  6. List<String>? next,
  7. List<WorkflowStepOutput>? outputs,
  8. List<String>? previous,
  9. StepStatus? status,
  10. StepActionType? stepActionType,
  11. List<String>? stepTarget,
  12. WorkflowStepAutomationConfiguration? workflowStepAutomationConfiguration,
})

Update a step in a migration workflow.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the step.

Parameter stepGroupId : The ID of the step group.

Parameter workflowId : The ID of the migration workflow.

Parameter description : The description of the step.

Parameter name : The name of the step.

Parameter next : The next step.

Parameter outputs : The outputs of a step.

Parameter previous : The previous step.

Parameter status : The status of the step.

Parameter stepActionType : The action type of the step. You must run and update the status of a manual step for the workflow to continue after the completion of the step.

Parameter stepTarget : The servers on which a step will be run.

Parameter workflowStepAutomationConfiguration : The custom script to run tests on the source and target environments.

Implementation

Future<UpdateWorkflowStepResponse> updateWorkflowStep({
  required String id,
  required String stepGroupId,
  required String workflowId,
  String? description,
  String? name,
  List<String>? next,
  List<WorkflowStepOutput>? outputs,
  List<String>? previous,
  StepStatus? status,
  StepActionType? stepActionType,
  List<String>? stepTarget,
  WorkflowStepAutomationConfiguration? workflowStepAutomationConfiguration,
}) async {
  final $payload = <String, dynamic>{
    'stepGroupId': stepGroupId,
    'workflowId': workflowId,
    if (description != null) 'description': description,
    if (name != null) 'name': name,
    if (next != null) 'next': next,
    if (outputs != null) 'outputs': outputs,
    if (previous != null) 'previous': previous,
    if (status != null) 'status': status.value,
    if (stepActionType != null) 'stepActionType': stepActionType.value,
    if (stepTarget != null) 'stepTarget': stepTarget,
    if (workflowStepAutomationConfiguration != null)
      'workflowStepAutomationConfiguration':
          workflowStepAutomationConfiguration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/workflowstep/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateWorkflowStepResponse.fromJson(response);
}