MigrationHubRefactorSpaces class

This API reference provides descriptions, syntax, and other details about each of the actions and data types for Amazon Web Services Migration Hub Refactor Spaces (Refactor Spaces). The topic for each action shows the API request parameters and the response. Alternatively, you can use one of the Amazon Web Services SDKs to access an API that is tailored to the programming language or platform that you're using. For more information, see Amazon Web Services SDKs.

Constructors

MigrationHubRefactorSpaces({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApplication({required String environmentIdentifier, required String name, required ProxyType proxyType, required String vpcId, ApiGatewayProxyInput? apiGatewayProxy, String? clientToken, Map<String, String>? tags}) Future<CreateApplicationResponse>
Creates an Amazon Web Services Migration Hub Refactor Spaces application. The account that owns the environment also owns the applications created inside the environment, regardless of the account that creates the application. Refactor Spaces provisions an Amazon API Gateway, API Gateway VPC link, and Network Load Balancer for the application proxy inside your account.
createEnvironment({required String name, required NetworkFabricType networkFabricType, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateEnvironmentResponse>
Creates an Amazon Web Services Migration Hub Refactor Spaces environment. The caller owns the environment resource, and all Refactor Spaces applications, services, and routes created within the environment. They are referred to as the environment owner. The environment owner has cross-account visibility and control of Refactor Spaces resources that are added to the environment by other accounts that the environment is shared with.
createRoute({required String applicationIdentifier, required String environmentIdentifier, required RouteType routeType, required String serviceIdentifier, String? clientToken, DefaultRouteInput? defaultRoute, Map<String, String>? tags, UriPathRouteInput? uriPathRoute}) Future<CreateRouteResponse>
Creates an Amazon Web Services Migration Hub Refactor Spaces route. The account owner of the service resource is always the environment owner, regardless of which account creates the route. Routes target a service in the application. If an application does not have any routes, then the first route must be created as a DEFAULT RouteType.
createService({required String applicationIdentifier, required ServiceEndpointType endpointType, required String environmentIdentifier, required String name, String? clientToken, String? description, LambdaEndpointInput? lambdaEndpoint, Map<String, String>? tags, UrlEndpointInput? urlEndpoint, String? vpcId}) Future<CreateServiceResponse>
Creates an Amazon Web Services Migration Hub Refactor Spaces service. The account owner of the service is always the environment owner, regardless of which account in the environment creates the service. Services have either a URL endpoint in a virtual private cloud (VPC), or a Lambda function endpoint.
deleteApplication({required String applicationIdentifier, required String environmentIdentifier}) Future<DeleteApplicationResponse>
Deletes an Amazon Web Services Migration Hub Refactor Spaces application. Before you can delete an application, you must first delete any services or routes within the application.
deleteEnvironment({required String environmentIdentifier}) Future<DeleteEnvironmentResponse>
Deletes an Amazon Web Services Migration Hub Refactor Spaces environment. Before you can delete an environment, you must first delete any applications and services within the environment.
deleteResourcePolicy({required String identifier}) Future<void>
Deletes the resource policy set for the environment.
deleteRoute({required String applicationIdentifier, required String environmentIdentifier, required String routeIdentifier}) Future<DeleteRouteResponse>
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
deleteService({required String applicationIdentifier, required String environmentIdentifier, required String serviceIdentifier}) Future<DeleteServiceResponse>
Deletes an Amazon Web Services Migration Hub Refactor Spaces service.
getApplication({required String applicationIdentifier, required String environmentIdentifier}) Future<GetApplicationResponse>
Gets an Amazon Web Services Migration Hub Refactor Spaces application.
getEnvironment({required String environmentIdentifier}) Future<GetEnvironmentResponse>
Gets an Amazon Web Services Migration Hub Refactor Spaces environment.
getResourcePolicy({required String identifier}) Future<GetResourcePolicyResponse>
Gets the resource-based permission policy that is set for the given environment.
getRoute({required String applicationIdentifier, required String environmentIdentifier, required String routeIdentifier}) Future<GetRouteResponse>
Gets an Amazon Web Services Migration Hub Refactor Spaces route.
getService({required String applicationIdentifier, required String environmentIdentifier, required String serviceIdentifier}) Future<GetServiceResponse>
Gets an Amazon Web Services Migration Hub Refactor Spaces service.
listApplications({required String environmentIdentifier, int? maxResults, String? nextToken}) Future<ListApplicationsResponse>
Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment.
listEnvironments({int? maxResults, String? nextToken}) Future<ListEnvironmentsResponse>
Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller account.
listEnvironmentVpcs({required String environmentIdentifier, int? maxResults, String? nextToken}) Future<ListEnvironmentVpcsResponse>
Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the environment.
listRoutes({required String applicationIdentifier, required String environmentIdentifier, int? maxResults, String? nextToken}) Future<ListRoutesResponse>
Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application.
listServices({required String applicationIdentifier, required String environmentIdentifier, int? maxResults, String? nextToken}) Future<ListServicesResponse>
Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags of a resource. The caller account must be the same as the resource’s OwnerAccountId. Listing tags in other accounts is not supported.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String policy, required String resourceArn}) Future<void>
Attaches a resource-based permission policy to the Amazon Web Services Migration Hub Refactor Spaces environment. The policy must contain the same actions and condition statements as the arn:aws:ram::aws:permission/AWSRAMDefaultPermissionRefactorSpacesEnvironment permission in Resource Access Manager. The policy must not contain new lines or blank lines.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Removes the tags of a given resource. Tags are metadata which can be used to manage a resource. To tag a resource, the caller account must be the same as the resource’s OwnerAccountId. Tagging resources in other accounts is not supported.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource. To untag a resource, the caller account must be the same as the resource’s OwnerAccountId. Untagging resources across accounts is not supported.
updateRoute({required RouteActivationState activationState, required String applicationIdentifier, required String environmentIdentifier, required String routeIdentifier}) Future<UpdateRouteResponse>
Updates an Amazon Web Services Migration Hub Refactor Spaces route.

Operators

operator ==(Object other) bool
The equality operator.
inherited