deleteApplication method

Future<DeleteApplicationResponse> deleteApplication({
  1. required String applicationIdentifier,
  2. required String environmentIdentifier,
})

Deletes an Amazon Web Services Migration Hub Refactor Spaces application. Before you can delete an application, you must first delete any services or routes within the application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationIdentifier : The ID of the application.

Parameter environmentIdentifier : The ID of the environment.

Implementation

Future<DeleteApplicationResponse> deleteApplication({
  required String applicationIdentifier,
  required String environmentIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/environments/${Uri.encodeComponent(environmentIdentifier)}/applications/${Uri.encodeComponent(applicationIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteApplicationResponse.fromJson(response);
}