deleteEnvironment method

Future<DeleteEnvironmentResponse> deleteEnvironment({
  1. required String environmentIdentifier,
})

Deletes an Amazon Web Services Migration Hub Refactor Spaces environment. Before you can delete an environment, you must first delete any applications and services within the environment.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentIdentifier : The ID of the environment.

Implementation

Future<DeleteEnvironmentResponse> deleteEnvironment({
  required String environmentIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/environments/${Uri.encodeComponent(environmentIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteEnvironmentResponse.fromJson(response);
}