deleteService method

Future<DeleteServiceResponse> deleteService({
  1. required String applicationIdentifier,
  2. required String environmentIdentifier,
  3. required String serviceIdentifier,
})

Deletes an Amazon Web Services Migration Hub Refactor Spaces service.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationIdentifier : Deletes a Refactor Spaces service.

Parameter environmentIdentifier : The ID of the environment that the service is in.

Parameter serviceIdentifier : The ID of the service to delete.

Implementation

Future<DeleteServiceResponse> deleteService({
  required String applicationIdentifier,
  required String environmentIdentifier,
  required String serviceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/environments/${Uri.encodeComponent(environmentIdentifier)}/applications/${Uri.encodeComponent(applicationIdentifier)}/services/${Uri.encodeComponent(serviceIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteServiceResponse.fromJson(response);
}