MigrationHubStrategy class

This API reference provides descriptions, syntax, and other details about each of the actions and data types for Migration Hub Strategy Recommendations (Strategy Recommendations). The topic for each action shows the API request parameters and the response. Alternatively, you can use one of the AWS SDKs to access an API that is tailored to the programming language or platform that you're using. For more information, see AWS SDKs.

Constructors

MigrationHubStrategy({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getApplicationComponentDetails({required String applicationComponentId}) Future<GetApplicationComponentDetailsResponse>
Retrieves details about an application component.
getApplicationComponentStrategies({required String applicationComponentId}) Future<GetApplicationComponentStrategiesResponse>
Retrieves a list of all the recommended strategies and tools for an application component running on a server.
getAssessment({required String id}) Future<GetAssessmentResponse>
Retrieves the status of an on-going assessment.
getImportFileTask({required String id}) Future<GetImportFileTaskResponse>
Retrieves the details about a specific import task.
getLatestAssessmentId() Future<GetLatestAssessmentIdResponse>
Retrieve the latest ID of a specific assessment task.
getPortfolioPreferences() Future<GetPortfolioPreferencesResponse>
Retrieves your migration and modernization preferences.
getPortfolioSummary() Future<GetPortfolioSummaryResponse>
Retrieves overall summary including the number of servers to rehost and the overall number of anti-patterns.
getRecommendationReportDetails({required String id}) Future<GetRecommendationReportDetailsResponse>
Retrieves detailed information about the specified recommendation report.
getServerDetails({required String serverId, int? maxResults, String? nextToken}) Future<GetServerDetailsResponse>
Retrieves detailed information about a specified server.
getServerStrategies({required String serverId}) Future<GetServerStrategiesResponse>
Retrieves recommended strategies and tools for the specified server.
listAnalyzableServers({int? maxResults, String? nextToken, SortOrder? sort}) Future<ListAnalyzableServersResponse>
Retrieves a list of all the servers fetched from customer vCenter using Strategy Recommendation Collector.
listApplicationComponents({ApplicationComponentCriteria? applicationComponentCriteria, String? filterValue, List<Group>? groupIdFilter, int? maxResults, String? nextToken, SortOrder? sort}) Future<ListApplicationComponentsResponse>
Retrieves a list of all the application components (processes).
listCollectors({int? maxResults, String? nextToken}) Future<ListCollectorsResponse>
Retrieves a list of all the installed collectors.
listImportFileTask({int? maxResults, String? nextToken}) Future<ListImportFileTaskResponse>
Retrieves a list of all the imports performed.
listServers({String? filterValue, List<Group>? groupIdFilter, int? maxResults, String? nextToken, ServerCriteria? serverCriteria, SortOrder? sort}) Future<ListServersResponse>
Returns a list of all the servers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putPortfolioPreferences({ApplicationMode? applicationMode, ApplicationPreferences? applicationPreferences, DatabasePreferences? databasePreferences, PrioritizeBusinessGoals? prioritizeBusinessGoals}) Future<void>
Saves the specified migration and modernization preferences.
startAssessment({AssessmentDataSourceType? assessmentDataSourceType, List<AssessmentTarget>? assessmentTargets, String? s3bucketForAnalysisData, String? s3bucketForReportData}) Future<StartAssessmentResponse>
Starts the assessment of an on-premises environment.
startImportFileTask({required String s3Bucket, required String name, required String s3key, DataSourceType? dataSourceType, List<Group>? groupId, String? s3bucketForReportData}) Future<StartImportFileTaskResponse>
Starts a file import.
startRecommendationReportGeneration({List<Group>? groupIdFilter, OutputFormat? outputFormat}) Future<StartRecommendationReportGenerationResponse>
Starts generating a recommendation report.
stopAssessment({required String assessmentId}) Future<void>
Stops the assessment of an on-premises environment.
toString() String
A string representation of this object.
inherited
updateApplicationComponentConfig({required String applicationComponentId, AppType? appType, bool? configureOnly, InclusionStatus? inclusionStatus, String? secretsManagerKey, List<SourceCode>? sourceCodeList, StrategyOption? strategyOption}) Future<void>
Updates the configuration of an application component.
updateServerConfig({required String serverId, StrategyOption? strategyOption}) Future<void>
Updates the configuration of the specified server.

Operators

operator ==(Object other) bool
The equality operator.
inherited