getApplicationComponentStrategies method

Future<GetApplicationComponentStrategiesResponse> getApplicationComponentStrategies({
  1. required String applicationComponentId,
})

Retrieves a list of all the recommended strategies and tools for an application component running on a server.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter applicationComponentId : The ID of the application component. The ID is unique within an AWS account.

Implementation

Future<GetApplicationComponentStrategiesResponse>
    getApplicationComponentStrategies({
  required String applicationComponentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/get-applicationcomponent-strategies/${Uri.encodeComponent(applicationComponentId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetApplicationComponentStrategiesResponse.fromJson(response);
}