updateApplicationComponentConfig method

Future<void> updateApplicationComponentConfig({
  1. required String applicationComponentId,
  2. AppType? appType,
  3. bool? configureOnly,
  4. InclusionStatus? inclusionStatus,
  5. String? secretsManagerKey,
  6. List<SourceCode>? sourceCodeList,
  7. StrategyOption? strategyOption,
})

Updates the configuration of an application component.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationComponentId : The ID of the application component. The ID is unique within an AWS account.

Parameter appType : The type of known component.

Parameter configureOnly : Update the configuration request of an application component. If it is set to true, the source code and/or database credentials are updated. If it is set to false, the source code and/or database credentials are updated and an analysis is initiated.

Parameter inclusionStatus : Indicates whether the application component has been included for server recommendation or not.

Parameter secretsManagerKey : Database credentials.

Parameter sourceCodeList : The list of source code configurations to update for the application component.

Parameter strategyOption : The preferred strategy options for the application component. Use values from the GetApplicationComponentStrategies response.

Implementation

Future<void> updateApplicationComponentConfig({
  required String applicationComponentId,
  AppType? appType,
  bool? configureOnly,
  InclusionStatus? inclusionStatus,
  String? secretsManagerKey,
  List<SourceCode>? sourceCodeList,
  StrategyOption? strategyOption,
}) async {
  final $payload = <String, dynamic>{
    'applicationComponentId': applicationComponentId,
    if (appType != null) 'appType': appType.value,
    if (configureOnly != null) 'configureOnly': configureOnly,
    if (inclusionStatus != null) 'inclusionStatus': inclusionStatus.value,
    if (secretsManagerKey != null) 'secretsManagerKey': secretsManagerKey,
    if (sourceCodeList != null) 'sourceCodeList': sourceCodeList,
    if (strategyOption != null) 'strategyOption': strategyOption,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-applicationcomponent-config/',
    exceptionFnMap: _exceptionFns,
  );
}