Mpa class

Multi-party approval is a capability of Organizations that allows you to protect a predefined list of operations through a distributed approval process. Use Multi-party approval to establish approval workflows and transform security processes into team-based decisions.

When to use Multi-party approval:

  • You need to align with the Zero Trust principle of "never trust, always verify"
  • You need to make sure that the right humans have access to the right things in the right way
  • You need distributed decision-making for sensitive or critical operations
  • You need to protect against unintended operations on sensitive or critical resources
  • You need formal reviews and approvals for auditing or compliance reasons
For more information, see What is Multi-party approval in the Multi-party approval User Guide.

Constructors

Mpa({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelSession({required String sessionArn}) Future<void>
Cancels an approval session. For more information, see Session in the Multi-party approval User Guide.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApprovalTeam({required ApprovalStrategy approvalStrategy, required List<ApprovalTeamRequestApprover> approvers, required String description, required String name, required List<PolicyReference> policies, String? clientToken, Map<String, String>? tags}) Future<CreateApprovalTeamResponse>
Creates a new approval team. For more information, see Approval team in the Multi-party approval User Guide.
createIdentitySource({required IdentitySourceParameters identitySourceParameters, String? clientToken, Map<String, String>? tags}) Future<CreateIdentitySourceResponse>
Creates a new identity source. For more information, see Identity Source in the Multi-party approval User Guide.
deleteIdentitySource({required String identitySourceArn}) Future<void>
Deletes an identity source. For more information, see Identity Source in the Multi-party approval User Guide.
deleteInactiveApprovalTeamVersion({required String arn, required String versionId}) Future<void>
Deletes an inactive approval team. For more information, see Team health in the Multi-party approval User Guide.
getApprovalTeam({required String arn}) Future<GetApprovalTeamResponse>
Returns details for an approval team.
getIdentitySource({required String identitySourceArn}) Future<GetIdentitySourceResponse>
Returns details for an identity source. For more information, see Identity Source in the Multi-party approval User Guide.
getPolicyVersion({required String policyVersionArn}) Future<GetPolicyVersionResponse>
Returns details for the version of a policy. Policies define the permissions for team resources.
getResourcePolicy({required String policyName, required PolicyType policyType, required String resourceArn}) Future<GetResourcePolicyResponse>
Returns details about a policy for a resource.
getSession({required String sessionArn}) Future<GetSessionResponse>
Returns details for an approval session. For more information, see Session in the Multi-party approval User Guide.
listApprovalTeams({int? maxResults, String? nextToken}) Future<ListApprovalTeamsResponse>
Returns a list of approval teams.
listIdentitySources({int? maxResults, String? nextToken}) Future<ListIdentitySourcesResponse>
Returns a list of identity sources. For more information, see Identity Source in the Multi-party approval User Guide.
listPolicies({int? maxResults, String? nextToken}) Future<ListPoliciesResponse>
Returns a list of policies. Policies define the permissions for team resources.
listPolicyVersions({required String policyArn, int? maxResults, String? nextToken}) Future<ListPolicyVersionsResponse>
Returns a list of the versions for policies. Policies define the permissions for team resources.
listResourcePolicies({required String resourceArn, int? maxResults, String? nextToken}) Future<ListResourcePoliciesResponse>
Returns a list of policies for a resource.
listSessions({required String approvalTeamArn, List<Filter>? filters, int? maxResults, String? nextToken}) Future<ListSessionsResponse>
Returns a list of approval sessions. For more information, see Session in the Multi-party approval User Guide.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of the tags for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startActiveApprovalTeamDeletion({required String arn, int? pendingWindowDays}) Future<StartActiveApprovalTeamDeletionResponse>
Starts the deletion process for an active approval team.
startApprovalTeamBaseline({required String arn, List<String>? approverIds}) Future<StartApprovalTeamBaselineResponse>
Starts a baseline session for specified approvers on an ACTIVE approval team.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Creates or updates a resource tag. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a resource tag. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
updateApprovalTeam({required String arn, ApprovalStrategy? approvalStrategy, List<ApprovalTeamRequestApprover>? approvers, String? description, List<UpdateAction>? updateActions}) Future<UpdateApprovalTeamResponse>
Updates an approval team. You can request to update the team description, approval threshold, and approvers in the team.

Operators

operator ==(Object other) bool
The equality operator.
inherited