startActiveApprovalTeamDeletion method

Future<StartActiveApprovalTeamDeletionResponse> startActiveApprovalTeamDeletion({
  1. required String arn,
  2. int? pendingWindowDays,
})

Starts the deletion process for an active approval team.

Requests to delete an active team must be approved by the team.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : Amazon Resource Name (ARN) for the team.

Parameter pendingWindowDays : Number of days between when the team approves the delete request and when the team is deleted.

Implementation

Future<StartActiveApprovalTeamDeletionResponse>
    startActiveApprovalTeamDeletion({
  required String arn,
  int? pendingWindowDays,
}) async {
  final $payload = <String, dynamic>{
    if (pendingWindowDays != null) 'PendingWindowDays': pendingWindowDays,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/approval-teams/${Uri.encodeComponent(arn)}?Delete',
    exceptionFnMap: _exceptionFns,
  );
  return StartActiveApprovalTeamDeletionResponse.fromJson(response);
}