Mwaa class

This section contains the Amazon Managed Workflows for Apache Airflow (MWAA) API reference documentation. For more information, see What is Amazon MWAA?.

Constructors

Mwaa({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCliToken({required String name}) Future<CreateCliTokenResponse>
Creates a CLI token for the Airflow CLI. To learn more, see Creating an Apache Airflow CLI token.
createEnvironment({required String dagS3Path, required String executionRoleArn, required String name, required NetworkConfiguration networkConfiguration, required String sourceBucketArn, Map<String, String>? airflowConfigurationOptions, String? airflowVersion, EndpointManagement? endpointManagement, String? environmentClass, String? kmsKey, LoggingConfigurationInput? loggingConfiguration, int? maxWebservers, int? maxWorkers, int? minWebservers, int? minWorkers, String? pluginsS3ObjectVersion, String? pluginsS3Path, String? requirementsS3ObjectVersion, String? requirementsS3Path, int? schedulers, String? startupScriptS3ObjectVersion, String? startupScriptS3Path, Map<String, String>? tags, WebserverAccessMode? webserverAccessMode, String? weeklyMaintenanceWindowStart}) Future<CreateEnvironmentOutput>
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
createWebLoginToken({required String name}) Future<CreateWebLoginTokenResponse>
Creates a web login token for the Airflow Web UI. To learn more, see Creating an Apache Airflow web login token.
deleteEnvironment({required String name}) Future<void>
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
getEnvironment({required String name}) Future<GetEnvironmentOutput>
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
invokeRestApi({required RestApiMethod method, required String name, required String path, Object? body, Document? queryParameters}) Future<InvokeRestApiResponse>
Invokes the Apache Airflow REST API on the webserver with the specified inputs. To learn more, see Using the Apache Airflow REST API
listEnvironments({int? maxResults, String? nextToken}) Future<ListEnvironmentsOutput>
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, "Environment": "Staging".
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publishMetrics({required String environmentName, required List<MetricDatum> metricData}) Future<void>
Internal only. Publishes environment health metrics to Amazon CloudWatch.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, "Environment": "Staging".
updateEnvironment({required String name, Map<String, String>? airflowConfigurationOptions, String? airflowVersion, String? dagS3Path, String? environmentClass, String? executionRoleArn, LoggingConfigurationInput? loggingConfiguration, int? maxWebservers, int? maxWorkers, int? minWebservers, int? minWorkers, UpdateNetworkConfigurationInput? networkConfiguration, String? pluginsS3ObjectVersion, String? pluginsS3Path, String? requirementsS3ObjectVersion, String? requirementsS3Path, int? schedulers, String? sourceBucketArn, String? startupScriptS3ObjectVersion, String? startupScriptS3Path, WebserverAccessMode? webserverAccessMode, String? weeklyMaintenanceWindowStart, WorkerReplacementStrategy? workerReplacementStrategy}) Future<UpdateEnvironmentOutput>
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

Operators

operator ==(Object other) bool
The equality operator.
inherited