createEnvironment method

Future<CreateEnvironmentOutput> createEnvironment({
  1. required String dagS3Path,
  2. required String executionRoleArn,
  3. required String name,
  4. required NetworkConfiguration networkConfiguration,
  5. required String sourceBucketArn,
  6. Map<String, String>? airflowConfigurationOptions,
  7. String? airflowVersion,
  8. EndpointManagement? endpointManagement,
  9. String? environmentClass,
  10. String? kmsKey,
  11. LoggingConfigurationInput? loggingConfiguration,
  12. int? maxWebservers,
  13. int? maxWorkers,
  14. int? minWebservers,
  15. int? minWorkers,
  16. String? pluginsS3ObjectVersion,
  17. String? pluginsS3Path,
  18. String? requirementsS3ObjectVersion,
  19. String? requirementsS3Path,
  20. int? schedulers,
  21. String? startupScriptS3ObjectVersion,
  22. String? startupScriptS3Path,
  23. Map<String, String>? tags,
  24. WebserverAccessMode? webserverAccessMode,
  25. String? weeklyMaintenanceWindowStart,
})

Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.

May throw InternalServerException. May throw ServiceUnavailableException. May throw ValidationException.

Parameter dagS3Path : The relative path to the DAGs folder on your Amazon S3 bucket. For example, dags. For more information, refer to Adding or updating DAGs.

Parameter executionRoleArn : The Amazon Resource Name (ARN) of the execution role for your environment. An execution role is an Amazon Web Services Identity and Access Management (IAM) role that grants MWAA permission to access Amazon Web Services services and resources used by your environment. For example, arn:aws:iam::123456789:role/my-execution-role. For more information, refer to Amazon MWAA Execution role.

Parameter name : The name of the Amazon MWAA environment. For example, MyMWAAEnvironment.

Parameter networkConfiguration : The VPC networking components used to secure and enable network traffic between the Amazon Web Services resources for your environment. For more information, refer to About networking on Amazon MWAA.

Parameter sourceBucketArn : The Amazon Resource Name (ARN) of the Amazon S3 bucket where your DAG code and supporting files are stored. For example, arn:aws:s3:::my-airflow-bucket-unique-name. For more information, refer to Create an Amazon S3 bucket for Amazon MWAA.

Parameter airflowConfigurationOptions : A list of key-value pairs containing the Apache Airflow configuration options you want to attach to your environment. For more information, refer to Apache Airflow configuration options.

Parameter airflowVersion : The Apache Airflow version for your environment. If no value is specified, it defaults to the latest version. For more information, refer to Apache Airflow versions on Amazon Managed Workflows for Apache Airflow (Amazon MWAA).

Valid values: 2.7.2, 2.8.1, 2.9.2, 2.10.1, 2.10.3, 2.11.0, and 3.0.6.

Parameter endpointManagement : Defines whether the VPC endpoints configured for the environment are created, and managed, by the customer or by Amazon MWAA. If set to SERVICE, Amazon MWAA will create and manage the required VPC endpoints in your VPC. If set to CUSTOMER, you must create, and manage, the VPC endpoints for your VPC. If you choose to create an environment in a shared VPC, you must set this value to CUSTOMER. In a shared VPC deployment, the environment will remain in PENDING status until you create the VPC endpoints. If you do not take action to create the endpoints within 72 hours, the status will change to CREATE_FAILED. You can delete the failed environment and create a new one.

Parameter environmentClass : The environment class type. Valid values: mw1.micro, mw1.small, mw1.medium, mw1.large, mw1.xlarge, and mw1.2xlarge. For more information, refer to Amazon MWAA environment class.

Parameter kmsKey : The Amazon Web Services Key Management Service (KMS) key to encrypt the data in your environment. You can use an Amazon Web Services owned CMK, or a Customer managed CMK (advanced). For more information, refer to Create an Amazon MWAA environment.

Parameter loggingConfiguration : Defines the Apache Airflow logs to send to CloudWatch Logs.

Parameter maxWebservers : The maximum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for MaxWebservers when you interact with your Apache Airflow environment using Apache Airflow REST API, or the Apache Airflow CLI. For example, in scenarios where your workload requires network calls to the Apache Airflow REST API with a high transaction-per-second (TPS) rate, Amazon MWAA will increase the number of web servers up to the number set in MaxWebserers. As TPS rates decrease Amazon MWAA disposes of the additional web servers, and scales down to the number set in MinxWebserers.

Valid values: For environments larger than mw1.micro, accepts values from 2 to 5. Defaults to 2 for all environment sizes except mw1.micro, which defaults to 1.

Parameter maxWorkers : The maximum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. For example, 20. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the one worker that is included with your environment, or the number you specify in MinWorkers.

Parameter minWebservers : The minimum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for MaxWebservers when you interact with your Apache Airflow environment using Apache Airflow REST API, or the Apache Airflow CLI. As the transaction-per-second rate, and the network load, decrease, Amazon MWAA disposes of the additional web servers, and scales down to the number set in MinxWebserers.

Valid values: For environments larger than mw1.micro, accepts values from 2 to 5. Defaults to 2 for all environment sizes except mw1.micro, which defaults to 1.

Parameter minWorkers : The minimum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the worker count you specify in the MinWorkers field. For example, 2.

Parameter pluginsS3ObjectVersion : The version of the plugins.zip file on your Amazon S3 bucket. You must specify a version each time a plugins.zip file is updated. For more information, refer to How S3 Versioning works.

Parameter pluginsS3Path : The relative path to the plugins.zip file on your Amazon S3 bucket. For example, plugins.zip. If specified, then the plugins.zip version is required. For more information, refer to Installing custom plugins.

Parameter requirementsS3ObjectVersion : The version of the requirements.txt file on your Amazon S3 bucket. You must specify a version each time a requirements.txt file is updated. For more information, refer to How S3 Versioning works.

Parameter requirementsS3Path : The relative path to the requirements.txt file on your Amazon S3 bucket. For example, requirements.txt. If specified, then a version is required. For more information, refer to Installing Python dependencies.

Parameter schedulers : The number of Apache Airflow schedulers to run in your environment. Valid values:

  • v2 - For environments larger than mw1.micro, accepts values from 2 to 5. Defaults to 2 for all environment sizes except mw1.micro, which defaults to 1.
  • v1 - Accepts 1.

Parameter startupScriptS3ObjectVersion : The version of the startup shell script in your Amazon S3 bucket. You must specify the version ID that Amazon S3 assigns to the file every time you update the script.

Version IDs are Unicode, UTF-8 encoded, URL-ready, opaque strings that are no more than 1,024 bytes long. The following is an example:

3sL4kqtJlcpXroDTDmJ+rmSpXd3dIbrHY+MTRCxf3vjVBH40Nr8X8gdRQBpUMLUo

For more information, refer to Using a startup script.

Parameter startupScriptS3Path : The relative path to the startup shell script in your Amazon S3 bucket. For example, s3://mwaa-environment/startup.sh.

Amazon MWAA runs the script as your environment starts, and before running the Apache Airflow process. You can use this script to install dependencies, modify Apache Airflow configuration options, and set environment variables. For more information, refer to Using a startup script.

Parameter tags : The key-value tag pairs you want to associate to your environment. For example, "Environment": "Staging". For more information, refer to Tagging Amazon Web Services resources.

Parameter webserverAccessMode : Defines the access mode for the Apache Airflow web server. For more information, refer to Apache Airflow access modes.

If set to PUBLIC_AND_PRIVATE, creates both a public network load balancer (NLB) for browser access and a private VPC endpoint (VPCE) for worker-to-webserver communication. This mode is only available for Apache Airflow version 3.2 and later.

Parameter weeklyMaintenanceWindowStart : The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time to start weekly maintenance updates of your environment in the following format: DAY:HH:MM. For example: TUE:03:30. You can specify a start time in 30 minute increments only.

Implementation

Future<CreateEnvironmentOutput> createEnvironment({
  required String dagS3Path,
  required String executionRoleArn,
  required String name,
  required NetworkConfiguration networkConfiguration,
  required String sourceBucketArn,
  Map<String, String>? airflowConfigurationOptions,
  String? airflowVersion,
  EndpointManagement? endpointManagement,
  String? environmentClass,
  String? kmsKey,
  LoggingConfigurationInput? loggingConfiguration,
  int? maxWebservers,
  int? maxWorkers,
  int? minWebservers,
  int? minWorkers,
  String? pluginsS3ObjectVersion,
  String? pluginsS3Path,
  String? requirementsS3ObjectVersion,
  String? requirementsS3Path,
  int? schedulers,
  String? startupScriptS3ObjectVersion,
  String? startupScriptS3Path,
  Map<String, String>? tags,
  WebserverAccessMode? webserverAccessMode,
  String? weeklyMaintenanceWindowStart,
}) async {
  _s.validateNumRange(
    'maxWebservers',
    maxWebservers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'maxWorkers',
    maxWorkers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'minWebservers',
    minWebservers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'minWorkers',
    minWorkers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'schedulers',
    schedulers,
    0,
    5,
  );
  final $payload = <String, dynamic>{
    'DagS3Path': dagS3Path,
    'ExecutionRoleArn': executionRoleArn,
    'NetworkConfiguration': networkConfiguration,
    'SourceBucketArn': sourceBucketArn,
    if (airflowConfigurationOptions != null)
      'AirflowConfigurationOptions': airflowConfigurationOptions,
    if (airflowVersion != null) 'AirflowVersion': airflowVersion,
    if (endpointManagement != null)
      'EndpointManagement': endpointManagement.value,
    if (environmentClass != null) 'EnvironmentClass': environmentClass,
    if (kmsKey != null) 'KmsKey': kmsKey,
    if (loggingConfiguration != null)
      'LoggingConfiguration': loggingConfiguration,
    if (maxWebservers != null) 'MaxWebservers': maxWebservers,
    if (maxWorkers != null) 'MaxWorkers': maxWorkers,
    if (minWebservers != null) 'MinWebservers': minWebservers,
    if (minWorkers != null) 'MinWorkers': minWorkers,
    if (pluginsS3ObjectVersion != null)
      'PluginsS3ObjectVersion': pluginsS3ObjectVersion,
    if (pluginsS3Path != null) 'PluginsS3Path': pluginsS3Path,
    if (requirementsS3ObjectVersion != null)
      'RequirementsS3ObjectVersion': requirementsS3ObjectVersion,
    if (requirementsS3Path != null) 'RequirementsS3Path': requirementsS3Path,
    if (schedulers != null) 'Schedulers': schedulers,
    if (startupScriptS3ObjectVersion != null)
      'StartupScriptS3ObjectVersion': startupScriptS3ObjectVersion,
    if (startupScriptS3Path != null)
      'StartupScriptS3Path': startupScriptS3Path,
    if (tags != null) 'Tags': tags,
    if (webserverAccessMode != null)
      'WebserverAccessMode': webserverAccessMode.value,
    if (weeklyMaintenanceWindowStart != null)
      'WeeklyMaintenanceWindowStart': weeklyMaintenanceWindowStart,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/environments/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateEnvironmentOutput.fromJson(response);
}