createWebLoginToken method
Creates a web login token for the Airflow Web UI. To learn more, see Creating an Apache Airflow web login token.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter name :
The name of the Amazon MWAA environment. For example,
MyMWAAEnvironment.
Implementation
Future<CreateWebLoginTokenResponse> createWebLoginToken({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/webtoken/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return CreateWebLoginTokenResponse.fromJson(response);
}