updateEnvironment method

Future<UpdateEnvironmentOutput> updateEnvironment({
  1. required String name,
  2. Map<String, String>? airflowConfigurationOptions,
  3. String? airflowVersion,
  4. String? dagS3Path,
  5. String? environmentClass,
  6. String? executionRoleArn,
  7. LoggingConfigurationInput? loggingConfiguration,
  8. int? maxWebservers,
  9. int? maxWorkers,
  10. int? minWebservers,
  11. int? minWorkers,
  12. UpdateNetworkConfigurationInput? networkConfiguration,
  13. String? pluginsS3ObjectVersion,
  14. String? pluginsS3Path,
  15. String? requirementsS3ObjectVersion,
  16. String? requirementsS3Path,
  17. int? schedulers,
  18. String? sourceBucketArn,
  19. String? startupScriptS3ObjectVersion,
  20. String? startupScriptS3Path,
  21. WebserverAccessMode? webserverAccessMode,
  22. String? weeklyMaintenanceWindowStart,
  23. WorkerReplacementStrategy? workerReplacementStrategy,
})

Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ValidationException.

Parameter name : The name of your Amazon MWAA environment. For example, MyMWAAEnvironment.

Parameter airflowConfigurationOptions : A list of key-value pairs containing the Apache Airflow configuration options you want to attach to your environment. For more information, refer to Apache Airflow configuration options.

Parameter airflowVersion : The Apache Airflow version for your environment. To upgrade your environment, specify a newer version of Apache Airflow supported by Amazon MWAA. To downgrade your environment, specify an older version of Apache Airflow supported by Amazon MWAA.

Before you upgrade or downgrade an environment, make sure your requirements, DAGs, plugins, and other resources used in your workflows are compatible with the new Apache Airflow version. For more information about updating your resources, see Upgrading and downgrading an Amazon MWAA environment.

Valid values: 2.7.2, 2.8.1, 2.9.2, 2.10.1, 2.10.3, 2.11.0, and 3.0.6.

Parameter dagS3Path : The relative path to the DAGs folder on your Amazon S3 bucket. For example, dags. For more information, refer to Adding or updating DAGs.

Parameter environmentClass : The environment class type. Valid values: mw1.micro, mw1.small, mw1.medium, mw1.large, mw1.xlarge, and mw1.2xlarge. For more information, refer to Amazon MWAA environment class.

Parameter executionRoleArn : The Amazon Resource Name (ARN) of the execution role in IAM that allows MWAA to access Amazon Web Services resources in your environment. For example, arn:aws:iam::123456789:role/my-execution-role. For more information, refer to Amazon MWAA Execution role.

Parameter loggingConfiguration : The Apache Airflow log types to send to CloudWatch Logs.

Parameter maxWebservers : The maximum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for MaxWebservers when you interact with your Apache Airflow environment using Apache Airflow REST API, or the Apache Airflow CLI. For example, in scenarios where your workload requires network calls to the Apache Airflow REST API with a high transaction-per-second (TPS) rate, Amazon MWAA will increase the number of web servers up to the number set in MaxWebserers. As TPS rates decrease Amazon MWAA disposes of the additional web servers, and scales down to the number set in MinxWebserers.

Valid values: For environments larger than mw1.micro, accepts values from 2 to 5. Defaults to 2 for all environment sizes except mw1.micro, which defaults to 1.

Parameter maxWorkers : The maximum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. For example, 20. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the one worker that is included with your environment, or the number you specify in MinWorkers.

Parameter minWebservers : The minimum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for MaxWebservers when you interact with your Apache Airflow environment using Apache Airflow REST API, or the Apache Airflow CLI. As the transaction-per-second rate, and the network load, decrease, Amazon MWAA disposes of the additional web servers, and scales down to the number set in MinxWebserers.

Valid values: For environments larger than mw1.micro, accepts values from 2 to 5. Defaults to 2 for all environment sizes except mw1.micro, which defaults to 1.

Parameter minWorkers : The minimum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the worker count you specify in the MinWorkers field. For example, 2.

Parameter networkConfiguration : The VPC networking components used to secure and enable network traffic between the Amazon Web Services resources for your environment. For more information, refer to About networking on Amazon MWAA.

Parameter pluginsS3ObjectVersion : The version of the plugins.zip file on your Amazon S3 bucket. You must specify a version each time a plugins.zip file is updated. For more information, refer to How S3 Versioning works.

Parameter pluginsS3Path : The relative path to the plugins.zip file on your Amazon S3 bucket. For example, plugins.zip. If specified, then the plugins.zip version is required. For more information, refer to Installing custom plugins.

Parameter requirementsS3ObjectVersion : The version of the requirements.txt file on your Amazon S3 bucket. You must specify a version each time a requirements.txt file is updated. For more information, refer to How S3 Versioning works.

Parameter requirementsS3Path : The relative path to the requirements.txt file on your Amazon S3 bucket. For example, requirements.txt. If specified, then a file version is required. For more information, refer to Installing Python dependencies.

Parameter schedulers : The number of Apache Airflow schedulers to run in your Amazon MWAA environment.

Parameter sourceBucketArn : The Amazon Resource Name (ARN) of the Amazon S3 bucket where your DAG code and supporting files are stored. For example, arn:aws:s3:::my-airflow-bucket-unique-name. For more information, refer to Create an Amazon S3 bucket for Amazon MWAA.

Parameter startupScriptS3ObjectVersion : The version of the startup shell script in your Amazon S3 bucket. You must specify the version ID that Amazon S3 assigns to the file every time you update the script.

Version IDs are Unicode, UTF-8 encoded, URL-ready, opaque strings that are no more than 1,024 bytes long. The following is an example:

3sL4kqtJlcpXroDTDmJ+rmSpXd3dIbrHY+MTRCxf3vjVBH40Nr8X8gdRQBpUMLUo

For more information, refer to Using a startup script.

Parameter startupScriptS3Path : The relative path to the startup shell script in your Amazon S3 bucket. For example, s3://mwaa-environment/startup.sh.

Amazon MWAA runs the script as your environment starts, and before running the Apache Airflow process. You can use this script to install dependencies, modify Apache Airflow configuration options, and set environment variables. For more information, refer to Using a startup script.

Parameter webserverAccessMode : The Apache Airflow Web server access mode. For more information, refer to Apache Airflow access modes.

If set to PUBLIC_AND_PRIVATE, creates both a public network load balancer (NLB) for browser access and a private VPC endpoint (VPCE) for worker-to-webserver communication. This mode is only available for Apache Airflow version 3.2 and later.

Parameter weeklyMaintenanceWindowStart : The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time to start weekly maintenance updates of your environment in the following format: DAY:HH:MM. For example: TUE:03:30. You can specify a start time in 30 minute increments only.

Parameter workerReplacementStrategy : The worker replacement strategy to use when updating the environment.

You can select one of the following strategies:

  • Forced - Stops and replaces Apache Airflow workers without waiting for tasks to complete before an update.
  • Graceful - Allows Apache Airflow workers to complete running tasks for up to 12 hours during an update before they're stopped and replaced.

Implementation

Future<UpdateEnvironmentOutput> updateEnvironment({
  required String name,
  Map<String, String>? airflowConfigurationOptions,
  String? airflowVersion,
  String? dagS3Path,
  String? environmentClass,
  String? executionRoleArn,
  LoggingConfigurationInput? loggingConfiguration,
  int? maxWebservers,
  int? maxWorkers,
  int? minWebservers,
  int? minWorkers,
  UpdateNetworkConfigurationInput? networkConfiguration,
  String? pluginsS3ObjectVersion,
  String? pluginsS3Path,
  String? requirementsS3ObjectVersion,
  String? requirementsS3Path,
  int? schedulers,
  String? sourceBucketArn,
  String? startupScriptS3ObjectVersion,
  String? startupScriptS3Path,
  WebserverAccessMode? webserverAccessMode,
  String? weeklyMaintenanceWindowStart,
  WorkerReplacementStrategy? workerReplacementStrategy,
}) async {
  _s.validateNumRange(
    'maxWebservers',
    maxWebservers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'maxWorkers',
    maxWorkers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'minWebservers',
    minWebservers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'minWorkers',
    minWorkers,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'schedulers',
    schedulers,
    0,
    5,
  );
  final $payload = <String, dynamic>{
    if (airflowConfigurationOptions != null)
      'AirflowConfigurationOptions': airflowConfigurationOptions,
    if (airflowVersion != null) 'AirflowVersion': airflowVersion,
    if (dagS3Path != null) 'DagS3Path': dagS3Path,
    if (environmentClass != null) 'EnvironmentClass': environmentClass,
    if (executionRoleArn != null) 'ExecutionRoleArn': executionRoleArn,
    if (loggingConfiguration != null)
      'LoggingConfiguration': loggingConfiguration,
    if (maxWebservers != null) 'MaxWebservers': maxWebservers,
    if (maxWorkers != null) 'MaxWorkers': maxWorkers,
    if (minWebservers != null) 'MinWebservers': minWebservers,
    if (minWorkers != null) 'MinWorkers': minWorkers,
    if (networkConfiguration != null)
      'NetworkConfiguration': networkConfiguration,
    if (pluginsS3ObjectVersion != null)
      'PluginsS3ObjectVersion': pluginsS3ObjectVersion,
    if (pluginsS3Path != null) 'PluginsS3Path': pluginsS3Path,
    if (requirementsS3ObjectVersion != null)
      'RequirementsS3ObjectVersion': requirementsS3ObjectVersion,
    if (requirementsS3Path != null) 'RequirementsS3Path': requirementsS3Path,
    if (schedulers != null) 'Schedulers': schedulers,
    if (sourceBucketArn != null) 'SourceBucketArn': sourceBucketArn,
    if (startupScriptS3ObjectVersion != null)
      'StartupScriptS3ObjectVersion': startupScriptS3ObjectVersion,
    if (startupScriptS3Path != null)
      'StartupScriptS3Path': startupScriptS3Path,
    if (webserverAccessMode != null)
      'WebserverAccessMode': webserverAccessMode.value,
    if (weeklyMaintenanceWindowStart != null)
      'WeeklyMaintenanceWindowStart': weeklyMaintenanceWindowStart,
    if (workerReplacementStrategy != null)
      'WorkerReplacementStrategy': workerReplacementStrategy.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/environments/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateEnvironmentOutput.fromJson(response);
}