getWorkflowRun method
Retrieves detailed information about a specific workflow run, including its status, execution details, and task instances.
May throw AccessDeniedException.
May throw InternalServerException.
May throw OperationTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter runId :
The unique identifier of the workflow run to retrieve.
Parameter workflowArn :
The Amazon Resource Name (ARN) of the workflow that contains the run.
Implementation
Future<GetWorkflowRunResponse> getWorkflowRun({
required String runId,
required String workflowArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonMWAAServerless.GetWorkflowRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RunId': runId,
'WorkflowArn': workflowArn,
},
);
return GetWorkflowRunResponse.fromJson(jsonResponse.body);
}