copyDBClusterParameterGroup method
Copies the specified DB cluster parameter group.
May throw DBParameterGroupAlreadyExistsFault.
May throw DBParameterGroupNotFoundFault.
May throw DBParameterGroupQuotaExceededFault.
Parameter sourceDBClusterParameterGroupIdentifier :
The identifier or Amazon Resource Name (ARN) for the source DB cluster
parameter group. For information about creating an ARN, see
Constructing an Amazon Resource Name (ARN).
Constraints:
- Must specify a valid DB cluster parameter group.
-
If the source DB cluster parameter group is in the same Amazon Region as
the copy, specify a valid DB parameter group identifier, for example
my-db-cluster-param-group, or a valid ARN. -
If the source DB parameter group is in a different Amazon Region than the
copy, specify a valid DB cluster parameter group ARN, for example
arn:aws:rds:us-east-1:123456789012:cluster-pg:custom-cluster-group1.
Parameter targetDBClusterParameterGroupDescription :
A description for the copied DB cluster parameter group.
Parameter targetDBClusterParameterGroupIdentifier :
The identifier for the copied DB cluster parameter group.
Constraints:
- Cannot be null, empty, or blank
- Must contain from 1 to 255 letters, numbers, or hyphens
- First character must be a letter
- Cannot end with a hyphen or contain two consecutive hyphens
my-cluster-param-group1
Parameter tags :
The tags to be assigned to the copied DB cluster parameter group.
Implementation
Future<CopyDBClusterParameterGroupResult> copyDBClusterParameterGroup({
required String sourceDBClusterParameterGroupIdentifier,
required String targetDBClusterParameterGroupDescription,
required String targetDBClusterParameterGroupIdentifier,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'SourceDBClusterParameterGroupIdentifier':
sourceDBClusterParameterGroupIdentifier,
'TargetDBClusterParameterGroupDescription':
targetDBClusterParameterGroupDescription,
'TargetDBClusterParameterGroupIdentifier':
targetDBClusterParameterGroupIdentifier,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CopyDBClusterParameterGroup',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CopyDBClusterParameterGroupResult',
);
return CopyDBClusterParameterGroupResult.fromXml($result);
}