deleteGlobalCluster method

Future<DeleteGlobalClusterResult> deleteGlobalCluster({
  1. required String globalClusterIdentifier,
})

Deletes a global database. The primary and all secondary clusters must already be detached or deleted first.

May throw GlobalClusterNotFoundFault. May throw InvalidGlobalClusterStateFault.

Parameter globalClusterIdentifier : The cluster identifier of the global database cluster being deleted.

Implementation

Future<DeleteGlobalClusterResult> deleteGlobalCluster({
  required String globalClusterIdentifier,
}) async {
  final $request = <String, String>{
    'GlobalClusterIdentifier': globalClusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteGlobalCluster',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteGlobalClusterResult',
  );
  return DeleteGlobalClusterResult.fromXml($result);
}