describeDBClusterSnapshotAttributes method
- required String dBClusterSnapshotIdentifier,
Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.
When sharing snapshots with other Amazon accounts,
DescribeDBClusterSnapshotAttributes returns the
restore attribute and a list of IDs for the Amazon accounts
that are authorized to copy or restore the manual DB cluster snapshot. If
all is included in the list of values for the
restore attribute, then the manual DB cluster snapshot is
public and can be copied or restored by all Amazon accounts.
To add or remove access for an Amazon account to copy or restore a manual DB cluster snapshot, or to make the manual DB cluster snapshot public or private, use the ModifyDBClusterSnapshotAttribute API action.
May throw DBClusterSnapshotNotFoundFault.
Parameter dBClusterSnapshotIdentifier :
The identifier for the DB cluster snapshot to describe the attributes for.
Implementation
Future<DescribeDBClusterSnapshotAttributesResult>
describeDBClusterSnapshotAttributes({
required String dBClusterSnapshotIdentifier,
}) async {
final $request = <String, String>{
'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterSnapshotAttributes',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterSnapshotAttributesResult',
);
return DescribeDBClusterSnapshotAttributesResult.fromXml($result);
}