describeDBClusters method
Returns information about provisioned DB clusters, and supports pagination.
May throw DBClusterNotFoundFault.
Parameter dBClusterIdentifier :
The user-supplied DB cluster identifier. If this parameter is specified,
information from only the specific DB cluster is returned. This parameter
isn't case-sensitive.
Constraints:
- If supplied, must match an existing DBClusterIdentifier.
Parameter filters :
A filter that specifies one or more DB clusters to describe.
Supported filters:
-
db-cluster-id- Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list will only include information about the DB clusters identified by these ARNs. -
engine- Accepts an engine name (such asneptune), and restricts the results list to DB clusters created by that engine.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBClusters request. If this parameter is specified, the
response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that the remaining results
can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBClusterMessage> describeDBClusters({
String? dBClusterIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBClusterIdentifier != null)
'DBClusterIdentifier': dBClusterIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusters',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClustersResult',
);
return DBClusterMessage.fromXml($result);
}