describeGlobalClusters method

Future<GlobalClustersMessage> describeGlobalClusters({
  1. String? globalClusterIdentifier,
  2. String? marker,
  3. int? maxRecords,
})

Returns information about Neptune global database clusters. This API supports pagination.

May throw GlobalClusterNotFoundFault.

Parameter globalClusterIdentifier : The user-supplied DB cluster identifier. If this parameter is specified, only information about the specified DB cluster is returned. This parameter is not case-sensitive.

Constraints: If supplied, must match an existing DB cluster identifier.

Parameter marker : (Optional) A pagination token returned by a previous call to DescribeGlobalClusters. If this parameter is specified, the response will only include records beyond the marker, up to the number specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination marker token is included in the response that you can use to retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.

Implementation

Future<GlobalClustersMessage> describeGlobalClusters({
  String? globalClusterIdentifier,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (globalClusterIdentifier != null)
      'GlobalClusterIdentifier': globalClusterIdentifier,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeGlobalClusters',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeGlobalClustersResult',
  );
  return GlobalClustersMessage.fromXml($result);
}