modifyDBParameterGroup method

Future<DBParameterGroupNameMessage> modifyDBParameterGroup({
  1. required String dBParameterGroupName,
  2. required List<Parameter> parameters,
})

Modifies the parameters of a DB parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.

May throw DBParameterGroupNotFoundFault. May throw InvalidDBParameterGroupStateFault.

Parameter dBParameterGroupName : The name of the DB parameter group.

Constraints:

  • If supplied, must match the name of an existing DBParameterGroup.

Parameter parameters : An array of parameter names, values, and the apply method for the parameter update. At least one parameter name, value, and apply method must be supplied; subsequent arguments are optional. A maximum of 20 parameters can be modified in a single request.

Valid Values (for the application method): immediate | pending-reboot

Implementation

Future<DBParameterGroupNameMessage> modifyDBParameterGroup({
  required String dBParameterGroupName,
  required List<Parameter> parameters,
}) async {
  final $request = <String, String>{
    'DBParameterGroupName': dBParameterGroupName,
    if (parameters.isEmpty)
      'Parameters': ''
    else
      for (var i1 = 0; i1 < parameters.length; i1++)
        for (var e3 in parameters[i1].toQueryMap().entries)
          'Parameters.Parameter.${i1 + 1}.${e3.key}': e3.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ModifyDBParameterGroup',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ModifyDBParameterGroupResult',
  );
  return DBParameterGroupNameMessage.fromXml($result);
}