modifyGlobalCluster method
Modify a setting for an Amazon Neptune global cluster. You can change one or more database configuration parameters by specifying these parameters and their new values in the request.
May throw GlobalClusterAlreadyExistsFault.
May throw GlobalClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidGlobalClusterStateFault.
Parameter globalClusterIdentifier :
The DB cluster identifier for the global cluster being modified. This
parameter is not case-sensitive.
Constraints: Must match the identifier of an existing global database cluster.
Parameter allowMajorVersionUpgrade :
A value that indicates whether major version upgrades are allowed.
Constraints: You must allow major version upgrades if you specify a value
for the EngineVersion parameter that is a different major
version than the DB cluster's current version.
If you upgrade the major version of a global database, the cluster and DB instance parameter groups are set to the default parameter groups for the new version, so you will need to apply any custom parameter groups after completing the upgrade.
Parameter deletionProtection :
Indicates whether the global database has deletion protection enabled. The
global database cannot be deleted when deletion protection is enabled.
Parameter engineVersion :
The version number of the database engine to which you want to upgrade.
Changing this parameter will result in an outage. The change is applied
during the next maintenance window unless ApplyImmediately is
enabled.
To list all of the available Neptune engine versions, use the following command:
Parameter newGlobalClusterIdentifier :
A new cluster identifier to assign to the global database. This value is
stored as a lowercase string.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- The first character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens
my-cluster2
Implementation
Future<ModifyGlobalClusterResult> modifyGlobalCluster({
required String globalClusterIdentifier,
bool? allowMajorVersionUpgrade,
bool? deletionProtection,
String? engineVersion,
String? newGlobalClusterIdentifier,
}) async {
final $request = <String, String>{
'GlobalClusterIdentifier': globalClusterIdentifier,
if (allowMajorVersionUpgrade != null)
'AllowMajorVersionUpgrade': allowMajorVersionUpgrade.toString(),
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (engineVersion != null) 'EngineVersion': engineVersion,
if (newGlobalClusterIdentifier != null)
'NewGlobalClusterIdentifier': newGlobalClusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'ModifyGlobalCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyGlobalClusterResult',
);
return ModifyGlobalClusterResult.fromXml($result);
}