NeptuneGraph class

Neptune Analytics is a new analytics database engine for Amazon Neptune that helps customers get to insights faster by quickly processing large amounts of graph data, invoking popular graph analytic algorithms in low-latency queries, and getting analytics results in seconds.

Constructors

NeptuneGraph({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelExportTask({required String taskIdentifier}) Future<CancelExportTaskOutput>
Cancel the specified export task.
cancelImportTask({required String taskIdentifier}) Future<CancelImportTaskOutput>
Deletes the specified import task.
cancelQuery({required String graphIdentifier, required String queryId}) Future<void>
Cancels a specified query.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createGraph({required String graphName, required int provisionedMemory, bool? deletionProtection, String? kmsKeyIdentifier, bool? publicConnectivity, int? replicaCount, Map<String, String>? tags, VectorSearchConfiguration? vectorSearchConfiguration}) Future<CreateGraphOutput>
Creates a new Neptune Analytics graph.
createGraphSnapshot({required String graphIdentifier, required String snapshotName, Map<String, String>? tags}) Future<CreateGraphSnapshotOutput>
Creates a snapshot of the specific graph.
createGraphUsingImportTask({required String graphName, required String roleArn, required String source, BlankNodeHandling? blankNodeHandling, bool? deletionProtection, bool? failOnError, Format? format, ImportOptions? importOptions, String? kmsKeyIdentifier, int? maxProvisionedMemory, int? minProvisionedMemory, ParquetType? parquetType, bool? publicConnectivity, int? replicaCount, Map<String, String>? tags, VectorSearchConfiguration? vectorSearchConfiguration}) Future<CreateGraphUsingImportTaskOutput>
Creates a new Neptune Analytics graph and imports data into it, either from Amazon Simple Storage Service (S3) or from a Neptune database or a Neptune database snapshot.
createPrivateGraphEndpoint({required String graphIdentifier, List<String>? subnetIds, String? vpcId, List<String>? vpcSecurityGroupIds}) Future<CreatePrivateGraphEndpointOutput>
Create a private graph endpoint to allow private access to the graph from within a VPC. You can attach security groups to the private graph endpoint.
deleteGraph({required String graphIdentifier, required bool skipSnapshot}) Future<DeleteGraphOutput>
Deletes the specified graph. Graphs cannot be deleted if delete-protection is enabled.
deleteGraphSnapshot({required String snapshotIdentifier}) Future<DeleteGraphSnapshotOutput>
Deletes the specified graph snapshot.
deletePrivateGraphEndpoint({required String graphIdentifier, required String vpcId}) Future<DeletePrivateGraphEndpointOutput>
Deletes a private graph endpoint.
executeQuery({required String graphIdentifier, required QueryLanguage language, required String queryString, ExplainMode? explainMode, Map<String, Document>? parameters, PlanCacheType? planCache, int? queryTimeoutMilliseconds}) Future<ExecuteQueryOutput>
Execute an openCypher query.
getExportTask({required String taskIdentifier}) Future<GetExportTaskOutput>
Retrieves a specified export task.
getGraph({required String graphIdentifier}) Future<GetGraphOutput>
Gets information about a specified graph.
getGraphSnapshot({required String snapshotIdentifier}) Future<GetGraphSnapshotOutput>
Retrieves a specified graph snapshot.
getGraphSummary({required String graphIdentifier, GraphSummaryMode? mode}) Future<GetGraphSummaryOutput>
Gets a graph summary for a property graph.
getImportTask({required String taskIdentifier}) Future<GetImportTaskOutput>
Retrieves a specified import task.
getPrivateGraphEndpoint({required String graphIdentifier, required String vpcId}) Future<GetPrivateGraphEndpointOutput>
Retrieves information about a specified private endpoint.
getQuery({required String graphIdentifier, required String queryId}) Future<GetQueryOutput>
Retrieves the status of a specified query.
listExportTasks({String? graphIdentifier, int? maxResults, String? nextToken}) Future<ListExportTasksOutput>
Retrieves a list of export tasks.
listGraphs({int? maxResults, String? nextToken}) Future<ListGraphsOutput>
Lists available Neptune Analytics graphs.
listGraphSnapshots({String? graphIdentifier, int? maxResults, String? nextToken}) Future<ListGraphSnapshotsOutput>
Lists available snapshots of a specified Neptune Analytics graph.
listImportTasks({int? maxResults, String? nextToken}) Future<ListImportTasksOutput>
Lists import tasks.
listPrivateGraphEndpoints({required String graphIdentifier, int? maxResults, String? nextToken}) Future<ListPrivateGraphEndpointsOutput>
Lists private endpoints for a specified Neptune Analytics graph.
listQueries({required String graphIdentifier, required int maxResults, QueryStateInput? state}) Future<ListQueriesOutput>
Lists active openCypher queries.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists tags associated with a specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetGraph({required String graphIdentifier, required bool skipSnapshot}) Future<ResetGraphOutput>
Empties the data from a specified Neptune Analytics graph.
restoreGraphFromSnapshot({required String graphName, required String snapshotIdentifier, bool? deletionProtection, int? provisionedMemory, bool? publicConnectivity, int? replicaCount, Map<String, String>? tags}) Future<RestoreGraphFromSnapshotOutput>
Restores a graph from a snapshot.
startExportTask({required String destination, required ExportFormat format, required String graphIdentifier, required String kmsKeyIdentifier, required String roleArn, ExportFilter? exportFilter, ParquetType? parquetType, Map<String, String>? tags}) Future<StartExportTaskOutput>
Export data from an existing Neptune Analytics graph to Amazon S3. The graph state should be AVAILABLE.
startGraph({required String graphIdentifier}) Future<StartGraphOutput>
Starts the specific graph.
startImportTask({required String graphIdentifier, required String roleArn, required String source, BlankNodeHandling? blankNodeHandling, bool? failOnError, Format? format, ImportOptions? importOptions, ParquetType? parquetType}) Future<StartImportTaskOutput>
Import data into existing Neptune Analytics graph from Amazon Simple Storage Service (S3). The graph needs to be empty and in the AVAILABLE state.
stopGraph({required String graphIdentifier}) Future<StopGraphOutput>
Stops the specific graph.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified resource.
updateGraph({required String graphIdentifier, bool? deletionProtection, int? provisionedMemory, bool? publicConnectivity}) Future<UpdateGraphOutput>
Updates the configuration of a specified Neptune Analytics graph

Operators

operator ==(Object other) bool
The equality operator.
inherited