createGraphSnapshot method

Future<CreateGraphSnapshotOutput> createGraphSnapshot({
  1. required String graphIdentifier,
  2. required String snapshotName,
  3. Map<String, String>? tags,
})

Creates a snapshot of the specific graph.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter graphIdentifier : The unique identifier of the Neptune Analytics graph.

Parameter snapshotName : The snapshot name. For example: my-snapshot-1.

The name must contain from 1 to 63 letters, numbers, or hyphens, and its first character must be a letter. It cannot end with a hyphen or contain two consecutive hyphens. Only lowercase letters are allowed.

Parameter tags : Adds metadata tags to the new graph. These tags can also be used with cost allocation reporting, or used in a Condition statement in an IAM policy.

Implementation

Future<CreateGraphSnapshotOutput> createGraphSnapshot({
  required String graphIdentifier,
  required String snapshotName,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'graphIdentifier': graphIdentifier,
    'snapshotName': snapshotName,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/snapshots',
    exceptionFnMap: _exceptionFns,
  );
  return CreateGraphSnapshotOutput.fromJson(response);
}