createPrivateGraphEndpoint method

Future<CreatePrivateGraphEndpointOutput> createPrivateGraphEndpoint({
  1. required String graphIdentifier,
  2. List<String>? subnetIds,
  3. String? vpcId,
  4. List<String>? vpcSecurityGroupIds,
})

Create a private graph endpoint to allow private access to the graph from within a VPC. You can attach security groups to the private graph endpoint.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter graphIdentifier : The unique identifier of the Neptune Analytics graph.

Parameter subnetIds : Subnets in which private graph endpoint ENIs are created.

Parameter vpcId : The VPC in which the private graph endpoint needs to be created.

Parameter vpcSecurityGroupIds : Security groups to be attached to the private graph endpoint.

Implementation

Future<CreatePrivateGraphEndpointOutput> createPrivateGraphEndpoint({
  required String graphIdentifier,
  List<String>? subnetIds,
  String? vpcId,
  List<String>? vpcSecurityGroupIds,
}) async {
  final $payload = <String, dynamic>{
    if (subnetIds != null) 'subnetIds': subnetIds,
    if (vpcId != null) 'vpcId': vpcId,
    if (vpcSecurityGroupIds != null)
      'vpcSecurityGroupIds': vpcSecurityGroupIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/graphs/${Uri.encodeComponent(graphIdentifier)}/endpoints/',
    exceptionFnMap: _exceptionFns,
  );
  return CreatePrivateGraphEndpointOutput.fromJson(response);
}