deleteGraph method

Future<DeleteGraphOutput> deleteGraph({
  1. required String graphIdentifier,
  2. required bool skipSnapshot,
})

Deletes the specified graph. Graphs cannot be deleted if delete-protection is enabled.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter graphIdentifier : The unique identifier of the Neptune Analytics graph.

Parameter skipSnapshot : Determines whether a final graph snapshot is created before the graph is deleted. If true is specified, no graph snapshot is created. If false is specified, a graph snapshot is created before the graph is deleted.

Implementation

Future<DeleteGraphOutput> deleteGraph({
  required String graphIdentifier,
  required bool skipSnapshot,
}) async {
  final $query = <String, List<String>>{
    'skipSnapshot': [skipSnapshot.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/graphs/${Uri.encodeComponent(graphIdentifier)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteGraphOutput.fromJson(response);
}