listImportTasks method
Lists import tasks.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The total number of records to return in the command's output.
If the total number of records available is more than the value specified,
nextToken is provided in the command's output. To resume
pagination, provide the nextToken output value in the
nextToken argument of a subsequent command. Do not use the
nextToken response element directly outside of the Amazon
CLI.
Parameter nextToken :
Pagination token used to paginate output.
When this value is provided as input, the service returns results from where the previous response left off. When this value is present in output, it indicates that there are more results to retrieve.
Implementation
Future<ListImportTasksOutput> listImportTasks({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/importtasks',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListImportTasksOutput.fromJson(response);
}