resetGraph method

Future<ResetGraphOutput> resetGraph({
  1. required String graphIdentifier,
  2. required bool skipSnapshot,
})

Empties the data from a specified Neptune Analytics graph.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter graphIdentifier : ID of the graph to reset.

Parameter skipSnapshot : Determines whether a final graph snapshot is created before the graph data is deleted. If set to true, no graph snapshot is created. If set to false, a graph snapshot is created before the data is deleted.

Implementation

Future<ResetGraphOutput> resetGraph({
  required String graphIdentifier,
  required bool skipSnapshot,
}) async {
  final $payload = <String, dynamic>{
    'skipSnapshot': skipSnapshot,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/graphs/${Uri.encodeComponent(graphIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return ResetGraphOutput.fromJson(response);
}