startExportTask method

Future<StartExportTaskOutput> startExportTask({
  1. required String destination,
  2. required ExportFormat format,
  3. required String graphIdentifier,
  4. required String kmsKeyIdentifier,
  5. required String roleArn,
  6. ExportFilter? exportFilter,
  7. ParquetType? parquetType,
  8. Map<String, String>? tags,
})

Export data from an existing Neptune Analytics graph to Amazon S3. The graph state should be AVAILABLE.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter destination : The Amazon S3 URI where data will be exported to.

Parameter format : The format of the export task.

Parameter graphIdentifier : The source graph identifier of the export task.

Parameter kmsKeyIdentifier : The KMS key identifier of the export task.

Parameter roleArn : The ARN of the IAM role that will allow data to be exported to the destination.

Parameter exportFilter : The export filter of the export task.

Parameter parquetType : The parquet type of the export task.

Parameter tags : Tags to be applied to the export task.

Implementation

Future<StartExportTaskOutput> startExportTask({
  required String destination,
  required ExportFormat format,
  required String graphIdentifier,
  required String kmsKeyIdentifier,
  required String roleArn,
  ExportFilter? exportFilter,
  ParquetType? parquetType,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'destination': destination,
    'format': format.value,
    'graphIdentifier': graphIdentifier,
    'kmsKeyIdentifier': kmsKeyIdentifier,
    'roleArn': roleArn,
    if (exportFilter != null) 'exportFilter': exportFilter,
    if (parquetType != null) 'parquetType': parquetType.value,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/exporttasks',
    exceptionFnMap: _exceptionFns,
  );
  return StartExportTaskOutput.fromJson(response);
}