neptune_graph_2023_11_29 library

Classes

AwsClientCredentials
AWS credentials.
NeptuneGraph
Neptune Analytics is a new analytics database engine for Amazon Neptune that helps customers get to insights faster by quickly processing large amounts of graph data, invoking popular graph analytic algorithms in low-latency queries, and getting analytics results in seconds.