Neptunedata class

The Amazon Neptune data API provides SDK support for more than 40 of Neptune's data operations, including data loading, query execution, data inquiry, and machine learning. It supports the Gremlin and openCypher query languages, and is available in all SDK languages. It automatically signs API requests and greatly simplifies integrating Neptune into your applications.

Constructors

Neptunedata({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelGremlinQuery({required String queryId}) Future<CancelGremlinQueryOutput>
Cancels a Gremlin query. See Gremlin query cancellation for more information.
cancelLoaderJob({required String loadId}) Future<CancelLoaderJobOutput>
Cancels a specified load job. This is an HTTP DELETE request. See Neptune Loader Get-Status API for more information.
cancelMLDataProcessingJob({required String id, bool? clean, String? neptuneIamRoleArn}) Future<CancelMLDataProcessingJobOutput>
Cancels a Neptune ML data processing job. See The dataprocessing command.
cancelMLModelTrainingJob({required String id, bool? clean, String? neptuneIamRoleArn}) Future<CancelMLModelTrainingJobOutput>
Cancels a Neptune ML model training job. See Model training using the modeltraining command.
cancelMLModelTransformJob({required String id, bool? clean, String? neptuneIamRoleArn}) Future<CancelMLModelTransformJobOutput>
Cancels a specified model transform job. See Use a trained model to generate new model artifacts.
cancelOpenCypherQuery({required String queryId, bool? silent}) Future<CancelOpenCypherQueryOutput>
Cancels a specified openCypher query. See Neptune openCypher status endpoint for more information.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createMLEndpoint({String? id, int? instanceCount, String? instanceType, String? mlModelTrainingJobId, String? mlModelTransformJobId, String? modelName, String? neptuneIamRoleArn, bool? update, String? volumeEncryptionKMSKey}) Future<CreateMLEndpointOutput>
Creates a new Neptune ML inference endpoint that lets you query one specific model that the model-training process constructed. See Managing inference endpoints using the endpoints command.
deleteMLEndpoint({required String id, bool? clean, String? neptuneIamRoleArn}) Future<DeleteMLEndpointOutput>
Cancels the creation of a Neptune ML inference endpoint. See Managing inference endpoints using the endpoints command.
deletePropertygraphStatistics() Future<DeletePropertygraphStatisticsOutput>
Deletes statistics for Gremlin and openCypher (property graph) data.
deleteSparqlStatistics() Future<DeleteSparqlStatisticsOutput>
Deletes SPARQL statistics
executeFastReset({required Action action, String? token}) Future<ExecuteFastResetOutput>
The fast reset REST API lets you reset a Neptune graph quicky and easily, removing all of its data.
executeGremlinExplainQuery({required String gremlinQuery}) Future<ExecuteGremlinExplainQueryOutput>
Executes a Gremlin Explain query.
executeGremlinProfileQuery({required String gremlinQuery, int? chop, bool? indexOps, bool? results, String? serializer}) Future<ExecuteGremlinProfileQueryOutput>
Executes a Gremlin Profile query, which runs a specified traversal, collects various metrics about the run, and produces a profile report as output. See Gremlin profile API in Neptune for details.
executeGremlinQuery({required String gremlinQuery, String? serializer}) Future<ExecuteGremlinQueryOutput>
This commands executes a Gremlin query. Amazon Neptune is compatible with Apache TinkerPop3 and Gremlin, so you can use the Gremlin traversal language to query the graph, as described under The Graph in the Apache TinkerPop3 documentation. More details can also be found in Accessing a Neptune graph with Gremlin.
executeOpenCypherExplainQuery({required OpenCypherExplainMode explainMode, required String openCypherQuery, String? parameters}) Future<ExecuteOpenCypherExplainQueryOutput>
Executes an openCypher explain request. See The openCypher explain feature for more information.
executeOpenCypherQuery({required String openCypherQuery, String? parameters}) Future<ExecuteOpenCypherQueryOutput>
Executes an openCypher query. See Accessing the Neptune Graph with openCypher for more information.
getEngineStatus() Future<GetEngineStatusOutput>
Retrieves the status of the graph database on the host.
getGremlinQueryStatus({required String queryId}) Future<GetGremlinQueryStatusOutput>
Gets the status of a specified Gremlin query.
getLoaderJobStatus({required String loadId, bool? details, bool? errors, int? errorsPerPage, int? page}) Future<GetLoaderJobStatusOutput>
Gets status information about a specified load job. Neptune keeps track of the most recent 1,024 bulk load jobs, and stores the last 10,000 error details per job.
getMLDataProcessingJob({required String id, String? neptuneIamRoleArn}) Future<GetMLDataProcessingJobOutput>
Retrieves information about a specified data processing job. See The dataprocessing command.
getMLEndpoint({required String id, String? neptuneIamRoleArn}) Future<GetMLEndpointOutput>
Retrieves details about an inference endpoint. See Managing inference endpoints using the endpoints command.
getMLModelTrainingJob({required String id, String? neptuneIamRoleArn}) Future<GetMLModelTrainingJobOutput>
Retrieves information about a Neptune ML model training job. See Model training using the modeltraining command.
getMLModelTransformJob({required String id, String? neptuneIamRoleArn}) Future<GetMLModelTransformJobOutput>
Gets information about a specified model transform job. See Use a trained model to generate new model artifacts.
getOpenCypherQueryStatus({required String queryId}) Future<GetOpenCypherQueryStatusOutput>
Retrieves the status of a specified openCypher query.
getPropertygraphStatistics() Future<GetPropertygraphStatisticsOutput>
Gets property graph statistics (Gremlin and openCypher).
getPropertygraphStream({int? commitNum, Encoding? encoding, IteratorType? iteratorType, int? limit, int? opNum}) Future<GetPropertygraphStreamOutput>
Gets a stream for a property graph.
getPropertygraphSummary({GraphSummaryType? mode}) Future<GetPropertygraphSummaryOutput>
Gets a graph summary for a property graph.
getRDFGraphSummary({GraphSummaryType? mode}) Future<GetRDFGraphSummaryOutput>
Gets a graph summary for an RDF graph.
getSparqlStatistics() Future<GetSparqlStatisticsOutput>
Gets RDF statistics (SPARQL).
getSparqlStream({int? commitNum, Encoding? encoding, IteratorType? iteratorType, int? limit, int? opNum}) Future<GetSparqlStreamOutput>
Gets a stream for an RDF graph.
listGremlinQueries({bool? includeWaiting}) Future<ListGremlinQueriesOutput>
Lists active Gremlin queries. See Gremlin query status API for details about the output.
listLoaderJobs({bool? includeQueuedLoads, int? limit}) Future<ListLoaderJobsOutput>
Retrieves a list of the loadIds for all active loader jobs.
listMLDataProcessingJobs({int? maxItems, String? neptuneIamRoleArn}) Future<ListMLDataProcessingJobsOutput>
Returns a list of Neptune ML data processing jobs. See Listing active data-processing jobs using the Neptune ML dataprocessing command.
listMLEndpoints({int? maxItems, String? neptuneIamRoleArn}) Future<ListMLEndpointsOutput>
Lists existing inference endpoints. See Managing inference endpoints using the endpoints command.
listMLModelTrainingJobs({int? maxItems, String? neptuneIamRoleArn}) Future<ListMLModelTrainingJobsOutput>
Lists Neptune ML model-training jobs. See Model training using the modeltraining command.
listMLModelTransformJobs({int? maxItems, String? neptuneIamRoleArn}) Future<ListMLModelTransformJobsOutput>
Returns a list of model transform job IDs. See Use a trained model to generate new model artifacts.
listOpenCypherQueries({bool? includeWaiting}) Future<ListOpenCypherQueriesOutput>
Lists active openCypher queries. See Neptune openCypher status endpoint for more information.
managePropertygraphStatistics({StatisticsAutoGenerationMode? mode}) Future<ManagePropertygraphStatisticsOutput>
Manages the generation and use of property graph statistics.
manageSparqlStatistics({StatisticsAutoGenerationMode? mode}) Future<ManageSparqlStatisticsOutput>
Manages the generation and use of RDF graph statistics.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startLoaderJob({required Format format, required String iamRoleArn, required S3BucketRegion s3BucketRegion, required String source, List<String>? dependencies, bool? edgeOnlyLoad, bool? failOnError, Mode? mode, Parallelism? parallelism, Map<String, String>? parserConfiguration, bool? queueRequest, bool? updateSingleCardinalityProperties, bool? userProvidedEdgeIds}) Future<StartLoaderJobOutput>
Starts a Neptune bulk loader job to load data from an Amazon S3 bucket into a Neptune DB instance. See Using the Amazon Neptune Bulk Loader to Ingest Data.
startMLDataProcessingJob({required String inputDataS3Location, required String processedDataS3Location, String? configFileName, String? id, String? modelType, String? neptuneIamRoleArn, String? previousDataProcessingJobId, String? processingInstanceType, int? processingInstanceVolumeSizeInGB, int? processingTimeOutInSeconds, String? s3OutputEncryptionKMSKey, String? sagemakerIamRoleArn, List<String>? securityGroupIds, List<String>? subnets, String? volumeEncryptionKMSKey}) Future<StartMLDataProcessingJobOutput>
Creates a new Neptune ML data processing job for processing the graph data exported from Neptune for training. See The dataprocessing command.
startMLModelTrainingJob({required String dataProcessingJobId, required String trainModelS3Location, String? baseProcessingInstanceType, CustomModelTrainingParameters? customModelTrainingParameters, bool? enableManagedSpotTraining, String? id, int? maxHPONumberOfTrainingJobs, int? maxHPOParallelTrainingJobs, String? neptuneIamRoleArn, String? previousModelTrainingJobId, String? s3OutputEncryptionKMSKey, String? sagemakerIamRoleArn, List<String>? securityGroupIds, List<String>? subnets, String? trainingInstanceType, int? trainingInstanceVolumeSizeInGB, int? trainingTimeOutInSeconds, String? volumeEncryptionKMSKey}) Future<StartMLModelTrainingJobOutput>
Creates a new Neptune ML model training job. See Model training using the modeltraining command.
startMLModelTransformJob({required String modelTransformOutputS3Location, String? baseProcessingInstanceType, int? baseProcessingInstanceVolumeSizeInGB, CustomModelTransformParameters? customModelTransformParameters, String? dataProcessingJobId, String? id, String? mlModelTrainingJobId, String? neptuneIamRoleArn, String? s3OutputEncryptionKMSKey, String? sagemakerIamRoleArn, List<String>? securityGroupIds, List<String>? subnets, String? trainingJobName, String? volumeEncryptionKMSKey}) Future<StartMLModelTransformJobOutput>
Creates a new model transform job. See Use a trained model to generate new model artifacts.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited