cancelGremlinQuery method
Cancels a Gremlin query. See Gremlin query cancellation for more information.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:CancelQuery IAM action in that cluster.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw FailureByQueryException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw ParsingException.
May throw PreconditionsFailedException.
May throw TimeLimitExceededException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter queryId :
The unique identifier that identifies the query to be canceled.
Implementation
Future<CancelGremlinQueryOutput> cancelGremlinQuery({
required String queryId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/gremlin/status/${Uri.encodeComponent(queryId)}',
exceptionFnMap: _exceptionFns,
);
return CancelGremlinQueryOutput.fromJson(response);
}