cancelLoaderJob method

Future<CancelLoaderJobOutput> cancelLoaderJob({
  1. required String loadId,
})

Cancels a specified load job. This is an HTTP DELETE request. See Neptune Loader Get-Status API for more information.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:CancelLoaderJob IAM action in that cluster..

May throw BadRequestException. May throw BulkLoadIdNotFoundException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InternalFailureException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw LoadUrlAccessDeniedException. May throw MissingParameterException. May throw PreconditionsFailedException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter loadId : The ID of the load job to be deleted.

Implementation

Future<CancelLoaderJobOutput> cancelLoaderJob({
  required String loadId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/loader/${Uri.encodeComponent(loadId)}',
    exceptionFnMap: _exceptionFns,
  );
  return CancelLoaderJobOutput.fromJson(response);
}