cancelOpenCypherQuery method

Future<CancelOpenCypherQueryOutput> cancelOpenCypherQuery({
  1. required String queryId,
  2. bool? silent,
})

Cancels a specified openCypher query. See Neptune openCypher status endpoint for more information.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:CancelQuery IAM action in that cluster.

May throw BadRequestException. May throw ClientTimeoutException. May throw ConcurrentModificationException. May throw ConstraintViolationException. May throw FailureByQueryException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidNumericDataException. May throw InvalidParameterException. May throw MissingParameterException. May throw ParsingException. May throw PreconditionsFailedException. May throw TimeLimitExceededException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter queryId : The unique ID of the openCypher query to cancel.

Parameter silent : If set to TRUE, causes the cancelation of the openCypher query to happen silently.

Implementation

Future<CancelOpenCypherQueryOutput> cancelOpenCypherQuery({
  required String queryId,
  bool? silent,
}) async {
  final $query = <String, List<String>>{
    if (silent != null) 'silent': [silent.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/opencypher/status/${Uri.encodeComponent(queryId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return CancelOpenCypherQueryOutput.fromJson(response);
}