deleteMLEndpoint method

Future<DeleteMLEndpointOutput> deleteMLEndpoint({
  1. required String id,
  2. bool? clean,
  3. String? neptuneIamRoleArn,
})

Cancels the creation of a Neptune ML inference endpoint. See Managing inference endpoints using the endpoints command.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:DeleteMLEndpoint IAM action in that cluster.

May throw BadRequestException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw MissingParameterException. May throw MLResourceNotFoundException. May throw PreconditionsFailedException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter id : The unique identifier of the inference endpoint.

Parameter clean : If this flag is set to TRUE, all Neptune ML S3 artifacts should be deleted when the job is stopped. The default is FALSE.

Parameter neptuneIamRoleArn : The ARN of an IAM role providing Neptune access to SageMaker and Amazon S3 resources. This must be listed in your DB cluster parameter group or an error will be thrown.

Implementation

Future<DeleteMLEndpointOutput> deleteMLEndpoint({
  required String id,
  bool? clean,
  String? neptuneIamRoleArn,
}) async {
  final $query = <String, List<String>>{
    if (clean != null) 'clean': [clean.toString()],
    if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': [neptuneIamRoleArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/ml/endpoints/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteMLEndpointOutput.fromJson(response);
}