getEngineStatus method
Retrieves the status of the graph database on the host.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetEngineStatus IAM action in that cluster.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InternalFailureException.
May throw InvalidArgumentException.
May throw PreconditionsFailedException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Implementation
Future<GetEngineStatusOutput> getEngineStatus() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/status',
exceptionFnMap: _exceptionFns,
);
return GetEngineStatusOutput.fromJson(response);
}