getGremlinQueryStatus method
Gets the status of a specified Gremlin query.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetQueryStatus IAM action in that cluster.
Note that the neptune-db:QueryLanguage:Gremlin IAM condition key can be used in the policy document to restrict the use of Gremlin queries (see Condition keys available in Neptune IAM data-access policy statements).
May throw AccessDeniedException.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw FailureByQueryException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw ParsingException.
May throw PreconditionsFailedException.
May throw ReadOnlyViolationException.
May throw TimeLimitExceededException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter queryId :
The unique identifier that identifies the Gremlin query.
Implementation
Future<GetGremlinQueryStatusOutput> getGremlinQueryStatus({
required String queryId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/gremlin/status/${Uri.encodeComponent(queryId)}',
exceptionFnMap: _exceptionFns,
);
return GetGremlinQueryStatusOutput.fromJson(response);
}