getMLEndpoint method
Retrieves details about an inference endpoint. See Managing inference endpoints using the endpoints command.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetMLEndpointStatus IAM action in that cluster.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw MLResourceNotFoundException.
May throw PreconditionsFailedException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter id :
The unique identifier of the inference endpoint.
Parameter neptuneIamRoleArn :
The ARN of an IAM role that provides Neptune access to SageMaker and
Amazon S3 resources. This must be listed in your DB cluster parameter
group or an error will occur.
Implementation
Future<GetMLEndpointOutput> getMLEndpoint({
required String id,
String? neptuneIamRoleArn,
}) async {
final $query = <String, List<String>>{
if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': [neptuneIamRoleArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/ml/endpoints/${Uri.encodeComponent(id)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetMLEndpointOutput.fromJson(response);
}