getMLModelTrainingJob method

Future<GetMLModelTrainingJobOutput> getMLModelTrainingJob({
  1. required String id,
  2. String? neptuneIamRoleArn,
})

Retrieves information about a Neptune ML model training job. See Model training using the modeltraining command.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetMLModelTrainingJobStatus IAM action in that cluster.

May throw BadRequestException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw MissingParameterException. May throw MLResourceNotFoundException. May throw PreconditionsFailedException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter id : The unique identifier of the model-training job to retrieve.

Parameter neptuneIamRoleArn : The ARN of an IAM role that provides Neptune access to SageMaker and Amazon S3 resources. This must be listed in your DB cluster parameter group or an error will occur.

Implementation

Future<GetMLModelTrainingJobOutput> getMLModelTrainingJob({
  required String id,
  String? neptuneIamRoleArn,
}) async {
  final $query = <String, List<String>>{
    if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': [neptuneIamRoleArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/ml/modeltraining/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetMLModelTrainingJobOutput.fromJson(response);
}