getPropertygraphStatistics method

Future<GetPropertygraphStatisticsOutput> getPropertygraphStatistics()

Gets property graph statistics (Gremlin and openCypher).

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetStatisticsStatus IAM action in that cluster.

May throw AccessDeniedException. May throw BadRequestException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw MissingParameterException. May throw PreconditionsFailedException. May throw ReadOnlyViolationException. May throw StatisticsNotAvailableException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Implementation

Future<GetPropertygraphStatisticsOutput> getPropertygraphStatistics() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/propertygraph/statistics',
    exceptionFnMap: _exceptionFns,
  );
  return GetPropertygraphStatisticsOutput.fromJson(response);
}