getRDFGraphSummary method
Gets a graph summary for an RDF graph.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetGraphSummary IAM action in that cluster.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw PreconditionsFailedException.
May throw ReadOnlyViolationException.
May throw StatisticsNotAvailableException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter mode :
Mode can take one of two values: BASIC (the default), and
DETAILED.
Implementation
Future<GetRDFGraphSummaryOutput> getRDFGraphSummary({
GraphSummaryType? mode,
}) async {
final $query = <String, List<String>>{
if (mode != null) 'mode': [mode.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/rdf/statistics/summary',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetRDFGraphSummaryOutput.fromJson(response);
}