listLoaderJobs method
Retrieves a list of the loadIds for all active loader jobs.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:ListLoaderJobs IAM action in that cluster..
May throw BadRequestException.
May throw BulkLoadIdNotFoundException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InternalFailureException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw LoadUrlAccessDeniedException.
May throw PreconditionsFailedException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter includeQueuedLoads :
An optional parameter that can be used to exclude the load IDs of queued
load requests when requesting a list of load IDs by setting the parameter
to FALSE. The default value is TRUE.
Parameter limit :
The number of load IDs to list. Must be a positive integer greater than
zero and not more than 100 (which is the default).
Implementation
Future<ListLoaderJobsOutput> listLoaderJobs({
bool? includeQueuedLoads,
int? limit,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
1152921504606846976,
);
final $query = <String, List<String>>{
if (includeQueuedLoads != null)
'includeQueuedLoads': [includeQueuedLoads.toString()],
if (limit != null) 'limit': [limit.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/loader',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListLoaderJobsOutput.fromJson(response);
}