listOpenCypherQueries method
Lists active openCypher queries. See Neptune openCypher status endpoint for more information.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetQueryStatus IAM action in that cluster.
Note that the neptune-db:QueryLanguage:OpenCypher IAM condition key can be used in the policy document to restrict the use of openCypher queries (see Condition keys available in Neptune IAM data-access policy statements).
May throw AccessDeniedException.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw FailureByQueryException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidNumericDataException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw ParsingException.
May throw PreconditionsFailedException.
May throw ReadOnlyViolationException.
May throw TimeLimitExceededException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter includeWaiting :
When set to TRUE and other parameters are not present, causes
status information to be returned for waiting queries as well as for
running queries.
Implementation
Future<ListOpenCypherQueriesOutput> listOpenCypherQueries({
bool? includeWaiting,
}) async {
final $query = <String, List<String>>{
if (includeWaiting != null) 'includeWaiting': [includeWaiting.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/opencypher/status',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListOpenCypherQueriesOutput.fromJson(response);
}