managePropertygraphStatistics method

Future<ManagePropertygraphStatisticsOutput> managePropertygraphStatistics({
  1. StatisticsAutoGenerationMode? mode,
})

Manages the generation and use of property graph statistics.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:ManageStatistics IAM action in that cluster.

May throw AccessDeniedException. May throw BadRequestException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw MissingParameterException. May throw PreconditionsFailedException. May throw ReadOnlyViolationException. May throw StatisticsNotAvailableException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter mode : The statistics generation mode. One of: DISABLE_AUTOCOMPUTE, ENABLE_AUTOCOMPUTE, or REFRESH, the last of which manually triggers DFE statistics generation.

Implementation

Future<ManagePropertygraphStatisticsOutput> managePropertygraphStatistics({
  StatisticsAutoGenerationMode? mode,
}) async {
  final $payload = <String, dynamic>{
    if (mode != null) 'mode': mode.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/propertygraph/statistics',
    exceptionFnMap: _exceptionFns,
  );
  return ManagePropertygraphStatisticsOutput.fromJson(response);
}