startMLModelTrainingJob method
- required String dataProcessingJobId,
- required String trainModelS3Location,
- String? baseProcessingInstanceType,
- CustomModelTrainingParameters? customModelTrainingParameters,
- bool? enableManagedSpotTraining,
- String? id,
- int? maxHPONumberOfTrainingJobs,
- int? maxHPOParallelTrainingJobs,
- String? neptuneIamRoleArn,
- String? previousModelTrainingJobId,
- String? s3OutputEncryptionKMSKey,
- String? sagemakerIamRoleArn,
- List<
String> ? securityGroupIds, - List<
String> ? subnets, - String? trainingInstanceType,
- int? trainingInstanceVolumeSizeInGB,
- int? trainingTimeOutInSeconds,
- String? volumeEncryptionKMSKey,
Creates a new Neptune ML model training job. See Model
training using the modeltraining command.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:StartMLModelTrainingJob IAM action in that cluster.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw MLResourceNotFoundException.
May throw PreconditionsFailedException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter dataProcessingJobId :
The job ID of the completed data-processing job that has created the data
that the training will work with.
Parameter trainModelS3Location :
The location in Amazon S3 where the model artifacts are to be stored.
Parameter baseProcessingInstanceType :
The type of ML instance used in preparing and managing training of ML
models. This is a CPU instance chosen based on memory requirements for
processing the training data and model.
Parameter customModelTrainingParameters :
The configuration for custom model training. This is a JSON object.
Parameter enableManagedSpotTraining :
Optimizes the cost of training machine-learning models by using Amazon
Elastic Compute Cloud spot instances. The default is False.
Parameter id :
A unique identifier for the new job. The default is An autogenerated UUID.
Parameter maxHPONumberOfTrainingJobs :
Maximum total number of training jobs to start for the hyperparameter
tuning job. The default is 2. Neptune ML automatically tunes the
hyperparameters of the machine learning model. To obtain a model that
performs well, use at least 10 jobs (in other words, set
maxHPONumberOfTrainingJobs to 10). In general, the more
tuning runs, the better the results.
Parameter maxHPOParallelTrainingJobs :
Maximum number of parallel training jobs to start for the hyperparameter
tuning job. The default is 2. The number of parallel jobs you can run is
limited by the available resources on your training instance.
Parameter neptuneIamRoleArn :
The ARN of an IAM role that provides Neptune access to SageMaker and
Amazon S3 resources. This must be listed in your DB cluster parameter
group or an error will occur.
Parameter previousModelTrainingJobId :
The job ID of a completed model-training job that you want to update
incrementally based on updated data.
Parameter s3OutputEncryptionKMSKey :
The Amazon Key Management Service (KMS) key that SageMaker uses to encrypt
the output of the processing job. The default is none.
Parameter sagemakerIamRoleArn :
The ARN of an IAM role for SageMaker execution.This must be listed in your
DB cluster parameter group or an error will occur.
Parameter securityGroupIds :
The VPC security group IDs. The default is None.
Parameter subnets :
The IDs of the subnets in the Neptune VPC. The default is None.
Parameter trainingInstanceType :
The type of ML instance used for model training. All Neptune ML models
support CPU, GPU, and multiGPU training. The default is
ml.p3.2xlarge. Choosing the right instance type for training
depends on the task type, graph size, and your budget.
Parameter trainingInstanceVolumeSizeInGB :
The disk volume size of the training instance. Both input data and the
output model are stored on disk, so the volume size must be large enough
to hold both data sets. The default is 0. If not specified or 0, Neptune
ML selects a disk volume size based on the recommendation generated in the
data processing step.
Parameter trainingTimeOutInSeconds :
Timeout in seconds for the training job. The default is 86,400 (1 day).
Parameter volumeEncryptionKMSKey :
The Amazon Key Management Service (KMS) key that SageMaker uses to encrypt
data on the storage volume attached to the ML compute instances that run
the training job. The default is None.
Implementation
Future<StartMLModelTrainingJobOutput> startMLModelTrainingJob({
required String dataProcessingJobId,
required String trainModelS3Location,
String? baseProcessingInstanceType,
CustomModelTrainingParameters? customModelTrainingParameters,
bool? enableManagedSpotTraining,
String? id,
int? maxHPONumberOfTrainingJobs,
int? maxHPOParallelTrainingJobs,
String? neptuneIamRoleArn,
String? previousModelTrainingJobId,
String? s3OutputEncryptionKMSKey,
String? sagemakerIamRoleArn,
List<String>? securityGroupIds,
List<String>? subnets,
String? trainingInstanceType,
int? trainingInstanceVolumeSizeInGB,
int? trainingTimeOutInSeconds,
String? volumeEncryptionKMSKey,
}) async {
final $payload = <String, dynamic>{
'dataProcessingJobId': dataProcessingJobId,
'trainModelS3Location': trainModelS3Location,
if (baseProcessingInstanceType != null)
'baseProcessingInstanceType': baseProcessingInstanceType,
if (customModelTrainingParameters != null)
'customModelTrainingParameters': customModelTrainingParameters,
if (enableManagedSpotTraining != null)
'enableManagedSpotTraining': enableManagedSpotTraining,
if (id != null) 'id': id,
if (maxHPONumberOfTrainingJobs != null)
'maxHPONumberOfTrainingJobs': maxHPONumberOfTrainingJobs,
if (maxHPOParallelTrainingJobs != null)
'maxHPOParallelTrainingJobs': maxHPOParallelTrainingJobs,
if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': neptuneIamRoleArn,
if (previousModelTrainingJobId != null)
'previousModelTrainingJobId': previousModelTrainingJobId,
if (s3OutputEncryptionKMSKey != null)
's3OutputEncryptionKMSKey': s3OutputEncryptionKMSKey,
if (sagemakerIamRoleArn != null)
'sagemakerIamRoleArn': sagemakerIamRoleArn,
if (securityGroupIds != null) 'securityGroupIds': securityGroupIds,
if (subnets != null) 'subnets': subnets,
if (trainingInstanceType != null)
'trainingInstanceType': trainingInstanceType,
if (trainingInstanceVolumeSizeInGB != null)
'trainingInstanceVolumeSizeInGB': trainingInstanceVolumeSizeInGB,
if (trainingTimeOutInSeconds != null)
'trainingTimeOutInSeconds': trainingTimeOutInSeconds,
if (volumeEncryptionKMSKey != null)
'volumeEncryptionKMSKey': volumeEncryptionKMSKey,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ml/modeltraining',
exceptionFnMap: _exceptionFns,
);
return StartMLModelTrainingJobOutput.fromJson(response);
}