startMLModelTransformJob method

Future<StartMLModelTransformJobOutput> startMLModelTransformJob({
  1. required String modelTransformOutputS3Location,
  2. String? baseProcessingInstanceType,
  3. int? baseProcessingInstanceVolumeSizeInGB,
  4. CustomModelTransformParameters? customModelTransformParameters,
  5. String? dataProcessingJobId,
  6. String? id,
  7. String? mlModelTrainingJobId,
  8. String? neptuneIamRoleArn,
  9. String? s3OutputEncryptionKMSKey,
  10. String? sagemakerIamRoleArn,
  11. List<String>? securityGroupIds,
  12. List<String>? subnets,
  13. String? trainingJobName,
  14. String? volumeEncryptionKMSKey,
})

Creates a new model transform job. See Use a trained model to generate new model artifacts.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:StartMLModelTransformJob IAM action in that cluster.

May throw BadRequestException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw MissingParameterException. May throw MLResourceNotFoundException. May throw PreconditionsFailedException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter modelTransformOutputS3Location : The location in Amazon S3 where the model artifacts are to be stored.

Parameter baseProcessingInstanceType : The type of ML instance used in preparing and managing training of ML models. This is an ML compute instance chosen based on memory requirements for processing the training data and model.

Parameter baseProcessingInstanceVolumeSizeInGB : The disk volume size of the training instance in gigabytes. The default is 0. Both input data and the output model are stored on disk, so the volume size must be large enough to hold both data sets. If not specified or 0, Neptune ML selects a disk volume size based on the recommendation generated in the data processing step.

Parameter customModelTransformParameters : Configuration information for a model transform using a custom model. The customModelTransformParameters object contains the following fields, which must have values compatible with the saved model parameters from the training job:

Parameter dataProcessingJobId : The job ID of a completed data-processing job. You must include either dataProcessingJobId and a mlModelTrainingJobId, or a trainingJobName.

Parameter id : A unique identifier for the new job. The default is an autogenerated UUID.

Parameter mlModelTrainingJobId : The job ID of a completed model-training job. You must include either dataProcessingJobId and a mlModelTrainingJobId, or a trainingJobName.

Parameter neptuneIamRoleArn : The ARN of an IAM role that provides Neptune access to SageMaker and Amazon S3 resources. This must be listed in your DB cluster parameter group or an error will occur.

Parameter s3OutputEncryptionKMSKey : The Amazon Key Management Service (KMS) key that SageMaker uses to encrypt the output of the processing job. The default is none.

Parameter sagemakerIamRoleArn : The ARN of an IAM role for SageMaker execution. This must be listed in your DB cluster parameter group or an error will occur.

Parameter securityGroupIds : The VPC security group IDs. The default is None.

Parameter subnets : The IDs of the subnets in the Neptune VPC. The default is None.

Parameter trainingJobName : The name of a completed SageMaker training job. You must include either dataProcessingJobId and a mlModelTrainingJobId, or a trainingJobName.

Parameter volumeEncryptionKMSKey : The Amazon Key Management Service (KMS) key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instances that run the training job. The default is None.

Implementation

Future<StartMLModelTransformJobOutput> startMLModelTransformJob({
  required String modelTransformOutputS3Location,
  String? baseProcessingInstanceType,
  int? baseProcessingInstanceVolumeSizeInGB,
  CustomModelTransformParameters? customModelTransformParameters,
  String? dataProcessingJobId,
  String? id,
  String? mlModelTrainingJobId,
  String? neptuneIamRoleArn,
  String? s3OutputEncryptionKMSKey,
  String? sagemakerIamRoleArn,
  List<String>? securityGroupIds,
  List<String>? subnets,
  String? trainingJobName,
  String? volumeEncryptionKMSKey,
}) async {
  final $payload = <String, dynamic>{
    'modelTransformOutputS3Location': modelTransformOutputS3Location,
    if (baseProcessingInstanceType != null)
      'baseProcessingInstanceType': baseProcessingInstanceType,
    if (baseProcessingInstanceVolumeSizeInGB != null)
      'baseProcessingInstanceVolumeSizeInGB':
          baseProcessingInstanceVolumeSizeInGB,
    if (customModelTransformParameters != null)
      'customModelTransformParameters': customModelTransformParameters,
    if (dataProcessingJobId != null)
      'dataProcessingJobId': dataProcessingJobId,
    if (id != null) 'id': id,
    if (mlModelTrainingJobId != null)
      'mlModelTrainingJobId': mlModelTrainingJobId,
    if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': neptuneIamRoleArn,
    if (s3OutputEncryptionKMSKey != null)
      's3OutputEncryptionKMSKey': s3OutputEncryptionKMSKey,
    if (sagemakerIamRoleArn != null)
      'sagemakerIamRoleArn': sagemakerIamRoleArn,
    if (securityGroupIds != null) 'securityGroupIds': securityGroupIds,
    if (subnets != null) 'subnets': subnets,
    if (trainingJobName != null) 'trainingJobName': trainingJobName,
    if (volumeEncryptionKMSKey != null)
      'volumeEncryptionKMSKey': volumeEncryptionKMSKey,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ml/modeltransform',
    exceptionFnMap: _exceptionFns,
  );
  return StartMLModelTransformJobOutput.fromJson(response);
}