acceptNetworkFirewallTransitGatewayAttachment method
- required String transitGatewayAttachmentId,
Accepts a transit gateway attachment request for Network Firewall. When you accept the attachment request, Network Firewall creates the necessary routing components to enable traffic flow between the transit gateway and firewall endpoints.
You must accept a transit gateway attachment to complete the creation of a transit gateway-attached firewall, unless auto-accept is enabled on the transit gateway. After acceptance, use DescribeFirewall to verify the firewall status.
To reject an attachment instead of accepting it, use RejectNetworkFirewallTransitGatewayAttachment.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter transitGatewayAttachmentId :
Required. The unique identifier of the transit gateway attachment to
accept. This ID is returned in the response when creating a transit
gateway-attached firewall.
Implementation
Future<AcceptNetworkFirewallTransitGatewayAttachmentResponse>
acceptNetworkFirewallTransitGatewayAttachment({
required String transitGatewayAttachmentId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.AcceptNetworkFirewallTransitGatewayAttachment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TransitGatewayAttachmentId': transitGatewayAttachmentId,
},
);
return AcceptNetworkFirewallTransitGatewayAttachmentResponse.fromJson(
jsonResponse.body);
}