createTLSInspectionConfiguration method
Creates an Network Firewall TLS inspection configuration. Network Firewall uses TLS inspection configurations to decrypt your firewall's inbound and outbound SSL/TLS traffic. After decryption, Network Firewall inspects the traffic according to your firewall policy's stateful rules, and then re-encrypts it before sending it to its destination. You can enable inspection of your firewall's inbound traffic, outbound traffic, or both. To use TLS inspection with your firewall, you must first import or provision certificates using ACM, create a TLS inspection configuration, add that configuration to a new firewall policy, and then associate that policy with your firewall.
To update the settings for a TLS inspection configuration, use UpdateTLSInspectionConfiguration.
To manage a TLS inspection configuration's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about TLS inspection configurations, use ListTLSInspectionConfigurations and DescribeTLSInspectionConfiguration.
For more information about TLS inspection configurations, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide.
May throw InsufficientCapacityException.
May throw InternalServerError.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ThrottlingException.
Parameter tLSInspectionConfiguration :
The object that defines a TLS inspection configuration. This, along with
TLSInspectionConfigurationResponse, define the TLS inspection
configuration. You can retrieve all objects for a TLS inspection
configuration by calling DescribeTLSInspectionConfiguration.
Network Firewall uses a TLS inspection configuration to decrypt traffic. Network Firewall re-encrypts the traffic before sending it to its destination.
To use a TLS inspection configuration, you add it to a new Network Firewall firewall policy, then you apply the firewall policy to a firewall. Network Firewall acts as a proxy service to decrypt and inspect the traffic traveling through your firewalls. You can reference a TLS inspection configuration from more than one firewall policy, and you can use a firewall policy in more than one firewall. For more information about using TLS inspection configurations, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide.
Parameter tLSInspectionConfigurationName :
The descriptive name of the TLS inspection configuration. You can't change
the name of a TLS inspection configuration after you create it.
Parameter description :
A description of the TLS inspection configuration.
Parameter tags :
The key:value pairs to associate with the resource.
Implementation
Future<CreateTLSInspectionConfigurationResponse>
createTLSInspectionConfiguration({
required TLSInspectionConfiguration tLSInspectionConfiguration,
required String tLSInspectionConfigurationName,
String? description,
EncryptionConfiguration? encryptionConfiguration,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.CreateTLSInspectionConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TLSInspectionConfiguration': tLSInspectionConfiguration,
'TLSInspectionConfigurationName': tLSInspectionConfigurationName,
if (description != null) 'Description': description,
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (tags != null) 'Tags': tags,
},
);
return CreateTLSInspectionConfigurationResponse.fromJson(jsonResponse.body);
}