deleteContainerAssociation method

Future<DeleteContainerAssociationResponse> deleteContainerAssociation({
  1. String? containerAssociationArn,
  2. String? containerAssociationName,
})

Deletes a container association. The resource transitions to a DELETING state. Deletion is asynchronous - Network Firewall returns immediately while cleanup proceeds in the background. You can't delete a container association while a rule group references it.

May throw InternalServerError. May throw InvalidOperationException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter containerAssociationArn : The Amazon Resource Name (ARN) of the container association.

You must specify the ARN or the name, and you can specify both.

Parameter containerAssociationName : The descriptive name of the container association.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteContainerAssociationResponse> deleteContainerAssociation({
  String? containerAssociationArn,
  String? containerAssociationName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.DeleteContainerAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (containerAssociationArn != null)
        'ContainerAssociationArn': containerAssociationArn,
      if (containerAssociationName != null)
        'ContainerAssociationName': containerAssociationName,
    },
  );

  return DeleteContainerAssociationResponse.fromJson(jsonResponse.body);
}