deleteFirewallPolicy method
Deletes the specified FirewallPolicy.
May throw InternalServerError.
May throw InvalidOperationException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedOperationException.
Parameter firewallPolicyArn :
The Amazon Resource Name (ARN) of the firewall policy.
You must specify the ARN or the name, and you can specify both.
Parameter firewallPolicyName :
The descriptive name of the firewall policy. You can't change the name of
a firewall policy after you create it.
You must specify the ARN or the name, and you can specify both.
Implementation
Future<DeleteFirewallPolicyResponse> deleteFirewallPolicy({
String? firewallPolicyArn,
String? firewallPolicyName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DeleteFirewallPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (firewallPolicyArn != null) 'FirewallPolicyArn': firewallPolicyArn,
if (firewallPolicyName != null)
'FirewallPolicyName': firewallPolicyName,
},
);
return DeleteFirewallPolicyResponse.fromJson(jsonResponse.body);
}