deleteProxy method

Future<DeleteProxyResponse> deleteProxy({
  1. required String natGatewayId,
  2. String? proxyArn,
  3. String? proxyName,
})

Deletes the specified Proxy.

Detaches a Proxy configuration from a NAT Gateway.

May throw InternalServerError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedOperationException.

Parameter natGatewayId : The NAT Gateway the proxy is attached to.

Parameter proxyArn : The Amazon Resource Name (ARN) of a proxy.

You must specify the ARN or the name, and you can specify both.

Parameter proxyName : The descriptive name of the proxy. You can't change the name of a proxy after you create it.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteProxyResponse> deleteProxy({
  required String natGatewayId,
  String? proxyArn,
  String? proxyName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.DeleteProxy'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'NatGatewayId': natGatewayId,
      if (proxyArn != null) 'ProxyArn': proxyArn,
      if (proxyName != null) 'ProxyName': proxyName,
    },
  );

  return DeleteProxyResponse.fromJson(jsonResponse.body);
}