deleteProxyConfiguration method

Future<DeleteProxyConfigurationResponse> deleteProxyConfiguration({
  1. String? proxyConfigurationArn,
  2. String? proxyConfigurationName,
})

Deletes the specified ProxyConfiguration.

May throw InternalServerError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter proxyConfigurationArn : The Amazon Resource Name (ARN) of a proxy configuration.

You must specify the ARN or the name, and you can specify both.

Parameter proxyConfigurationName : The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteProxyConfigurationResponse> deleteProxyConfiguration({
  String? proxyConfigurationArn,
  String? proxyConfigurationName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.DeleteProxyConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (proxyConfigurationArn != null)
        'ProxyConfigurationArn': proxyConfigurationArn,
      if (proxyConfigurationName != null)
        'ProxyConfigurationName': proxyConfigurationName,
    },
  );

  return DeleteProxyConfigurationResponse.fromJson(jsonResponse.body);
}