deleteProxyRuleGroup method

Future<DeleteProxyRuleGroupResponse> deleteProxyRuleGroup({
  1. String? proxyRuleGroupArn,
  2. String? proxyRuleGroupName,
})

Deletes the specified ProxyRuleGroup.

May throw InternalServerError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter proxyRuleGroupArn : The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.

Parameter proxyRuleGroupName : The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteProxyRuleGroupResponse> deleteProxyRuleGroup({
  String? proxyRuleGroupArn,
  String? proxyRuleGroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.DeleteProxyRuleGroup'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (proxyRuleGroupArn != null) 'ProxyRuleGroupArn': proxyRuleGroupArn,
      if (proxyRuleGroupName != null)
        'ProxyRuleGroupName': proxyRuleGroupName,
    },
  );

  return DeleteProxyRuleGroupResponse.fromJson(jsonResponse.body);
}