deleteTLSInspectionConfiguration method

Future<DeleteTLSInspectionConfigurationResponse> deleteTLSInspectionConfiguration({
  1. String? tLSInspectionConfigurationArn,
  2. String? tLSInspectionConfigurationName,
})

Deletes the specified TLSInspectionConfiguration.

May throw InternalServerError. May throw InvalidOperationException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter tLSInspectionConfigurationArn : The Amazon Resource Name (ARN) of the TLS inspection configuration.

You must specify the ARN or the name, and you can specify both.

Parameter tLSInspectionConfigurationName : The descriptive name of the TLS inspection configuration. You can't change the name of a TLS inspection configuration after you create it.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteTLSInspectionConfigurationResponse>
    deleteTLSInspectionConfiguration({
  String? tLSInspectionConfigurationArn,
  String? tLSInspectionConfigurationName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'NetworkFirewall_20201112.DeleteTLSInspectionConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (tLSInspectionConfigurationArn != null)
        'TLSInspectionConfigurationArn': tLSInspectionConfigurationArn,
      if (tLSInspectionConfigurationName != null)
        'TLSInspectionConfigurationName': tLSInspectionConfigurationName,
    },
  );

  return DeleteTLSInspectionConfigurationResponse.fromJson(jsonResponse.body);
}