deleteVpcEndpointAssociation method
- required String vpcEndpointAssociationArn,
Deletes the specified VpcEndpointAssociation.
You can check whether an endpoint association is in use by reviewing the route tables for the Availability Zones where you have the endpoint subnet mapping. You can retrieve the subnet mapping by calling DescribeVpcEndpointAssociation. You define and update the route tables through Amazon VPC. As needed, update the route tables for the Availability Zone to remove the firewall endpoint for the association. When the route tables no longer use the firewall endpoint, you can remove the endpoint association safely.
May throw InternalServerError.
May throw InvalidOperationException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter vpcEndpointAssociationArn :
The Amazon Resource Name (ARN) of a VPC endpoint association.
Implementation
Future<DeleteVpcEndpointAssociationResponse> deleteVpcEndpointAssociation({
required String vpcEndpointAssociationArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DeleteVpcEndpointAssociation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'VpcEndpointAssociationArn': vpcEndpointAssociationArn,
},
);
return DeleteVpcEndpointAssociationResponse.fromJson(jsonResponse.body);
}