describeProxy method
Returns the data objects for the specified proxy.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter proxyArn :
The Amazon Resource Name (ARN) of a proxy.
You must specify the ARN or the name, and you can specify both.
Parameter proxyName :
The descriptive name of the proxy. You can't change the name of a proxy
after you create it.
You must specify the ARN or the name, and you can specify both.
Implementation
Future<DescribeProxyResponse> describeProxy({
String? proxyArn,
String? proxyName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DescribeProxy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (proxyArn != null) 'ProxyArn': proxyArn,
if (proxyName != null) 'ProxyName': proxyName,
},
);
return DescribeProxyResponse.fromJson(jsonResponse.body);
}