describeRuleGroupSummary method
Returns detailed information for a stateful rule group.
For active threat defense Amazon Web Services managed rule groups, this operation provides insight into the protections enabled by the rule group, based on Suricata rule metadata fields. Summaries are available for rule groups you manage and for active threat defense Amazon Web Services managed rule groups.
To modify how threat information appears in summaries, use the
SummaryConfiguration parameter in UpdateRuleGroup.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter ruleGroupArn :
Required. The Amazon Resource Name (ARN) of the rule group.
You must specify the ARN or the name, and you can specify both.
Parameter ruleGroupName :
The descriptive name of the rule group. You can't change the name of a
rule group after you create it.
You must specify the ARN or the name, and you can specify both.
Parameter type :
The type of rule group you want a summary for. This is a required field.
Valid value: STATEFUL
Note that STATELESS exists but is not currently supported. If
you provide STATELESS, an exception is returned.
Implementation
Future<DescribeRuleGroupSummaryResponse> describeRuleGroupSummary({
String? ruleGroupArn,
String? ruleGroupName,
RuleGroupType? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DescribeRuleGroupSummary'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (ruleGroupArn != null) 'RuleGroupArn': ruleGroupArn,
if (ruleGroupName != null) 'RuleGroupName': ruleGroupName,
if (type != null) 'Type': type.value,
},
);
return DescribeRuleGroupSummaryResponse.fromJson(jsonResponse.body);
}