disassociateAvailabilityZones method
Removes the specified Availability Zone associations from a transit gateway-attached firewall. This removes the firewall endpoints from these Availability Zones and stops traffic filtering in those zones. Before removing an Availability Zone, ensure you've updated your transit gateway route tables to redirect traffic appropriately. To verify the status of your Availability Zone changes, use DescribeFirewall.
May throw InternalServerError.
May throw InvalidOperationException.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter availabilityZoneMappings :
Required. The Availability Zones to remove from the firewall's
configuration.
Parameter firewallArn :
The Amazon Resource Name (ARN) of the firewall.
You must specify the ARN or the name, and you can specify both.
Parameter firewallName :
The descriptive name of the firewall. You can't change the name of a
firewall after you create it.
You must specify the ARN or the name, and you can specify both.
Parameter updateToken :
An optional token that you can use for optimistic locking. Network
Firewall returns a token to your requests that access the firewall. The
token marks the state of the firewall resource at the time of the request.
To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.
To make a conditional change to the firewall, provide the token in your
update request. Network Firewall uses the token to ensure that the
firewall hasn't changed since you last retrieved it. If it has changed,
the operation fails with an InvalidTokenException. If this
happens, retrieve the firewall again to get a current copy of it with a
new token. Reapply your changes as needed, then try the operation again
using the new token.
Implementation
Future<DisassociateAvailabilityZonesResponse> disassociateAvailabilityZones({
required List<AvailabilityZoneMapping> availabilityZoneMappings,
String? firewallArn,
String? firewallName,
String? updateToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DisassociateAvailabilityZones'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AvailabilityZoneMappings': availabilityZoneMappings,
if (firewallArn != null) 'FirewallArn': firewallArn,
if (firewallName != null) 'FirewallName': firewallName,
if (updateToken != null) 'UpdateToken': updateToken,
},
);
return DisassociateAvailabilityZonesResponse.fromJson(jsonResponse.body);
}