listContainerAssociations method

Future<ListContainerAssociationsResponse> listContainerAssociations({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the container associations in your account and Region. Use the NextToken parameter in subsequent requests to retrieve additional results.

May throw InternalServerError. May throw InvalidRequestException. May throw ThrottlingException.

Parameter maxResults : The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

Parameter nextToken : When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request.

Implementation

Future<ListContainerAssociationsResponse> listContainerAssociations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.ListContainerAssociations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListContainerAssociationsResponse.fromJson(jsonResponse.body);
}