listFirewalls method

Future<ListFirewallsResponse> listFirewalls({
  1. int? maxResults,
  2. String? nextToken,
  3. List<String>? vpcIds,
})

Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs.

Depending on your setting for max results and the number of firewalls, a single call might not return the full list.

May throw InternalServerError. May throw InvalidRequestException. May throw ThrottlingException.

Parameter maxResults : The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

Parameter nextToken : When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request.

Parameter vpcIds : The unique identifiers of the VPCs that you want Network Firewall to retrieve the firewalls for. Leave this blank to retrieve all firewalls that you have defined.

Implementation

Future<ListFirewallsResponse> listFirewalls({
  int? maxResults,
  String? nextToken,
  List<String>? vpcIds,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.ListFirewalls'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (vpcIds != null) 'VpcIds': vpcIds,
    },
  );

  return ListFirewallsResponse.fromJson(jsonResponse.body);
}