listVpcEndpointAssociations method
Retrieves the metadata for the VPC endpoint associations that you have defined. If you specify a fireawll, this returns only the endpoint associations for that firewall.
Depending on your setting for max results and the number of associations, a single call might not return the full list.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter firewallArn :
The Amazon Resource Name (ARN) of the firewall.
If you don't specify this, Network Firewall retrieves all VPC endpoint associations that you have defined.
Parameter maxResults :
The maximum number of objects that you want Network Firewall to return for
this request. If more objects are available, in the response, Network
Firewall provides a NextToken value that you can use in a
subsequent call to get the next batch of objects.
Parameter nextToken :
When you request a list of objects with a MaxResults setting,
if the number of objects that are still available for retrieval exceeds
the maximum you requested, Network Firewall returns a
NextToken value in the response. To retrieve the next batch
of objects, use the token returned from the prior request in your next
request.
Implementation
Future<ListVpcEndpointAssociationsResponse> listVpcEndpointAssociations({
String? firewallArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.ListVpcEndpointAssociations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (firewallArn != null) 'FirewallArn': firewallArn,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListVpcEndpointAssociationsResponse.fromJson(jsonResponse.body);
}