rejectNetworkFirewallTransitGatewayAttachment method
- required String transitGatewayAttachmentId,
Rejects a transit gateway attachment request for Network Firewall. When you reject the attachment request, Network Firewall cancels the creation of routing components between the transit gateway and firewall endpoints.
Only the transit gateway owner can reject the attachment. After rejection, no traffic will flow through the firewall endpoints for this attachment.
Use DescribeFirewall to monitor the rejection status. To accept the attachment instead of rejecting it, use AcceptNetworkFirewallTransitGatewayAttachment.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter transitGatewayAttachmentId :
Required. The unique identifier of the transit gateway attachment to
reject. This ID is returned in the response when creating a transit
gateway-attached firewall.
Implementation
Future<RejectNetworkFirewallTransitGatewayAttachmentResponse>
rejectNetworkFirewallTransitGatewayAttachment({
required String transitGatewayAttachmentId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.RejectNetworkFirewallTransitGatewayAttachment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TransitGatewayAttachmentId': transitGatewayAttachmentId,
},
);
return RejectNetworkFirewallTransitGatewayAttachmentResponse.fromJson(
jsonResponse.body);
}