updateAvailabilityZoneChangeProtection method
Modifies the AvailabilityZoneChangeProtection setting for a
transit gateway-attached firewall. When enabled, this setting prevents
accidental changes to the firewall's Availability Zone configuration. This
helps protect against disrupting traffic flow in production environments.
When enabled, you must disable this protection before using AssociateAvailabilityZones or DisassociateAvailabilityZones to modify the firewall's Availability Zone configuration.
May throw InternalServerError.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ResourceOwnerCheckException.
May throw ThrottlingException.
Parameter availabilityZoneChangeProtection :
A setting indicating whether the firewall is protected against changes to
the subnet associations. Use this setting to protect against accidentally
modifying the subnet associations for a firewall that is in use. When you
create a firewall, the operation initializes this setting to
TRUE.
Parameter firewallArn :
The Amazon Resource Name (ARN) of the firewall.
You must specify the ARN or the name, and you can specify both.
Parameter firewallName :
The descriptive name of the firewall. You can't change the name of a
firewall after you create it.
You must specify the ARN or the name, and you can specify both.
Parameter updateToken :
An optional token that you can use for optimistic locking. Network
Firewall returns a token to your requests that access the firewall. The
token marks the state of the firewall resource at the time of the request.
To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.
To make a conditional change to the firewall, provide the token in your
update request. Network Firewall uses the token to ensure that the
firewall hasn't changed since you last retrieved it. If it has changed,
the operation fails with an InvalidTokenException. If this
happens, retrieve the firewall again to get a current copy of it with a
new token. Reapply your changes as needed, then try the operation again
using the new token.
Implementation
Future<UpdateAvailabilityZoneChangeProtectionResponse>
updateAvailabilityZoneChangeProtection({
required bool availabilityZoneChangeProtection,
String? firewallArn,
String? firewallName,
String? updateToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.UpdateAvailabilityZoneChangeProtection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AvailabilityZoneChangeProtection': availabilityZoneChangeProtection,
if (firewallArn != null) 'FirewallArn': firewallArn,
if (firewallName != null) 'FirewallName': firewallName,
if (updateToken != null) 'UpdateToken': updateToken,
},
);
return UpdateAvailabilityZoneChangeProtectionResponse.fromJson(
jsonResponse.body);
}