updateFirewallEncryptionConfiguration method
A complex type that contains settings for encryption of your firewall resources.
May throw InternalServerError.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ResourceOwnerCheckException.
May throw ThrottlingException.
Parameter firewallArn :
The Amazon Resource Name (ARN) of the firewall.
Parameter firewallName :
The descriptive name of the firewall. You can't change the name of a
firewall after you create it.
Parameter updateToken :
An optional token that you can use for optimistic locking. Network
Firewall returns a token to your requests that access the firewall. The
token marks the state of the firewall resource at the time of the request.
To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.
To make a conditional change to the firewall, provide the token in your
update request. Network Firewall uses the token to ensure that the
firewall hasn't changed since you last retrieved it. If it has changed,
the operation fails with an InvalidTokenException. If this
happens, retrieve the firewall again to get a current copy of it with a
new token. Reapply your changes as needed, then try the operation again
using the new token.
Implementation
Future<UpdateFirewallEncryptionConfigurationResponse>
updateFirewallEncryptionConfiguration({
EncryptionConfiguration? encryptionConfiguration,
String? firewallArn,
String? firewallName,
String? updateToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.UpdateFirewallEncryptionConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (firewallArn != null) 'FirewallArn': firewallArn,
if (firewallName != null) 'FirewallName': firewallName,
if (updateToken != null) 'UpdateToken': updateToken,
},
);
return UpdateFirewallEncryptionConfigurationResponse.fromJson(
jsonResponse.body);
}