updateFirewallPolicy method
Updates the properties of the specified firewall policy.
May throw InternalServerError.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter firewallPolicy :
The updated firewall policy to use for the firewall. You can't add or
remove a TLSInspectionConfiguration after you create a firewall
policy. However, you can replace an existing TLS inspection configuration
with another TLSInspectionConfiguration.
Parameter updateToken :
A token used for optimistic locking. Network Firewall returns a token to
your requests that access the firewall policy. The token marks the state
of the policy resource at the time of the request.
To make changes to the policy, you provide the token in your request.
Network Firewall uses the token to ensure that the policy hasn't changed
since you last retrieved it. If it has changed, the operation fails with
an InvalidTokenException. If this happens, retrieve the
firewall policy again to get a current copy of it with current token.
Reapply your changes as needed, then try the operation again using the new
token.
Parameter description :
A description of the firewall policy.
Parameter dryRun :
Indicates whether you want Network Firewall to just check the validity of
the request, rather than run the request.
If set to TRUE, Network Firewall checks whether the request
can run successfully, but doesn't actually make the requested changes. The
call returns the value that the request would return if you ran it with
dry run set to FALSE, but doesn't make additions or changes
to your resources. This option allows you to make sure that you have the
required permissions to run the request and that your request parameters
are valid.
If set to FALSE, Network Firewall makes the requested changes
to your resources.
Parameter encryptionConfiguration :
A complex type that contains settings for encryption of your firewall
policy resources.
Parameter firewallPolicyArn :
The Amazon Resource Name (ARN) of the firewall policy.
You must specify the ARN or the name, and you can specify both.
Parameter firewallPolicyName :
The descriptive name of the firewall policy. You can't change the name of
a firewall policy after you create it.
You must specify the ARN or the name, and you can specify both.
Implementation
Future<UpdateFirewallPolicyResponse> updateFirewallPolicy({
required FirewallPolicy firewallPolicy,
required String updateToken,
String? description,
bool? dryRun,
EncryptionConfiguration? encryptionConfiguration,
String? firewallPolicyArn,
String? firewallPolicyName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.UpdateFirewallPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FirewallPolicy': firewallPolicy,
'UpdateToken': updateToken,
if (description != null) 'Description': description,
if (dryRun != null) 'DryRun': dryRun,
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (firewallPolicyArn != null) 'FirewallPolicyArn': firewallPolicyArn,
if (firewallPolicyName != null)
'FirewallPolicyName': firewallPolicyName,
},
);
return UpdateFirewallPolicyResponse.fromJson(jsonResponse.body);
}