updateTLSInspectionConfiguration method
Updates the TLS inspection configuration settings for the specified TLS inspection configuration. You use a TLS inspection configuration by referencing it in one or more firewall policies. When you modify a TLS inspection configuration, you modify all firewall policies that use the TLS inspection configuration.
To update a TLS inspection configuration, first call DescribeTLSInspectionConfiguration to retrieve the current TLSInspectionConfiguration object, update the object as needed, and then provide the updated object to this call.
May throw InternalServerError.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter tLSInspectionConfiguration :
The object that defines a TLS inspection configuration. This, along with
TLSInspectionConfigurationResponse, define the TLS inspection
configuration. You can retrieve all objects for a TLS inspection
configuration by calling DescribeTLSInspectionConfiguration.
Network Firewall uses a TLS inspection configuration to decrypt traffic. Network Firewall re-encrypts the traffic before sending it to its destination.
To use a TLS inspection configuration, you add it to a new Network Firewall firewall policy, then you apply the firewall policy to a firewall. Network Firewall acts as a proxy service to decrypt and inspect the traffic traveling through your firewalls. You can reference a TLS inspection configuration from more than one firewall policy, and you can use a firewall policy in more than one firewall. For more information about using TLS inspection configurations, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide.
Parameter updateToken :
A token used for optimistic locking. Network Firewall returns a token to
your requests that access the TLS inspection configuration. The token
marks the state of the TLS inspection configuration resource at the time
of the request.
To make changes to the TLS inspection configuration, you provide the token
in your request. Network Firewall uses the token to ensure that the TLS
inspection configuration hasn't changed since you last retrieved it. If it
has changed, the operation fails with an
InvalidTokenException. If this happens, retrieve the TLS
inspection configuration again to get a current copy of it with a current
token. Reapply your changes as needed, then try the operation again using
the new token.
Parameter description :
A description of the TLS inspection configuration.
Parameter encryptionConfiguration :
A complex type that contains the Amazon Web Services KMS encryption
configuration settings for your TLS inspection configuration.
Parameter tLSInspectionConfigurationArn :
The Amazon Resource Name (ARN) of the TLS inspection configuration.
Parameter tLSInspectionConfigurationName :
The descriptive name of the TLS inspection configuration. You can't change
the name of a TLS inspection configuration after you create it.
Implementation
Future<UpdateTLSInspectionConfigurationResponse>
updateTLSInspectionConfiguration({
required TLSInspectionConfiguration tLSInspectionConfiguration,
required String updateToken,
String? description,
EncryptionConfiguration? encryptionConfiguration,
String? tLSInspectionConfigurationArn,
String? tLSInspectionConfigurationName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'NetworkFirewall_20201112.UpdateTLSInspectionConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TLSInspectionConfiguration': tLSInspectionConfiguration,
'UpdateToken': updateToken,
if (description != null) 'Description': description,
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (tLSInspectionConfigurationArn != null)
'TLSInspectionConfigurationArn': tLSInspectionConfigurationArn,
if (tLSInspectionConfigurationName != null)
'TLSInspectionConfigurationName': tLSInspectionConfigurationName,
},
);
return UpdateTLSInspectionConfigurationResponse.fromJson(jsonResponse.body);
}