NetworkFlowMonitor class

Network Flow Monitor is a feature of Amazon CloudWatch Network Monitoring that provides visibility into the performance of network flows for your Amazon Web Services workloads, between instances in subnets, as well as to and from Amazon Web Services. Lightweight agents that you install on the instances capture performance metrics for your network flows, such as packet loss and latency, and send them to the Network Flow Monitor backend. Then, you can view and analyze metrics from the top contributors for each metric type, to help troubleshoot issues.

In addition, when you create a monitor, Network Flow Monitor provides a network health indicator (NHI) that informs you whether there were Amazon Web Services network issues for one or more of the network flows tracked by a monitor, during a time period that you choose. By using this value, you can independently determine if the Amazon Web Services network is impacting your workload during a specific time frame, to help you focus troubleshooting efforts.

To learn more about Network Flow Monitor, see the Network Flow Monitor User Guide in the Amazon CloudWatch User Guide.

Constructors

NetworkFlowMonitor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createMonitor({required List<MonitorLocalResource> localResources, required String monitorName, required String scopeArn, String? clientToken, List<MonitorRemoteResource>? remoteResources, Map<String, String>? tags}) Future<CreateMonitorOutput>
Create a monitor for specific network flows between local and remote resources, so that you can monitor network performance for one or several of your workloads. For each monitor, Network Flow Monitor publishes detailed end-to-end performance metrics and a network health indicator (NHI) that informs you whether there were Amazon Web Services network issues for one or more of the network flows tracked by a monitor, during a time period that you choose.
createScope({required List<TargetResource> targets, String? clientToken, Map<String, String>? tags}) Future<CreateScopeOutput>
In Network Flow Monitor, you specify a scope for the service to generate metrics for. By using the scope, Network Flow Monitor can generate a topology of all the resources to measure performance metrics for. When you create a scope, you enable permissions for Network Flow Monitor.
deleteMonitor({required String monitorName}) Future<void>
Deletes a monitor in Network Flow Monitor.
deleteScope({required String scopeId}) Future<void>
Deletes a scope that has been defined.
getMonitor({required String monitorName}) Future<GetMonitorOutput>
Gets information about a monitor in Network Flow Monitor based on a monitor name. The information returned includes the Amazon Resource Name (ARN), create time, modified time, resources included in the monitor, and status information.
getQueryResultsMonitorTopContributors({required String monitorName, required String queryId, int? maxResults, String? nextToken}) Future<GetQueryResultsMonitorTopContributorsOutput>
Return the data for a query with the Network Flow Monitor query interface. You specify the query that you want to return results for by providing a query ID and a monitor name. This query returns the top contributors for a specific monitor.
getQueryResultsWorkloadInsightsTopContributors({required String queryId, required String scopeId, int? maxResults, String? nextToken}) Future<GetQueryResultsWorkloadInsightsTopContributorsOutput>
Return the data for a query with the Network Flow Monitor query interface. You specify the query that you want to return results for by providing a query ID and a monitor name.
getQueryResultsWorkloadInsightsTopContributorsData({required String queryId, required String scopeId, int? maxResults, String? nextToken}) Future<GetQueryResultsWorkloadInsightsTopContributorsDataOutput>
Return the data for a query with the Network Flow Monitor query interface. Specify the query that you want to return results for by providing a query ID and a scope ID.
getQueryStatusMonitorTopContributors({required String monitorName, required String queryId}) Future<GetQueryStatusMonitorTopContributorsOutput>
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor. This call returns the query status for the top contributors for a monitor.
getQueryStatusWorkloadInsightsTopContributors({required String queryId, required String scopeId}) Future<GetQueryStatusWorkloadInsightsTopContributorsOutput>
Return the data for a query with the Network Flow Monitor query interface. Specify the query that you want to return results for by providing a query ID and a monitor name. This query returns the top contributors for workload insights.
getQueryStatusWorkloadInsightsTopContributorsData({required String queryId, required String scopeId}) Future<GetQueryStatusWorkloadInsightsTopContributorsDataOutput>
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor. This call returns the query status for the top contributors data for workload insights.
getScope({required String scopeId}) Future<GetScopeOutput>
Gets information about a scope, including the name, status, tags, and target details. The scope in Network Flow Monitor is an account.
listMonitors({int? maxResults, MonitorStatus? monitorStatus, String? nextToken}) Future<ListMonitorsOutput>
List all monitors in an account. Optionally, you can list only monitors that have a specific status, by using the STATUS parameter.
listScopes({int? maxResults, String? nextToken}) Future<ListScopesOutput>
List all the scopes for an account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Returns all the tags for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startQueryMonitorTopContributors({required DestinationCategory destinationCategory, required DateTime endTime, required MonitorMetric metricName, required String monitorName, required DateTime startTime, int? limit}) Future<StartQueryMonitorTopContributorsOutput>
Create a query that you can use with the Network Flow Monitor query interface to return the top contributors for a monitor. Specify the monitor that you want to create the query for.
startQueryWorkloadInsightsTopContributors({required DestinationCategory destinationCategory, required DateTime endTime, required WorkloadInsightsMetric metricName, required String scopeId, required DateTime startTime, int? limit}) Future<StartQueryWorkloadInsightsTopContributorsOutput>
Create a query with the Network Flow Monitor query interface that you can run to return workload insights top contributors. Specify the scope that you want to create a query for.
startQueryWorkloadInsightsTopContributorsData({required DestinationCategory destinationCategory, required DateTime endTime, required WorkloadInsightsMetric metricName, required String scopeId, required DateTime startTime}) Future<StartQueryWorkloadInsightsTopContributorsDataOutput>
Create a query with the Network Flow Monitor query interface that you can run to return data for workload insights top contributors. Specify the scope that you want to create a query for.
stopQueryMonitorTopContributors({required String monitorName, required String queryId}) Future<void>
Stop a top contributors query for a monitor. Specify the query that you want to stop by providing a query ID and a monitor name.
stopQueryWorkloadInsightsTopContributors({required String queryId, required String scopeId}) Future<void>
Stop a top contributors query for workload insights. Specify the query that you want to stop by providing a query ID and a scope ID.
stopQueryWorkloadInsightsTopContributorsData({required String queryId, required String scopeId}) Future<void>
Stop a top contributors data query for workload insights. Specify the query that you want to stop by providing a query ID and a scope ID.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds a tag to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag from a resource.
updateMonitor({required String monitorName, String? clientToken, List<MonitorLocalResource>? localResourcesToAdd, List<MonitorLocalResource>? localResourcesToRemove, List<MonitorRemoteResource>? remoteResourcesToAdd, List<MonitorRemoteResource>? remoteResourcesToRemove}) Future<UpdateMonitorOutput>
Update a monitor to add or remove local or remote resources.
updateScope({required String scopeId, List<TargetResource>? resourcesToAdd, List<TargetResource>? resourcesToDelete}) Future<UpdateScopeOutput>
Update a scope to add or remove resources that you want to be available for Network Flow Monitor to generate metrics for, when you have active agents on those resources sending metrics reports to the Network Flow Monitor backend.

Operators

operator ==(Object other) bool
The equality operator.
inherited