getMonitor method

Future<GetMonitorOutput> getMonitor({
  1. required String monitorName,
})

Gets information about a monitor in Network Flow Monitor based on a monitor name. The information returned includes the Amazon Resource Name (ARN), create time, modified time, resources included in the monitor, and status information.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter monitorName : The name of the monitor.

Implementation

Future<GetMonitorOutput> getMonitor({
  required String monitorName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/monitors/${Uri.encodeComponent(monitorName)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMonitorOutput.fromJson(response);
}