NetworkManager class
Amazon Web Services enables you to centrally manage your Amazon Web Services Cloud WAN core network and your Transit Gateway network across Amazon Web Services accounts, Regions, and on-premises locations.
Constructors
- NetworkManager({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptAttachment(
{required String attachmentId}) → Future< AcceptAttachmentResponse> - Accepts a core network attachment request.
-
associateConnectPeer(
{required String connectPeerId, required String deviceId, required String globalNetworkId, String? linkId}) → Future< AssociateConnectPeerResponse> - Associates a core network Connect peer with a device and optionally, with a link.
-
associateCustomerGateway(
{required String customerGatewayArn, required String deviceId, required String globalNetworkId, String? linkId}) → Future< AssociateCustomerGatewayResponse> - Associates a customer gateway with a device and optionally, with a link. If you specify a link, it must be associated with the specified device.
-
associateLink(
{required String deviceId, required String globalNetworkId, required String linkId}) → Future< AssociateLinkResponse> - Associates a link to a device. A device can be associated to multiple links and a link can be associated to multiple devices. The device and link must be in the same global network and the same site.
-
associateTransitGatewayConnectPeer(
{required String deviceId, required String globalNetworkId, required String transitGatewayConnectPeerArn, String? linkId}) → Future< AssociateTransitGatewayConnectPeerResponse> - Associates a transit gateway Connect peer with a device, and optionally, with a link. If you specify a link, it must be associated with the specified device.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createConnectAttachment(
{required String coreNetworkId, required String edgeLocation, required ConnectAttachmentOptions options, required String transportAttachmentId, String? clientToken, String? routingPolicyLabel, List< Tag> ? tags}) → Future<CreateConnectAttachmentResponse> - Creates a core network Connect attachment from a specified core network attachment.
-
createConnection(
{required String connectedDeviceId, required String deviceId, required String globalNetworkId, String? connectedLinkId, String? description, String? linkId, List< Tag> ? tags}) → Future<CreateConnectionResponse> - Creates a connection between two devices. The devices can be a physical or virtual appliance that connects to a third-party appliance in a VPC, or a physical appliance that connects to another physical appliance in an on-premises network.
-
createConnectPeer(
{required String connectAttachmentId, required String peerAddress, BgpOptions? bgpOptions, String? clientToken, String? coreNetworkAddress, List< String> ? insideCidrBlocks, String? subnetArn, List<Tag> ? tags}) → Future<CreateConnectPeerResponse> - Creates a core network Connect peer for a specified core network connect attachment between a core network and an appliance. The peer address and transit gateway address must be the same IP address family (IPv4 or IPv6).
-
createCoreNetwork(
{required String globalNetworkId, String? clientToken, String? description, String? policyDocument, List< Tag> ? tags}) → Future<CreateCoreNetworkResponse> - Creates a core network as part of your global network, and optionally, with a core network policy.
-
createCoreNetworkPrefixListAssociation(
{required String coreNetworkId, required String prefixListAlias, required String prefixListArn, String? clientToken}) → Future< CreateCoreNetworkPrefixListAssociationResponse> - Creates an association between a core network and a prefix list for routing control.
-
createDevice(
{required String globalNetworkId, AWSLocation? awsLocation, String? description, Location? location, String? model, String? serialNumber, String? siteId, List< Tag> ? tags, String? type, String? vendor}) → Future<CreateDeviceResponse> - Creates a new device in a global network. If you specify both a site ID and a location, the location of the site is used for visualization in the Network Manager console.
-
createDirectConnectGatewayAttachment(
{required String coreNetworkId, required String directConnectGatewayArn, required List< String> edgeLocations, String? clientToken, String? routingPolicyLabel, List<Tag> ? tags}) → Future<CreateDirectConnectGatewayAttachmentResponse> - Creates an Amazon Web Services Direct Connect gateway attachment
-
createGlobalNetwork(
{String? description, List< Tag> ? tags}) → Future<CreateGlobalNetworkResponse> - Creates a new, empty global network.
-
createLink(
{required Bandwidth bandwidth, required String globalNetworkId, required String siteId, String? description, String? provider, List< Tag> ? tags, String? type}) → Future<CreateLinkResponse> - Creates a new link for a specified site.
-
createSite(
{required String globalNetworkId, String? description, Location? location, List< Tag> ? tags}) → Future<CreateSiteResponse> - Creates a new site in a global network.
-
createSiteToSiteVpnAttachment(
{required String coreNetworkId, required String vpnConnectionArn, String? clientToken, String? routingPolicyLabel, List< Tag> ? tags}) → Future<CreateSiteToSiteVpnAttachmentResponse> - Creates an Amazon Web Services site-to-site VPN attachment on an edge location of a core network.
-
createTransitGatewayPeering(
{required String coreNetworkId, required String transitGatewayArn, String? clientToken, List< Tag> ? tags}) → Future<CreateTransitGatewayPeeringResponse> - Creates a transit gateway peering connection.
-
createTransitGatewayRouteTableAttachment(
{required String peeringId, required String transitGatewayRouteTableArn, String? clientToken, String? routingPolicyLabel, List< Tag> ? tags}) → Future<CreateTransitGatewayRouteTableAttachmentResponse> - Creates a transit gateway route table attachment.
-
createVpcAttachment(
{required String coreNetworkId, required List< String> subnetArns, required String vpcArn, String? clientToken, VpcOptions? options, String? routingPolicyLabel, List<Tag> ? tags}) → Future<CreateVpcAttachmentResponse> - Creates a VPC attachment on an edge location of a core network.
-
deleteAttachment(
{required String attachmentId}) → Future< DeleteAttachmentResponse> - Deletes an attachment. Supports all attachment types.
-
deleteConnection(
{required String connectionId, required String globalNetworkId}) → Future< DeleteConnectionResponse> - Deletes the specified connection in your global network.
-
deleteConnectPeer(
{required String connectPeerId}) → Future< DeleteConnectPeerResponse> - Deletes a Connect peer.
-
deleteCoreNetwork(
{required String coreNetworkId}) → Future< DeleteCoreNetworkResponse> - Deletes a core network along with all core network policies. This can only be done if there are no attachments on a core network.
-
deleteCoreNetworkPolicyVersion(
{required String coreNetworkId, required int policyVersionId}) → Future< DeleteCoreNetworkPolicyVersionResponse> - Deletes a policy version from a core network. You can't delete the current LIVE policy.
-
deleteCoreNetworkPrefixListAssociation(
{required String coreNetworkId, required String prefixListArn}) → Future< DeleteCoreNetworkPrefixListAssociationResponse> - Deletes an association between a core network and a prefix list.
-
deleteDevice(
{required String deviceId, required String globalNetworkId}) → Future< DeleteDeviceResponse> - Deletes an existing device. You must first disassociate the device from any links and customer gateways.
-
deleteGlobalNetwork(
{required String globalNetworkId}) → Future< DeleteGlobalNetworkResponse> - Deletes an existing global network. You must first delete all global network objects (devices, links, and sites), deregister all transit gateways, and delete any core networks.
-
deleteLink(
{required String globalNetworkId, required String linkId}) → Future< DeleteLinkResponse> - Deletes an existing link. You must first disassociate the link from any devices and customer gateways.
-
deletePeering(
{required String peeringId}) → Future< DeletePeeringResponse> - Deletes an existing peering connection.
-
deleteResourcePolicy(
{required String resourceArn}) → Future< void> - Deletes a resource policy for the specified resource. This revokes the access of the principals specified in the resource policy.
-
deleteSite(
{required String globalNetworkId, required String siteId}) → Future< DeleteSiteResponse> - Deletes an existing site. The site cannot be associated with any device or link.
-
deregisterTransitGateway(
{required String globalNetworkId, required String transitGatewayArn}) → Future< DeregisterTransitGatewayResponse> - Deregisters a transit gateway from your global network. This action does not delete your transit gateway, or modify any of its attachments. This action removes any customer gateway associations.
-
describeGlobalNetworks(
{List< String> ? globalNetworkIds, int? maxResults, String? nextToken}) → Future<DescribeGlobalNetworksResponse> -
Describes one or more global networks. By default, all global networks are
described. To describe the objects in your global network, you must use
the appropriate
Get*action. For example, to list the transit gateways in your global network, use GetTransitGatewayRegistrations. -
disassociateConnectPeer(
{required String connectPeerId, required String globalNetworkId}) → Future< DisassociateConnectPeerResponse> - Disassociates a core network Connect peer from a device and a link.
-
disassociateCustomerGateway(
{required String customerGatewayArn, required String globalNetworkId}) → Future< DisassociateCustomerGatewayResponse> - Disassociates a customer gateway from a device and a link.
-
disassociateLink(
{required String deviceId, required String globalNetworkId, required String linkId}) → Future< DisassociateLinkResponse> - Disassociates an existing device from a link. You must first disassociate any customer gateways that are associated with the link.
-
disassociateTransitGatewayConnectPeer(
{required String globalNetworkId, required String transitGatewayConnectPeerArn}) → Future< DisassociateTransitGatewayConnectPeerResponse> - Disassociates a transit gateway Connect peer from a device and link.
-
executeCoreNetworkChangeSet(
{required String coreNetworkId, required int policyVersionId}) → Future< void> - Executes a change set on your core network. Deploys changes globally based on the policy submitted..
-
getConnectAttachment(
{required String attachmentId}) → Future< GetConnectAttachmentResponse> - Returns information about a core network Connect attachment.
-
getConnections(
{required String globalNetworkId, List< String> ? connectionIds, String? deviceId, int? maxResults, String? nextToken}) → Future<GetConnectionsResponse> - Gets information about one or more of your connections in a global network.
-
getConnectPeer(
{required String connectPeerId}) → Future< GetConnectPeerResponse> - Returns information about a core network Connect peer.
-
getConnectPeerAssociations(
{required String globalNetworkId, List< String> ? connectPeerIds, int? maxResults, String? nextToken}) → Future<GetConnectPeerAssociationsResponse> - Returns information about a core network Connect peer associations.
-
getCoreNetwork(
{required String coreNetworkId}) → Future< GetCoreNetworkResponse> - Returns information about the LIVE policy for a core network.
-
getCoreNetworkChangeEvents(
{required String coreNetworkId, required int policyVersionId, int? maxResults, String? nextToken}) → Future< GetCoreNetworkChangeEventsResponse> - Returns information about a core network change event.
-
getCoreNetworkChangeSet(
{required String coreNetworkId, required int policyVersionId, int? maxResults, String? nextToken}) → Future< GetCoreNetworkChangeSetResponse> - Returns a change set between the LIVE core network policy and a submitted policy.
-
getCoreNetworkPolicy(
{required String coreNetworkId, CoreNetworkPolicyAlias? alias, int? policyVersionId}) → Future< GetCoreNetworkPolicyResponse> - Returns details about a core network policy. You can get details about your current live policy or any previous policy version.
-
getCustomerGatewayAssociations(
{required String globalNetworkId, List< String> ? customerGatewayArns, int? maxResults, String? nextToken}) → Future<GetCustomerGatewayAssociationsResponse> - Gets the association information for customer gateways that are associated with devices and links in your global network.
-
getDevices(
{required String globalNetworkId, List< String> ? deviceIds, int? maxResults, String? nextToken, String? siteId}) → Future<GetDevicesResponse> - Gets information about one or more of your devices in a global network.
-
getDirectConnectGatewayAttachment(
{required String attachmentId}) → Future< GetDirectConnectGatewayAttachmentResponse> - Returns information about a specific Amazon Web Services Direct Connect gateway attachment.
-
getLinkAssociations(
{required String globalNetworkId, String? deviceId, String? linkId, int? maxResults, String? nextToken}) → Future< GetLinkAssociationsResponse> - Gets the link associations for a device or a link. Either the device ID or the link ID must be specified.
-
getLinks(
{required String globalNetworkId, List< String> ? linkIds, int? maxResults, String? nextToken, String? provider, String? siteId, String? type}) → Future<GetLinksResponse> - Gets information about one or more links in a specified global network.
-
getNetworkResourceCounts(
{required String globalNetworkId, int? maxResults, String? nextToken, String? resourceType}) → Future< GetNetworkResourceCountsResponse> - Gets the count of network resources, by resource type, for the specified global network.
-
getNetworkResourceRelationships(
{required String globalNetworkId, String? accountId, String? awsRegion, String? coreNetworkId, int? maxResults, String? nextToken, String? registeredGatewayArn, String? resourceArn, String? resourceType}) → Future< GetNetworkResourceRelationshipsResponse> - Gets the network resource relationships for the specified global network.
-
getNetworkResources(
{required String globalNetworkId, String? accountId, String? awsRegion, String? coreNetworkId, int? maxResults, String? nextToken, String? registeredGatewayArn, String? resourceArn, String? resourceType}) → Future< GetNetworkResourcesResponse> - Describes the network resources for the specified global network.
-
getNetworkRoutes(
{required String globalNetworkId, required RouteTableIdentifier routeTableIdentifier, Map< String, List< ? destinationFilters, List<String> >String> ? exactCidrMatches, List<String> ? longestPrefixMatches, List<String> ? prefixListIds, List<RouteState> ? states, List<String> ? subnetOfMatches, List<String> ? supernetOfMatches, List<RouteType> ? types}) → Future<GetNetworkRoutesResponse> - Gets the network routes of the specified global network.
-
getNetworkTelemetry(
{required String globalNetworkId, String? accountId, String? awsRegion, String? coreNetworkId, int? maxResults, String? nextToken, String? registeredGatewayArn, String? resourceArn, String? resourceType}) → Future< GetNetworkTelemetryResponse> - Gets the network telemetry of the specified global network.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> - Returns information about a resource policy.
-
getRouteAnalysis(
{required String globalNetworkId, required String routeAnalysisId}) → Future< GetRouteAnalysisResponse> - Gets information about the specified route analysis.
-
getSites(
{required String globalNetworkId, int? maxResults, String? nextToken, List< String> ? siteIds}) → Future<GetSitesResponse> - Gets information about one or more of your sites in a global network.
-
getSiteToSiteVpnAttachment(
{required String attachmentId}) → Future< GetSiteToSiteVpnAttachmentResponse> - Returns information about a site-to-site VPN attachment.
-
getTransitGatewayConnectPeerAssociations(
{required String globalNetworkId, int? maxResults, String? nextToken, List< String> ? transitGatewayConnectPeerArns}) → Future<GetTransitGatewayConnectPeerAssociationsResponse> - Gets information about one or more of your transit gateway Connect peer associations in a global network.
-
getTransitGatewayPeering(
{required String peeringId}) → Future< GetTransitGatewayPeeringResponse> - Returns information about a transit gateway peer.
-
getTransitGatewayRegistrations(
{required String globalNetworkId, int? maxResults, String? nextToken, List< String> ? transitGatewayArns}) → Future<GetTransitGatewayRegistrationsResponse> - Gets information about the transit gateway registrations in a specified global network.
-
getTransitGatewayRouteTableAttachment(
{required String attachmentId}) → Future< GetTransitGatewayRouteTableAttachmentResponse> - Returns information about a transit gateway route table attachment.
-
getVpcAttachment(
{required String attachmentId}) → Future< GetVpcAttachmentResponse> - Returns information about a VPC attachment.
-
listAttachmentRoutingPolicyAssociations(
{required String coreNetworkId, String? attachmentId, int? maxResults, String? nextToken}) → Future< ListAttachmentRoutingPolicyAssociationsResponse> - Lists the routing policy associations for attachments in a core network.
-
listAttachments(
{AttachmentType? attachmentType, String? coreNetworkId, String? edgeLocation, int? maxResults, String? nextToken, AttachmentState? state}) → Future< ListAttachmentsResponse> - Returns a list of core network attachments.
-
listConnectPeers(
{String? connectAttachmentId, String? coreNetworkId, int? maxResults, String? nextToken}) → Future< ListConnectPeersResponse> - Returns a list of core network Connect peers.
-
listCoreNetworkPolicyVersions(
{required String coreNetworkId, int? maxResults, String? nextToken}) → Future< ListCoreNetworkPolicyVersionsResponse> - Returns a list of core network policy versions.
-
listCoreNetworkPrefixListAssociations(
{required String coreNetworkId, int? maxResults, String? nextToken, String? prefixListArn}) → Future< ListCoreNetworkPrefixListAssociationsResponse> - Lists the prefix list associations for a core network.
-
listCoreNetworkRoutingInformation(
{required String coreNetworkId, required String edgeLocation, required String segmentName, List< String> ? communityMatches, List<String> ? exactAsPathMatches, List<String> ? localPreferenceMatches, int? maxResults, List<String> ? medMatches, Map<String, List< ? nextHopFilters, String? nextToken}) → Future<String> >ListCoreNetworkRoutingInformationResponse> - Lists routing information for a core network, including routes and their attributes.
-
listCoreNetworks(
{int? maxResults, String? nextToken}) → Future< ListCoreNetworksResponse> - Returns a list of owned and shared core networks.
-
listOrganizationServiceAccessStatus(
{int? maxResults, String? nextToken}) → Future< ListOrganizationServiceAccessStatusResponse> - Gets the status of the Service Linked Role (SLR) deployment for the accounts in a given Amazon Web Services Organization.
-
listPeerings(
{String? coreNetworkId, String? edgeLocation, int? maxResults, String? nextToken, PeeringType? peeringType, PeeringState? state}) → Future< ListPeeringsResponse> - Lists the peerings for a core network.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for a specified resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAttachmentRoutingPolicyLabel(
{required String attachmentId, required String coreNetworkId, required String routingPolicyLabel, String? clientToken}) → Future< PutAttachmentRoutingPolicyLabelResponse> - Applies a routing policy label to an attachment for traffic routing decisions.
-
putCoreNetworkPolicy(
{required String coreNetworkId, required Object policyDocument, String? clientToken, String? description, int? latestVersionId}) → Future< PutCoreNetworkPolicyResponse> - Creates a new, immutable version of a core network policy. A subsequent change set is created showing the differences between the LIVE policy and the submitted policy.
-
putResourcePolicy(
{required Object policyDocument, required String resourceArn}) → Future< void> - Creates or updates a resource policy.
-
registerTransitGateway(
{required String globalNetworkId, required String transitGatewayArn}) → Future< RegisterTransitGatewayResponse> - Registers a transit gateway in your global network. Not all Regions support transit gateways for global networks. For a list of the supported Regions, see Region Availability in the Amazon Web Services Transit Gateways for Global Networks User Guide. The transit gateway can be in any of the supported Amazon Web Services Regions, but it must be owned by the same Amazon Web Services account that owns the global network. You cannot register a transit gateway in more than one global network.
-
rejectAttachment(
{required String attachmentId}) → Future< RejectAttachmentResponse> - Rejects a core network attachment request.
-
removeAttachmentRoutingPolicyLabel(
{required String attachmentId, required String coreNetworkId}) → Future< RemoveAttachmentRoutingPolicyLabelResponse> - Removes a routing policy label from an attachment.
-
restoreCoreNetworkPolicyVersion(
{required String coreNetworkId, required int policyVersionId}) → Future< RestoreCoreNetworkPolicyVersionResponse> - Restores a previous policy version as a new, immutable version of a core network policy. A subsequent change set is created showing the differences between the LIVE policy and restored policy.
-
startOrganizationServiceAccessUpdate(
{required String action}) → Future< StartOrganizationServiceAccessUpdateResponse> - Enables the Network Manager service for an Amazon Web Services Organization. This can only be called by a management account within the organization.
-
startRouteAnalysis(
{required RouteAnalysisEndpointOptionsSpecification destination, required String globalNetworkId, required RouteAnalysisEndpointOptionsSpecification source, bool? includeReturnPath, bool? useMiddleboxes}) → Future< StartRouteAnalysisResponse> - Starts analyzing the routing path between the specified source and destination. For more information, see Route Analyzer.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Tags a specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from a specified resource.
-
updateConnection(
{required String connectionId, required String globalNetworkId, String? connectedLinkId, String? description, String? linkId}) → Future< UpdateConnectionResponse> - Updates the information for an existing connection. To remove information for any of the parameters, specify an empty string.
-
updateCoreNetwork(
{required String coreNetworkId, String? description}) → Future< UpdateCoreNetworkResponse> - Updates the description of a core network.
-
updateDevice(
{required String deviceId, required String globalNetworkId, AWSLocation? awsLocation, String? description, Location? location, String? model, String? serialNumber, String? siteId, String? type, String? vendor}) → Future< UpdateDeviceResponse> - Updates the details for an existing device. To remove information for any of the parameters, specify an empty string.
-
updateDirectConnectGatewayAttachment(
{required String attachmentId, List< String> ? edgeLocations}) → Future<UpdateDirectConnectGatewayAttachmentResponse> - Updates the edge locations associated with an Amazon Web Services Direct Connect gateway attachment.
-
updateGlobalNetwork(
{required String globalNetworkId, String? description}) → Future< UpdateGlobalNetworkResponse> - Updates an existing global network. To remove information for any of the parameters, specify an empty string.
-
updateLink(
{required String globalNetworkId, required String linkId, Bandwidth? bandwidth, String? description, String? provider, String? type}) → Future< UpdateLinkResponse> - Updates the details for an existing link. To remove information for any of the parameters, specify an empty string.
-
updateNetworkResourceMetadata(
{required String globalNetworkId, required Map< String, String> metadata, required String resourceArn}) → Future<UpdateNetworkResourceMetadataResponse> - Updates the resource metadata for the specified global network.
-
updateSite(
{required String globalNetworkId, required String siteId, String? description, Location? location}) → Future< UpdateSiteResponse> - Updates the information for an existing site. To remove information for any of the parameters, specify an empty string.
-
updateVpcAttachment(
{required String attachmentId, List< String> ? addSubnetArns, VpcOptions? options, List<String> ? removeSubnetArns}) → Future<UpdateVpcAttachmentResponse> - Updates a VPC attachment.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited