acceptAttachment method

Future<AcceptAttachmentResponse> acceptAttachment({
  1. required String attachmentId,
})

Accepts a core network attachment request.

Once the attachment request is accepted by a core network owner, the attachment is created and connected to a core network.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter attachmentId : The ID of the attachment.

Implementation

Future<AcceptAttachmentResponse> acceptAttachment({
  required String attachmentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/attachments/${Uri.encodeComponent(attachmentId)}/accept',
    exceptionFnMap: _exceptionFns,
  );
  return AcceptAttachmentResponse.fromJson(response);
}