deleteCoreNetwork method

Future<DeleteCoreNetworkResponse> deleteCoreNetwork({
  1. required String coreNetworkId,
})

Deletes a core network along with all core network policies. This can only be done if there are no attachments on a core network.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter coreNetworkId : The network ID of the deleted core network.

Implementation

Future<DeleteCoreNetworkResponse> deleteCoreNetwork({
  required String coreNetworkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/core-networks/${Uri.encodeComponent(coreNetworkId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteCoreNetworkResponse.fromJson(response);
}