deleteGlobalNetwork method

Future<DeleteGlobalNetworkResponse> deleteGlobalNetwork({
  1. required String globalNetworkId,
})

Deletes an existing global network. You must first delete all global network objects (devices, links, and sites), deregister all transit gateways, and delete any core networks.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter globalNetworkId : The ID of the global network.

Implementation

Future<DeleteGlobalNetworkResponse> deleteGlobalNetwork({
  required String globalNetworkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/global-networks/${Uri.encodeComponent(globalNetworkId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteGlobalNetworkResponse.fromJson(response);
}