disassociateConnectPeer method
Disassociates a core network Connect peer from a device and a link.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter connectPeerId :
The ID of the Connect peer to disassociate from a device.
Parameter globalNetworkId :
The ID of the global network.
Implementation
Future<DisassociateConnectPeerResponse> disassociateConnectPeer({
required String connectPeerId,
required String globalNetworkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/global-networks/${Uri.encodeComponent(globalNetworkId)}/connect-peer-associations/${Uri.encodeComponent(connectPeerId)}',
exceptionFnMap: _exceptionFns,
);
return DisassociateConnectPeerResponse.fromJson(response);
}