getDirectConnectGatewayAttachment method

Future<GetDirectConnectGatewayAttachmentResponse> getDirectConnectGatewayAttachment({
  1. required String attachmentId,
})

Returns information about a specific Amazon Web Services Direct Connect gateway attachment.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter attachmentId : The ID of the Direct Connect gateway attachment that you want to see details about.

Implementation

Future<GetDirectConnectGatewayAttachmentResponse>
    getDirectConnectGatewayAttachment({
  required String attachmentId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/direct-connect-gateway-attachments/${Uri.encodeComponent(attachmentId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDirectConnectGatewayAttachmentResponse.fromJson(response);
}