registerTransitGateway method
Registers a transit gateway in your global network. Not all Regions support transit gateways for global networks. For a list of the supported Regions, see Region Availability in the Amazon Web Services Transit Gateways for Global Networks User Guide. The transit gateway can be in any of the supported Amazon Web Services Regions, but it must be owned by the same Amazon Web Services account that owns the global network. You cannot register a transit gateway in more than one global network.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter globalNetworkId :
The ID of the global network.
Parameter transitGatewayArn :
The Amazon Resource Name (ARN) of the transit gateway.
Implementation
Future<RegisterTransitGatewayResponse> registerTransitGateway({
required String globalNetworkId,
required String transitGatewayArn,
}) async {
final $payload = <String, dynamic>{
'TransitGatewayArn': transitGatewayArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/global-networks/${Uri.encodeComponent(globalNetworkId)}/transit-gateway-registrations',
exceptionFnMap: _exceptionFns,
);
return RegisterTransitGatewayResponse.fromJson(response);
}