startRouteAnalysis method
Starts analyzing the routing path between the specified source and destination. For more information, see Route Analyzer.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter destination :
The destination.
Parameter globalNetworkId :
The ID of the global network.
Parameter source :
The source from which traffic originates.
Parameter includeReturnPath :
Indicates whether to analyze the return path. The default is
false.
Parameter useMiddleboxes :
Indicates whether to include the location of middlebox appliances in the
route analysis. The default is false.
Implementation
Future<StartRouteAnalysisResponse> startRouteAnalysis({
required RouteAnalysisEndpointOptionsSpecification destination,
required String globalNetworkId,
required RouteAnalysisEndpointOptionsSpecification source,
bool? includeReturnPath,
bool? useMiddleboxes,
}) async {
final $payload = <String, dynamic>{
'Destination': destination,
'Source': source,
if (includeReturnPath != null) 'IncludeReturnPath': includeReturnPath,
if (useMiddleboxes != null) 'UseMiddleboxes': useMiddleboxes,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/global-networks/${Uri.encodeComponent(globalNetworkId)}/route-analyses',
exceptionFnMap: _exceptionFns,
);
return StartRouteAnalysisResponse.fromJson(response);
}