updateDirectConnectGatewayAttachment method

Future<UpdateDirectConnectGatewayAttachmentResponse> updateDirectConnectGatewayAttachment({
  1. required String attachmentId,
  2. List<String>? edgeLocations,
})

Updates the edge locations associated with an Amazon Web Services Direct Connect gateway attachment.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter attachmentId : The ID of the Direct Connect gateway attachment for the updated edge locations.

Parameter edgeLocations : One or more edge locations to update for the Direct Connect gateway attachment. The updated array of edge locations overwrites the previous array of locations. EdgeLocations is only used for Direct Connect gateway attachments.

Implementation

Future<UpdateDirectConnectGatewayAttachmentResponse>
    updateDirectConnectGatewayAttachment({
  required String attachmentId,
  List<String>? edgeLocations,
}) async {
  final $payload = <String, dynamic>{
    if (edgeLocations != null) 'EdgeLocations': edgeLocations,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/direct-connect-gateway-attachments/${Uri.encodeComponent(attachmentId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateDirectConnectGatewayAttachmentResponse.fromJson(response);
}