getProbe method

Future<GetProbeOutput> getProbe({
  1. required String monitorName,
  2. required String probeId,
})

Returns the details about a probe. This action requires both the monitorName and probeId parameters. Run ListMonitors to get a list of monitor names. Run GetMonitor to get a list of probes and probe IDs.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter monitorName : The name of the monitor associated with the probe. Run ListMonitors to get a list of monitor names.

Parameter probeId : The ID of the probe to get information about. Run GetMonitor action to get a list of probes and probe IDs for the monitor.

Implementation

Future<GetProbeOutput> getProbe({
  required String monitorName,
  required String probeId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/monitors/${Uri.encodeComponent(monitorName)}/probes/${Uri.encodeComponent(probeId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetProbeOutput.fromJson(response);
}