Notifications class

The User Notifications API Reference provides descriptions, API request parameters, and the JSON response for each of the User Notifications API actions.

User Notification control plane APIs are currently available in US East (Virginia) - us-east-1.

GetNotificationEvent and ListNotificationEvents APIs are currently available in commercial partition Regions and only return notifications stored in the same Region in which they're called.

The User Notifications console can only be used in US East (Virginia). Your data however, is stored in each Region chosen as a notification hub in addition to US East (Virginia).

Constructors

Notifications({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateChannel({required String arn, required String notificationConfigurationArn}) Future<void>
Associates a delivery Channel with a particular NotificationConfiguration. Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
associateManagedNotificationAccountContact({required AccountContactType contactIdentifier, required String managedNotificationConfigurationArn}) Future<void>
Associates an Account Contact with a particular ManagedNotificationConfiguration.
associateManagedNotificationAdditionalChannel({required String channelArn, required String managedNotificationConfigurationArn}) Future<void>
Associates an additional Channel with a particular ManagedNotificationConfiguration.
associateOrganizationalUnit({required String notificationConfigurationArn, required String organizationalUnitId}) Future<void>
Associates an organizational unit with a notification configuration.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createEventRule({required String eventType, required String notificationConfigurationArn, required List<String> regions, required String source, String? eventPattern}) Future<CreateEventRuleResponse>
Creates an EventRule that is associated with a specified NotificationConfiguration.
createNotificationConfiguration({required String description, required String name, AggregationDuration? aggregationDuration, Map<String, String>? tags}) Future<CreateNotificationConfigurationResponse>
Creates a new NotificationConfiguration.
deleteEventRule({required String arn}) Future<void>
Deletes an EventRule.
deleteNotificationConfiguration({required String arn}) Future<void>
Deletes a NotificationConfiguration.
deregisterNotificationHub({required String notificationHubRegion}) Future<DeregisterNotificationHubResponse>
Deregisters a NotificationConfiguration in the specified Region.
disableNotificationsAccessForOrganization() Future<void>
Disables service trust between User Notifications and Amazon Web Services Organizations.
disassociateChannel({required String arn, required String notificationConfigurationArn}) Future<void>
Disassociates a Channel from a specified NotificationConfiguration. Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
disassociateManagedNotificationAccountContact({required AccountContactType contactIdentifier, required String managedNotificationConfigurationArn}) Future<void>
Disassociates an Account Contact with a particular ManagedNotificationConfiguration.
disassociateManagedNotificationAdditionalChannel({required String channelArn, required String managedNotificationConfigurationArn}) Future<void>
Disassociates an additional Channel from a particular ManagedNotificationConfiguration.
disassociateOrganizationalUnit({required String notificationConfigurationArn, required String organizationalUnitId}) Future<void>
Removes the association between an organizational unit and a notification configuration.
enableNotificationsAccessForOrganization() Future<void>
Enables service trust between User Notifications and Amazon Web Services Organizations.
getEventRule({required String arn}) Future<GetEventRuleResponse>
Returns a specified EventRule.
getManagedNotificationChildEvent({required String arn, LocaleCode? locale}) Future<GetManagedNotificationChildEventResponse>
Returns the child event of a specific given ManagedNotificationEvent.
getManagedNotificationConfiguration({required String arn}) Future<GetManagedNotificationConfigurationResponse>
Returns a specified ManagedNotificationConfiguration.
getManagedNotificationEvent({required String arn, LocaleCode? locale}) Future<GetManagedNotificationEventResponse>
Returns a specified ManagedNotificationEvent.
getNotificationConfiguration({required String arn}) Future<GetNotificationConfigurationResponse>
Returns a specified NotificationConfiguration.
getNotificationEvent({required String arn, LocaleCode? locale}) Future<GetNotificationEventResponse>
Returns a specified NotificationEvent.
getNotificationsAccessForOrganization() Future<GetNotificationsAccessForOrganizationResponse>
Returns the AccessStatus of Service Trust Enablement for User Notifications and Amazon Web Services Organizations.
listChannels({required String notificationConfigurationArn, int? maxResults, String? nextToken}) Future<ListChannelsResponse>
Returns a list of Channels for a NotificationConfiguration.
listEventRules({required String notificationConfigurationArn, int? maxResults, String? nextToken}) Future<ListEventRulesResponse>
Returns a list of EventRules according to specified filters, in reverse chronological order (newest first).
listManagedNotificationChannelAssociations({required String managedNotificationConfigurationArn, int? maxResults, String? nextToken}) Future<ListManagedNotificationChannelAssociationsResponse>
Returns a list of Account contacts and Channels associated with a ManagedNotificationConfiguration, in paginated format.
listManagedNotificationChildEvents({required String aggregateManagedNotificationEventArn, DateTime? endTime, LocaleCode? locale, int? maxResults, String? nextToken, String? organizationalUnitId, String? relatedAccount, DateTime? startTime}) Future<ListManagedNotificationChildEventsResponse>
Returns a list of ManagedNotificationChildEvents for a specified aggregate ManagedNotificationEvent, ordered by creation time in reverse chronological order (newest first).
listManagedNotificationConfigurations({String? channelIdentifier, int? maxResults, String? nextToken}) Future<ListManagedNotificationConfigurationsResponse>
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
listManagedNotificationEvents({DateTime? endTime, LocaleCode? locale, int? maxResults, String? nextToken, String? organizationalUnitId, String? relatedAccount, String? source, DateTime? startTime}) Future<ListManagedNotificationEventsResponse>
Returns a list of Managed Notification Events according to specified filters, ordered by creation time in reverse chronological order (newest first).
listMemberAccounts({required String notificationConfigurationArn, int? maxResults, String? memberAccount, String? nextToken, String? organizationalUnitId, MemberAccountNotificationConfigurationStatus? status}) Future<ListMemberAccountsResponse>
Returns a list of member accounts associated with a notification configuration.
listNotificationConfigurations({String? channelArn, String? eventRuleSource, int? maxResults, String? nextToken, NotificationConfigurationStatus? status, NotificationConfigurationSubtype? subtype}) Future<ListNotificationConfigurationsResponse>
Returns a list of abbreviated NotificationConfigurations according to specified filters, in reverse chronological order (newest first).
listNotificationEvents({String? aggregateNotificationEventArn, DateTime? endTime, bool? includeChildEvents, LocaleCode? locale, int? maxResults, String? nextToken, String? organizationalUnitId, String? source, DateTime? startTime}) Future<ListNotificationEventsResponse>
Returns a list of NotificationEvents according to specified filters, in reverse chronological order (newest first).
listNotificationHubs({int? maxResults, String? nextToken}) Future<ListNotificationHubsResponse>
Returns a list of NotificationHubs.
listOrganizationalUnits({required String notificationConfigurationArn, int? maxResults, String? nextToken}) Future<ListOrganizationalUnitsResponse>
Returns a list of organizational units associated with a notification configuration.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Returns a list of tags for a specified Amazon Resource Name (ARN).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerNotificationHub({required String notificationHubRegion}) Future<RegisterNotificationHubResponse>
Registers a NotificationConfiguration in the specified Region.
tagResource({required String arn, required Map<String, String> tags}) Future<void>
Tags the resource with a tag key and value.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, required List<String> tagKeys}) Future<void>
Untags a resource with a specified Amazon Resource Name (ARN).
updateEventRule({required String arn, String? eventPattern, List<String>? regions}) Future<UpdateEventRuleResponse>
Updates an existing EventRule.
updateNotificationConfiguration({required String arn, AggregationDuration? aggregationDuration, String? description, String? name}) Future<UpdateNotificationConfigurationResponse>
Updates a NotificationConfiguration.

Operators

operator ==(Object other) bool
The equality operator.
inherited