associateChannel method
Associates a delivery Channel
with a particular NotificationConfiguration. Supported
Channels include Amazon Q Developer in chat applications, the Console
Mobile Application, and emails (notifications-contacts).
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) of the Channel to associate with the
NotificationConfiguration.
Supported ARNs include Amazon Q Developer in chat applications, the Console Mobile Application, and notifications-contacts.
Parameter notificationConfigurationArn :
The ARN of the NotificationConfiguration to associate with
the Channel.
Implementation
Future<void> associateChannel({
required String arn,
required String notificationConfigurationArn,
}) async {
final $payload = <String, dynamic>{
'notificationConfigurationArn': notificationConfigurationArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/channels/associate/${Uri.encodeComponent(arn)}',
exceptionFnMap: _exceptionFns,
);
}