associateOrganizationalUnit method

Future<void> associateOrganizationalUnit({
  1. required String notificationConfigurationArn,
  2. required String organizationalUnitId,
})

Associates an organizational unit with a notification configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter notificationConfigurationArn : The Amazon Resource Name (ARN) of the notification configuration to associate with the organizational unit.

Parameter organizationalUnitId : The unique identifier of the organizational unit to associate.

Implementation

Future<void> associateOrganizationalUnit({
  required String notificationConfigurationArn,
  required String organizationalUnitId,
}) async {
  final $payload = <String, dynamic>{
    'notificationConfigurationArn': notificationConfigurationArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/organizational-units/associate/${Uri.encodeComponent(organizationalUnitId)}',
    exceptionFnMap: _exceptionFns,
  );
}