disassociateOrganizationalUnit method

Future<void> disassociateOrganizationalUnit({
  1. required String notificationConfigurationArn,
  2. required String organizationalUnitId,
})

Removes the association between an organizational unit and a notification configuration.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter notificationConfigurationArn : The Amazon Resource Name (ARN) of the notification configuration to disassociate from the organizational unit.

Parameter organizationalUnitId : The unique identifier of the organizational unit to disassociate.

Implementation

Future<void> disassociateOrganizationalUnit({
  required String notificationConfigurationArn,
  required String organizationalUnitId,
}) async {
  final $payload = <String, dynamic>{
    'notificationConfigurationArn': notificationConfigurationArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/organizational-units/disassociate/${Uri.encodeComponent(organizationalUnitId)}',
    exceptionFnMap: _exceptionFns,
  );
}