getManagedNotificationChildEvent method

Future<GetManagedNotificationChildEventResponse> getManagedNotificationChildEvent({
  1. required String arn,
  2. LocaleCode? locale,
})

Returns the child event of a specific given ManagedNotificationEvent.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the ManagedNotificationChildEvent to return.

Parameter locale : The locale code of the language used for the retrieved ManagedNotificationChildEvent. The default locale is English en_US.

Implementation

Future<GetManagedNotificationChildEventResponse>
    getManagedNotificationChildEvent({
  required String arn,
  LocaleCode? locale,
}) async {
  final $query = <String, List<String>>{
    if (locale != null) 'locale': [locale.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/managed-notification-child-events/${Uri.encodeComponent(arn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetManagedNotificationChildEventResponse.fromJson(response);
}