listManagedNotificationChildEvents method

Future<ListManagedNotificationChildEventsResponse> listManagedNotificationChildEvents({
  1. required String aggregateManagedNotificationEventArn,
  2. DateTime? endTime,
  3. LocaleCode? locale,
  4. int? maxResults,
  5. String? nextToken,
  6. String? organizationalUnitId,
  7. String? relatedAccount,
  8. DateTime? startTime,
})

Returns a list of ManagedNotificationChildEvents for a specified aggregate ManagedNotificationEvent, ordered by creation time in reverse chronological order (newest first).

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter aggregateManagedNotificationEventArn : The Amazon Resource Name (ARN) of the ManagedNotificationEvent.

Parameter endTime : Latest time of events to return from this call.

Parameter locale : The locale code of the language used for the retrieved NotificationEvent. The default locale is English.en_US.

Parameter maxResults : The maximum number of results to be returned in this call. Defaults to 20.

Parameter nextToken : The start token for paginated calls. Retrieved from the response of a previous ListManagedNotificationChannelAssociations call. Next token uses Base64 encoding.

Parameter organizationalUnitId : The identifier of the Amazon Web Services Organizations organizational unit (OU) associated with the Managed Notification Child Events.

Parameter relatedAccount : The Amazon Web Services account ID associated with the Managed Notification Child Events.

Parameter startTime : The earliest time of events to return from this call.

Implementation

Future<ListManagedNotificationChildEventsResponse>
    listManagedNotificationChildEvents({
  required String aggregateManagedNotificationEventArn,
  DateTime? endTime,
  LocaleCode? locale,
  int? maxResults,
  String? nextToken,
  String? organizationalUnitId,
  String? relatedAccount,
  DateTime? startTime,
}) async {
  final $query = <String, List<String>>{
    if (endTime != null) 'endTime': [_s.iso8601ToJson(endTime).toString()],
    if (locale != null) 'locale': [locale.value],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (organizationalUnitId != null)
      'organizationalUnitId': [organizationalUnitId],
    if (relatedAccount != null) 'relatedAccount': [relatedAccount],
    if (startTime != null)
      'startTime': [_s.iso8601ToJson(startTime).toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/list-managed-notification-child-events/${Uri.encodeComponent(aggregateManagedNotificationEventArn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListManagedNotificationChildEventsResponse.fromJson(response);
}