listNotificationHubs method

Future<ListNotificationHubsResponse> listNotificationHubs({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of NotificationHubs.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of records to list in a single response.

Parameter nextToken : A pagination token. Set to null to start listing notification hubs from the start.

Implementation

Future<ListNotificationHubsResponse> listNotificationHubs({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/notification-hubs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListNotificationHubsResponse.fromJson(response);
}