listOrganizationalUnits method
Returns a list of organizational units associated with a notification configuration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter notificationConfigurationArn :
The Amazon Resource Name (ARN) of the notification configuration used to
filter the organizational units.
Parameter maxResults :
The maximum number of organizational units to return in a single call.
Valid values are 1-100.
Parameter nextToken :
The token for the next page of results. Use the value returned in the
previous response.
Implementation
Future<ListOrganizationalUnitsResponse> listOrganizationalUnits({
required String notificationConfigurationArn,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
'notificationConfigurationArn': [notificationConfigurationArn],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/organizational-units',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListOrganizationalUnitsResponse.fromJson(response);
}