untagResource method

Future<void> untagResource({
  1. required String arn,
  2. required List<String> tagKeys,
})

Untags a resource with a specified Amazon Resource Name (ARN).

For more information, see Tagging your Amazon Web Services resources in the Tagging Amazon Web Services Resources User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) to use to untag a resource.

Parameter tagKeys : The tag keys to use to untag a resource.

Implementation

Future<void> untagResource({
  required String arn,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/tags/${Uri.encodeComponent(arn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}