NotificationsContacts class

AWS User Notifications Contacts is a service that allows you to create and manage email contacts for AWS User Notifications. The AWS User Notifications Contacts API Reference provides descriptions, API request parameters, and the JSON response for all email contact related API actions.

Constructors

NotificationsContacts({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateEmailContact({required String arn, required String code}) Future<void>
Activates an email contact using an activation code. This code is in the activation email sent to the email address associated with this email contact.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createEmailContact({required String emailAddress, required String name, Map<String, String>? tags}) Future<CreateEmailContactResponse>
Creates an email contact for the provided email address.
deleteEmailContact({required String arn}) Future<void>
Deletes an email contact.
getEmailContact({required String arn}) Future<GetEmailContactResponse>
Returns an email contact.
listEmailContacts({int? maxResults, String? nextToken}) Future<ListEmailContactsResponse>
Lists all email contacts created under the Account.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendActivationCode({required String arn}) Future<void>
Sends an activation email to the email address associated with the specified email contact.
tagResource({required String arn, required Map<String, String> tags}) Future<void>
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, required List<String> tagKeys}) Future<void>
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts..

Operators

operator ==(Object other) bool
The equality operator.
inherited