activateEmailContact method
Activates an email contact using an activation code. This code is in the activation email sent to the email address associated with this email contact.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) of the resource.
Parameter code :
The activation code for this email contact.
An email contact has a maximum of five activation attempts. Activation codes expire after 12 hours and are generated by the SendActivationCode API action.
Implementation
Future<void> activateEmailContact({
required String arn,
required String code,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PUT',
requestUri:
'/emailcontacts/${Uri.encodeComponent(arn)}/activate/${Uri.encodeComponent(code)}',
exceptionFnMap: _exceptionFns,
);
}