untagResource method

Future<void> untagResource({
  1. required String arn,
  2. required List<String> tagKeys,
})

Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts..

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The value of the resource that will have the tag removed. An Amazon Resource Name (ARN) is an identifier for a specific AWS resource, such as a server, user, or role.

Parameter tagKeys : Specifies a list of tag keys that you want to remove from the specified resources.

Implementation

Future<void> untagResource({
  required String arn,
  required List<String> tagKeys,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/tags/${Uri.encodeComponent(arn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}