notifications_contacts_2018_05_10 library

Classes

AwsClientCredentials
AWS credentials.
NotificationsContacts
AWS User Notifications Contacts is a service that allows you to create and manage email contacts for AWS User Notifications. The AWS User Notifications Contacts API Reference provides descriptions, API request parameters, and the JSON response for all email contact related API actions.