listActs method

Future<ListActsResponse> listActs({
  1. required String workflowDefinitionName,
  2. int? maxResults,
  3. String? nextToken,
  4. String? sessionId,
  5. SortOrder? sortOrder,
  6. String? workflowRunId,
})

Lists all acts within a specific session with their current status and execution details.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter workflowDefinitionName : The name of the workflow definition containing the session.

Parameter maxResults : The maximum number of acts to return in a single response.

Parameter nextToken : The token for retrieving the next page of results.

Parameter sessionId : The unique identifier of the session to list acts for.

Parameter sortOrder : The sort order for the returned acts (ascending or descending).

Parameter workflowRunId : The unique identifier of the workflow run containing the session.

Implementation

Future<ListActsResponse> listActs({
  required String workflowDefinitionName,
  int? maxResults,
  String? nextToken,
  String? sessionId,
  SortOrder? sortOrder,
  String? workflowRunId,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (sessionId != null) 'sessionId': [sessionId],
    if (workflowRunId != null) 'workflowRunId': [workflowRunId],
  };
  final $payload = <String, dynamic>{
    if (sortOrder != null) 'sortOrder': sortOrder.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/workflow-definitions/${Uri.encodeComponent(workflowDefinitionName)}/acts',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListActsResponse.fromJson(response);
}