listModels method
Lists all available AI models that can be used for workflow execution, including their status and compatibility information.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
Parameter clientCompatibilityVersion :
The client compatibility version to filter models by compatibility.
Implementation
Future<ListModelsResponse> listModels({
required int clientCompatibilityVersion,
}) async {
final $query = <String, List<String>>{
'clientCompatibilityVersion': [clientCompatibilityVersion.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/models',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListModelsResponse.fromJson(response);
}