updateAct method

Future<void> updateAct({
  1. required String actId,
  2. required String sessionId,
  3. required ActStatus status,
  4. required String workflowDefinitionName,
  5. required String workflowRunId,
  6. ActError? error,
})

Updates an existing act's configuration, status, or error information.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter actId : The unique identifier of the act to update.

Parameter sessionId : The unique identifier of the session containing the act.

Parameter status : The new status to set for the act.

Parameter workflowDefinitionName : The name of the workflow definition containing the act.

Parameter workflowRunId : The unique identifier of the workflow run containing the act.

Parameter error : Error information to associate with the act, if applicable.

Implementation

Future<void> updateAct({
  required String actId,
  required String sessionId,
  required ActStatus status,
  required String workflowDefinitionName,
  required String workflowRunId,
  ActError? error,
}) async {
  final $payload = <String, dynamic>{
    'status': status.value,
    if (error != null) 'error': error,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/workflow-definitions/${Uri.encodeComponent(workflowDefinitionName)}/workflow-runs/${Uri.encodeComponent(workflowRunId)}/sessions/${Uri.encodeComponent(sessionId)}/acts/${Uri.encodeComponent(actId)}',
    exceptionFnMap: _exceptionFns,
  );
}