createLink method

Future<CreateLinkOutput> createLink({
  1. required String labelTemplate,
  2. required List<ResourceType> resourceTypes,
  3. required String sinkIdentifier,
  4. LinkConfiguration? linkConfiguration,
  5. Map<String, String>? tags,
})

Creates a link between a source account and a sink that you have created in a monitoring account. After the link is created, data is sent from the source account to the monitoring account. When you create a link, you can optionally specify filters that specify which metric namespaces and which log groups are shared from the source account to the monitoring account.

Before you create a link, you must create a sink in the monitoring account and create a sink policy in that account. The sink policy must permit the source account to link to it. You can grant permission to source accounts by granting permission to an entire organization or to individual accounts.

For more information, see CreateSink and PutSinkPolicy.

Each monitoring account can be linked to as many as 100,000 source accounts.

Each source account can be linked to as many as five monitoring accounts.

May throw ConflictException. May throw InternalServiceFault. May throw InvalidParameterException. May throw MissingRequiredParameterException. May throw ServiceQuotaExceededException.

Parameter labelTemplate : Specify a friendly human-readable name to use to identify this source account when you are viewing data from it in the monitoring account.

You can use a custom label or use the following variables:

  • $AccountName is the name of the account
  • $AccountEmail is the globally unique email address of the account
  • $AccountEmailNoDomain is the email address of the account without the domain name

Parameter resourceTypes : An array of strings that define which types of data that the source account shares with the monitoring account.

Parameter sinkIdentifier : The ARN of the sink to use to create this link. You can use ListSinks to find the ARNs of sinks.

For more information about sinks, see CreateSink.

Parameter linkConfiguration : Use this structure to optionally create filters that specify that only some metric namespaces or log groups are to be shared from the source account to the monitoring account.

Parameter tags : Assigns one or more tags (key-value pairs) to the link.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.

For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.

Implementation

Future<CreateLinkOutput> createLink({
  required String labelTemplate,
  required List<ResourceType> resourceTypes,
  required String sinkIdentifier,
  LinkConfiguration? linkConfiguration,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'LabelTemplate': labelTemplate,
    'ResourceTypes': resourceTypes.map((e) => e.value).toList(),
    'SinkIdentifier': sinkIdentifier,
    if (linkConfiguration != null) 'LinkConfiguration': linkConfiguration,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CreateLink',
    exceptionFnMap: _exceptionFns,
  );
  return CreateLinkOutput.fromJson(response);
}