createSink method
Use this to create a sink in the current account, so that it can be used as a monitoring account in CloudWatch cross-account observability. A sink is a resource that represents an attachment point in a monitoring account. Source accounts can link to the sink to send observability data.
After you create a sink, you must create a sink policy that allows source accounts to attach to it. For more information, see PutSinkPolicy.
Each account can contain one sink per Region. If you delete a sink, you can then create a new one in that Region.
May throw ConflictException.
May throw InternalServiceFault.
May throw InvalidParameterException.
May throw MissingRequiredParameterException.
May throw ServiceQuotaExceededException.
Parameter name :
A name for the sink.
Parameter tags :
Assigns one or more tags (key-value pairs) to the link.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.
Implementation
Future<CreateSinkOutput> createSink({
required String name,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'Name': name,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateSink',
exceptionFnMap: _exceptionFns,
);
return CreateSinkOutput.fromJson(response);
}