getSink method

Future<GetSinkOutput> getSink({
  1. required String identifier,
  2. bool? includeTags,
})

Returns complete information about one monitoring account sink.

To use this operation, provide the sink ARN. To retrieve a list of sink ARNs, use ListSinks.

May throw InternalServiceFault. May throw InvalidParameterException. May throw MissingRequiredParameterException. May throw ResourceNotFoundException.

Parameter identifier : The ARN of the sink to retrieve information for.

Parameter includeTags : Specifies whether to include the tags associated with the sink in the response. When IncludeTags is set to true and the caller has the required permission, oam:ListTagsForResource, the API will return the tags for the specified resource. If the caller doesn't have the required permission, oam:ListTagsForResource, the API will raise an exception.

The default value is false.

Implementation

Future<GetSinkOutput> getSink({
  required String identifier,
  bool? includeTags,
}) async {
  final $payload = <String, dynamic>{
    'Identifier': identifier,
    if (includeTags != null) 'IncludeTags': includeTags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetSink',
    exceptionFnMap: _exceptionFns,
  );
  return GetSinkOutput.fromJson(response);
}