getSinkPolicy method
Returns the current sink policy attached to this sink. The sink policy specifies what accounts can attach to this sink as source accounts, and what types of data they can share.
May throw InternalServiceFault.
May throw InvalidParameterException.
May throw MissingRequiredParameterException.
May throw ResourceNotFoundException.
Parameter sinkIdentifier :
The ARN of the sink to retrieve the policy of.
Implementation
Future<GetSinkPolicyOutput> getSinkPolicy({
required String sinkIdentifier,
}) async {
final $payload = <String, dynamic>{
'SinkIdentifier': sinkIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetSinkPolicy',
exceptionFnMap: _exceptionFns,
);
return GetSinkPolicyOutput.fromJson(response);
}