listLinks method

Future<ListLinksOutput> listLinks({
  1. int? maxResults,
  2. String? nextToken,
})

Use this operation in a source account to return a list of links to monitoring account sinks that this source account has.

To find a list of links for one monitoring account sink, use ListAttachedLinks from within the monitoring account.

May throw InternalServiceFault. May throw InvalidParameterException. May throw ResourceNotFoundException.

Parameter maxResults : Limits the number of returned links to the specified number.

Parameter nextToken : The token for the next set of items to return. You received this token from a previous call.

Implementation

Future<ListLinksOutput> listLinks({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    5,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListLinks',
    exceptionFnMap: _exceptionFns,
  );
  return ListLinksOutput.fromJson(response);
}