listSinks method
Use this operation in a monitoring account to return the list of sinks created in that account.
May throw InternalServiceFault.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
Parameter maxResults :
Limits the number of returned links to the specified number.
Parameter nextToken :
The token for the next set of items to return. You received this token
from a previous call.
Implementation
Future<ListSinksOutput> listSinks({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListSinks',
exceptionFnMap: _exceptionFns,
);
return ListSinksOutput.fromJson(response);
}