ObservabilityAdmin class

You can use Amazon CloudWatch Observability Admin to discover and understand the state of telemetry configuration in CloudWatch for your Amazon Web Services Organization or account. This simplifies the process of auditing your telemetry collection configurations across multiple resource types within your Amazon Web Services Organization or account. By providing a consolidated view, it allows you to easily review and manage telemetry settings, helping you ensure proper monitoring and data collection across your Amazon Web Services environment. For more information, see Auditing CloudWatch telemetry configurations in the CloudWatch User Guide.

For information on the permissions you need to use this API, see Identity and access management for Amazon CloudWatch in the CloudWatch User Guide.

Constructors

ObservabilityAdmin({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCentralizationRuleForOrganization({required CentralizationRule rule, required String ruleName, Map<String, String>? tags}) Future<CreateCentralizationRuleForOrganizationOutput>
Creates a centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
createS3TableIntegration({required Encryption encryption, required String roleArn, Map<String, String>? tags}) Future<CreateS3TableIntegrationOutput>
Creates an integration between CloudWatch and S3 Tables for analytics. This integration enables querying CloudWatch telemetry data using analytics engines like Amazon Athena, Amazon Redshift, and Apache Spark.
createTelemetryPipeline({required TelemetryPipelineConfiguration configuration, required String name, Map<String, String>? tags}) Future<CreateTelemetryPipelineOutput>
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
createTelemetryRule({required TelemetryRule rule, required String ruleName, Map<String, String>? tags}) Future<CreateTelemetryRuleOutput>
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
createTelemetryRuleForOrganization({required TelemetryRule rule, required String ruleName, Map<String, String>? tags}) Future<CreateTelemetryRuleForOrganizationOutput>
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
deleteCentralizationRuleForOrganization({required String ruleIdentifier}) Future<void>
Deletes an organization-wide centralization rule. This operation can only be called by the organization's management account or a delegated administrator account.
deleteS3TableIntegration({required String arn}) Future<void>
Deletes an S3 Table integration and its associated data. This operation removes the connection between CloudWatch Observability Admin and S3 Tables.
deleteTelemetryPipeline({required String pipelineIdentifier}) Future<void>
Deletes a telemetry pipeline and its associated resources. This operation stops data processing and removes the pipeline configuration.
deleteTelemetryRule({required String ruleIdentifier}) Future<void>
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
deleteTelemetryRuleForOrganization({required String ruleIdentifier}) Future<void>
Deletes an organization-wide telemetry rule. This operation can only be called by the organization's management account or a delegated administrator account.
getCentralizationRuleForOrganization({required String ruleIdentifier}) Future<GetCentralizationRuleForOrganizationOutput>
Retrieves the details of a specific organization centralization rule. This operation can only be called by the organization's management account or a delegated administrator account.
getS3TableIntegration({required String arn}) Future<GetS3TableIntegrationOutput>
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
getTelemetryEnrichmentStatus() Future<GetTelemetryEnrichmentStatusOutput>
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
getTelemetryEvaluationStatus() Future<GetTelemetryEvaluationStatusOutput>
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
getTelemetryEvaluationStatusForOrganization() Future<GetTelemetryEvaluationStatusForOrganizationOutput>
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
getTelemetryPipeline({required String pipelineIdentifier}) Future<GetTelemetryPipelineOutput>
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
getTelemetryRule({required String ruleIdentifier}) Future<GetTelemetryRuleOutput>
Retrieves the details of a specific telemetry rule in your account.
getTelemetryRuleForOrganization({required String ruleIdentifier}) Future<GetTelemetryRuleForOrganizationOutput>
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization's management account or a delegated administrator account.
listCentralizationRulesForOrganization({bool? allRegions, int? maxResults, String? nextToken, String? ruleNamePrefix}) Future<ListCentralizationRulesForOrganizationOutput>
Lists all centralization rules in your organization. This operation can only be called by the organization's management account or a delegated administrator account.
listResourceTelemetry({int? maxResults, String? nextToken, String? resourceIdentifierPrefix, Map<String, String>? resourceTags, List<ResourceType>? resourceTypes, Map<TelemetryType, TelemetryState>? telemetryConfigurationState}) Future<ListResourceTelemetryOutput>
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see Auditing CloudWatch telemetry configurations.
listResourceTelemetryForOrganization({List<String>? accountIdentifiers, int? maxResults, String? nextToken, String? resourceIdentifierPrefix, Map<String, String>? resourceTags, List<ResourceType>? resourceTypes, Map<TelemetryType, TelemetryState>? telemetryConfigurationState}) Future<ListResourceTelemetryForOrganizationOutput>
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
listS3TableIntegrations({int? maxResults, String? nextToken}) Future<ListS3TableIntegrationsOutput>
Lists all S3 Table integrations in your account. We recommend using pagination to ensure that the operation returns quickly and successfully.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceOutput>
Lists all tags attached to the specified resource. Supports telemetry rule resources and telemetry pipeline resources.
listTelemetryPipelines({int? maxResults, String? nextToken}) Future<ListTelemetryPipelinesOutput>
Returns a list of telemetry pipelines in your account. Returns up to 100 results. If more than 100 telemetry pipelines exist, include the NextToken value from the response to retrieve the next set of results.
listTelemetryRules({int? maxResults, String? nextToken, String? ruleNamePrefix}) Future<ListTelemetryRulesOutput>
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
listTelemetryRulesForOrganization({int? maxResults, String? nextToken, String? ruleNamePrefix, List<String>? sourceAccountIds, List<String>? sourceOrganizationUnitIds}) Future<ListTelemetryRulesForOrganizationOutput>
Lists all telemetry rules in your organization. This operation can only be called by the organization's management account or a delegated administrator account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTelemetryEnrichment() Future<StartTelemetryEnrichmentOutput>
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
startTelemetryEvaluation({bool? allRegions, List<String>? regions}) Future<void>
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
startTelemetryEvaluationForOrganization({bool? allRegions, List<String>? regions}) Future<void>
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
stopTelemetryEnrichment() Future<StopTelemetryEnrichmentOutput>
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
stopTelemetryEvaluation() Future<void>
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
stopTelemetryEvaluationForOrganization() Future<void>
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
tagResource({required String resourceARN, required Map<String, String> tags}) Future<void>
Adds or updates tags for a resource. Supports telemetry rule resources and telemetry pipeline resources.
testTelemetryPipeline({required TelemetryPipelineConfiguration configuration, required List<Record> records}) Future<TestTelemetryPipelineOutput>
Tests a pipeline configuration with sample records to validate data processing before deployment. This operation helps ensure your pipeline configuration works as expected.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.
updateCentralizationRuleForOrganization({required CentralizationRule rule, required String ruleIdentifier}) Future<UpdateCentralizationRuleForOrganizationOutput>
Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
updateTelemetryPipeline({required TelemetryPipelineConfiguration configuration, required String pipelineIdentifier}) Future<void>
Updates the configuration of an existing telemetry pipeline.
updateTelemetryRule({required TelemetryRule rule, required String ruleIdentifier}) Future<UpdateTelemetryRuleOutput>
Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.
updateTelemetryRuleForOrganization({required TelemetryRule rule, required String ruleIdentifier}) Future<UpdateTelemetryRuleForOrganizationOutput>
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
validateTelemetryPipelineConfiguration({required TelemetryPipelineConfiguration configuration}) Future<ValidateTelemetryPipelineConfigurationOutput>
Validates a pipeline configuration without creating the pipeline. This operation checks the configuration for syntax errors and compatibility issues.

Operators

operator ==(Object other) bool
The equality operator.
inherited