deleteTelemetryRule method

Future<void> deleteTelemetryRule({
  1. required String ruleIdentifier,
})

Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter ruleIdentifier : The identifier (name or ARN) of the telemetry rule to delete.

Implementation

Future<void> deleteTelemetryRule({
  required String ruleIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'RuleIdentifier': ruleIdentifier,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteTelemetryRule',
    exceptionFnMap: _exceptionFns,
  );
}