getTelemetryEnrichmentStatus method

Future<GetTelemetryEnrichmentStatusOutput> getTelemetryEnrichmentStatus()

Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException.

Implementation

Future<GetTelemetryEnrichmentStatusOutput>
    getTelemetryEnrichmentStatus() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/GetTelemetryEnrichmentStatus',
    exceptionFnMap: _exceptionFns,
  );
  return GetTelemetryEnrichmentStatusOutput.fromJson(response);
}