getTelemetryEvaluationStatusForOrganization method

Future<GetTelemetryEvaluationStatusForOrganizationOutput> getTelemetryEvaluationStatusForOrganization()

This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.

May throw AccessDeniedException. May throw InternalServerException. May throw TooManyRequestsException. May throw ValidationException.

Implementation

Future<GetTelemetryEvaluationStatusForOrganizationOutput>
    getTelemetryEvaluationStatusForOrganization() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/GetTelemetryEvaluationStatusForOrganization',
    exceptionFnMap: _exceptionFns,
  );
  return GetTelemetryEvaluationStatusForOrganizationOutput.fromJson(response);
}