listTelemetryPipelines method

Future<ListTelemetryPipelinesOutput> listTelemetryPipelines({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of telemetry pipelines in your account. Returns up to 100 results. If more than 100 telemetry pipelines exist, include the NextToken value from the response to retrieve the next set of results.

May throw AccessDeniedException. May throw InternalServerException. May throw TooManyRequestsException. May throw ValidationException.

Parameter maxResults : The maximum number of telemetry pipelines to return in a single call.

Parameter nextToken : The token for the next set of results. A previous call generates this token.

Implementation

Future<ListTelemetryPipelinesOutput> listTelemetryPipelines({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListTelemetryPipelines',
    exceptionFnMap: _exceptionFns,
  );
  return ListTelemetryPipelinesOutput.fromJson(response);
}