listTelemetryRules method
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter maxResults :
The maximum number of telemetry rules to return in a single call.
Parameter nextToken :
The token for the next set of results. A previous call generates this
token.
Parameter ruleNamePrefix :
A string to filter telemetry rules whose names begin with the specified
prefix.
Implementation
Future<ListTelemetryRulesOutput> listTelemetryRules({
int? maxResults,
String? nextToken,
String? ruleNamePrefix,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (ruleNamePrefix != null) 'RuleNamePrefix': ruleNamePrefix,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListTelemetryRules',
exceptionFnMap: _exceptionFns,
);
return ListTelemetryRulesOutput.fromJson(response);
}