startTelemetryEnrichment method

Future<StartTelemetryEnrichmentOutput> startTelemetryEnrichment()

Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw TooManyRequestsException.

Implementation

Future<StartTelemetryEnrichmentOutput> startTelemetryEnrichment() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/StartTelemetryEnrichment',
    exceptionFnMap: _exceptionFns,
  );
  return StartTelemetryEnrichmentOutput.fromJson(response);
}