startTelemetryEvaluation method
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter allRegions :
If set to true, telemetry evaluation starts in all Amazon Web
Services Regions where Amazon CloudWatch Observability Admin is available
in the current partition. The current region becomes the home region for
managing multi-region evaluation. When new regions become available,
evaluation automatically expands to include them. Mutually exclusive with
Regions.
Parameter regions :
An optional list of Amazon Web Services Regions to include in multi-region
telemetry evaluation. The current region is always implicitly included and
must not be specified in this list. When provided, telemetry evaluation
starts in the current region and propagates to all specified regions.
Mutually exclusive with AllRegions. If neither
Regions nor AllRegions is provided, the
operation applies only to the current region.
Implementation
Future<void> startTelemetryEvaluation({
bool? allRegions,
List<String>? regions,
}) async {
final $payload = <String, dynamic>{
if (allRegions != null) 'AllRegions': allRegions,
if (regions != null) 'Regions': regions,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StartTelemetryEvaluation',
exceptionFnMap: _exceptionFns,
);
}