stopTelemetryEvaluationForOrganization method

Future<void> stopTelemetryEvaluationForOrganization()

This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.

May throw AccessDeniedException. May throw InternalServerException. May throw TooManyRequestsException. May throw ValidationException.

Implementation

Future<void> stopTelemetryEvaluationForOrganization() async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/StopTelemetryEvaluationForOrganization',
    exceptionFnMap: _exceptionFns,
  );
}