untagResource method

Future<void> untagResource({
  1. required String resourceARN,
  2. required List<String> tagKeys,
})

Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter resourceARN : The Amazon Resource Name (ARN) of the telemetry rule resource to remove tags from.

Parameter tagKeys : The list of tag keys to remove from the telemetry rule resource.

Implementation

Future<void> untagResource({
  required String resourceARN,
  required List<String> tagKeys,
}) async {
  final $payload = <String, dynamic>{
    'ResourceARN': resourceARN,
    'TagKeys': tagKeys,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UntagResource',
    exceptionFnMap: _exceptionFns,
  );
}