updateCentralizationRuleForOrganization method

Future<UpdateCentralizationRuleForOrganizationOutput> updateCentralizationRuleForOrganization({
  1. required CentralizationRule rule,
  2. required String ruleIdentifier,
})

Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw TooManyRequestsException. May throw ValidationException.

Parameter rule : The configuration details for the organization-wide centralization rule, including the source configuration and the destination configuration to centralize telemetry data across the organization.

Parameter ruleIdentifier : The identifier (name or ARN) of the organization centralization rule to update.

Implementation

Future<UpdateCentralizationRuleForOrganizationOutput>
    updateCentralizationRuleForOrganization({
  required CentralizationRule rule,
  required String ruleIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'Rule': rule,
    'RuleIdentifier': ruleIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateCentralizationRuleForOrganization',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateCentralizationRuleForOrganizationOutput.fromJson(response);
}