updateTelemetryRule method

Future<UpdateTelemetryRuleOutput> updateTelemetryRule({
  1. required TelemetryRule rule,
  2. required String ruleIdentifier,
})

Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw TooManyRequestsException. May throw ValidationException.

Parameter rule : The new configuration details for the telemetry rule.

Parameter ruleIdentifier : The identifier (name or ARN) of the telemetry rule to update.

Implementation

Future<UpdateTelemetryRuleOutput> updateTelemetryRule({
  required TelemetryRule rule,
  required String ruleIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'Rule': rule,
    'RuleIdentifier': ruleIdentifier,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateTelemetryRule',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateTelemetryRuleOutput.fromJson(response);
}