Odb class

Oracle Database@Amazon Web Services is an offering that enables you to access Oracle Exadata infrastructure managed by Oracle Cloud Infrastructure (OCI) inside Amazon Web Services data centers. You can migrate your Oracle Exadata workloads, establish low-latency connectivity with applications running on Amazon Web Services, and integrate with Amazon Web Services services. For example, you can run application servers in a Virtual Private Cloud (VPC) and access an Oracle Exadata system running in Oracle Database@Amazon Web Services. You can get started with Oracle Database@Amazon Web Services by using the familiar Amazon Web Services Management Console, APIs, or CLI.

This interface reference for Oracle Database@Amazon Web Services contains documentation for a programming or command line interface that you can use to manage Oracle Database@Amazon Web Services. Oracle Database@Amazon Web Services is asynchronous, which means that some interfaces might require techniques such as polling or callback functions to determine when a command has been applied. The reference structure is as follows.

Oracle Database@Amazon Web Services API Reference

Constructors

Odb({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptMarketplaceRegistration({required String marketplaceRegistrationToken}) Future<void>
Registers the Amazon Web Services Marketplace token for your Amazon Web Services account to activate your Oracle Database@Amazon Web Services subscription.
associateIamRoleToResource({required SupportedAwsIntegration awsIntegration, required String iamRoleArn, required String resourceArn}) Future<void>
Associates an Amazon Web Services Identity and Access Management (IAM) service role with a specified resource to enable Amazon Web Services service integration.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createCloudAutonomousVmCluster({required double autonomousDataStorageSizeInTBs, required String cloudExadataInfrastructureId, required int cpuCoreCountPerNode, required String displayName, required int memoryPerOracleComputeUnitInGBs, required String odbNetworkId, required int totalContainerDatabases, String? clientToken, List<String>? dbServers, String? description, bool? isMtlsEnabledVmCluster, LicenseModel? licenseModel, MaintenanceWindow? maintenanceWindow, int? scanListenerPortNonTls, int? scanListenerPortTls, Map<String, String>? tags, String? timeZone}) Future<CreateCloudAutonomousVmClusterOutput>
Creates a new Autonomous VM cluster in the specified Exadata infrastructure.
createCloudExadataInfrastructure({required int computeCount, required String displayName, required String shape, required int storageCount, String? availabilityZone, String? availabilityZoneId, String? clientToken, List<CustomerContact>? customerContactsToSendToOCI, String? databaseServerType, MaintenanceWindow? maintenanceWindow, String? storageServerType, Map<String, String>? tags}) Future<CreateCloudExadataInfrastructureOutput>
Creates an Exadata infrastructure.
createCloudVmCluster({required String cloudExadataInfrastructureId, required int cpuCoreCount, required String displayName, required String giVersion, required String hostname, required String odbNetworkId, required List<String> sshPublicKeys, String? clientToken, String? clusterName, DataCollectionOptions? dataCollectionOptions, double? dataStorageSizeInTBs, int? dbNodeStorageSizeInGBs, List<String>? dbServers, bool? isLocalBackupEnabled, bool? isSparseDiskgroupEnabled, LicenseModel? licenseModel, int? memorySizeInGBs, int? scanListenerPortTcp, String? systemVersion, Map<String, String>? tags, String? timeZone}) Future<CreateCloudVmClusterOutput>
Creates a VM cluster on the specified Exadata infrastructure.
createOdbNetwork({required String clientSubnetCidr, required String displayName, String? availabilityZone, String? availabilityZoneId, String? backupSubnetCidr, String? clientToken, List<String>? crossRegionS3RestoreSourcesToEnable, String? customDomainName, String? defaultDnsPrefix, Access? kmsAccess, String? kmsPolicyDocument, Access? s3Access, String? s3PolicyDocument, Access? stsAccess, String? stsPolicyDocument, Map<String, String>? tags, Access? zeroEtlAccess}) Future<CreateOdbNetworkOutput>
Creates an ODB network.
createOdbPeeringConnection({required String odbNetworkId, required String peerNetworkId, String? clientToken, String? displayName, List<String>? peerNetworkCidrsToBeAdded, List<String>? peerNetworkRouteTableIds, Map<String, String>? tags}) Future<CreateOdbPeeringConnectionOutput>
Creates a peering connection between an ODB network and a VPC.
deleteCloudAutonomousVmCluster({required String cloudAutonomousVmClusterId}) Future<void>
Deletes an Autonomous VM cluster.
deleteCloudExadataInfrastructure({required String cloudExadataInfrastructureId}) Future<void>
Deletes the specified Exadata infrastructure. Before you use this operation, make sure to delete all of the VM clusters that are hosted on this Exadata infrastructure.
deleteCloudVmCluster({required String cloudVmClusterId}) Future<void>
Deletes the specified VM cluster.
deleteOdbNetwork({required bool deleteAssociatedResources, required String odbNetworkId}) Future<void>
Deletes the specified ODB network.
deleteOdbPeeringConnection({required String odbPeeringConnectionId}) Future<void>
Deletes an ODB peering connection.
disassociateIamRoleFromResource({required SupportedAwsIntegration awsIntegration, required String iamRoleArn, required String resourceArn}) Future<void>
Disassociates an Amazon Web Services Identity and Access Management (IAM) service role from a specified resource to disable Amazon Web Services service integration.
getCloudAutonomousVmCluster({required String cloudAutonomousVmClusterId}) Future<GetCloudAutonomousVmClusterOutput>
Gets information about a specific Autonomous VM cluster.
getCloudExadataInfrastructure({required String cloudExadataInfrastructureId}) Future<GetCloudExadataInfrastructureOutput>
Returns information about the specified Exadata infrastructure.
getCloudExadataInfrastructureUnallocatedResources({required String cloudExadataInfrastructureId, List<String>? dbServers}) Future<GetCloudExadataInfrastructureUnallocatedResourcesOutput>
Retrieves information about unallocated resources in a specified Cloud Exadata Infrastructure.
getCloudVmCluster({required String cloudVmClusterId}) Future<GetCloudVmClusterOutput>
Returns information about the specified VM cluster.
getDbNode({required String cloudVmClusterId, required String dbNodeId}) Future<GetDbNodeOutput>
Returns information about the specified DB node.
getDbServer({required String cloudExadataInfrastructureId, required String dbServerId}) Future<GetDbServerOutput>
Returns information about the specified database server.
getOciOnboardingStatus() Future<GetOciOnboardingStatusOutput>
Returns the tenancy activation link and onboarding status for your Amazon Web Services account.
getOdbNetwork({required String odbNetworkId}) Future<GetOdbNetworkOutput>
Returns information about the specified ODB network.
getOdbPeeringConnection({required String odbPeeringConnectionId}) Future<GetOdbPeeringConnectionOutput>
Retrieves information about an ODB peering connection.
initializeService({bool? ociIdentityDomain}) Future<void>
Initializes the ODB service for the first time in an account.
listAutonomousVirtualMachines({required String cloudAutonomousVmClusterId, int? maxResults, String? nextToken}) Future<ListAutonomousVirtualMachinesOutput>
Lists all Autonomous VMs in an Autonomous VM cluster.
listCloudAutonomousVmClusters({String? cloudExadataInfrastructureId, int? maxResults, String? nextToken}) Future<ListCloudAutonomousVmClustersOutput>
Lists all Autonomous VM clusters in a specified Cloud Exadata infrastructure.
listCloudExadataInfrastructures({int? maxResults, String? nextToken}) Future<ListCloudExadataInfrastructuresOutput>
Returns information about the Exadata infrastructures owned by your Amazon Web Services account.
listCloudVmClusters({String? cloudExadataInfrastructureId, int? maxResults, String? nextToken}) Future<ListCloudVmClustersOutput>
Returns information about the VM clusters owned by your Amazon Web Services account or only the ones on the specified Exadata infrastructure.
listDbNodes({required String cloudVmClusterId, int? maxResults, String? nextToken}) Future<ListDbNodesOutput>
Returns information about the DB nodes for the specified VM cluster.
listDbServers({required String cloudExadataInfrastructureId, int? maxResults, String? nextToken}) Future<ListDbServersOutput>
Returns information about the database servers that belong to the specified Exadata infrastructure.
listDbSystemShapes({String? availabilityZone, String? availabilityZoneId, int? maxResults, String? nextToken}) Future<ListDbSystemShapesOutput>
Returns information about the shapes that are available for an Exadata infrastructure.
listGiVersions({int? maxResults, String? nextToken, String? shape}) Future<ListGiVersionsOutput>
Returns information about Oracle Grid Infrastructure (GI) software versions that are available for a VM cluster for the specified shape.
listOdbNetworks({int? maxResults, String? nextToken}) Future<ListOdbNetworksOutput>
Returns information about the ODB networks owned by your Amazon Web Services account.
listOdbPeeringConnections({int? maxResults, String? nextToken, String? odbNetworkId}) Future<ListOdbPeeringConnectionsOutput>
Lists all ODB peering connections or those associated with a specific ODB network.
listSystemVersions({required String giVersion, required String shape, int? maxResults, String? nextToken}) Future<ListSystemVersionsOutput>
Returns information about the system versions that are available for a VM cluster for the specified giVersion and shape.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns information about the tags applied to this resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebootDbNode({required String cloudVmClusterId, required String dbNodeId}) Future<RebootDbNodeOutput>
Reboots the specified DB node in a VM cluster.
startDbNode({required String cloudVmClusterId, required String dbNodeId}) Future<StartDbNodeOutput>
Starts the specified DB node in a VM cluster.
stopDbNode({required String cloudVmClusterId, required String dbNodeId}) Future<StopDbNodeOutput>
Stops the specified DB node in a VM cluster.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Applies tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from the specified resource.
updateCloudExadataInfrastructure({required String cloudExadataInfrastructureId, MaintenanceWindow? maintenanceWindow}) Future<UpdateCloudExadataInfrastructureOutput>
Updates the properties of an Exadata infrastructure resource.
updateOdbNetwork({required String odbNetworkId, List<String>? crossRegionS3RestoreSourcesToDisable, List<String>? crossRegionS3RestoreSourcesToEnable, String? displayName, Access? kmsAccess, String? kmsPolicyDocument, List<String>? peeredCidrsToBeAdded, List<String>? peeredCidrsToBeRemoved, Access? s3Access, String? s3PolicyDocument, Access? stsAccess, String? stsPolicyDocument, Access? zeroEtlAccess}) Future<UpdateOdbNetworkOutput>
Updates properties of a specified ODB network.
updateOdbPeeringConnection({required String odbPeeringConnectionId, String? displayName, List<String>? peerNetworkCidrsToBeAdded, List<String>? peerNetworkCidrsToBeRemoved}) Future<UpdateOdbPeeringConnectionOutput>
Modifies the settings of an Oracle Database@Amazon Web Services peering connection. You can update the display name and add or remove CIDR blocks from the peering connection.

Operators

operator ==(Object other) bool
The equality operator.
inherited