acceptMarketplaceRegistration method

Future<void> acceptMarketplaceRegistration({
  1. required String marketplaceRegistrationToken,
})

Registers the Amazon Web Services Marketplace token for your Amazon Web Services account to activate your Oracle Database@Amazon Web Services subscription.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter marketplaceRegistrationToken : The registration token that's generated by Amazon Web Services Marketplace and sent to Oracle Database@Amazon Web Services.

Implementation

Future<void> acceptMarketplaceRegistration({
  required String marketplaceRegistrationToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.AcceptMarketplaceRegistration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'marketplaceRegistrationToken': marketplaceRegistrationToken,
    },
  );
}