deleteCloudExadataInfrastructure method

Future<void> deleteCloudExadataInfrastructure({
  1. required String cloudExadataInfrastructureId,
})

Deletes the specified Exadata infrastructure. Before you use this operation, make sure to delete all of the VM clusters that are hosted on this Exadata infrastructure.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter cloudExadataInfrastructureId : The unique identifier of the Exadata infrastructure to delete.

Implementation

Future<void> deleteCloudExadataInfrastructure({
  required String cloudExadataInfrastructureId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.DeleteCloudExadataInfrastructure'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
    },
  );
}