listAutonomousDatabasePeers method

Future<ListAutonomousDatabasePeersOutput> listAutonomousDatabasePeers({
  1. required String autonomousDatabaseId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the peer databases of the specified Autonomous Database.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter autonomousDatabaseId : The unique identifier of the Autonomous Database whose peer databases you want to list.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Implementation

Future<ListAutonomousDatabasePeersOutput> listAutonomousDatabasePeers({
  required String autonomousDatabaseId,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.ListAutonomousDatabasePeers'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'autonomousDatabaseId': autonomousDatabaseId,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListAutonomousDatabasePeersOutput.fromJson(jsonResponse.body);
}