listAutonomousDatabaseVersions method

Future<ListAutonomousDatabaseVersionsOutput> listAutonomousDatabaseVersions({
  1. DbWorkload? dbWorkload,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the available Oracle Database software versions for Autonomous Databases.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter dbWorkload : The intended use of the Autonomous Database to return versions for, such as transaction processing, data warehouse, JSON database, or APEX.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Implementation

Future<ListAutonomousDatabaseVersionsOutput> listAutonomousDatabaseVersions({
  DbWorkload? dbWorkload,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.ListAutonomousDatabaseVersions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (dbWorkload != null) 'dbWorkload': dbWorkload.value,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListAutonomousDatabaseVersionsOutput.fromJson(jsonResponse.body);
}