listCloudAutonomousVmClusters method
Lists all Autonomous VM clusters in a specified Cloud Exadata infrastructure.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cloudExadataInfrastructureId :
The unique identifier of the Cloud Exadata Infrastructure that hosts the
Autonomous VM clusters to be listed.
Parameter maxResults :
The maximum number of items to return per page.
Parameter nextToken :
The pagination token to continue listing from.
Implementation
Future<ListCloudAutonomousVmClustersOutput> listCloudAutonomousVmClusters({
String? cloudExadataInfrastructureId,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.ListCloudAutonomousVmClusters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (cloudExadataInfrastructureId != null)
'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListCloudAutonomousVmClustersOutput.fromJson(jsonResponse.body);
}