listDbServers method

Future<ListDbServersOutput> listDbServers({
  1. required String cloudExadataInfrastructureId,
  2. int? maxResults,
  3. String? nextToken,
})

Returns information about the database servers that belong to the specified Exadata infrastructure.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter cloudExadataInfrastructureId : The unique identifier of the Oracle Exadata infrastructure.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Implementation

Future<ListDbServersOutput> listDbServers({
  required String cloudExadataInfrastructureId,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.ListDbServers'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListDbServersOutput.fromJson(jsonResponse.body);
}