listGiVersions method

Future<ListGiVersionsOutput> listGiVersions({
  1. int? maxResults,
  2. String? nextToken,
  3. String? shape,
})

Returns information about Oracle Grid Infrastructure (GI) software versions that are available for a VM cluster for the specified shape.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Parameter shape : The shape to return GI versions for. For a list of valid shapes, use the ListDbSystemShapes operation..

Implementation

Future<ListGiVersionsOutput> listGiVersions({
  int? maxResults,
  String? nextToken,
  String? shape,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.ListGiVersions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
      if (shape != null) 'shape': shape,
    },
  );

  return ListGiVersionsOutput.fromJson(jsonResponse.body);
}