listSystemVersions method

Future<ListSystemVersionsOutput> listSystemVersions({
  1. required String giVersion,
  2. required String shape,
  3. int? maxResults,
  4. String? nextToken,
})

Returns information about the system versions that are available for a VM cluster for the specified giVersion and shape.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter giVersion : The software version of the Exadata Grid Infrastructure (GI).

Parameter shape : The Exadata hardware system model.

Parameter maxResults : The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Parameter nextToken : The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Implementation

Future<ListSystemVersionsOutput> listSystemVersions({
  required String giVersion,
  required String shape,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Odb.ListSystemVersions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'giVersion': giVersion,
      'shape': shape,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListSystemVersionsOutput.fromJson(jsonResponse.body);
}