Omics class

Amazon Web Services HealthOmics is a service that helps users such as bioinformaticians, researchers, and scientists to store, query, analyze, and generate insights from genomics and other biological data. It simplifies and accelerates the process of storing and analyzing genomic information for Amazon Web Services.

For an introduction to the service, see What is Amazon Web Services HealthOmics? in the Amazon Web Services HealthOmics User Guide.

Constructors

Omics({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abortMultipartReadSetUpload({required String sequenceStoreId, required String uploadId}) Future<void>
Stops a multipart read set upload into a sequence store and returns a response with no body if the operation is successful. To confirm that a multipart read set upload has been stopped, use the ListMultipartReadSetUploads API operation to view all active multipart read set uploads.
acceptShare({required String shareId}) Future<AcceptShareResponse>
Accept a resource share request.
batchDeleteReadSet({required List<String> ids, required String sequenceStoreId}) Future<BatchDeleteReadSetResponse>
Deletes one or more read sets. If the operation is successful, it returns a response with no body. If there is an error with deleting one of the read sets, the operation returns an error list. If the operation successfully deletes only a subset of files, it will return an error list for the remaining files that fail to be deleted. There is a limit of 100 read sets that can be deleted in each BatchDeleteReadSet API call.
cancelAnnotationImportJob({required String jobId}) Future<void>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
cancelRun({required String id}) Future<void>
Cancels a run using its ID and returns a response with no body if the operation is successful. To confirm that the run has been cancelled, use the ListRuns API operation to check that it is no longer listed.
cancelRunBatch({required String batchId}) Future<void>
Cancels all runs within a specified batch. This operation prevents not-yet-submitted runs from starting and submits CancelRun requests for runs that have already started.
cancelVariantImportJob({required String jobId}) Future<void>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
completeMultipartReadSetUpload({required List<CompleteReadSetUploadPartListItem> parts, required String sequenceStoreId, required String uploadId}) Future<CompleteMultipartReadSetUploadResponse>
Completes a multipart read set upload into a sequence store after you have initiated the upload process with CreateMultipartReadSetUpload and uploaded all read set parts using UploadReadSetPart. You must specify the parts you uploaded using the parts parameter. If the operation is successful, it returns the read set ID(s) of the uploaded read set(s).
createAnnotationStore({required StoreFormat storeFormat, String? description, String? name, ReferenceItem? reference, SseConfig? sseConfig, StoreOptions? storeOptions, Map<String, String>? tags, String? versionName}) Future<CreateAnnotationStoreResponse>
May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.
createAnnotationStoreVersion({required String name, required String versionName, String? description, Map<String, String>? tags, VersionOptions? versionOptions}) Future<CreateAnnotationStoreVersionResponse>
Creates a new version of an annotation store.
createConfiguration({required String name, required RunConfigurations runConfigurations, String? description, String? requestId, Map<String, String>? tags}) Future<CreateConfigurationResponse>
Create a new configuration.
createMultipartReadSetUpload({required String name, required String sampleId, required String sequenceStoreId, required FileType sourceFileType, required String subjectId, String? clientToken, String? description, String? generatedFrom, String? referenceArn, Map<String, String>? tags}) Future<CreateMultipartReadSetUploadResponse>
Initiates a multipart read set upload for uploading partitioned source files into a sequence store. You can directly import source files from an EC2 instance and other local compute, or from an S3 bucket. To separate these source files into parts, use the split operation. Each part cannot be larger than 100 MB. If the operation is successful, it provides an uploadId which is required by the UploadReadSetPart API operation to upload parts into a sequence store.
createReferenceStore({required String name, String? clientToken, String? description, SseConfig? sseConfig, Map<String, String>? tags}) Future<CreateReferenceStoreResponse>
Creates a reference store and returns metadata in JSON format. Reference stores are used to store reference genomes in FASTA format. A reference store is created when the first reference genome is imported. To import additional reference genomes from an Amazon S3 bucket, use the StartReferenceImportJob API operation.
createRunCache({required String cacheS3Location, CacheBehavior? cacheBehavior, String? cacheBucketOwnerId, String? description, String? name, String? requestId, Map<String, String>? tags}) Future<CreateRunCacheResponse>
Creates a run cache to store and reference task outputs from completed private runs. Specify an Amazon S3 location where Amazon Web Services HealthOmics saves the cached data. This data must be immediately accessible and not in an archived state. You can save intermediate task files to a run cache if they are declared as task outputs in the workflow definition file.
createRunGroup({int? maxCpus, int? maxDuration, int? maxGpus, int? maxRuns, String? name, String? requestId, Map<String, String>? tags}) Future<CreateRunGroupResponse>
Creates a run group to limit the compute resources for the runs that are added to the group. Returns an ARN, ID, and tags for the run group.
createSequenceStore({required String name, String? clientToken, String? description, ETagAlgorithmFamily? eTagAlgorithmFamily, String? fallbackLocation, List<String>? propagatedSetLevelTags, S3AccessConfig? s3AccessConfig, SseConfig? sseConfig, Map<String, String>? tags}) Future<CreateSequenceStoreResponse>
Creates a sequence store and returns its metadata. Sequence stores are used to store sequence data files called read sets that are saved in FASTQ, BAM, uBAM, or CRAM formats. For aligned formats (BAM and CRAM), a sequence store can only use one reference genome. For unaligned formats (FASTQ and uBAM), a reference genome is not required. You can create multiple sequence stores per region per account.
createShare({required String principalSubscriber, required String resourceArn, String? shareName}) Future<CreateShareResponse>
Creates a cross-account shared resource. The resource owner makes an offer to share the resource with the principal subscriber (an AWS user with a different account than the resource owner).
createVariantStore({required ReferenceItem reference, String? description, String? name, SseConfig? sseConfig, Map<String, String>? tags}) Future<CreateVariantStoreResponse>
May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.
createWorkflow({Accelerators? accelerators, ContainerRegistryMap? containerRegistryMap, String? containerRegistryMapUri, DefinitionRepository? definitionRepository, String? definitionUri, Uint8List? definitionZip, String? description, WorkflowEngine? engine, String? main, String? name, Map<String, WorkflowParameter>? parameterTemplate, String? parameterTemplatePath, String? readmeMarkdown, String? readmePath, String? readmeUri, String? requestId, int? storageCapacity, StorageType? storageType, Map<String, String>? tags, String? workflowBucketOwnerId}) Future<CreateWorkflowResponse>
Creates a private workflow. Before you create a private workflow, you must create and configure these required resources:
createWorkflowVersion({required String versionName, required String workflowId, Accelerators? accelerators, ContainerRegistryMap? containerRegistryMap, String? containerRegistryMapUri, DefinitionRepository? definitionRepository, String? definitionUri, Uint8List? definitionZip, String? description, WorkflowEngine? engine, String? main, Map<String, WorkflowParameter>? parameterTemplate, String? parameterTemplatePath, String? readmeMarkdown, String? readmePath, String? readmeUri, String? requestId, int? storageCapacity, StorageType? storageType, Map<String, String>? tags, String? workflowBucketOwnerId}) Future<CreateWorkflowVersionResponse>
Creates a new workflow version for the workflow that you specify with the workflowId parameter.
deleteAnnotationStore({required String name, bool? force}) Future<DeleteAnnotationStoreResponse>
May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
deleteAnnotationStoreVersions({required String name, required List<String> versions, bool? force}) Future<DeleteAnnotationStoreVersionsResponse>
Deletes one or multiple versions of an annotation store.
deleteBatch({required String batchId}) Future<void>
Deletes a run batch resource and its associated metadata. This operation does not delete the individual workflow runs. To delete the runs, call DeleteRunBatch before calling DeleteBatch.
deleteConfiguration({required String name}) Future<void>
Delete an existing configuration.
deleteReference({required String id, required String referenceStoreId}) Future<void>
Deletes a reference genome and returns a response with no body if the operation is successful. The read set associated with the reference genome must first be deleted before deleting the reference genome. After the reference genome is deleted, you can delete the reference store using the DeleteReferenceStore API operation.
deleteReferenceStore({required String id}) Future<void>
Deletes a reference store and returns a response with no body if the operation is successful. You can only delete a reference store when it does not contain any reference genomes. To empty a reference store, use DeleteReference.
deleteRun({required String id}) Future<void>
Deletes a run and returns a response with no body if the operation is successful. You can only delete a run that has reached a COMPLETED, FAILED, or CANCELLED stage. A completed run has delivered an output, or was cancelled and resulted in no output. When you delete a run, only the metadata associated with the run is deleted. The run outputs remain in Amazon S3 and logs remain in CloudWatch.
deleteRunBatch({required String batchId}) Future<void>
Deletes the individual workflow runs within a batch. This operation is separate from DeleteBatch, which removes the batch metadata.
deleteRunCache({required String id}) Future<void>
Deletes a run cache and returns a response with no body if the operation is successful. This action removes the cache metadata stored in the service account, but does not delete the data in Amazon S3. You can access the cache data in Amazon S3, for inspection or to troubleshoot issues. You can remove old cache data using standard S3 Delete operations.
deleteRunGroup({required String id}) Future<void>
Deletes a run group and returns a response with no body if the operation is successful.
deleteS3AccessPolicy({required String s3AccessPointArn}) Future<void>
Deletes an access policy for the specified store.
deleteSequenceStore({required String id}) Future<void>
Deletes a sequence store and returns a response with no body if the operation is successful. You can only delete a sequence store when it does not contain any read sets.
deleteShare({required String shareId}) Future<DeleteShareResponse>
Deletes a resource share. If you are the resource owner, the subscriber will no longer have access to the shared resource. If you are the subscriber, this operation deletes your access to the share.
deleteVariantStore({required String name, bool? force}) Future<DeleteVariantStoreResponse>
May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
deleteWorkflow({required String id}) Future<void>
Deletes a workflow by specifying its ID. This operation returns a response with no body if the deletion is successful.
deleteWorkflowVersion({required String versionName, required String workflowId}) Future<void>
Deletes a workflow version. Deleting a workflow version doesn't affect any ongoing runs that are using the workflow version.
getAnnotationImportJob({required String jobId}) Future<GetAnnotationImportResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
getAnnotationStore({required String name}) Future<GetAnnotationStoreResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
getAnnotationStoreVersion({required String name, required String versionName}) Future<GetAnnotationStoreVersionResponse>
Retrieves the metadata for an annotation store version.
getBatch({required String batchId}) Future<GetBatchResponse>
Retrieves details and current status for a specific run batch, including submission progress and run execution counts.
getConfiguration({required String name}) Future<GetConfigurationResponse>
Retrieve configuration details for specified name.
getReadSet({required String id, required int partNumber, required String sequenceStoreId, ReadSetFile? file}) Future<GetReadSetResponse>
Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded. You must have read sets uploaded to your sequence store in order to run this operation.
getReadSetActivationJob({required String id, required String sequenceStoreId}) Future<GetReadSetActivationJobResponse>
Returns detailed information about the status of a read set activation job in JSON format.
getReadSetExportJob({required String id, required String sequenceStoreId}) Future<GetReadSetExportJobResponse>
Retrieves status information about a read set export job and returns the data in JSON format. Use this operation to actively monitor the progress of an export job.
getReadSetImportJob({required String id, required String sequenceStoreId}) Future<GetReadSetImportJobResponse>
Gets detailed and status information about a read set import job and returns the data in JSON format.
getReadSetMetadata({required String id, required String sequenceStoreId}) Future<GetReadSetMetadataResponse>
Retrieves the metadata for a read set from a sequence store in JSON format. This operation does not return tags. To retrieve the list of tags for a read set, use the ListTagsForResource API operation.
getReference({required String id, required int partNumber, required String referenceStoreId, ReferenceFile? file, String? range}) Future<GetReferenceResponse>
Downloads parts of data from a reference genome and returns the reference file in the same format that it was uploaded.
getReferenceImportJob({required String id, required String referenceStoreId}) Future<GetReferenceImportJobResponse>
Monitors the status of a reference import job. This operation can be called after calling the StartReferenceImportJob operation.
getReferenceMetadata({required String id, required String referenceStoreId}) Future<GetReferenceMetadataResponse>
Retrieves metadata for a reference genome. This operation returns the number of parts, part size, and MD5 of an entire file. This operation does not return tags. To retrieve the list of tags for a read set, use the ListTagsForResource API operation.
getReferenceStore({required String id}) Future<GetReferenceStoreResponse>
Gets information about a reference store.
getRun({required String id, List<RunExport>? export}) Future<GetRunResponse>
Gets detailed information about a specific run using its ID.
getRunCache({required String id}) Future<GetRunCacheResponse>
Retrieves detailed information about the specified run cache using its ID.
getRunGroup({required String id}) Future<GetRunGroupResponse>
Gets information about a run group and returns its metadata.
getRunTask({required String id, required String taskId}) Future<GetRunTaskResponse>
Gets detailed information about a run task using its ID.
getS3AccessPolicy({required String s3AccessPointArn}) Future<GetS3AccessPolicyResponse>
Retrieves details about an access policy on a given store.
getSequenceStore({required String id}) Future<GetSequenceStoreResponse>
Retrieves metadata for a sequence store using its ID and returns it in JSON format.
getShare({required String shareId}) Future<GetShareResponse>
Retrieves the metadata for the specified resource share.
getVariantImportJob({required String jobId}) Future<GetVariantImportResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
getVariantStore({required String name}) Future<GetVariantStoreResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
getWorkflow({required String id, List<WorkflowExport>? export, WorkflowType? type, String? workflowOwnerId}) Future<GetWorkflowResponse>
Gets all information about a workflow using its ID.
getWorkflowVersion({required String versionName, required String workflowId, List<WorkflowExport>? export, WorkflowType? type, String? workflowOwnerId}) Future<GetWorkflowVersionResponse>
Gets information about a workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
listAnnotationImportJobs({ListAnnotationImportJobsFilter? filter, List<String>? ids, int? maxResults, String? nextToken}) Future<ListAnnotationImportJobsResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
listAnnotationStores({ListAnnotationStoresFilter? filter, List<String>? ids, int? maxResults, String? nextToken}) Future<ListAnnotationStoresResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
listAnnotationStoreVersions({required String name, ListAnnotationStoreVersionsFilter? filter, int? maxResults, String? nextToken}) Future<ListAnnotationStoreVersionsResponse>
Lists the versions of an annotation store.
listBatch({int? maxItems, String? name, String? runGroupId, String? startingToken, BatchStatus? status}) Future<ListBatchResponse>
Returns a list of run batches in your account, with optional filtering by status, name, or run group. Results are paginated. Only one filter per call is supported.
listConfigurations({int? maxResults, String? startingToken}) Future<ListConfigurationsResponse>
List all configurations for the account.
listMultipartReadSetUploads({required String sequenceStoreId, int? maxResults, String? nextToken}) Future<ListMultipartReadSetUploadsResponse>
Lists in-progress multipart read set uploads for a sequence store and returns it in a JSON formatted output. Multipart read set uploads are initiated by the CreateMultipartReadSetUploads API operation. This operation returns a response with no body when the upload is complete.
listReadSetActivationJobs({required String sequenceStoreId, ActivateReadSetFilter? filter, int? maxResults, String? nextToken}) Future<ListReadSetActivationJobsResponse>
Retrieves a list of read set activation jobs and returns the metadata in a JSON formatted output. To extract metadata from a read set activation job, use the GetReadSetActivationJob API operation.
listReadSetExportJobs({required String sequenceStoreId, ExportReadSetFilter? filter, int? maxResults, String? nextToken}) Future<ListReadSetExportJobsResponse>
Retrieves a list of read set export jobs in a JSON formatted response. This API operation is used to check the status of a read set export job initiated by the StartReadSetExportJob API operation.
listReadSetImportJobs({required String sequenceStoreId, ImportReadSetFilter? filter, int? maxResults, String? nextToken}) Future<ListReadSetImportJobsResponse>
Retrieves a list of read set import jobs and returns the data in JSON format.
listReadSets({required String sequenceStoreId, ReadSetFilter? filter, int? maxResults, String? nextToken}) Future<ListReadSetsResponse>
Retrieves a list of read sets from a sequence store ID and returns the metadata in JSON format.
listReadSetUploadParts({required ReadSetPartSource partSource, required String sequenceStoreId, required String uploadId, ReadSetUploadPartListFilter? filter, int? maxResults, String? nextToken}) Future<ListReadSetUploadPartsResponse>
Lists all parts in a multipart read set upload for a sequence store and returns the metadata in a JSON formatted output.
listReferenceImportJobs({required String referenceStoreId, ImportReferenceFilter? filter, int? maxResults, String? nextToken}) Future<ListReferenceImportJobsResponse>
Retrieves the metadata of one or more reference import jobs for a reference store.
listReferences({required String referenceStoreId, ReferenceFilter? filter, int? maxResults, String? nextToken}) Future<ListReferencesResponse>
Retrieves the metadata of one or more reference genomes in a reference store.
listReferenceStores({ReferenceStoreFilter? filter, int? maxResults, String? nextToken}) Future<ListReferenceStoresResponse>
Retrieves a list of reference stores linked to your account and returns their metadata in JSON format.
listRunCaches({int? maxResults, String? startingToken}) Future<ListRunCachesResponse>
Retrieves a list of your run caches and the metadata for each cache.
listRunGroups({int? maxResults, String? name, String? startingToken}) Future<ListRunGroupsResponse>
Retrieves a list of all run groups and returns the metadata for each run group.
listRuns({String? batchId, int? maxResults, String? name, String? runGroupId, String? startingToken, RunStatus? status}) Future<ListRunsResponse>
Retrieves a list of runs and returns each run's metadata and status.
listRunsInBatch({required String batchId, int? maxItems, String? runId, String? runSettingId, String? startingToken, SubmissionStatus? submissionStatus}) Future<ListRunsInBatchResponse>
Returns a paginated list of individual workflow runs within a specific batch. Use this operation to map each runSettingId to its HealthOmics-generated runId, and to check the submission status of each run. Only one filter per call is supported.
listRunTasks({required String id, int? maxResults, String? startingToken, TaskStatus? status}) Future<ListRunTasksResponse>
Returns a list of tasks and status information within their specified run. Use this operation to monitor runs and to identify which specific tasks have failed.
listSequenceStores({SequenceStoreFilter? filter, int? maxResults, String? nextToken}) Future<ListSequenceStoresResponse>
Retrieves a list of sequence stores and returns each sequence store's metadata.
listShares({required ResourceOwner resourceOwner, Filter? filter, int? maxResults, String? nextToken}) Future<ListSharesResponse>
Retrieves the resource shares associated with an account. Use the filter parameter to retrieve a specific subset of the shares.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Retrieves a list of tags for a resource.
listVariantImportJobs({ListVariantImportJobsFilter? filter, List<String>? ids, int? maxResults, String? nextToken}) Future<ListVariantImportJobsResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
listVariantStores({ListVariantStoresFilter? filter, List<String>? ids, int? maxResults, String? nextToken}) Future<ListVariantStoresResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
listWorkflows({int? maxResults, String? name, String? startingToken, WorkflowType? type}) Future<ListWorkflowsResponse>
Retrieves a list of existing workflows. You can filter for specific workflows by their name and type. Using the type parameter, specify PRIVATE to retrieve a list of private workflows or specify READY2RUN for a list of all Ready2Run workflows. If you do not specify the type of workflow, this operation returns a list of existing workflows.
listWorkflowVersions({required String workflowId, int? maxResults, String? startingToken, WorkflowType? type, String? workflowOwnerId}) Future<ListWorkflowVersionsResponse>
Lists the workflow versions for the specified workflow. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putS3AccessPolicy({required String s3AccessPointArn, required Object s3AccessPolicy}) Future<PutS3AccessPolicyResponse>
Adds an access policy to the specified store.
startAnnotationImportJob({required String destinationName, required List<AnnotationImportItemSource> items, required String roleArn, Map<String, String>? annotationFields, FormatOptions? formatOptions, bool? runLeftNormalization, String? versionName}) Future<StartAnnotationImportResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.
startReadSetActivationJob({required String sequenceStoreId, required List<StartReadSetActivationJobSourceItem> sources, String? clientToken}) Future<StartReadSetActivationJobResponse>
Activates an archived read set and returns its metadata in a JSON formatted output. AWS HealthOmics automatically archives unused read sets after 30 days. To monitor the status of your read set activation job, use the GetReadSetActivationJob operation.
startReadSetExportJob({required String destination, required String roleArn, required String sequenceStoreId, required List<ExportReadSet> sources, String? clientToken}) Future<StartReadSetExportJobResponse>
Starts a read set export job. When the export job is finished, the read set is exported to an Amazon S3 bucket which can be retrieved using the GetReadSetExportJob API operation.
startReadSetImportJob({required String roleArn, required String sequenceStoreId, required List<StartReadSetImportJobSourceItem> sources, String? clientToken}) Future<StartReadSetImportJobResponse>
Imports a read set from the sequence store. Read set import jobs support a maximum of 100 read sets of different types. Monitor the progress of your read set import job by calling the GetReadSetImportJob API operation.
startReferenceImportJob({required String referenceStoreId, required String roleArn, required List<StartReferenceImportJobSourceItem> sources, String? clientToken}) Future<StartReferenceImportJobResponse>
Imports a reference genome from Amazon S3 into a specified reference store. You can have multiple reference genomes in a reference store. You can only import reference genomes one at a time into each reference store. Monitor the status of your reference import job by using the GetReferenceImportJob API operation.
startRun({required String outputUri, required String roleArn, CacheBehavior? cacheBehavior, String? cacheId, String? configurationName, Object? engineSettings, RunLogLevel? logLevel, String? name, NetworkingMode? networkingMode, Object? parameters, int? priority, String? requestId, RunRetentionMode? retentionMode, String? runGroupId, String? runId, int? storageCapacity, StorageType? storageType, Map<String, String>? tags, String? workflowId, String? workflowOwnerId, WorkflowType? workflowType, String? workflowVersionName}) Future<StartRunResponse>
Starts a new run and returns details about the run, or duplicates an existing run. A run is a single invocation of a workflow. If you provide request IDs, Amazon Web Services HealthOmics identifies duplicate requests and starts the run only once. Monitor the progress of the run by calling the GetRun API operation.
startRunBatch({required BatchRunSettings batchRunSettings, required DefaultRunSetting defaultRunSetting, String? batchName, String? requestId, Map<String, String>? tags}) Future<StartRunBatchResponse>
Starts a batch of workflow runs. You can group up to 100,000 runs into a single batch that share a common configuration defined in defaultRunSetting. Per-run overrides can be provided either inline via inlineSettings (up to 100 runs) or via a JSON file stored in Amazon S3 via s3UriSettings (up to 100,000 runs).
startVariantImportJob({required String destinationName, required List<VariantImportItemSource> items, required String roleArn, Map<String, String>? annotationFields, bool? runLeftNormalization}) Future<StartVariantImportResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Tags a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a resource.
updateAnnotationStore({required String name, String? description}) Future<UpdateAnnotationStoreResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
updateAnnotationStoreVersion({required String name, required String versionName, String? description}) Future<UpdateAnnotationStoreVersionResponse>
Updates the description of an annotation store version.
updateRunCache({required String id, CacheBehavior? cacheBehavior, String? description, String? name}) Future<void>
Updates a run cache using its ID and returns a response with no body if the operation is successful. You can update the run cache description, name, or the default run cache behavior with CACHE_ON_FAILURE or CACHE_ALWAYS. To confirm that your run cache settings have been properly updated, use the GetRunCache API operation.
updateRunGroup({required String id, int? maxCpus, int? maxDuration, int? maxGpus, int? maxRuns, String? name}) Future<void>
Updates the settings of a run group and returns a response with no body if the operation is successful.
updateSequenceStore({required String id, String? clientToken, String? description, String? fallbackLocation, String? name, List<String>? propagatedSetLevelTags, S3AccessConfig? s3AccessConfig}) Future<UpdateSequenceStoreResponse>
Update one or more parameters for the sequence store.
updateVariantStore({required String name, String? description}) Future<UpdateVariantStoreResponse>
May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.
updateWorkflow({required String id, String? description, String? name, String? readmeMarkdown, int? storageCapacity, StorageType? storageType}) Future<void>
Updates information about a workflow.
updateWorkflowVersion({required String versionName, required String workflowId, String? description, String? readmeMarkdown, int? storageCapacity, StorageType? storageType}) Future<void>
Updates information about the workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
uploadReadSetPart({required int partNumber, required ReadSetPartSource partSource, required Uint8List payload, required String sequenceStoreId, required String uploadId}) Future<UploadReadSetPartResponse>
Uploads a specific part of a read set into a sequence store. When you a upload a read set part with a part number that already exists, the new part replaces the existing one. This operation returns a JSON formatted response containing a string identifier that is used to confirm that parts are being added to the intended upload.

Operators

operator ==(Object other) bool
The equality operator.
inherited