abortMultipartReadSetUpload method
Stops a multipart read set upload into a sequence store and returns a
response with no body if the operation is successful. To confirm that a
multipart read set upload has been stopped, use the
ListMultipartReadSetUploads API operation to view all active
multipart read set uploads.
May throw AccessDeniedException.
May throw InternalServerException.
May throw NotSupportedOperationException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sequenceStoreId :
The sequence store ID for the store involved in the multipart upload.
Parameter uploadId :
The ID for the multipart upload.
Implementation
Future<void> abortMultipartReadSetUpload({
required String sequenceStoreId,
required String uploadId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/upload/${Uri.encodeComponent(uploadId)}/abort',
exceptionFnMap: _exceptionFns,
);
}