cancelRun method

Future<void> cancelRun({
  1. required String id,
})

Cancels a run using its ID and returns a response with no body if the operation is successful. To confirm that the run has been cancelled, use the ListRuns API operation to check that it is no longer listed.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The run's ID.

Implementation

Future<void> cancelRun({
  required String id,
}) async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/run/${Uri.encodeComponent(id)}/cancel',
    exceptionFnMap: _exceptionFns,
  );
}