completeMultipartReadSetUpload method
Completes a multipart read set upload into a sequence store after you have
initiated the upload process with
CreateMultipartReadSetUpload and uploaded all read set parts
using UploadReadSetPart. You must specify the parts you
uploaded using the parts parameter. If the operation is successful, it
returns the read set ID(s) of the uploaded read set(s).
For more information, see Direct upload to a sequence store in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw NotSupportedOperationException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter parts :
The individual uploads or parts of a multipart upload.
Parameter sequenceStoreId :
The sequence store ID for the store involved in the multipart upload.
Parameter uploadId :
The ID for the multipart upload.
Implementation
Future<CompleteMultipartReadSetUploadResponse>
completeMultipartReadSetUpload({
required List<CompleteReadSetUploadPartListItem> parts,
required String sequenceStoreId,
required String uploadId,
}) async {
final $payload = <String, dynamic>{
'parts': parts,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/upload/${Uri.encodeComponent(uploadId)}/complete',
exceptionFnMap: _exceptionFns,
);
return CompleteMultipartReadSetUploadResponse.fromJson(response);
}