createAnnotationStoreVersion method

Future<CreateAnnotationStoreVersionResponse> createAnnotationStoreVersion({
  1. required String name,
  2. required String versionName,
  3. String? description,
  4. Map<String, String>? tags,
  5. VersionOptions? versionOptions,
})

Creates a new version of an annotation store.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter name : The name of an annotation store version from which versions are being created.

Parameter versionName : The name given to an annotation store version to distinguish it from other versions.

Parameter description : The description of an annotation store version.

Parameter tags : Any tags added to annotation store version.

Parameter versionOptions : The options for an annotation store version.

Implementation

Future<CreateAnnotationStoreVersionResponse> createAnnotationStoreVersion({
  required String name,
  required String versionName,
  String? description,
  Map<String, String>? tags,
  VersionOptions? versionOptions,
}) async {
  final $payload = <String, dynamic>{
    'versionName': versionName,
    if (description != null) 'description': description,
    if (tags != null) 'tags': tags,
    if (versionOptions != null) 'versionOptions': versionOptions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/annotationStore/${Uri.encodeComponent(name)}/version',
    hostPrefix: 'analytics-',
    exceptionFnMap: _exceptionFns,
  );
  return CreateAnnotationStoreVersionResponse.fromJson(response);
}