createReferenceStore method

Future<CreateReferenceStoreResponse> createReferenceStore({
  1. required String name,
  2. String? clientToken,
  3. String? description,
  4. SseConfig? sseConfig,
  5. Map<String, String>? tags,
})

Creates a reference store and returns metadata in JSON format. Reference stores are used to store reference genomes in FASTA format. A reference store is created when the first reference genome is imported. To import additional reference genomes from an Amazon S3 bucket, use the StartReferenceImportJob API operation.

For more information, see Creating a HealthOmics reference store in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter name : A name for the store.

Parameter clientToken : To ensure that requests don't run multiple times, specify a unique token for each request.

Parameter description : A description for the store.

Parameter sseConfig : Server-side encryption (SSE) settings for the store.

Parameter tags : Tags for the store.

Implementation

Future<CreateReferenceStoreResponse> createReferenceStore({
  required String name,
  String? clientToken,
  String? description,
  SseConfig? sseConfig,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'name': name,
    if (clientToken != null) 'clientToken': clientToken,
    if (description != null) 'description': description,
    if (sseConfig != null) 'sseConfig': sseConfig,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/referencestore',
    exceptionFnMap: _exceptionFns,
  );
  return CreateReferenceStoreResponse.fromJson(response);
}