deleteAnnotationStoreVersions method

Future<DeleteAnnotationStoreVersionsResponse> deleteAnnotationStoreVersions({
  1. required String name,
  2. required List<String> versions,
  3. bool? force,
})

Deletes one or multiple versions of an annotation store.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter name : The name of the annotation store from which versions are being deleted.

Parameter versions : The versions of an annotation store to be deleted.

Parameter force : Forces the deletion of an annotation store version when imports are in-progress..

Implementation

Future<DeleteAnnotationStoreVersionsResponse> deleteAnnotationStoreVersions({
  required String name,
  required List<String> versions,
  bool? force,
}) async {
  final $query = <String, List<String>>{
    if (force != null) 'force': [force.toString()],
  };
  final $payload = <String, dynamic>{
    'versions': versions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/annotationStore/${Uri.encodeComponent(name)}/versions/delete',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAnnotationStoreVersionsResponse.fromJson(response);
}