deleteBatch method

Future<void> deleteBatch({
  1. required String batchId,
})

Deletes a run batch resource and its associated metadata. This operation does not delete the individual workflow runs. To delete the runs, call DeleteRunBatch before calling DeleteBatch.

DeleteBatch requires the batch to be in a terminal state: PROCESSED, FAILED, CANCELLED, or RUNS_DELETED. After DeleteBatch completes, the batch metadata is no longer accessible. You cannot call GetBatch, ListRunsInBatch, DeleteRunBatch, or CancelRunBatch on a deleted batch.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter batchId : The identifier portion of the run batch ARN.

Implementation

Future<void> deleteBatch({
  required String batchId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/runBatch/${Uri.encodeComponent(batchId)}',
    exceptionFnMap: _exceptionFns,
  );
}