deleteReference method

Future<void> deleteReference({
  1. required String id,
  2. required String referenceStoreId,
})

Deletes a reference genome and returns a response with no body if the operation is successful. The read set associated with the reference genome must first be deleted before deleting the reference genome. After the reference genome is deleted, you can delete the reference store using the DeleteReferenceStore API operation.

For more information, see Deleting HealthOmics reference and sequence stores in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The reference's ID.

Parameter referenceStoreId : The reference's store ID.

Implementation

Future<void> deleteReference({
  required String id,
  required String referenceStoreId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/referencestore/${Uri.encodeComponent(referenceStoreId)}/reference/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}