deleteReferenceStore method

Future<void> deleteReferenceStore({
  1. required String id,
})

Deletes a reference store and returns a response with no body if the operation is successful. You can only delete a reference store when it does not contain any reference genomes. To empty a reference store, use DeleteReference.

For more information about your workflow status, see Deleting HealthOmics reference and sequence stores in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The store's ID.

Implementation

Future<void> deleteReferenceStore({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/referencestore/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}