deleteRunCache method
Deletes a run cache and returns a response with no body if the operation
is successful. This action removes the cache metadata stored in the
service account, but does not delete the data in Amazon S3. You can access
the cache data in Amazon S3, for inspection or to troubleshoot issues. You
can remove old cache data using standard S3 Delete
operations.
For more information, see Deleting a run cache in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
Run cache identifier for the cache you want to delete.
Implementation
Future<void> deleteRunCache({
required String id,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/runCache/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}