deleteSequenceStore method

Future<void> deleteSequenceStore({
  1. required String id,
})

Deletes a sequence store and returns a response with no body if the operation is successful. You can only delete a sequence store when it does not contain any read sets.

Use the BatchDeleteReadSet API operation to ensure that all read sets in the sequence store are deleted. When a sequence store is deleted, all tags associated with the store are also deleted.

For more information, see Deleting HealthOmics reference and sequence stores in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The sequence store's ID.

Implementation

Future<void> deleteSequenceStore({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/sequencestore/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}