deleteShare method

Future<DeleteShareResponse> deleteShare({
  1. required String shareId,
})

Deletes a resource share. If you are the resource owner, the subscriber will no longer have access to the shared resource. If you are the subscriber, this operation deletes your access to the share.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter shareId : The ID for the resource share to be deleted.

Implementation

Future<DeleteShareResponse> deleteShare({
  required String shareId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/share/${Uri.encodeComponent(shareId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteShareResponse.fromJson(response);
}