deleteWorkflow method

Future<void> deleteWorkflow({
  1. required String id,
})

Deletes a workflow by specifying its ID. This operation returns a response with no body if the deletion is successful.

To verify that the workflow is deleted:

  • Use ListWorkflows to confirm the workflow no longer appears in the list.
  • Use GetWorkflow to verify the workflow cannot be found.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The workflow's ID.

Implementation

Future<void> deleteWorkflow({
  required String id,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/workflow/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}