deleteWorkflowVersion method
Deletes a workflow version. Deleting a workflow version doesn't affect any ongoing runs that are using the workflow version.
For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter versionName :
The workflow version name.
Parameter workflowId :
The workflow's ID.
Implementation
Future<void> deleteWorkflowVersion({
required String versionName,
required String workflowId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/workflow/${Uri.encodeComponent(workflowId)}/version/${Uri.encodeComponent(versionName)}',
exceptionFnMap: _exceptionFns,
);
}