getBatch method

Future<GetBatchResponse> getBatch({
  1. required String batchId,
})

Retrieves details and current status for a specific run batch, including submission progress and run execution counts.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter batchId : The identifier portion of the run batch ARN.

Implementation

Future<GetBatchResponse> getBatch({
  required String batchId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/runBatch/${Uri.encodeComponent(batchId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetBatchResponse.fromJson(response);
}