getReadSet method

Future<GetReadSetResponse> getReadSet({
  1. required String id,
  2. required int partNumber,
  3. required String sequenceStoreId,
  4. ReadSetFile? file,
})

Retrieves detailed information from parts of a read set and returns the read set in the same format that it was uploaded. You must have read sets uploaded to your sequence store in order to run this operation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RangeNotSatisfiableException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The read set's ID.

Parameter partNumber : The part number to retrieve.

Parameter sequenceStoreId : The read set's sequence store ID.

Parameter file : The file to retrieve.

Implementation

Future<GetReadSetResponse> getReadSet({
  required String id,
  required int partNumber,
  required String sequenceStoreId,
  ReadSetFile? file,
}) async {
  final $query = <String, List<String>>{
    'partNumber': [partNumber.toString()],
    if (file != null) 'file': [file.value],
  };
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/readset/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetReadSetResponse(
    payload: await response.stream.toBytes(),
  );
}