getReadSetExportJob method

Future<GetReadSetExportJobResponse> getReadSetExportJob({
  1. required String id,
  2. required String sequenceStoreId,
})

Retrieves status information about a read set export job and returns the data in JSON format. Use this operation to actively monitor the progress of an export job.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The job's ID.

Parameter sequenceStoreId : The job's sequence store ID.

Implementation

Future<GetReadSetExportJobResponse> getReadSetExportJob({
  required String id,
  required String sequenceStoreId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/exportjob/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetReadSetExportJobResponse.fromJson(response);
}