getReadSetImportJob method
Gets detailed and status information about a read set import job and returns the data in JSON format.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The job's ID.
Parameter sequenceStoreId :
The job's sequence store ID.
Implementation
Future<GetReadSetImportJobResponse> getReadSetImportJob({
required String id,
required String sequenceStoreId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/importjob/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return GetReadSetImportJobResponse.fromJson(response);
}