getReadSetMetadata method

Future<GetReadSetMetadataResponse> getReadSetMetadata({
  1. required String id,
  2. required String sequenceStoreId,
})

Retrieves the metadata for a read set from a sequence store in JSON format. This operation does not return tags. To retrieve the list of tags for a read set, use the ListTagsForResource API operation.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The read set's ID.

Parameter sequenceStoreId : The read set's sequence store ID.

Implementation

Future<GetReadSetMetadataResponse> getReadSetMetadata({
  required String id,
  required String sequenceStoreId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/readset/${Uri.encodeComponent(id)}/metadata',
    exceptionFnMap: _exceptionFns,
  );
  return GetReadSetMetadataResponse.fromJson(response);
}