getReferenceMetadata method

Future<GetReferenceMetadataResponse> getReferenceMetadata({
  1. required String id,
  2. required String referenceStoreId,
})

Retrieves metadata for a reference genome. This operation returns the number of parts, part size, and MD5 of an entire file. This operation does not return tags. To retrieve the list of tags for a read set, use the ListTagsForResource API operation.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The reference's ID.

Parameter referenceStoreId : The reference's reference store ID.

Implementation

Future<GetReferenceMetadataResponse> getReferenceMetadata({
  required String id,
  required String referenceStoreId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/referencestore/${Uri.encodeComponent(referenceStoreId)}/reference/${Uri.encodeComponent(id)}/metadata',
    exceptionFnMap: _exceptionFns,
  );
  return GetReferenceMetadataResponse.fromJson(response);
}