getRun method

Future<GetRunResponse> getRun({
  1. required String id,
  2. List<RunExport>? export,
})

Gets detailed information about a specific run using its ID.

Amazon Web Services HealthOmics stores a configurable number of runs, as determined by service limits, that are available to the console and API. If GetRun does not return the requested run, you can find all run logs in the CloudWatch logs. For more information about viewing the run logs, see CloudWatch logs in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The run's ID.

Parameter export : The run's export format.

Implementation

Future<GetRunResponse> getRun({
  required String id,
  List<RunExport>? export,
}) async {
  final $query = <String, List<String>>{
    if (export != null) 'export': export.map((e) => e.value).toList(),
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/run/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetRunResponse.fromJson(response);
}