getRunCache method

Future<GetRunCacheResponse> getRunCache({
  1. required String id,
})

Retrieves detailed information about the specified run cache using its ID.

For more information, see Call caching for Amazon Web Services HealthOmics runs in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The identifier of the run cache to retrieve.

Implementation

Future<GetRunCacheResponse> getRunCache({
  required String id,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/runCache/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRunCacheResponse.fromJson(response);
}