getWorkflow method

Future<GetWorkflowResponse> getWorkflow({
  1. required String id,
  2. List<WorkflowExport>? export,
  3. WorkflowType? type,
  4. String? workflowOwnerId,
})

Gets all information about a workflow using its ID.

If a workflow is shared with you, you cannot export the workflow.

For more information about your workflow status, see Verify the workflow status in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The workflow's ID.

Parameter export : The export format for the workflow.

Parameter type : The workflow's type.

Parameter workflowOwnerId : The ID of the workflow owner.

Implementation

Future<GetWorkflowResponse> getWorkflow({
  required String id,
  List<WorkflowExport>? export,
  WorkflowType? type,
  String? workflowOwnerId,
}) async {
  final $query = <String, List<String>>{
    if (export != null) 'export': export.map((e) => e.value).toList(),
    if (type != null) 'type': [type.value],
    if (workflowOwnerId != null) 'workflowOwnerId': [workflowOwnerId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/workflow/${Uri.encodeComponent(id)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetWorkflowResponse.fromJson(response);
}