getWorkflowVersion method

Future<GetWorkflowVersionResponse> getWorkflowVersion({
  1. required String versionName,
  2. required String workflowId,
  3. List<WorkflowExport>? export,
  4. WorkflowType? type,
  5. String? workflowOwnerId,
})

Gets information about a workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter versionName : The workflow version name.

Parameter workflowId : The workflow's ID. The workflowId is not the UUID.

Parameter export : The export format for the workflow.

Parameter type : The workflow's type.

Parameter workflowOwnerId : The 12-digit account ID of the workflow owner. The workflow owner ID can be retrieved using the GetShare API operation. If you are the workflow owner, you do not need to include this ID.

Implementation

Future<GetWorkflowVersionResponse> getWorkflowVersion({
  required String versionName,
  required String workflowId,
  List<WorkflowExport>? export,
  WorkflowType? type,
  String? workflowOwnerId,
}) async {
  final $query = <String, List<String>>{
    if (export != null) 'export': export.map((e) => e.value).toList(),
    if (type != null) 'type': [type.value],
    if (workflowOwnerId != null) 'workflowOwnerId': [workflowOwnerId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/workflow/${Uri.encodeComponent(workflowId)}/version/${Uri.encodeComponent(versionName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetWorkflowVersionResponse.fromJson(response);
}