listReadSetImportJobs method
Retrieves a list of read set import jobs and returns the data in JSON format.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sequenceStoreId :
The jobs' sequence store ID.
Parameter filter :
A filter to apply to the list.
Parameter maxResults :
The maximum number of jobs to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListReadSetImportJobsResponse> listReadSetImportJobs({
required String sequenceStoreId,
ImportReadSetFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/importjobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReadSetImportJobsResponse.fromJson(response);
}