listReadSetUploadParts method

Future<ListReadSetUploadPartsResponse> listReadSetUploadParts({
  1. required ReadSetPartSource partSource,
  2. required String sequenceStoreId,
  3. required String uploadId,
  4. ReadSetUploadPartListFilter? filter,
  5. int? maxResults,
  6. String? nextToken,
})

Lists all parts in a multipart read set upload for a sequence store and returns the metadata in a JSON formatted output.

May throw AccessDeniedException. May throw InternalServerException. May throw NotSupportedOperationException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter partSource : The source file for the upload part.

Parameter sequenceStoreId : The Sequence Store ID used for the multipart uploads.

Parameter uploadId : The ID for the initiated multipart upload.

Parameter filter : Attributes used to filter for a specific subset of read set part uploads.

Parameter maxResults : The maximum number of read set upload parts returned in a page.

Parameter nextToken : Next token returned in the response of a previous ListReadSetUploadPartsRequest call. Used to get the next page of results.

Implementation

Future<ListReadSetUploadPartsResponse> listReadSetUploadParts({
  required ReadSetPartSource partSource,
  required String sequenceStoreId,
  required String uploadId,
  ReadSetUploadPartListFilter? filter,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final $payload = <String, dynamic>{
    'partSource': partSource.value,
    if (filter != null) 'filter': filter,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/upload/${Uri.encodeComponent(uploadId)}/parts',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListReadSetUploadPartsResponse.fromJson(response);
}