listReadSets method
Retrieves a list of read sets from a sequence store ID and returns the metadata in JSON format.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sequenceStoreId :
The jobs' sequence store ID.
Parameter filter :
A filter to apply to the list.
Parameter maxResults :
The maximum number of read sets to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListReadSetsResponse> listReadSets({
required String sequenceStoreId,
ReadSetFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/readsets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReadSetsResponse.fromJson(response);
}