listReferenceImportJobs method

Future<ListReferenceImportJobsResponse> listReferenceImportJobs({
  1. required String referenceStoreId,
  2. ImportReferenceFilter? filter,
  3. int? maxResults,
  4. String? nextToken,
})

Retrieves the metadata of one or more reference import jobs for a reference store.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter referenceStoreId : The job's reference store ID.

Parameter filter : A filter to apply to the list.

Parameter maxResults : The maximum number of jobs to return in one page of results.

Parameter nextToken : Specify the pagination token from a previous request to retrieve the next page of results.

Implementation

Future<ListReferenceImportJobsResponse> listReferenceImportJobs({
  required String referenceStoreId,
  ImportReferenceFilter? filter,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final $payload = <String, dynamic>{
    if (filter != null) 'filter': filter,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/referencestore/${Uri.encodeComponent(referenceStoreId)}/importjobs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListReferenceImportJobsResponse.fromJson(response);
}