listReferences method
Retrieves the metadata of one or more reference genomes in a reference store.
For more information, see Creating a reference store in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter referenceStoreId :
The references' reference store ID.
Parameter filter :
A filter to apply to the list.
Parameter maxResults :
The maximum number of references to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListReferencesResponse> listReferences({
required String referenceStoreId,
ReferenceFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/referencestore/${Uri.encodeComponent(referenceStoreId)}/references',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReferencesResponse.fromJson(response);
}