listRunGroups method

Future<ListRunGroupsResponse> listRunGroups({
  1. int? maxResults,
  2. String? name,
  3. String? startingToken,
})

Retrieves a list of all run groups and returns the metadata for each run group.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of run groups to return in one page of results.

Parameter name : The run groups' name.

Parameter startingToken : Specify the pagination token from a previous request to retrieve the next page of results.

Implementation

Future<ListRunGroupsResponse> listRunGroups({
  int? maxResults,
  String? name,
  String? startingToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (name != null) 'name': [name],
    if (startingToken != null) 'startingToken': [startingToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/runGroup',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRunGroupsResponse.fromJson(response);
}