listWorkflowVersions method
Lists the workflow versions for the specified workflow. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workflowId :
The workflow's ID. The workflowId is not the UUID.
Parameter maxResults :
The maximum number of workflows to return in one page of results.
Parameter startingToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter type :
The workflow type.
Parameter workflowOwnerId :
The 12-digit account ID of the workflow owner. The workflow owner ID can
be retrieved using the GetShare API operation. If you are the
workflow owner, you do not need to include this ID.
Implementation
Future<ListWorkflowVersionsResponse> listWorkflowVersions({
required String workflowId,
int? maxResults,
String? startingToken,
WorkflowType? type,
String? workflowOwnerId,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (startingToken != null) 'startingToken': [startingToken],
if (type != null) 'type': [type.value],
if (workflowOwnerId != null) 'workflowOwnerId': [workflowOwnerId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/workflow/${Uri.encodeComponent(workflowId)}/version',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListWorkflowVersionsResponse.fromJson(response);
}