startReadSetActivationJob method
Activates an archived read set and returns its metadata in a JSON
formatted output. AWS HealthOmics automatically archives unused read sets
after 30 days. To monitor the status of your read set activation job, use
the GetReadSetActivationJob operation.
To learn more, see Activating read sets in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sequenceStoreId :
The read set's sequence store ID.
Parameter sources :
The job's source files.
Parameter clientToken :
To ensure that jobs don't run multiple times, specify a unique token for
each job.
Implementation
Future<StartReadSetActivationJobResponse> startReadSetActivationJob({
required String sequenceStoreId,
required List<StartReadSetActivationJobSourceItem> sources,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'sources': sources,
if (clientToken != null) 'clientToken': clientToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/activationjob',
exceptionFnMap: _exceptionFns,
);
return StartReadSetActivationJobResponse.fromJson(response);
}