startReferenceImportJob method

Future<StartReferenceImportJobResponse> startReferenceImportJob({
  1. required String referenceStoreId,
  2. required String roleArn,
  3. required List<StartReferenceImportJobSourceItem> sources,
  4. String? clientToken,
})

Imports a reference genome from Amazon S3 into a specified reference store. You can have multiple reference genomes in a reference store. You can only import reference genomes one at a time into each reference store. Monitor the status of your reference import job by using the GetReferenceImportJob API operation.

May throw AccessDeniedException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter referenceStoreId : The job's reference store ID.

Parameter roleArn : A service role for the job.

Parameter sources : The job's source files.

Parameter clientToken : To ensure that jobs don't run multiple times, specify a unique token for each job.

Implementation

Future<StartReferenceImportJobResponse> startReferenceImportJob({
  required String referenceStoreId,
  required String roleArn,
  required List<StartReferenceImportJobSourceItem> sources,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'roleArn': roleArn,
    'sources': sources,
    if (clientToken != null) 'clientToken': clientToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/referencestore/${Uri.encodeComponent(referenceStoreId)}/importjob',
    exceptionFnMap: _exceptionFns,
  );
  return StartReferenceImportJobResponse.fromJson(response);
}