updateRunCache method
Updates a run cache using its ID and returns a response with no body if
the operation is successful. You can update the run cache description,
name, or the default run cache behavior with CACHE_ON_FAILURE
or CACHE_ALWAYS. To confirm that your run cache settings have
been properly updated, use the GetRunCache API operation.
For more information, see How call caching works in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The identifier of the run cache you want to update.
Parameter cacheBehavior :
Update the default run cache behavior.
Parameter description :
Update the run cache description.
Parameter name :
Update the name of the run cache.
Implementation
Future<void> updateRunCache({
required String id,
CacheBehavior? cacheBehavior,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (cacheBehavior != null) 'cacheBehavior': cacheBehavior.value,
if (description != null) 'description': description,
if (name != null) 'name': name,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/runCache/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}