updateSequenceStore method

Future<UpdateSequenceStoreResponse> updateSequenceStore({
  1. required String id,
  2. String? clientToken,
  3. String? description,
  4. String? fallbackLocation,
  5. String? name,
  6. List<String>? propagatedSetLevelTags,
  7. S3AccessConfig? s3AccessConfig,
})

Update one or more parameters for the sequence store.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the sequence store.

Parameter clientToken : To ensure that requests don't run multiple times, specify a unique token for each request.

Parameter description : A description for the sequence store.

Parameter fallbackLocation : The S3 URI of a bucket and folder to store Read Sets that fail to upload.

Parameter name : A name for the sequence store.

Parameter propagatedSetLevelTags : The tags keys to propagate to the S3 objects associated with read sets in the sequence store.

Parameter s3AccessConfig : S3 access configuration parameters.

Implementation

Future<UpdateSequenceStoreResponse> updateSequenceStore({
  required String id,
  String? clientToken,
  String? description,
  String? fallbackLocation,
  String? name,
  List<String>? propagatedSetLevelTags,
  S3AccessConfig? s3AccessConfig,
}) async {
  final $payload = <String, dynamic>{
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (description != null) 'description': description,
    if (fallbackLocation != null) 'fallbackLocation': fallbackLocation,
    if (name != null) 'name': name,
    if (propagatedSetLevelTags != null)
      'propagatedSetLevelTags': propagatedSetLevelTags,
    if (s3AccessConfig != null) 's3AccessConfig': s3AccessConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/sequencestore/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSequenceStoreResponse.fromJson(response);
}