updateWorkflowVersion method

Future<void> updateWorkflowVersion({
  1. required String versionName,
  2. required String workflowId,
  3. String? description,
  4. String? readmeMarkdown,
  5. int? storageCapacity,
  6. StorageType? storageType,
})

Updates information about the workflow version. For more information, see Workflow versioning in Amazon Web Services HealthOmics in the Amazon Web Services HealthOmics User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw RequestTimeoutException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter versionName : The name of the workflow version.

Parameter workflowId : The workflow's ID. The workflowId is not the UUID.

Parameter description : Description of the workflow version.

Parameter readmeMarkdown : The markdown content for the workflow version's README file. This provides documentation and usage information for users of this specific workflow version.

Parameter storageCapacity : The default static storage capacity (in gibibytes) for runs that use this workflow version. The storageCapacity can be overwritten at run time. The storage capacity is not required for runs with a DYNAMIC storage type.

Parameter storageType : The default storage type for runs that use this workflow version. The storageType can be overridden at run time. DYNAMIC storage dynamically scales the storage up or down, based on file system utilization. STATIC storage allocates a fixed amount of storage. For more information about dynamic and static storage types, see Run storage types in the in the Amazon Web Services HealthOmics User Guide .

Implementation

Future<void> updateWorkflowVersion({
  required String versionName,
  required String workflowId,
  String? description,
  String? readmeMarkdown,
  int? storageCapacity,
  StorageType? storageType,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (readmeMarkdown != null) 'readmeMarkdown': readmeMarkdown,
    if (storageCapacity != null) 'storageCapacity': storageCapacity,
    if (storageType != null) 'storageType': storageType.value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/workflow/${Uri.encodeComponent(workflowId)}/version/${Uri.encodeComponent(versionName)}',
    exceptionFnMap: _exceptionFns,
  );
}