uploadReadSetPart method
Uploads a specific part of a read set into a sequence store. When you a upload a read set part with a part number that already exists, the new part replaces the existing one. This operation returns a JSON formatted response containing a string identifier that is used to confirm that parts are being added to the intended upload.
For more information, see Direct upload to a sequence store in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw NotSupportedOperationException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter partNumber :
The number of the part being uploaded.
Parameter partSource :
The source file for an upload part.
Parameter payload :
The read set data to upload for a part.
Parameter sequenceStoreId :
The Sequence Store ID used for the multipart upload.
Parameter uploadId :
The ID for the initiated multipart upload.
Implementation
Future<UploadReadSetPartResponse> uploadReadSetPart({
required int partNumber,
required ReadSetPartSource partSource,
required Uint8List payload,
required String sequenceStoreId,
required String uploadId,
}) async {
final $query = <String, List<String>>{
'partNumber': [partNumber.toString()],
'partSource': [partSource.value],
};
final response = await _protocol.send(
payload: payload,
method: 'PUT',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/upload/${Uri.encodeComponent(uploadId)}/part',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return UploadReadSetPartResponse.fromJson(response);
}