OpenSearch class
Use the Amazon OpenSearch Service configuration API to create, configure, and manage OpenSearch Service domains. The endpoint for configuration service requests is Region specific: es.region.amazonaws.com. For example, es.us-east-1.amazonaws.com. For a current list of supported Regions and endpoints, see Amazon Web Services service endpoints.
Constructors
- OpenSearch({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptInboundConnection(
{required String connectionId}) → Future< AcceptInboundConnectionResponse> - Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
addDataSource(
{required DataSourceType dataSourceType, required String domainName, required String name, String? description}) → Future< AddDataSourceResponse> - Creates a new direct-query data source to the specified domain. For more information, see Creating Amazon OpenSearch Service data source integrations with Amazon S3.
-
addDirectQueryDataSource(
{required String dataSourceName, required DirectQueryDataSourceType dataSourceType, String? dataSourceAccessPolicy, String? description, List< String> ? openSearchArns, List<Tag> ? tagList}) → Future<AddDirectQueryDataSourceResponse> - Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.
-
addTags(
{required String arn, required List< Tag> tagList}) → Future<void> - Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application.
-
associatePackage(
{required String domainName, required String packageID, PackageAssociationConfiguration? associationConfiguration, List< String> ? prerequisitePackageIDList}) → Future<AssociatePackageResponse> - Associates a package with an Amazon OpenSearch Service domain. For more information, see Custom packages for Amazon OpenSearch Service.
-
associatePackages(
{required String domainName, required List< PackageDetailsForAssociation> packageList}) → Future<AssociatePackagesResponse> - Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.
- Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
cancelDomainConfigChange(
{required String domainName, bool? dryRun}) → Future< CancelDomainConfigChangeResponse> - Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
cancelServiceSoftwareUpdate(
{required String domainName}) → Future< CancelServiceSoftwareUpdateResponse> -
Cancels a scheduled service software update for an Amazon OpenSearch
Service domain. You can only perform this operation before the
AutomatedUpdateDateand when the domain'sUpdateStatusisPENDING_UPDATE. For more information, see Service software updates in Amazon OpenSearch Service. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createApplication(
{required String name, List< AppConfig> ? appConfigs, String? clientToken, List<DataSource> ? dataSources, IamIdentityCenterOptionsInput? iamIdentityCenterOptions, String? kmsKeyArn, List<Tag> ? tagList}) → Future<CreateApplicationResponse> - Creates an OpenSearch UI application. For more information, see Using the OpenSearch user interface in Amazon OpenSearch Service.
-
createDomain(
{required String domainName, AIMLOptionsInput? aIMLOptions, String? accessPolicies, Map< String, String> ? advancedOptions, AdvancedSecurityOptionsInput? advancedSecurityOptions, AutoTuneOptionsInput? autoTuneOptions, AutomatedSnapshotPauseRequestOptions? automatedSnapshotPauseOptions, ClusterConfig? clusterConfig, CognitoOptions? cognitoOptions, DeploymentStrategyOptions? deploymentStrategyOptions, DomainEndpointOptions? domainEndpointOptions, EBSOptions? eBSOptions, EncryptionAtRestOptions? encryptionAtRestOptions, String? engineVersion, IPAddressType? iPAddressType, IdentityCenterOptionsInput? identityCenterOptions, Map<LogType, LogPublishingOption> ? logPublishingOptions, NodeToNodeEncryptionOptions? nodeToNodeEncryptionOptions, OffPeakWindowOptions? offPeakWindowOptions, SnapshotOptions? snapshotOptions, SoftwareUpdateOptions? softwareUpdateOptions, List<Tag> ? tagList, VPCOptions? vPCOptions}) → Future<CreateDomainResponse> - Creates an Amazon OpenSearch Service domain. For more information, see Creating and managing Amazon OpenSearch Service domains.
-
createIndex(
{required String domainName, required String indexName, required Object indexSchema}) → Future< CreateIndexResponse> - Creates an OpenSearch index with optional automatic semantic enrichment for specified text fields. Automatic semantic enrichment enables semantic search capabilities without requiring machine learning expertise, improving search relevance by up to 20% by understanding search intent and contextual meaning beyond keyword matching. The semantic enrichment process has zero impact on search latency as sparse encodings are stored directly within the index during indexing. For more information, see Automatic semantic enrichment.
-
createOutboundConnection(
{required String connectionAlias, required DomainInformationContainer localDomainInfo, required DomainInformationContainer remoteDomainInfo, ConnectionMode? connectionMode, ConnectionProperties? connectionProperties}) → Future< CreateOutboundConnectionResponse> - Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
createPackage(
{required String packageName, required PackageSource packageSource, required PackageType packageType, String? engineVersion, PackageConfiguration? packageConfiguration, String? packageDescription, PackageEncryptionOptions? packageEncryptionOptions, PackageVendingOptions? packageVendingOptions}) → Future< CreatePackageResponse> - Creates a package for use with Amazon OpenSearch Service domains. For more information, see Custom packages for Amazon OpenSearch Service.
-
createVpcEndpoint(
{required String domainArn, required VPCOptions vpcOptions, String? clientToken}) → Future< CreateVpcEndpointResponse> - Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
deleteApplication(
{required String id}) → Future< void> - Deletes a specified OpenSearch application.
-
deleteDataSource(
{required String domainName, required String name}) → Future< DeleteDataSourceResponse> - Deletes a direct-query data source. For more information, see Deleting an Amazon OpenSearch Service data source with Amazon S3.
-
deleteDirectQueryDataSource(
{required String dataSourceName}) → Future< void> - Deletes a previously configured direct query data source from Amazon OpenSearch Service.
-
deleteDomain(
{required String domainName}) → Future< DeleteDomainResponse> - Deletes an Amazon OpenSearch Service domain and all of its data. You can't recover a domain after you delete it.
-
deleteInboundConnection(
{required String connectionId}) → Future< DeleteInboundConnectionResponse> - Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
deleteIndex(
{required String domainName, required String indexName}) → Future< DeleteIndexResponse> - Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.
-
deleteOutboundConnection(
{required String connectionId}) → Future< DeleteOutboundConnectionResponse> - Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
deletePackage(
{required String packageID}) → Future< DeletePackageResponse> - Deletes an Amazon OpenSearch Service package. For more information, see Custom packages for Amazon OpenSearch Service.
-
deleteVpcEndpoint(
{required String vpcEndpointId}) → Future< DeleteVpcEndpointResponse> - Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
deregisterCapability(
{required String applicationId, required String capabilityName}) → Future< DeregisterCapabilityResponse> - Deregisters a capability from an OpenSearch UI application. This operation removes the capability and its associated configuration.
-
describeDomain(
{required String domainName}) → Future< DescribeDomainResponse> - Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.
-
describeDomainAutoTunes(
{required String domainName, int? maxResults, String? nextToken}) → Future< DescribeDomainAutoTunesResponse> - Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain. For more information, see Auto-Tune for Amazon OpenSearch Service.
-
describeDomainChangeProgress(
{required String domainName, String? changeId}) → Future< DescribeDomainChangeProgressResponse> - Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain. For more information, see Making configuration changes in Amazon OpenSearch Service.
-
describeDomainConfig(
{required String domainName}) → Future< DescribeDomainConfigResponse> - Returns the configuration of an Amazon OpenSearch Service domain.
-
describeDomainHealth(
{required String domainName}) → Future< DescribeDomainHealthResponse> - Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
-
describeDomainNodes(
{required String domainName}) → Future< DescribeDomainNodesResponse> - Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states.
-
describeDomains(
{required List< String> domainNames}) → Future<DescribeDomainsResponse> - Returns domain configuration information about the specified Amazon OpenSearch Service domains.
-
describeDryRunProgress(
{required String domainName, String? dryRunId, bool? loadDryRunConfig}) → Future< DescribeDryRunProgressResponse> - Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain. For more information, see Determining whether a change will cause a blue/green deployment.
-
describeInboundConnections(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeInboundConnectionsResponse> - Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
describeInsightDetails(
{required InsightEntity entity, required String insightId, bool? showHtmlContent}) → Future< DescribeInsightDetailsResponse> - Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.
-
describeInstanceTypeLimits(
{required String engineVersion, required OpenSearchPartitionInstanceType instanceType, String? domainName}) → Future< DescribeInstanceTypeLimitsResponse> - Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type.
-
describeOutboundConnections(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeOutboundConnectionsResponse> - Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.
-
describePackages(
{List< DescribePackagesFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribePackagesResponse> - Describes all packages available to OpenSearch Service. For more information, see Custom packages for Amazon OpenSearch Service.
-
describeReservedInstanceOfferings(
{int? maxResults, String? nextToken, String? reservedInstanceOfferingId}) → Future< DescribeReservedInstanceOfferingsResponse> - Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region. For more information, see Reserved Instances in Amazon OpenSearch Service.
-
describeReservedInstances(
{int? maxResults, String? nextToken, String? reservedInstanceId}) → Future< DescribeReservedInstancesResponse> - Describes the Amazon OpenSearch Service instances that you have reserved in a given Region. For more information, see Reserved Instances in Amazon OpenSearch Service.
-
describeVpcEndpoints(
{required List< String> vpcEndpointIds}) → Future<DescribeVpcEndpointsResponse> - Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
dissociatePackage(
{required String domainName, required String packageID}) → Future< DissociatePackageResponse> - Removes a package from the specified Amazon OpenSearch Service domain. The package can't be in use with any OpenSearch index for the dissociation to succeed. The package is still available in OpenSearch Service for association later. For more information, see Custom packages for Amazon OpenSearch Service.
-
dissociatePackages(
{required String domainName, required List< String> packageList}) → Future<DissociatePackagesResponse> - Dissociates multiple packages from a domain simultaneously.
-
getApplication(
{required String id}) → Future< GetApplicationResponse> - Retrieves the configuration and status of an existing OpenSearch application.
-
getCapability(
{required String applicationId, required String capabilityName}) → Future< GetCapabilityResponse> - Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
-
getCompatibleVersions(
{String? domainName}) → Future< GetCompatibleVersionsResponse> - Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.
-
getDataSource(
{required String domainName, required String name}) → Future< GetDataSourceResponse> - Retrieves information about a direct query data source.
-
getDefaultApplicationSetting(
) → Future< GetDefaultApplicationSettingResponse> - Gets the ARN of the current default application.
-
getDirectQueryDataSource(
{required String dataSourceName}) → Future< GetDirectQueryDataSourceResponse> - Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
-
getDomainMaintenanceStatus(
{required String domainName, required String maintenanceId}) → Future< GetDomainMaintenanceStatusResponse> - The status of the maintenance action.
-
getIndex(
{required String domainName, required String indexName}) → Future< GetIndexResponse> - Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration. Use this operation to view the current index structure and semantic search settings.
-
getPackageVersionHistory(
{required String packageID, int? maxResults, String? nextToken}) → Future< GetPackageVersionHistoryResponse> - Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package). For more information, see Custom packages for Amazon OpenSearch Service.
-
getUpgradeHistory(
{required String domainName, int? maxResults, String? nextToken}) → Future< GetUpgradeHistoryResponse> - Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain.
-
getUpgradeStatus(
{required String domainName}) → Future< GetUpgradeStatusResponse> - Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
-
listApplications(
{int? maxResults, String? nextToken, List< ApplicationStatus> ? statuses}) → Future<ListApplicationsResponse> - Lists all OpenSearch applications under your account.
-
listDataSources(
{required String domainName}) → Future< ListDataSourcesResponse> - Lists direct-query data sources for a specific domain. For more information, see For more information, see Working with Amazon OpenSearch Service direct queries with Amazon S3.
-
listDirectQueryDataSources(
{String? nextToken}) → Future< ListDirectQueryDataSourcesResponse> - Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
-
listDomainMaintenances(
{required String domainName, MaintenanceType? action, int? maxResults, String? nextToken, MaintenanceStatus? status}) → Future< ListDomainMaintenancesResponse> - A list of maintenance actions for the domain.
-
listDomainNames(
{EngineType? engineType}) → Future< ListDomainNamesResponse> - Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region.
-
listDomainsForPackage(
{required String packageID, int? maxResults, String? nextToken}) → Future< ListDomainsForPackageResponse> - Lists all Amazon OpenSearch Service domains associated with a given package. For more information, see Custom packages for Amazon OpenSearch Service.
-
listInsights(
{required InsightEntity entity, int? maxResults, String? nextToken, InsightSortOrder? sortOrder, InsightTimeRange? timeRange}) → Future< ListInsightsResponse> - Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account. Returns a paginated list of insights based on the specified entity, filters, time range, and sort order.
-
listInstanceTypeDetails(
{required String engineVersion, String? domainName, String? instanceType, int? maxResults, String? nextToken, bool? retrieveAZs}) → Future< ListInstanceTypeDetailsResponse> - Lists all instance types and available features for a given OpenSearch or Elasticsearch version.
-
listPackagesForDomain(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListPackagesForDomainResponse> - Lists all packages associated with an Amazon OpenSearch Service domain. For more information, see Custom packages for Amazon OpenSearch Service.
-
listScheduledActions(
{required String domainName, int? maxResults, String? nextToken}) → Future< ListScheduledActionsResponse> - Retrieves a list of configuration changes that are scheduled for a domain. These changes can be service software updates or blue/green Auto-Tune enhancements.
-
listTags(
{required String arn}) → Future< ListTagsResponse> - Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application. For more information, see Tagging Amazon OpenSearch Service resources.
-
listVersions(
{int? maxResults, String? nextToken}) → Future< ListVersionsResponse> - Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports.
-
listVpcEndpointAccess(
{required String domainName, String? nextToken}) → Future< ListVpcEndpointAccessResponse> - Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
listVpcEndpoints(
{String? nextToken}) → Future< ListVpcEndpointsResponse> - Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.
-
listVpcEndpointsForDomain(
{required String domainName, String? nextToken}) → Future< ListVpcEndpointsForDomainResponse> - Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purchaseReservedInstanceOffering(
{required String reservationName, required String reservedInstanceOfferingId, int? instanceCount}) → Future< PurchaseReservedInstanceOfferingResponse> - Allows you to purchase Amazon OpenSearch Service Reserved Instances.
-
putDefaultApplicationSetting(
{required String applicationArn, required bool setAsDefault}) → Future< PutDefaultApplicationSettingResponse> - Sets the default application to the application with the specified ARN.
-
registerCapability(
{required String applicationId, required CapabilityBaseRequestConfig capabilityConfig, required String capabilityName}) → Future< RegisterCapabilityResponse> - Registers a capability for an OpenSearch UI application. Use this operation to enable specific capabilities, such as AI features, for a given application. The capability configuration defines the type and settings of the capability to register. For more information about the AI features, see Agentic AI for OpenSearch UI.
-
rejectInboundConnection(
{required String connectionId}) → Future< RejectInboundConnectionResponse> - Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.
-
removeTags(
{required String arn, required List< String> tagKeys}) → Future<void> - Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application. For more information, see Tagging Amazon OpenSearch Service resources.
-
revokeVpcEndpointAccess(
{required String domainName, String? account, AWSServicePrincipal? service, ServiceOptions? serviceOptions}) → Future< void> - Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
rollbackServiceSoftwareUpdate(
{required String domainName}) → Future< RollbackServiceSoftwareUpdateResponse> - Rolls back a service software update for a domain to the previous version. For more information, see Service software updates in Amazon OpenSearch Service.
-
startDomainMaintenance(
{required MaintenanceType action, required String domainName, String? nodeId}) → Future< StartDomainMaintenanceResponse> - Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart, or a Dashboard or Kibana restart.
-
startServiceSoftwareUpdate(
{required String domainName, int? desiredStartTime, ScheduleAt? scheduleAt}) → Future< StartServiceSoftwareUpdateResponse> - Schedules a service software update for an Amazon OpenSearch Service domain. For more information, see Service software updates in Amazon OpenSearch Service.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateApplication(
{required String id, List< AppConfig> ? appConfigs, List<DataSource> ? dataSources}) → Future<UpdateApplicationResponse> - Updates the configuration and settings of an existing OpenSearch application.
-
updateDataSource(
{required DataSourceType dataSourceType, required String domainName, required String name, String? description, DataSourceStatus? status}) → Future< UpdateDataSourceResponse> - Updates a direct-query data source. For more information, see Working with Amazon OpenSearch Service data source integrations with Amazon S3.
-
updateDirectQueryDataSource(
{required String dataSourceName, required DirectQueryDataSourceType dataSourceType, String? dataSourceAccessPolicy, String? description, List< String> ? openSearchArns}) → Future<UpdateDirectQueryDataSourceResponse> - Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service.
-
updateDomainConfig(
{required String domainName, AIMLOptionsInput? aIMLOptions, String? accessPolicies, Map< String, String> ? advancedOptions, AdvancedSecurityOptionsInput? advancedSecurityOptions, AutoTuneOptions? autoTuneOptions, AutomatedSnapshotPauseRequestOptions? automatedSnapshotPauseOptions, ClusterConfig? clusterConfig, CognitoOptions? cognitoOptions, DeploymentStrategyOptions? deploymentStrategyOptions, DomainEndpointOptions? domainEndpointOptions, bool? dryRun, DryRunMode? dryRunMode, EBSOptions? eBSOptions, EncryptionAtRestOptions? encryptionAtRestOptions, IPAddressType? iPAddressType, IdentityCenterOptionsInput? identityCenterOptions, Map<LogType, LogPublishingOption> ? logPublishingOptions, NodeToNodeEncryptionOptions? nodeToNodeEncryptionOptions, OffPeakWindowOptions? offPeakWindowOptions, SnapshotOptions? snapshotOptions, SoftwareUpdateOptions? softwareUpdateOptions, VPCOptions? vPCOptions}) → Future<UpdateDomainConfigResponse> - Modifies the cluster configuration of the specified Amazon OpenSearch Service domain.
-
updateIndex(
{required String domainName, required String indexName, required Object indexSchema}) → Future< UpdateIndexResponse> - Updates an existing OpenSearch index schema and semantic enrichment configuration. This operation allows modification of field mappings and semantic search settings for text fields. Changes to semantic enrichment configuration will apply to newly ingested documents.
-
updatePackage(
{required String packageID, required PackageSource packageSource, String? commitMessage, PackageConfiguration? packageConfiguration, String? packageDescription, PackageEncryptionOptions? packageEncryptionOptions}) → Future< UpdatePackageResponse> - Updates a package for use with Amazon OpenSearch Service domains. For more information, see Custom packages for Amazon OpenSearch Service.
-
updatePackageScope(
{required PackageScopeOperationEnum operation, required String packageID, required List< String> packageUserList}) → Future<UpdatePackageScopeResponse> - Updates the scope of a package. Scope of the package defines users who can view and associate a package.
-
updateScheduledAction(
{required String actionID, required ActionType actionType, required String domainName, required ScheduleAt scheduleAt, int? desiredStartTime}) → Future< UpdateScheduledActionResponse> - Reschedules a planned domain configuration change for a later time. This change can be a scheduled service software update or a blue/green Auto-Tune enhancement.
-
updateVpcEndpoint(
{required String vpcEndpointId, required VPCOptions vpcOptions}) → Future< UpdateVpcEndpointResponse> - Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
upgradeDomain(
{required String domainName, required String targetVersion, Map< String, String> ? advancedOptions, bool? performCheckOnly}) → Future<UpgradeDomainResponse> - Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited