associatePackages method

Future<AssociatePackagesResponse> associatePackages({
  1. required String domainName,
  2. required List<PackageDetailsForAssociation> packageList,
})

Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.

May throw BaseException. May throw ConflictException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter packageList : A list of packages and their prerequisites to be associated with a domain.

Implementation

Future<AssociatePackagesResponse> associatePackages({
  required String domainName,
  required List<PackageDetailsForAssociation> packageList,
}) async {
  final $payload = <String, dynamic>{
    'DomainName': domainName,
    'PackageList': packageList,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2021-01-01/packages/associateMultiple',
    exceptionFnMap: _exceptionFns,
  );
  return AssociatePackagesResponse.fromJson(response);
}