cancelDomainConfigChange method

Future<CancelDomainConfigChangeResponse> cancelDomainConfigChange({
  1. required String domainName,
  2. bool? dryRun,
})

Cancels a pending configuration change on an Amazon OpenSearch Service domain.

May throw BaseException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter dryRun : When set to True, returns the list of change IDs and properties that will be cancelled without actually cancelling the change.

Implementation

Future<CancelDomainConfigChangeResponse> cancelDomainConfigChange({
  required String domainName,
  bool? dryRun,
}) async {
  final $payload = <String, dynamic>{
    if (dryRun != null) 'DryRun': dryRun,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/config/cancel',
    exceptionFnMap: _exceptionFns,
  );
  return CancelDomainConfigChangeResponse.fromJson(response);
}