cancelServiceSoftwareUpdate method

Future<CancelServiceSoftwareUpdateResponse> cancelServiceSoftwareUpdate({
  1. required String domainName,
})

Cancels a scheduled service software update for an Amazon OpenSearch Service domain. You can only perform this operation before the AutomatedUpdateDate and when the domain's UpdateStatus is PENDING_UPDATE. For more information, see Service software updates in Amazon OpenSearch Service.

May throw BaseException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter domainName : Name of the OpenSearch Service domain that you want to cancel the service software update on.

Implementation

Future<CancelServiceSoftwareUpdateResponse> cancelServiceSoftwareUpdate({
  required String domainName,
}) async {
  final $payload = <String, dynamic>{
    'DomainName': domainName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2021-01-01/opensearch/serviceSoftwareUpdate/cancel',
    exceptionFnMap: _exceptionFns,
  );
  return CancelServiceSoftwareUpdateResponse.fromJson(response);
}