deleteOutboundConnection method

Future<DeleteOutboundConnectionResponse> deleteOutboundConnection({
  1. required String connectionId,
})

Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection. For more information, see Cross-cluster search for Amazon OpenSearch Service.

May throw DisabledOperationException. May throw ResourceNotFoundException.

Parameter connectionId : The ID of the outbound connection you want to permanently delete.

Implementation

Future<DeleteOutboundConnectionResponse> deleteOutboundConnection({
  required String connectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/2021-01-01/opensearch/cc/outboundConnection/${Uri.encodeComponent(connectionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteOutboundConnectionResponse.fromJson(response);
}