describeDomain method

Future<DescribeDomainResponse> describeDomain({
  1. required String domainName,
})

Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN.

May throw BaseException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter domainName : The name of the domain that you want information about.

Implementation

Future<DescribeDomainResponse> describeDomain({
  required String domainName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDomainResponse.fromJson(response);
}