describeDomainAutoTunes method

Future<DescribeDomainAutoTunesResponse> describeDomainAutoTunes({
  1. required String domainName,
  2. int? maxResults,
  3. String? nextToken,
})

Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain. For more information, see Auto-Tune for Amazon OpenSearch Service.

May throw BaseException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter domainName : Name of the domain that you want Auto-Tune details about.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

Parameter nextToken : If your initial DescribeDomainAutoTunes operation returns a nextToken, you can include the returned nextToken in subsequent DescribeDomainAutoTunes operations, which returns results in the next page.

Implementation

Future<DescribeDomainAutoTunesResponse> describeDomainAutoTunes({
  required String domainName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/autoTunes',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDomainAutoTunesResponse.fromJson(response);
}