describeDomainChangeProgress method
Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain. For more information, see Making configuration changes in Amazon OpenSearch Service.
May throw BaseException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The name of the domain to get progress information for.
Parameter changeId :
The specific change ID for which you want to get progress information. If
omitted, the request returns information about the most recent
configuration change.
Implementation
Future<DescribeDomainChangeProgressResponse> describeDomainChangeProgress({
required String domainName,
String? changeId,
}) async {
final $query = <String, List<String>>{
if (changeId != null) 'changeid': [changeId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/progress',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeDomainChangeProgressResponse.fromJson(response);
}