describeDomains method
Returns domain configuration information about the specified Amazon OpenSearch Service domains.
May throw BaseException.
May throw InternalException.
May throw ValidationException.
Parameter domainNames :
Array of OpenSearch Service domain names that you want information about.
You must specify at least one domain name.
Implementation
Future<DescribeDomainsResponse> describeDomains({
required List<String> domainNames,
}) async {
final $payload = <String, dynamic>{
'DomainNames': domainNames,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2021-01-01/opensearch/domain-info',
exceptionFnMap: _exceptionFns,
);
return DescribeDomainsResponse.fromJson(response);
}