describeInboundConnections method

Future<DescribeInboundConnectionsResponse> describeInboundConnections({
  1. List<Filter>? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.

May throw DisabledOperationException. May throw InvalidPaginationTokenException.

Parameter filters : A list of filters used to match properties for inbound cross-cluster connections.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

Parameter nextToken : If your initial DescribeInboundConnections operation returns a nextToken, you can include the returned nextToken in subsequent DescribeInboundConnections operations, which returns results in the next page.

Implementation

Future<DescribeInboundConnectionsResponse> describeInboundConnections({
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $payload = <String, dynamic>{
    if (filters != null) 'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2021-01-01/opensearch/cc/inboundConnection/search',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeInboundConnectionsResponse.fromJson(response);
}