describeInsightDetails method
Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter entity :
The entity for which to retrieve insight details. Specifies the type and
value of the entity, such as a domain name or Amazon Web Services account
ID.
Parameter insightId :
The unique identifier of the insight to describe.
Parameter showHtmlContent :
Specifies whether to show response with HTML content in response or not.
Implementation
Future<DescribeInsightDetailsResponse> describeInsightDetails({
required InsightEntity entity,
required String insightId,
bool? showHtmlContent,
}) async {
final $payload = <String, dynamic>{
'Entity': entity,
'InsightId': insightId,
if (showHtmlContent != null) 'ShowHtmlContent': showHtmlContent,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2021-01-01/opensearch/insight-details',
exceptionFnMap: _exceptionFns,
);
return DescribeInsightDetailsResponse.fromJson(response);
}