describeOutboundConnections method

Future<DescribeOutboundConnectionsResponse> describeOutboundConnections({
  1. List<Filter>? filters,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain. For more information, see Cross-cluster search for Amazon OpenSearch Service.

May throw DisabledOperationException. May throw InvalidPaginationTokenException.

Parameter filters : List of filter names and values that you can use for requests.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

Parameter nextToken : If your initial DescribeOutboundConnections operation returns a nextToken, you can include the returned nextToken in subsequent DescribeOutboundConnections operations, which returns results in the next page.

Implementation

Future<DescribeOutboundConnectionsResponse> describeOutboundConnections({
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final $payload = <String, dynamic>{
    if (filters != null) 'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2021-01-01/opensearch/cc/outboundConnection/search',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeOutboundConnectionsResponse.fromJson(response);
}