dissociatePackage method
Removes a package from the specified Amazon OpenSearch Service domain. The package can't be in use with any OpenSearch index for the dissociation to succeed. The package is still available in OpenSearch Service for association later. For more information, see Custom packages for Amazon OpenSearch Service.
May throw AccessDeniedException.
May throw BaseException.
May throw ConflictException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
Name of the domain to dissociate the package from.
Parameter packageID :
Internal ID of the package to dissociate from the domain. Use
ListPackagesForDomain to find this value.
Implementation
Future<DissociatePackageResponse> dissociatePackage({
required String domainName,
required String packageID,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/2021-01-01/packages/dissociate/${Uri.encodeComponent(packageID)}/${Uri.encodeComponent(domainName)}',
exceptionFnMap: _exceptionFns,
);
return DissociatePackageResponse.fromJson(response);
}