getCompatibleVersions method

Future<GetCompatibleVersionsResponse> getCompatibleVersions({
  1. String? domainName,
})

Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to.

May throw BaseException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter domainName : The name of an existing domain. Provide this parameter to limit the results to a single domain.

Implementation

Future<GetCompatibleVersionsResponse> getCompatibleVersions({
  String? domainName,
}) async {
  final $query = <String, List<String>>{
    if (domainName != null) 'domainName': [domainName],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2021-01-01/opensearch/compatibleVersions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetCompatibleVersionsResponse.fromJson(response);
}