getUpgradeStatus method
Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The domain of the domain to get upgrade status information for.
Implementation
Future<GetUpgradeStatusResponse> getUpgradeStatus({
required String domainName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/upgradeDomain/${Uri.encodeComponent(domainName)}/status',
exceptionFnMap: _exceptionFns,
);
return GetUpgradeStatusResponse.fromJson(response);
}