listVpcEndpointAccess method
Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
Parameter domainName :
The name of the OpenSearch Service domain to retrieve access information
for.
Parameter nextToken :
If your initial ListVpcEndpointAccess operation returns a
nextToken, you can include the returned
nextToken in subsequent ListVpcEndpointAccess
operations, which returns results in the next page.
Implementation
Future<ListVpcEndpointAccessResponse> listVpcEndpointAccess({
required String domainName,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/listVpcEndpointAccess',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListVpcEndpointAccessResponse.fromJson(response);
}