listVpcEndpoints method

Future<ListVpcEndpointsResponse> listVpcEndpoints({
  1. String? nextToken,
})

Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.

May throw BaseException. May throw DisabledOperationException. May throw InternalException.

Parameter nextToken : If your initial ListVpcEndpoints operation returns a nextToken, you can include the returned nextToken in subsequent ListVpcEndpoints operations, which returns results in the next page.

Implementation

Future<ListVpcEndpointsResponse> listVpcEndpoints({
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2021-01-01/opensearch/vpcEndpoints',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListVpcEndpointsResponse.fromJson(response);
}