listVpcEndpointsForDomain method

Future<ListVpcEndpointsForDomainResponse> listVpcEndpointsForDomain({
  1. required String domainName,
  2. String? nextToken,
})

Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.

May throw BaseException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException.

Parameter domainName : The name of the domain to list associated VPC endpoints for.

Parameter nextToken : If your initial ListEndpointsForDomain operation returns a nextToken, you can include the returned nextToken in subsequent ListEndpointsForDomain operations, which returns results in the next page.

Implementation

Future<ListVpcEndpointsForDomainResponse> listVpcEndpointsForDomain({
  required String domainName,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/vpcEndpoints',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListVpcEndpointsForDomainResponse.fromJson(response);
}