putDefaultApplicationSetting method

Future<PutDefaultApplicationSettingResponse> putDefaultApplicationSetting({
  1. required String applicationArn,
  2. required bool setAsDefault,
})

Sets the default application to the application with the specified ARN.

To remove the default application, use the GetDefaultApplicationSetting operation to get the current default and then call the PutDefaultApplicationSetting with the current applications ARN and the setAsDefault parameter set to false.

May throw AccessDeniedException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter setAsDefault : Set to true to set the specified ARN as the default application. Set to false to clear the default application.

Implementation

Future<PutDefaultApplicationSettingResponse> putDefaultApplicationSetting({
  required String applicationArn,
  required bool setAsDefault,
}) async {
  final $payload = <String, dynamic>{
    'applicationArn': applicationArn,
    'setAsDefault': setAsDefault,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/2021-01-01/opensearch/defaultApplicationSetting',
    exceptionFnMap: _exceptionFns,
  );
  return PutDefaultApplicationSettingResponse.fromJson(response);
}