rejectInboundConnection method

Future<RejectInboundConnectionResponse> rejectInboundConnection({
  1. required String connectionId,
})

Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request.

May throw DisabledOperationException. May throw ResourceNotFoundException.

Parameter connectionId : The unique identifier of the inbound connection to reject.

Implementation

Future<RejectInboundConnectionResponse> rejectInboundConnection({
  required String connectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/2021-01-01/opensearch/cc/inboundConnection/${Uri.encodeComponent(connectionId)}/reject',
    exceptionFnMap: _exceptionFns,
  );
  return RejectInboundConnectionResponse.fromJson(response);
}