revokeVpcEndpointAccess method
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The name of the OpenSearch Service domain.
Parameter account :
The account ID to revoke access from.
Parameter service :
The service SP to revoke access from.
Parameter serviceOptions :
The options for the service, including the supported Regions for the
endpoint access.
Implementation
Future<void> revokeVpcEndpointAccess({
required String domainName,
String? account,
AWSServicePrincipal? service,
ServiceOptions? serviceOptions,
}) async {
final $payload = <String, dynamic>{
if (account != null) 'Account': account,
if (service != null) 'Service': service.value,
if (serviceOptions != null) 'ServiceOptions': serviceOptions,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/revokeVpcEndpointAccess',
exceptionFnMap: _exceptionFns,
);
}