rollbackServiceSoftwareUpdate method

Future<RollbackServiceSoftwareUpdateResponse> rollbackServiceSoftwareUpdate({
  1. required String domainName,
})

Rolls back a service software update for a domain to the previous version. For more information, see Service software updates in Amazon OpenSearch Service.

May throw BaseException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter domainName : The name of the domain to roll back the service software update on.

Implementation

Future<RollbackServiceSoftwareUpdateResponse> rollbackServiceSoftwareUpdate({
  required String domainName,
}) async {
  final $payload = <String, dynamic>{
    'DomainName': domainName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2021-01-01/opensearch/serviceSoftwareUpdate/rollback',
    exceptionFnMap: _exceptionFns,
  );
  return RollbackServiceSoftwareUpdateResponse.fromJson(response);
}