batchGetEffectiveLifecyclePolicy method

Future<BatchGetEffectiveLifecyclePolicyResponse> batchGetEffectiveLifecyclePolicy({
  1. required List<LifecyclePolicyResourceIdentifier> resourceIdentifiers,
})

Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes. For more information, see Viewing data lifecycle policies.

May throw InternalServerException. May throw ValidationException.

Parameter resourceIdentifiers : The unique identifiers of policy types and resource names.

Implementation

Future<BatchGetEffectiveLifecyclePolicyResponse>
    batchGetEffectiveLifecyclePolicy({
  required List<LifecyclePolicyResourceIdentifier> resourceIdentifiers,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'OpenSearchServerless.BatchGetEffectiveLifecyclePolicy'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'resourceIdentifiers': resourceIdentifiers,
    },
  );

  return BatchGetEffectiveLifecyclePolicyResponse.fromJson(jsonResponse.body);
}