describeCreateAccountStatus method

Future<DescribeCreateAccountStatusResponse> describeCreateAccountStatus({
  1. required String createAccountRequestId,
})

Retrieves the current status of an asynchronous request to create an account.

You can only call this operation from the management account or a member account that is a delegated administrator.

May throw AccessDeniedException. May throw AWSOrganizationsNotInUseException. May throw CreateAccountStatusNotFoundException. May throw InvalidInputException. May throw ServiceException. May throw TooManyRequestsException. May throw UnsupportedAPIEndpointException.

Parameter createAccountRequestId : Specifies the Id value that uniquely identifies the CreateAccount request. You can get the value from the CreateAccountStatus.Id response in an earlier CreateAccount request, or from the ListCreateAccountStatus operation.

The regex pattern for a create account request ID string requires "car-" followed by from 8 to 32 lowercase letters or digits.

Implementation

Future<DescribeCreateAccountStatusResponse> describeCreateAccountStatus({
  required String createAccountRequestId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSOrganizationsV20161128.DescribeCreateAccountStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CreateAccountRequestId': createAccountRequestId,
    },
  );

  return DescribeCreateAccountStatusResponse.fromJson(jsonResponse.body);
}