describeHandshake method

Future<DescribeHandshakeResponse> describeHandshake({
  1. required String handshakeId,
})

Returns details for a handshake. A handshake is the secure exchange of information between two Amazon Web Services accounts: a sender and a recipient.

You can view ACCEPTED, DECLINED, or CANCELED handshakes in API Responses for 30 days before they are deleted.

You can call this operation from any account in a organization.

May throw AccessDeniedException. May throw ConcurrentModificationException. May throw HandshakeNotFoundException. May throw InvalidInputException. May throw ServiceException. May throw TooManyRequestsException.

Parameter handshakeId : ID for the handshake that you want information about.

The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

Implementation

Future<DescribeHandshakeResponse> describeHandshake({
  required String handshakeId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSOrganizationsV20161128.DescribeHandshake'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'HandshakeId': handshakeId,
    },
  );

  return DescribeHandshakeResponse.fromJson(jsonResponse.body);
}