detachPolicy method
Detaches a policy from a target root, organizational unit (OU), or
account.
Every root, OU, and account must have at least one SCP attached. If you
want to replace the default FullAWSAccess policy with an SCP
that limits the permissions that can be delegated, you must attach the
replacement SCP before you can remove the default SCP. This is the
authorization strategy of an "allow
list". If you instead attach a second SCP and leave the
FullAWSAccess SCP still attached, and specify "Effect":
"Deny" in the second SCP to override the "Effect":
"Allow" in the FullAWSAccess policy (or any other
attached SCP), you're using the authorization strategy of a "deny
list".
You can only call this operation from the management account or a member account that is a delegated administrator.
May throw AccessDeniedException.
May throw AWSOrganizationsNotInUseException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw InvalidInputException.
May throw PolicyChangesInProgressException.
May throw PolicyNotAttachedException.
May throw PolicyNotFoundException.
May throw ServiceException.
May throw TargetNotFoundException.
May throw TooManyRequestsException.
May throw UnsupportedAPIEndpointException.
Parameter policyId :
ID for the policy you want to detach. You can get the ID from the
ListPolicies or ListPoliciesForTarget operations.
The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).
Parameter targetId :
ID for the root, OU, or account that you want to detach the policy from.
You can get the ID from the ListRoots,
ListOrganizationalUnitsForParent, or ListAccounts
operations.
The regex pattern for a target ID string requires one of the following:
- Root - A string that begins with "r-" followed by from 4 to 32 lowercase letters or digits.
- Account - A string that consists of exactly 12 digits.
- Organizational unit (OU) - A string that begins with "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
Implementation
Future<void> detachPolicy({
required String policyId,
required String targetId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrganizationsV20161128.DetachPolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PolicyId': policyId,
'TargetId': targetId,
},
);
}