leaveOrganization method
Removes a member account from its parent organization. This version of the operation is performed by the account that wants to leave. To remove a member account as a user in the management account, use RemoveAccountFromOrganization instead.
You can only call from operation from a member account.
When an account leaves an organization, Organizations logs a membership
event in CloudTrail. The event is an
AccountDepartedOrganization event with
departedMethod:Left and departedTime. This event
is available only in the management account's event history.
-
The management account in an organization with all features enabled can
set service control policies (SCPs) that can restrict what administrators
of member accounts can do. This includes preventing them from successfully
calling
LeaveOrganizationand leaving the organization. -
You can leave an organization as a member account only if the account is
configured with the information required to operate as a standalone
account. When you create an account in an organization using the
Organizations console, API, or CLI commands, the information required of
standalone accounts is not automatically collected. For each
account that you want to make standalone, you must perform the following
steps. If any of the steps are already completed for this account, that
step doesn't appear.
- Choose a support plan
- Provide and verify the required contact information
- Provide a current payment method
- The account that you want to leave must not be a delegated administrator account for any Amazon Web Services service enabled for your organization. If the account is a delegated administrator, you must first change the delegated administrator account to another account that is remaining in the organization.
- After the account leaves the organization, all tags that were attached to the account object in the organization are deleted. Amazon Web Services accounts outside of an organization do not support tags.
- A newly created account has a waiting period before it can be removed from its organization. You must wait until at least four days after the account was created. Invited accounts aren't subject to this waiting period.
-
If you are using an organization principal to call
LeaveOrganizationacross multiple accounts, you can only do this up to 5 accounts per second in a single organization.
May throw AccessDeniedException.
May throw AccountNotFoundException.
May throw AWSOrganizationsNotInUseException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw InvalidInputException.
May throw MasterCannotLeaveOrganizationException.
May throw ServiceException.
May throw TooManyRequestsException.
Implementation
Future<void> leaveOrganization() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrganizationsV20161128.LeaveOrganization'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}