listCreateAccountStatus method

Future<ListCreateAccountStatusResponse> listCreateAccountStatus({
  1. int? maxResults,
  2. String? nextToken,
  3. List<CreateAccountState>? states,
})

Lists the account creation requests that match the specified status that is currently being tracked for the organization. You can only call this operation from the management account or a member account that is a delegated administrator.

May throw AccessDeniedException. May throw AWSOrganizationsNotInUseException. May throw InvalidInputException. May throw ServiceException. May throw TooManyRequestsException. May throw UnsupportedAPIEndpointException.

Parameter maxResults : The maximum number of items to return in the response. If more results exist than the specified MaxResults value, a token is included in the response so that you can retrieve the remaining results.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from.

Parameter states : A list of one or more states that you want included in the response. If this parameter isn't present, all requests are included in the response.

Implementation

Future<ListCreateAccountStatusResponse> listCreateAccountStatus({
  int? maxResults,
  String? nextToken,
  List<CreateAccountState>? states,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    20,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSOrganizationsV20161128.ListCreateAccountStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (states != null) 'States': states.map((e) => e.value).toList(),
    },
  );

  return ListCreateAccountStatusResponse.fromJson(jsonResponse.body);
}