listInboundResponsibilityTransfers method
Lists transfers that allow you to manage the specified responsibilities for another organization. This operation returns both transfer invitations and transfers.
May throw AccessDeniedException.
May throw AWSOrganizationsNotInUseException.
May throw ConstraintViolationException.
May throw InvalidInputException.
May throw ResponsibilityTransferNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
May throw UnsupportedAPIEndpointException.
Parameter type :
The type of responsibility. Currently, only BILLING is
supported.
Parameter id :
ID for the transfer.
Parameter maxResults :
The maximum number of items to return in the response. If more results
exist than the specified MaxResults value, a token is
included in the response so that you can retrieve the remaining results.
Parameter nextToken :
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from.
Implementation
Future<ListInboundResponsibilityTransfersResponse>
listInboundResponsibilityTransfers({
required ResponsibilityTransferType type,
String? id,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSOrganizationsV20161128.ListInboundResponsibilityTransfers'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Type': type.value,
if (id != null) 'Id': id,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListInboundResponsibilityTransfersResponse.fromJson(
jsonResponse.body);
}