listOutboundResponsibilityTransfers method

Future<ListOutboundResponsibilityTransfersResponse> listOutboundResponsibilityTransfers({
  1. required ResponsibilityTransferType type,
  2. int? maxResults,
  3. String? nextToken,
})

Lists transfers that allow an account outside your organization to manage the specified responsibilities for your organization. This operation returns both transfer invitations and transfers.

May throw AccessDeniedException. May throw AWSOrganizationsNotInUseException. May throw ConstraintViolationException. May throw InvalidInputException. May throw ServiceException. May throw TooManyRequestsException. May throw UnsupportedAPIEndpointException.

Parameter type : The type of responsibility. Currently, only BILLING is supported.

Parameter maxResults : The maximum number of items to return in the response. If more results exist than the specified MaxResults value, a token is included in the response so that you can retrieve the remaining results.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from.

Implementation

Future<ListOutboundResponsibilityTransfersResponse>
    listOutboundResponsibilityTransfers({
  required ResponsibilityTransferType type,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    20,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSOrganizationsV20161128.ListOutboundResponsibilityTransfers'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Type': type.value,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListOutboundResponsibilityTransfersResponse.fromJson(
      jsonResponse.body);
}