listPoliciesForTarget method
Lists the policies that are directly attached to the specified target root, organizational unit (OU), or account. You must specify the policy type that you want included in the returned list. You can only call this operation from the management account or a member account that is a delegated administrator.
May throw AccessDeniedException.
May throw AWSOrganizationsNotInUseException.
May throw InvalidInputException.
May throw ServiceException.
May throw TargetNotFoundException.
May throw TooManyRequestsException.
May throw UnsupportedAPIEndpointException.
Parameter filter :
The type of policy that you want to include in the returned list. You must
specify one of the following values:
- SERVICE_CONTROL_POLICY
- RESOURCE_CONTROL_POLICY
- DECLARATIVE_POLICY_EC2
- BACKUP_POLICY
- TAG_POLICY
- CHATBOT_POLICY
- AISERVICES_OPT_OUT_POLICY
- SECURITYHUB_POLICY
- UPGRADE_ROLLOUT_POLICY
- INSPECTOR_POLICY
- BEDROCK_POLICY
- S3_POLICY
- NETWORK_SECURITY_DIRECTOR_POLICY
Parameter targetId :
ID for the root, organizational unit, or account whose policies you want
to list.
The regex pattern for a target ID string requires one of the following:
- Root - A string that begins with "r-" followed by from 4 to 32 lowercase letters or digits.
- Account - A string that consists of exactly 12 digits.
- Organizational unit (OU) - A string that begins with "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
Parameter maxResults :
The maximum number of items to return in the response. If more results
exist than the specified MaxResults value, a token is
included in the response so that you can retrieve the remaining results.
Parameter nextToken :
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from.
Implementation
Future<ListPoliciesForTargetResponse> listPoliciesForTarget({
required PolicyType filter,
required String targetId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrganizationsV20161128.ListPoliciesForTarget'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Filter': filter.value,
'TargetId': targetId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListPoliciesForTargetResponse.fromJson(jsonResponse.body);
}