Osis class

Use the Amazon OpenSearch Ingestion API to create and manage ingestion pipelines. OpenSearch Ingestion is a fully managed data collector that delivers real-time log and trace data to OpenSearch Service domains. For more information, see Getting data into your cluster using OpenSearch Ingestion.

Constructors

Osis({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createPipeline({required int maxUnits, required int minUnits, required String pipelineConfigurationBody, required String pipelineName, BufferOptions? bufferOptions, EncryptionAtRestOptions? encryptionAtRestOptions, LogPublishingOptions? logPublishingOptions, String? pipelineRoleArn, List<Tag>? tags, VpcOptions? vpcOptions}) Future<CreatePipelineResponse>
Creates an OpenSearch Ingestion pipeline. For more information, see Creating Amazon OpenSearch Ingestion pipelines.
createPipelineEndpoint({required String pipelineArn, required PipelineEndpointVpcOptions vpcOptions}) Future<CreatePipelineEndpointResponse>
Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.
deletePipeline({required String pipelineName}) Future<void>
Deletes an OpenSearch Ingestion pipeline. For more information, see Deleting Amazon OpenSearch Ingestion pipelines.
deletePipelineEndpoint({required String endpointId}) Future<void>
Deletes a VPC endpoint for an OpenSearch Ingestion pipeline.
deleteResourcePolicy({required String resourceArn}) Future<void>
Deletes a resource-based policy from an OpenSearch Ingestion resource.
getPipeline({required String pipelineName}) Future<GetPipelineResponse>
Retrieves information about an OpenSearch Ingestion pipeline.
getPipelineBlueprint({required String blueprintName, String? format}) Future<GetPipelineBlueprintResponse>
Retrieves information about a specific blueprint for OpenSearch Ingestion. Blueprints are templates for the configuration needed for a CreatePipeline request. For more information, see Using blueprints to create a pipeline.
getPipelineChangeProgress({required String pipelineName}) Future<GetPipelineChangeProgressResponse>
Returns progress information for the current change happening on an OpenSearch Ingestion pipeline. Currently, this operation only returns information when a pipeline is being created.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyResponse>
Retrieves the resource-based policy attached to an OpenSearch Ingestion resource.
listPipelineBlueprints() Future<ListPipelineBlueprintsResponse>
Retrieves a list of all available blueprints for Data Prepper. For more information, see Using blueprints to create a pipeline.
listPipelineEndpointConnections({int? maxResults, String? nextToken}) Future<ListPipelineEndpointConnectionsResponse>
Lists the pipeline endpoints connected to pipelines in your account.
listPipelineEndpoints({int? maxResults, String? nextToken}) Future<ListPipelineEndpointsResponse>
Lists all pipeline endpoints in your account.
listPipelines({int? maxResults, String? nextToken}) Future<ListPipelinesResponse>
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region. For more information, see Viewing Amazon OpenSearch Ingestion pipelines.
listTagsForResource({required String arn}) Future<ListTagsForResourceResponse>
Lists all resource tags associated with an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String policy, required String resourceArn}) Future<PutResourcePolicyResponse>
Attaches a resource-based policy to an OpenSearch Ingestion resource. Resource-based policies grant permissions to principals to perform actions on the resource.
revokePipelineEndpointConnections({required List<String> endpointIds, required String pipelineArn}) Future<RevokePipelineEndpointConnectionsResponse>
Revokes pipeline endpoints from specified endpoint IDs.
startPipeline({required String pipelineName}) Future<StartPipelineResponse>
Starts an OpenSearch Ingestion pipeline. For more information, see Starting an OpenSearch Ingestion pipeline.
stopPipeline({required String pipelineName}) Future<StopPipelineResponse>
Stops an OpenSearch Ingestion pipeline. For more information, see Stopping an OpenSearch Ingestion pipeline.
tagResource({required String arn, required List<Tag> tags}) Future<void>
Tags an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
toString() String
A string representation of this object.
inherited
untagResource({required String arn, required List<String> tagKeys}) Future<void>
Removes one or more tags from an OpenSearch Ingestion pipeline. For more information, see Tagging Amazon OpenSearch Ingestion pipelines.
updatePipeline({required String pipelineName, BufferOptions? bufferOptions, EncryptionAtRestOptions? encryptionAtRestOptions, LogPublishingOptions? logPublishingOptions, int? maxUnits, int? minUnits, String? pipelineConfigurationBody, String? pipelineRoleArn}) Future<UpdatePipelineResponse>
Updates an OpenSearch Ingestion pipeline. For more information, see Updating Amazon OpenSearch Ingestion pipelines.
validatePipeline({required String pipelineConfigurationBody}) Future<ValidatePipelineResponse>
Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation. For more information, see Creating Amazon OpenSearch Ingestion pipelines.

Operators

operator ==(Object other) bool
The equality operator.
inherited