createPipelineEndpoint method

Future<CreatePipelineEndpointResponse> createPipelineEndpoint({
  1. required String pipelineArn,
  2. required PipelineEndpointVpcOptions vpcOptions,
})

Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.

May throw AccessDeniedException. May throw DisabledOperationException. May throw InternalException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter pipelineArn : The Amazon Resource Name (ARN) of the pipeline to create the endpoint for.

Parameter vpcOptions : Container for the VPC configuration for the pipeline endpoint, including subnet IDs and security group IDs.

Implementation

Future<CreatePipelineEndpointResponse> createPipelineEndpoint({
  required String pipelineArn,
  required PipelineEndpointVpcOptions vpcOptions,
}) async {
  final $payload = <String, dynamic>{
    'PipelineArn': pipelineArn,
    'VpcOptions': vpcOptions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2022-01-01/osis/createPipelineEndpoint',
    exceptionFnMap: _exceptionFns,
  );
  return CreatePipelineEndpointResponse.fromJson(response);
}