getPipelineChangeProgress method

Future<GetPipelineChangeProgressResponse> getPipelineChangeProgress({
  1. required String pipelineName,
})

Returns progress information for the current change happening on an OpenSearch Ingestion pipeline. Currently, this operation only returns information when a pipeline is being created.

For more information, see Tracking the status of pipeline creation.

May throw AccessDeniedException. May throw DisabledOperationException. May throw InternalException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter pipelineName : The name of the pipeline.

Implementation

Future<GetPipelineChangeProgressResponse> getPipelineChangeProgress({
  required String pipelineName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/2022-01-01/osis/getPipelineChangeProgress/${Uri.encodeComponent(pipelineName)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetPipelineChangeProgressResponse.fromJson(response);
}