listPipelineEndpoints method

Future<ListPipelineEndpointsResponse> listPipelineEndpoints({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all pipeline endpoints in your account.

May throw AccessDeniedException. May throw DisabledOperationException. May throw InternalException. May throw LimitExceededException. May throw ValidationException.

Parameter maxResults : The maximum number of pipeline endpoints to return in the response.

Parameter nextToken : If your initial ListPipelineEndpoints operation returns a NextToken, you can include the returned NextToken in subsequent ListPipelineEndpoints operations, which returns results in the next page.

Implementation

Future<ListPipelineEndpointsResponse> listPipelineEndpoints({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/2022-01-01/osis/listPipelineEndpoints',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListPipelineEndpointsResponse.fromJson(response);
}