listPipelines method
Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region. For more information, see Viewing Amazon OpenSearch Ingestion pipelines.
May throw AccessDeniedException.
May throw DisabledOperationException.
May throw InternalException.
May throw InvalidPaginationTokenException.
May throw ValidationException.
Parameter maxResults :
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to get the next page of
results.
Parameter nextToken :
If your initial ListPipelines operation returns a
nextToken, you can include the returned
nextToken in subsequent ListPipelines
operations, which returns results in the next page.
Implementation
Future<ListPipelinesResponse> listPipelines({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2022-01-01/osis/listPipelines',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListPipelinesResponse.fromJson(response);
}