validatePipeline method

Future<ValidatePipelineResponse> validatePipeline({
  1. required String pipelineConfigurationBody,
})

Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation. For more information, see Creating Amazon OpenSearch Ingestion pipelines.

May throw AccessDeniedException. May throw DisabledOperationException. May throw InternalException. May throw ValidationException.

Parameter pipelineConfigurationBody : The pipeline configuration in YAML format. The command accepts the pipeline configuration as a string or within a .yaml file. If you provide the configuration as a string, each new line must be escaped with \n.

Implementation

Future<ValidatePipelineResponse> validatePipeline({
  required String pipelineConfigurationBody,
}) async {
  final $payload = <String, dynamic>{
    'PipelineConfigurationBody': pipelineConfigurationBody,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/2022-01-01/osis/validatePipeline',
    exceptionFnMap: _exceptionFns,
  );
  return ValidatePipelineResponse.fromJson(response);
}