Outposts class

Amazon Web Services Outposts is a fully managed service that extends Amazon Web Services infrastructure, APIs, and tools to customer premises. By providing local access to Amazon Web Services managed infrastructure, Amazon Web Services Outposts enables customers to build and run applications on premises using the same programming interfaces as in Amazon Web Services Regions, while using local compute and storage resources for lower latency and local data processing needs.

Constructors

Outposts({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelCapacityTask({required String capacityTaskId, required String outpostIdentifier}) Future<void>
Cancels the capacity task.
cancelOrder({required String orderId}) Future<void>
Cancels the specified order for an Outpost.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createOrder({required String outpostIdentifier, required PaymentOption paymentOption, List<LineItemRequest>? lineItems, PaymentTerm? paymentTerm}) Future<CreateOrderOutput>
Creates an order for an Outpost.
createOutpost({required String name, required String siteId, String? availabilityZone, String? availabilityZoneId, String? description, SupportedHardwareType? supportedHardwareType, Map<String, String>? tags}) Future<CreateOutpostOutput>
Creates an Outpost.
createRenewal({required String outpostIdentifier, required PaymentOption paymentOption, required PaymentTerm paymentTerm, String? clientToken}) Future<CreateRenewalOutput>
Creates a renewal contract for the specified Outpost.
createSite({required String name, String? description, String? notes, Address? operatingAddress, RackPhysicalProperties? rackPhysicalProperties, Address? shippingAddress, Map<String, String>? tags}) Future<CreateSiteOutput>
Creates a site for an Outpost.
deleteOutpost({required String outpostId}) Future<void>
Deletes the specified Outpost.
deleteSite({required String siteId}) Future<void>
Deletes the specified site.
getCapacityTask({required String capacityTaskId, required String outpostIdentifier}) Future<GetCapacityTaskOutput>
Gets details of the specified capacity task.
getCatalogItem({required String catalogItemId}) Future<GetCatalogItemOutput>
Gets information about the specified catalog item.
getConnection({required String connectionId}) Future<GetConnectionResponse>
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see Amazon Web Services managed policies for Amazon Web Services Outposts and Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail in the Amazon Web Services Outposts User Guide.
getOrder({required String orderId}) Future<GetOrderOutput>
Gets information about the specified order.
getOutpost({required String outpostId}) Future<GetOutpostOutput>
Gets information about the specified Outpost.
getOutpostBillingInformation({required String outpostIdentifier, int? maxResults, String? nextToken}) Future<GetOutpostBillingInformationOutput>
Gets current and historical billing information about the specified Outpost.
getOutpostInstanceTypes({required String outpostId, int? maxResults, String? nextToken}) Future<GetOutpostInstanceTypesOutput>
Gets the instance types for the specified Outpost.
getOutpostSupportedInstanceTypes({required String outpostIdentifier, String? assetId, int? maxResults, String? nextToken, String? orderId}) Future<GetOutpostSupportedInstanceTypesOutput>
Gets the instance types that an Outpost can support in InstanceTypeCapacity. This will generally include instance types that are not currently configured and therefore cannot be launched with the current Outpost capacity configuration.
getRenewalPricing({required String outpostIdentifier}) Future<GetRenewalPricingOutput>
Gets all available renewal pricing options for the specified Outpost.
getSite({required String siteId}) Future<GetSiteOutput>
Gets information about the specified Outpost site.
getSiteAddress({required AddressType addressType, required String siteId}) Future<GetSiteAddressOutput>
Gets the site address of the specified site.
listAssetInstances({required String outpostIdentifier, List<String>? accountIdFilter, List<String>? assetIdFilter, List<AWSServiceName>? awsServiceFilter, List<String>? instanceTypeFilter, int? maxResults, String? nextToken}) Future<ListAssetInstancesOutput>
A list of Amazon EC2 instances, belonging to all accounts, running on the specified Outpost. Does not include Amazon EBS or Amazon S3 instances.
listAssets({required String outpostIdentifier, List<AssetType>? assetTypeFilter, List<String>? hostIdFilter, int? maxResults, String? nextToken, List<AssetState>? statusFilter}) Future<ListAssetsOutput>
Lists the hardware assets for the specified Outpost.
listBlockingInstancesForCapacityTask({required String capacityTaskId, required String outpostIdentifier, int? maxResults, String? nextToken}) Future<ListBlockingInstancesForCapacityTaskOutput>
A list of Amazon EC2 instances running on the Outpost and belonging to the account that initiated the capacity task. Use this list to specify the instances you cannot stop to free up capacity to run the capacity task.
listCapacityTasks({List<CapacityTaskStatus>? capacityTaskStatusFilter, int? maxResults, String? nextToken, String? outpostIdentifierFilter}) Future<ListCapacityTasksOutput>
Lists the capacity tasks for your Amazon Web Services account.
listCatalogItems({List<String>? eC2FamilyFilter, List<CatalogItemClass>? itemClassFilter, int? maxResults, String? nextToken, List<SupportedStorageEnum>? supportedStorageFilter}) Future<ListCatalogItemsOutput>
Lists the items in the catalog.
listOrders({int? maxResults, String? nextToken, String? outpostIdentifierFilter}) Future<ListOrdersOutput>
Lists the Outpost orders for your Amazon Web Services account.
listOutposts({List<String>? availabilityZoneFilter, List<String>? availabilityZoneIdFilter, List<String>? lifeCycleStatusFilter, int? maxResults, String? nextToken}) Future<ListOutpostsOutput>
Lists the Outposts for your Amazon Web Services account.
listSites({int? maxResults, String? nextToken, List<String>? operatingAddressCityFilter, List<String>? operatingAddressCountryCodeFilter, List<String>? operatingAddressStateOrRegionFilter}) Future<ListSitesOutput>
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for the specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCapacityTask({required List<InstanceTypeCapacity> instancePools, required String outpostIdentifier, String? assetId, bool? dryRun, InstancesToExclude? instancesToExclude, String? orderId, TaskActionOnBlockingInstances? taskActionOnBlockingInstances}) Future<StartCapacityTaskOutput>
Starts the specified capacity task. You can have one active capacity task for each order and each Outpost.
startConnection({required String assetId, required String clientPublicKey, required int networkInterfaceDeviceIndex, String? deviceSerialNumber}) Future<StartConnectionResponse>
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see Amazon Web Services managed policies for Amazon Web Services Outposts and Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail in the Amazon Web Services Outposts User Guide.
startOutpostDecommission({required String outpostIdentifier, bool? validateOnly}) Future<StartOutpostDecommissionOutput>
Starts the decommission process to return the Outposts racks or servers.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from the specified resource.
updateOutpost({required String outpostId, String? description, String? name, SupportedHardwareType? supportedHardwareType}) Future<UpdateOutpostOutput>
Updates an Outpost.
updateSite({required String siteId, String? description, String? name, String? notes}) Future<UpdateSiteOutput>
Updates the specified site.
updateSiteAddress({required Address address, required AddressType addressType, required String siteId}) Future<UpdateSiteAddressOutput>
Updates the address of the specified site.
updateSiteRackPhysicalProperties({required String siteId, FiberOpticCableType? fiberOpticCableType, MaximumSupportedWeightLbs? maximumSupportedWeightLbs, OpticalStandard? opticalStandard, PowerConnector? powerConnector, PowerDrawKva? powerDrawKva, PowerFeedDrop? powerFeedDrop, PowerPhase? powerPhase, UplinkCount? uplinkCount, UplinkGbps? uplinkGbps}) Future<UpdateSiteRackPhysicalPropertiesOutput>
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see Network readiness checklist in the Amazon Web Services Outposts User Guide.

Operators

operator ==(Object other) bool
The equality operator.
inherited