getConnection method

Future<GetConnectionResponse> getConnection({
  1. required String connectionId,
})
Gets information about the specified connection.

Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see Amazon Web Services managed policies for Amazon Web Services Outposts and Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail in the Amazon Web Services Outposts User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw NotFoundException. May throw ValidationException.

Parameter connectionId : The ID of the connection.

Implementation

Future<GetConnectionResponse> getConnection({
  required String connectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/connections/${Uri.encodeComponent(connectionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetConnectionResponse.fromJson(response);
}