listSites method
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ValidationException.
Parameter operatingAddressCityFilter :
Filters the results by city.
Parameter operatingAddressCountryCodeFilter :
Filters the results by country code.
Parameter operatingAddressStateOrRegionFilter :
Filters the results by state or region.
Implementation
Future<ListSitesOutput> listSites({
int? maxResults,
String? nextToken,
List<String>? operatingAddressCityFilter,
List<String>? operatingAddressCountryCodeFilter,
List<String>? operatingAddressStateOrRegionFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
if (operatingAddressCityFilter != null)
'OperatingAddressCityFilter': operatingAddressCityFilter,
if (operatingAddressCountryCodeFilter != null)
'OperatingAddressCountryCodeFilter': operatingAddressCountryCodeFilter,
if (operatingAddressStateOrRegionFilter != null)
'OperatingAddressStateOrRegionFilter':
operatingAddressStateOrRegionFilter,
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/sites',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSitesOutput.fromJson(response);
}