startOutpostDecommission method
Starts the decommission process to return the Outposts racks or servers.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw NotFoundException.
May throw ValidationException.
Parameter outpostIdentifier :
The ID or ARN of the Outpost that you want to decommission.
Parameter validateOnly :
Validates the request without starting the decommission process.
Implementation
Future<StartOutpostDecommissionOutput> startOutpostDecommission({
required String outpostIdentifier,
bool? validateOnly,
}) async {
final $payload = <String, dynamic>{
if (validateOnly != null) 'ValidateOnly': validateOnly,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/outposts/${Uri.encodeComponent(outpostIdentifier)}/decommission',
exceptionFnMap: _exceptionFns,
);
return StartOutpostDecommissionOutput.fromJson(response);
}