updateSiteAddress method

Future<UpdateSiteAddressOutput> updateSiteAddress({
  1. required Address address,
  2. required AddressType addressType,
  3. required String siteId,
})

Updates the address of the specified site.

You can't update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.

You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw NotFoundException. May throw ValidationException.

Parameter address : The address for the site.

Parameter addressType : The type of the address.

Parameter siteId : The ID or the Amazon Resource Name (ARN) of the site.

Implementation

Future<UpdateSiteAddressOutput> updateSiteAddress({
  required Address address,
  required AddressType addressType,
  required String siteId,
}) async {
  final $payload = <String, dynamic>{
    'Address': address,
    'AddressType': addressType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/sites/${Uri.encodeComponent(siteId)}/address',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSiteAddressOutput.fromJson(response);
}