acceptConnectionInvitation method

Future<AcceptConnectionInvitationResponse> acceptConnectionInvitation({
  1. required String catalog,
  2. required String identifier,
  3. String? clientToken,
})

Accepts a connection invitation from another partner, establishing a formal partnership connection between the two parties.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : The catalog identifier where the connection invitation exists.

Parameter identifier : The unique identifier of the connection invitation to accept.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementation

Future<AcceptConnectionInvitationResponse> acceptConnectionInvitation({
  required String catalog,
  required String identifier,
  String? clientToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'PartnerCentralAccount.AcceptConnectionInvitation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Catalog': catalog,
      'Identifier': identifier,
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    },
  );

  return AcceptConnectionInvitationResponse.fromJson(jsonResponse.body);
}