associateAwsTrainingCertificationEmailDomain method

Future<void> associateAwsTrainingCertificationEmailDomain({
  1. required String catalog,
  2. required String email,
  3. required String emailVerificationCode,
  4. required String identifier,
  5. String? clientToken,
})

Associates an email domain with AWS training and certification for the partner account, enabling automatic verification of employee certifications.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : The catalog identifier for the partner account.

Parameter email : The email address used to verify domain ownership for AWS training and certification association.

Parameter emailVerificationCode : The verification code sent to the email address to confirm domain ownership.

Parameter identifier : The unique identifier of the partner account.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementation

Future<void> associateAwsTrainingCertificationEmailDomain({
  required String catalog,
  required String email,
  required String emailVerificationCode,
  required String identifier,
  String? clientToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'PartnerCentralAccount.AssociateAwsTrainingCertificationEmailDomain'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Catalog': catalog,
      'Email': email,
      'EmailVerificationCode': emailVerificationCode,
      'Identifier': identifier,
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    },
  );
}