disassociateAwsTrainingCertificationEmailDomain method

Future<void> disassociateAwsTrainingCertificationEmailDomain({
  1. required String catalog,
  2. required String domainName,
  3. required String identifier,
  4. String? clientToken,
})

Removes the association between an email domain and AWS training and certification for the partner account.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : The catalog identifier for the partner account.

Parameter domainName : The domain name to disassociate from AWS training and certification.

Parameter identifier : The unique identifier of the partner account.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementation

Future<void> disassociateAwsTrainingCertificationEmailDomain({
  required String catalog,
  required String domainName,
  required String identifier,
  String? clientToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'PartnerCentralAccount.DisassociateAwsTrainingCertificationEmailDomain'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Catalog': catalog,
      'DomainName': domainName,
      'Identifier': identifier,
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    },
  );
}