getVerification method

Future<GetVerificationResponse> getVerification({
  1. required VerificationType verificationType,
})

Retrieves the current status and details of a verification process for a partner account. This operation allows partners to check the progress and results of business or registrant verification processes.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter verificationType : The type of verification to retrieve information for. Valid values include business verification for company registration details and registrant verification for individual identity confirmation.

Implementation

Future<GetVerificationResponse> getVerification({
  required VerificationType verificationType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'PartnerCentralAccount.GetVerification'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'VerificationType': verificationType.value,
    },
  );

  return GetVerificationResponse.fromJson(jsonResponse.body);
}