startVerification method

Future<StartVerificationResponse> startVerification({
  1. String? clientToken,
  2. VerificationDetails? verificationDetails,
})

Initiates a new verification process for a partner account. This operation begins the verification workflow for either business registration or individual registrant identity verification as required by AWS Partner Central.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This prevents duplicate verification processes from being started accidentally.

Parameter verificationDetails : The specific details required for the verification process, including business information for business verification or personal information for registrant verification.

Implementation

Future<StartVerificationResponse> startVerification({
  String? clientToken,
  VerificationDetails? verificationDetails,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'PartnerCentralAccount.StartVerification'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
      if (verificationDetails != null)
        'VerificationDetails': verificationDetails,
    },
  );

  return StartVerificationResponse.fromJson(jsonResponse.body);
}