submitBenefitApplication method
Submits a benefit application for review and processing by AWS.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
The catalog identifier that specifies which benefit catalog the
application belongs to.
Parameter identifier :
The unique identifier of the benefit application to submit.
Implementation
Future<void> submitBenefitApplication({
required String catalog,
required String identifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PartnerCentralBenefitsService.SubmitBenefitApplication'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
'Identifier': identifier,
},
);
}