PartnerCentralChannel class

AWS Partner Central Channel service for managing partner relationships, handshakes, and program management accounts.

Constructors

PartnerCentralChannel({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptChannelHandshake({required String catalog, required String identifier}) Future<AcceptChannelHandshakeResponse>
Accepts a pending channel handshake request from another AWS account.
cancelChannelHandshake({required String catalog, required String identifier}) Future<CancelChannelHandshakeResponse>
Cancels a pending channel handshake request.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createChannelHandshake({required String associatedResourceIdentifier, required String catalog, required HandshakeType handshakeType, String? clientToken, ChannelHandshakePayload? payload, List<Tag>? tags}) Future<CreateChannelHandshakeResponse>
Creates a new channel handshake request to establish a partnership with another AWS account.
createProgramManagementAccount({required String accountId, required String catalog, required String displayName, required Program program, String? clientToken, List<Tag>? tags}) Future<CreateProgramManagementAccountResponse>
Creates a new program management account for managing partner relationships.
createRelationship({required String associatedAccountId, required AssociationType associationType, required String catalog, required String displayName, required String programManagementAccountIdentifier, required Sector sector, String? clientToken, SupportPlan? requestedSupportPlan, ResaleAccountModel? resaleAccountModel, List<Tag>? tags}) Future<CreateRelationshipResponse>
Creates a new partner relationship between accounts.
deleteProgramManagementAccount({required String catalog, required String identifier, String? clientToken}) Future<void>
Deletes a program management account.
deleteRelationship({required String catalog, required String identifier, required String programManagementAccountIdentifier, String? clientToken}) Future<void>
Deletes a partner relationship.
getRelationship({required String catalog, required String identifier, required String programManagementAccountIdentifier}) Future<GetRelationshipResponse>
Retrieves details of a specific partner relationship.
listChannelHandshakes({required String catalog, required HandshakeType handshakeType, required ParticipantType participantType, List<String>? associatedResourceIdentifiers, ListChannelHandshakesTypeFilters? handshakeTypeFilters, ListChannelHandshakesTypeSort? handshakeTypeSort, int? maxResults, String? nextToken, List<HandshakeStatus>? statuses}) Future<ListChannelHandshakesResponse>
Lists channel handshakes based on specified criteria.
listProgramManagementAccounts({required String catalog, List<String>? accountIds, List<String>? displayNames, int? maxResults, String? nextToken, List<Program>? programs, ListProgramManagementAccountsSortBase? sort, List<ProgramManagementAccountStatus>? statuses}) Future<ListProgramManagementAccountsResponse>
Lists program management accounts based on specified criteria.
listRelationships({required String catalog, List<String>? associatedAccountIds, List<AssociationType>? associationTypes, List<String>? displayNames, int? maxResults, String? nextToken, List<String>? programManagementAccountIdentifiers, ListRelationshipsSortBase? sort}) Future<ListRelationshipsResponse>
Lists partner relationships based on specified criteria.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists tags associated with a specific resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectChannelHandshake({required String catalog, required String identifier}) Future<RejectChannelHandshakeResponse>
Rejects a pending channel handshake request.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Adds or updates tags for a specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a specified resource.
updateProgramManagementAccount({required String catalog, required String identifier, String? displayName, String? revision}) Future<UpdateProgramManagementAccountResponse>
Updates the properties of a program management account.
updateRelationship({required String catalog, required String identifier, required String programManagementAccountIdentifier, String? displayName, SupportPlan? requestedSupportPlan, String? revision}) Future<UpdateRelationshipResponse>
Updates the properties of a partner relationship.

Operators

operator ==(Object other) bool
The equality operator.
inherited