acceptChannelHandshake method

Future<AcceptChannelHandshakeResponse> acceptChannelHandshake({
  1. required String catalog,
  2. required String identifier,
})

Accepts a pending channel handshake request from another AWS account.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : The catalog identifier for the handshake request.

Parameter identifier : The unique identifier of the channel handshake to accept.

Implementation

Future<AcceptChannelHandshakeResponse> acceptChannelHandshake({
  required String catalog,
  required String identifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'PartnerCentralChannel.AcceptChannelHandshake'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'catalog': catalog,
      'identifier': identifier,
    },
  );

  return AcceptChannelHandshakeResponse.fromJson(jsonResponse.body);
}