updateProgramManagementAccount method
Updates the properties of a program management account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
The catalog identifier for the program management account.
Parameter identifier :
The unique identifier of the program management account to update.
Parameter displayName :
The new display name for the program management account.
Parameter revision :
The current revision number of the program management account.
Implementation
Future<UpdateProgramManagementAccountResponse>
updateProgramManagementAccount({
required String catalog,
required String identifier,
String? displayName,
String? revision,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PartnerCentralChannel.UpdateProgramManagementAccount'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'catalog': catalog,
'identifier': identifier,
if (displayName != null) 'displayName': displayName,
if (revision != null) 'revision': revision,
},
);
return UpdateProgramManagementAccountResponse.fromJson(jsonResponse.body);
}