PartnerCentralSelling class
AWS Partner Central API for Selling Reference Guide
Constructors
- PartnerCentralSelling({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptEngagementInvitation(
{required String catalog, required String identifier}) → Future< void> -
Use the
AcceptEngagementInvitationaction to accept an engagement invitation shared by AWS. Accepting the invitation indicates your willingness to participate in the engagement, granting you access to all engagement-related data. -
assignOpportunity(
{required AssigneeContact assignee, required String catalog, required String identifier}) → Future< void> -
Enables you to reassign an existing
Opportunityto another user within your Partner Central account. The specified user receives the opportunity, and it appears on their Partner Central dashboard, allowing them to take necessary actions or proceed with the opportunity. -
associateOpportunity(
{required String catalog, required String opportunityIdentifier, }) → Future< void> -
Enables you to create a formal association between an
Opportunityand various related entities, enriching the context and details of the opportunity for better collaboration and decision making. You can associate an opportunity with the following entity types: -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createEngagement(
{required String catalog, required String description, required String title, String? clientToken, List< EngagementContextDetails> ? contexts}) → Future<CreateEngagementResponse> -
The
CreateEngagementaction allows you to create anEngagement, which serves as a collaborative space between different parties such as AWS Partners and AWS Sellers. This action automatically adds the caller's AWS account as an active member of the newly createdEngagement. -
createEngagementContext(
{required String catalog, required String engagementIdentifier, required EngagementContextPayload payload, required EngagementContextType type, String? clientToken}) → Future< CreateEngagementContextResponse> - Creates a new context within an existing engagement. This action allows you to add contextual information such as customer projects or documents to an engagement, providing additional details that help facilitate collaboration between engagement members.
-
createEngagementInvitation(
{required String catalog, required String engagementIdentifier, required Invitation invitation, String? clientToken}) → Future< CreateEngagementInvitationResponse> - This action creates an invitation from a sender to a single receiver to join an engagement.
-
createOpportunity(
{required String catalog, String? clientToken, Customer? customer, LifeCycle? lifeCycle, Marketing? marketing, NationalSecurity? nationalSecurity, List< Contact> ? opportunityTeam, OpportunityType? opportunityType, OpportunityOrigin? origin, String? partnerOpportunityIdentifier, List<PrimaryNeedFromAws> ? primaryNeedsFromAws, Project? project, SoftwareRevenue? softwareRevenue, List<Tag> ? tags}) → Future<CreateOpportunityResponse> -
Creates an
Opportunityrecord in Partner Central. Use this operation to create a potential business opportunity for submission to Amazon Web Services. Creating an opportunity setsLifecycle.ReviewStatustoPending Submission. -
createResourceSnapshot(
{required String catalog, required String engagementIdentifier, required String resourceIdentifier, required String resourceSnapshotTemplateIdentifier, required ResourceType resourceType, String? clientToken}) → Future< CreateResourceSnapshotResponse> - This action allows you to create an immutable snapshot of a specific resource, such as an opportunity, within the context of an engagement. The snapshot captures a subset of the resource's data based on the schema defined by the provided template.
-
createResourceSnapshotJob(
{required String catalog, required String engagementIdentifier, required String resourceIdentifier, required String resourceSnapshotTemplateIdentifier, required ResourceType resourceType, String? clientToken, List< Tag> ? tags}) → Future<CreateResourceSnapshotJobResponse> - Use this action to create a job to generate a snapshot of the specified resource within an engagement. It initiates an asynchronous process to create a resource snapshot. The job creates a new snapshot only if the resource state has changed, adhering to the same access control and immutability rules as direct snapshot creation.
-
deleteResourceSnapshotJob(
{required String catalog, required String resourceSnapshotJobIdentifier}) → Future< void> - Use this action to deletes a previously created resource snapshot job. The job must be in a stopped state before it can be deleted.
-
disassociateOpportunity(
{required String catalog, required String opportunityIdentifier, }) → Future< void> -
Allows you to remove an existing association between an
Opportunityand related entities, such as a Partner Solution, Amazon Web Services product, or an Amazon Web Services Marketplace offer. This operation is the counterpart toAssociateOpportunity, and it provides flexibility to manage associations as business needs change. -
getAwsOpportunitySummary(
{required String catalog, }) → Future< GetAwsOpportunitySummaryResponse> - Retrieves a summary of an AWS Opportunity. This summary includes high-level details about the opportunity sourced from AWS, such as lifecycle information, customer details, and involvement type. It is useful for tracking updates on the AWS opportunity corresponding to an opportunity in the partner's account.
-
getEngagement(
{required String catalog, required String identifier}) → Future< GetEngagementResponse> -
Use this action to retrieve the engagement record for a given
EngagementIdentifier. -
getEngagementInvitation(
{required String catalog, required String identifier}) → Future< GetEngagementInvitationResponse> -
Retrieves the details of an engagement invitation shared by AWS with a
partner. The information includes aspects such as customer, project
details, and lifecycle information. To connect an engagement invitation
with an opportunity, match the invitation’s
Payload.Project.Titlewith opportunityProject.Title. -
getOpportunity(
{required String catalog, required String identifier}) → Future< GetOpportunityResponse> -
Fetches the
Opportunityrecord from Partner Central by a givenIdentifier. -
getResourceSnapshot(
{required String catalog, required String engagementIdentifier, required String resourceIdentifier, required String resourceSnapshotTemplateIdentifier, required ResourceType resourceType, int? revision}) → Future< GetResourceSnapshotResponse> - Use this action to retrieve a specific snapshot record.
-
getResourceSnapshotJob(
{required String catalog, required String resourceSnapshotJobIdentifier}) → Future< GetResourceSnapshotJobResponse> - Use this action to retrieves information about a specific resource snapshot job.
-
getSellingSystemSettings(
{required String catalog}) → Future< GetSellingSystemSettingsResponse> - Retrieves the currently set system settings, which include the IAM Role used for resource snapshot jobs.
-
listEngagementByAcceptingInvitationTasks(
{required String catalog, List< String> ? engagementInvitationIdentifier, int? maxResults, String? nextToken, List<String> ? opportunityIdentifier, ListTasksSortBase? sort, List<String> ? taskIdentifier, List<TaskStatus> ? taskStatus}) → Future<ListEngagementByAcceptingInvitationTasksResponse> - Lists all in-progress, completed, or failed StartEngagementByAcceptingInvitationTask tasks that were initiated by the caller's account.
-
listEngagementFromOpportunityTasks(
{required String catalog, List< String> ? engagementIdentifier, int? maxResults, String? nextToken, List<String> ? opportunityIdentifier, ListTasksSortBase? sort, List<String> ? taskIdentifier, List<TaskStatus> ? taskStatus}) → Future<ListEngagementFromOpportunityTasksResponse> -
Lists all in-progress, completed, or failed
EngagementFromOpportunitytasks that were initiated by the caller's account. -
listEngagementInvitations(
{required String catalog, required ParticipantType participantType, List< String> ? engagementIdentifier, int? maxResults, String? nextToken, List<EngagementInvitationPayloadType> ? payloadType, List<String> ? senderAwsAccountId, OpportunityEngagementInvitationSort? sort, List<InvitationStatus> ? status}) → Future<ListEngagementInvitationsResponse> - Retrieves a list of engagement invitations sent to the partner. This allows partners to view all pending or past engagement invitations, helping them track opportunities shared by AWS.
-
listEngagementMembers(
{required String catalog, required String identifier, int? maxResults, String? nextToken}) → Future< ListEngagementMembersResponse> -
Retrieves the details of member partners in an Engagement. This operation
can only be invoked by members of the Engagement. The
ListEngagementMembersoperation allows you to fetch information about the members of a specific Engagement. This action is restricted to members of the Engagement being queried. -
listEngagementResourceAssociations(
{required String catalog, String? createdBy, String? engagementIdentifier, int? maxResults, String? nextToken, String? resourceIdentifier, ResourceType? resourceType}) → Future< ListEngagementResourceAssociationsResponse> - Lists the associations between resources and engagements where the caller is a member and has at least one snapshot in the engagement.
-
listEngagements(
{required String catalog, List< EngagementContextType> ? contextTypes, List<String> ? createdBy, List<String> ? engagementIdentifier, List<EngagementContextType> ? excludeContextTypes, List<String> ? excludeCreatedBy, int? maxResults, String? nextToken, EngagementSort? sort}) → Future<ListEngagementsResponse> - This action allows users to retrieve a list of Engagement records from Partner Central. This action can be used to manage and track various engagements across different stages of the partner selling process.
-
listOpportunities(
{required String catalog, CreatedDateFilter? createdDate, List< String> ? customerCompanyName, List<String> ? identifier, LastModifiedDate? lastModifiedDate, List<ReviewStatus> ? lifeCycleReviewStatus, List<Stage> ? lifeCycleStage, int? maxResults, String? nextToken, OpportunitySort? sort, TargetCloseDateFilter? targetCloseDate}) → Future<ListOpportunitiesResponse> -
This request accepts a list of filters that retrieve opportunity subsets
as well as sort options. This feature is available to partners from Partner Central using
the
ListOpportunitiesAPI action. -
listOpportunityFromEngagementTasks(
{required String catalog, List< String> ? contextIdentifier, List<String> ? engagementIdentifier, int? maxResults, String? nextToken, List<String> ? opportunityIdentifier, ListTasksSortBase? sort, List<String> ? taskIdentifier, List<TaskStatus> ? taskStatus}) → Future<ListOpportunityFromEngagementTasksResponse> - Lists all in-progress, completed, or failed opportunity creation tasks from engagements that were initiated by the caller's account.
-
listResourceSnapshotJobs(
{required String catalog, String? engagementIdentifier, int? maxResults, String? nextToken, SortObject? sort, ResourceSnapshotJobStatus? status}) → Future< ListResourceSnapshotJobsResponse> - Lists resource snapshot jobs owned by the customer. This operation supports various filtering scenarios, including listing all jobs owned by the caller, jobs for a specific engagement, jobs with a specific status, or any combination of these filters.
-
listResourceSnapshots(
{required String catalog, required String engagementIdentifier, String? createdBy, int? maxResults, String? nextToken, String? resourceIdentifier, String? resourceSnapshotTemplateIdentifier, ResourceType? resourceType}) → Future< ListResourceSnapshotsResponse> - Retrieves a list of resource view snapshots based on specified criteria. This operation supports various use cases, including:
-
listSolutions(
{required String catalog, List< String> ? category, List<String> ? identifier, int? maxResults, String? nextToken, SolutionSort? sort, List<SolutionStatus> ? status}) → Future<ListSolutionsResponse> - Retrieves a list of Partner Solutions that the partner registered on Partner Central. This API is used to generate a list of solutions that an end user selects from for association with an opportunity.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putSellingSystemSettings(
{required String catalog, String? resourceSnapshotJobRoleIdentifier}) → Future< PutSellingSystemSettingsResponse> - Updates the currently set system settings, which include the IAM Role used for resource snapshot jobs.
-
rejectEngagementInvitation(
{required String catalog, required String identifier, String? rejectionReason}) → Future< void> -
This action rejects an
EngagementInvitationthat AWS shared. Rejecting an invitation indicates that the partner doesn't want to pursue the opportunity, and all related data will become inaccessible thereafter. -
startEngagementByAcceptingInvitationTask(
{required String catalog, required String identifier, String? clientToken, List< Tag> ? tags}) → Future<StartEngagementByAcceptingInvitationTaskResponse> -
This action starts the engagement by accepting an
EngagementInvitation. The task is asynchronous and involves the following steps: accepting the invitation, creating an opportunity in the partner’s account from the AWS opportunity, and copying details for tracking. When completed, anOpportunity Createdevent is generated, indicating that the opportunity has been successfully created in the partner's account. -
startEngagementFromOpportunityTask(
{required AwsSubmission awsSubmission, required String catalog, required String identifier, String? clientToken, List< Tag> ? tags}) → Future<StartEngagementFromOpportunityTaskResponse> -
Similar to
StartEngagementByAcceptingInvitationTask, this action is asynchronous and performs multiple steps before completion. This action orchestrates a comprehensive workflow that combines multiple API operations into a single task to create and initiate an engagement from an existing opportunity. It automatically executes a sequence of operations includingGetOpportunity,CreateEngagement(if it doesn't exist),CreateResourceSnapshot,CreateResourceSnapshotJob,CreateEngagementInvitation(if not already invited/accepted), andSubmitOpportunity. -
startOpportunityFromEngagementTask(
{required String catalog, required String contextIdentifier, required String identifier, String? clientToken, List< Tag> ? tags}) → Future<StartOpportunityFromEngagementTaskResponse> - This action creates an opportunity from an existing engagement context. The task is asynchronous and orchestrates the process of converting engagement contextual information into a structured opportunity record within the partner's account.
-
startResourceSnapshotJob(
{required String catalog, required String resourceSnapshotJobIdentifier}) → Future< void> - Starts a resource snapshot job that has been previously created.
-
stopResourceSnapshotJob(
{required String catalog, required String resourceSnapshotJobIdentifier}) → Future< void> - Stops a resource snapshot job. The job must be started prior to being stopped.
-
submitOpportunity(
{required String catalog, required String identifier, required SalesInvolvementType involvementType, Visibility? visibility}) → Future< void> -
Use this action to submit an Opportunity that was previously created by
partner for AWS review. After you perform this action, the Opportunity
becomes non-editable until it is reviewed by AWS and has
LifeCycle.ReviewStatusas eitherApprovedorAction Required. -
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag or tags from a resource.
-
updateEngagementContext(
{required String catalog, required String contextIdentifier, required String engagementIdentifier, required DateTime engagementLastModifiedAt, required UpdateEngagementContextPayload payload, required EngagementContextType type}) → Future< UpdateEngagementContextResponse> - Updates the context information for an existing engagement with new or modified data.
-
updateOpportunity(
{required String catalog, required String identifier, required DateTime lastModifiedDate, Customer? customer, LifeCycle? lifeCycle, Marketing? marketing, NationalSecurity? nationalSecurity, OpportunityType? opportunityType, String? partnerOpportunityIdentifier, List< PrimaryNeedFromAws> ? primaryNeedsFromAws, Project? project, SoftwareRevenue? softwareRevenue}) → Future<UpdateOpportunityResponse> -
Updates the
Opportunityrecord identified by a givenIdentifier. This operation allows you to modify the details of an existing opportunity to reflect the latest information and progress. Use this action to keep the opportunity record up-to-date and accurate.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited