putSellingSystemSettings method

Future<PutSellingSystemSettingsResponse> putSellingSystemSettings({
  1. required String catalog,
  2. String? resourceSnapshotJobRoleIdentifier,
})

Updates the currently set system settings, which include the IAM Role used for resource snapshot jobs.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : Specifies the catalog in which the settings will be updated. Acceptable values include AWS for production and Sandbox for testing environments.

Parameter resourceSnapshotJobRoleIdentifier : Specifies the ARN of the IAM Role used for resource snapshot job executions.

Implementation

Future<PutSellingSystemSettingsResponse> putSellingSystemSettings({
  required String catalog,
  String? resourceSnapshotJobRoleIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSPartnerCentralSelling.PutSellingSystemSettings'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Catalog': catalog,
      if (resourceSnapshotJobRoleIdentifier != null)
        'ResourceSnapshotJobRoleIdentifier':
            resourceSnapshotJobRoleIdentifier,
    },
  );

  return PutSellingSystemSettingsResponse.fromJson(jsonResponse.body);
}