startResourceSnapshotJob method

Future<void> startResourceSnapshotJob({
  1. required String catalog,
  2. required String resourceSnapshotJobIdentifier,
})

Starts a resource snapshot job that has been previously created.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter catalog : Specifies the catalog related to the request. Valid values are:

  • AWS: Starts the request from the production AWS environment.
  • Sandbox: Starts the request from a sandbox environment used for testing or development purposes.

Parameter resourceSnapshotJobIdentifier : The identifier of the resource snapshot job to start.

Implementation

Future<void> startResourceSnapshotJob({
  required String catalog,
  required String resourceSnapshotJobIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSPartnerCentralSelling.StartResourceSnapshotJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Catalog': catalog,
      'ResourceSnapshotJobIdentifier': resourceSnapshotJobIdentifier,
    },
  );
}