createKey method
Creates an Amazon Web Services Payment Cryptography key, a logical representation of a cryptographic key, that is unique in your account and Amazon Web Services Region. You use keys for cryptographic functions such as encryption and decryption.
In addition to the key material used in cryptographic operations, an Amazon Web Services Payment Cryptography key includes metadata such as the key ARN, key usage, key origin, creation date, description, and key state.
When you create a key, you specify both immutable and mutable data about
the key. The immutable data contains key attributes that define the scope
and cryptographic operations that you can perform using the key, for
example key class (example: SYMMETRIC_KEY), key algorithm
(example: TDES_2KEY), key usage (example:
TR31_P0_PIN_ENCRYPTION_KEY) and key modes of use (example:
Encrypt). Amazon Web Services Payment Cryptography binds key
attributes to keys using key blocks when you store or export them. Amazon
Web Services Payment Cryptography stores the key contents wrapped and
never stores or transmits them in the clear.
For information about valid combinations of key attributes, see Understanding key attributes in the Amazon Web Services Payment Cryptography User Guide. The mutable data contained within a key includes usage timestamp and key deletion timestamp and can be modified after creation.
You can use the CreateKey operation to generate an ECC
(Elliptic Curve Cryptography) key pair used for establishing an ECDH
(Elliptic Curve Diffie-Hellman) key agreement between two parties. In the
ECDH key agreement process, both parties generate their own ECC key pair
with key usage K3 and exchange the public keys. Each party then use their
private key, the received public key from the other party, and the key
derivation parameters including key derivation function, hash algorithm,
derivation data, and key algorithm to derive a shared key.
To maintain the single-use principle of cryptographic keys in payments,
ECDH derived keys should not be used for multiple purposes, such as a
TR31_P0_PIN_ENCRYPTION_KEY and
TR31_K1_KEY_BLOCK_PROTECTION_KEY. When creating ECC key pairs
in Amazon Web Services Payment Cryptography you can optionally set the
DeriveKeyUsage parameter, which defines the key usage bound
to the symmetric key that will be derived using the ECC key pair.
Cross-account use: This operation can't be used across different Amazon Web Services accounts.
Related operations:
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter exportable :
Specifies whether the key is exportable from the service.
Parameter keyAttributes :
The role of the key, the algorithm it supports, and the cryptographic
operations allowed with the key. This data is immutable after the key is
created.
Parameter deriveKeyUsage :
The intended cryptographic usage of keys derived from the ECC key pair to
be created.
After creating an ECC key pair, you cannot change the intended cryptographic usage of keys derived from it using ECDH.
Parameter enabled :
Specifies whether to enable the key. If the key is enabled, it is
activated for use within the service. If the key is not enabled, then it
is created but not activated. The default value is enabled.
Parameter keyCheckValueAlgorithm :
The algorithm that Amazon Web Services Payment Cryptography uses to
calculate the key check value (KCV). It is used to validate the key
integrity.
For TDES keys, the KCV is computed by encrypting 8 bytes, each with value of zero, with the key to be checked and retaining the 3 highest order bytes of the encrypted result. For AES keys, the KCV is computed using a CMAC algorithm where the input data is 16 bytes of zero and retaining the 3 highest order bytes of the encrypted result. For HMAC keys, the KCV is computed using the hash selected at key creation on a zero-length message, taking the leftmost 3 bytes.
Parameter tags :
Assigns one or more tags to the Amazon Web Services Payment Cryptography
key. Use this parameter to tag a key when it is created. To tag an
existing Amazon Web Services Payment Cryptography key, use the TagResource
operation.
Each tag consists of a tag key and a tag value. Both the tag key and the tag value are required, but the tag value can be an empty (null) string. You can't have more than one tag on an Amazon Web Services Payment Cryptography key with the same tag key.
Implementation
Future<CreateKeyOutput> createKey({
required bool exportable,
required KeyAttributes keyAttributes,
DeriveKeyUsage? deriveKeyUsage,
bool? enabled,
KeyCheckValueAlgorithm? keyCheckValueAlgorithm,
List<String>? replicationRegions,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PaymentCryptographyControlPlane.CreateKey'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Exportable': exportable,
'KeyAttributes': keyAttributes,
if (deriveKeyUsage != null) 'DeriveKeyUsage': deriveKeyUsage.value,
if (enabled != null) 'Enabled': enabled,
if (keyCheckValueAlgorithm != null)
'KeyCheckValueAlgorithm': keyCheckValueAlgorithm.value,
if (replicationRegions != null)
'ReplicationRegions': replicationRegions,
if (tags != null) 'Tags': tags,
},
);
return CreateKeyOutput.fromJson(jsonResponse.body);
}