getDefaultKeyReplicationRegions method

Future<GetDefaultKeyReplicationRegionsOutput> getDefaultKeyReplicationRegions()

Retrieves the list of Amazon Web Services Regions where Multi-Region key replication is currently enabled for your Amazon Web Services account.

This operation returns the current Multi-Region key replication configuration. New keys created in your account will be automatically replicated to these regions unless explicitly overridden during key creation.

Cross-account use: This operation can't be used across different Amazon Web Services accounts.

Related operations:

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<GetDefaultKeyReplicationRegionsOutput>
    getDefaultKeyReplicationRegions() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'PaymentCryptographyControlPlane.GetDefaultKeyReplicationRegions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return GetDefaultKeyReplicationRegionsOutput.fromJson(jsonResponse.body);
}