PaymentCryptographyData class

You use the Amazon Web Services Payment Cryptography Data Plane to manage how encryption keys are used for payment-related transaction processing and associated cryptographic operations. You can encrypt, decrypt, generate, verify, and translate payment-related cryptographic operations in Amazon Web Services Payment Cryptography. For more information, see Data operations in the Amazon Web Services Payment Cryptography User Guide.

To manage your encryption keys, you use the Amazon Web Services Payment Cryptography Control Plane. You can create, import, export, share, manage, and delete keys. You can also manage Identity and Access Management (IAM) policies for keys.

Constructors

PaymentCryptographyData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
decryptData({required String cipherText, required EncryptionDecryptionAttributes decryptionAttributes, required String keyIdentifier, WrappedKey? wrappedKey}) Future<DecryptDataOutput>
Decrypts ciphertext data to plaintext using a symmetric (TDES, AES), asymmetric (RSA), or derived (DUKPT or EMV) encryption key scheme. For more information, see Decrypt data in the Amazon Web Services Payment Cryptography User Guide.
encryptData({required EncryptionDecryptionAttributes encryptionAttributes, required String keyIdentifier, required String plainText, WrappedKey? wrappedKey}) Future<EncryptDataOutput>
Encrypts plaintext data to ciphertext using a symmetric (TDES, AES), asymmetric (RSA), or derived (DUKPT or EMV) encryption key scheme. For more information, see Encrypt data in the Amazon Web Services Payment Cryptography User Guide.
generateAs2805KekValidation({required As2805KekValidationType kekValidationType, required String keyIdentifier, required RandomKeySendVariantMask randomKeySendVariantMask}) Future<GenerateAs2805KekValidationOutput>
Generates a KekValidationRequest or a KekValidationResponse for node-to-node initialization between payment processing nodes using Australian Standard 2805 (AS2805).
generateAuthRequestCryptogram({required String keyIdentifier, required MajorKeyDerivationMode majorKeyDerivationMode, required SessionKeyDerivation sessionKeyDerivationAttributes, required String transactionData}) Future<GenerateAuthRequestCryptogramOutput>
Generates an Authorization Request Cryptogram (ARQC) for an EMV chip payment card authorization. For more information, see Generate auth request cryptogram in the Amazon Web Services Payment Cryptography User Guide.
generateCardValidationData({required CardGenerationAttributes generationAttributes, required String keyIdentifier, required String primaryAccountNumber, int? validationDataLength}) Future<GenerateCardValidationDataOutput>
Generates card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2), or Card Security Codes (CSC). For more information, see Generate card data in the Amazon Web Services Payment Cryptography User Guide.
generateMac({required MacAttributes generationAttributes, required String keyIdentifier, required String messageData, int? macLength}) Future<GenerateMacOutput>
Generates a Message Authentication Code (MAC) cryptogram within Amazon Web Services Payment Cryptography.
generateMacEmvPinChange({required DerivationMethodAttributes derivationMethodAttributes, required String messageData, required String newEncryptedPinBlock, required String newPinPekIdentifier, required PinBlockFormatForEmvPinChange pinBlockFormat, required String secureMessagingConfidentialityKeyIdentifier, required String secureMessagingIntegrityKeyIdentifier}) Future<GenerateMacEmvPinChangeOutput>
Generates an issuer script mac for EMV payment cards that use offline PINs as the cardholder verification method (CVM).
generatePinData({required String encryptionKeyIdentifier, required PinGenerationAttributes generationAttributes, required String generationKeyIdentifier, required PinBlockFormatForPinData pinBlockFormat, WrappedKey? encryptionWrappedKey, int? pinDataLength, String? primaryAccountNumber}) Future<GeneratePinDataOutput>
Generates pin-related data such as PIN, PIN Verification Value (PVV), PIN Block, and PIN Offset during new card issuance or reissuance. For more information, see Generate PIN data in the Amazon Web Services Payment Cryptography User Guide.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reEncryptData({required String cipherText, required ReEncryptionAttributes incomingEncryptionAttributes, required String incomingKeyIdentifier, required ReEncryptionAttributes outgoingEncryptionAttributes, required String outgoingKeyIdentifier, WrappedKey? incomingWrappedKey, WrappedKey? outgoingWrappedKey}) Future<ReEncryptDataOutput>
Re-encrypt ciphertext using DUKPT or Symmetric data encryption keys.
toString() String
A string representation of this object.
inherited
translateKeyMaterial({required IncomingKeyMaterial incomingKeyMaterial, required OutgoingKeyMaterial outgoingKeyMaterial, KeyCheckValueAlgorithm? keyCheckValueAlgorithm}) Future<TranslateKeyMaterialOutput>
Translates an cryptographic key between different wrapping keys without importing the key into Amazon Web Services Payment Cryptography.
translatePinData({required String encryptedPinBlock, required String incomingKeyIdentifier, required TranslationIsoFormats incomingTranslationAttributes, required String outgoingKeyIdentifier, required TranslationIsoFormats outgoingTranslationAttributes, As2805PekDerivationAttributes? incomingAs2805Attributes, DukptDerivationAttributes? incomingDukptAttributes, WrappedKey? incomingWrappedKey, DukptDerivationAttributes? outgoingDukptAttributes, WrappedKey? outgoingWrappedKey}) Future<TranslatePinDataOutput>
Translates encrypted PIN block from and to ISO 9564 formats 0,1,3,4. For more information, see Translate PIN data in the Amazon Web Services Payment Cryptography User Guide.
verifyAuthRequestCryptogram({required String authRequestCryptogram, required String keyIdentifier, required MajorKeyDerivationMode majorKeyDerivationMode, required SessionKeyDerivation sessionKeyDerivationAttributes, required String transactionData, CryptogramAuthResponse? authResponseAttributes}) Future<VerifyAuthRequestCryptogramOutput>
Verifies Authorization Request Cryptogram (ARQC) for a EMV chip payment card authorization. For more information, see Verify auth request cryptogram in the Amazon Web Services Payment Cryptography User Guide.
verifyCardValidationData({required String keyIdentifier, required String primaryAccountNumber, required String validationData, required CardVerificationAttributes verificationAttributes}) Future<VerifyCardValidationDataOutput>
Verifies card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) and Card Security Codes (CSC). For more information, see Verify card data in the Amazon Web Services Payment Cryptography User Guide.
verifyMac({required String keyIdentifier, required String mac, required String messageData, required MacAttributes verificationAttributes, int? macLength}) Future<VerifyMacOutput>
Verifies a Message Authentication Code (MAC).
verifyPinData({required String encryptedPinBlock, required String encryptionKeyIdentifier, required PinBlockFormatForPinData pinBlockFormat, required PinVerificationAttributes verificationAttributes, required String verificationKeyIdentifier, DukptAttributes? dukptAttributes, WrappedKey? encryptionWrappedKey, int? pinDataLength, String? primaryAccountNumber}) Future<VerifyPinDataOutput>
Verifies pin-related data such as PIN and PIN Offset using algorithms including VISA PVV and IBM3624. For more information, see Verify PIN data in the Amazon Web Services Payment Cryptography User Guide.

Operators

operator ==(Object other) bool
The equality operator.
inherited