verifyCardValidationData method
Verifies card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) and Card Security Codes (CSC). For more information, see Verify card data in the Amazon Web Services Payment Cryptography User Guide.
This operation validates the CVV or CSC codes that is printed on a payment credit or debit card during card payment transaction. The input values are typically provided as part of an inbound transaction to an issuer or supporting platform partner. Amazon Web Services Payment Cryptography uses CVV or CSC, PAN (Primary Account Number) and expiration date of the card to check its validity during transaction processing. In this operation, the CVK (Card Verification Key) encryption key for use with card data verification is same as the one in used for GenerateCardValidationData.
For information about valid keys for this operation, see Understanding key attributes and Key types for specific data operations in the Amazon Web Services Payment Cryptography User Guide.
Cross-account use: This operation supports cross-account use when the key has a resource-based policy that grants access. For more information, see Resource-based policies.
Related operations:
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
May throw VerificationFailedException.
Parameter keyIdentifier :
The keyARN of the CVK encryption key that Amazon Web Services
Payment Cryptography uses to verify card data.
Parameter primaryAccountNumber :
The Primary Account Number (PAN), a unique identifier for a payment credit
or debit card that associates the card with a specific account holder.
Parameter validationData :
The CVV or CSC value for use for card data verification within Amazon Web
Services Payment Cryptography.
Parameter verificationAttributes :
The algorithm to use for verification of card data within Amazon Web
Services Payment Cryptography.
Implementation
Future<VerifyCardValidationDataOutput> verifyCardValidationData({
required String keyIdentifier,
required String primaryAccountNumber,
required String validationData,
required CardVerificationAttributes verificationAttributes,
}) async {
final $payload = <String, dynamic>{
'KeyIdentifier': keyIdentifier,
'PrimaryAccountNumber': primaryAccountNumber,
'ValidationData': validationData,
'VerificationAttributes': verificationAttributes,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/cardvalidationdata/verify',
exceptionFnMap: _exceptionFns,
);
return VerifyCardValidationDataOutput.fromJson(response);
}