createConnector method
Creates a connector between Amazon Web Services Private CA and an Active Directory. You must specify the private CA, directory ID, and security groups.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter certificateAuthorityArn :
The Amazon Resource Name (ARN) of the certificate authority being used.
Parameter directoryId :
The identifier of the Active Directory.
Parameter vpcInformation :
Information about your VPC and security groups used with the connector.
Parameter clientToken :
Idempotency token.
Parameter tags :
Metadata assigned to a connector consisting of a key-value pair.
Implementation
Future<CreateConnectorResponse> createConnector({
required String certificateAuthorityArn,
required String directoryId,
required VpcInformation vpcInformation,
String? clientToken,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'CertificateAuthorityArn': certificateAuthorityArn,
'DirectoryId': directoryId,
'VpcInformation': vpcInformation,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/connectors',
exceptionFnMap: _exceptionFns,
);
return CreateConnectorResponse.fromJson(response);
}