createTemplateGroupAccessControlEntry method

Future<void> createTemplateGroupAccessControlEntry({
  1. required AccessRights accessRights,
  2. required String groupDisplayName,
  3. required String groupSecurityIdentifier,
  4. required String templateArn,
  5. String? clientToken,
})

Create a group access control entry. Allow or deny Active Directory groups from enrolling and/or autoenrolling with the template based on the group security identifiers (SIDs).

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter accessRights : Allow or deny permissions for an Active Directory group to enroll or autoenroll certificates for a template.

Parameter groupDisplayName : Name of the Active Directory group. This name does not need to match the group name in Active Directory.

Parameter groupSecurityIdentifier : Security identifier (SID) of the group object from Active Directory. The SID starts with "S-".

Parameter templateArn : The Amazon Resource Name (ARN) that was returned when you called CreateTemplate.

Parameter clientToken : Idempotency token.

Implementation

Future<void> createTemplateGroupAccessControlEntry({
  required AccessRights accessRights,
  required String groupDisplayName,
  required String groupSecurityIdentifier,
  required String templateArn,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'AccessRights': accessRights,
    'GroupDisplayName': groupDisplayName,
    'GroupSecurityIdentifier': groupSecurityIdentifier,
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/templates/${Uri.encodeComponent(templateArn)}/accessControlEntries',
    exceptionFnMap: _exceptionFns,
  );
}