listTemplates method
Lists the templates, if any, that are associated with a connector.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter connectorArn :
The Amazon Resource Name (ARN) that was returned when you called CreateConnector.
Parameter maxResults :
Use this parameter when paginating results to specify the maximum number
of items to return in the response on each page. If additional items exist
beyond the number you specify, the NextToken element is sent
in the response. Use this NextToken value in a subsequent
request to retrieve additional items.
Parameter nextToken :
Use this parameter when paginating results in a subsequent request after
you receive a response with truncated results. Set it to the value of the
NextToken parameter from the response you just received.
Implementation
Future<ListTemplatesResponse> listTemplates({
required String connectorArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
'ConnectorArn': [connectorArn],
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/templates',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListTemplatesResponse.fromJson(response);
}