deleteComputeNodeGroup method

Future<void> deleteComputeNodeGroup({
  1. required String clusterIdentifier,
  2. required String computeNodeGroupIdentifier,
  3. String? clientToken,
})

Deletes a compute node group. You must delete all queues associated with the compute node group first.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter clusterIdentifier : The name or ID of the cluster of the compute node group.

Parameter computeNodeGroupIdentifier : The name or ID of the compute node group to delete.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.

Implementation

Future<void> deleteComputeNodeGroup({
  required String clusterIdentifier,
  required String computeNodeGroupIdentifier,
  String? clientToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSParallelComputingService.DeleteComputeNodeGroup'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'clusterIdentifier': clusterIdentifier,
      'computeNodeGroupIdentifier': computeNodeGroupIdentifier,
      'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    },
  );
}