listComputeNodeGroups method

Future<ListComputeNodeGroupsResponse> listComputeNodeGroups({
  1. required String clusterIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of all compute node groups associated with a cluster.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter clusterIdentifier : The name or ID of the cluster to list compute node groups for.

Parameter maxResults : The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.

Parameter nextToken : The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.

Implementation

Future<ListComputeNodeGroupsResponse> listComputeNodeGroups({
  required String clusterIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AWSParallelComputingService.ListComputeNodeGroups'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'clusterIdentifier': clusterIdentifier,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListComputeNodeGroupsResponse.fromJson(jsonResponse.body);
}