updateQueue method
Updates the compute node group configuration of a queue. Use this API to change the compute node groups that the queue can send jobs to.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterIdentifier :
The name or ID of the cluster of the queue.
Parameter queueIdentifier :
The name or ID of the queue.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Idempotency ensures that an API request
completes only once. With an idempotent request, if the original request
completes successfully, the subsequent retries with the same client token
return the result from the original successful request and they have no
additional effect. If you don't specify a client token, the CLI and SDK
automatically generate 1 for you.
Parameter computeNodeGroupConfigurations :
The list of compute node group configurations to associate with the queue.
Queues assign jobs to associated compute node groups.
Parameter slurmConfiguration :
Additional options related to the Slurm scheduler.
Implementation
Future<UpdateQueueResponse> updateQueue({
required String clusterIdentifier,
required String queueIdentifier,
String? clientToken,
List<ComputeNodeGroupConfiguration>? computeNodeGroupConfigurations,
UpdateQueueSlurmConfigurationRequest? slurmConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSParallelComputingService.UpdateQueue'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'clusterIdentifier': clusterIdentifier,
'queueIdentifier': queueIdentifier,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (computeNodeGroupConfigurations != null)
'computeNodeGroupConfigurations': computeNodeGroupConfigurations,
if (slurmConfiguration != null)
'slurmConfiguration': slurmConfiguration,
},
);
return UpdateQueueResponse.fromJson(jsonResponse.body);
}