Personalize class
Amazon Personalize is a machine learning service that makes it easy to add individualized recommendations to customers.
Constructors
- Personalize({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBatchInferenceJob(
{required BatchInferenceJobInput jobInput, required String jobName, required BatchInferenceJobOutput jobOutput, required String roleArn, required String solutionVersionArn, BatchInferenceJobConfig? batchInferenceJobConfig, BatchInferenceJobMode? batchInferenceJobMode, String? filterArn, int? numResults, List< Tag> ? tags, ThemeGenerationConfig? themeGenerationConfig}) → Future<CreateBatchInferenceJobResponse> - Generates batch recommendations based on a list of items or users stored in Amazon S3 and exports the recommendations to an Amazon S3 bucket.
-
createBatchSegmentJob(
{required BatchSegmentJobInput jobInput, required String jobName, required BatchSegmentJobOutput jobOutput, required String roleArn, required String solutionVersionArn, String? filterArn, int? numResults, List< Tag> ? tags}) → Future<CreateBatchSegmentJobResponse> - Creates a batch segment job. The operation can handle up to 50 million records and the input file must be in JSON format. For more information, see Getting batch recommendations and user segments.
-
createCampaign(
{required String name, required String solutionVersionArn, CampaignConfig? campaignConfig, int? minProvisionedTPS, List< Tag> ? tags}) → Future<CreateCampaignResponse> - GetRecommendations
-
createDataDeletionJob(
{required DataSource dataSource, required String datasetGroupArn, required String jobName, required String roleArn, List< Tag> ? tags}) → Future<CreateDataDeletionJobResponse> - Creates a batch job that deletes all references to specific users from an Amazon Personalize dataset group in batches. You specify the users to delete in a CSV file of userIds in an Amazon S3 bucket. After a job completes, Amazon Personalize no longer trains on the users’ data and no longer considers the users when generating user segments. For more information about creating a data deletion job, see Deleting users.
-
createDataset(
{required String datasetGroupArn, required String datasetType, required String name, required String schemaArn, List< Tag> ? tags}) → Future<CreateDatasetResponse> - Creates an empty dataset and adds it to the specified dataset group. Use CreateDatasetImportJob to import your training data to a dataset.
-
createDatasetExportJob(
{required String datasetArn, required String jobName, required DatasetExportJobOutput jobOutput, required String roleArn, IngestionMode? ingestionMode, List< Tag> ? tags}) → Future<CreateDatasetExportJobResponse> -
Creates a job that exports data from your dataset to an Amazon S3 bucket.
To allow Amazon Personalize to export the training data, you must specify
an service-linked IAM role that gives Amazon Personalize
PutObjectpermissions for your Amazon S3 bucket. For information, see Exporting a dataset in the Amazon Personalize developer guide. -
createDatasetGroup(
{required String name, Domain? domain, String? kmsKeyArn, String? roleArn, List< Tag> ? tags}) → Future<CreateDatasetGroupResponse> - Creates an empty dataset group. A dataset group is a container for Amazon Personalize resources. A dataset group can contain at most three datasets, one for each type of dataset:
-
createDatasetImportJob(
{required DataSource dataSource, required String datasetArn, required String jobName, ImportMode? importMode, bool? publishAttributionMetricsToS3, String? roleArn, List< Tag> ? tags}) → Future<CreateDatasetImportJobResponse> - Creates a job that imports training data from your data source (an Amazon S3 bucket) to an Amazon Personalize dataset. To allow Amazon Personalize to import the training data, you must specify an IAM service role that has permission to read from the data source, as Amazon Personalize makes a copy of your data and processes it internally. For information on granting access to your Amazon S3 bucket, see Giving Amazon Personalize Access to Amazon S3 Resources.
-
createEventTracker(
{required String datasetGroupArn, required String name, List< Tag> ? tags}) → Future<CreateEventTrackerResponse> - Creates an event tracker that you use when adding event data to a specified dataset group using the PutEvents API. When you create an event tracker, the response includes a tracking ID, which you pass as a parameter when you use the PutEvents operation. Amazon Personalize then appends the event data to the Item interactions dataset of the dataset group you specify in your event tracker.
-
createFilter(
{required String datasetGroupArn, required String filterExpression, required String name, List< Tag> ? tags}) → Future<CreateFilterResponse> - Creates a recommendation filter. For more information, see Filtering recommendations and user segments.
-
createMetricAttribution(
{required String datasetGroupArn, required List< MetricAttribute> metrics, required MetricAttributionOutput metricsOutputConfig, required String name}) → Future<CreateMetricAttributionResponse> - Creates a metric attribution. A metric attribution creates reports on the data that you import into Amazon Personalize. Depending on how you imported the data, you can view reports in Amazon CloudWatch or Amazon S3. For more information, see Measuring impact of recommendations.
-
createRecommender(
{required String datasetGroupArn, required String name, required String recipeArn, RecommenderConfig? recommenderConfig, List< Tag> ? tags}) → Future<CreateRecommenderResponse> - Creates a recommender with the recipe (a Domain dataset group use case) you specify. You create recommenders for a Domain dataset group and specify the recommender's Amazon Resource Name (ARN) when you make a GetRecommendations request.
-
createSchema(
{required String name, required String schema, Domain? domain}) → Future< CreateSchemaResponse> - Creates an Amazon Personalize schema from the specified schema string. The schema you create must be in Avro JSON format.
-
createSolution(
{required String datasetGroupArn, required String name, String? eventType, bool? performAutoML, bool? performAutoTraining, bool? performHPO, bool? performIncrementalUpdate, String? recipeArn, SolutionConfig? solutionConfig, List< Tag> ? tags}) → Future<CreateSolutionResponse> - Creating and configuring a solution
-
createSolutionVersion(
{required String solutionArn, String? name, List< Tag> ? tags, TrainingMode? trainingMode}) → Future<CreateSolutionVersionResponse> -
Trains or retrains an active solution in a Custom dataset group. A
solution is created using the CreateSolution
operation and must be in the ACTIVE state before calling
CreateSolutionVersion. A new version of the solution is created every time you call this operation. -
deleteCampaign(
{required String campaignArn}) → Future< void> - Removes a campaign by deleting the solution deployment. The solution that the campaign is based on is not deleted and can be redeployed when needed. A deleted campaign can no longer be specified in a GetRecommendations request. For information on creating campaigns, see CreateCampaign.
-
deleteDataset(
{required String datasetArn}) → Future< void> -
Deletes a dataset. You can't delete a dataset if an associated
DatasetImportJoborSolutionVersionis in the CREATE PENDING or IN PROGRESS state. For more information about deleting datasets, see Deleting a dataset. -
deleteDatasetGroup(
{required String datasetGroupArn}) → Future< void> - Deletes a dataset group. Before you delete a dataset group, you must delete the following:
-
deleteEventTracker(
{required String eventTrackerArn}) → Future< void> - Deletes the event tracker. Does not delete the dataset from the dataset group. For more information on event trackers, see CreateEventTracker.
-
deleteFilter(
{required String filterArn}) → Future< void> - Deletes a filter.
-
deleteMetricAttribution(
{required String metricAttributionArn}) → Future< void> - Deletes a metric attribution.
-
deleteRecommender(
{required String recommenderArn}) → Future< void> - Deactivates and removes a recommender. A deleted recommender can no longer be specified in a GetRecommendations request.
-
deleteSchema(
{required String schemaArn}) → Future< void> - Deletes a schema. Before deleting a schema, you must delete all datasets referencing the schema. For more information on schemas, see CreateSchema.
-
deleteSolution(
{required String solutionArn}) → Future< void> -
Deletes all versions of a solution and the
Solutionobject itself. Before deleting a solution, you must delete all campaigns based on the solution. To determine what campaigns are using the solution, call ListCampaigns and supply the Amazon Resource Name (ARN) of the solution. You can't delete a solution if an associatedSolutionVersionis in the CREATE PENDING or IN PROGRESS state. For more information on solutions, see CreateSolution. -
describeAlgorithm(
{required String algorithmArn}) → Future< DescribeAlgorithmResponse> - Describes the given algorithm.
-
describeBatchInferenceJob(
{required String batchInferenceJobArn}) → Future< DescribeBatchInferenceJobResponse> - Gets the properties of a batch inference job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate the recommendations.
-
describeBatchSegmentJob(
{required String batchSegmentJobArn}) → Future< DescribeBatchSegmentJobResponse> - Gets the properties of a batch segment job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate segments.
-
describeCampaign(
{required String campaignArn}) → Future< DescribeCampaignResponse> - Describes the given campaign, including its status.
-
describeDataDeletionJob(
{required String dataDeletionJobArn}) → Future< DescribeDataDeletionJobResponse> - Describes the data deletion job created by CreateDataDeletionJob, including the job status.
-
describeDataset(
{required String datasetArn}) → Future< DescribeDatasetResponse> - Describes the given dataset. For more information on datasets, see CreateDataset.
-
describeDatasetExportJob(
{required String datasetExportJobArn}) → Future< DescribeDatasetExportJobResponse> - Describes the dataset export job created by CreateDatasetExportJob, including the export job status.
-
describeDatasetGroup(
{required String datasetGroupArn}) → Future< DescribeDatasetGroupResponse> - Describes the given dataset group. For more information on dataset groups, see CreateDatasetGroup.
-
describeDatasetImportJob(
{required String datasetImportJobArn}) → Future< DescribeDatasetImportJobResponse> - Describes the dataset import job created by CreateDatasetImportJob, including the import job status.
-
describeEventTracker(
{required String eventTrackerArn}) → Future< DescribeEventTrackerResponse> -
Describes an event tracker. The response includes the
trackingIdandstatusof the event tracker. For more information on event trackers, see CreateEventTracker. -
describeFeatureTransformation(
{required String featureTransformationArn}) → Future< DescribeFeatureTransformationResponse> - Describes the given feature transformation.
-
describeFilter(
{required String filterArn}) → Future< DescribeFilterResponse> - Describes a filter's properties.
-
describeMetricAttribution(
{required String metricAttributionArn}) → Future< DescribeMetricAttributionResponse> - Describes a metric attribution.
-
describeRecipe(
{required String recipeArn}) → Future< DescribeRecipeResponse> - Describes a recipe.
-
describeRecommender(
{required String recommenderArn}) → Future< DescribeRecommenderResponse> - Describes the given recommender, including its status.
-
describeSchema(
{required String schemaArn}) → Future< DescribeSchemaResponse> - Describes a schema. For more information on schemas, see CreateSchema.
-
describeSolution(
{required String solutionArn}) → Future< DescribeSolutionResponse> - Describes a solution. For more information on solutions, see CreateSolution.
-
describeSolutionVersion(
{required String solutionVersionArn}) → Future< DescribeSolutionVersionResponse> - Describes a specific version of a solution. For more information on solutions, see CreateSolution
-
getSolutionMetrics(
{required String solutionVersionArn}) → Future< GetSolutionMetricsResponse> - Gets the metrics for the specified solution version.
-
listBatchInferenceJobs(
{int? maxResults, String? nextToken, String? solutionVersionArn}) → Future< ListBatchInferenceJobsResponse> - Gets a list of the batch inference jobs that have been performed off of a solution version.
-
listBatchSegmentJobs(
{int? maxResults, String? nextToken, String? solutionVersionArn}) → Future< ListBatchSegmentJobsResponse> - Gets a list of the batch segment jobs that have been performed off of a solution version that you specify.
-
listCampaigns(
{int? maxResults, String? nextToken, String? solutionArn}) → Future< ListCampaignsResponse> - Returns a list of campaigns that use the given solution. When a solution is not specified, all the campaigns associated with the account are listed. The response provides the properties for each campaign, including the Amazon Resource Name (ARN). For more information on campaigns, see CreateCampaign.
-
listDataDeletionJobs(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListDataDeletionJobsResponse> - Returns a list of data deletion jobs for a dataset group ordered by creation time, with the most recent first. When a dataset group is not specified, all the data deletion jobs associated with the account are listed. The response provides the properties for each job, including the Amazon Resource Name (ARN). For more information on data deletion jobs, see Deleting users.
-
listDatasetExportJobs(
{String? datasetArn, int? maxResults, String? nextToken}) → Future< ListDatasetExportJobsResponse> - Returns a list of dataset export jobs that use the given dataset. When a dataset is not specified, all the dataset export jobs associated with the account are listed. The response provides the properties for each dataset export job, including the Amazon Resource Name (ARN). For more information on dataset export jobs, see CreateDatasetExportJob. For more information on datasets, see CreateDataset.
-
listDatasetGroups(
{int? maxResults, String? nextToken}) → Future< ListDatasetGroupsResponse> - Returns a list of dataset groups. The response provides the properties for each dataset group, including the Amazon Resource Name (ARN). For more information on dataset groups, see CreateDatasetGroup.
-
listDatasetImportJobs(
{String? datasetArn, int? maxResults, String? nextToken}) → Future< ListDatasetImportJobsResponse> - Returns a list of dataset import jobs that use the given dataset. When a dataset is not specified, all the dataset import jobs associated with the account are listed. The response provides the properties for each dataset import job, including the Amazon Resource Name (ARN). For more information on dataset import jobs, see CreateDatasetImportJob. For more information on datasets, see CreateDataset.
-
listDatasets(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListDatasetsResponse> - Returns the list of datasets contained in the given dataset group. The response provides the properties for each dataset, including the Amazon Resource Name (ARN). For more information on datasets, see CreateDataset.
-
listEventTrackers(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListEventTrackersResponse> - Returns the list of event trackers associated with the account. The response provides the properties for each event tracker, including the Amazon Resource Name (ARN) and tracking ID. For more information on event trackers, see CreateEventTracker.
-
listFilters(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListFiltersResponse> - Lists all filters that belong to a given dataset group.
-
listMetricAttributionMetrics(
{int? maxResults, String? metricAttributionArn, String? nextToken}) → Future< ListMetricAttributionMetricsResponse> - Lists the metrics for the metric attribution.
-
listMetricAttributions(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListMetricAttributionsResponse> - Lists metric attributions.
-
listRecipes(
{Domain? domain, int? maxResults, String? nextToken, RecipeProvider? recipeProvider}) → Future< ListRecipesResponse> - Returns a list of available recipes. The response provides the properties for each recipe, including the recipe's Amazon Resource Name (ARN).
-
listRecommenders(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListRecommendersResponse> - Returns a list of recommenders in a given Domain dataset group. When a Domain dataset group is not specified, all the recommenders associated with the account are listed. The response provides the properties for each recommender, including the Amazon Resource Name (ARN). For more information on recommenders, see CreateRecommender.
-
listSchemas(
{int? maxResults, String? nextToken}) → Future< ListSchemasResponse> - Returns the list of schemas associated with the account. The response provides the properties for each schema, including the Amazon Resource Name (ARN). For more information on schemas, see CreateSchema.
-
listSolutions(
{String? datasetGroupArn, int? maxResults, String? nextToken}) → Future< ListSolutionsResponse> - Returns a list of solutions in a given dataset group. When a dataset group is not specified, all the solutions associated with the account are listed. The response provides the properties for each solution, including the Amazon Resource Name (ARN). For more information on solutions, see CreateSolution.
-
listSolutionVersions(
{int? maxResults, String? nextToken, String? solutionArn}) → Future< ListSolutionVersionsResponse> - Returns a list of solution versions for the given solution. When a solution is not specified, all the solution versions associated with the account are listed. The response provides the properties for each solution version, including the Amazon Resource Name (ARN).
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Get a list of tags attached to a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startRecommender(
{required String recommenderArn}) → Future< StartRecommenderResponse> - Starts a recommender that is INACTIVE. Starting a recommender does not create any new models, but resumes billing and automatic retraining for the recommender.
-
stopRecommender(
{required String recommenderArn}) → Future< StopRecommenderResponse> - Stops a recommender that is ACTIVE. Stopping a recommender halts billing and automatic retraining for the recommender.
-
stopSolutionVersionCreation(
{required String solutionVersionArn}) → Future< void> - Stops creating a solution version that is in a state of CREATE_PENDING or CREATE IN_PROGRESS.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Add a list of tags to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags that are attached to a resource. For more information, see Removing tags from Amazon Personalize resources.
-
updateCampaign(
{required String campaignArn, CampaignConfig? campaignConfig, int? minProvisionedTPS, String? solutionVersionArn}) → Future< UpdateCampaignResponse> -
Updates a campaign to deploy a retrained solution version with an existing
campaign, change your campaign's
minProvisionedTPS, or modify your campaign's configuration. For example, you can setenableMetadataWithRecommendationsto true for an existing campaign. -
updateDataset(
{required String datasetArn, required String schemaArn}) → Future< UpdateDatasetResponse> - Update a dataset to replace its schema with a new or existing one. For more information, see Replacing a dataset's schema.
-
updateMetricAttribution(
{List< MetricAttribute> ? addMetrics, String? metricAttributionArn, MetricAttributionOutput? metricsOutputConfig, List<String> ? removeMetrics}) → Future<UpdateMetricAttributionResponse> - Updates a metric attribution.
-
updateRecommender(
{required String recommenderArn, required RecommenderConfig recommenderConfig}) → Future< UpdateRecommenderResponse> -
Updates the recommender to modify the recommender configuration. If you
update the recommender to modify the columns used in training, Amazon
Personalize automatically starts a full retraining of the models backing
your recommender. While the update completes, you can still get
recommendations from the recommender. The recommender uses the previous
configuration until the update completes. To track the status of this
update, use the
latestRecommenderUpdatereturned in the DescribeRecommender operation. -
updateSolution(
{required String solutionArn, bool? performAutoTraining, bool? performIncrementalUpdate, SolutionUpdateConfig? solutionUpdateConfig}) → Future< UpdateSolutionResponse> - Updates an Amazon Personalize solution to use a different automatic training configuration. When you update a solution, you can change whether the solution uses automatic training, and you can change the training frequency. For more information about updating a solution, see Updating a solution.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited