listBatchSegmentJobs method
Gets a list of the batch segment jobs that have been performed off of a solution version that you specify.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter maxResults :
The maximum number of batch segment job results to return in each page.
The default value is 100.
Parameter nextToken :
The token to request the next page of results.
Parameter solutionVersionArn :
The Amazon Resource Name (ARN) of the solution version that the batch
segment jobs used to generate batch segments.
Implementation
Future<ListBatchSegmentJobsResponse> listBatchSegmentJobs({
int? maxResults,
String? nextToken,
String? solutionVersionArn,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonPersonalize.ListBatchSegmentJobs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (solutionVersionArn != null)
'solutionVersionArn': solutionVersionArn,
},
);
return ListBatchSegmentJobsResponse.fromJson(jsonResponse.body);
}