listDatasetExportJobs method
Returns a list of dataset export jobs that use the given dataset. When a dataset is not specified, all the dataset export jobs associated with the account are listed. The response provides the properties for each dataset export job, including the Amazon Resource Name (ARN). For more information on dataset export jobs, see CreateDatasetExportJob. For more information on datasets, see CreateDataset.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter datasetArn :
The Amazon Resource Name (ARN) of the dataset to list the dataset export
jobs for.
Parameter maxResults :
The maximum number of dataset export jobs to return.
Parameter nextToken :
A token returned from the previous call to
ListDatasetExportJobs for getting the next set of dataset
export jobs (if they exist).
Implementation
Future<ListDatasetExportJobsResponse> listDatasetExportJobs({
String? datasetArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonPersonalize.ListDatasetExportJobs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (datasetArn != null) 'datasetArn': datasetArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListDatasetExportJobsResponse.fromJson(jsonResponse.body);
}