stopSolutionVersionCreation method

Future<void> stopSolutionVersionCreation({
  1. required String solutionVersionArn,
})

Stops creating a solution version that is in a state of CREATE_PENDING or CREATE IN_PROGRESS.

Depending on the current state of the solution version, the solution version state changes as follows:

  • CREATE_PENDING > CREATE_STOPPED

    or

  • CREATE_IN_PROGRESS > CREATE_STOPPING > CREATE_STOPPED
You are billed for all of the training completed up until you stop the solution version creation. You cannot resume creating a solution version once it has been stopped.

May throw InvalidInputException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter solutionVersionArn : The Amazon Resource Name (ARN) of the solution version you want to stop creating.

Implementation

Future<void> stopSolutionVersionCreation({
  required String solutionVersionArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonPersonalize.StopSolutionVersionCreation'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'solutionVersionArn': solutionVersionArn,
    },
  );
}