untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Removes the specified tags that are attached to a resource. For more information, see Removing tags from Amazon Personalize resources.

May throw InvalidInputException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw TooManyTagKeysException.

Parameter resourceArn : The resource's Amazon Resource Name (ARN).

Parameter tagKeys : The keys of the tags to be removed.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonPersonalize.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'resourceArn': resourceArn,
      'tagKeys': tagKeys,
    },
  );
}