PersonalizeEvents class

Amazon Personalize can consume real-time user event data, such as stream or click data, and use it for model training either alone or combined with historical data. For more information see Recording item interaction events.

Constructors

PersonalizeEvents({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putActionInteractions({required List<ActionInteraction> actionInteractions, required String trackingId}) Future<void>
Records action interaction event data. An action interaction event is an interaction between a user and an action. For example, a user taking an action, such a enrolling in a membership program or downloading your app.
putActions({required List<Action> actions, required String datasetArn}) Future<void>
Adds one or more actions to an Actions dataset. For more information see Importing actions individually.
putEvents({required List<Event> eventList, required String sessionId, required String trackingId, String? userId}) Future<void>
Records item interaction event data. For more information see Recording item interaction events.
putItems({required String datasetArn, required List<Item> items}) Future<void>
Adds one or more items to an Items dataset. For more information see Importing items individually.
putUsers({required String datasetArn, required List<User> users}) Future<void>
Adds one or more users to a Users dataset. For more information see Importing users individually.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited