putActionInteractions method

Future<void> putActionInteractions({
  1. required List<ActionInteraction> actionInteractions,
  2. required String trackingId,
})

Records action interaction event data. An action interaction event is an interaction between a user and an action. For example, a user taking an action, such a enrolling in a membership program or downloading your app.

For more information about recording action interactions, see Recording action interaction events. For more information about actions in an Actions dataset, see Actions dataset.

May throw InvalidInputException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter actionInteractions : A list of action interaction events from the session.

Parameter trackingId : The ID of your action interaction event tracker. When you create an Action interactions dataset, Amazon Personalize creates an action interaction event tracker for you. For more information, see Action interaction event tracker ID.

Implementation

Future<void> putActionInteractions({
  required List<ActionInteraction> actionInteractions,
  required String trackingId,
}) async {
  final $payload = <String, dynamic>{
    'actionInteractions': actionInteractions,
    'trackingId': trackingId,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/action-interactions',
    exceptionFnMap: _exceptionFns,
  );
}