PersonalizeRuntime class

Constructors

PersonalizeRuntime({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getActionRecommendations({String? campaignArn, String? filterArn, Map<String, String>? filterValues, int? numResults, String? userId}) Future<GetActionRecommendationsResponse>
Returns a list of recommended actions in sorted in descending order by prediction score. Use the GetActionRecommendations API if you have a custom campaign that deploys a solution version trained with a PERSONALIZED_ACTIONS recipe.
getPersonalizedRanking({required String campaignArn, required List<String> inputList, required String userId, Map<String, String>? context, String? filterArn, Map<String, String>? filterValues, Map<String, List<String>>? metadataColumns}) Future<GetPersonalizedRankingResponse>
Re-ranks a list of recommended items for the given user. The first item in the list is deemed the most likely item to be of interest to the user.
getRecommendations({String? campaignArn, Map<String, String>? context, String? filterArn, Map<String, String>? filterValues, String? itemId, Map<String, List<String>>? metadataColumns, int? numResults, List<Promotion>? promotions, String? recommenderArn, String? userId}) Future<GetRecommendationsResponse>
Returns a list of recommended items. For campaigns, the campaign's Amazon Resource Name (ARN) is required and the required user and item input depends on the recipe type used to create the solution backing the campaign as follows:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited