getRecommendations method

Future<GetRecommendationsResponse> getRecommendations({
  1. String? campaignArn,
  2. Map<String, String>? context,
  3. String? filterArn,
  4. Map<String, String>? filterValues,
  5. String? itemId,
  6. Map<String, List<String>>? metadataColumns,
  7. int? numResults,
  8. List<Promotion>? promotions,
  9. String? recommenderArn,
  10. String? userId,
})

Returns a list of recommended items. For campaigns, the campaign's Amazon Resource Name (ARN) is required and the required user and item input depends on the recipe type used to create the solution backing the campaign as follows:

  • USER_PERSONALIZATION - userId required, itemId not used
  • RELATED_ITEMS - itemId required, userId not used
For recommenders, the recommender's ARN is required and the required item and user input depends on the use case (domain-based recipe) backing the recommender. For information on use case requirements see Choosing recommender use cases.

May throw InvalidInputException. May throw ResourceNotFoundException.

Parameter campaignArn : The Amazon Resource Name (ARN) of the campaign to use for getting recommendations.

Parameter context : The contextual metadata to use when getting recommendations. Contextual metadata includes any interaction information that might be relevant when getting a user's recommendations, such as the user's current location or device type.

Parameter filterArn : The ARN of the filter to apply to the returned recommendations. For more information, see Filtering Recommendations.

When using this parameter, be sure the filter resource is ACTIVE.

Parameter filterValues : The values to use when filtering recommendations. For each placeholder parameter in your filter expression, provide the parameter name (in matching case) as a key and the filter value(s) as the corresponding value. Separate multiple values for one parameter with a comma.

For filter expressions that use an INCLUDE element to include items, you must provide values for all parameters that are defined in the expression. For filters with expressions that use an EXCLUDE element to exclude items, you can omit the filter-values.In this case, Amazon Personalize doesn't use that portion of the expression to filter recommendations.

For more information, see Filtering recommendations and user segments.

Parameter itemId : The item ID to provide recommendations for.

Required for RELATED_ITEMS recipe type.

Parameter metadataColumns : If you enabled metadata in recommendations when you created or updated the campaign or recommender, specify the metadata columns from your Items dataset to include in item recommendations. The map key is ITEMS and the value is a list of column names from your Items dataset. The maximum number of columns you can provide is 10.

For information about enabling metadata for a campaign, see Enabling metadata in recommendations for a campaign. For information about enabling metadata for a recommender, see Enabling metadata in recommendations for a recommender.

Parameter numResults : The number of results to return. The default is 25. If you are including metadata in recommendations, the maximum is 50. Otherwise, the maximum is 500.

Parameter promotions : The promotions to apply to the recommendation request. A promotion defines additional business rules that apply to a configurable subset of recommended items.

Parameter recommenderArn : The Amazon Resource Name (ARN) of the recommender to use to get recommendations. Provide a recommender ARN if you created a Domain dataset group with a recommender for a domain use case.

Parameter userId : The user ID to provide recommendations for.

Required for USER_PERSONALIZATION recipe type.

Implementation

Future<GetRecommendationsResponse> getRecommendations({
  String? campaignArn,
  Map<String, String>? context,
  String? filterArn,
  Map<String, String>? filterValues,
  String? itemId,
  Map<String, List<String>>? metadataColumns,
  int? numResults,
  List<Promotion>? promotions,
  String? recommenderArn,
  String? userId,
}) async {
  _s.validateNumRange(
    'numResults',
    numResults,
    0,
    1152921504606846976,
  );
  final $payload = <String, dynamic>{
    if (campaignArn != null) 'campaignArn': campaignArn,
    if (context != null) 'context': context,
    if (filterArn != null) 'filterArn': filterArn,
    if (filterValues != null) 'filterValues': filterValues,
    if (itemId != null) 'itemId': itemId,
    if (metadataColumns != null) 'metadataColumns': metadataColumns,
    if (numResults != null) 'numResults': numResults,
    if (promotions != null) 'promotions': promotions,
    if (recommenderArn != null) 'recommenderArn': recommenderArn,
    if (userId != null) 'userId': userId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/recommendations',
    exceptionFnMap: _exceptionFns,
  );
  return GetRecommendationsResponse.fromJson(response);
}