PI class

Amazon RDS Performance Insights enables you to monitor and explore different dimensions of database load based on data captured from a running DB instance. The guide provides detailed information about Performance Insights data types, parameters and errors.

Constructors

PI({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createPerformanceAnalysisReport({required String identifier, required ServiceType serviceType, required DateTime startTime, DateTime? endTime, List<Tag>? tags}) Future<CreatePerformanceAnalysisReportResponse>
Creates a new performance analysis report for a specific time period for the DB instance.
deletePerformanceAnalysisReport({required String analysisReportId, required String identifier, required ServiceType serviceType}) Future<void>
Deletes a performance analysis report.
describeDimensionKeys({required DateTime endTime, required DimensionGroup groupBy, required String identifier, required String metric, required ServiceType serviceType, required DateTime startTime, List<String>? additionalMetrics, Map<String, String>? filter, int? maxResults, String? nextToken, DimensionGroup? partitionBy, int? periodInSeconds}) Future<DescribeDimensionKeysResponse>
For a specific time period, retrieve the top N dimension keys for a metric.
getDimensionKeyDetails({required String group, required String groupIdentifier, required String identifier, required ServiceType serviceType, List<String>? requestedDimensions}) Future<GetDimensionKeyDetailsResponse>
Get the attributes of the specified dimension group for a DB instance or data source. For example, if you specify a SQL ID, GetDimensionKeyDetails retrieves the full text of the dimension db.sql.statement associated with this ID. This operation is useful because GetResourceMetrics and DescribeDimensionKeys don't support retrieval of large SQL statement text, lock snapshots, and execution plans.
getPerformanceAnalysisReport({required String analysisReportId, required String identifier, required ServiceType serviceType, AcceptLanguage? acceptLanguage, TextFormat? textFormat}) Future<GetPerformanceAnalysisReportResponse>
Retrieves the report including the report ID, status, time details, and the insights with recommendations. The report status can be RUNNING, SUCCEEDED, or FAILED. The insights include the description and recommendation fields.
getResourceMetadata({required String identifier, required ServiceType serviceType}) Future<GetResourceMetadataResponse>
Retrieve the metadata for different features. For example, the metadata might indicate that a feature is turned on or off on a specific DB instance.
getResourceMetrics({required DateTime endTime, required String identifier, required List<MetricQuery> metricQueries, required ServiceType serviceType, required DateTime startTime, int? maxResults, String? nextToken, PeriodAlignment? periodAlignment, int? periodInSeconds}) Future<GetResourceMetricsResponse>
Retrieve Performance Insights metrics for a set of data sources over a time period. You can provide specific dimension groups and dimensions, and provide filtering criteria for each group. You must specify an aggregate function for each metric.
listAvailableResourceDimensions({required String identifier, required List<String> metrics, required ServiceType serviceType, List<FineGrainedAction>? authorizedActions, int? maxResults, String? nextToken}) Future<ListAvailableResourceDimensionsResponse>
Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.
listAvailableResourceMetrics({required String identifier, required List<String> metricTypes, required ServiceType serviceType, int? maxResults, String? nextToken}) Future<ListAvailableResourceMetricsResponse>
Retrieve metrics of the specified types that can be queried for a specified DB instance.
listPerformanceAnalysisReportRecommendations({required String analysisReportId, required String identifier, required ServiceType serviceType, int? maxResults, String? nextToken, List<String>? recommendationIds}) Future<ListPerformanceAnalysisReportRecommendationsResponse>
Retrieves recommendations for a performance analysis report.
listPerformanceAnalysisReports({required String identifier, required ServiceType serviceType, bool? listTags, int? maxResults, String? nextToken}) Future<ListPerformanceAnalysisReportsResponse>
Lists all the analysis reports created for the DB instance. The reports are sorted based on the start time of each report.
listTagsForResource({required String resourceARN, required ServiceType serviceType}) Future<ListTagsForResourceResponse>
Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceARN, required ServiceType serviceType, required List<Tag> tags}) Future<void>
Adds metadata tags to the Amazon RDS Performance Insights resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required ServiceType serviceType, required List<String> tagKeys}) Future<void>
Deletes the metadata tags from the Amazon RDS Performance Insights resource.

Operators

operator ==(Object other) bool
The equality operator.
inherited