deletePerformanceAnalysisReport method

Future<void> deletePerformanceAnalysisReport({
  1. required String analysisReportId,
  2. required String identifier,
  3. required ServiceType serviceType,
})

Deletes a performance analysis report.

May throw InternalServiceError. May throw InvalidArgumentException. May throw NotAuthorizedException.

Parameter analysisReportId : The unique identifier of the analysis report for deletion.

Parameter identifier : An immutable identifier for a data source that is unique for an Amazon Web Services Region. Performance Insights gathers metrics from this data source. In the console, the identifier is shown as ResourceID. When you call DescribeDBInstances, the identifier is returned as DbiResourceId.

To use a DB instance as a data source, specify its DbiResourceId value. For example, specify db-ABCDEFGHIJKLMNOPQRSTU1VW2X.

Parameter serviceType : The Amazon Web Services service for which Performance Insights will return metrics. Valid value is RDS.

Implementation

Future<void> deletePerformanceAnalysisReport({
  required String analysisReportId,
  required String identifier,
  required ServiceType serviceType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'PerformanceInsightsv20180227.DeletePerformanceAnalysisReport'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AnalysisReportId': analysisReportId,
      'Identifier': identifier,
      'ServiceType': serviceType.value,
    },
  );
}