describeDimensionKeys method
- required DateTime endTime,
- required DimensionGroup groupBy,
- required String identifier,
- required String metric,
- required ServiceType serviceType,
- required DateTime startTime,
- List<
String> ? additionalMetrics, - Map<
String, String> ? filter, - int? maxResults,
- String? nextToken,
- DimensionGroup? partitionBy,
- int? periodInSeconds,
For a specific time period, retrieve the top N dimension keys
for a metric.
May throw InternalServiceError.
May throw InvalidArgumentException.
May throw NotAuthorizedException.
Parameter endTime :
The date and time specifying the end of the requested time series data.
The value specified is exclusive, which means that data points less
than (but not equal to) EndTime are returned.
The value for EndTime must be later than the value for
StartTime.
Parameter groupBy :
A specification for how to aggregate the data points from a query result.
You must specify a valid dimension group. Performance Insights returns all
dimensions within this group, unless you provide the names of specific
dimensions within this group. You can also request that Performance
Insights return a limited number of values for a dimension.
Parameter identifier :
An immutable, Amazon Web Services Region-unique identifier for a data
source. Performance Insights gathers metrics from this data source.
To use an Amazon RDS instance as a data source, you specify its
DbiResourceId value. For example, specify
db-FAIHNTYBKTGAUSUZQYPDS2GW4A.
Parameter metric :
The name of a Performance Insights metric to be measured.
Valid values for Metric are:
-
db.load.avg- A scaled representation of the number of active sessions for the database engine. -
db.sampledload.avg- The raw number of active sessions for the database engine.
db.load.avg and
db.sampledload.avg are the same value. If the number of
active sessions is greater than the internal threshold, Performance
Insights samples the active sessions, with db.load.avg
showing the scaled values, db.sampledload.avg showing the raw
values, and db.sampledload.avg less than
db.load.avg. For most use cases, you can query
db.load.avg only.
Parameter serviceType :
The Amazon Web Services service for which Performance Insights will return
metrics. Valid values are as follows:
-
RDS -
DOCDB
Parameter startTime :
The date and time specifying the beginning of the requested time series
data. You must specify a StartTime within the past 7 days.
The value specified is inclusive, which means that data points
equal to or greater than StartTime are returned.
The value for StartTime must be earlier than the value for
EndTime.
Parameter additionalMetrics :
Additional metrics for the top N dimension keys. If the
specified dimension group in the GroupBy parameter is
db.sql_tokenized, you can specify per-SQL metrics to get the
values for the top N SQL digests. The response syntax is as
follows: "AdditionalMetrics" : { "string" : "string"
}.
The only supported statistic function is .avg.
Parameter filter :
One or more filters to apply in the request. Restrictions:
-
Any number of filters by the same dimension, as specified in the
GroupByorPartitionparameters. - A single filter for any other dimension in this dimension group.
Parameter maxResults :
The maximum number of items to return in the response. If more items exist
than the specified MaxRecords value, a pagination token is
included in the response so that the remaining results can be retrieved.
Parameter nextToken :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
token, up to the value specified by MaxRecords.
Parameter partitionBy :
For each dimension specified in GroupBy, specify a secondary
dimension to further subdivide the partition keys in the response.
Parameter periodInSeconds :
The granularity, in seconds, of the data points returned from Performance
Insights. A period can be as short as one second, or as long as one day
(86400 seconds). Valid values are:
-
1(one second) -
60(one minute) -
300(five minutes) -
3600(one hour) -
86400(twenty-four hours)
PeriodInSeconds, then Performance
Insights chooses a value for you, with a goal of returning roughly 100-200
data points in the response.
Implementation
Future<DescribeDimensionKeysResponse> describeDimensionKeys({
required DateTime endTime,
required DimensionGroup groupBy,
required String identifier,
required String metric,
required ServiceType serviceType,
required DateTime startTime,
List<String>? additionalMetrics,
Map<String, String>? filter,
int? maxResults,
String? nextToken,
DimensionGroup? partitionBy,
int? periodInSeconds,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
25,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PerformanceInsightsv20180227.DescribeDimensionKeys'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EndTime': unixTimestampToJson(endTime),
'GroupBy': groupBy,
'Identifier': identifier,
'Metric': metric,
'ServiceType': serviceType.value,
'StartTime': unixTimestampToJson(startTime),
if (additionalMetrics != null) 'AdditionalMetrics': additionalMetrics,
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (partitionBy != null) 'PartitionBy': partitionBy,
if (periodInSeconds != null) 'PeriodInSeconds': periodInSeconds,
},
);
return DescribeDimensionKeysResponse.fromJson(jsonResponse.body);
}