untagResource method

Future<void> untagResource({
  1. required String resourceARN,
  2. required ServiceType serviceType,
  3. required List<String> tagKeys,
})

Deletes the metadata tags from the Amazon RDS Performance Insights resource.

May throw InternalServiceError. May throw InvalidArgumentException. May throw NotAuthorizedException.

Parameter resourceARN : The Amazon RDS Performance Insights resource that the tags are added to. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see Constructing an RDS Amazon Resource Name (ARN).

Parameter serviceType : List the tags for the Amazon Web Services service for which Performance Insights returns metrics. Valid value is RDS.

Parameter tagKeys : The metadata assigned to an Amazon RDS Performance Insights resource consisting of a key-value pair.

Implementation

Future<void> untagResource({
  required String resourceARN,
  required ServiceType serviceType,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'PerformanceInsightsv20180227.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceARN': resourceARN,
      'ServiceType': serviceType.value,
      'TagKeys': tagKeys,
    },
  );
}