getJourneyRuns method

Future<GetJourneyRunsResponse> getJourneyRuns({
  1. required String applicationId,
  2. required String journeyId,
  3. String? pageSize,
  4. String? token,
})

Provides information about the runs of a journey.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw PayloadTooLargeException. May throw TooManyRequestsException.

Parameter applicationId : The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

Parameter journeyId : The unique identifier for the journey.

Parameter pageSize : The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

Parameter token : The NextToken string that specifies which page of results to return in a paginated response.

Implementation

Future<GetJourneyRunsResponse> getJourneyRuns({
  required String applicationId,
  required String journeyId,
  String? pageSize,
  String? token,
}) async {
  final $query = <String, List<String>>{
    if (pageSize != null) 'page-size': [pageSize],
    if (token != null) 'token': [token],
  };
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/apps/${Uri.encodeComponent(applicationId)}/journeys/${Uri.encodeComponent(journeyId)}/runs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return GetJourneyRunsResponse(
    journeyRunsResponse: JourneyRunsResponse.fromJson($json),
  );
}