getRecommenderConfigurations method

Future<GetRecommenderConfigurationsResponse> getRecommenderConfigurations({
  1. String? pageSize,
  2. String? token,
})

Retrieves information about all the recommender model configurations that are associated with your Amazon Pinpoint account.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw PayloadTooLargeException. May throw TooManyRequestsException.

Parameter pageSize : The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

Parameter token : The NextToken string that specifies which page of results to return in a paginated response.

Implementation

Future<GetRecommenderConfigurationsResponse> getRecommenderConfigurations({
  String? pageSize,
  String? token,
}) async {
  final $query = <String, List<String>>{
    if (pageSize != null) 'page-size': [pageSize],
    if (token != null) 'token': [token],
  };
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri: '/v1/recommenders',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  final $json = await _s.jsonFromResponse(response);
  return GetRecommenderConfigurationsResponse(
    listRecommenderConfigurationsResponse:
        ListRecommenderConfigurationsResponse.fromJson($json),
  );
}