listJourneys method
Retrieves information about the status, configuration, and other settings for all the journeys that are associated with an application.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw MethodNotAllowedException.
May throw NotFoundException.
May throw PayloadTooLargeException.
May throw TooManyRequestsException.
Parameter applicationId :
The unique identifier for the application. This identifier is displayed as
the Project ID on the Amazon Pinpoint console.
Parameter pageSize :
The maximum number of items to include in each page of a paginated
response. This parameter is not supported for application, campaign, and
journey metrics.
Parameter token :
The NextToken string that specifies which page of results to return in a
paginated response.
Implementation
Future<ListJourneysResponse> listJourneys({
required String applicationId,
String? pageSize,
String? token,
}) async {
final $query = <String, List<String>>{
if (pageSize != null) 'page-size': [pageSize],
if (token != null) 'token': [token],
};
final response = await _protocol.sendRaw(
payload: null,
method: 'GET',
requestUri: '/v1/apps/${Uri.encodeComponent(applicationId)}/journeys',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return ListJourneysResponse(
journeysResponse: JourneysResponse.fromJson($json),
);
}