getBlacklistReports method

Future<GetBlacklistReportsResponse> getBlacklistReports({
  1. required List<String> blacklistItemNames,
})

Retrieve a list of the blacklists that your dedicated IP addresses appear on.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter blacklistItemNames : A list of IP addresses that you want to retrieve blacklist information about. You can only specify the dedicated IP addresses that you use to send email using Amazon Pinpoint or Amazon SES.

Implementation

Future<GetBlacklistReportsResponse> getBlacklistReports({
  required List<String> blacklistItemNames,
}) async {
  final $query = <String, List<String>>{
    'BlacklistItemNames': blacklistItemNames,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/email/deliverability-dashboard/blacklist-report',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetBlacklistReportsResponse.fromJson(response);
}