getEmailIdentity method
Provides information about a specific identity associated with your Amazon Pinpoint account, including the identity's verification status, its DKIM authentication status, and its custom Mail-From settings.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter emailIdentity :
The email identity that you want to retrieve details for.
Implementation
Future<GetEmailIdentityResponse> getEmailIdentity({
required String emailIdentity,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/email/identities/${Uri.encodeComponent(emailIdentity)}',
exceptionFnMap: _exceptionFns,
);
return GetEmailIdentityResponse.fromJson(response);
}