putEmailIdentityDkimAttributes method
Used to enable or disable DKIM authentication for an email identity.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter emailIdentity :
The email identity that you want to change the DKIM settings for.
Parameter signingEnabled :
Sets the DKIM signing configuration for the identity.
When you set this value true, then the messages that Amazon
Pinpoint sends from the identity are DKIM-signed. When you set this value
to false, then the messages that Amazon Pinpoint sends from
the identity aren't DKIM-signed.
Implementation
Future<void> putEmailIdentityDkimAttributes({
required String emailIdentity,
bool? signingEnabled,
}) async {
final $payload = <String, dynamic>{
if (signingEnabled != null) 'SigningEnabled': signingEnabled,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/email/identities/${Uri.encodeComponent(emailIdentity)}/dkim',
exceptionFnMap: _exceptionFns,
);
}