createConfigurationSet method

Future<void> createConfigurationSet({
  1. String? configurationSetName,
})

Create a new configuration set. After you create the configuration set, you can add one or more event destinations to it.

May throw AlreadyExistsException. May throw BadRequestException. May throw InternalServiceErrorException. May throw LimitExceededException. May throw TooManyRequestsException.

Parameter configurationSetName : The name that you want to give the configuration set.

Implementation

Future<void> createConfigurationSet({
  String? configurationSetName,
}) async {
  final $payload = <String, dynamic>{
    if (configurationSetName != null)
      'ConfigurationSetName': configurationSetName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/sms-voice/configuration-sets',
    exceptionFnMap: _exceptionFns,
  );
}