getConfigurationSetEventDestinations method
Future<GetConfigurationSetEventDestinationsResponse>
getConfigurationSetEventDestinations({
- required String configurationSetName,
Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.
May throw BadRequestException.
May throw InternalServiceErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter configurationSetName :
ConfigurationSetName
Implementation
Future<GetConfigurationSetEventDestinationsResponse>
getConfigurationSetEventDestinations({
required String configurationSetName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/sms-voice/configuration-sets/${Uri.encodeComponent(configurationSetName)}/event-destinations',
exceptionFnMap: _exceptionFns,
);
return GetConfigurationSetEventDestinationsResponse.fromJson(response);
}