updateConfigurationSetEventDestination method
Update an event destination in a configuration set. An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.
May throw BadRequestException.
May throw InternalServiceErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter configurationSetName :
ConfigurationSetName
Parameter eventDestinationName :
EventDestinationName
Implementation
Future<void> updateConfigurationSetEventDestination({
required String configurationSetName,
required String eventDestinationName,
EventDestinationDefinition? eventDestination,
}) async {
final $payload = <String, dynamic>{
if (eventDestination != null) 'EventDestination': eventDestination,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/sms-voice/configuration-sets/${Uri.encodeComponent(configurationSetName)}/event-destinations/${Uri.encodeComponent(eventDestinationName)}',
exceptionFnMap: _exceptionFns,
);
}