PinpointSmsVoiceV2 class

Welcome to the End User Messaging SMS, version 2 API Reference. This guide provides information about End User Messaging SMS, version 2 API resources, including supported HTTP methods, parameters, and schemas.

Amazon Pinpoint is an Amazon Web Services service that you can use to engage with your recipients across multiple messaging channels. The End User Messaging SMS, version 2 API provides programmatic access to options that are unique to the SMS and voice channels. End User Messaging SMS, version 2 resources such as phone numbers, sender IDs, and opt-out lists can be used by the Amazon Pinpoint API.

If you're new to End User Messaging SMS, it's also helpful to review the End User Messaging SMS User Guide, where you'll find tutorials, code samples, and procedures that demonstrate how to use End User Messaging SMS features programmatically and how to integrate functionality into mobile apps and other types of applications. The guide also provides key information, such as End User Messaging SMS integration with other Amazon Web Services services, and the quotas that apply to use of the service.

Regional availability

The End User Messaging SMS version 2 API Reference is available in several Amazon Web Services Regions and it provides an endpoint for each of these Regions. For a list of all the Regions and endpoints where the API is currently available, see Amazon Web Services Service Endpoints and Amazon Pinpoint endpoints and quotas in the Amazon Web Services General Reference. To learn more about Amazon Web Services Regions, see Managing Amazon Web Services Regions in the Amazon Web Services General Reference.

In each Region, Amazon Web Services maintains multiple Availability Zones. These Availability Zones are physically isolated from each other, but are united by private, low-latency, high-throughput, and highly redundant network connections. These Availability Zones enable us to provide very high levels of availability and redundancy, while also minimizing latency. To learn more about the number of Availability Zones that are available in each Region, see Amazon Web Services Global Infrastructure.

Constructors

PinpointSmsVoiceV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateOriginationIdentity({required String originationIdentity, required String poolId, String? clientToken, String? isoCountryCode}) Future<AssociateOriginationIdentityResult>
Associates the specified origination identity with a pool.
associateProtectConfiguration({required String configurationSetName, required String protectConfigurationId}) Future<AssociateProtectConfigurationResult>
Associate a protect configuration with a configuration set. This replaces the configuration sets current protect configuration. A configuration set can only be associated with one protect configuration at a time. A protect configuration can be associated with multiple configuration sets.
carrierLookup({required String phoneNumber}) Future<CarrierLookupResult>
Returns information about a destination phone number, including whether the number type and whether it is valid, the carrier, and more.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createConfigurationSet({required String configurationSetName, String? clientToken, List<Tag>? tags}) Future<CreateConfigurationSetResult>
Creates a new configuration set. After you create the configuration set, you can add one or more event destinations to it.
createEventDestination({required String configurationSetName, required String eventDestinationName, required List<EventType> matchingEventTypes, String? clientToken, CloudWatchLogsDestination? cloudWatchLogsDestination, KinesisFirehoseDestination? kinesisFirehoseDestination, SnsDestination? snsDestination}) Future<CreateEventDestinationResult>
Creates a new event destination in a configuration set.
createNotifyConfiguration({required String displayName, required List<NumberCapability> enabledChannels, required NotifyConfigurationUseCase useCase, String? clientToken, String? defaultTemplateId, bool? deletionProtectionEnabled, List<String>? enabledCountries, String? poolId, List<Tag>? tags}) Future<CreateNotifyConfigurationResult>
Creates a new notify configuration for managed messaging. A notify configuration defines the settings for sending templated messages, including the display name, use case, enabled channels, and enabled countries.
createOptOutList({required String optOutListName, String? clientToken, List<Tag>? tags}) Future<CreateOptOutListResult>
Creates a new opt-out list.
createPool({required MessageType messageType, required String originationIdentity, String? clientToken, bool? deletionProtectionEnabled, String? isoCountryCode, List<Tag>? tags}) Future<CreatePoolResult>
Creates a new pool and associates the specified origination identity to the pool. A pool can include one or more phone numbers and SenderIds that are associated with your Amazon Web Services account.
createProtectConfiguration({String? clientToken, bool? deletionProtectionEnabled, List<Tag>? tags}) Future<CreateProtectConfigurationResult>
Create a new protect configuration. By default all country rule sets for each capability are set to ALLOW. Update the country rule sets using UpdateProtectConfigurationCountryRuleSet. A protect configurations name is stored as a Tag with the key set to Name and value as the name of the protect configuration.
createRcsAgent({String? clientToken, bool? deletionProtectionEnabled, String? optOutListName, List<Tag>? tags}) Future<CreateRcsAgentResult>
Creates a new RCS agent for sending rich messages through the RCS channel. The RCS agent serves as an origination identity for sending RCS messages to your recipients.
createRegistration({required String registrationType, String? clientToken, List<Tag>? tags}) Future<CreateRegistrationResult>
Creates a new registration based on the RegistrationType field.
createRegistrationAssociation({required String registrationId, required String resourceId}) Future<CreateRegistrationAssociationResult>
Associate the registration with an origination identity such as a phone number or sender ID.
createRegistrationAttachment({Uint8List? attachmentBody, String? attachmentUrl, String? clientToken, List<Tag>? tags}) Future<CreateRegistrationAttachmentResult>
Create a new registration attachment to use for uploading a file or a URL to a file. The maximum file size is 500KB and valid file extensions are PDF, JPEG and PNG. For example, many sender ID registrations require a signed “letter of authorization” (LOA) to be submitted.
createRegistrationVersion({required String registrationId}) Future<CreateRegistrationVersionResult>
Create a new version of the registration and increase the VersionNumber. The previous version of the registration becomes read-only.
createVerifiedDestinationNumber({required String destinationPhoneNumber, String? clientToken, String? rcsAgentId, List<Tag>? tags}) Future<CreateVerifiedDestinationNumberResult>
You can only send messages to verified destination numbers when your account is in the sandbox. You can add up to 10 verified destination numbers.
deleteAccountDefaultProtectConfiguration() Future<DeleteAccountDefaultProtectConfigurationResult>
Removes the current account default protect configuration.
deleteConfigurationSet({required String configurationSetName}) Future<DeleteConfigurationSetResult>
Deletes an existing configuration set.
deleteDefaultMessageType({required String configurationSetName}) Future<DeleteDefaultMessageTypeResult>
Deletes an existing default message type on a configuration set.
deleteDefaultSenderId({required String configurationSetName}) Future<DeleteDefaultSenderIdResult>
Deletes an existing default sender ID on a configuration set.
deleteEventDestination({required String configurationSetName, required String eventDestinationName}) Future<DeleteEventDestinationResult>
Deletes an existing event destination.
deleteKeyword({required String keyword, required String originationIdentity}) Future<DeleteKeywordResult>
Deletes an existing keyword from an origination phone number or pool.
deleteMediaMessageSpendLimitOverride() Future<DeleteMediaMessageSpendLimitOverrideResult>
Deletes an account-level monthly spending limit override for sending multimedia messages (MMS). Deleting a spend limit override will set the EnforcedLimit to equal the MaxLimit, which is controlled by Amazon Web Services. For more information on spend limits (quotas) see Quotas for Server Migration Service in the Server Migration Service User Guide.
deleteNotifyConfiguration({required String notifyConfigurationId}) Future<DeleteNotifyConfigurationResult>
Deletes an existing notify configuration.
deleteNotifyMessageSpendLimitOverride() Future<DeleteNotifyMessageSpendLimitOverrideResult>
Deletes an account-level monthly spending limit override for sending notify messages. Deleting a spend limit override will set the EnforcedLimit to equal the MaxLimit, which is controlled by Amazon Web Services. For more information on spend limits (quotas) see Quotas in the End User Messaging SMS User Guide.
deleteOptedOutNumber({required String optOutListName, required String optedOutNumber}) Future<DeleteOptedOutNumberResult>
Deletes an existing opted out destination phone number from the specified opt-out list.
deleteOptOutList({required String optOutListName}) Future<DeleteOptOutListResult>
Deletes an existing opt-out list. All opted out phone numbers in the opt-out list are deleted.
deletePool({required String poolId}) Future<DeletePoolResult>
Deletes an existing pool. Deleting a pool disassociates all origination identities from that pool.
deleteProtectConfiguration({required String protectConfigurationId}) Future<DeleteProtectConfigurationResult>
Permanently delete the protect configuration. The protect configuration must have deletion protection disabled and must not be associated as the account default protect configuration or associated with a configuration set.
deleteProtectConfigurationRuleSetNumberOverride({required String destinationPhoneNumber, required String protectConfigurationId}) Future<DeleteProtectConfigurationRuleSetNumberOverrideResult>
Permanently delete the protect configuration rule set number override.
deleteRcsAgent({required String rcsAgentId}) Future<DeleteRcsAgentResult>
Deletes an existing RCS agent. If deletion protection is enabled, an error is returned.
deleteRegistration({required String registrationId}) Future<DeleteRegistrationResult>
Permanently delete an existing registration from your account.
deleteRegistrationAttachment({required String registrationAttachmentId}) Future<DeleteRegistrationAttachmentResult>
Permanently delete the specified registration attachment.
deleteRegistrationFieldValue({required String fieldPath, required String registrationId}) Future<DeleteRegistrationFieldValueResult>
Delete the value in a registration form field.
deleteResourcePolicy({required String resourceArn}) Future<DeleteResourcePolicyResult>
Deletes the resource-based policy document attached to the End User Messaging SMS resource. A shared resource can be a Pool, Opt-out list, Sender Id, or Phone number.
deleteTextMessageSpendLimitOverride() Future<DeleteTextMessageSpendLimitOverrideResult>
Deletes an account-level monthly spending limit override for sending text messages. Deleting a spend limit override will set the EnforcedLimit to equal the MaxLimit, which is controlled by Amazon Web Services. For more information on spend limits (quotas) see Quotas in the End User Messaging SMS User Guide.
deleteVerifiedDestinationNumber({required String verifiedDestinationNumberId}) Future<DeleteVerifiedDestinationNumberResult>
Delete a verified destination phone number.
deleteVoiceMessageSpendLimitOverride() Future<DeleteVoiceMessageSpendLimitOverrideResult>
Deletes an account level monthly spend limit override for sending voice messages. Deleting a spend limit override sets the EnforcedLimit equal to the MaxLimit, which is controlled by Amazon Web Services. For more information on spending limits (quotas) see Quotas in the End User Messaging SMS User Guide.
describeAccountAttributes({int? maxResults, String? nextToken}) Future<DescribeAccountAttributesResult>
Describes attributes of your Amazon Web Services account. The supported account attributes include account tier, which indicates whether your account is in the sandbox or production environment. When you're ready to move your account out of the sandbox, create an Amazon Web Services Support case for a service limit increase request.
describeAccountLimits({int? maxResults, String? nextToken}) Future<DescribeAccountLimitsResult>
Describes the current End User Messaging SMS SMS Voice V2 resource quotas for your account. The description for a quota includes the quota name, current usage toward that quota, and the quota's maximum value.
describeConfigurationSets({List<String>? configurationSetNames, List<ConfigurationSetFilter>? filters, int? maxResults, String? nextToken}) Future<DescribeConfigurationSetsResult>
Describes the specified configuration sets or all in your account.
describeKeywords({required String originationIdentity, List<KeywordFilter>? filters, List<String>? keywords, int? maxResults, String? nextToken}) Future<DescribeKeywordsResult>
Describes the specified keywords or all keywords on your origination phone number or pool.
describeNotifyConfigurations({List<NotifyConfigurationFilter>? filters, int? maxResults, String? nextToken, List<String>? notifyConfigurationIds}) Future<DescribeNotifyConfigurationsResult>
Describes the specified notify configurations or all notify configurations in your account.
describeNotifyTemplates({List<NotifyTemplateFilter>? filters, int? maxResults, String? nextToken, List<String>? templateIds}) Future<DescribeNotifyTemplatesResult>
Describes the specified notify templates or all notify templates in your account.
describeOptedOutNumbers({required String optOutListName, List<OptedOutFilter>? filters, int? maxResults, String? nextToken, List<String>? optedOutNumbers}) Future<DescribeOptedOutNumbersResult>
Describes the specified opted out destination numbers or all opted out destination numbers in an opt-out list.
describeOptOutLists({int? maxResults, String? nextToken, List<String>? optOutListNames, Owner? owner}) Future<DescribeOptOutListsResult>
Describes the specified opt-out list or all opt-out lists in your account.
describePhoneNumbers({List<PhoneNumberFilter>? filters, int? maxResults, String? nextToken, Owner? owner, List<String>? phoneNumberIds}) Future<DescribePhoneNumbersResult>
Describes the specified origination phone number, or all the phone numbers in your account.
describePools({List<PoolFilter>? filters, int? maxResults, String? nextToken, Owner? owner, List<String>? poolIds}) Future<DescribePoolsResult>
Retrieves the specified pools or all pools associated with your Amazon Web Services account.
describeProtectConfigurations({List<ProtectConfigurationFilter>? filters, int? maxResults, String? nextToken, List<String>? protectConfigurationIds}) Future<DescribeProtectConfigurationsResult>
Retrieves the protect configurations that match any of filters. If a filter isn’t provided then all protect configurations are returned.
describeRcsAgentCountryLaunchStatus({required String rcsAgentId, List<CountryLaunchStatusFilter>? filters, List<String>? isoCountryCodes, int? maxResults, String? nextToken}) Future<DescribeRcsAgentCountryLaunchStatusResult>
Retrieves the per-country launch status of an RCS agent, including carrier-level details for each country.
describeRcsAgents({List<RcsAgentFilter>? filters, int? maxResults, String? nextToken, Owner? owner, List<String>? rcsAgentIds}) Future<DescribeRcsAgentsResult>
Retrieves the specified RCS agents or all RCS agents associated with your Amazon Web Services account.
describeRegistrationAttachments({List<RegistrationAttachmentFilter>? filters, int? maxResults, String? nextToken, List<String>? registrationAttachmentIds}) Future<DescribeRegistrationAttachmentsResult>
Retrieves the specified registration attachments or all registration attachments associated with your Amazon Web Services account.
describeRegistrationFieldDefinitions({required String registrationType, List<String>? fieldPaths, int? maxResults, String? nextToken, String? sectionPath}) Future<DescribeRegistrationFieldDefinitionsResult>
Retrieves the specified registration type field definitions. You can use DescribeRegistrationFieldDefinitions to view the requirements for creating, filling out, and submitting each registration type.
describeRegistrationFieldValues({required String registrationId, List<String>? fieldPaths, int? maxResults, String? nextToken, String? sectionPath, int? versionNumber}) Future<DescribeRegistrationFieldValuesResult>
Retrieves the specified registration field values.
describeRegistrations({List<RegistrationFilter>? filters, int? maxResults, String? nextToken, List<String>? registrationIds}) Future<DescribeRegistrationsResult>
Retrieves the specified registrations.
describeRegistrationSectionDefinitions({required String registrationType, int? maxResults, String? nextToken, List<String>? sectionPaths}) Future<DescribeRegistrationSectionDefinitionsResult>
Retrieves the specified registration section definitions. You can use DescribeRegistrationSectionDefinitions to view the requirements for creating, filling out, and submitting each registration type.
describeRegistrationTypeDefinitions({List<RegistrationTypeFilter>? filters, int? maxResults, String? nextToken, List<String>? registrationTypes}) Future<DescribeRegistrationTypeDefinitionsResult>
Retrieves the specified registration type definitions. You can use DescribeRegistrationTypeDefinitions to view the requirements for creating, filling out, and submitting each registration type.
describeRegistrationVersions({required String registrationId, List<RegistrationVersionFilter>? filters, int? maxResults, String? nextToken, List<int>? versionNumbers}) Future<DescribeRegistrationVersionsResult>
Retrieves the specified registration version.
describeSenderIds({List<SenderIdFilter>? filters, int? maxResults, String? nextToken, Owner? owner, List<SenderIdAndCountry>? senderIds}) Future<DescribeSenderIdsResult>
Describes the specified SenderIds or all SenderIds associated with your Amazon Web Services account.
describeSpendLimits({int? maxResults, String? nextToken}) Future<DescribeSpendLimitsResult>
Describes the current monthly spend limits for sending voice and text messages.
describeVerifiedDestinationNumbers({List<String>? destinationPhoneNumbers, List<VerifiedDestinationNumberFilter>? filters, int? maxResults, String? nextToken, List<String>? verifiedDestinationNumberIds}) Future<DescribeVerifiedDestinationNumbersResult>
Retrieves the specified verified destination numbers.
disassociateOriginationIdentity({required String originationIdentity, required String poolId, String? clientToken, String? isoCountryCode}) Future<DisassociateOriginationIdentityResult>
Removes the specified origination identity from an existing pool.
disassociateProtectConfiguration({required String configurationSetName, required String protectConfigurationId}) Future<DisassociateProtectConfigurationResult>
Disassociate a protect configuration from a configuration set.
discardRegistrationVersion({required String registrationId}) Future<DiscardRegistrationVersionResult>
Discard the current version of the registration.
getProtectConfigurationCountryRuleSet({required NumberCapability numberCapability, required String protectConfigurationId}) Future<GetProtectConfigurationCountryRuleSetResult>
Retrieve the CountryRuleSet for the specified NumberCapability from a protect configuration.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyResult>
Retrieves the JSON text of the resource-based policy document attached to the End User Messaging SMS resource. A shared resource can be a Pool, Opt-out list, Sender Id, or Phone number.
listNotifyCountries({List<NumberCapability>? channels, int? maxResults, String? nextToken, NotifyConfigurationTier? tier, List<NotifyConfigurationUseCase>? useCases}) Future<ListNotifyCountriesResult>
Lists countries that support notify messaging. You can optionally filter by channel, use case, or tier.
listPoolOriginationIdentities({required String poolId, List<PoolOriginationIdentitiesFilter>? filters, int? maxResults, String? nextToken}) Future<ListPoolOriginationIdentitiesResult>
Lists all associated origination identities in your pool.
listProtectConfigurationRuleSetNumberOverrides({required String protectConfigurationId, List<ProtectConfigurationRuleSetNumberOverrideFilterItem>? filters, int? maxResults, String? nextToken}) Future<ListProtectConfigurationRuleSetNumberOverridesResult>
Retrieve all of the protect configuration rule set number overrides that match the filters.
listRegistrationAssociations({required String registrationId, List<RegistrationAssociationFilter>? filters, int? maxResults, String? nextToken}) Future<ListRegistrationAssociationsResult>
Retrieve all of the origination identities that are associated with a registration.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResult>
List all tags associated with a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putKeyword({required String keyword, required String keywordMessage, required String originationIdentity, KeywordAction? keywordAction}) Future<PutKeywordResult>
Creates or updates a keyword configuration on an origination phone number or pool.
putMessageFeedback({required MessageFeedbackStatus messageFeedbackStatus, required String messageId}) Future<PutMessageFeedbackResult>
Set the MessageFeedbackStatus as RECEIVED or FAILED for the passed in MessageId.
putOptedOutNumber({required String optOutListName, required String optedOutNumber}) Future<PutOptedOutNumberResult>
Creates an opted out destination phone number in the opt-out list.
putProtectConfigurationRuleSetNumberOverride({required ProtectConfigurationRuleOverrideAction action, required String destinationPhoneNumber, required String protectConfigurationId, String? clientToken, DateTime? expirationTimestamp}) Future<PutProtectConfigurationRuleSetNumberOverrideResult>
Create or update a phone number rule override and associate it with a protect configuration.
putRegistrationFieldValue({required String fieldPath, required String registrationId, String? registrationAttachmentId, List<String>? selectChoices, String? textValue}) Future<PutRegistrationFieldValueResult>
Creates or updates a field value for a registration.
putResourcePolicy({required String policy, required String resourceArn}) Future<PutResourcePolicyResult>
Attaches a resource-based policy to a End User Messaging SMS resource(phone number, sender Id, phone poll, or opt-out list) that is used for sharing the resource. A shared resource can be a Pool, Opt-out list, Sender Id, or Phone number. For more information about resource-based policies, see Working with shared resources in the End User Messaging SMS User Guide.
releasePhoneNumber({required String phoneNumberId}) Future<ReleasePhoneNumberResult>
Releases an existing origination phone number in your account. Once released, a phone number is no longer available for sending messages.
releaseSenderId({required String isoCountryCode, required String senderId}) Future<ReleaseSenderIdResult>
Releases an existing sender ID in your account.
requestPhoneNumber({required String isoCountryCode, required MessageType messageType, required List<NumberCapability> numberCapabilities, required RequestableNumberType numberType, String? clientToken, bool? deletionProtectionEnabled, bool? internationalSendingEnabled, String? optOutListName, String? poolId, String? registrationId, List<Tag>? tags}) Future<RequestPhoneNumberResult>
Request an origination phone number for use in your account. For more information on phone number request see Request a phone number in the End User Messaging SMS User Guide.
requestSenderId({required String isoCountryCode, required String senderId, String? clientToken, bool? deletionProtectionEnabled, List<MessageType>? messageTypes, List<Tag>? tags}) Future<RequestSenderIdResult>
Request a new sender ID that doesn't require registration.
sendDestinationNumberVerificationCode({required VerificationChannel verificationChannel, required String verifiedDestinationNumberId, String? configurationSetName, Map<String, String>? context, Map<DestinationCountryParameterKey, String>? destinationCountryParameters, LanguageCode? languageCode, String? originationIdentity}) Future<SendDestinationNumberVerificationCodeResult>
Before you can send test messages to a verified destination phone number you need to opt-in the verified destination phone number. Creates a new text message with a verification code and send it to a verified destination phone number. Once you have the verification code use VerifyDestinationNumber to opt-in the verified destination phone number to receive messages.
sendMediaMessage({required String destinationPhoneNumber, required String originationIdentity, String? configurationSetName, Map<String, String>? context, bool? dryRun, String? maxPrice, List<String>? mediaUrls, String? messageBody, bool? messageFeedbackEnabled, String? protectConfigurationId, int? timeToLive}) Future<SendMediaMessageResult>
Creates a new multimedia message (MMS) and sends it to a recipient's phone number.
sendNotifyTextMessage({required String destinationPhoneNumber, required String notifyConfigurationId, required Map<String, String> templateVariables, String? configurationSetName, Map<String, String>? context, bool? dryRun, bool? messageFeedbackEnabled, String? templateId, int? timeToLive}) Future<SendNotifyTextMessageResult>
Sends a templated text message through a notify configuration to a recipient's phone number.
sendNotifyVoiceMessage({required String destinationPhoneNumber, required String notifyConfigurationId, required Map<String, String> templateVariables, String? configurationSetName, Map<String, String>? context, bool? dryRun, bool? messageFeedbackEnabled, String? templateId, int? timeToLive, VoiceId? voiceId}) Future<SendNotifyVoiceMessageResult>
Sends a templated voice message through a notify configuration to a recipient's phone number.
sendTextMessage({required String destinationPhoneNumber, String? configurationSetName, Map<String, String>? context, Map<DestinationCountryParameterKey, String>? destinationCountryParameters, bool? dryRun, String? keyword, String? maxPrice, String? messageBody, bool? messageFeedbackEnabled, MessageType? messageType, String? originationIdentity, String? protectConfigurationId, int? timeToLive}) Future<SendTextMessageResult>
Creates a new text message and sends it to a recipient's phone number. SendTextMessage only sends an SMS message to one recipient each time it is invoked.
sendVoiceMessage({required String destinationPhoneNumber, required String originationIdentity, String? configurationSetName, Map<String, String>? context, bool? dryRun, String? maxPricePerMinute, String? messageBody, VoiceMessageBodyTextType? messageBodyTextType, bool? messageFeedbackEnabled, String? protectConfigurationId, int? timeToLive, VoiceId? voiceId}) Future<SendVoiceMessageResult>
Allows you to send a request that sends a voice message. This operation uses Amazon Polly to convert a text script into a voice message.
setAccountDefaultProtectConfiguration({required String protectConfigurationId}) Future<SetAccountDefaultProtectConfigurationResult>
Set a protect configuration as your account default. You can only have one account default protect configuration at a time. The current account default protect configuration is replaced with the provided protect configuration.
setDefaultMessageFeedbackEnabled({required String configurationSetName, required bool messageFeedbackEnabled}) Future<SetDefaultMessageFeedbackEnabledResult>
Sets a configuration set's default for message feedback.
setDefaultMessageType({required String configurationSetName, required MessageType messageType}) Future<SetDefaultMessageTypeResult>
Sets the default message type on a configuration set.
setDefaultSenderId({required String configurationSetName, required String senderId}) Future<SetDefaultSenderIdResult>
Sets default sender ID on a configuration set.
setMediaMessageSpendLimitOverride({required int monthlyLimit}) Future<SetMediaMessageSpendLimitOverrideResult>
Sets an account level monthly spend limit override for sending MMS messages. The requested spend limit must be less than or equal to the MaxLimit, which is set by Amazon Web Services.
setNotifyMessageSpendLimitOverride({required int monthlyLimit}) Future<SetNotifyMessageSpendLimitOverrideResult>
Sets an account level monthly spend limit override for sending notify messages. The requested spend limit must be less than or equal to the MaxLimit, which is set by Amazon Web Services.
setTextMessageSpendLimitOverride({required int monthlyLimit}) Future<SetTextMessageSpendLimitOverrideResult>
Sets an account level monthly spend limit override for sending text messages. The requested spend limit must be less than or equal to the MaxLimit, which is set by Amazon Web Services.
setVoiceMessageSpendLimitOverride({required int monthlyLimit}) Future<SetVoiceMessageSpendLimitOverrideResult>
Sets an account level monthly spend limit override for sending voice messages. The requested spend limit must be less than or equal to the MaxLimit, which is set by Amazon Web Services.
submitRegistrationVersion({required String registrationId, bool? awsReview}) Future<SubmitRegistrationVersionResult>
Submit the specified registration for review and approval.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Adds or overwrites only the specified tags for the specified resource. When you specify an existing tag key, the value is overwritten with the new value. Each tag consists of a key and an optional value. Tag keys must be unique per resource. For more information about tags, see Tags in the End User Messaging SMS User Guide.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the association of the specified tags from a resource. For more information on tags see Tags in the End User Messaging SMS User Guide.
updateEventDestination({required String configurationSetName, required String eventDestinationName, CloudWatchLogsDestination? cloudWatchLogsDestination, bool? enabled, KinesisFirehoseDestination? kinesisFirehoseDestination, List<EventType>? matchingEventTypes, SnsDestination? snsDestination}) Future<UpdateEventDestinationResult>
Updates an existing event destination in a configuration set. You can update the IAM role ARN for CloudWatch Logs and Firehose. You can also enable or disable the event destination.
updateNotifyConfiguration({required String notifyConfigurationId, String? defaultTemplateId, bool? deletionProtectionEnabled, List<NumberCapability>? enabledChannels, List<String>? enabledCountries, String? poolId}) Future<UpdateNotifyConfigurationResult>
Updates an existing notify configuration. You can update the default template, pool association, enabled channels, enabled countries, and deletion protection settings.
updatePhoneNumber({required String phoneNumberId, bool? deletionProtectionEnabled, bool? internationalSendingEnabled, String? optOutListName, bool? selfManagedOptOutsEnabled, String? twoWayChannelArn, String? twoWayChannelRole, bool? twoWayEnabled}) Future<UpdatePhoneNumberResult>
Updates the configuration of an existing origination phone number. You can update the opt-out list, enable or disable two-way messaging, change the TwoWayChannelArn, enable or disable self-managed opt-outs, and enable or disable deletion protection.
updatePool({required String poolId, bool? deletionProtectionEnabled, String? optOutListName, bool? selfManagedOptOutsEnabled, bool? sharedRoutesEnabled, String? twoWayChannelArn, String? twoWayChannelRole, bool? twoWayEnabled}) Future<UpdatePoolResult>
Updates the configuration of an existing pool. You can update the opt-out list, enable or disable two-way messaging, change the TwoWayChannelArn, enable or disable self-managed opt-outs, enable or disable deletion protection, and enable or disable shared routes.
updateProtectConfiguration({required String protectConfigurationId, bool? deletionProtectionEnabled}) Future<UpdateProtectConfigurationResult>
Update the setting for an existing protect configuration.
updateProtectConfigurationCountryRuleSet({required Map<String, ProtectConfigurationCountryRuleSetInformation> countryRuleSetUpdates, required NumberCapability numberCapability, required String protectConfigurationId}) Future<UpdateProtectConfigurationCountryRuleSetResult>
Update a country rule set to ALLOW, BLOCK, MONITOR, or FILTER messages to be sent to the specified destination counties. You can update one or multiple countries at a time. The updates are only applied to the specified NumberCapability type.
updateRcsAgent({required String rcsAgentId, bool? deletionProtectionEnabled, String? optOutListName, bool? selfManagedOptOutsEnabled, String? twoWayChannelArn, String? twoWayChannelRole, bool? twoWayEnabled}) Future<UpdateRcsAgentResult>
Updates the configuration of an existing RCS agent. You can update the opt-out list, deletion protection, two-way messaging settings, and self-managed opt-outs configuration.
updateSenderId({required String isoCountryCode, required String senderId, bool? deletionProtectionEnabled}) Future<UpdateSenderIdResult>
Updates the configuration of an existing sender ID.
verifyDestinationNumber({required String verificationCode, required String verifiedDestinationNumberId}) Future<VerifyDestinationNumberResult>
Use the verification code that was received by the verified destination phone number to opt-in the verified destination phone number to receive more messages.

Operators

operator ==(Object other) bool
The equality operator.
inherited