Pipes class

Amazon EventBridge Pipes connects event sources to targets. Pipes reduces the need for specialized knowledge and integration code when developing event driven architectures. This helps ensures consistency across your company’s applications. With Pipes, the target can be any available EventBridge target. To set up a pipe, you select the event source, add optional event filtering, define optional enrichment, and select the target for the event data.

Constructors

Pipes({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createPipe({required String name, required String roleArn, required String source, required String target, String? description, RequestedPipeState? desiredState, String? enrichment, PipeEnrichmentParameters? enrichmentParameters, String? kmsKeyIdentifier, PipeLogConfigurationParameters? logConfiguration, PipeSourceParameters? sourceParameters, Map<String, String>? tags, PipeTargetParameters? targetParameters}) Future<CreatePipeResponse>
Create a pipe. Amazon EventBridge Pipes connect event sources to targets and reduces the need for specialized knowledge and integration code.
deletePipe({required String name}) Future<DeletePipeResponse>
Delete an existing pipe. For more information about pipes, see Amazon EventBridge Pipes in the Amazon EventBridge User Guide.
describePipe({required String name}) Future<DescribePipeResponse>
Get the information about an existing pipe. For more information about pipes, see Amazon EventBridge Pipes in the Amazon EventBridge User Guide.
listPipes({PipeState? currentState, RequestedPipeState? desiredState, int? limit, String? namePrefix, String? nextToken, String? sourcePrefix, String? targetPrefix}) Future<ListPipesResponse>
Get the pipes associated with this account. For more information about pipes, see Amazon EventBridge Pipes in the Amazon EventBridge User Guide.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Displays the tags associated with a pipe.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startPipe({required String name}) Future<StartPipeResponse>
Start an existing pipe.
stopPipe({required String name}) Future<StopPipeResponse>
Stop an existing pipe.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one or more tags (key-value pairs) to the specified pipe. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from the specified pipes.
updatePipe({required String name, required String roleArn, String? description, RequestedPipeState? desiredState, String? enrichment, PipeEnrichmentParameters? enrichmentParameters, String? kmsKeyIdentifier, PipeLogConfigurationParameters? logConfiguration, UpdatePipeSourceParameters? sourceParameters, String? target, PipeTargetParameters? targetParameters}) Future<UpdatePipeResponse>
Update an existing pipe. When you call UpdatePipe, EventBridge only the updates fields you have specified in the request; the rest remain unchanged. The exception to this is if you modify any Amazon Web Services-service specific fields in the SourceParameters, EnrichmentParameters, or TargetParameters objects. For example, DynamoDBStreamParameters or EventBridgeEventBusParameters. EventBridge updates the fields in these objects atomically as one and overrides existing values. This is by design, and means that if you don't specify an optional field in one of these Parameters objects, EventBridge sets that field to its system-default value during the update.

Operators

operator ==(Object other) bool
The equality operator.
inherited