deleteLexicon method
Deletes the specified pronunciation lexicon stored in an Amazon Web
Services Region. A lexicon which has been deleted is not available for
speech synthesis, nor is it possible to retrieve it using either the
GetLexicon or ListLexicon APIs.
For more information, see Managing Lexicons.
May throw LexiconNotFoundException.
May throw ServiceFailureException.
Parameter name :
The name of the lexicon to delete. Must be an existing lexicon in the
region.
Implementation
Future<void> deleteLexicon({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/lexicons/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
}