Pricing class

The Amazon Web Services Price List API is a centralized and convenient way to programmatically query Amazon Web Services for services, products, and pricing information. The Amazon Web Services Price List uses standardized product attributes such as Location, Storage Class, and Operating System, and provides prices at the SKU level. You can use the Amazon Web Services Price List to do the following:

  • Build cost control and scenario planning tools
  • Reconcile billing data
  • Forecast future spend for budgeting purposes
  • Provide cost benefit analysis that compare your internal workloads with Amazon Web Services
Use GetServices without a service code to retrieve the service codes for all Amazon Web Services services, then GetServices with a service code to retrieve the attribute names for that service. After you have the service code and attribute names, you can use GetAttributeValues to see what values are available for an attribute. With the service code and an attribute name and value, you can use GetProducts to find specific products that you're interested in, such as an AmazonEC2 instance, with a Provisioned IOPS volumeType.

For more information, see Using the Amazon Web Services Price List API in the Billing User Guide.

Constructors

Pricing({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
describeServices({String? formatVersion, int? maxResults, String? nextToken, String? serviceCode}) Future<DescribeServicesResponse>
Returns the metadata for one service or a list of the metadata for all services. Use this without a service code to get the service codes for all services. Use it with a service code, such as AmazonEC2, to get information specific to that service, such as the attribute names available for that service. For example, some of the attribute names available for EC2 are volumeType, maxIopsVolume, operation, locationType, and instanceCapacity10xlarge.
getAttributeValues({required String attributeName, required String serviceCode, int? maxResults, String? nextToken}) Future<GetAttributeValuesResponse>
Returns a list of attribute values. Attributes are similar to the details in a Price List API offer file. For a list of available attributes, see Offer File Definitions in the Billing and Cost Management User Guide.
getPriceListFileUrl({required String fileFormat, required String priceListArn}) Future<GetPriceListFileUrlResponse>
This feature is in preview release and is subject to change. Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).
getProducts({required String serviceCode, List<Filter>? filters, String? formatVersion, int? maxResults, String? nextToken}) Future<GetProductsResponse>
Returns a list of all products that match the filter criteria.
listPriceLists({required String currencyCode, required DateTime effectiveDate, required String serviceCode, int? maxResults, String? nextToken, String? regionCode}) Future<ListPriceListsResponse>
This feature is in preview release and is subject to change. Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited