Proton class
This is the Proton Service API Reference. It provides descriptions, syntax and usage examples for each of the actions and data types for the Proton service.
The documentation for each action shows the Query API request parameters and the XML response.
Alternatively, you can use the Amazon Web Services CLI to access an API. For more information, see the Amazon Web Services Command Line Interface User Guide.
The Proton service is a two-pronged automation framework. Administrators create service templates to provide standardized infrastructure and deployment tooling for serverless and container based applications. Developers, in turn, select from the available service templates to automate their application or service deployments.
Because administrators define the infrastructure and tooling that Proton deploys and manages, they need permissions to use all of the listed API operations.
When developers select a specific infrastructure and tooling set, Proton deploys their applications. To monitor their applications that are running on Proton, developers need permissions to the service create, list, update and delete API operations and the service instance list and update API operations.
To learn more about Proton, see the Proton User Guide.
Ensuring Idempotency
When you make a mutating API request, the request typically returns a result before the asynchronous workflows of the operation are complete. Operations might also time out or encounter other server issues before they're complete, even if the request already returned a result. This might make it difficult to determine whether the request succeeded. Moreover, you might need to retry the request multiple times to ensure that the operation completes successfully. However, if the original request and the subsequent retries are successful, the operation occurs multiple times. This means that you might create more resources than you intended.
Idempotency ensures that an API request action completes no more than one time. With an idempotent request, if the original request action completes successfully, any subsequent retries complete successfully without performing any further actions. However, the result might contain updated information, such as the current creation status.
The following lists of APIs are grouped according to methods that ensure idempotency.
Idempotent create APIs with a client token
The API actions in this list support idempotency with the use of a client token. The corresponding Amazon Web Services CLI commands also support idempotency using a client token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. To make an idempotent API request using one of these actions, specify a client token in the request. We recommend that you don't reuse the same client token for other API requests. If you don’t provide a client token for these APIs, a default client token is automatically provided by SDKs.
Given a request action that has succeeded:
If you retry the request using the same client token and the same parameters, the retry succeeds without performing any further actions other than returning the original resource detail data in the response.
If you retry the request using the same client token, but one or more of the
parameters are different, the retry throws a
ValidationException with an
IdempotentParameterMismatch error.
Client tokens expire eight hours after a request is made. If you retry the request with the expired token, a new resource is created.
If the original resource is deleted and you retry the request, a new resource is created.
Idempotent create APIs with a client token:
- CreateEnvironmentTemplateVersion
- CreateServiceTemplateVersion
- CreateEnvironmentAccountConnection
Given a request action that has succeeded:
If you retry the request with an API from this group, and the original resource hasn't been modified, the retry succeeds without performing any further actions other than returning the original resource detail data in the response.
If the original resource has been modified, the retry throws a
ConflictException.
If you retry with different input parameters, the retry throws a
ValidationException with an
IdempotentParameterMismatch error.
Idempotent create APIs:
- CreateEnvironmentTemplate
- CreateServiceTemplate
- CreateEnvironment
- CreateService
Given a request action that has succeeded:
When you retry the request with an API from this group and the resource was deleted, its metadata is returned in the response.
If you retry and the resource doesn't exist, the response is empty.
In both cases, the retry succeeds.
Idempotent delete APIs:
- DeleteEnvironmentTemplate
- DeleteEnvironmentTemplateVersion
- DeleteServiceTemplate
- DeleteServiceTemplateVersion
- DeleteEnvironmentAccountConnection
Given a request action that has succeeded:
If you retry the request with an API from this group, if the original
request delete operation status is DELETE_IN_PROGRESS, the
retry returns the resource detail data in the response without performing
any further actions.
If the original request delete operation is complete, a retry returns an empty response.
Asynchronous idempotent delete APIs:
- DeleteEnvironment
- DeleteService
Constructors
- Proton({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptEnvironmentAccountConnection(
{required String id}) → Future< AcceptEnvironmentAccountConnectionOutput> - In a management account, an environment account connection request is accepted. When the environment account connection request is accepted, Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.
-
cancelComponentDeployment(
{required String componentName}) → Future< CancelComponentDeploymentOutput> -
Attempts to cancel a component deployment (for a component that is in the
IN_PROGRESSdeployment status). -
cancelEnvironmentDeployment(
{required String environmentName}) → Future< CancelEnvironmentDeploymentOutput> -
Attempts to cancel an environment deployment on an
UpdateEnvironment action, if the deployment is
IN_PROGRESS. For more information, see Update an environment in the Proton User guide. -
cancelServiceInstanceDeployment(
{required String serviceInstanceName, required String serviceName}) → Future< CancelServiceInstanceDeploymentOutput> -
Attempts to cancel a service instance deployment on an
UpdateServiceInstance action, if the deployment is
IN_PROGRESS. For more information, see Update a service instance in the Proton User guide. -
cancelServicePipelineDeployment(
{required String serviceName}) → Future< CancelServicePipelineDeploymentOutput> -
Attempts to cancel a service pipeline deployment on an
UpdateServicePipeline action, if the deployment is
IN_PROGRESS. For more information, see Update a service pipeline in the Proton User guide. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createComponent(
{required String manifest, required String name, required String templateFile, String? clientToken, String? description, String? environmentName, String? serviceInstanceName, String? serviceName, String? serviceSpec, List< Tag> ? tags}) → Future<CreateComponentOutput> - Create an Proton component. A component is an infrastructure extension for a service instance.
-
createEnvironment(
{required String name, required String spec, required String templateMajorVersion, required String templateName, String? codebuildRoleArn, String? componentRoleArn, String? description, String? environmentAccountConnectionId, String? protonServiceRoleArn, RepositoryBranchInput? provisioningRepository, List< Tag> ? tags, String? templateMinorVersion}) → Future<CreateEnvironmentOutput> - Deploy a new environment. An Proton environment is created from an environment template that defines infrastructure and resources that can be shared across services.
-
createEnvironmentAccountConnection(
{required String environmentName, required String managementAccountId, String? clientToken, String? codebuildRoleArn, String? componentRoleArn, String? roleArn, List< Tag> ? tags}) → Future<CreateEnvironmentAccountConnectionOutput> - Create an environment account connection in an environment account so that environment infrastructure resources can be provisioned in the environment account from a management account.
-
createEnvironmentTemplate(
{required String name, String? description, String? displayName, String? encryptionKey, Provisioning? provisioning, List< Tag> ? tags}) → Future<CreateEnvironmentTemplateOutput> - Create an environment template for Proton. For more information, see Environment Templates in the Proton User Guide.
-
createEnvironmentTemplateVersion(
{required TemplateVersionSourceInput source, required String templateName, String? clientToken, String? description, String? majorVersion, List< Tag> ? tags}) → Future<CreateEnvironmentTemplateVersionOutput> - Create a new major or minor version of an environment template. A major version of an environment template is a version that isn't backwards compatible. A minor version of an environment template is a version that's backwards compatible within its major version.
-
createRepository(
{required String connectionArn, required String name, required RepositoryProvider provider, String? encryptionKey, List< Tag> ? tags}) → Future<CreateRepositoryOutput> - Create and register a link to a repository. Proton uses the link to repeatedly access the repository, to either push to it (self-managed provisioning) or pull from it (template sync). You can share a linked repository across multiple resources (like environments using self-managed provisioning, or synced templates). When you create a repository link, Proton creates a service-linked role for you.
-
createService(
{required String name, required String spec, required String templateMajorVersion, required String templateName, String? branchName, String? description, String? repositoryConnectionArn, String? repositoryId, List< Tag> ? tags, String? templateMinorVersion}) → Future<CreateServiceOutput> - Create an Proton service. An Proton service is an instantiation of a service template and often includes several service instances and pipeline. For more information, see Services in the Proton User Guide.
-
createServiceInstance(
{required String name, required String serviceName, required String spec, String? clientToken, List< Tag> ? tags, String? templateMajorVersion, String? templateMinorVersion}) → Future<CreateServiceInstanceOutput> - Create a service instance.
-
createServiceSyncConfig(
{required String branch, required String filePath, required String repositoryName, required RepositoryProvider repositoryProvider, required String serviceName}) → Future< CreateServiceSyncConfigOutput> - Create the Proton Ops configuration file.
-
createServiceTemplate(
{required String name, String? description, String? displayName, String? encryptionKey, Provisioning? pipelineProvisioning, List< Tag> ? tags}) → Future<CreateServiceTemplateOutput> - Create a service template. The administrator creates a service template to define standardized infrastructure and an optional CI/CD service pipeline. Developers, in turn, select the service template from Proton. If the selected service template includes a service pipeline definition, they provide a link to their source code repository. Proton then deploys and manages the infrastructure defined by the selected service template. For more information, see Proton templates in the Proton User Guide.
-
createServiceTemplateVersion(
{required List< CompatibleEnvironmentTemplateInput> compatibleEnvironmentTemplates, required TemplateVersionSourceInput source, required String templateName, String? clientToken, String? description, String? majorVersion, List<ServiceTemplateSupportedComponentSourceType> ? supportedComponentSources, List<Tag> ? tags}) → Future<CreateServiceTemplateVersionOutput> - Create a new major or minor version of a service template. A major version of a service template is a version that isn't backward compatible. A minor version of a service template is a version that's backward compatible within its major version.
-
createTemplateSyncConfig(
{required String branch, required String repositoryName, required RepositoryProvider repositoryProvider, required String templateName, required TemplateType templateType, String? subdirectory}) → Future< CreateTemplateSyncConfigOutput> - Set up a template to create new template versions automatically by tracking a linked repository. A linked repository is a repository that has been registered with Proton. For more information, see CreateRepository.
-
deleteComponent(
{required String name}) → Future< DeleteComponentOutput> - Delete an Proton component resource.
-
deleteDeployment(
{required String id}) → Future< DeleteDeploymentOutput> - Delete the deployment.
-
deleteEnvironment(
{required String name}) → Future< DeleteEnvironmentOutput> - Delete an environment.
-
deleteEnvironmentAccountConnection(
{required String id}) → Future< DeleteEnvironmentAccountConnectionOutput> - In an environment account, delete an environment account connection.
-
deleteEnvironmentTemplate(
{required String name}) → Future< DeleteEnvironmentTemplateOutput> - If no other major or minor versions of an environment template exist, delete the environment template.
-
deleteEnvironmentTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName}) → Future< DeleteEnvironmentTemplateVersionOutput> -
If no other minor versions of an environment template exist, delete a
major version of the environment template if it's not the
Recommendedversion. Delete theRecommendedversion of the environment template if no other major versions or minor versions of the environment template exist. A major version of an environment template is a version that's not backward compatible. -
deleteRepository(
{required String name, required RepositoryProvider provider}) → Future< DeleteRepositoryOutput> - De-register and unlink your repository.
-
deleteService(
{required String name}) → Future< DeleteServiceOutput> - Delete a service, with its instances and pipeline.
-
deleteServiceSyncConfig(
{required String serviceName}) → Future< DeleteServiceSyncConfigOutput> - Delete the Proton Ops file.
-
deleteServiceTemplate(
{required String name}) → Future< DeleteServiceTemplateOutput> - If no other major or minor versions of the service template exist, delete the service template.
-
deleteServiceTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName}) → Future< DeleteServiceTemplateVersionOutput> -
If no other minor versions of a service template exist, delete a major
version of the service template if it's not the
Recommendedversion. Delete theRecommendedversion of the service template if no other major versions or minor versions of the service template exist. A major version of a service template is a version that isn't backwards compatible. -
deleteTemplateSyncConfig(
{required String templateName, required TemplateType templateType}) → Future< DeleteTemplateSyncConfigOutput> - Delete a template sync configuration.
-
getAccountSettings(
) → Future< GetAccountSettingsOutput> - Get detail data for Proton account-wide settings.
-
getComponent(
{required String name}) → Future< GetComponentOutput> - Get detailed data for a component.
-
getDeployment(
{required String id, String? componentName, String? environmentName, String? serviceInstanceName, String? serviceName}) → Future< GetDeploymentOutput> - Get detailed data for a deployment.
-
getEnvironment(
{required String name}) → Future< GetEnvironmentOutput> - Get detailed data for an environment.
-
getEnvironmentAccountConnection(
{required String id}) → Future< GetEnvironmentAccountConnectionOutput> - In an environment account, get the detailed data for an environment account connection.
-
getEnvironmentTemplate(
{required String name}) → Future< GetEnvironmentTemplateOutput> - Get detailed data for an environment template.
-
getEnvironmentTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName}) → Future< GetEnvironmentTemplateVersionOutput> - Get detailed data for a major or minor version of an environment template.
-
getRepository(
{required String name, required RepositoryProvider provider}) → Future< GetRepositoryOutput> - Get detail data for a linked repository.
-
getRepositorySyncStatus(
{required String branch, required String repositoryName, required RepositoryProvider repositoryProvider, required SyncType syncType}) → Future< GetRepositorySyncStatusOutput> - Get the sync status of a repository used for Proton template sync. For more information about template sync, see .
-
getResourcesSummary(
) → Future< GetResourcesSummaryOutput> - Get counts of Proton resources.
-
getService(
{required String name}) → Future< GetServiceOutput> - Get detailed data for a service.
-
getServiceInstance(
{required String name, required String serviceName}) → Future< GetServiceInstanceOutput> - Get detailed data for a service instance. A service instance is an instantiation of service template and it runs in a specific environment.
-
getServiceInstanceSyncStatus(
{required String serviceInstanceName, required String serviceName}) → Future< GetServiceInstanceSyncStatusOutput> - Get the status of the synced service instance.
-
getServiceSyncBlockerSummary(
{required String serviceName, String? serviceInstanceName}) → Future< GetServiceSyncBlockerSummaryOutput> - Get detailed data for the service sync blocker summary.
-
getServiceSyncConfig(
{required String serviceName}) → Future< GetServiceSyncConfigOutput> - Get detailed information for the service sync configuration.
-
getServiceTemplate(
{required String name}) → Future< GetServiceTemplateOutput> - Get detailed data for a service template.
-
getServiceTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName}) → Future< GetServiceTemplateVersionOutput> - Get detailed data for a major or minor version of a service template.
-
getTemplateSyncConfig(
{required String templateName, required TemplateType templateType}) → Future< GetTemplateSyncConfigOutput> - Get detail data for a template sync configuration.
-
getTemplateSyncStatus(
{required String templateName, required TemplateType templateType, required String templateVersion}) → Future< GetTemplateSyncStatusOutput> - Get the status of a template sync.
-
listComponentOutputs(
{required String componentName, String? deploymentId, String? nextToken}) → Future< ListComponentOutputsOutput> - Get a list of component Infrastructure as Code (IaC) outputs.
-
listComponentProvisionedResources(
{required String componentName, String? nextToken}) → Future< ListComponentProvisionedResourcesOutput> - List provisioned resources for a component with details.
-
listComponents(
{String? environmentName, int? maxResults, String? nextToken, String? serviceInstanceName, String? serviceName}) → Future< ListComponentsOutput> - List components with summary data. You can filter the result list by environment, service, or a single service instance.
-
listDeployments(
{String? componentName, String? environmentName, int? maxResults, String? nextToken, String? serviceInstanceName, String? serviceName}) → Future< ListDeploymentsOutput> - List deployments. You can filter the result list by environment, service, or a single service instance.
-
listEnvironmentAccountConnections(
{required EnvironmentAccountConnectionRequesterAccountType requestedBy, String? environmentName, int? maxResults, String? nextToken, List< EnvironmentAccountConnectionStatus> ? statuses}) → Future<ListEnvironmentAccountConnectionsOutput> - View a list of environment account connections.
-
listEnvironmentOutputs(
{required String environmentName, String? deploymentId, String? nextToken}) → Future< ListEnvironmentOutputsOutput> - List the infrastructure as code outputs for your environment.
-
listEnvironmentProvisionedResources(
{required String environmentName, String? nextToken}) → Future< ListEnvironmentProvisionedResourcesOutput> - List the provisioned resources for your environment.
-
listEnvironments(
{List< EnvironmentTemplateFilter> ? environmentTemplates, int? maxResults, String? nextToken}) → Future<ListEnvironmentsOutput> - List environments with detail data summaries.
-
listEnvironmentTemplates(
{int? maxResults, String? nextToken}) → Future< ListEnvironmentTemplatesOutput> - List environment templates.
-
listEnvironmentTemplateVersions(
{required String templateName, String? majorVersion, int? maxResults, String? nextToken}) → Future< ListEnvironmentTemplateVersionsOutput> - List major or minor versions of an environment template with detail data.
-
listRepositories(
{int? maxResults, String? nextToken}) → Future< ListRepositoriesOutput> - List linked repositories with detail data.
-
listRepositorySyncDefinitions(
{required String repositoryName, required RepositoryProvider repositoryProvider, required SyncType syncType, String? nextToken}) → Future< ListRepositorySyncDefinitionsOutput> - List repository sync definitions with detail data.
-
listServiceInstanceOutputs(
{required String serviceInstanceName, required String serviceName, String? deploymentId, String? nextToken}) → Future< ListServiceInstanceOutputsOutput> - Get a list service of instance Infrastructure as Code (IaC) outputs.
-
listServiceInstanceProvisionedResources(
{required String serviceInstanceName, required String serviceName, String? nextToken}) → Future< ListServiceInstanceProvisionedResourcesOutput> - List provisioned resources for a service instance with details.
-
listServiceInstances(
{List< ListServiceInstancesFilter> ? filters, int? maxResults, String? nextToken, String? serviceName, ListServiceInstancesSortBy? sortBy, SortOrder? sortOrder}) → Future<ListServiceInstancesOutput> - List service instances with summary data. This action lists service instances of all services in the Amazon Web Services account.
-
listServicePipelineOutputs(
{required String serviceName, String? deploymentId, String? nextToken}) → Future< ListServicePipelineOutputsOutput> - Get a list of service pipeline Infrastructure as Code (IaC) outputs.
-
listServicePipelineProvisionedResources(
{required String serviceName, String? nextToken}) → Future< ListServicePipelineProvisionedResourcesOutput> - List provisioned resources for a service and pipeline with details.
-
listServices(
{int? maxResults, String? nextToken}) → Future< ListServicesOutput> - List services with summaries of detail data.
-
listServiceTemplates(
{int? maxResults, String? nextToken}) → Future< ListServiceTemplatesOutput> - List service templates with detail data.
-
listServiceTemplateVersions(
{required String templateName, String? majorVersion, int? maxResults, String? nextToken}) → Future< ListServiceTemplateVersionsOutput> - List major or minor versions of a service template with detail data.
-
listTagsForResource(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListTagsForResourceOutput> - List tags for a resource. For more information, see Proton resources and tagging in the Proton User Guide.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyResourceDeploymentStatusChange(
{required String resourceArn, String? deploymentId, List< Output> ? outputs, ResourceDeploymentStatus? status, String? statusMessage}) → Future<void> - Notify Proton of status changes to a provisioned resource when you use self-managed provisioning.
-
rejectEnvironmentAccountConnection(
{required String id}) → Future< RejectEnvironmentAccountConnectionOutput> - In a management account, reject an environment account connection from another environment account.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Tag a resource. A tag is a key-value pair of metadata that you associate with an Proton resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Remove a customer tag from a resource. A tag is a key-value pair of metadata associated with an Proton resource.
-
updateAccountSettings(
{bool? deletePipelineProvisioningRepository, String? pipelineCodebuildRoleArn, RepositoryBranchInput? pipelineProvisioningRepository, String? pipelineServiceRoleArn}) → Future< UpdateAccountSettingsOutput> - Update Proton settings that are used for multiple services in the Amazon Web Services account.
-
updateComponent(
{required ComponentDeploymentUpdateType deploymentType, required String name, String? clientToken, String? description, String? serviceInstanceName, String? serviceName, String? serviceSpec, String? templateFile}) → Future< UpdateComponentOutput> - Update a component.
-
updateEnvironment(
{required DeploymentUpdateType deploymentType, required String name, String? codebuildRoleArn, String? componentRoleArn, String? description, String? environmentAccountConnectionId, String? protonServiceRoleArn, RepositoryBranchInput? provisioningRepository, String? spec, String? templateMajorVersion, String? templateMinorVersion}) → Future< UpdateEnvironmentOutput> - Update an environment.
-
updateEnvironmentAccountConnection(
{required String id, String? codebuildRoleArn, String? componentRoleArn, String? roleArn}) → Future< UpdateEnvironmentAccountConnectionOutput> - In an environment account, update an environment account connection to use a new IAM role.
-
updateEnvironmentTemplate(
{required String name, String? description, String? displayName}) → Future< UpdateEnvironmentTemplateOutput> - Update an environment template.
-
updateEnvironmentTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName, String? description, TemplateVersionStatus? status}) → Future< UpdateEnvironmentTemplateVersionOutput> - Update a major or minor version of an environment template.
-
updateService(
{required String name, String? description, String? spec}) → Future< UpdateServiceOutput> -
Edit a service description or use a spec to add and delete service
instances.
Use the
descriptionparameter to modify the description. -
updateServiceInstance(
{required DeploymentUpdateType deploymentType, required String name, required String serviceName, String? clientToken, String? spec, String? templateMajorVersion, String? templateMinorVersion}) → Future< UpdateServiceInstanceOutput> - Update a service instance.
-
updateServicePipeline(
{required DeploymentUpdateType deploymentType, required String serviceName, required String spec, String? templateMajorVersion, String? templateMinorVersion}) → Future< UpdateServicePipelineOutput> - Update the service pipeline.
-
updateServiceSyncBlocker(
{required String id, required String resolvedReason}) → Future< UpdateServiceSyncBlockerOutput> - Update the service sync blocker by resolving it.
-
updateServiceSyncConfig(
{required String branch, required String filePath, required String repositoryName, required RepositoryProvider repositoryProvider, required String serviceName}) → Future< UpdateServiceSyncConfigOutput> - Update the Proton Ops config file.
-
updateServiceTemplate(
{required String name, String? description, String? displayName}) → Future< UpdateServiceTemplateOutput> - Update a service template.
-
updateServiceTemplateVersion(
{required String majorVersion, required String minorVersion, required String templateName, List< CompatibleEnvironmentTemplateInput> ? compatibleEnvironmentTemplates, String? description, TemplateVersionStatus? status, List<ServiceTemplateSupportedComponentSourceType> ? supportedComponentSources}) → Future<UpdateServiceTemplateVersionOutput> - Update a major or minor version of a service template.
-
updateTemplateSyncConfig(
{required String branch, required String repositoryName, required RepositoryProvider repositoryProvider, required String templateName, required TemplateType templateType, String? subdirectory}) → Future< UpdateTemplateSyncConfigOutput> -
Update template sync configuration parameters, except for the
templateNameandtemplateType. Repository details (branch, name, and provider) should be of a linked repository. A linked repository is a repository that has been registered with Proton. For more information, see CreateRepository.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited