acceptEnvironmentAccountConnection method
Future<AcceptEnvironmentAccountConnectionOutput>
acceptEnvironmentAccountConnection({
- required String id,
In a management account, an environment account connection request is accepted. When the environment account connection request is accepted, Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.
For more information, see Environment account connections in the Proton User guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The ID of the environment account connection.
Implementation
Future<AcceptEnvironmentAccountConnectionOutput>
acceptEnvironmentAccountConnection({
required String id,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.AcceptEnvironmentAccountConnection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'id': id,
},
);
return AcceptEnvironmentAccountConnectionOutput.fromJson(jsonResponse.body);
}