createEnvironmentAccountConnection method

Future<CreateEnvironmentAccountConnectionOutput> createEnvironmentAccountConnection({
  1. required String environmentName,
  2. required String managementAccountId,
  3. String? clientToken,
  4. String? codebuildRoleArn,
  5. String? componentRoleArn,
  6. String? roleArn,
  7. List<Tag>? tags,
})

Create an environment account connection in an environment account so that environment infrastructure resources can be provisioned in the environment account from a management account.

An environment account connection is a secure bi-directional connection between a management account and an environment account that maintains authorization and permissions. For more information, see Environment account connections in the Proton User guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter environmentName : The name of the Proton environment that's created in the associated management account.

Parameter managementAccountId : The ID of the management account that accepts or rejects the environment account connection. You create and manage the Proton environment in this account. If the management account accepts the environment account connection, Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.

Parameter clientToken : When included, if two identical requests are made with the same client token, Proton returns the environment account connection that the first request created.

Parameter codebuildRoleArn : The Amazon Resource Name (ARN) of an IAM service role in the environment account. Proton uses this role to provision infrastructure resources using CodeBuild-based provisioning in the associated environment account.

Parameter componentRoleArn : The Amazon Resource Name (ARN) of the IAM service role that Proton uses when provisioning directly defined components in the associated environment account. It determines the scope of infrastructure that a component can provision in the account.

You must specify componentRoleArn to allow directly defined components to be associated with any environments running in this account.

For more information about components, see Proton components in the Proton User Guide.

Parameter roleArn : The Amazon Resource Name (ARN) of the IAM service role that's created in the environment account. Proton uses this role to provision infrastructure resources in the associated environment account.

Parameter tags : An optional list of metadata items that you can associate with the Proton environment account connection. A tag is a key-value pair.

For more information, see Proton resources and tagging in the Proton User Guide.

Implementation

Future<CreateEnvironmentAccountConnectionOutput>
    createEnvironmentAccountConnection({
  required String environmentName,
  required String managementAccountId,
  String? clientToken,
  String? codebuildRoleArn,
  String? componentRoleArn,
  String? roleArn,
  List<Tag>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.CreateEnvironmentAccountConnection'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'environmentName': environmentName,
      'managementAccountId': managementAccountId,
      'clientToken': clientToken ?? _s.generateIdempotencyToken(),
      if (codebuildRoleArn != null) 'codebuildRoleArn': codebuildRoleArn,
      if (componentRoleArn != null) 'componentRoleArn': componentRoleArn,
      if (roleArn != null) 'roleArn': roleArn,
      if (tags != null) 'tags': tags,
    },
  );

  return CreateEnvironmentAccountConnectionOutput.fromJson(jsonResponse.body);
}