deleteEnvironmentAccountConnection method

Future<DeleteEnvironmentAccountConnectionOutput> deleteEnvironmentAccountConnection({
  1. required String id,
})

In an environment account, delete an environment account connection.

After you delete an environment account connection that’s in use by an Proton environment, Proton can’t manage the environment infrastructure resources until a new environment account connection is accepted for the environment account and associated environment. You're responsible for cleaning up provisioned resources that remain without an environment connection.

For more information, see Environment account connections in the Proton User guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the environment account connection to delete.

Implementation

Future<DeleteEnvironmentAccountConnectionOutput>
    deleteEnvironmentAccountConnection({
  required String id,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.DeleteEnvironmentAccountConnection'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'id': id,
    },
  );

  return DeleteEnvironmentAccountConnectionOutput.fromJson(jsonResponse.body);
}