getEnvironmentAccountConnection method

Future<GetEnvironmentAccountConnectionOutput> getEnvironmentAccountConnection({
  1. required String id,
})

In an environment account, get the detailed data for an environment account connection.

For more information, see Environment account connections in the Proton User guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the environment account connection that you want to get the detailed data for.

Implementation

Future<GetEnvironmentAccountConnectionOutput>
    getEnvironmentAccountConnection({
  required String id,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.GetEnvironmentAccountConnection'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'id': id,
    },
  );

  return GetEnvironmentAccountConnectionOutput.fromJson(jsonResponse.body);
}