getServiceInstanceSyncStatus method

Future<GetServiceInstanceSyncStatusOutput> getServiceInstanceSyncStatus({
  1. required String serviceInstanceName,
  2. required String serviceName,
})

Get the status of the synced service instance.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceInstanceName : The name of the service instance that you want the sync status input for.

Parameter serviceName : The name of the service that the service instance belongs to.

Implementation

Future<GetServiceInstanceSyncStatusOutput> getServiceInstanceSyncStatus({
  required String serviceInstanceName,
  required String serviceName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.GetServiceInstanceSyncStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceInstanceName': serviceInstanceName,
      'serviceName': serviceName,
    },
  );

  return GetServiceInstanceSyncStatusOutput.fromJson(jsonResponse.body);
}