listComponentOutputs method
Get a list of component Infrastructure as Code (IaC) outputs.
For more information about components, see Proton components in the Proton User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter componentName :
The name of the component whose outputs you want.
Parameter deploymentId :
The ID of the deployment whose outputs you want.
Parameter nextToken :
A token that indicates the location of the next output in the array of
outputs, after the list of outputs that was previously requested.
Implementation
Future<ListComponentOutputsOutput> listComponentOutputs({
required String componentName,
String? deploymentId,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.ListComponentOutputs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'componentName': componentName,
if (deploymentId != null) 'deploymentId': deploymentId,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListComponentOutputsOutput.fromJson(jsonResponse.body);
}