listServiceInstanceOutputs method

Future<ListServiceInstanceOutputsOutput> listServiceInstanceOutputs({
  1. required String serviceInstanceName,
  2. required String serviceName,
  3. String? deploymentId,
  4. String? nextToken,
})

Get a list service of instance Infrastructure as Code (IaC) outputs.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceInstanceName : The name of the service instance whose outputs you want.

Parameter serviceName : The name of the service that serviceInstanceName is associated to.

Parameter deploymentId : The ID of the deployment whose outputs you want.

Parameter nextToken : A token that indicates the location of the next output in the array of outputs, after the list of outputs that was previously requested.

Implementation

Future<ListServiceInstanceOutputsOutput> listServiceInstanceOutputs({
  required String serviceInstanceName,
  required String serviceName,
  String? deploymentId,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.ListServiceInstanceOutputs'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceInstanceName': serviceInstanceName,
      'serviceName': serviceName,
      if (deploymentId != null) 'deploymentId': deploymentId,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListServiceInstanceOutputsOutput.fromJson(jsonResponse.body);
}