listServiceInstanceProvisionedResources method

Future<ListServiceInstanceProvisionedResourcesOutput> listServiceInstanceProvisionedResources({
  1. required String serviceInstanceName,
  2. required String serviceName,
  3. String? nextToken,
})

List provisioned resources for a service instance with details.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceInstanceName : The name of the service instance whose provisioned resources you want.

Parameter serviceName : The name of the service that serviceInstanceName is associated to.

Parameter nextToken : A token that indicates the location of the next provisioned resource in the array of provisioned resources, after the list of provisioned resources that was previously requested.

Implementation

Future<ListServiceInstanceProvisionedResourcesOutput>
    listServiceInstanceProvisionedResources({
  required String serviceInstanceName,
  required String serviceName,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'AwsProton20200720.ListServiceInstanceProvisionedResources'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceInstanceName': serviceInstanceName,
      'serviceName': serviceName,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListServiceInstanceProvisionedResourcesOutput.fromJson(
      jsonResponse.body);
}