listServicePipelineOutputs method

Future<ListServicePipelineOutputsOutput> listServicePipelineOutputs({
  1. required String serviceName,
  2. String? deploymentId,
  3. String? nextToken,
})

Get a list of service pipeline Infrastructure as Code (IaC) outputs.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceName : The name of the service whose pipeline's outputs you want.

Parameter deploymentId : The ID of the deployment you want the outputs for.

Parameter nextToken : A token that indicates the location of the next output in the array of outputs, after the list of outputs that was previously requested.

Implementation

Future<ListServicePipelineOutputsOutput> listServicePipelineOutputs({
  required String serviceName,
  String? deploymentId,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AwsProton20200720.ListServicePipelineOutputs'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'serviceName': serviceName,
      if (deploymentId != null) 'deploymentId': deploymentId,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListServicePipelineOutputsOutput.fromJson(jsonResponse.body);
}