listServicePipelineProvisionedResources method
List provisioned resources for a service and pipeline with details.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter serviceName :
The name of the service whose pipeline's provisioned resources you want.
Parameter nextToken :
A token that indicates the location of the next provisioned resource in
the array of provisioned resources, after the list of provisioned
resources that was previously requested.
Implementation
Future<ListServicePipelineProvisionedResourcesOutput>
listServicePipelineProvisionedResources({
required String serviceName,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'AwsProton20200720.ListServicePipelineProvisionedResources'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'serviceName': serviceName,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListServicePipelineProvisionedResourcesOutput.fromJson(
jsonResponse.body);
}