proton_2020_07_20 library

Classes

AwsClientCredentials
AWS credentials.
Proton
This is the Proton Service API Reference. It provides descriptions, syntax and usage examples for each of the actions and data types for the Proton service.