QApps class
The Amazon Q Apps feature capability within Amazon Q Business allows web experience users to create lightweight, purpose-built AI apps to fulfill specific tasks from within their web experience. For example, users can create a Q App that exclusively generates marketing-related content to improve your marketing team's productivity or a Q App for writing customer emails and creating promotional content using a certain style of voice, tone, and branding. For more information on the capabilities, see Amazon Q Apps capabilities in the Amazon Q Business User Guide.
For an overview of the Amazon Q App APIs, see Overview of Amazon Q Apps API operations.
For information about the IAM access control permissions you need to use the Amazon Q Apps API, see IAM role for the Amazon Q Business web experience including Amazon Q Apps in the Amazon Q Business User Guide.
Constructors
- QApps({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateLibraryItemReview(
{required String instanceId, required String libraryItemId}) → Future< void> - Associates a rating or review for a library item with the user submitting the request. This increments the rating count for the specified library item.
-
associateQAppWithUser(
{required String appId, required String instanceId}) → Future< void> - This operation creates a link between the user's identity calling the operation and a specific Q App. This is useful to mark the Q App as a favorite for the user if the user doesn't own the Amazon Q App so they can still run it and see it in their inventory of Q Apps.
-
batchCreateCategory(
{required List< BatchCreateCategoryInputCategory> categories, required String instanceId}) → Future<void> - Creates Categories for the Amazon Q Business application environment instance. Web experience users use Categories to tag and filter library items. For more information, see Custom labels for Amazon Q Apps.
-
batchDeleteCategory(
{required List< String> categories, required String instanceId}) → Future<void> - Deletes Categories for the Amazon Q Business application environment instance. Web experience users use Categories to tag and filter library items. For more information, see Custom labels for Amazon Q Apps.
-
batchUpdateCategory(
{required List< CategoryInput> categories, required String instanceId}) → Future<void> - Updates Categories for the Amazon Q Business application environment instance. Web experience users use Categories to tag and filter library items. For more information, see Custom labels for Amazon Q Apps.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createLibraryItem(
{required String appId, required int appVersion, required List< String> categories, required String instanceId}) → Future<CreateLibraryItemOutput> - Creates a new library item for an Amazon Q App, allowing it to be discovered and used by other allowed users.
-
createPresignedUrl(
{required String appId, required String cardId, required String fileContentsSha256, required String fileName, required String instanceId, required DocumentScope scope, String? sessionId}) → Future< CreatePresignedUrlOutput> -
Creates a presigned URL for an S3 POST operation to upload a file. You can
use this URL to set a default file for a
FileUploadCardin a Q App definition or to provide a file for a single Q App run. Thescopeparameter determines how the file will be used, either at the app definition level or the app session level. -
createQApp(
{required AppDefinitionInput appDefinition, required String instanceId, required String title, String? description, Map< String, String> ? tags}) → Future<CreateQAppOutput> - Creates a new Amazon Q App based on the provided definition. The Q App definition specifies the cards and flow of the Q App. This operation also calculates the dependencies between the cards by inspecting the references in the prompts.
-
deleteLibraryItem(
{required String instanceId, required String libraryItemId}) → Future< void> - Deletes a library item for an Amazon Q App, removing it from the library so it can no longer be discovered or used by other users.
-
deleteQApp(
{required String appId, required String instanceId}) → Future< void> - Deletes an Amazon Q App owned by the user. If the Q App was previously published to the library, it is also removed from the library.
-
describeQAppPermissions(
{required String appId, required String instanceId}) → Future< DescribeQAppPermissionsOutput> - Describes read permissions for a Amazon Q App in Amazon Q Business application environment instance.
-
disassociateLibraryItemReview(
{required String instanceId, required String libraryItemId}) → Future< void> - Removes a rating or review previously submitted by the user for a library item.
-
disassociateQAppFromUser(
{required String appId, required String instanceId}) → Future< void> - Disassociates a Q App from a user removing the user's access to run the Q App.
-
exportQAppSessionData(
{required String instanceId, required String sessionId}) → Future< ExportQAppSessionDataOutput> - Exports the collected data of a Q App data collection session.
-
getLibraryItem(
{required String instanceId, required String libraryItemId, String? appId}) → Future< GetLibraryItemOutput> - Retrieves details about a library item for an Amazon Q App, including its metadata, categories, ratings, and usage statistics.
-
getQApp(
{required String appId, required String instanceId, int? appVersion}) → Future< GetQAppOutput> - Retrieves the full details of an Q App, including its definition specifying the cards and flow.
-
getQAppSession(
{required String instanceId, required String sessionId}) → Future< GetQAppSessionOutput> - Retrieves the current state and results for an active session of an Amazon Q App.
-
getQAppSessionMetadata(
{required String instanceId, required String sessionId}) → Future< GetQAppSessionMetadataOutput> - Retrieves the current configuration of a Q App session.
-
importDocument(
{required String appId, required String cardId, required String fileContentsBase64, required String fileName, required String instanceId, required DocumentScope scope, String? sessionId}) → Future< ImportDocumentOutput> -
Uploads a file that can then be used either as a default in a
FileUploadCardfrom Q App definition or as a file that is used inside a single Q App run. The purpose of the document is determined by a scope parameter that indicates whether it is at the app definition level or at the app session level. -
listCategories(
{required String instanceId}) → Future< ListCategoriesOutput> - Lists the categories of a Amazon Q Business application environment instance. For more information, see Custom labels for Amazon Q Apps.
-
listLibraryItems(
{required String instanceId, String? categoryId, int? limit, String? nextToken}) → Future< ListLibraryItemsOutput> - Lists the library items for Amazon Q Apps that are published and available for users in your Amazon Web Services account.
-
listQApps(
{required String instanceId, int? limit, String? nextToken}) → Future< ListQAppsOutput> - Lists the Amazon Q Apps owned by or associated with the user either because they created it or because they used it from the library in the past. The user identity is extracted from the credentials used to invoke this operation..
-
listQAppSessionData(
{required String instanceId, required String sessionId}) → Future< ListQAppSessionDataOutput> - Lists the collected data of a Q App data collection session.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Lists the tags associated with an Amazon Q Apps resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
predictQApp(
{required String instanceId, PredictQAppInputOptions? options}) → Future< PredictQAppOutput> -
Generates an Amazon Q App definition based on either a conversation or a
problem statement provided as input.The resulting app definition can be
used to call
CreateQApp. This API doesn't create Amazon Q Apps directly. -
startQAppSession(
{required String appId, required int appVersion, required String instanceId, List< CardValue> ? initialValues, String? sessionId, Map<String, String> ? tags}) → Future<StartQAppSessionOutput> - Starts a new session for an Amazon Q App, allowing inputs to be provided and the app to be run.
-
stopQAppSession(
{required String instanceId, required String sessionId}) → Future< void> - Stops an active session for an Amazon Q App.This deletes all data related to the session and makes it invalid for future uses. The results of the session will be persisted as part of the conversation.
-
tagResource(
{required String resourceARN, required Map< String, String> tags}) → Future<void> - Associates tags with an Amazon Q Apps resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Disassociates tags from an Amazon Q Apps resource.
-
updateLibraryItem(
{required String instanceId, required String libraryItemId, List< String> ? categories, LibraryItemStatus? status}) → Future<UpdateLibraryItemOutput> - Updates the library item for an Amazon Q App.
-
updateLibraryItemMetadata(
{required String instanceId, required String libraryItemId, bool? isVerified}) → Future< void> - Updates the verification status of a library item for an Amazon Q App.
-
updateQApp(
{required String appId, required String instanceId, AppDefinitionInput? appDefinition, String? description, String? title}) → Future< UpdateQAppOutput> - Updates an existing Amazon Q App, allowing modifications to its title, description, and definition.
-
updateQAppPermissions(
{required String appId, required String instanceId, List< PermissionInput> ? grantPermissions, List<PermissionInput> ? revokePermissions}) → Future<UpdateQAppPermissionsOutput> - Updates read permissions for a Amazon Q App in Amazon Q Business application environment instance.
-
updateQAppSession(
{required String instanceId, required String sessionId, List< CardValue> ? values}) → Future<UpdateQAppSessionOutput> -
Updates the session for a given Q App
sessionId. This is only valid when at least one card of the session is in theWAITINGstate. Data for eachWAITINGcard can be provided as input. If inputs are not provided, the call will be accepted but session will not move forward. Inputs for cards that are not in theWAITINGstatus will be ignored. -
updateQAppSessionMetadata(
{required String instanceId, required String sessionId, required SessionSharingConfiguration sharingConfiguration, String? sessionName}) → Future< UpdateQAppSessionMetadataOutput> -
Updates the configuration metadata of a session for a given Q App
sessionId.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited