associateLibraryItemReview method
Associates a rating or review for a library item with the user submitting the request. This increments the rating count for the specified library item.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier for the Amazon Q Business application environment
instance.
Parameter libraryItemId :
The unique identifier of the library item to associate the review with.
Implementation
Future<void> associateLibraryItemReview({
required String instanceId,
required String libraryItemId,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'libraryItemId': libraryItemId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/catalog.associateItemRating',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}