batchDeleteCategory method
Deletes Categories for the Amazon Q Business application environment instance. Web experience users use Categories to tag and filter library items. For more information, see Custom labels for Amazon Q Apps.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter categories :
The list of IDs of the categories to be deleted.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Implementation
Future<void> batchDeleteCategory({
required List<String> categories,
required String instanceId,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'categories': categories,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/catalog.deleteCategories',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}