deleteQApp method

Future<void> deleteQApp({
  1. required String appId,
  2. required String instanceId,
})

Deletes an Amazon Q App owned by the user. If the Q App was previously published to the library, it is also removed from the library.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter appId : The unique identifier of the Q App to delete.

Parameter instanceId : The unique identifier of the Amazon Q Business application environment instance.

Implementation

Future<void> deleteQApp({
  required String appId,
  required String instanceId,
}) async {
  final headers = <String, String>{
    'instance-id': instanceId.toString(),
  };
  final $payload = <String, dynamic>{
    'appId': appId,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/apps.delete',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}