disassociateQAppFromUser method

Future<void> disassociateQAppFromUser({
  1. required String appId,
  2. required String instanceId,
})

Disassociates a Q App from a user removing the user's access to run the Q App.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter appId : The unique identifier of the Q App to disassociate from the user.

Parameter instanceId : The unique identifier of the Amazon Q Business application environment instance.

Implementation

Future<void> disassociateQAppFromUser({
  required String appId,
  required String instanceId,
}) async {
  final headers = <String, String>{
    'instance-id': instanceId.toString(),
  };
  final $payload = <String, dynamic>{
    'appId': appId,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/apps.uninstall',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}