getQApp method

Future<GetQAppOutput> getQApp({
  1. required String appId,
  2. required String instanceId,
  3. int? appVersion,
})

Retrieves the full details of an Q App, including its definition specifying the cards and flow.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter appId : The unique identifier of the Q App to retrieve.

Parameter instanceId : The unique identifier of the Amazon Q Business application environment instance.

Parameter appVersion : The version of the Q App.

Implementation

Future<GetQAppOutput> getQApp({
  required String appId,
  required String instanceId,
  int? appVersion,
}) async {
  _s.validateNumRange(
    'appVersion',
    appVersion,
    0,
    2147483647,
  );
  final headers = <String, String>{
    'instance-id': instanceId.toString(),
  };
  final $query = <String, List<String>>{
    'appId': [appId],
    if (appVersion != null) 'appVersion': [appVersion.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/apps.get',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return GetQAppOutput.fromJson(response);
}