getQAppSession method

Future<GetQAppSessionOutput> getQAppSession({
  1. required String instanceId,
  2. required String sessionId,
})

Retrieves the current state and results for an active session of an Amazon Q App.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter instanceId : The unique identifier of the Amazon Q Business application environment instance.

Parameter sessionId : The unique identifier of the Q App session to retrieve.

Implementation

Future<GetQAppSessionOutput> getQAppSession({
  required String instanceId,
  required String sessionId,
}) async {
  final headers = <String, String>{
    'instance-id': instanceId.toString(),
  };
  final $query = <String, List<String>>{
    'sessionId': [sessionId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/runtime.getQAppSession',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return GetQAppSessionOutput.fromJson(response);
}