listQApps method
Lists the Amazon Q Apps owned by or associated with the user either because they created it or because they used it from the library in the past. The user identity is extracted from the credentials used to invoke this operation..
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Parameter limit :
The maximum number of Q Apps to return in the response.
Parameter nextToken :
The token to request the next page of results.
Implementation
Future<ListQAppsOutput> listQApps({
required String instanceId,
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $query = <String, List<String>>{
if (limit != null) 'limit': [limit.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/apps.list',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListQAppsOutput.fromJson(response);
}