updateQAppSession method

Future<UpdateQAppSessionOutput> updateQAppSession({
  1. required String instanceId,
  2. required String sessionId,
  3. List<CardValue>? values,
})

Updates the session for a given Q App sessionId. This is only valid when at least one card of the session is in the WAITING state. Data for each WAITING card can be provided as input. If inputs are not provided, the call will be accepted but session will not move forward. Inputs for cards that are not in the WAITING status will be ignored.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter instanceId : The unique identifier of the Amazon Q Business application environment instance.

Parameter sessionId : The unique identifier of the Q App session to provide input for.

Parameter values : The input values to provide for the current state of the Q App session.

Implementation

Future<UpdateQAppSessionOutput> updateQAppSession({
  required String instanceId,
  required String sessionId,
  List<CardValue>? values,
}) async {
  final headers = <String, String>{
    'instance-id': instanceId.toString(),
  };
  final $payload = <String, dynamic>{
    'sessionId': sessionId,
    if (values != null) 'values': values,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/runtime.updateQAppSession',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateQAppSessionOutput.fromJson(response);
}