deleteConversation method
Deletes an Amazon Q Business web experience conversation.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw LicenseNotFoundException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application associated with the
conversation.
Parameter conversationId :
The identifier of the Amazon Q Business web experience conversation being
deleted.
Parameter userId :
The identifier of the user who is deleting the conversation.
Implementation
Future<void> deleteConversation({
required String applicationId,
required String conversationId,
String? userId,
}) async {
final $query = <String, List<String>>{
if (userId != null) 'userId': [userId],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/conversations/${Uri.encodeComponent(conversationId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}