deleteRetriever method

Future<void> deleteRetriever({
  1. required String applicationId,
  2. required String retrieverId,
})

Deletes the retriever used by an Amazon Q Business application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the Amazon Q Business application using the retriever.

Parameter retrieverId : The identifier of the retriever being deleted.

Implementation

Future<void> deleteRetriever({
  required String applicationId,
  required String retrieverId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/retrievers/${Uri.encodeComponent(retrieverId)}',
    exceptionFnMap: _exceptionFns,
  );
}