deleteWebExperience method

Future<void> deleteWebExperience({
  1. required String applicationId,
  2. required String webExperienceId,
})

Deletes an Amazon Q Business web experience.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the Amazon Q Business application linked to the Amazon Q Business web experience.

Parameter webExperienceId : The identifier of the Amazon Q Business web experience being deleted.

Implementation

Future<void> deleteWebExperience({
  required String applicationId,
  required String webExperienceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/experiences/${Uri.encodeComponent(webExperienceId)}',
    exceptionFnMap: _exceptionFns,
  );
}