getChatResponseConfiguration method

Future<GetChatResponseConfigurationResponse> getChatResponseConfiguration({
  1. required String applicationId,
  2. required String chatResponseConfigurationId,
})

Retrieves detailed information about a specific chat response configuration from an Amazon Q Business application. This operation returns the complete configuration settings and metadata.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The unique identifier of the Amazon Q Business application containing the chat response configuration to retrieve.

Parameter chatResponseConfigurationId : The unique identifier of the chat response configuration to retrieve from the specified application.

Implementation

Future<GetChatResponseConfigurationResponse> getChatResponseConfiguration({
  required String applicationId,
  required String chatResponseConfigurationId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/chatresponseconfigurations/${Uri.encodeComponent(chatResponseConfigurationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetChatResponseConfigurationResponse.fromJson(response);
}