getGroup method

Future<GetGroupResponse> getGroup({
  1. required String applicationId,
  2. required String groupName,
  3. required String indexId,
  4. String? dataSourceId,
})

Describes a group by group name.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the application id the group is attached to.

Parameter groupName : The name of the group.

Parameter indexId : The identifier of the index the group is attached to.

Parameter dataSourceId : The identifier of the data source the group is attached to.

Implementation

Future<GetGroupResponse> getGroup({
  required String applicationId,
  required String groupName,
  required String indexId,
  String? dataSourceId,
}) async {
  final $query = <String, List<String>>{
    if (dataSourceId != null) 'dataSourceId': [dataSourceId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}/groups/${Uri.encodeComponent(groupName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetGroupResponse.fromJson(response);
}