getRetriever method

Future<GetRetrieverResponse> getRetriever({
  1. required String applicationId,
  2. required String retrieverId,
})

Gets information about an existing retriever used by an Amazon Q Business application.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the Amazon Q Business application using the retriever.

Parameter retrieverId : The identifier of the retriever.

Implementation

Future<GetRetrieverResponse> getRetriever({
  required String applicationId,
  required String retrieverId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/retrievers/${Uri.encodeComponent(retrieverId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRetrieverResponse.fromJson(response);
}