listApplications method

Future<ListApplicationsResponse> listApplications({
  1. int? maxResults,
  2. String? nextToken,
})

Lists Amazon Q Business applications.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of Amazon Q Business applications to return.

Parameter nextToken : If the maxResults response was incomplete because there is more data to retrieve, Amazon Q Business returns a pagination token in the response. You can use this pagination token to retrieve the next set of Amazon Q Business applications.

Implementation

Future<ListApplicationsResponse> listApplications({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListApplicationsResponse.fromJson(response);
}