listPluginActions method

Future<ListPluginActionsResponse> listPluginActions({
  1. required String applicationId,
  2. required String pluginId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists configured Amazon Q Business actions for a specific plugin in an Amazon Q Business application.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the Amazon Q Business application the plugin is attached to.

Parameter pluginId : The identifier of the Amazon Q Business plugin.

Parameter maxResults : The maximum number of plugin actions to return.

Parameter nextToken : If the number of plugin actions returned exceeds maxResults, Amazon Q Business returns a next token as a pagination token to retrieve the next set of plugin actions.

Implementation

Future<ListPluginActionsResponse> listPluginActions({
  required String applicationId,
  required String pluginId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/plugins/${Uri.encodeComponent(pluginId)}/actions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListPluginActionsResponse.fromJson(response);
}