listSubscriptions method
Lists all subscriptions created in an Amazon Q Business application.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application linked to the
subscription.
Parameter maxResults :
The maximum number of Amazon Q Business subscriptions to return.
Parameter nextToken :
If the maxResults response was incomplete because there is
more data to retrieve, Amazon Q Business returns a pagination token in the
response. You can use this pagination token to retrieve the next set of
Amazon Q Business subscriptions.
Implementation
Future<ListSubscriptionsResponse> listSubscriptions({
required String applicationId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/subscriptions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSubscriptionsResponse.fromJson(response);
}