listWebExperiences method

Future<ListWebExperiencesResponse> listWebExperiences({
  1. required String applicationId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists one or more Amazon Q Business Web Experiences.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of the Amazon Q Business application linked to the listed web experiences.

Parameter maxResults : The maximum number of Amazon Q Business Web Experiences to return.

Parameter nextToken : If the maxResults response was incomplete because there is more data to retrieve, Amazon Q Business returns a pagination token in the response. You can use this pagination token to retrieve the next set of Amazon Q Business conversations.

Implementation

Future<ListWebExperiencesResponse> listWebExperiences({
  required String applicationId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/experiences',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListWebExperiencesResponse.fromJson(response);
}