startDataSourceSyncJob method

Future<StartDataSourceSyncJobResponse> startDataSourceSyncJob({
  1. required String applicationId,
  2. required String dataSourceId,
  3. required String indexId,
})

Starts a data source connector synchronization job. If a synchronization job is already in progress, Amazon Q Business returns a ConflictException.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationId : The identifier of Amazon Q Business application the data source is connected to.

Parameter dataSourceId : The identifier of the data source connector.

Parameter indexId : The identifier of the index used with the data source connector.

Implementation

Future<StartDataSourceSyncJobResponse> startDataSourceSyncJob({
  required String applicationId,
  required String dataSourceId,
  required String indexId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}/datasources/${Uri.encodeComponent(dataSourceId)}/startsync',
    exceptionFnMap: _exceptionFns,
  );
  return StartDataSourceSyncJobResponse.fromJson(response);
}