QConnect class
Amazon Q in Connect is a generative AI customer service assistant. It is an
LLM-enhanced evolution of Amazon Connect Wisdom that delivers real-time
recommendations to help contact center agents resolve customer issues
quickly and accurately.
Amazon Q in Connect automatically detects customer intent during calls and chats using conversational analytics and natural language understanding (NLU). It then provides agents with immediate, real-time generative responses and suggested actions, and links to relevant documents and articles. Agents can also query Amazon Q in Connect directly using natural language or keywords to answer customer requests.
Use the Amazon Q in Connect APIs to create an assistant and a knowledge base, for example, or manage content by uploading custom files.
For more information, see Use Amazon Q in Connect for generative AI powered agent assistance in real-time in the Amazon Connect Administrator Guide.
Constructors
- QConnect({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateMessageTemplate(
{required String knowledgeBaseId, required String messageTemplateId, required int versionNumber}) → Future< ActivateMessageTemplateResponse> -
Activates a specific version of the Amazon Q in Connect message template.
After the version is activated, the previous active version will be
deactivated automatically. You can use the
$ACTIVE_VERSIONqualifier later to reference the version that is in active status. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAIAgent(
{required String assistantId, required AIAgentConfiguration configuration, required String name, required AIAgentType type, required VisibilityStatus visibilityStatus, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateAIAgentResponse> - Creates an Amazon Q in Connect AI Agent.
-
createAIAgentVersion(
{required String aiAgentId, required String assistantId, String? clientToken, DateTime? modifiedTime}) → Future< CreateAIAgentVersionResponse> - Creates and Amazon Q in Connect AI Agent version.
-
createAIGuardrail(
{required String assistantId, required String blockedInputMessaging, required String blockedOutputsMessaging, required String name, required VisibilityStatus visibilityStatus, String? clientToken, AIGuardrailContentPolicyConfig? contentPolicyConfig, AIGuardrailContextualGroundingPolicyConfig? contextualGroundingPolicyConfig, String? description, AIGuardrailSensitiveInformationPolicyConfig? sensitiveInformationPolicyConfig, Map< String, String> ? tags, AIGuardrailTopicPolicyConfig? topicPolicyConfig, AIGuardrailWordPolicyConfig? wordPolicyConfig}) → Future<CreateAIGuardrailResponse> - Creates an Amazon Q in Connect AI Guardrail.
-
createAIGuardrailVersion(
{required String aiGuardrailId, required String assistantId, String? clientToken, DateTime? modifiedTime}) → Future< CreateAIGuardrailVersionResponse> - Creates an Amazon Q in Connect AI Guardrail version.
-
createAIPrompt(
{required AIPromptAPIFormat apiFormat, required String assistantId, required String modelId, required String name, required AIPromptTemplateConfiguration templateConfiguration, required AIPromptTemplateType templateType, required AIPromptType type, required VisibilityStatus visibilityStatus, String? clientToken, String? description, AIPromptInferenceConfiguration? inferenceConfiguration, Map< String, String> ? tags}) → Future<CreateAIPromptResponse> - Creates an Amazon Q in Connect AI Prompt.
-
createAIPromptVersion(
{required String aiPromptId, required String assistantId, String? clientToken, DateTime? modifiedTime}) → Future< CreateAIPromptVersionResponse> - Creates an Amazon Q in Connect AI Prompt version.
-
createAssistant(
{required String name, required AssistantType type, String? clientToken, String? description, ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration, Map< String, String> ? tags}) → Future<CreateAssistantResponse> - Creates an Amazon Q in Connect assistant.
-
createAssistantAssociation(
{required String assistantId, required AssistantAssociationInputData association, required AssociationType associationType, String? clientToken, Map< String, String> ? tags}) → Future<CreateAssistantAssociationResponse> - Creates an association between an Amazon Q in Connect assistant and another resource. Currently, the only supported association is with a knowledge base. An assistant can have only a single association.
-
createContent(
{required String knowledgeBaseId, required String name, required String uploadId, String? clientToken, Map< String, String> ? metadata, String? overrideLinkOutUri, Map<String, String> ? tags, String? title}) → Future<CreateContentResponse> - Creates Amazon Q in Connect content. Before to calling this API, use StartContentUpload to upload an asset.
-
createContentAssociation(
{required ContentAssociationContents association, required ContentAssociationType associationType, required String contentId, required String knowledgeBaseId, String? clientToken, Map< String, String> ? tags}) → Future<CreateContentAssociationResponse> - Creates an association between a content resource in a knowledge base and step-by-step guides. Step-by-step guides offer instructions to agents for resolving common customer issues. You create a content association to integrate Amazon Q in Connect and step-by-step guides.
-
createKnowledgeBase(
{required KnowledgeBaseType knowledgeBaseType, required String name, String? clientToken, String? description, RenderingConfiguration? renderingConfiguration, ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration, SourceConfiguration? sourceConfiguration, Map< String, String> ? tags, VectorIngestionConfiguration? vectorIngestionConfiguration}) → Future<CreateKnowledgeBaseResponse> - Creates a knowledge base.
-
createMessageTemplate(
{required ChannelSubtype channelSubtype, required String knowledgeBaseId, String? clientToken, MessageTemplateContentProvider? content, MessageTemplateAttributes? defaultAttributes, String? description, GroupingConfiguration? groupingConfiguration, String? language, String? name, MessageTemplateSourceConfiguration? sourceConfiguration, Map< String, String> ? tags}) → Future<CreateMessageTemplateResponse> -
Creates an Amazon Q in Connect message template. The name of the message
template has to be unique for each knowledge base. The channel subtype of
the message template is immutable and cannot be modified after creation.
After the message template is created, you can use the
$LATESTqualifier to reference the created message template. -
createMessageTemplateAttachment(
{required String body, required ContentDisposition contentDisposition, required String knowledgeBaseId, required String messageTemplateId, required String name, String? clientToken}) → Future< CreateMessageTemplateAttachmentResponse> -
Uploads an attachment file to the specified Amazon Q in Connect message
template. The name of the message template attachment has to be unique for
each message template referenced by the
$LATESTqualifier. The body of the attachment file should be encoded using base64 encoding. After the file is uploaded, you can use the pre-signed Amazon S3 URL returned in response to download the uploaded file. -
createMessageTemplateVersion(
{required String knowledgeBaseId, required String messageTemplateId, String? messageTemplateContentSha256}) → Future< CreateMessageTemplateVersionResponse> -
Creates a new Amazon Q in Connect message template version from the
current content and configuration of a message template. Versions are
immutable and monotonically increasing. Once a version is created, you can
reference a specific version of the message template by passing in
<message-template-id>:<versionNumber>as the message template identifier. An error is displayed if the suppliedmessageTemplateContentSha256is different from themessageTemplateContentSha256of the message template with$LATESTqualifier. If multipleCreateMessageTemplateVersionrequests are made while the message template remains the same, only the first invocation creates a new version and the succeeding requests will return the same response as the first invocation. -
createQuickResponse(
{required QuickResponseDataProvider content, required String knowledgeBaseId, required String name, List< String> ? channels, String? clientToken, String? contentType, String? description, GroupingConfiguration? groupingConfiguration, bool? isActive, String? language, String? shortcutKey, Map<String, String> ? tags}) → Future<CreateQuickResponseResponse> - Creates an Amazon Q in Connect quick response.
-
createSession(
{required String assistantId, required String name, Map< AIAgentType, AIAgentConfigurationData> ? aiAgentConfiguration, String? clientToken, String? contactArn, String? description, List<OrchestratorConfigurationEntry> ? orchestratorConfigurationList, bool? removeOrchestratorConfigurationList, TagFilter? tagFilter, Map<String, String> ? tags}) → Future<CreateSessionResponse> - Creates a session. A session is a contextual container used for generating recommendations. Amazon Connect creates a new Amazon Q in Connect session for each contact on which Amazon Q in Connect is enabled.
-
deactivateMessageTemplate(
{required String knowledgeBaseId, required String messageTemplateId, required int versionNumber}) → Future< DeactivateMessageTemplateResponse> -
Deactivates a specific version of the Amazon Q in Connect message template
. After the version is deactivated, you can no longer use the
$ACTIVE_VERSIONqualifier to reference the version in active status. -
deleteAIAgent(
{required String aiAgentId, required String assistantId}) → Future< void> - Deletes an Amazon Q in Connect AI Agent.
-
deleteAIAgentVersion(
{required String aiAgentId, required String assistantId, required int versionNumber}) → Future< void> - Deletes an Amazon Q in Connect AI Agent Version.
-
deleteAIGuardrail(
{required String aiGuardrailId, required String assistantId}) → Future< void> - Deletes an Amazon Q in Connect AI Guardrail.
-
deleteAIGuardrailVersion(
{required String aiGuardrailId, required String assistantId, required int versionNumber}) → Future< void> - Delete and Amazon Q in Connect AI Guardrail version.
-
deleteAIPrompt(
{required String aiPromptId, required String assistantId}) → Future< void> - Deletes an Amazon Q in Connect AI Prompt.
-
deleteAIPromptVersion(
{required String aiPromptId, required String assistantId, required int versionNumber}) → Future< void> - Delete and Amazon Q in Connect AI Prompt version.
-
deleteAssistant(
{required String assistantId}) → Future< void> - Deletes an assistant.
-
deleteAssistantAssociation(
{required String assistantAssociationId, required String assistantId}) → Future< void> - Deletes an assistant association.
-
deleteContent(
{required String contentId, required String knowledgeBaseId}) → Future< void> - Deletes the content.
-
deleteContentAssociation(
{required String contentAssociationId, required String contentId, required String knowledgeBaseId}) → Future< void> - Deletes the content association.
-
deleteImportJob(
{required String importJobId, required String knowledgeBaseId}) → Future< void> - Deletes the quick response import job.
-
deleteKnowledgeBase(
{required String knowledgeBaseId}) → Future< void> - Deletes the knowledge base.
-
deleteMessageTemplate(
{required String knowledgeBaseId, required String messageTemplateId}) → Future< void> -
Deletes an Amazon Q in Connect message template entirely or a specific
version of the message template if version is supplied in the request. You
can provide the message template identifier as
<message-template-id>:<versionNumber>to delete a specific version of the message template. If it is not supplied, the message template and all available versions will be deleted. -
deleteMessageTemplateAttachment(
{required String attachmentId, required String knowledgeBaseId, required String messageTemplateId}) → Future< void> -
Deletes the attachment file from the Amazon Q in Connect message template
that is referenced by
$LATESTqualifier. Attachments on available message template versions will remain unchanged. -
deleteQuickResponse(
{required String knowledgeBaseId, required String quickResponseId}) → Future< void> - Deletes a quick response.
-
getAIAgent(
{required String aiAgentId, required String assistantId}) → Future< GetAIAgentResponse> - Gets an Amazon Q in Connect AI Agent.
-
getAIGuardrail(
{required String aiGuardrailId, required String assistantId}) → Future< GetAIGuardrailResponse> - Gets the Amazon Q in Connect AI Guardrail.
-
getAIPrompt(
{required String aiPromptId, required String assistantId}) → Future< GetAIPromptResponse> - Gets and Amazon Q in Connect AI Prompt.
-
getAssistant(
{required String assistantId}) → Future< GetAssistantResponse> - Retrieves information about an assistant.
-
getAssistantAssociation(
{required String assistantAssociationId, required String assistantId}) → Future< GetAssistantAssociationResponse> - Retrieves information about an assistant association.
-
getContent(
{required String contentId, required String knowledgeBaseId}) → Future< GetContentResponse> - Retrieves content, including a pre-signed URL to download the content.
-
getContentAssociation(
{required String contentAssociationId, required String contentId, required String knowledgeBaseId}) → Future< GetContentAssociationResponse> - Returns the content association.
-
getContentSummary(
{required String contentId, required String knowledgeBaseId}) → Future< GetContentSummaryResponse> - Retrieves summary information about the content.
-
getImportJob(
{required String importJobId, required String knowledgeBaseId}) → Future< GetImportJobResponse> - Retrieves the started import job.
-
getKnowledgeBase(
{required String knowledgeBaseId}) → Future< GetKnowledgeBaseResponse> - Retrieves information about the knowledge base.
-
getMessageTemplate(
{required String knowledgeBaseId, required String messageTemplateId}) → Future< GetMessageTemplateResponse> -
Retrieves the Amazon Q in Connect message template. The message template
identifier can contain an optional qualifier, for example,
<message-template-id>:<qualifier>, which is either an actual version number or an Amazon Q Connect managed qualifier$ACTIVE_VERSION|$LATEST. If it is not supplied, then$LATESTis assumed implicitly. -
getNextMessage(
{required String assistantId, required String nextMessageToken, required String sessionId}) → Future< GetNextMessageResponse> - Retrieves next message on an Amazon Q in Connect session.
-
getQuickResponse(
{required String knowledgeBaseId, required String quickResponseId}) → Future< GetQuickResponseResponse> - Retrieves the quick response.
-
getRecommendations(
{required String assistantId, required String sessionId, int? maxResults, String? nextChunkToken, RecommendationType? recommendationType, int? waitTimeSeconds}) → Future< GetRecommendationsResponse> - NotifyRecommendationsReceived
-
getSession(
{required String assistantId, required String sessionId}) → Future< GetSessionResponse> - Retrieves information for a specified session.
-
listAIAgents(
{required String assistantId, int? maxResults, String? nextToken, Origin? origin}) → Future< ListAIAgentsResponse> - Lists AI Agents.
-
listAIAgentVersions(
{required String aiAgentId, required String assistantId, int? maxResults, String? nextToken, Origin? origin}) → Future< ListAIAgentVersionsResponse> - List AI Agent versions.
-
listAIGuardrails(
{required String assistantId, int? maxResults, String? nextToken}) → Future< ListAIGuardrailsResponse> - Lists the AI Guardrails available on the Amazon Q in Connect assistant.
-
listAIGuardrailVersions(
{required String aiGuardrailId, required String assistantId, int? maxResults, String? nextToken}) → Future< ListAIGuardrailVersionsResponse> - Lists AI Guardrail versions.
-
listAIPrompts(
{required String assistantId, int? maxResults, String? nextToken, Origin? origin}) → Future< ListAIPromptsResponse> - Lists the AI Prompts available on the Amazon Q in Connect assistant.
-
listAIPromptVersions(
{required String aiPromptId, required String assistantId, int? maxResults, String? nextToken, Origin? origin}) → Future< ListAIPromptVersionsResponse> - Lists AI Prompt versions.
-
listAssistantAssociations(
{required String assistantId, int? maxResults, String? nextToken}) → Future< ListAssistantAssociationsResponse> - Lists information about assistant associations.
-
listAssistants(
{int? maxResults, String? nextToken}) → Future< ListAssistantsResponse> - Lists information about assistants.
-
listContentAssociations(
{required String contentId, required String knowledgeBaseId, int? maxResults, String? nextToken}) → Future< ListContentAssociationsResponse> - Lists the content associations.
-
listContents(
{required String knowledgeBaseId, int? maxResults, String? nextToken}) → Future< ListContentsResponse> - Lists the content.
-
listImportJobs(
{required String knowledgeBaseId, int? maxResults, String? nextToken}) → Future< ListImportJobsResponse> - Lists information about import jobs.
-
listKnowledgeBases(
{int? maxResults, String? nextToken}) → Future< ListKnowledgeBasesResponse> - Lists the knowledge bases.
-
listMessages(
{required String assistantId, required String sessionId, MessageFilterType? filter, int? maxResults, String? nextToken}) → Future< ListMessagesResponse> - Lists messages on an Amazon Q in Connect session.
-
listMessageTemplates(
{required String knowledgeBaseId, int? maxResults, String? nextToken}) → Future< ListMessageTemplatesResponse> - Lists all the available Amazon Q in Connect message templates for the specified knowledge base.
-
listMessageTemplateVersions(
{required String knowledgeBaseId, required String messageTemplateId, int? maxResults, String? nextToken}) → Future< ListMessageTemplateVersionsResponse> - Lists all the available versions for the specified Amazon Q in Connect message template.
-
listModels(
{required String assistantId, AIPromptType? aiPromptType, int? maxResults, ModelLifecycle? modelLifecycle, String? nextToken}) → Future< ListModelsResponse> - Lists the models available to an Amazon Q in Connect assistant in the assistant's Amazon Web Services Region. The available models are determined by the region of the specified assistant.
-
listQuickResponses(
{required String knowledgeBaseId, int? maxResults, String? nextToken}) → Future< ListQuickResponsesResponse> - Lists information about quick response.
-
listSpans(
{required String assistantId, required String sessionId, int? maxResults, String? nextToken}) → Future< ListSpansResponse> - Retrieves AI agent execution traces for a session, providing granular visibility into agent orchestration flows, LLM interactions, and tool invocations.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for the specified resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyRecommendationsReceived(
{required String assistantId, required List< String> recommendationIds, required String sessionId}) → Future<NotifyRecommendationsReceivedResponse> -
Removes the specified recommendations from the specified assistant's queue
of newly available recommendations. You can use this API in conjunction
with GetRecommendations
and a
waitTimeSecondsinput for long-polling behavior and avoiding duplicate recommendations. -
putFeedback(
{required String assistantId, required ContentFeedbackData contentFeedback, required String targetId, required TargetType targetType}) → Future< PutFeedbackResponse> - Provides feedback against the specified assistant for the specified target. This API only supports generative targets.
-
queryAssistant(
{required String assistantId, int? maxResults, String? nextToken, KnowledgeBaseSearchType? overrideKnowledgeBaseSearchType, List< QueryCondition> ? queryCondition, QueryInputData? queryInputData, String? queryText, String? sessionId}) → Future<QueryAssistantResponse> - GetRecommendations
-
removeAssistantAIAgent(
{required AIAgentType aiAgentType, required String assistantId, String? orchestratorUseCase}) → Future< void> - Removes the AI Agent that is set for use by default on an Amazon Q in Connect Assistant.
-
removeKnowledgeBaseTemplateUri(
{required String knowledgeBaseId}) → Future< void> - Removes a URI template from a knowledge base.
-
renderMessageTemplate(
{required MessageTemplateAttributes attributes, required String knowledgeBaseId, required String messageTemplateId}) → Future< RenderMessageTemplateResponse> - Renders the Amazon Q in Connect message template based on the attribute values provided and generates the message content. For any variable present in the message template, if the attribute value is neither provided in the attribute request parameter nor the default attribute of the message template, the rendered message content will keep the variable placeholder as it is and return the attribute keys that are missing.
-
retrieve(
{required String assistantId, required RetrievalConfiguration retrievalConfiguration, required String retrievalQuery}) → Future< RetrieveResponse> - Retrieves content from knowledge sources based on a query.
-
searchContent(
{required String knowledgeBaseId, required SearchExpression searchExpression, int? maxResults, String? nextToken}) → Future< SearchContentResponse> - Searches for content in a specified knowledge base. Can be used to get a specific content resource by its name.
-
searchMessageTemplates(
{required String knowledgeBaseId, required MessageTemplateSearchExpression searchExpression, int? maxResults, String? nextToken}) → Future< SearchMessageTemplatesResponse> - Searches for Amazon Q in Connect message templates in the specified knowledge base.
-
searchQuickResponses(
{required String knowledgeBaseId, required QuickResponseSearchExpression searchExpression, Map< String, String> ? attributes, int? maxResults, String? nextToken}) → Future<SearchQuickResponsesResponse> - Searches existing Amazon Q in Connect quick responses in an Amazon Q in Connect knowledge base.
-
searchSessions(
{required String assistantId, required SearchExpression searchExpression, int? maxResults, String? nextToken}) → Future< SearchSessionsResponse> - Searches for sessions.
-
sendMessage(
{required String assistantId, required MessageInput message, required String sessionId, required MessageType type, String? aiAgentId, String? clientToken, MessageConfiguration? configuration, ConversationContext? conversationContext, Map< String, String> ? metadata, String? orchestratorUseCase, String? originRequestId}) → Future<SendMessageResponse> - Submits a message to the Amazon Q in Connect session.
-
startContentUpload(
{required String contentType, required String knowledgeBaseId, int? presignedUrlTimeToLive}) → Future< StartContentUploadResponse> - Get a URL to upload content to a knowledge base. To upload content, first make a PUT request to the returned URL with your file, making sure to include the required headers. Then use CreateContent to finalize the content creation process or UpdateContent to modify an existing resource. You can only upload content to a knowledge base of type CUSTOM.
-
startImportJob(
{required ImportJobType importJobType, required String knowledgeBaseId, required String uploadId, String? clientToken, ExternalSourceConfiguration? externalSourceConfiguration, Map< String, String> ? metadata}) → Future<StartImportJobResponse> - Start an asynchronous job to import Amazon Q in Connect resources from an uploaded source file. Before calling this API, use StartContentUpload to upload an asset that contains the resource data.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds the specified tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the specified resource.
-
updateAIAgent(
{required String aiAgentId, required String assistantId, required VisibilityStatus visibilityStatus, String? clientToken, AIAgentConfiguration? configuration, String? description}) → Future< UpdateAIAgentResponse> - Updates an AI Agent.
-
updateAIGuardrail(
{required String aiGuardrailId, required String assistantId, required String blockedInputMessaging, required String blockedOutputsMessaging, required VisibilityStatus visibilityStatus, String? clientToken, AIGuardrailContentPolicyConfig? contentPolicyConfig, AIGuardrailContextualGroundingPolicyConfig? contextualGroundingPolicyConfig, String? description, AIGuardrailSensitiveInformationPolicyConfig? sensitiveInformationPolicyConfig, AIGuardrailTopicPolicyConfig? topicPolicyConfig, AIGuardrailWordPolicyConfig? wordPolicyConfig}) → Future< UpdateAIGuardrailResponse> - Updates an AI Guardrail.
-
updateAIPrompt(
{required String aiPromptId, required String assistantId, required VisibilityStatus visibilityStatus, String? clientToken, String? description, AIPromptInferenceConfiguration? inferenceConfiguration, String? modelId, AIPromptTemplateConfiguration? templateConfiguration}) → Future< UpdateAIPromptResponse> - Updates an AI Prompt.
-
updateAssistantAIAgent(
{required AIAgentType aiAgentType, required String assistantId, required AIAgentConfigurationData configuration, String? orchestratorUseCase}) → Future< UpdateAssistantAIAgentResponse> - Updates the AI Agent that is set for use by default on an Amazon Q in Connect Assistant.
-
updateContent(
{required String contentId, required String knowledgeBaseId, Map< String, String> ? metadata, String? overrideLinkOutUri, bool? removeOverrideLinkOutUri, String? revisionId, String? title, String? uploadId}) → Future<UpdateContentResponse> - Updates information about the content.
-
updateKnowledgeBaseTemplateUri(
{required String knowledgeBaseId, required String templateUri}) → Future< UpdateKnowledgeBaseTemplateUriResponse> -
Updates the template URI of a knowledge base. This is only supported for
knowledge bases of type EXTERNAL. Include a single variable in
${variable}format; this interpolated by Amazon Q in Connect using ingested content. For example, if you ingest a Salesforce article, it has anIdvalue, and you can set the template URI tohttps://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view. -
updateMessageTemplate(
{required String knowledgeBaseId, required String messageTemplateId, MessageTemplateContentProvider? content, MessageTemplateAttributes? defaultAttributes, String? language, MessageTemplateSourceConfiguration? sourceConfiguration}) → Future< UpdateMessageTemplateResponse> -
Updates the Amazon Q in Connect message template. Partial update is
supported. If any field is not supplied, it will remain unchanged for the
message template that is referenced by the
$LATESTqualifier. Any modification will only apply to the message template that is referenced by the$LATESTqualifier. The fields for all available versions will remain unchanged. -
updateMessageTemplateMetadata(
{required String knowledgeBaseId, required String messageTemplateId, String? description, GroupingConfiguration? groupingConfiguration, String? name}) → Future< UpdateMessageTemplateMetadataResponse> -
Updates the Amazon Q in Connect message template metadata. Note that any
modification to the message template’s name, description and grouping
configuration will applied to the message template pointed by the
$LATESTqualifier and all available versions. Partial update is supported. If any field is not supplied, it will remain unchanged for the message template. -
updateQuickResponse(
{required String knowledgeBaseId, required String quickResponseId, List< String> ? channels, QuickResponseDataProvider? content, String? contentType, String? description, GroupingConfiguration? groupingConfiguration, bool? isActive, String? language, String? name, bool? removeDescription, bool? removeGroupingConfiguration, bool? removeShortcutKey, String? shortcutKey}) → Future<UpdateQuickResponseResponse> - Updates an existing Amazon Q in Connect quick response.
-
updateSession(
{required String assistantId, required String sessionId, Map< AIAgentType, AIAgentConfigurationData> ? aiAgentConfiguration, String? description, List<OrchestratorConfigurationEntry> ? orchestratorConfigurationList, bool? removeOrchestratorConfigurationList, TagFilter? tagFilter}) → Future<UpdateSessionResponse> - Updates a session. A session is a contextual container used for generating recommendations. Amazon Connect updates the existing Amazon Q in Connect session for each contact on which Amazon Q in Connect is enabled.
-
updateSessionData(
{required String assistantId, required List< RuntimeSessionData> data, required String sessionId, SessionDataNamespace? namespace}) → Future<UpdateSessionDataResponse> - Updates the data stored on an Amazon Q in Connect Session.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited