deleteAIAgentVersion method

Future<void> deleteAIAgentVersion({
  1. required String aiAgentId,
  2. required String assistantId,
  3. required int versionNumber,
})

Deletes an Amazon Q in Connect AI Agent Version.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter aiAgentId : The identifier of the Amazon Q in Connect AI Agent. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter assistantId : The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter versionNumber : The version number of the AI Agent version.

Implementation

Future<void> deleteAIAgentVersion({
  required String aiAgentId,
  required String assistantId,
  required int versionNumber,
}) async {
  _s.validateNumRange(
    'versionNumber',
    versionNumber,
    1,
    1152921504606846976,
    isRequired: true,
  );
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/assistants/${Uri.encodeComponent(assistantId)}/aiagents/${Uri.encodeComponent(aiAgentId)}/versions/${Uri.encodeComponent(versionNumber.toString())}',
    exceptionFnMap: _exceptionFns,
  );
}