deleteMessageTemplateAttachment method

Future<void> deleteMessageTemplateAttachment({
  1. required String attachmentId,
  2. required String knowledgeBaseId,
  3. required String messageTemplateId,
})

Deletes the attachment file from the Amazon Q in Connect message template that is referenced by $LATEST qualifier. Attachments on available message template versions will remain unchanged.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter attachmentId : The identifier of the attachment file.

Parameter knowledgeBaseId : The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter messageTemplateId : The identifier of the message template. Can be either the ID or the ARN. It cannot contain any qualifier.

Implementation

Future<void> deleteMessageTemplateAttachment({
  required String attachmentId,
  required String knowledgeBaseId,
  required String messageTemplateId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/knowledgeBases/${Uri.encodeComponent(knowledgeBaseId)}/messageTemplates/${Uri.encodeComponent(messageTemplateId)}/attachments/${Uri.encodeComponent(attachmentId)}',
    exceptionFnMap: _exceptionFns,
  );
}