getAIAgent method

Future<GetAIAgentResponse> getAIAgent({
  1. required String aiAgentId,
  2. required String assistantId,
})

Gets an Amazon Q in Connect AI Agent.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter aiAgentId : The identifier of the Amazon Q in Connect AI Agent (with or without a version qualifier). Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter assistantId : The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.

Implementation

Future<GetAIAgentResponse> getAIAgent({
  required String aiAgentId,
  required String assistantId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/assistants/${Uri.encodeComponent(assistantId)}/aiagents/${Uri.encodeComponent(aiAgentId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetAIAgentResponse.fromJson(response);
}