listAIPromptVersions method

Future<ListAIPromptVersionsResponse> listAIPromptVersions({
  1. required String aiPromptId,
  2. required String assistantId,
  3. int? maxResults,
  4. String? nextToken,
  5. Origin? origin,
})

Lists AI Prompt versions.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter aiPromptId : The identifier of the Amazon Q in Connect AI prompt for which versions are to be listed.

Parameter assistantId : The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Parameter origin : The origin of the AI Prompt versions to be listed. SYSTEM for a default AI Agent created by Q in Connect or CUSTOMER for an AI Agent created by calling AI Agent creation APIs.

Implementation

Future<ListAIPromptVersionsResponse> listAIPromptVersions({
  required String aiPromptId,
  required String assistantId,
  int? maxResults,
  String? nextToken,
  Origin? origin,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (origin != null) 'origin': [origin.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/assistants/${Uri.encodeComponent(assistantId)}/aiprompts/${Uri.encodeComponent(aiPromptId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAIPromptVersionsResponse.fromJson(response);
}