listAIPrompts method
Lists the AI Prompts available on the Amazon Q in Connect assistant.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter assistantId :
The identifier of the Amazon Q in Connect assistant. Can be either the ID
or the ARN. URLs cannot contain the ARN.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter origin :
The origin of the AI Prompts to be listed. SYSTEM for a
default AI Agent created by Q in Connect or CUSTOMER for an
AI Agent created by calling AI Agent creation APIs.
Implementation
Future<ListAIPromptsResponse> listAIPrompts({
required String assistantId,
int? maxResults,
String? nextToken,
Origin? origin,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (origin != null) 'origin': [origin.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/assistants/${Uri.encodeComponent(assistantId)}/aiprompts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAIPromptsResponse.fromJson(response);
}