listMessageTemplateVersions method

Future<ListMessageTemplateVersionsResponse> listMessageTemplateVersions({
  1. required String knowledgeBaseId,
  2. required String messageTemplateId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the available versions for the specified Amazon Q in Connect message template.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter knowledgeBaseId : The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter messageTemplateId : The identifier of the message template. Can be either the ID or the ARN. It cannot contain any qualifier.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListMessageTemplateVersionsResponse> listMessageTemplateVersions({
  required String knowledgeBaseId,
  required String messageTemplateId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/knowledgeBases/${Uri.encodeComponent(knowledgeBaseId)}/messageTemplates/${Uri.encodeComponent(messageTemplateId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListMessageTemplateVersionsResponse.fromJson(response);
}