batchDeleteTopicReviewedAnswer method

Future<BatchDeleteTopicReviewedAnswerResponse> batchDeleteTopicReviewedAnswer({
  1. required String awsAccountId,
  2. required String topicId,
  3. List<String>? answerIds,
})

Deletes reviewed answers for Q Topic.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that you want to delete a reviewed answers in.

Parameter topicId : The ID for the topic reviewed answer that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Parameter answerIds : The Answer IDs of the Answers to be deleted.

Implementation

Future<BatchDeleteTopicReviewedAnswerResponse>
    batchDeleteTopicReviewedAnswer({
  required String awsAccountId,
  required String topicId,
  List<String>? answerIds,
}) async {
  final $payload = <String, dynamic>{
    if (answerIds != null) 'AnswerIds': answerIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/batch-delete-reviewed-answers',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeleteTopicReviewedAnswerResponse.fromJson(response);
}