createFolderMembership method

Future<CreateFolderMembershipResponse> createFolderMembership({
  1. required String awsAccountId,
  2. required String folderId,
  3. required String memberId,
  4. required MemberType memberType,
})

Adds an asset, such as a dashboard, analysis, or dataset into a folder.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID for the Amazon Web Services account that contains the folder.

Parameter folderId : The ID of the folder.

Parameter memberId : The ID of the asset that you want to add to the folder.

Parameter memberType : The member type of the asset that you want to add to a folder.

Implementation

Future<CreateFolderMembershipResponse> createFolderMembership({
  required String awsAccountId,
  required String folderId,
  required String memberId,
  required MemberType memberType,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/folders/${Uri.encodeComponent(folderId)}/members/${Uri.encodeComponent(memberType.value)}/${Uri.encodeComponent(memberId)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateFolderMembershipResponse.fromJson(response);
}