createGroup method

Future<CreateGroupResponse> createGroup({
  1. required String awsAccountId,
  2. required String groupName,
  3. required String namespace,
  4. String? description,
})

Use the CreateGroup operation to create a group in Quick Sight. You can create up to 10,000 groups in a namespace. If you want to create more than 10,000 groups in a namespace, contact Amazon Web Services Support.

The permissions resource is arn:aws:quicksight:.

The response is a group object.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw PreconditionNotMetException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter groupName : A name for the group that you want to create.

Parameter namespace : The namespace that you want the group to be a part of.

Parameter description : A description for the group that you want to create.

Implementation

Future<CreateGroupResponse> createGroup({
  required String awsAccountId,
  required String groupName,
  required String namespace,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    'GroupName': groupName,
    if (description != null) 'Description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups',
    exceptionFnMap: _exceptionFns,
  );
  return CreateGroupResponse.fromJson(response);
}