createGroupMembership method

Future<CreateGroupMembershipResponse> createGroupMembership({
  1. required String awsAccountId,
  2. required String groupName,
  3. required String memberName,
  4. required String namespace,
})

Adds an Amazon Quick Sight user to an Amazon Quick Sight group.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter groupName : The name of the group that you want to add the user to.

Parameter memberName : The name of the user that you want to add to the group membership.

Parameter namespace : The namespace that you want the user to be a part of.

Implementation

Future<CreateGroupMembershipResponse> createGroupMembership({
  required String awsAccountId,
  required String groupName,
  required String memberName,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}/members/${Uri.encodeComponent(memberName)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateGroupMembershipResponse.fromJson(response);
}