createIngestion method

Future<CreateIngestionResponse> createIngestion({
  1. required String awsAccountId,
  2. required String dataSetId,
  3. required String ingestionId,
  4. IngestionType? ingestionType,
})

Creates and starts a new SPICE ingestion for a dataset. You can manually refresh datasets in an Enterprise edition account 32 times in a 24-hour period. You can manually refresh datasets in a Standard edition account 8 times in a 24-hour period. Each 24-hour period is measured starting 24 hours before the current date and time.

Any ingestions operating on tagged datasets inherit the same tags automatically for use in access control. For an example, see How do I create an IAM policy to control access to Amazon EC2 resources using tags? in the Amazon Web Services Knowledge Center. Tags are visible on the tagged dataset, but not on the ingestion resource.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter dataSetId : The ID of the dataset used in the ingestion.

Parameter ingestionId : An ID for the ingestion.

Parameter ingestionType : The type of ingestion that you want to create.

Implementation

Future<CreateIngestionResponse> createIngestion({
  required String awsAccountId,
  required String dataSetId,
  required String ingestionId,
  IngestionType? ingestionType,
}) async {
  final $payload = <String, dynamic>{
    if (ingestionType != null) 'IngestionType': ingestionType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets/${Uri.encodeComponent(dataSetId)}/ingestions/${Uri.encodeComponent(ingestionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateIngestionResponse.fromJson(response);
}