createNamespace method
(Enterprise edition only) Creates a new namespace for you to use with Amazon Quick Sight.
A namespace allows you to isolate the Quick Sight users and groups that are registered for that namespace. Users that access the namespace can share assets only with other users or groups in the same namespace. They can't see users and groups in other namespaces. You can create a namespace after your Amazon Web Services account is subscribed to Quick Sight. The namespace must be unique within the Amazon Web Services account. By default, there is a limit of 100 namespaces per Amazon Web Services account. To increase your limit, create a ticket with Amazon Web Services Support.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw PreconditionNotMetException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that you want to create the
Quick Sight namespace in.
Parameter identityStore :
Specifies the type of your user identity directory. Currently, this
supports users with an identity type of QUICKSIGHT.
Parameter namespace :
The name that you want to use to describe the new namespace.
Parameter tags :
The tags that you want to associate with the namespace that you're
creating.
Implementation
Future<CreateNamespaceResponse> createNamespace({
required String awsAccountId,
required IdentityStore identityStore,
required String namespace,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'IdentityStore': identityStore.value,
'Namespace': namespace,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}',
exceptionFnMap: _exceptionFns,
);
return CreateNamespaceResponse.fromJson(response);
}