createRoleMembership method

Future<CreateRoleMembershipResponse> createRoleMembership({
  1. required String awsAccountId,
  2. required String memberName,
  3. required String namespace,
  4. required Role role,
})

Use CreateRoleMembership to add an existing Quick Sight group to an existing role.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter memberName : The name of the group that you want to add to the role.

Parameter namespace : The namespace that the role belongs to.

Parameter role : The role that you want to add a group to.

Implementation

Future<CreateRoleMembershipResponse> createRoleMembership({
  required String awsAccountId,
  required String memberName,
  required String namespace,
  required Role role,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/roles/${Uri.encodeComponent(role.value)}/members/${Uri.encodeComponent(memberName)}',
    exceptionFnMap: _exceptionFns,
  );
  return CreateRoleMembershipResponse.fromJson(response);
}