createSpace method
Creates a new Amazon QuickSight space. A space is a collection of resources that can be used to organize and manage QuickSight assets.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw ResourceExistsException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the space.
Parameter name :
A display name for the space.
Parameter spaceId :
The ID of the space. This ID is unique per Amazon Web Services Region for
each Amazon Web Services account.
Parameter description :
A description of the space.
Implementation
Future<CreateSpaceResponse> createSpace({
required String awsAccountId,
required String name,
required String spaceId,
String? description,
}) async {
final $payload = <String, dynamic>{
'Name': name,
'SpaceId': spaceId,
if (description != null) 'Description': description,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces',
exceptionFnMap: _exceptionFns,
);
return CreateSpaceResponse.fromJson(response);
}