createTemplateAlias method
Creates a template alias for a template.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter aliasName :
The name that you want to give to the template alias that you're creating.
Don't start the alias name with the $ character. Alias names
that start with $ are reserved by Quick Sight.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the template that
you creating an alias for.
Parameter templateId :
An ID for the template.
Parameter templateVersionNumber :
The version number of the template.
Implementation
Future<CreateTemplateAliasResponse> createTemplateAlias({
required String aliasName,
required String awsAccountId,
required String templateId,
required int templateVersionNumber,
}) async {
_s.validateNumRange(
'templateVersionNumber',
templateVersionNumber,
1,
1152921504606846976,
isRequired: true,
);
final $payload = <String, dynamic>{
'TemplateVersionNumber': templateVersionNumber,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/templates/${Uri.encodeComponent(templateId)}/aliases/${Uri.encodeComponent(aliasName)}',
exceptionFnMap: _exceptionFns,
);
return CreateTemplateAliasResponse.fromJson(response);
}