deleteAccountCustomPermission method

Future<DeleteAccountCustomPermissionResponse> deleteAccountCustomPermission({
  1. required String awsAccountId,
})

Unapplies a custom permissions profile from an account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account from which you want to unapply the custom permissions profile.

Implementation

Future<DeleteAccountCustomPermissionResponse> deleteAccountCustomPermission({
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permission',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAccountCustomPermissionResponse.fromJson(response);
}