deleteAccountCustomization method

Future<DeleteAccountCustomizationResponse> deleteAccountCustomization({
  1. required String awsAccountId,
  2. String? namespace,
})
Deletes all Amazon Quick Sight customizations for the specified Amazon Web Services account and Quick Sight namespace.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to delete Quick Sight customizations from.

Parameter namespace : The Quick Sight namespace that you're deleting the customizations from.

Implementation

Future<DeleteAccountCustomizationResponse> deleteAccountCustomization({
  required String awsAccountId,
  String? namespace,
}) async {
  final $query = <String, List<String>>{
    if (namespace != null) 'namespace': [namespace],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/customizations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAccountCustomizationResponse.fromJson(response);
}