deleteAccountSubscription method

Future<DeleteAccountSubscriptionResponse> deleteAccountSubscription({
  1. required String awsAccountId,
})
Use the DeleteAccountSubscription operation to delete an Quick Sight account. This operation will result in an error message if you have configured your account termination protection settings to True. To change this setting and delete your account, call the UpdateAccountSettings API and set the value of the TerminationProtectionEnabled parameter to False, then make another call to the DeleteAccountSubscription API.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID of the account that you want to delete.

Implementation

Future<DeleteAccountSubscriptionResponse> deleteAccountSubscription({
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/account/${Uri.encodeComponent(awsAccountId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAccountSubscriptionResponse.fromJson(response);
}