deleteCustomPermissions method

Future<DeleteCustomPermissionsResponse> deleteCustomPermissions({
  1. required String awsAccountId,
  2. required String customPermissionsName,
})

Deletes a custom permissions profile.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the custom permissions profile that you want to delete.

Parameter customPermissionsName : The name of the custom permissions profile that you want to delete.

Implementation

Future<DeleteCustomPermissionsResponse> deleteCustomPermissions({
  required String awsAccountId,
  required String customPermissionsName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permissions/${Uri.encodeComponent(customPermissionsName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteCustomPermissionsResponse.fromJson(response);
}