deleteDataSet method

Future<DeleteDataSetResponse> deleteDataSet({
  1. required String awsAccountId,
  2. required String dataSetId,
})

Deletes a dataset.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter dataSetId : The ID for the dataset that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DeleteDataSetResponse> deleteDataSet({
  required String awsAccountId,
  required String dataSetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets/${Uri.encodeComponent(dataSetId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDataSetResponse.fromJson(response);
}