deleteDataSource method

Future<DeleteDataSourceResponse> deleteDataSource({
  1. required String awsAccountId,
  2. required String dataSourceId,
})

Deletes the data source permanently. This operation breaks all the datasets that reference the deleted data source.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter dataSourceId : The ID of the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DeleteDataSourceResponse> deleteDataSource({
  required String awsAccountId,
  required String dataSourceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sources/${Uri.encodeComponent(dataSourceId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDataSourceResponse.fromJson(response);
}