deleteFlow method

Future<DeleteFlowResponse> deleteFlow({
  1. required String awsAccountId,
  2. required String flowId,
})

Permanently deletes a flow from the specified Amazon Web Services account. This operation cannot be undone.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the flow that you are deleting.

Parameter flowId : The unique identifier of the flow to delete.

Implementation

Future<DeleteFlowResponse> deleteFlow({
  required String awsAccountId,
  required String flowId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/flows/${Uri.encodeComponent(flowId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFlowResponse.fromJson(response);
}