deleteFolderMembership method
Removes an asset, such as a dashboard, analysis, or dataset, from a folder.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that contains the folder.
Parameter folderId :
The Folder ID.
Parameter memberId :
The ID of the asset that you want to delete.
Parameter memberType :
The member type of the asset that you want to delete from a folder.
Implementation
Future<DeleteFolderMembershipResponse> deleteFolderMembership({
required String awsAccountId,
required String folderId,
required String memberId,
required MemberType memberType,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/folders/${Uri.encodeComponent(folderId)}/members/${Uri.encodeComponent(memberType.value)}/${Uri.encodeComponent(memberId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteFolderMembershipResponse.fromJson(response);
}