deleteGroup method
Removes a user group from Amazon Quick Sight.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that the group is in.
Currently, you use the ID for the Amazon Web Services account that
contains your Amazon Quick Sight account.
Parameter groupName :
The name of the group that you want to delete.
Parameter namespace :
The namespace of the group that you want to delete.
Implementation
Future<DeleteGroupResponse> deleteGroup({
required String awsAccountId,
required String groupName,
required String namespace,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}',
exceptionFnMap: _exceptionFns,
);
return DeleteGroupResponse.fromJson(response);
}