deleteRoleCustomPermission method

Future<DeleteRoleCustomPermissionResponse> deleteRoleCustomPermission({
  1. required String awsAccountId,
  2. required String namespace,
  3. required Role role,
})

Removes custom permissions from the role.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter namespace : The namespace that includes the role.

Parameter role : The role that you want to remove permissions from.

Implementation

Future<DeleteRoleCustomPermissionResponse> deleteRoleCustomPermission({
  required String awsAccountId,
  required String namespace,
  required Role role,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/roles/${Uri.encodeComponent(role.value)}/custom-permission',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteRoleCustomPermissionResponse.fromJson(response);
}