deleteRoleMembership method

Future<DeleteRoleMembershipResponse> deleteRoleMembership({
  1. required String awsAccountId,
  2. required String memberName,
  3. required String namespace,
  4. required Role role,
})

Removes a group from a role.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter memberName : The name of the group.

Parameter namespace : The namespace that contains the role.

Parameter role : The role that you want to remove permissions from.

Implementation

Future<DeleteRoleMembershipResponse> deleteRoleMembership({
  required String awsAccountId,
  required String memberName,
  required String namespace,
  required Role role,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/roles/${Uri.encodeComponent(role.value)}/members/${Uri.encodeComponent(memberName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteRoleMembershipResponse.fromJson(response);
}