deleteTopic method

Future<DeleteTopicResponse> deleteTopic({
  1. required String awsAccountId,
  2. required String topicId,
})

Deletes a topic.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the topic that you want to delete.

Parameter topicId : The ID of the topic that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DeleteTopicResponse> deleteTopic({
  required String awsAccountId,
  required String topicId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteTopicResponse.fromJson(response);
}