deleteTopicRefreshSchedule method

Future<DeleteTopicRefreshScheduleResponse> deleteTopicRefreshSchedule({
  1. required String awsAccountId,
  2. required String datasetId,
  3. required String topicId,
})

Deletes a topic refresh schedule.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter datasetId : The ID of the dataset.

Parameter topicId : The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DeleteTopicRefreshScheduleResponse> deleteTopicRefreshSchedule({
  required String awsAccountId,
  required String datasetId,
  required String topicId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/schedules/${Uri.encodeComponent(datasetId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteTopicRefreshScheduleResponse.fromJson(response);
}