deleteUserByPrincipalId method

Future<DeleteUserByPrincipalIdResponse> deleteUserByPrincipalId({
  1. required String awsAccountId,
  2. required String namespace,
  3. required String principalId,
})

Deletes a user identified by its principal ID.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter namespace : The namespace. Currently, you should set this to default.

Parameter principalId : The principal ID of the user.

Implementation

Future<DeleteUserByPrincipalIdResponse> deleteUserByPrincipalId({
  required String awsAccountId,
  required String namespace,
  required String principalId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/user-principals/${Uri.encodeComponent(principalId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteUserByPrincipalIdResponse.fromJson(response);
}