describeAccountSubscription method

Future<DescribeAccountSubscriptionResponse> describeAccountSubscription({
  1. required String awsAccountId,
})

Use the DescribeAccountSubscription operation to receive a description of an Quick Sight account's subscription. A successful API call returns an AccountInfo object that includes an account's name, subscription status, authentication type, edition, and notification email address.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID associated with your Quick Sight account.

Implementation

Future<DescribeAccountSubscriptionResponse> describeAccountSubscription({
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/account/${Uri.encodeComponent(awsAccountId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAccountSubscriptionResponse.fromJson(response);
}