describeActionConnector method
Retrieves detailed information about an action connector, including its configuration, authentication settings, enabled actions, and current status.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter actionConnectorId :
The unique identifier of the action connector to describe.
Parameter awsAccountId :
The Amazon Web Services account ID that contains the action connector.
Implementation
Future<DescribeActionConnectorResponse> describeActionConnector({
required String actionConnectorId,
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/action-connectors/${Uri.encodeComponent(actionConnectorId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeActionConnectorResponse.fromJson(response);
}