describeActionConnectorPermissions method

Future<DescribeActionConnectorPermissionsResponse> describeActionConnectorPermissions({
  1. required String actionConnectorId,
  2. required String awsAccountId,
})

Retrieves the permissions configuration for an action connector, showing which users, groups, and namespaces have access and what operations they can perform.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter actionConnectorId : The unique identifier of the action connector whose permissions you want to describe.

Parameter awsAccountId : The Amazon Web Services account ID that contains the action connector.

Implementation

Future<DescribeActionConnectorPermissionsResponse>
    describeActionConnectorPermissions({
  required String actionConnectorId,
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/action-connectors/${Uri.encodeComponent(actionConnectorId)}/permissions',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeActionConnectorPermissionsResponse.fromJson(response);
}