describeAnalysisPermissions method
Provides the read and write permissions for an analysis.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter analysisId :
The ID of the analysis whose permissions you're describing. The ID is part
of the analysis URL.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the analysis whose
permissions you're describing. You must be using the Amazon Web Services
account that the analysis is in.
Implementation
Future<DescribeAnalysisPermissionsResponse> describeAnalysisPermissions({
required String analysisId,
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/analyses/${Uri.encodeComponent(analysisId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return DescribeAnalysisPermissionsResponse.fromJson(response);
}