describeAssetBundleImportJob method

Future<DescribeAssetBundleImportJobResponse> describeAssetBundleImportJob({
  1. required String assetBundleImportJobId,
  2. required String awsAccountId,
})

Describes an existing import job.

Poll job descriptions after starting a job to know when it has succeeded or failed. Job descriptions are available for 14 days after job starts.

May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter assetBundleImportJobId : The ID of the job. The job ID is set when you start a new job with a StartAssetBundleImportJob API call.

Parameter awsAccountId : The ID of the Amazon Web Services account the import job was executed in.

Implementation

Future<DescribeAssetBundleImportJobResponse> describeAssetBundleImportJob({
  required String assetBundleImportJobId,
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/asset-bundle-import-jobs/${Uri.encodeComponent(assetBundleImportJobId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAssetBundleImportJobResponse.fromJson(response);
}