describeAutomationJob method

Future<DescribeAutomationJobResponse> describeAutomationJob({
  1. required String automationGroupId,
  2. required String automationId,
  3. required String awsAccountId,
  4. required String jobId,
  5. bool? includeInputPayload,
  6. bool? includeOutputPayload,
})

Retrieves the status and details of a specified automation job, including its status and outputs.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter automationGroupId : The ID of the automation group that contains the automation.

Parameter automationId : The ID of the automation that the job belongs to.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the automation job.

Parameter jobId : The ID of the automation job to describe.

Parameter includeInputPayload : A Boolean value that indicates whether to include the input payload in the response. If set to true, the input payload will be included. If set to false, the input payload will be returned as null.

Parameter includeOutputPayload : A Boolean value that indicates whether to include the output payload in the response. If set to true, the output payload will be included. If set to false, the output payload will be returned as null.

Implementation

Future<DescribeAutomationJobResponse> describeAutomationJob({
  required String automationGroupId,
  required String automationId,
  required String awsAccountId,
  required String jobId,
  bool? includeInputPayload,
  bool? includeOutputPayload,
}) async {
  final $query = <String, List<String>>{
    if (includeInputPayload != null)
      'includeInputPayload': [includeInputPayload.toString()],
    if (includeOutputPayload != null)
      'includeOutputPayload': [includeOutputPayload.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/automation-groups/${Uri.encodeComponent(automationGroupId)}/automations/${Uri.encodeComponent(automationId)}/jobs/${Uri.encodeComponent(jobId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeAutomationJobResponse.fromJson(response);
}