describeCustomPermissions method

Future<DescribeCustomPermissionsResponse> describeCustomPermissions({
  1. required String awsAccountId,
  2. required String customPermissionsName,
})

Describes a custom permissions profile.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the custom permissions profile that you want described.

Parameter customPermissionsName : The name of the custom permissions profile to describe.

Implementation

Future<DescribeCustomPermissionsResponse> describeCustomPermissions({
  required String awsAccountId,
  required String customPermissionsName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permissions/${Uri.encodeComponent(customPermissionsName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeCustomPermissionsResponse.fromJson(response);
}