describeDashboardDefinition method

Future<DescribeDashboardDefinitionResponse> describeDashboardDefinition({
  1. required String awsAccountId,
  2. required String dashboardId,
  3. String? aliasName,
  4. int? versionNumber,
})

Provides a detailed description of the definition of a dashboard.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the dashboard that you're describing.

Parameter dashboardId : The ID for the dashboard.

Parameter aliasName : The alias name.

Parameter versionNumber : The version number for the dashboard. If a version number isn't passed, the latest published dashboard version is described.

Implementation

Future<DescribeDashboardDefinitionResponse> describeDashboardDefinition({
  required String awsAccountId,
  required String dashboardId,
  String? aliasName,
  int? versionNumber,
}) async {
  _s.validateNumRange(
    'versionNumber',
    versionNumber,
    1,
    1152921504606846976,
  );
  final $query = <String, List<String>>{
    if (aliasName != null) 'alias-name': [aliasName],
    if (versionNumber != null) 'version-number': [versionNumber.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/definition',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDashboardDefinitionResponse.fromJson(response);
}