describeDataSet method
Describes a dataset. This operation doesn't support datasets that include uploaded files as a source.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The Amazon Web Services account ID.
Parameter dataSetId :
The ID for the dataset that you want to describe. This ID is unique per
Amazon Web Services Region for each Amazon Web Services account.
Implementation
Future<DescribeDataSetResponse> describeDataSet({
required String awsAccountId,
required String dataSetId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets/${Uri.encodeComponent(dataSetId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeDataSetResponse.fromJson(response);
}