describeDataSetPermissions method

Future<DescribeDataSetPermissionsResponse> describeDataSetPermissions({
  1. required String awsAccountId,
  2. required String dataSetId,
})

Describes the permissions on a dataset.

The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/data-set-id.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter dataSetId : The ID for the dataset that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DescribeDataSetPermissionsResponse> describeDataSetPermissions({
  required String awsAccountId,
  required String dataSetId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets/${Uri.encodeComponent(dataSetId)}/permissions',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDataSetPermissionsResponse.fromJson(response);
}