describeDefaultQBusinessApplication method
Describes a Amazon Q Business application that is linked to an Quick Sight account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Quick Sight account that is linked to the Amazon Q Business
application that you want described.
Parameter namespace :
The Quick Sight namespace that contains the linked Amazon Q Business
application. If this field is left blank, the default namespace is used.
Currently, the default namespace is the only valid value for this
parameter.
Implementation
Future<DescribeDefaultQBusinessApplicationResponse>
describeDefaultQBusinessApplication({
required String awsAccountId,
String? namespace,
}) async {
final $query = <String, List<String>>{
if (namespace != null) 'namespace': [namespace],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/default-qbusiness-application',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeDefaultQBusinessApplicationResponse.fromJson(response);
}