describeFlow method

Future<DescribeFlowResponse> describeFlow({
  1. required String awsAccountId,
  2. required String flowId,
  3. required FlowPublishState publishState,
})

Returns the full details of a flow for the latest version of the requested publish state.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the flow that you are describing.

Parameter flowId : The unique identifier of the flow.

Parameter publishState : The publish state of the flow version to describe. Valid values are DRAFT, PUBLISHED, or PENDING_APPROVAL.

Implementation

Future<DescribeFlowResponse> describeFlow({
  required String awsAccountId,
  required String flowId,
  required FlowPublishState publishState,
}) async {
  final $query = <String, List<String>>{
    'publish-state': [publishState.value],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/flows/${Uri.encodeComponent(flowId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeFlowResponse.fromJson(response);
}