describeGroup method
Returns an Amazon Quick Sight group's description and Amazon Resource Name (ARN).
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that the group is in.
Currently, you use the ID for the Amazon Web Services account that
contains your Amazon Quick Sight account.
Parameter groupName :
The name of the group that you want to describe.
Parameter namespace :
The namespace of the group that you want described.
Implementation
Future<DescribeGroupResponse> describeGroup({
required String awsAccountId,
required String groupName,
required String namespace,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeGroupResponse.fromJson(response);
}