describeGroupMembership method

Future<DescribeGroupMembershipResponse> describeGroupMembership({
  1. required String awsAccountId,
  2. required String groupName,
  3. required String memberName,
  4. required String namespace,
})

Use the DescribeGroupMembership operation to determine if a user is a member of the specified group. If the user exists and is a member of the specified group, an associated GroupMember object is returned.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter groupName : The name of the group that you want to search.

Parameter memberName : The user name of the user that you want to search for.

Parameter namespace : The namespace that includes the group you are searching within.

Implementation

Future<DescribeGroupMembershipResponse> describeGroupMembership({
  required String awsAccountId,
  required String groupName,
  required String memberName,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}/members/${Uri.encodeComponent(memberName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeGroupMembershipResponse.fromJson(response);
}