describeIAMPolicyAssignment method

Future<DescribeIAMPolicyAssignmentResponse> describeIAMPolicyAssignment({
  1. required String assignmentName,
  2. required String awsAccountId,
  3. required String namespace,
})

Describes an existing IAM policy assignment, as specified by the assignment name.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter assignmentName : The name of the assignment, also called a rule.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the assignment that you want to describe.

Parameter namespace : The namespace that contains the assignment.

Implementation

Future<DescribeIAMPolicyAssignmentResponse> describeIAMPolicyAssignment({
  required String assignmentName,
  required String awsAccountId,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/iam-policy-assignments/${Uri.encodeComponent(assignmentName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeIAMPolicyAssignmentResponse.fromJson(response);
}