describeNamespace method

Future<DescribeNamespaceResponse> describeNamespace({
  1. required String awsAccountId,
  2. required String namespace,
})

Describes the current namespace.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that contains the Quick Sight namespace that you want to describe.

Parameter namespace : The namespace that you want to describe.

Implementation

Future<DescribeNamespaceResponse> describeNamespace({
  required String awsAccountId,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeNamespaceResponse.fromJson(response);
}