describeQPersonalizationConfiguration method

Future<DescribeQPersonalizationConfigurationResponse> describeQPersonalizationConfiguration({
  1. required String awsAccountId,
})

Describes a personalization configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the personalization configuration that the user wants described.

Implementation

Future<DescribeQPersonalizationConfigurationResponse>
    describeQPersonalizationConfiguration({
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/q-personalization-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeQPersonalizationConfigurationResponse.fromJson(response);
}