describeQuickSightQSearchConfiguration method

Future<DescribeQuickSightQSearchConfigurationResponse> describeQuickSightQSearchConfiguration({
  1. required String awsAccountId,
})

Describes the state of a Quick Sight Q Search configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the Quick Sight Q Search configuration that the user wants described.

Implementation

Future<DescribeQuickSightQSearchConfigurationResponse>
    describeQuickSightQSearchConfiguration({
  required String awsAccountId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/quicksight-q-search-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeQuickSightQSearchConfigurationResponse.fromJson(response);
}