describeRoleCustomPermission method

Future<DescribeRoleCustomPermissionResponse> describeRoleCustomPermission({
  1. required String awsAccountId,
  2. required String namespace,
  3. required Role role,
})

Describes all custom permissions that are mapped to a role.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter namespace : The namespace that contains the role.

Parameter role : The name of the role whose permissions you want described.

Implementation

Future<DescribeRoleCustomPermissionResponse> describeRoleCustomPermission({
  required String awsAccountId,
  required String namespace,
  required Role role,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/roles/${Uri.encodeComponent(role.value)}/custom-permission',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeRoleCustomPermissionResponse.fromJson(response);
}