describeSelfUpgradeConfiguration method

Future<DescribeSelfUpgradeConfigurationResponse> describeSelfUpgradeConfiguration({
  1. required String awsAccountId,
  2. required String namespace,
})

Describes the self-upgrade configuration for a Quick account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration.

Parameter namespace : The Quick namespace that you want to describe the Quick self-upgrade configuration for.

Implementation

Future<DescribeSelfUpgradeConfigurationResponse>
    describeSelfUpgradeConfiguration({
  required String awsAccountId,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/self-upgrade-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeSelfUpgradeConfigurationResponse.fromJson(response);
}