describeSpace method

Future<DescribeSpaceResponse> describeSpace({
  1. required String awsAccountId,
  2. required String spaceId,
  3. int? maxContributors,
})

Describes an Amazon QuickSight space.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the space.

Parameter spaceId : The ID of the space that you want to describe.

Parameter maxContributors : The maximum number of contributors to include in the response.

Implementation

Future<DescribeSpaceResponse> describeSpace({
  required String awsAccountId,
  required String spaceId,
  int? maxContributors,
}) async {
  _s.validateNumRange(
    'maxContributors',
    maxContributors,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxContributors != null)
      'maxContributors': [maxContributors.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces/${Uri.encodeComponent(spaceId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeSpaceResponse.fromJson(response);
}