describeSpacePermissions method
Describes the permissions for an Amazon QuickSight space.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the space.
Parameter spaceId :
The ID of the space that you want to describe permissions for.
Implementation
Future<DescribeSpacePermissionsResponse> describeSpacePermissions({
required String awsAccountId,
required String spaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces/${Uri.encodeComponent(spaceId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return DescribeSpacePermissionsResponse.fromJson(response);
}