describeTemplateAlias method

Future<DescribeTemplateAliasResponse> describeTemplateAlias({
  1. required String aliasName,
  2. required String awsAccountId,
  3. required String templateId,
})

Describes the template alias for a template.

May throw InternalFailureException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter aliasName : The name of the template alias that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the template by providing the keyword $LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't apply to templates.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the template alias that you're describing.

Parameter templateId : The ID for the template.

Implementation

Future<DescribeTemplateAliasResponse> describeTemplateAlias({
  required String aliasName,
  required String awsAccountId,
  required String templateId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/templates/${Uri.encodeComponent(templateId)}/aliases/${Uri.encodeComponent(aliasName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeTemplateAliasResponse.fromJson(response);
}