describeTopic method

Future<DescribeTopicResponse> describeTopic({
  1. required String awsAccountId,
  2. required String topicId,
})

Describes a topic.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter topicId : The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<DescribeTopicResponse> describeTopic({
  required String awsAccountId,
  required String topicId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeTopicResponse.fromJson(response);
}