describeTopicPermissions method
Describes the permissions of a topic.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the topic that you
want described.
Parameter topicId :
The ID of the topic that you want to describe. This ID is unique per
Amazon Web Services Region for each Amazon Web Services account.
Implementation
Future<DescribeTopicPermissionsResponse> describeTopicPermissions({
required String awsAccountId,
required String topicId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return DescribeTopicPermissionsResponse.fromJson(response);
}