describeUser method
Returns information about a user, given the user name.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that the user is in. Currently,
you use the ID for the Amazon Web Services account that contains your
Amazon Quick Sight account.
Parameter namespace :
The namespace. Currently, you should set this to default.
Parameter userName :
The name of the user that you want to describe.
Implementation
Future<DescribeUserResponse> describeUser({
required String awsAccountId,
required String namespace,
required String userName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/users/${Uri.encodeComponent(userName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeUserResponse.fromJson(response);
}