describeVPCConnection method

Future<DescribeVPCConnectionResponse> describeVPCConnection({
  1. required String awsAccountId,
  2. required String vPCConnectionId,
})

Describes a VPC connection.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The Amazon Web Services account ID of the account that contains the VPC connection that you want described.

Parameter vPCConnectionId : The ID of the VPC connection that you're creating. This ID is a unique identifier for each Amazon Web Services Region in an Amazon Web Services account.

Implementation

Future<DescribeVPCConnectionResponse> describeVPCConnection({
  required String awsAccountId,
  required String vPCConnectionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/vpc-connections/${Uri.encodeComponent(vPCConnectionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeVPCConnectionResponse.fromJson(response);
}