getDashboardEmbedUrl method
Generates a temporary session URL and authorization code(bearer token) that you can use to embed an Amazon Quick Sight read-only dashboard in your website or application. Before you use this command, make sure that you have configured the dashboards and permissions.
Currently, you can use GetDashboardEmbedURL only from the
server, not from the user's browser. The following rules apply to the
generated URL:
- They must be used together.
- They can be used one time only.
- They are valid for 5 minutes after you run this command.
- You are charged only when the URL is used or there is interaction with Quick.
-
The resulting user session is valid for 15 minutes (default) up to 10
hours (maximum). You can use the optional
SessionLifetimeInMinutesparameter to customize session duration.
For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon Quick Developer Portal.
May throw AccessDeniedException.
May throw DomainNotWhitelistedException.
May throw IdentityTypeNotSupportedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw QuickSightUserNotFoundException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw SessionLifetimeInMinutesInvalidException.
May throw ThrottlingException.
May throw UnsupportedPricingPlanException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that contains the dashboard
that you're embedding.
Parameter dashboardId :
The ID for the dashboard, also added to the Identity and Access Management
(IAM) policy.
Parameter identityType :
The authentication method that the user uses to sign in.
Parameter additionalDashboardIds :
A list of one or more dashboard IDs that you want anonymous users to have
tempporary access to. Currently, the IdentityType parameter
must be set to ANONYMOUS because other identity types
authenticate as Quick or IAM users. For example, if you set
"--dashboard-id dash_id1 --dashboard-id dash_id2 dash_id3
identity-type ANONYMOUS", the session can access all three
dashboards.
Parameter namespace :
The Amazon Quick Sight namespace that contains the dashboard IDs in this
request. If you're not using a custom namespace, set Namespace =
default.
Parameter resetDisabled :
Remove the reset button on the embedded dashboard. The default is FALSE,
which enables the reset button.
Parameter sessionLifetimeInMinutes :
How many minutes the session is valid. The session lifetime must be 15-600
minutes.
Parameter statePersistenceEnabled :
Adds persistence of state for the user session in an embedded dashboard.
Persistence applies to the sheet and the parameter settings. These are
control settings that the dashboard subscriber (Amazon Quick Sight reader)
chooses while viewing the dashboard. If this is set to TRUE,
the settings are the same when the subscriber reopens the same dashboard
URL. The state is stored in Amazon Quick Sight, not in a browser cookie.
If this is set to FALSE, the state of the user session is not persisted.
The default is FALSE.
Parameter undoRedoDisabled :
Remove the undo/redo button on the embedded dashboard. The default is
FALSE, which enables the undo/redo button.
Parameter userArn :
The Amazon Quick user's Amazon Resource Name (ARN), for use with
QUICKSIGHT identity type. You can use this for any Amazon
Quick users in your account (readers, authors, or admins) authenticated as
one of the following:
- Active Directory (AD) users or group members
- Invited nonfederated users
- IAM users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation.
Implementation
Future<GetDashboardEmbedUrlResponse> getDashboardEmbedUrl({
required String awsAccountId,
required String dashboardId,
required EmbeddingIdentityType identityType,
List<String>? additionalDashboardIds,
String? namespace,
bool? resetDisabled,
int? sessionLifetimeInMinutes,
bool? statePersistenceEnabled,
bool? undoRedoDisabled,
String? userArn,
}) async {
_s.validateNumRange(
'sessionLifetimeInMinutes',
sessionLifetimeInMinutes,
15,
600,
);
final $query = <String, List<String>>{
'creds-type': [identityType.value],
if (additionalDashboardIds != null)
'additional-dashboard-ids': additionalDashboardIds,
if (namespace != null) 'namespace': [namespace],
if (resetDisabled != null) 'reset-disabled': [resetDisabled.toString()],
if (sessionLifetimeInMinutes != null)
'session-lifetime': [sessionLifetimeInMinutes.toString()],
if (statePersistenceEnabled != null)
'state-persistence-enabled': [statePersistenceEnabled.toString()],
if (undoRedoDisabled != null)
'undo-redo-disabled': [undoRedoDisabled.toString()],
if (userArn != null) 'user-arn': [userArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/embed-url',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetDashboardEmbedUrlResponse.fromJson(response);
}