listAnalyses method

Future<ListAnalysesResponse> listAnalyses({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists Amazon Quick Sight analyses that exist in the specified Amazon Web Services account.

May throw InternalFailureException. May throw InvalidNextTokenException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the analyses.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : A pagination token that can be used in a subsequent request.

Implementation

Future<ListAnalysesResponse> listAnalyses({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/analyses',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAnalysesResponse.fromJson(response);
}