listBrands method

Future<ListBrandsResponse> listBrands({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all brands in an Quick Sight account.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidRequestException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that owns the brands that you want to list.

Parameter maxResults : The maximum number of results to be returned in a single request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListBrandsResponse> listBrands({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/brands',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListBrandsResponse.fromJson(response);
}