listDashboardVersions method

Future<ListDashboardVersionsResponse> listDashboardVersions({
  1. required String awsAccountId,
  2. required String dashboardId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the versions of the dashboards in the Amazon Quick Sight subscription.

May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the dashboard that you're listing versions for.

Parameter dashboardId : The ID for the dashboard.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListDashboardVersionsResponse> listDashboardVersions({
  required String awsAccountId,
  required String dashboardId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDashboardVersionsResponse.fromJson(response);
}