listDataSets method

Future<ListDataSetsResponse> listDataSets({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all of the datasets belonging to the current Amazon Web Services account in an Amazon Web Services Region.

The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/*.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListDataSetsResponse> listDataSets({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDataSetsResponse.fromJson(response);
}