listDataSources method

Future<ListDataSourcesResponse> listDataSources({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists data sources in current Amazon Web Services Region that belong to this Amazon Web Services account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListDataSourcesResponse> listDataSources({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/data-sources',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListDataSourcesResponse.fromJson(response);
}