listFolders method
Lists all folders in an account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that contains the folder.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Implementation
Future<ListFoldersResponse> listFolders({
required String awsAccountId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/folders',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFoldersResponse.fromJson(response);
}