listFoldersForResource method

Future<ListFoldersForResourceResponse> listFoldersForResource({
  1. required String awsAccountId,
  2. required String resourceArn,
  3. int? maxResults,
  4. String? nextToken,
})

List all folders that a resource is a member of.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID for the Amazon Web Services account that contains the resource.

Parameter resourceArn : The Amazon Resource Name (ARN) the resource whose folders you need to list.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListFoldersForResourceResponse> listFoldersForResource({
  required String awsAccountId,
  required String resourceArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/resource/${Uri.encodeComponent(resourceArn)}/folders',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListFoldersForResourceResponse.fromJson(response);
}