listGroupMemberships method

Future<ListGroupMembershipsResponse> listGroupMemberships({
  1. required String awsAccountId,
  2. required String groupName,
  3. required String namespace,
  4. int? maxResults,
  5. String? nextToken,
})

Lists member users in a group.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter groupName : The name of the group that you want to see a membership list of.

Parameter namespace : The namespace of the group that you want a list of users from.

Parameter maxResults : The maximum number of results to return from this request.

Parameter nextToken : A pagination token that can be used in a subsequent request.

Implementation

Future<ListGroupMembershipsResponse> listGroupMemberships({
  required String awsAccountId,
  required String groupName,
  required String namespace,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}/members',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListGroupMembershipsResponse.fromJson(response);
}