listIAMPolicyAssignmentsForUser method
Lists all of the IAM policy assignments, including the Amazon Resource Names (ARNs), for the IAM policies assigned to the specified user and group, or groups that the user belongs to.
May throw AccessDeniedException.
May throw ConcurrentUpdatingException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the assignments.
Parameter namespace :
The namespace of the assignment.
Parameter userName :
The name of the user.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Implementation
Future<ListIAMPolicyAssignmentsForUserResponse>
listIAMPolicyAssignmentsForUser({
required String awsAccountId,
required String namespace,
required String userName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/users/${Uri.encodeComponent(userName)}/iam-policy-assignments',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIAMPolicyAssignmentsForUserResponse.fromJson(response);
}