listIdentityPropagationConfigs method
Lists all services and authorized targets that the Quick Sight IAM Identity Center application can access.
This operation is only supported for Quick Sight accounts that use IAM Identity Center.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contain the identity
propagation configurations of.
Parameter maxResults :
The maximum number of results to be returned.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Implementation
Future<ListIdentityPropagationConfigsResponse>
listIdentityPropagationConfigs({
required String awsAccountId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
10,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/identity-propagation-config',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIdentityPropagationConfigsResponse.fromJson(response);
}