listKnowledgeBases method
Lists all knowledge bases in an Amazon QuickSight account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw PreconditionNotMetException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the knowledge
base.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Implementation
Future<ListKnowledgeBasesResponse> listKnowledgeBases({
required String awsAccountId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/accounts/${Uri.encodeComponent(awsAccountId)}/knowledge-bases',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListKnowledgeBasesResponse.fromJson(response);
}