listOAuthClientApplications method

Future<ListOAuthClientApplicationsResponse> listOAuthClientApplications({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all OAuthClientApplications in the current Amazon Web Services Region that belong to this Amazon Web Services account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The Amazon Web Services account ID.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : A pagination token that can be used in a subsequent request.

Implementation

Future<ListOAuthClientApplicationsResponse> listOAuthClientApplications({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/oauth-client-applications',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListOAuthClientApplicationsResponse.fromJson(response);
}