listRoleMemberships method

Future<ListRoleMembershipsResponse> listRoleMemberships({
  1. required String awsAccountId,
  2. required String namespace,
  3. required Role role,
  4. int? maxResults,
  5. String? nextToken,
})

Lists all groups that are associated with a role.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter namespace : The namespace that includes the role.

Parameter role : The name of the role.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : A pagination token that can be used in a subsequent request.

Implementation

Future<ListRoleMembershipsResponse> listRoleMemberships({
  required String awsAccountId,
  required String namespace,
  required Role role,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/roles/${Uri.encodeComponent(role.value)}/members',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRoleMembershipsResponse.fromJson(response);
}