listSelfUpgrades method

Future<ListSelfUpgradesResponse> listSelfUpgrades({
  1. required String awsAccountId,
  2. required String namespace,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all self-upgrade requests for a Quick account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the self-upgrade requests.

Parameter namespace : The Quick namespace for the self-upgrade requests.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListSelfUpgradesResponse> listSelfUpgrades({
  required String awsAccountId,
  required String namespace,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/self-upgrade-requests',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSelfUpgradesResponse.fromJson(response);
}