listSpaceResources method

Future<ListSpaceResourcesResponse> listSpaceResources({
  1. required String awsAccountId,
  2. required String spaceId,
})

Lists the resources in an Amazon QuickSight space.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the space.

Parameter spaceId : The ID of the space that you want to list resources for.

Implementation

Future<ListSpaceResourcesResponse> listSpaceResources({
  required String awsAccountId,
  required String spaceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces/${Uri.encodeComponent(spaceId)}/resources',
    exceptionFnMap: _exceptionFns,
  );
  return ListSpaceResourcesResponse.fromJson(response);
}