listSpaces method

Future<ListSpacesResponse> listSpaces({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all Amazon QuickSight spaces in an Amazon Web Services account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the spaces.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListSpacesResponse> listSpaces({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSpacesResponse.fromJson(response);
}