listTemplateVersions method

Future<ListTemplateVersionsResponse> listTemplateVersions({
  1. required String awsAccountId,
  2. required String templateId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the versions of the templates in the current Amazon Quick Sight account.

May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the templates that you're listing.

Parameter templateId : The ID for the template.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListTemplateVersionsResponse> listTemplateVersions({
  required String awsAccountId,
  required String templateId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/templates/${Uri.encodeComponent(templateId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTemplateVersionsResponse.fromJson(response);
}