listTemplates method

Future<ListTemplatesResponse> listTemplates({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all the templates in the current Amazon Quick Sight account.

May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the templates that you're listing.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListTemplatesResponse> listTemplates({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-result': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/templates',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTemplatesResponse.fromJson(response);
}