listThemeAliases method

Future<ListThemeAliasesResponse> listThemeAliases({
  1. required String awsAccountId,
  2. required String themeId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the aliases of a theme.

May throw ConflictException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the theme aliases that you're listing.

Parameter themeId : The ID for the theme.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListThemeAliasesResponse> listThemeAliases({
  required String awsAccountId,
  required String themeId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-result': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}/aliases',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListThemeAliasesResponse.fromJson(response);
}