listThemeVersions method

Future<ListThemeVersionsResponse> listThemeVersions({
  1. required String awsAccountId,
  2. required String themeId,
  3. int? maxResults,
  4. String? nextToken,
})

Lists all the versions of the themes in the current Amazon Web Services account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the themes that you're listing.

Parameter themeId : The ID for the theme.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListThemeVersionsResponse> listThemeVersions({
  required String awsAccountId,
  required String themeId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}/versions',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListThemeVersionsResponse.fromJson(response);
}