listTopicRefreshSchedules method

Future<ListTopicRefreshSchedulesResponse> listTopicRefreshSchedules({
  1. required String awsAccountId,
  2. required String topicId,
})

Lists all of the refresh schedules for a topic.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want described.

Parameter topicId : The ID for the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Implementation

Future<ListTopicRefreshSchedulesResponse> listTopicRefreshSchedules({
  required String awsAccountId,
  required String topicId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/schedules',
    exceptionFnMap: _exceptionFns,
  );
  return ListTopicRefreshSchedulesResponse.fromJson(response);
}