listUsers method
Returns a list of all of the Amazon Quick Sight users belonging to this account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that the user is in. Currently,
you use the ID for the Amazon Web Services account that contains your
Amazon Quick Sight account.
Parameter namespace :
The namespace. Currently, you should set this to default.
Parameter maxResults :
The maximum number of results to return from this request.
Parameter nextToken :
A pagination token that can be used in a subsequent request.
Implementation
Future<ListUsersResponse> listUsers({
required String awsAccountId,
required String namespace,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/users',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListUsersResponse.fromJson(response);
}