listVPCConnections method

Future<ListVPCConnectionsResponse> listVPCConnections({
  1. required String awsAccountId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all of the VPC connections in the current set Amazon Web Services Region of an Amazon Web Services account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The Amazon Web Services account ID of the account that contains the VPC connections that you want to list.

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<ListVPCConnectionsResponse> listVPCConnections({
  required String awsAccountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'max-results': [maxResults.toString()],
    if (nextToken != null) 'next-token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/vpc-connections',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListVPCConnectionsResponse.fromJson(response);
}