searchAnalyses method
Searches for analyses that belong to the user specified in the filter.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the analyses that
you're searching for.
Parameter filters :
The structure for the search filters that you want to apply to your
search.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
A pagination token that can be used in a subsequent request.
Implementation
Future<SearchAnalysesResponse> searchAnalyses({
required String awsAccountId,
required List<AnalysisSearchFilter> filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/search/analyses',
exceptionFnMap: _exceptionFns,
);
return SearchAnalysesResponse.fromJson(response);
}