searchFolders method

Future<SearchFoldersResponse> searchFolders({
  1. required String awsAccountId,
  2. required List<FolderSearchFilter> filters,
  3. int? maxResults,
  4. String? nextToken,
})

Searches the subfolders in a folder.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidNextTokenException. May throw InvalidParameterValueException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID for the Amazon Web Services account that contains the folder.

Parameter filters : The filters to apply to the search. Currently, you can search only by the parent folder ARN. For example, "Filters": [ { "Name": "PARENT_FOLDER_ARN", "Operator": "StringEquals", "Value": "arn:aws:quicksight:us-east-1:1:folder/folderId" } ].

Parameter maxResults : The maximum number of results to be returned per request.

Parameter nextToken : The token for the next set of results, or null if there are no more results.

Implementation

Future<SearchFoldersResponse> searchFolders({
  required String awsAccountId,
  required List<FolderSearchFilter> filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $payload = <String, dynamic>{
    'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/search/folders',
    exceptionFnMap: _exceptionFns,
  );
  return SearchFoldersResponse.fromJson(response);
}