searchSpaces method
Searches for Amazon QuickSight spaces that match the specified filters.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the spaces.
Parameter filters :
The filters to apply to the search.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Implementation
Future<SearchSpacesResponse> searchSpaces({
required String awsAccountId,
required List<SpaceQuicksightSearchFilter> filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v1/accounts/${Uri.encodeComponent(awsAccountId)}/search/spaces',
exceptionFnMap: _exceptionFns,
);
return SearchSpacesResponse.fromJson(response);
}