startAssetBundleImportJob method
- required String assetBundleImportJobId,
- required AssetBundleImportSource assetBundleImportSource,
- required String awsAccountId,
- AssetBundleImportFailureAction? failureAction,
- AssetBundleImportJobOverrideParameters? overrideParameters,
- AssetBundleImportJobOverridePermissions? overridePermissions,
- AssetBundleImportJobOverrideTags? overrideTags,
- AssetBundleImportJobOverrideValidationStrategy? overrideValidationStrategy,
Starts an Asset Bundle import job.
An Asset Bundle import job imports specified Amazon Quick Sight assets into an Amazon Quick Sight account. You can also choose to import a naming prefix and specified configuration overrides. The assets that are contained in the bundle file that you provide are used to create or update a new or existing asset in your Amazon Quick Sight account. Each Amazon Quick Sight account can run up to 5 import jobs concurrently.
The API caller must have the necessary "create",
"describe", and "update" permissions in their
IAM role to access each resource type that is contained in the bundle file
before the resources can be imported.
May throw AccessDeniedException.
May throw ConflictException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter assetBundleImportJobId :
The ID of the job. This ID is unique while the job is running. After the
job is completed, you can reuse this ID for another job.
Parameter assetBundleImportSource :
The source of the asset bundle zip file that contains the data that you
want to import. The file must be in QUICKSIGHT_JSON format.
Parameter awsAccountId :
The ID of the Amazon Web Services account to import assets into.
Parameter failureAction :
The failure action for the import job.
If you choose ROLLBACK, failed import jobs will attempt to
undo any asset changes caused by the failed job.
If you choose DO_NOTHING, failed import jobs will not attempt
to roll back any asset changes caused by the failed job, possibly keeping
the Amazon Quick Sight account in an inconsistent state.
Parameter overrideParameters :
Optional overrides that are applied to the resource configuration before
import.
Parameter overridePermissions :
Optional permission overrides that are applied to the resource
configuration before import.
Parameter overrideTags :
Optional tag overrides that are applied to the resource configuration
before import.
Parameter overrideValidationStrategy :
An optional validation strategy override for all analyses and dashboards
that is applied to the resource configuration before import.
Implementation
Future<StartAssetBundleImportJobResponse> startAssetBundleImportJob({
required String assetBundleImportJobId,
required AssetBundleImportSource assetBundleImportSource,
required String awsAccountId,
AssetBundleImportFailureAction? failureAction,
AssetBundleImportJobOverrideParameters? overrideParameters,
AssetBundleImportJobOverridePermissions? overridePermissions,
AssetBundleImportJobOverrideTags? overrideTags,
AssetBundleImportJobOverrideValidationStrategy? overrideValidationStrategy,
}) async {
final $payload = <String, dynamic>{
'AssetBundleImportJobId': assetBundleImportJobId,
'AssetBundleImportSource': assetBundleImportSource,
if (failureAction != null) 'FailureAction': failureAction.value,
if (overrideParameters != null) 'OverrideParameters': overrideParameters,
if (overridePermissions != null)
'OverridePermissions': overridePermissions,
if (overrideTags != null) 'OverrideTags': overrideTags,
if (overrideValidationStrategy != null)
'OverrideValidationStrategy': overrideValidationStrategy,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/asset-bundle-import-jobs/import',
exceptionFnMap: _exceptionFns,
);
return StartAssetBundleImportJobResponse.fromJson(response);
}