startDashboardSnapshotJobSchedule method

Future<StartDashboardSnapshotJobScheduleResponse> startDashboardSnapshotJobSchedule({
  1. required String awsAccountId,
  2. required String dashboardId,
  3. required String scheduleId,
})

Starts an asynchronous job that runs an existing dashboard schedule and sends the dashboard snapshot through email.

Only one job can run simultaneously in a given schedule. Repeated requests are skipped with a 202 HTTP status code.

For more information, see Scheduling and sending Amazon Quick Sight reports by email and Configuring email report settings for a Amazon Quick Sight dashboard in the Amazon Quick Sight User Guide.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.

Parameter dashboardId : The ID of the dashboard that you want to start a snapshot job schedule for.

Parameter scheduleId : The ID of the schedule that you want to start a snapshot job schedule for. The schedule ID can be found in the Amazon Quick Sight console in the Schedules pane of the dashboard that the schedule is configured for.

Implementation

Future<StartDashboardSnapshotJobScheduleResponse>
    startDashboardSnapshotJobSchedule({
  required String awsAccountId,
  required String dashboardId,
  required String scheduleId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/schedules/${Uri.encodeComponent(scheduleId)}',
    exceptionFnMap: _exceptionFns,
  );
  return StartDashboardSnapshotJobScheduleResponse.fromJson(response);
}