updateAccountCustomPermission method

Future<UpdateAccountCustomPermissionResponse> updateAccountCustomPermission({
  1. required String awsAccountId,
  2. required String customPermissionsName,
})

Applies a custom permissions profile to an account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account for which you want to apply a custom permissions profile.

Parameter customPermissionsName : The name of the custom permissions profile that you want to apply to an account.

Implementation

Future<UpdateAccountCustomPermissionResponse> updateAccountCustomPermission({
  required String awsAccountId,
  required String customPermissionsName,
}) async {
  final $payload = <String, dynamic>{
    'CustomPermissionsName': customPermissionsName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permission',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateAccountCustomPermissionResponse.fromJson(response);
}