updateAccountCustomization method

Future<UpdateAccountCustomizationResponse> updateAccountCustomization({
  1. required AccountCustomization accountCustomization,
  2. required String awsAccountId,
  3. String? namespace,
})

Updates Amazon Quick Sight customizations. Currently, the only customization that you can use is a theme.

You can use customizations for your Amazon Web Services account or, if you specify a namespace, for a Quick Sight namespace instead. Customizations that apply to a namespace override customizations that apply to an Amazon Web Services account. To find out which customizations apply, use the DescribeAccountCustomization API operation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter accountCustomization : The Quick Sight customizations you're updating.

Parameter awsAccountId : The ID for the Amazon Web Services account that you want to update Quick Sight customizations for.

Parameter namespace : The namespace that you want to update Quick Sight customizations for.

Implementation

Future<UpdateAccountCustomizationResponse> updateAccountCustomization({
  required AccountCustomization accountCustomization,
  required String awsAccountId,
  String? namespace,
}) async {
  final $query = <String, List<String>>{
    if (namespace != null) 'namespace': [namespace],
  };
  final $payload = <String, dynamic>{
    'AccountCustomization': accountCustomization,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/customizations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateAccountCustomizationResponse.fromJson(response);
}