updateActionConnector method

Future<UpdateActionConnectorResponse> updateActionConnector({
  1. required String actionConnectorId,
  2. required AuthConfig authenticationConfig,
  3. required String awsAccountId,
  4. required String name,
  5. String? description,
  6. String? vpcConnectionArn,
})

Updates an existing action connector with new configuration details, authentication settings, or enabled actions. You can modify the connector's name, description, authentication configuration, and which actions are enabled. For more information, https://docs.aws.amazon.com/quicksuite/latest/userguide/quick-action-auth.html.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter actionConnectorId : The unique identifier of the action connector to update.

Parameter authenticationConfig : The updated authentication configuration for connecting to the external service.

Parameter awsAccountId : The Amazon Web Services account ID that contains the action connector to update.

Parameter name : The new name for the action connector.

Parameter description : The updated description of the action connector.

Parameter vpcConnectionArn : The updated ARN of the VPC connection to use for secure connectivity.

Implementation

Future<UpdateActionConnectorResponse> updateActionConnector({
  required String actionConnectorId,
  required AuthConfig authenticationConfig,
  required String awsAccountId,
  required String name,
  String? description,
  String? vpcConnectionArn,
}) async {
  final $payload = <String, dynamic>{
    'AuthenticationConfig': authenticationConfig,
    'Name': name,
    if (description != null) 'Description': description,
    if (vpcConnectionArn != null) 'VpcConnectionArn': vpcConnectionArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/action-connectors/${Uri.encodeComponent(actionConnectorId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateActionConnectorResponse.fromJson(response);
}