updateApplicationWithTokenExchangeGrant method

Future<UpdateApplicationWithTokenExchangeGrantResponse> updateApplicationWithTokenExchangeGrant({
  1. required String awsAccountId,
  2. required String namespace,
})

Updates an Quick application with a token exchange grant. This operation only supports Quick applications that are registered with IAM Identity Center.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw InvalidRequestException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account to be updated with a token exchange grant.

Parameter namespace : The namespace of the Quick application.

Implementation

Future<UpdateApplicationWithTokenExchangeGrantResponse>
    updateApplicationWithTokenExchangeGrant({
  required String awsAccountId,
  required String namespace,
}) async {
  final $query = <String, List<String>>{
    'namespace': [namespace],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/application-with-token-exchange-grant',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateApplicationWithTokenExchangeGrantResponse.fromJson(response);
}