updateCustomPermissions method

Future<UpdateCustomPermissionsResponse> updateCustomPermissions({
  1. required String awsAccountId,
  2. required String customPermissionsName,
  3. Capabilities? capabilities,
})

Updates a custom permissions profile.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the custom permissions profile that you want to update.

Parameter customPermissionsName : The name of the custom permissions profile that you want to update.

Parameter capabilities : A set of actions to include in the custom permissions profile.

Implementation

Future<UpdateCustomPermissionsResponse> updateCustomPermissions({
  required String awsAccountId,
  required String customPermissionsName,
  Capabilities? capabilities,
}) async {
  final $payload = <String, dynamic>{
    if (capabilities != null) 'Capabilities': capabilities,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permissions/${Uri.encodeComponent(customPermissionsName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateCustomPermissionsResponse.fromJson(response);
}