updateDashboardLinks method

Future<UpdateDashboardLinksResponse> updateDashboardLinks({
  1. required String awsAccountId,
  2. required String dashboardId,
  3. required List<String> linkEntities,
})

Updates the linked analyses on a dashboard.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the dashboard whose links you want to update.

Parameter dashboardId : The ID for the dashboard.

Parameter linkEntities : list of analysis Amazon Resource Names (ARNs) to be linked to the dashboard.

Implementation

Future<UpdateDashboardLinksResponse> updateDashboardLinks({
  required String awsAccountId,
  required String dashboardId,
  required List<String> linkEntities,
}) async {
  final $payload = <String, dynamic>{
    'LinkEntities': linkEntities,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/linked-entities',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateDashboardLinksResponse.fromJson(response);
}