updateDataSetPermissions method
Updates the permissions on a dataset.
The permissions resource is
arn:aws:quicksight:region:aws-account-id:dataset/data-set-id.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The Amazon Web Services account ID.
Parameter dataSetId :
The ID for the dataset whose permissions you want to update. This ID is
unique per Amazon Web Services Region for each Amazon Web Services
account.
Parameter grantPermissions :
The resource permissions that you want to grant to the dataset.
Parameter revokePermissions :
The resource permissions that you want to revoke from the dataset.
Implementation
Future<UpdateDataSetPermissionsResponse> updateDataSetPermissions({
required String awsAccountId,
required String dataSetId,
List<ResourcePermission>? grantPermissions,
List<ResourcePermission>? revokePermissions,
}) async {
final $payload = <String, dynamic>{
if (grantPermissions != null) 'GrantPermissions': grantPermissions,
if (revokePermissions != null) 'RevokePermissions': revokePermissions,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/data-sets/${Uri.encodeComponent(dataSetId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return UpdateDataSetPermissionsResponse.fromJson(response);
}