updateDefaultQBusinessApplication method

Future<UpdateDefaultQBusinessApplicationResponse> updateDefaultQBusinessApplication({
  1. required String applicationId,
  2. required String awsAccountId,
  3. String? namespace,
})

Updates a Amazon Q Business application that is linked to a Quick Sight account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter applicationId : The ID of the Amazon Q Business application that you want to update.

Parameter awsAccountId : The ID of the Quick Sight account that is connected to the Amazon Q Business application that you want to update.

Parameter namespace : The Quick Sight namespace that contains the linked Amazon Q Business application. If this field is left blank, the default namespace is used. Currently, the default namespace is the only valid value for this parameter.

Implementation

Future<UpdateDefaultQBusinessApplicationResponse>
    updateDefaultQBusinessApplication({
  required String applicationId,
  required String awsAccountId,
  String? namespace,
}) async {
  final $query = <String, List<String>>{
    if (namespace != null) 'namespace': [namespace],
  };
  final $payload = <String, dynamic>{
    'ApplicationId': applicationId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/default-qbusiness-application',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return UpdateDefaultQBusinessApplicationResponse.fromJson(response);
}