updateGroup method

Future<UpdateGroupResponse> updateGroup({
  1. required String awsAccountId,
  2. required String groupName,
  3. required String namespace,
  4. String? description,
})

Changes a group description.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw PreconditionNotMetException. May throw ResourceNotFoundException. May throw ResourceUnavailableException. May throw ThrottlingException.

Parameter awsAccountId : The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Parameter groupName : The name of the group that you want to update.

Parameter namespace : The namespace of the group that you want to update.

Parameter description : The description for the group that you want to update.

Implementation

Future<UpdateGroupResponse> updateGroup({
  required String awsAccountId,
  required String groupName,
  required String namespace,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'Description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/groups/${Uri.encodeComponent(groupName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateGroupResponse.fromJson(response);
}