updateKeyRegistration method

Future<UpdateKeyRegistrationResponse> updateKeyRegistration({
  1. required String awsAccountId,
  2. required List<RegisteredCustomerManagedKey> keyRegistration,
})

Updates a customer managed key in a Quick Sight account.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the customer managed key registration that you want to update.

Parameter keyRegistration : A list of RegisteredCustomerManagedKey objects to be updated to the Quick Sight account.

Implementation

Future<UpdateKeyRegistrationResponse> updateKeyRegistration({
  required String awsAccountId,
  required List<RegisteredCustomerManagedKey> keyRegistration,
}) async {
  final $payload = <String, dynamic>{
    'KeyRegistration': keyRegistration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/key-registration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateKeyRegistrationResponse.fromJson(response);
}