updatePublicSharingSettings method

Future<UpdatePublicSharingSettingsResponse> updatePublicSharingSettings({
  1. required String awsAccountId,
  2. bool? publicSharingEnabled,
})
Use the UpdatePublicSharingSettings operation to turn on or turn off the public sharing settings of an Amazon Quick Sight dashboard.

To use this operation, turn on session capacity pricing for your Amazon Quick Sight account.

Before you can turn on public sharing on your account, make sure to give public sharing permissions to an administrative user in the Identity and Access Management (IAM) console. For more information on using IAM with Amazon Quick Sight, see Using Quick with IAM in the Amazon Quick Sight User Guide.

May throw AccessDeniedException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedPricingPlanException.

Parameter awsAccountId : The Amazon Web Services account ID associated with your Amazon Quick Sight subscription.

Parameter publicSharingEnabled : A Boolean value that indicates whether public sharing is turned on for an Quick account.

Implementation

Future<UpdatePublicSharingSettingsResponse> updatePublicSharingSettings({
  required String awsAccountId,
  bool? publicSharingEnabled,
}) async {
  final $payload = <String, dynamic>{
    if (publicSharingEnabled != null)
      'PublicSharingEnabled': publicSharingEnabled,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/public-sharing-settings',
    exceptionFnMap: _exceptionFns,
  );
  return UpdatePublicSharingSettingsResponse.fromJson(response);
}