updateQuickSightQSearchConfiguration method

Future<UpdateQuickSightQSearchConfigurationResponse> updateQuickSightQSearchConfiguration({
  1. required String awsAccountId,
  2. required QSearchStatus qSearchStatus,
})

Updates the state of a Quick Sight Q Search configuration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the Quick Sight Q Search configuration that you want to update.

Parameter qSearchStatus : The status of the Quick Sight Q Search configuration that the user wants to update.

Implementation

Future<UpdateQuickSightQSearchConfigurationResponse>
    updateQuickSightQSearchConfiguration({
  required String awsAccountId,
  required QSearchStatus qSearchStatus,
}) async {
  final $payload = <String, dynamic>{
    'QSearchStatus': qSearchStatus.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/quicksight-q-search-configuration',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateQuickSightQSearchConfigurationResponse.fromJson(response);
}