updateSelfUpgrade method
Updates a self-upgrade request for a Quick user by approving, denying, or verifying the request.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter action :
The action to perform on the self-upgrade request. Valid values are
APPROVE, DENY, or VERIFY.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the self-upgrade
request.
Parameter namespace :
The Quick namespace for the self-upgrade request.
Parameter upgradeRequestId :
The ID of the self-upgrade request to update.
Implementation
Future<UpdateSelfUpgradeResponse> updateSelfUpgrade({
required SelfUpgradeAdminAction action,
required String awsAccountId,
required String namespace,
required String upgradeRequestId,
}) async {
final $payload = <String, dynamic>{
'Action': action.value,
'UpgradeRequestId': upgradeRequestId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/update-self-upgrade-request',
exceptionFnMap: _exceptionFns,
);
return UpdateSelfUpgradeResponse.fromJson(response);
}