updateSpacePermissions method
Updates the permissions for an Amazon QuickSight space.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the space.
Parameter spaceId :
The ID of the space that you want to update permissions for.
Parameter grantPermissions :
The permissions that you want to grant on the space.
Parameter revokePermissions :
The permissions that you want to revoke from the space.
Implementation
Future<UpdateSpacePermissionsResponse> updateSpacePermissions({
required String awsAccountId,
required String spaceId,
List<ResourcePermission>? grantPermissions,
List<ResourcePermission>? revokePermissions,
}) async {
final $payload = <String, dynamic>{
if (grantPermissions != null) 'GrantPermissions': grantPermissions,
if (revokePermissions != null) 'RevokePermissions': revokePermissions,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces/${Uri.encodeComponent(spaceId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return UpdateSpacePermissionsResponse.fromJson(response);
}