updateTheme method
Updates a theme.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the theme that
you're updating.
Parameter baseThemeId :
The theme ID, defined by Amazon Quick Sight, that a custom theme inherits
from. All themes initially inherit from a default Quick Sight theme.
Parameter themeId :
The ID for the theme.
Parameter configuration :
The theme configuration, which contains the theme display properties.
Parameter name :
The name for the theme.
Parameter versionDescription :
A description of the theme version that you're updating Every time that
you call UpdateTheme, you create a new version of the theme.
Each version of the theme maintains a description of the version in
VersionDescription.
Implementation
Future<UpdateThemeResponse> updateTheme({
required String awsAccountId,
required String baseThemeId,
required String themeId,
ThemeConfiguration? configuration,
String? name,
String? versionDescription,
}) async {
final $payload = <String, dynamic>{
'BaseThemeId': baseThemeId,
if (configuration != null) 'Configuration': configuration,
if (name != null) 'Name': name,
if (versionDescription != null) 'VersionDescription': versionDescription,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateThemeResponse.fromJson(response);
}