updateThemeAlias method

Future<UpdateThemeAliasResponse> updateThemeAlias({
  1. required String aliasName,
  2. required String awsAccountId,
  3. required String themeId,
  4. required int themeVersionNumber,
})

Updates an alias of a theme.

May throw ConflictException. May throw InternalFailureException. May throw InvalidParameterValueException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw UnsupportedUserEditionException.

Parameter aliasName : The name of the theme alias that you want to update.

Parameter awsAccountId : The ID of the Amazon Web Services account that contains the theme alias that you're updating.

Parameter themeId : The ID for the theme.

Parameter themeVersionNumber : The version number of the theme that the alias should reference.

Implementation

Future<UpdateThemeAliasResponse> updateThemeAlias({
  required String aliasName,
  required String awsAccountId,
  required String themeId,
  required int themeVersionNumber,
}) async {
  _s.validateNumRange(
    'themeVersionNumber',
    themeVersionNumber,
    1,
    1152921504606846976,
    isRequired: true,
  );
  final $payload = <String, dynamic>{
    'ThemeVersionNumber': themeVersionNumber,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}/aliases/${Uri.encodeComponent(aliasName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateThemeAliasResponse.fromJson(response);
}