acceptResourceShareInvitation method

Future<AcceptResourceShareInvitationResponse> acceptResourceShareInvitation({
  1. required String resourceShareInvitationArn,
  2. String? clientToken,
})

Accepts an invitation to a resource share from another Amazon Web Services account. After you accept the invitation, the resources included in the resource share are available to interact with in the relevant Amazon Web Services Management Consoles and tools.

May throw IdempotentParameterMismatchException. May throw InvalidClientTokenException. May throw MalformedArnException. May throw OperationNotPermittedException. May throw ResourceShareInvitationAlreadyAcceptedException. May throw ResourceShareInvitationAlreadyRejectedException. May throw ResourceShareInvitationArnNotFoundException. May throw ResourceShareInvitationExpiredException. May throw ServerInternalException. May throw ServiceUnavailableException.

Parameter resourceShareInvitationArn : The Amazon Resource Name (ARN) of the invitation that you want to accept.

Parameter clientToken : Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value..

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotentParameterMismatch error.

Implementation

Future<AcceptResourceShareInvitationResponse> acceptResourceShareInvitation({
  required String resourceShareInvitationArn,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'resourceShareInvitationArn': resourceShareInvitationArn,
    if (clientToken != null) 'clientToken': clientToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/acceptresourceshareinvitation',
    exceptionFnMap: _exceptionFns,
  );
  return AcceptResourceShareInvitationResponse.fromJson(response);
}