associateResourceSharePermission method
Adds or replaces the RAM permission for a resource type included in a resource share. You can have exactly one permission associated with each resource type in the resource share. You can add a new RAM permission only if there are currently no resources of that resource type currently in the resource share.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter permissionArn :
Specifies the Amazon
Resource Name (ARN) of the RAM permission to associate with the
resource share. To find the ARN for a permission, use either the
ListPermissions operation or go to the Permissions
library page in the RAM console and then choose the name of the
permission. The ARN is displayed on the detail page.
Parameter resourceShareArn :
Specifies the Amazon
Resource Name (ARN) of the resource share to which you want to add or
replace permissions.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter permissionVersion :
Specifies the version of the RAM permission to associate with the resource
share. You can specify only the version that is currently set as
the default version for the permission. If you also set the
replace pararameter to true, then this operation
updates an outdated version of the permission to the current default
version.
Parameter replace :
Specifies whether the specified permission should replace the existing
permission associated with the resource share. Use true to
replace the current permissions. Use false to add the
permission to a resource share that currently doesn't have a permission.
The default value is false.
Implementation
Future<AssociateResourceSharePermissionResponse>
associateResourceSharePermission({
required String permissionArn,
required String resourceShareArn,
String? clientToken,
int? permissionVersion,
bool? replace,
}) async {
final $payload = <String, dynamic>{
'permissionArn': permissionArn,
'resourceShareArn': resourceShareArn,
if (clientToken != null) 'clientToken': clientToken,
if (permissionVersion != null) 'permissionVersion': permissionVersion,
if (replace != null) 'replace': replace,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/associateresourcesharepermission',
exceptionFnMap: _exceptionFns,
);
return AssociateResourceSharePermissionResponse.fromJson(response);
}