createPermission method
Creates a customer managed permission for a specified resource type that you can attach to resource shares. It is created in the Amazon Web Services Region in which you call the operation.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw InvalidPolicyException.
May throw MalformedPolicyTemplateException.
May throw OperationNotPermittedException.
May throw PermissionAlreadyExistsException.
May throw PermissionLimitExceededException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
Parameter name :
Specifies the name of the customer managed permission. The name must be
unique within the Amazon Web Services Region.
Parameter policyTemplate :
A string in JSON format string that contains the following elements of a
resource-based policy:
-
Effect: must be set to
ALLOW. - Action: specifies the actions that are allowed by this customer managed permission. The list must contain only actions that are supported by the specified resource type. For a list of all actions supported by each resource type, see Actions, resources, and condition keys for Amazon Web Services services in the Identity and Access Management User Guide.
- Condition: (optional) specifies conditional parameters that must evaluate to true when a user attempts an action for that action to be allowed. For more information about the Condition element, see IAM policies: Condition element in the Identity and Access Management User Guide.
Resource or
Principal elements. Those are both filled in by RAM when it
instantiates the resource-based policy on each resource shared using this
managed permission. The Resource comes from the ARN of the
specific resource that you are sharing. The Principal comes
from the list of identities added to the resource share.
Parameter resourceType :
Specifies the name of the resource type that this customer managed
permission applies to.
The format is :
and is case sensitive. For example, to specify an Amazon EC2 Subnet, you
can use the string ec2:Subnet. To see the list of valid
values for this parameter, query the ListResourceTypes operation.
This value must match the display name of the resource (available in
ListResourceTypes).
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter tags :
Specifies a list of one or more tag key and value pairs to attach to the
permission.
Implementation
Future<CreatePermissionResponse> createPermission({
required String name,
required String policyTemplate,
required String resourceType,
String? clientToken,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'name': name,
'policyTemplate': policyTemplate,
'resourceType': resourceType,
if (clientToken != null) 'clientToken': clientToken,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/createpermission',
exceptionFnMap: _exceptionFns,
);
return CreatePermissionResponse.fromJson(response);
}