createPermissionVersion method
Creates a new version of the specified customer managed permission. The new version is automatically set as the default version of the customer managed permission. New resource shares automatically use the default permission. Existing resource shares continue to use their original permission versions, but you can use ReplacePermissionAssociations to update them.
If the specified customer managed permission already has the maximum of 5 versions, then you must delete one of the existing versions before you can create a new one.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw InvalidPolicyException.
May throw MalformedArnException.
May throw MalformedPolicyTemplateException.
May throw PermissionVersionsLimitExceededException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter permissionArn :
Specifies the Amazon
Resource Name (ARN) of the customer managed permission you're creating
a new version for.
Parameter policyTemplate :
A string in JSON format string that contains the following elements of a
resource-based policy:
-
Effect: must be set to
ALLOW. - Action: specifies the actions that are allowed by this customer managed permission. The list must contain only actions that are supported by the specified resource type. For a list of all actions supported by each resource type, see Actions, resources, and condition keys for Amazon Web Services services in the Identity and Access Management User Guide.
- Condition: (optional) specifies conditional parameters that must evaluate to true when a user attempts an action for that action to be allowed. For more information about the Condition element, see IAM policies: Condition element in the Identity and Access Management User Guide.
Resource or
Principal elements. Those are both filled in by RAM when it
instantiates the resource-based policy on each resource shared using this
managed permission. The Resource comes from the ARN of the
specific resource that you are sharing. The Principal comes
from the list of identities added to the resource share.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Implementation
Future<CreatePermissionVersionResponse> createPermissionVersion({
required String permissionArn,
required String policyTemplate,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'permissionArn': permissionArn,
'policyTemplate': policyTemplate,
if (clientToken != null) 'clientToken': clientToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/createpermissionversion',
exceptionFnMap: _exceptionFns,
);
return CreatePermissionVersionResponse.fromJson(response);
}