deletePermission method

Future<DeletePermissionResponse> deletePermission({
  1. required String permissionArn,
  2. String? clientToken,
})

Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation. You can delete a customer managed permission only if it isn't attached to any resource share. The operation deletes all versions associated with the customer managed permission.

May throw IdempotentParameterMismatchException. May throw InvalidClientTokenException. May throw MalformedArnException. May throw OperationNotPermittedException. May throw ServerInternalException. May throw ServiceUnavailableException. May throw UnknownResourceException.

Parameter permissionArn : Specifies the Amazon Resource Name (ARN) of the customer managed permission that you want to delete.

Parameter clientToken : Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value..

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotentParameterMismatch error.

Implementation

Future<DeletePermissionResponse> deletePermission({
  required String permissionArn,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    'permissionArn': [permissionArn],
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/deletepermission',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeletePermissionResponse.fromJson(response);
}