deleteResourceShare method

Future<DeleteResourceShareResponse> deleteResourceShare({
  1. required String resourceShareArn,
  2. String? clientToken,
})

Deletes the specified resource share.

May throw IdempotentParameterMismatchException. May throw InvalidClientTokenException. May throw InvalidParameterException. May throw InvalidStateTransitionException. May throw MalformedArnException. May throw OperationNotPermittedException. May throw ServerInternalException. May throw ServiceUnavailableException. May throw ThrottlingException. May throw UnknownResourceException.

Parameter resourceShareArn : Specifies the Amazon Resource Name (ARN) of the resource share to delete.

Parameter clientToken : Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value..

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotentParameterMismatch error.

Implementation

Future<DeleteResourceShareResponse> deleteResourceShare({
  required String resourceShareArn,
  String? clientToken,
}) async {
  final $query = <String, List<String>>{
    'resourceShareArn': [resourceShareArn],
    if (clientToken != null) 'clientToken': [clientToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/deleteresourceshare',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteResourceShareResponse.fromJson(response);
}