getResourcePolicies method

Future<GetResourcePoliciesResponse> getResourcePolicies({
  1. required List<String> resourceArns,
  2. int? maxResults,
  3. String? nextToken,
  4. String? principal,
})

Retrieves the resource policies for the specified resources that you own and have shared.

May throw InvalidNextTokenException. May throw InvalidParameterException. May throw MalformedArnException. May throw ResourceArnNotFoundException. May throw ServerInternalException. May throw ServiceUnavailableException.

Parameter resourceArns : Specifies the Amazon Resource Names (ARNs) of the resources whose policies you want to retrieve.

Parameter maxResults : Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's NextToken response to request the next page of results.

Parameter principal : Specifies the principal.

Implementation

Future<GetResourcePoliciesResponse> getResourcePolicies({
  required List<String> resourceArns,
  int? maxResults,
  String? nextToken,
  String? principal,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $payload = <String, dynamic>{
    'resourceArns': resourceArns,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (principal != null) 'principal': principal,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/getresourcepolicies',
    exceptionFnMap: _exceptionFns,
  );
  return GetResourcePoliciesResponse.fromJson(response);
}