getResourceShareInvitations method
Retrieves details about invitations that you have received for resource shares.
May throw InvalidMaxResultsException.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw ResourceShareInvitationArnNotFoundException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter maxResults :
Specifies the total number of results that you want included on each page
of the response. If you do not include this parameter, it defaults to a
value that is specific to the operation. If additional items exist beyond
the number you specify, the NextToken response element is
returned with a value (not null). Include the specified value as the
NextToken request parameter in the next call to the operation
to get the next part of the results. Note that the service might return
fewer results than the maximum even when there are more results available.
You should check NextToken after every operation to ensure
that you receive all of the results.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Parameter resourceShareArns :
Specifies that you want details about invitations only for the resource
shares described by this list of Amazon
Resource Names (ARNs)
Parameter resourceShareInvitationArns :
Specifies the Amazon
Resource Names (ARNs) of the resource share invitations you want
information about.
Implementation
Future<GetResourceShareInvitationsResponse> getResourceShareInvitations({
int? maxResults,
String? nextToken,
List<String>? resourceShareArns,
List<String>? resourceShareInvitationArns,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (resourceShareArns != null) 'resourceShareArns': resourceShareArns,
if (resourceShareInvitationArns != null)
'resourceShareInvitationArns': resourceShareInvitationArns,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/getresourceshareinvitations',
exceptionFnMap: _exceptionFns,
);
return GetResourceShareInvitationsResponse.fromJson(response);
}