listPermissionVersions method

Future<ListPermissionVersionsResponse> listPermissionVersions({
  1. required String permissionArn,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the available versions of the specified RAM permission.

May throw InvalidNextTokenException. May throw InvalidParameterException. May throw MalformedArnException. May throw OperationNotPermittedException. May throw ServerInternalException. May throw ServiceUnavailableException. May throw UnknownResourceException.

Parameter permissionArn : Specifies the Amazon Resource Name (ARN) of the RAM permission whose versions you want to list. You can use the permissionVersion parameter on the AssociateResourceSharePermission operation to specify a non-default version to attach.

Parameter maxResults : Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's NextToken response to request the next page of results.

Implementation

Future<ListPermissionVersionsResponse> listPermissionVersions({
  required String permissionArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $payload = <String, dynamic>{
    'permissionArn': permissionArn,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/listpermissionversions',
    exceptionFnMap: _exceptionFns,
  );
  return ListPermissionVersionsResponse.fromJson(response);
}