listPermissions method

Future<ListPermissionsResponse> listPermissions({
  1. int? maxResults,
  2. String? nextToken,
  3. PermissionTypeFilter? permissionType,
  4. String? resourceType,
})

Retrieves a list of available RAM permissions that you can use for the supported resource types.

May throw InvalidNextTokenException. May throw InvalidParameterException. May throw OperationNotPermittedException. May throw ServerInternalException. May throw ServiceUnavailableException.

Parameter maxResults : Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's NextToken response to request the next page of results.

Parameter permissionType : Specifies that you want to list only permissions of this type:

  • AWS – returns only Amazon Web Services managed permissions.
  • LOCAL – returns only customer managed permissions
  • ALL – returns both Amazon Web Services managed permissions and customer managed permissions.
If you don't specify this parameter, the default is All.

Parameter resourceType : Specifies that you want to list only those permissions that apply to the specified resource type. This parameter is not case sensitive.

For example, to list only permissions that apply to Amazon EC2 subnets, specify ec2:subnet. You can use the ListResourceTypes operation to get the specific string required.

Implementation

Future<ListPermissionsResponse> listPermissions({
  int? maxResults,
  String? nextToken,
  PermissionTypeFilter? permissionType,
  String? resourceType,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (permissionType != null) 'permissionType': permissionType.value,
    if (resourceType != null) 'resourceType': resourceType,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/listpermissions',
    exceptionFnMap: _exceptionFns,
  );
  return ListPermissionsResponse.fromJson(response);
}