listPrincipals method
Lists the principals that you are sharing resources with or that are sharing resources with you.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter resourceOwner :
Specifies that you want to list information for only resource shares that
match the following:
-
SELF– principals that your account is sharing resources with -
OTHER-ACCOUNTS– principals that are sharing resources with your account
Parameter maxResults :
Specifies the total number of results that you want included on each page
of the response. If you do not include this parameter, it defaults to a
value that is specific to the operation. If additional items exist beyond
the number you specify, the NextToken response element is
returned with a value (not null). Include the specified value as the
NextToken request parameter in the next call to the operation
to get the next part of the results. Note that the service might return
fewer results than the maximum even when there are more results available.
You should check NextToken after every operation to ensure
that you receive all of the results.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Parameter principals :
Specifies that you want to list information for only the listed
principals.
You can include the following values:
-
An Amazon Web Services account ID, for example:
123456789012 -
An Amazon
Resource Name (ARN) of an organization in Organizations, for example:
organizations::123456789012:organization/o-exampleorgid -
An ARN of an organizational unit (OU) in Organizations, for example:
organizations::123456789012:ou/o-exampleorgid/ou-examplerootid-exampleouid123 -
An ARN of an IAM role, for example:
iam::123456789012:role/rolename -
An ARN of an IAM user, for example:
iam::123456789012user/username -
A service principal name, for example:
service-id.amazonaws.com
Parameter resourceArn :
Specifies that you want to list principal information for the resource
share with the specified Amazon
Resource Name (ARN).
Parameter resourceShareArns :
Specifies that you want to list information for only principals associated
with the resource shares specified by a list the Amazon
Resource Names (ARNs).
Parameter resourceType :
Specifies that you want to list information for only principals associated
with resource shares that include the specified resource type.
For a list of valid values, query the ListResourceTypes operation.
Implementation
Future<ListPrincipalsResponse> listPrincipals({
required ResourceOwner resourceOwner,
int? maxResults,
String? nextToken,
List<String>? principals,
String? resourceArn,
List<String>? resourceShareArns,
String? resourceType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
'resourceOwner': resourceOwner.value,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (principals != null) 'principals': principals,
if (resourceArn != null) 'resourceArn': resourceArn,
if (resourceShareArns != null) 'resourceShareArns': resourceShareArns,
if (resourceType != null) 'resourceType': resourceType,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listprincipals',
exceptionFnMap: _exceptionFns,
);
return ListPrincipalsResponse.fromJson(response);
}