listResources method

Future<ListResourcesResponse> listResources({
  1. required ResourceOwner resourceOwner,
  2. int? maxResults,
  3. String? nextToken,
  4. String? principal,
  5. List<String>? resourceArns,
  6. ResourceRegionScopeFilter? resourceRegionScope,
  7. List<String>? resourceShareArns,
  8. String? resourceType,
})

Lists the resources that you added to a resource share or the resources that are shared with you.

May throw InvalidNextTokenException. May throw InvalidParameterException. May throw InvalidResourceTypeException. May throw MalformedArnException. May throw ServerInternalException. May throw ServiceUnavailableException. May throw UnknownResourceException.

Parameter resourceOwner : Specifies that you want to list only the resource shares that match the following:

  • SELF – resources that your account shares with other accounts
  • OTHER-ACCOUNTS – resources that other accounts share with your account

Parameter maxResults : Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's NextToken response to request the next page of results.

Parameter principal : Specifies that you want to list only the resource shares that are associated with the specified principal.

Parameter resourceArns : Specifies that you want to list only the resource shares that include resources with the specified Amazon Resource Names (ARNs).

Parameter resourceRegionScope : Specifies that you want the results to include only resources that have the specified scope.

  • ALL – the results include both global and regional resources or resource types.
  • GLOBAL – the results include only global resources or resource types.
  • REGIONAL – the results include only regional resources or resource types.
The default value is ALL.

Parameter resourceShareArns : Specifies that you want to list only resources in the resource shares identified by the specified Amazon Resource Names (ARNs).

Parameter resourceType : Specifies that you want to list only the resource shares that include resources of the specified resource type.

For valid values, query the ListResourceTypes operation.

Implementation

Future<ListResourcesResponse> listResources({
  required ResourceOwner resourceOwner,
  int? maxResults,
  String? nextToken,
  String? principal,
  List<String>? resourceArns,
  ResourceRegionScopeFilter? resourceRegionScope,
  List<String>? resourceShareArns,
  String? resourceType,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    500,
  );
  final $payload = <String, dynamic>{
    'resourceOwner': resourceOwner.value,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (principal != null) 'principal': principal,
    if (resourceArns != null) 'resourceArns': resourceArns,
    if (resourceRegionScope != null)
      'resourceRegionScope': resourceRegionScope.value,
    if (resourceShareArns != null) 'resourceShareArns': resourceShareArns,
    if (resourceType != null) 'resourceType': resourceType,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/listresources',
    exceptionFnMap: _exceptionFns,
  );
  return ListResourcesResponse.fromJson(response);
}