rejectResourceShareInvitation method
Rejects an invitation to a resource share from another Amazon Web Services account.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ResourceShareInvitationAlreadyAcceptedException.
May throw ResourceShareInvitationAlreadyRejectedException.
May throw ResourceShareInvitationArnNotFoundException.
May throw ResourceShareInvitationExpiredException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
Parameter resourceShareInvitationArn :
Specifies the Amazon
Resource Name (ARN) of the invitation that you want to reject.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Implementation
Future<RejectResourceShareInvitationResponse> rejectResourceShareInvitation({
required String resourceShareInvitationArn,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'resourceShareInvitationArn': resourceShareInvitationArn,
if (clientToken != null) 'clientToken': clientToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/rejectresourceshareinvitation',
exceptionFnMap: _exceptionFns,
);
return RejectResourceShareInvitationResponse.fromJson(response);
}