setDefaultPermissionVersion method
Designates the specified version number as the default version for the specified customer managed permission. New resource shares automatically use this new default permission. Existing resource shares continue to use their original permission version, but you can use ReplacePermissionAssociations to update them.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter permissionArn :
Specifies the Amazon
Resource Name (ARN) of the customer managed permission whose default
version you want to change.
Parameter permissionVersion :
Specifies the version number that you want to designate as the default for
customer managed permission. To see a list of all available version
numbers, use ListPermissionVersions.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Implementation
Future<SetDefaultPermissionVersionResponse> setDefaultPermissionVersion({
required String permissionArn,
required int permissionVersion,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'permissionArn': permissionArn,
'permissionVersion': permissionVersion,
if (clientToken != null) 'clientToken': clientToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/setdefaultpermissionversion',
exceptionFnMap: _exceptionFns,
);
return SetDefaultPermissionVersionResponse.fromJson(response);
}