addSourceIdentifierToSubscription method

Future<AddSourceIdentifierToSubscriptionResult> addSourceIdentifierToSubscription({
  1. required String sourceIdentifier,
  2. required String subscriptionName,
})

Adds a source identifier to an existing RDS event notification subscription.

May throw SourceNotFoundFault. May throw SubscriptionNotFoundFault.

Parameter sourceIdentifier : The identifier of the event source to be added.

Constraints:

  • If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.
  • If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.
  • If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.
  • If the source type is a DB security group, a DBSecurityGroupName value must be supplied.
  • If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.
  • If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.
  • If the source type is an RDS Proxy, a DBProxyName value must be supplied.

Parameter subscriptionName : The name of the RDS event notification subscription you want to add a source identifier to.

Implementation

Future<AddSourceIdentifierToSubscriptionResult>
    addSourceIdentifierToSubscription({
  required String sourceIdentifier,
  required String subscriptionName,
}) async {
  final $request = <String, String>{
    'SourceIdentifier': sourceIdentifier,
    'SubscriptionName': subscriptionName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'AddSourceIdentifierToSubscription',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'AddSourceIdentifierToSubscriptionResult',
  );
  return AddSourceIdentifierToSubscriptionResult.fromXml($result);
}