backtrackDBCluster method
Backtracks a DB cluster to a specific time, without creating a new DB cluster.
For more information on backtracking, see Backtracking an Aurora DB Cluster in the Amazon Aurora User Guide.
May throw DBClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
Parameter backtrackTo :
The timestamp of the time to backtrack the DB cluster to, specified in ISO
8601 format. For more information about ISO 8601, see the ISO8601 Wikipedia page.
Constraints:
- Must contain a valid ISO 8601 timestamp.
- Can't contain a timestamp set in the future.
2017-07-08T18:00Z
Parameter dBClusterIdentifier :
The DB cluster identifier of the DB cluster to be backtracked. This
parameter is stored as a lowercase string.
Constraints:
- Must contain from 1 to 63 alphanumeric characters or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-cluster1
Parameter force :
Specifies whether to force the DB cluster to backtrack when binary logging
is enabled. Otherwise, an error occurs when binary logging is enabled.
Parameter useEarliestTimeOnPointInTimeUnavailable :
Specifies whether to backtrack the DB cluster to the earliest possible
backtrack time when BacktrackTo is set to a timestamp earlier than
the earliest backtrack time. When this parameter is disabled and
BacktrackTo is set to a timestamp earlier than the earliest
backtrack time, an error occurs.
Implementation
Future<DBClusterBacktrack> backtrackDBCluster({
required DateTime backtrackTo,
required String dBClusterIdentifier,
bool? force,
bool? useEarliestTimeOnPointInTimeUnavailable,
}) async {
final $request = <String, String>{
'BacktrackTo': _s.iso8601ToJson(backtrackTo),
'DBClusterIdentifier': dBClusterIdentifier,
if (force != null) 'Force': force.toString(),
if (useEarliestTimeOnPointInTimeUnavailable != null)
'UseEarliestTimeOnPointInTimeUnavailable':
useEarliestTimeOnPointInTimeUnavailable.toString(),
};
final $result = await _protocol.send(
$request,
action: 'BacktrackDBCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'BacktrackDBClusterResult',
);
return DBClusterBacktrack.fromXml($result);
}