cancelExportTask method
Cancels an export task in progress that is exporting a snapshot or cluster to Amazon S3. Any data that has already been written to the S3 bucket isn't removed.
May throw ExportTaskNotFoundFault.
May throw InvalidExportTaskStateFault.
Parameter exportTaskIdentifier :
The identifier of the snapshot or cluster export task to cancel.
Implementation
Future<ExportTask> cancelExportTask({
required String exportTaskIdentifier,
}) async {
final $request = <String, String>{
'ExportTaskIdentifier': exportTaskIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'CancelExportTask',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CancelExportTaskResult',
);
return ExportTask.fromXml($result);
}