copyDBClusterSnapshot method
Copies a snapshot of a DB cluster.
To copy a DB cluster snapshot from a shared manual DB cluster snapshot,
SourceDBClusterSnapshotIdentifier must be the Amazon Resource
Name (ARN) of the shared DB cluster snapshot.
You can copy an encrypted DB cluster snapshot from another Amazon Web
Services Region. In that case, the Amazon Web Services Region where you
call the CopyDBClusterSnapshot operation is the destination
Amazon Web Services Region for the encrypted DB cluster snapshot to be
copied to. To copy an encrypted DB cluster snapshot from another Amazon
Web Services Region, you must provide the following values:
-
KmsKeyId- The Amazon Web Services Key Management System (Amazon Web Services KMS) key identifier for the key to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. -
TargetDBClusterSnapshotIdentifier- The identifier for the new copy of the DB cluster snapshot in the destination Amazon Web Services Region. -
SourceDBClusterSnapshotIdentifier- The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the ARN format for the source Amazon Web Services Region and is the same value as theSourceDBClusterSnapshotIdentifierin the presigned URL.
TargetDBClusterSnapshotIdentifier while that DB cluster
snapshot is in "copying" status.
For more information on copying encrypted Amazon Aurora DB cluster snapshots from one Amazon Web Services Region to another, see Copying a Snapshot in the Amazon Aurora User Guide.
For more information on Amazon Aurora DB clusters, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
May throw DBClusterSnapshotAlreadyExistsFault.
May throw DBClusterSnapshotNotFoundFault.
May throw InvalidDBClusterSnapshotStateFault.
May throw InvalidDBClusterStateFault.
May throw KMSKeyNotAccessibleFault.
May throw SnapshotQuotaExceededFault.
Parameter sourceDBClusterSnapshotIdentifier :
The identifier of the DB cluster snapshot to copy. This parameter isn't
case-sensitive.
Constraints:
- Must specify a valid source snapshot in the "available" state.
- If the source snapshot is in the same Amazon Web Services Region as the copy, specify a valid DB snapshot identifier.
- If the source snapshot is in a different Amazon Web Services Region than the copy, specify a valid DB cluster snapshot ARN. You can also specify an ARN of a snapshot that is in a different account and a different Amazon Web Services Region. For more information, go to Copying Snapshots Across Amazon Web Services Regions in the Amazon Aurora User Guide.
my-cluster-snapshot1
Parameter targetDBClusterSnapshotIdentifier :
The identifier of the new DB cluster snapshot to create from the source DB
cluster snapshot. This parameter isn't case-sensitive.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-cluster-snapshot2
Parameter copyTags :
Specifies whether to copy all tags from the source DB cluster snapshot to
the target DB cluster snapshot. By default, tags are not copied.
Parameter kmsKeyId :
The Amazon Web Services KMS key identifier for an encrypted DB cluster
snapshot. The Amazon Web Services KMS key identifier is the key ARN, key
ID, alias ARN, or alias name for the Amazon Web Services KMS key.
If you copy an encrypted DB cluster snapshot from your Amazon Web Services
account, you can specify a value for KmsKeyId to encrypt the
copy with a new KMS key. If you don't specify a value for
KmsKeyId, then the copy of the DB cluster snapshot is
encrypted with the same KMS key as the source DB cluster snapshot.
If you copy an encrypted DB cluster snapshot that is shared from another
Amazon Web Services account, then you must specify a value for
KmsKeyId.
To copy an encrypted DB cluster snapshot to another Amazon Web Services
Region, you must set KmsKeyId to the Amazon Web Services KMS
key identifier you want to use to encrypt the copy of the DB cluster
snapshot in the destination Amazon Web Services Region. KMS keys are
specific to the Amazon Web Services Region that they are created in, and
you can't use KMS keys from one Amazon Web Services Region in another
Amazon Web Services Region.
If you copy an unencrypted DB cluster snapshot and specify a value for the
KmsKeyId parameter, an error is returned.
Parameter preSignedUrl :
When you are copying a DB cluster snapshot from one Amazon Web Services
GovCloud (US) Region to another, the URL that contains a Signature Version
4 signed request for the CopyDBClusterSnapshot API operation
in the Amazon Web Services Region that contains the source DB cluster
snapshot to copy. Use the PreSignedUrl parameter when copying
an encrypted DB cluster snapshot from another Amazon Web Services Region.
Don't specify PreSignedUrl when copying an encrypted DB
cluster snapshot in the same Amazon Web Services Region.
This setting applies only to Amazon Web Services GovCloud (US) Regions. It's ignored in other Amazon Web Services Regions.
The presigned URL must be a valid request for the
CopyDBClusterSnapshot API operation that can run in the
source Amazon Web Services Region that contains the encrypted DB cluster
snapshot to copy. The presigned URL request must contain the following
parameter values:
-
KmsKeyId- The KMS key identifier for the KMS key to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. This is the same identifier for both theCopyDBClusterSnapshotoperation that is called in the destination Amazon Web Services Region, and the operation contained in the presigned URL. -
DestinationRegion- The name of the Amazon Web Services Region that the DB cluster snapshot is to be created in. -
SourceDBClusterSnapshotIdentifier- The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster snapshot from the us-west-2 Amazon Web Services Region, then yourSourceDBClusterSnapshotIdentifierlooks like the following example:arn:aws:rds:us-west-2:123456789012:cluster-snapshot:aurora-cluster1-snapshot-20161115.
Implementation
Future<CopyDBClusterSnapshotResult> copyDBClusterSnapshot({
required String sourceDBClusterSnapshotIdentifier,
required String targetDBClusterSnapshotIdentifier,
bool? copyTags,
String? kmsKeyId,
String? preSignedUrl,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'SourceDBClusterSnapshotIdentifier': sourceDBClusterSnapshotIdentifier,
'TargetDBClusterSnapshotIdentifier': targetDBClusterSnapshotIdentifier,
if (copyTags != null) 'CopyTags': copyTags.toString(),
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (preSignedUrl != null) 'PreSignedUrl': preSignedUrl,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CopyDBClusterSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CopyDBClusterSnapshotResult',
);
return CopyDBClusterSnapshotResult.fromXml($result);
}