createDBCluster method
- required String dBClusterIdentifier,
- required String engine,
- int? allocatedStorage,
- bool? autoMinorVersionUpgrade,
- List<
String> ? availabilityZones, - int? backtrackWindow,
- int? backupRetentionPeriod,
- String? cACertificateIdentifier,
- String? characterSetName,
- ClusterScalabilityType? clusterScalabilityType,
- bool? copyTagsToSnapshot,
- String? dBClusterInstanceClass,
- String? dBClusterParameterGroupName,
- String? dBSubnetGroupName,
- String? dBSystemId,
- DatabaseInsightsMode? databaseInsightsMode,
- String? databaseName,
- bool? deletionProtection,
- String? domain,
- String? domainIAMRoleName,
- List<
String> ? enableCloudwatchLogsExports, - bool? enableGlobalWriteForwarding,
- bool? enableHttpEndpoint,
- bool? enableIAMDatabaseAuthentication,
- bool? enableLimitlessDatabase,
- bool? enableLocalWriteForwarding,
- bool? enablePerformanceInsights,
- String? engineLifecycleSupport,
- String? engineMode,
- String? engineVersion,
- String? globalClusterIdentifier,
- int? iops,
- String? kmsKeyId,
- bool? manageMasterUserPassword,
- MasterUserAuthenticationType? masterUserAuthenticationType,
- String? masterUserPassword,
- String? masterUserSecretKmsKeyId,
- String? masterUsername,
- int? monitoringInterval,
- String? monitoringRoleArn,
- String? networkType,
- String? optionGroupName,
- String? performanceInsightsKMSKeyId,
- int? performanceInsightsRetentionPeriod,
- int? port,
- String? preSignedUrl,
- String? preferredBackupWindow,
- String? preferredMaintenanceWindow,
- bool? publiclyAccessible,
- RdsCustomClusterConfiguration? rdsCustomClusterConfiguration,
- String? replicationSourceIdentifier,
- ScalingConfiguration? scalingConfiguration,
- ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
- bool? storageEncrypted,
- String? storageType,
- List<
TagSpecification> ? tagSpecifications, - List<
Tag> ? tags, - List<
String> ? vpcSecurityGroupIds, - bool? withExpressConfiguration,
Creates a new Amazon Aurora DB cluster or Multi-AZ DB cluster.
If you create an Aurora DB cluster, the request creates an empty cluster. You must explicitly create the writer instance for your DB cluster using the CreateDBInstance operation. If you create a Multi-AZ DB cluster, the request creates a writer and two reader DB instances for you, each in a different Availability Zone.
You can use the ReplicationSourceIdentifier parameter to
create an Amazon Aurora DB cluster as a read replica of another DB cluster
or Amazon RDS for MySQL or PostgreSQL DB instance. For more information
about Amazon Aurora, see What
is Amazon Aurora? in the Amazon Aurora User Guide.
You can also use the ReplicationSourceIdentifier parameter to
create a Multi-AZ DB cluster read replica with an RDS for MySQL or
PostgreSQL DB instance as the source. For more information about Multi-AZ
DB clusters, see Multi-AZ
DB cluster deployments in the Amazon RDS User Guide.
You can use the WithExpressConfiguration parameter to create
an Aurora DB Cluster with express configuration and create cluster in
seconds. Express configuration provides a cluster with a writer instance
and feature specific values set to all other input parameters of this API.
May throw DBClusterAlreadyExistsFault.
May throw DBClusterNotFoundFault.
May throw DBClusterParameterGroupNotFoundFault.
May throw DBClusterQuotaExceededFault.
May throw DBInstanceNotFoundFault.
May throw DBSubnetGroupDoesNotCoverEnoughAZs.
May throw DBSubnetGroupNotFoundFault.
May throw DomainNotFoundFault.
May throw GlobalClusterNotFoundFault.
May throw InsufficientDBInstanceCapacityFault.
May throw InsufficientStorageClusterCapacityFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidDBSubnetGroupFault.
May throw InvalidDBSubnetGroupStateFault.
May throw InvalidGlobalClusterStateFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw NetworkTypeNotSupported.
May throw OptionGroupNotFoundFault.
May throw StorageQuotaExceededFault.
May throw StorageTypeNotSupportedFault.
May throw VpcEncryptionControlViolationException.
Parameter dBClusterIdentifier :
The identifier for this DB cluster. This parameter is stored as a
lowercase string.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must contain from 1 to 63 (for Aurora DB clusters) or 1 to 52 (for Multi-AZ DB clusters) letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-cluster1
Parameter engine :
The database engine to use for this DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
-
aurora-mysql -
aurora-postgresql -
mysql -
postgres -
neptune- For information about using Amazon Neptune, see the Amazon Neptune User Guide .
Parameter allocatedStorage :
The amount of storage in gibibytes (GiB) to allocate to each DB instance
in the Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
This setting is required to create a Multi-AZ DB cluster.
Parameter autoMinorVersionUpgrade :
Specifies whether minor engine upgrades are applied automatically to the
DB cluster during the maintenance window. By default, minor engine
upgrades are applied automatically.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB cluster.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
Parameter availabilityZones :
A list of Availability Zones (AZs) where you specifically want to create
DB instances in the DB cluster.
For the first three DB instances that you create, RDS distributes each DB instance to a different AZ that you specify. For additional DB instances that you create, RDS randomly distributes them to the AZs that you specified. For example, if you create a DB cluster with one writer instance and three reader instances, RDS might distribute the writer instance to AZ 1, the first reader instance to AZ 2, the second reader instance to AZ 3, and the third reader instance to either AZ 1, AZ 2, or AZ 3.
For more information, see Availability Zones and High availability for Aurora DB instances in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters only
Constraints:
- Can't specify more than three AZs.
Parameter backtrackWindow :
The target backtrack window, in seconds. To disable backtracking, set this
value to 0.
Valid for Cluster Type: Aurora MySQL DB clusters only
Default: 0
Constraints:
- If specified, this value must be set to a number from 0 to 259,200 (72 hours).
Parameter backupRetentionPeriod :
The number of days for which automated backups are retained.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Default: 1
Constraints:
- Must be a value from 1 to 35.
Parameter cACertificateIdentifier :
The CA certificate identifier to use for the DB cluster's server
certificate.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide.
Valid for Cluster Type: Multi-AZ DB clusters
Parameter characterSetName :
The name of the character set (CharacterSet) to associate the
DB cluster with.
Valid for Cluster Type: Aurora DB clusters only
Parameter clusterScalabilityType :
Specifies the scalability mode of the Aurora DB cluster. When set to
limitless, the cluster operates as an Aurora Limitless
Database. When set to standard (the default), the cluster
uses normal DB instance creation.
Valid for: Aurora DB clusters only
Parameter copyTagsToSnapshot :
Specifies whether to copy all tags from the DB cluster to snapshots of the
DB cluster. The default is not to copy them.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter dBClusterInstanceClass :
The compute and memory capacity of each DB instance in the Multi-AZ DB
cluster, for example db.m6gd.xlarge. Not all DB instance
classes are available in all Amazon Web Services Regions, or for all
database engines.
For the full list of DB instance classes and availability for your engine, see DB instance class in the Amazon RDS User Guide.
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
Parameter dBClusterParameterGroupName :
The name of the DB cluster parameter group to associate with this DB
cluster. If you don't specify a value, then the default DB cluster
parameter group for the specified DB engine and version is used.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- If supplied, must match the name of an existing DB cluster parameter group.
Parameter dBSubnetGroupName :
A DB subnet group to associate with this DB cluster.
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must match the name of an existing DB subnet group.
mydbsubnetgroup
Parameter dBSystemId :
Reserved for future use.
Parameter databaseInsightsMode :
The mode of Database Insights to enable for the DB cluster.
If you set this value to advanced, you must also set the
PerformanceInsightsEnabled parameter to true and
the PerformanceInsightsRetentionPeriod parameter to 465.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter databaseName :
The name for your database of up to 64 alphanumeric characters. A database
named postgres is always created. If this parameter is
specified, an additional database with this name is created.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter deletionProtection :
Specifies whether the DB cluster has deletion protection enabled. The
database can't be deleted when deletion protection is enabled. By default,
deletion protection isn't enabled.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter domain :
The Active Directory directory ID to create the DB cluster in.
For Amazon Aurora DB clusters, Amazon RDS can use Kerberos authentication to authenticate users that connect to the DB cluster.
For more information, see Kerberos authentication in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters only
Parameter domainIAMRoleName :
The name of the IAM role to use when making API calls to the Directory
Service.
Valid for Cluster Type: Aurora DB clusters only
Parameter enableCloudwatchLogsExports :
The list of log types that need to be enabled for exporting to CloudWatch
Logs.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The following values are valid for each DB engine:
-
Aurora MySQL -
audit | error | general | instance | slowquery | iam-db-auth-error -
Aurora PostgreSQL -
instance | postgresql | iam-db-auth-error -
RDS for MySQL -
error | general | slowquery | iam-db-auth-error -
RDS for PostgreSQL -
postgresql | upgrade | iam-db-auth-error
For more information about exporting CloudWatch Logs for Amazon Aurora, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide.
Parameter enableGlobalWriteForwarding :
Specifies whether to enable this DB cluster to forward write operations to
the primary cluster of a global cluster (Aurora global database). By
default, write operations are not allowed on Aurora DB clusters that are
secondary clusters in an Aurora global database.
You can set this value only on Aurora DB clusters that are members of an Aurora global database. With this parameter enabled, a secondary cluster can forward writes to the current primary cluster, and the resulting changes are replicated back to this cluster. For the primary DB cluster of an Aurora global database, this value is used immediately if the primary is demoted by a global cluster API operation, but it does nothing until then.
Valid for Cluster Type: Aurora DB clusters only
Parameter enableHttpEndpoint :
Specifies whether to enable the HTTP endpoint for the DB cluster. By
default, the HTTP endpoint isn't enabled.
When enabled, the HTTP endpoint provides a connectionless web service API (RDS Data API) for running SQL queries on the DB cluster. You can also query your database from inside the RDS console with the RDS query editor.
For more information, see Using RDS Data API in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters only
Parameter enableIAMDatabaseAuthentication :
Specifies whether to enable mapping of Amazon Web Services Identity and
Access Management (IAM) accounts to database accounts. By default, mapping
isn't enabled.
For more information, see IAM Database Authentication in the Amazon Aurora User Guide or IAM database authentication for MariaDB, MySQL, and PostgreSQL in the Amazon RDS User Guide.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter enableLimitlessDatabase :
Specifies whether to enable Aurora Limitless Database. You must enable
Aurora Limitless Database to create a DB shard group.
Valid for: Aurora DB clusters only
Parameter enableLocalWriteForwarding :
Specifies whether read replicas can forward write operations to the writer
DB instance in the DB cluster. By default, write operations aren't allowed
on reader DB instances.
Valid for: Aurora DB clusters only
Parameter enablePerformanceInsights :
Specifies whether to turn on Performance Insights for the DB cluster.
For more information, see Using Amazon Performance Insights in the Amazon RDS User Guide.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter engineLifecycleSupport :
The life cycle type for this DB cluster.
You can use this setting to enroll your DB cluster into Amazon RDS
Extended Support. With RDS Extended Support, you can run the selected
major engine version on your DB cluster past the end of standard support
for that engine version. For more information, see the following sections:
- Amazon Aurora - Amazon RDS Extended Support with Amazon Aurora in the Amazon Aurora User Guide
- Amazon RDS - Amazon RDS Extended Support with Amazon RDS in the Amazon RDS User Guide
Valid Values: open-source-rds-extended-support |
open-source-rds-extended-support-disabled
Default: open-source-rds-extended-support
Parameter engineMode :
The DB engine mode of the DB cluster, either provisioned or
serverless.
The serverless engine mode only applies for Aurora Serverless
v1 DB clusters. Aurora Serverless v2 DB clusters use the
provisioned engine mode.
For information about limitations and requirements for Serverless DB clusters, see the following sections in the Amazon Aurora User Guide:
Valid for Cluster Type: Aurora DB clusters onlyParameter engineVersion :
The version number of the database engine to use.
To list all of the available engine versions for Aurora MySQL version 2 (5.7-compatible) and version 3 (MySQL 8.0-compatible), use the following command:
aws rds describe-db-engine-versions --engine aurora-mysql --query
"DBEngineVersions[].EngineVersion"
You can supply either 5.7 or 8.0 to use the
default engine version for Aurora MySQL version 2 or version 3,
respectively.
To list all of the available engine versions for Aurora PostgreSQL, use the following command:
aws rds describe-db-engine-versions --engine aurora-postgresql
--query "DBEngineVersions[].EngineVersion"
To list all of the available engine versions for RDS for MySQL, use the following command:
aws rds describe-db-engine-versions --engine mysql --query
"DBEngineVersions[].EngineVersion"
To list all of the available engine versions for RDS for PostgreSQL, use the following command:
aws rds describe-db-engine-versions --engine postgres --query
"DBEngineVersions[].EngineVersion"
For information about a specific engine, see the following topics:
- Aurora MySQL - see Database engine updates for Amazon Aurora MySQL in the Amazon Aurora User Guide.
- Aurora PostgreSQL - see Amazon Aurora PostgreSQL releases and engine versions in the Amazon Aurora User Guide.
- RDS for MySQL - see Amazon RDS for MySQL in the Amazon RDS User Guide.
- RDS for PostgreSQL - see Amazon RDS for PostgreSQL in the Amazon RDS User Guide.
Parameter globalClusterIdentifier :
The global cluster ID of an Aurora cluster that becomes the primary
cluster in the new global database cluster.
Valid for Cluster Type: Aurora DB clusters only
Parameter iops :
The amount of Provisioned IOPS (input/output operations per second) to be
initially allocated for each DB instance in the Multi-AZ DB cluster.
For information about valid IOPS values, see Provisioned IOPS storage in the Amazon RDS User Guide.
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
Constraints:
- Must be a multiple between .5 and 50 of the storage amount for the DB cluster.
Parameter kmsKeyId :
The Amazon Web Services KMS key identifier for an encrypted DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
When a KMS key isn't specified in KmsKeyId:
-
If
ReplicationSourceIdentifieridentifies an encrypted source, then Amazon RDS uses the KMS key used to encrypt the source. Otherwise, Amazon RDS uses your default KMS key. -
If the
StorageEncryptedparameter is enabled andReplicationSourceIdentifierisn't specified, then Amazon RDS uses your default KMS key.
If you create a read replica of an encrypted DB cluster in another Amazon
Web Services Region, make sure to set KmsKeyId to a KMS key
identifier that is valid in the destination Amazon Web Services Region.
This KMS key is used to encrypt the read replica in that Amazon Web
Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter manageMasterUserPassword :
Specifies whether to manage the master user password with Amazon Web
Services Secrets Manager.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide and Password management with Amazon Web Services Secrets Manager in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
-
Can't manage the master user password with Amazon Web Services Secrets
Manager if
MasterUserPasswordis specified.
Parameter masterUserAuthenticationType :
Specifies the authentication type for the master user. With IAM master
user authentication, you can configure the master DB user with IAM
database authentication when you create a DB cluster.
You can specify one of the following values:
-
password- Use standard database authentication with a password. -
iam-db-auth- Use IAM database authentication for the master user.
This option is only valid for RDS for PostgreSQL and Aurora PostgreSQL engines.
Parameter masterUserPassword :
The password for the master database user.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must contain from 8 to 41 characters.
- Can contain any printable ASCII character except "/", """, or "@".
-
Can't be specified if
ManageMasterUserPasswordis turned on.
Parameter masterUserSecretKmsKeyId :
The Amazon Web Services KMS key identifier to encrypt a secret that is
automatically generated and managed in Amazon Web Services Secrets
Manager.
This setting is valid only if the master user password is managed by RDS in Amazon Web Services Secrets Manager for the DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If you don't specify MasterUserSecretKmsKeyId, then the
aws/secretsmanager KMS key is used to encrypt the secret. If
the secret is in a different Amazon Web Services account, then you can't
use the aws/secretsmanager KMS key to encrypt the secret, and
you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter masterUsername :
The name of the master user for the DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must be 1 to 16 letters or numbers.
- First character must be a letter.
- Can't be a reserved word for the chosen database engine.
Parameter monitoringInterval :
The interval, in seconds, between points when Enhanced Monitoring metrics
are collected for the DB cluster. To turn off collecting Enhanced
Monitoring metrics, specify 0.
If MonitoringRoleArn is specified, also set
MonitoringInterval to a value other than 0.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values: 0 | 1 | 5 | 10 | 15 | 30 | 60
Default: 0
Parameter monitoringRoleArn :
The Amazon Resource Name (ARN) for the IAM role that permits RDS to send
Enhanced Monitoring metrics to Amazon CloudWatch Logs. An example is
arn:aws:iam:123456789012:role/emaccess. For information on
creating a monitoring role, see Setting
up and enabling Enhanced Monitoring in the Amazon RDS User
Guide.
If MonitoringInterval is set to a value other than
0, supply a MonitoringRoleArn value.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter networkType :
The network type of the DB cluster.
The network type is determined by the DBSubnetGroup specified
for the DB cluster. A DBSubnetGroup can support only the IPv4
protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters only
Valid Values: IPV4 | DUAL
Parameter optionGroupName :
The option group to associate the DB cluster with.
DB clusters are associated with a default option group that can't be modified.
Parameter performanceInsightsKMSKeyId :
The Amazon Web Services KMS key identifier for encryption of Performance
Insights data.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
If you don't specify a value for PerformanceInsightsKMSKeyId,
then Amazon RDS uses your default KMS key. There is a default KMS key for
your Amazon Web Services account. Your Amazon Web Services account has a
different default KMS key for each Amazon Web Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter performanceInsightsRetentionPeriod :
The number of days to retain Performance Insights data.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
-
7 -
month * 31, where month is a number of months from 1-23.
Examples:
93(3 months * 31),341(11 months * 31),589(19 months * 31) -
731
7 days
If you specify a retention period that isn't valid, such as
94, Amazon RDS issues an error.
Parameter port :
The port number on which the instances in the DB cluster accept
connections.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values: 1150-65535
Default:
-
RDS for MySQL and Aurora MySQL -
3306 -
RDS for PostgreSQL and Aurora PostgreSQL -
5432
Parameter preSignedUrl :
When you are replicating a DB cluster from one Amazon Web Services
GovCloud (US) Region to another, an URL that contains a Signature Version
4 signed request for the CreateDBCluster operation to be
called in the source Amazon Web Services Region where the DB cluster is
replicated from. Specify PreSignedUrl only when you are
performing cross-Region replication from an encrypted DB cluster.
The presigned URL must be a valid request for the
CreateDBCluster API operation that can run in the source
Amazon Web Services Region that contains the encrypted DB cluster to copy.
The presigned URL request must contain the following parameter values:
-
KmsKeyId- The KMS key identifier for the KMS key to use to encrypt the copy of the DB cluster in the destination Amazon Web Services Region. This should refer to the same KMS key for both theCreateDBClusteroperation that is called in the destination Amazon Web Services Region, and the operation contained in the presigned URL. -
DestinationRegion- The name of the Amazon Web Services Region that Aurora read replica will be created in. -
ReplicationSourceIdentifier- The DB cluster identifier for the encrypted DB cluster to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster from the us-west-2 Amazon Web Services Region, then yourReplicationSourceIdentifierwould look like Example:arn:aws:rds:us-west-2:123456789012:cluster:aurora-cluster1.
Parameter preferredBackupWindow :
The daily time range during which automated backups are created if
automated backups are enabled using the BackupRetentionPeriod
parameter.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. To view the time blocks available, see Backup window in the Amazon Aurora User Guide.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
Parameter preferredMaintenanceWindow :
The weekly time range during which system maintenance can occur.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region, occurring on a random day of the week. To see the time blocks available, see Adjusting the Preferred DB Cluster Maintenance Window in the Amazon Aurora User Guide.
Constraints:
-
Must be in the format
ddd:hh24:mi-ddd:hh24:mi. -
Days must be one of
Mon | Tue | Wed | Thu | Fri | Sat | Sun. - Must be in Universal Coordinated Time (UTC).
- Must be at least 30 minutes.
Parameter publiclyAccessible :
Specifies whether the DB cluster is publicly accessible.
Valid for Cluster Type: Multi-AZ DB clusters only
When the DB cluster is publicly accessible and you connect from outside of the DB cluster's virtual private cloud (VPC), its domain name system (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB cluster, the endpoint resolves to the private IP address. Access to the DB cluster is controlled by its security group settings.
When the DB cluster isn't publicly accessible, it is an internal DB cluster with a DNS name that resolves to a private IP address.
The default behavior when PubliclyAccessible is not specified
depends on whether a DBSubnetGroup is specified.
If DBSubnetGroup isn't specified,
PubliclyAccessible defaults to true.
If DBSubnetGroup is specified,
PubliclyAccessible defaults to false unless the
value of DBSubnetGroup is default, in which case
PubliclyAccessible defaults to true.
If PubliclyAccessible is true and the VPC that the
DBSubnetGroup is in doesn't have an internet gateway attached
to it, Amazon RDS returns an error.
Parameter rdsCustomClusterConfiguration :
Reserved for future use.
Parameter replicationSourceIdentifier :
The Amazon Resource Name (ARN) of the source DB instance or DB cluster if
this DB cluster is created as a read replica.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter scalingConfiguration :
For DB clusters in serverless DB engine mode, the scaling
properties of the DB cluster.
Valid for Cluster Type: Aurora DB clusters only
Parameter storageEncrypted :
Specifies whether the DB cluster is encrypted.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter storageType :
The storage type to associate with the DB cluster.
For information on storage types for Aurora DB clusters, see Storage configurations for Amazon Aurora DB clusters. For information on storage types for Multi-AZ DB clusters, see Settings for creating Multi-AZ DB clusters.
This setting is required to create a Multi-AZ DB cluster.
When specified for a Multi-AZ DB cluster, a value for the
Iops parameter is required.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
-
Aurora DB clusters -
aurora | aurora-iopt1 -
Multi-AZ DB clusters -
io1 | io2 | gp3
-
Aurora DB clusters -
aurora -
Multi-AZ DB clusters -
io1
Parameter tagSpecifications :
Tags to assign to resources associated with the DB cluster.
Valid Values:
-
cluster-auto-backup- The DB cluster's automated backup.
Parameter tags :
Tags to assign to the DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter vpcSecurityGroupIds :
A list of EC2 VPC security groups to associate with this DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Parameter withExpressConfiguration :
Specifies to create an Aurora DB Cluster with express configuration in
seconds. Express configuration provides a cluster with a writer instance
and feature specific values set to all other input parameters of this API.
Valid for Cluster Type: Aurora DB clusters
Implementation
Future<CreateDBClusterResult> createDBCluster({
required String dBClusterIdentifier,
required String engine,
int? allocatedStorage,
bool? autoMinorVersionUpgrade,
List<String>? availabilityZones,
int? backtrackWindow,
int? backupRetentionPeriod,
String? cACertificateIdentifier,
String? characterSetName,
ClusterScalabilityType? clusterScalabilityType,
bool? copyTagsToSnapshot,
String? dBClusterInstanceClass,
String? dBClusterParameterGroupName,
String? dBSubnetGroupName,
String? dBSystemId,
DatabaseInsightsMode? databaseInsightsMode,
String? databaseName,
bool? deletionProtection,
String? domain,
String? domainIAMRoleName,
List<String>? enableCloudwatchLogsExports,
bool? enableGlobalWriteForwarding,
bool? enableHttpEndpoint,
bool? enableIAMDatabaseAuthentication,
bool? enableLimitlessDatabase,
bool? enableLocalWriteForwarding,
bool? enablePerformanceInsights,
String? engineLifecycleSupport,
String? engineMode,
String? engineVersion,
String? globalClusterIdentifier,
int? iops,
String? kmsKeyId,
bool? manageMasterUserPassword,
MasterUserAuthenticationType? masterUserAuthenticationType,
String? masterUserPassword,
String? masterUserSecretKmsKeyId,
String? masterUsername,
int? monitoringInterval,
String? monitoringRoleArn,
String? networkType,
String? optionGroupName,
String? performanceInsightsKMSKeyId,
int? performanceInsightsRetentionPeriod,
int? port,
String? preSignedUrl,
String? preferredBackupWindow,
String? preferredMaintenanceWindow,
bool? publiclyAccessible,
RdsCustomClusterConfiguration? rdsCustomClusterConfiguration,
String? replicationSourceIdentifier,
ScalingConfiguration? scalingConfiguration,
ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
bool? storageEncrypted,
String? storageType,
List<TagSpecification>? tagSpecifications,
List<Tag>? tags,
List<String>? vpcSecurityGroupIds,
bool? withExpressConfiguration,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
'Engine': engine,
if (allocatedStorage != null)
'AllocatedStorage': allocatedStorage.toString(),
if (autoMinorVersionUpgrade != null)
'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
if (availabilityZones != null)
if (availabilityZones.isEmpty)
'AvailabilityZones': ''
else
for (var i1 = 0; i1 < availabilityZones.length; i1++)
'AvailabilityZones.AvailabilityZone.${i1 + 1}':
availabilityZones[i1],
if (backtrackWindow != null)
'BacktrackWindow': backtrackWindow.toString(),
if (backupRetentionPeriod != null)
'BackupRetentionPeriod': backupRetentionPeriod.toString(),
if (cACertificateIdentifier != null)
'CACertificateIdentifier': cACertificateIdentifier,
if (characterSetName != null) 'CharacterSetName': characterSetName,
if (clusterScalabilityType != null)
'ClusterScalabilityType': clusterScalabilityType.value,
if (copyTagsToSnapshot != null)
'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
if (dBClusterInstanceClass != null)
'DBClusterInstanceClass': dBClusterInstanceClass,
if (dBClusterParameterGroupName != null)
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (dBSystemId != null) 'DBSystemId': dBSystemId,
if (databaseInsightsMode != null)
'DatabaseInsightsMode': databaseInsightsMode.value,
if (databaseName != null) 'DatabaseName': databaseName,
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (domain != null) 'Domain': domain,
if (domainIAMRoleName != null) 'DomainIAMRoleName': domainIAMRoleName,
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (enableGlobalWriteForwarding != null)
'EnableGlobalWriteForwarding': enableGlobalWriteForwarding.toString(),
if (enableHttpEndpoint != null)
'EnableHttpEndpoint': enableHttpEndpoint.toString(),
if (enableIAMDatabaseAuthentication != null)
'EnableIAMDatabaseAuthentication':
enableIAMDatabaseAuthentication.toString(),
if (enableLimitlessDatabase != null)
'EnableLimitlessDatabase': enableLimitlessDatabase.toString(),
if (enableLocalWriteForwarding != null)
'EnableLocalWriteForwarding': enableLocalWriteForwarding.toString(),
if (enablePerformanceInsights != null)
'EnablePerformanceInsights': enablePerformanceInsights.toString(),
if (engineLifecycleSupport != null)
'EngineLifecycleSupport': engineLifecycleSupport,
if (engineMode != null) 'EngineMode': engineMode,
if (engineVersion != null) 'EngineVersion': engineVersion,
if (globalClusterIdentifier != null)
'GlobalClusterIdentifier': globalClusterIdentifier,
if (iops != null) 'Iops': iops.toString(),
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (manageMasterUserPassword != null)
'ManageMasterUserPassword': manageMasterUserPassword.toString(),
if (masterUserAuthenticationType != null)
'MasterUserAuthenticationType': masterUserAuthenticationType.value,
if (masterUserPassword != null) 'MasterUserPassword': masterUserPassword,
if (masterUserSecretKmsKeyId != null)
'MasterUserSecretKmsKeyId': masterUserSecretKmsKeyId,
if (masterUsername != null) 'MasterUsername': masterUsername,
if (monitoringInterval != null)
'MonitoringInterval': monitoringInterval.toString(),
if (monitoringRoleArn != null) 'MonitoringRoleArn': monitoringRoleArn,
if (networkType != null) 'NetworkType': networkType,
if (optionGroupName != null) 'OptionGroupName': optionGroupName,
if (performanceInsightsKMSKeyId != null)
'PerformanceInsightsKMSKeyId': performanceInsightsKMSKeyId,
if (performanceInsightsRetentionPeriod != null)
'PerformanceInsightsRetentionPeriod':
performanceInsightsRetentionPeriod.toString(),
if (port != null) 'Port': port.toString(),
if (preSignedUrl != null) 'PreSignedUrl': preSignedUrl,
if (preferredBackupWindow != null)
'PreferredBackupWindow': preferredBackupWindow,
if (preferredMaintenanceWindow != null)
'PreferredMaintenanceWindow': preferredMaintenanceWindow,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible.toString(),
if (rdsCustomClusterConfiguration != null)
for (var e1 in rdsCustomClusterConfiguration.toQueryMap().entries)
'RdsCustomClusterConfiguration.${e1.key}': e1.value,
if (replicationSourceIdentifier != null)
'ReplicationSourceIdentifier': replicationSourceIdentifier,
if (scalingConfiguration != null)
for (var e1 in scalingConfiguration.toQueryMap().entries)
'ScalingConfiguration.${e1.key}': e1.value,
if (serverlessV2ScalingConfiguration != null)
for (var e1 in serverlessV2ScalingConfiguration.toQueryMap().entries)
'ServerlessV2ScalingConfiguration.${e1.key}': e1.value,
if (storageEncrypted != null)
'StorageEncrypted': storageEncrypted.toString(),
if (storageType != null) 'StorageType': storageType,
if (tagSpecifications != null)
if (tagSpecifications.isEmpty)
'TagSpecifications': ''
else
for (var i1 = 0; i1 < tagSpecifications.length; i1++)
for (var e3 in tagSpecifications[i1].toQueryMap().entries)
'TagSpecifications.item.${i1 + 1}.${e3.key}': e3.value,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
if (withExpressConfiguration != null)
'WithExpressConfiguration': withExpressConfiguration.toString(),
};
final $result = await _protocol.send(
$request,
action: 'CreateDBCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateDBClusterResult',
);
return CreateDBClusterResult.fromXml($result);
}