createDBInstanceReadReplica method

Future<CreateDBInstanceReadReplicaResult> createDBInstanceReadReplica({
  1. required String dBInstanceIdentifier,
  2. List<AdditionalStorageVolume>? additionalStorageVolumes,
  3. int? allocatedStorage,
  4. bool? autoMinorVersionUpgrade,
  5. String? availabilityZone,
  6. String? backupTarget,
  7. String? cACertificateIdentifier,
  8. bool? copyTagsToSnapshot,
  9. String? customIamInstanceProfile,
  10. String? dBInstanceClass,
  11. String? dBParameterGroupName,
  12. String? dBSubnetGroupName,
  13. DatabaseInsightsMode? databaseInsightsMode,
  14. bool? dedicatedLogVolume,
  15. bool? deletionProtection,
  16. String? domain,
  17. String? domainAuthSecretArn,
  18. List<String>? domainDnsIps,
  19. String? domainFqdn,
  20. String? domainIAMRoleName,
  21. String? domainOu,
  22. List<String>? enableCloudwatchLogsExports,
  23. bool? enableCustomerOwnedIp,
  24. bool? enableIAMDatabaseAuthentication,
  25. bool? enablePerformanceInsights,
  26. int? iops,
  27. String? kmsKeyId,
  28. int? maxAllocatedStorage,
  29. int? monitoringInterval,
  30. String? monitoringRoleArn,
  31. bool? multiAZ,
  32. String? networkType,
  33. String? optionGroupName,
  34. String? performanceInsightsKMSKeyId,
  35. int? performanceInsightsRetentionPeriod,
  36. int? port,
  37. String? preSignedUrl,
  38. List<ProcessorFeature>? processorFeatures,
  39. bool? publiclyAccessible,
  40. ReplicaMode? replicaMode,
  41. String? sourceDBClusterIdentifier,
  42. String? sourceDBInstanceIdentifier,
  43. int? storageThroughput,
  44. String? storageType,
  45. List<TagSpecification>? tagSpecifications,
  46. List<Tag>? tags,
  47. bool? upgradeStorageConfig,
  48. bool? useDefaultProcessorFeatures,
  49. List<String>? vpcSecurityGroupIds,
})

Creates a new DB instance that acts as a read replica for an existing source DB instance or Multi-AZ DB cluster. You can create a read replica for a DB instance running Db2, MariaDB, MySQL, Oracle, PostgreSQL, or SQL Server. You can create a read replica for a Multi-AZ DB cluster running MySQL or PostgreSQL. For more information, see Working with read replicas and Migrating from a Multi-AZ DB cluster to a DB instance using a read replica in the Amazon RDS User Guide.

Amazon Aurora doesn't support this operation. To create a DB instance for an Aurora DB cluster, use the CreateDBInstance operation.

RDS creates read replicas with backups disabled. All other attributes (including DB security groups and DB parameter groups) are inherited from the source DB instance or cluster, except as specified.

May throw CertificateNotFoundFault. May throw DBClusterNotFoundFault. May throw DBInstanceAlreadyExistsFault. May throw DBInstanceNotFoundFault. May throw DBParameterGroupNotFoundFault. May throw DBSecurityGroupNotFoundFault. May throw DBSubnetGroupDoesNotCoverEnoughAZs. May throw DBSubnetGroupNotAllowedFault. May throw DBSubnetGroupNotFoundFault. May throw DomainNotFoundFault. May throw InstanceQuotaExceededFault. May throw InsufficientDBInstanceCapacityFault. May throw InvalidDBClusterStateFault. May throw InvalidDBInstanceStateFault. May throw InvalidDBSubnetGroupFault. May throw InvalidSubnet. May throw InvalidVPCNetworkStateFault. May throw KMSKeyNotAccessibleFault. May throw NetworkTypeNotSupported. May throw OptionGroupNotFoundFault. May throw ProvisionedIopsNotAvailableInAZFault. May throw StorageQuotaExceededFault. May throw StorageTypeNotSupportedFault. May throw TenantDatabaseQuotaExceededFault. May throw VpcEncryptionControlViolationException.

Parameter dBInstanceIdentifier : The DB instance identifier of the read replica. This identifier is the unique key that identifies a DB instance. This parameter is stored as a lowercase string.

Parameter additionalStorageVolumes : A list of additional storage volumes to create for the DB instance. You can create up to three additional storage volumes using the names rdsdbdata2, rdsdbdata3, and rdsdbdata4. Additional storage volumes are supported for RDS for Oracle and RDS for SQL Server DB instances only.

Parameter allocatedStorage : The amount of storage (in gibibytes) to allocate initially for the read replica. Follow the allocation rules specified in CreateDBInstance.

This setting isn't valid for RDS for SQL Server.

Parameter autoMinorVersionUpgrade : Specifies whether to automatically apply minor engine upgrades to the read replica during the maintenance window.

This setting doesn't apply to RDS Custom DB instances.

Default: Inherits the value from the source DB instance.

For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.

Parameter availabilityZone : The Availability Zone (AZ) where the read replica will be created.

Default: A random, system-chosen Availability Zone in the endpoint's Amazon Web Services Region.

Example: us-east-1d

Parameter backupTarget : The location where RDS stores automated backups and manual snapshots.

Valid Values:

  • local for Dedicated Local Zones
  • region for Amazon Web Services Region

Parameter cACertificateIdentifier : The CA certificate identifier to use for the read replica's server certificate.

This setting doesn't apply to RDS Custom DB instances.

For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.

Parameter copyTagsToSnapshot : Specifies whether to copy all tags from the read replica to snapshots of the read replica. By default, tags aren't copied.

Parameter customIamInstanceProfile : The instance profile associated with the underlying Amazon EC2 instance of an RDS Custom DB instance. The instance profile must meet the following requirements:

  • The profile must exist in your account.
  • The profile must have an IAM role that Amazon EC2 has permissions to assume.
  • The instance profile name and the associated IAM role name must start with the prefix AWSRDSCustom.
For the list of permissions required for the IAM role, see Configure IAM and your VPC in the Amazon RDS User Guide.

This setting is required for RDS Custom DB instances.

Parameter dBInstanceClass : The compute and memory capacity of the read replica, for example db.m4.large. Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines. For the full list of DB instance classes, and availability for your engine, see DB Instance Class in the Amazon RDS User Guide.

Default: Inherits the value from the source DB instance.

Parameter dBParameterGroupName : The name of the DB parameter group to associate with this read replica DB instance.

For the Db2 DB engine, if your source DB instance uses the bring your own license (BYOL) model, then a custom parameter group must be associated with the replica. For a same Amazon Web Services Region replica, if you don't specify a custom parameter group, Amazon RDS associates the custom parameter group associated with the source DB instance. For a cross-Region replica, you must specify a custom parameter group. This custom parameter group must include your IBM Site ID and IBM Customer ID. For more information, see IBM IDs for bring your own license (BYOL) for Db2.

For Single-AZ or Multi-AZ DB instance read replica instances, if you don't specify a value for DBParameterGroupName, then Amazon RDS uses the DBParameterGroup of the source DB instance for a same Region read replica, or the default DBParameterGroup for the specified DB engine for a cross-Region read replica.

For Multi-AZ DB cluster same Region read replica instances, if you don't specify a value for DBParameterGroupName, then Amazon RDS uses the default DBParameterGroup.

Specifying a parameter group for this operation is only supported for MySQL DB instances for cross-Region read replicas, for Multi-AZ DB cluster read replica instances, for Db2 DB instances, and for Oracle DB instances. It isn't supported for MySQL DB instances for same Region read replicas or for RDS Custom.

Constraints:

  • Must be 1 to 255 letters, numbers, or hyphens.
  • First character must be a letter.
  • Can't end with a hyphen or contain two consecutive hyphens.

Parameter dBSubnetGroupName : A DB subnet group for the DB instance. The new DB instance is created in the VPC associated with the DB subnet group. If no DB subnet group is specified, then the new DB instance isn't created in a VPC.

Constraints:

  • If supplied, must match the name of an existing DB subnet group.
  • The specified DB subnet group must be in the same Amazon Web Services Region in which the operation is running.
  • All read replicas in one Amazon Web Services Region that are created from the same source DB instance must either:
    • Specify DB subnet groups from the same VPC. All these read replicas are created in the same VPC.
    • Not specify a DB subnet group. All these read replicas are created outside of any VPC.
Example: mydbsubnetgroup

Parameter databaseInsightsMode : The mode of Database Insights to enable for the read replica.

Parameter dedicatedLogVolume : Indicates whether the DB instance has a dedicated log volume (DLV) enabled.

Parameter deletionProtection : Specifies whether to enable deletion protection for the DB instance. The database can't be deleted when deletion protection is enabled. By default, deletion protection isn't enabled. For more information, see Deleting a DB Instance.

Parameter domain : The Active Directory directory ID to create the DB instance in. Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances can be created in an Active Directory Domain.

For more information, see Kerberos Authentication in the Amazon RDS User Guide.

This setting doesn't apply to RDS Custom DB instances.

Parameter domainAuthSecretArn : The ARN for the Secrets Manager secret with the credentials for the user joining the domain.

Example: arn:aws:secretsmanager:region:account-number:secret:myselfmanagedADtestsecret-123456

Parameter domainDnsIps : The IPv4 DNS IP addresses of your primary and secondary Active Directory domain controllers.

Constraints:

  • Two IP addresses must be provided. If there isn't a secondary domain controller, use the IP address of the primary domain controller for both entries in the list.
Example: 123.124.125.126,234.235.236.237

Parameter domainFqdn : The fully qualified domain name (FQDN) of an Active Directory domain.

Constraints:

  • Can't be longer than 64 characters.
Example: mymanagedADtest.mymanagedAD.mydomain

Parameter domainIAMRoleName : The name of the IAM role to use when making API calls to the Directory Service.

This setting doesn't apply to RDS Custom DB instances.

Parameter domainOu : The Active Directory organizational unit for your DB instance to join.

Constraints:

  • Must be in the distinguished name format.
  • Can't be longer than 64 characters.
Example: OU=mymanagedADtestOU,DC=mymanagedADtest,DC=mymanagedAD,DC=mydomain

Parameter enableCloudwatchLogsExports : The list of logs that the new DB instance is to export to CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon RDS User Guide.

This setting doesn't apply to RDS Custom DB instances.

Parameter enableCustomerOwnedIp : Specifies whether to enable a customer-owned IP address (CoIP) for an RDS on Outposts read replica.

A CoIP provides local or external connectivity to resources in your Outpost subnets through your on-premises network. For some use cases, a CoIP can provide lower latency for connections to the read replica from outside of its virtual private cloud (VPC) on your local network.

For more information about RDS on Outposts, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.

For more information about CoIPs, see Customer-owned IP addresses in the Amazon Web Services Outposts User Guide.

Parameter enableIAMDatabaseAuthentication : Specifies whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping isn't enabled.

For more information about IAM database authentication, see IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide.

This setting doesn't apply to RDS Custom DB instances.

Parameter enablePerformanceInsights : Specifies whether to enable Performance Insights for the read replica.

For more information, see Using Amazon Performance Insights in the Amazon RDS User Guide.

This setting doesn't apply to RDS Custom DB instances.

Parameter iops : The amount of Provisioned IOPS (input/output operations per second) to initially allocate for the DB instance.

Parameter kmsKeyId : The Amazon Web Services KMS key identifier for an encrypted read replica.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

If you create an encrypted read replica in the same Amazon Web Services Region as the source DB instance or Multi-AZ DB cluster, don't specify a value for this parameter. A read replica in the same Amazon Web Services Region is always encrypted with the same KMS key as the source DB instance or cluster.

If you create an encrypted read replica in a different Amazon Web Services Region, then you must specify a KMS key identifier for the destination Amazon Web Services Region. KMS keys are specific to the Amazon Web Services Region that they are created in, and you can't use KMS keys from one Amazon Web Services Region in another Amazon Web Services Region.

You can't create an encrypted read replica from an unencrypted DB instance or Multi-AZ DB cluster.

This setting doesn't apply to RDS Custom, which uses the same KMS key as the primary replica.

Parameter maxAllocatedStorage : The upper limit in gibibytes (GiB) to which Amazon RDS can automatically scale the storage of the DB instance.

For more information about this setting, including limitations that apply to it, see Managing capacity automatically with Amazon RDS storage autoscaling in the Amazon RDS User Guide.

Parameter monitoringInterval : The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the read replica. To disable collection of Enhanced Monitoring metrics, specify 0. The default is 0.

If MonitoringRoleArn is specified, then you must set MonitoringInterval to a value other than 0.

This setting doesn't apply to RDS Custom DB instances.

Valid Values: 0, 1, 5, 10, 15, 30, 60

Default: 0

Parameter monitoringRoleArn : The ARN for the IAM role that permits RDS to send enhanced monitoring metrics to Amazon CloudWatch Logs. For example, arn:aws:iam:123456789012:role/emaccess. For information on creating a monitoring role, go to To create an IAM role for Amazon RDS Enhanced Monitoring in the Amazon RDS User Guide.

If MonitoringInterval is set to a value other than 0, then you must supply a MonitoringRoleArn value.

This setting doesn't apply to RDS Custom DB instances.

Parameter multiAZ : Specifies whether the read replica is in a Multi-AZ deployment.

You can create a read replica as a Multi-AZ DB instance. RDS creates a standby of your replica in another Availability Zone for failover support for the replica. Creating your read replica as a Multi-AZ DB instance is independent of whether the source is a Multi-AZ DB instance or a Multi-AZ DB cluster.

This setting doesn't apply to RDS Custom DB instances.

Parameter networkType : The network type of the DB instance.

Valid Values:

  • IPV4
  • DUAL
The network type is determined by the DBSubnetGroup specified for read replica. A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).

For more information, see Working with a DB instance in a VPC in the Amazon RDS User Guide.

Parameter optionGroupName : The option group to associate the DB instance with. If not specified, RDS uses the option group associated with the source DB instance or cluster. This setting doesn't apply to RDS Custom DB instances.

Parameter performanceInsightsKMSKeyId : The Amazon Web Services KMS key identifier for encryption of Performance Insights data.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

If you do not specify a value for PerformanceInsightsKMSKeyId, then Amazon RDS uses your default KMS key. There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.

This setting doesn't apply to RDS Custom DB instances.

Parameter performanceInsightsRetentionPeriod : The number of days to retain Performance Insights data.

This setting doesn't apply to RDS Custom DB instances.

Valid Values:

  • 7
  • month * 31, where month is a number of months from 1-23. Examples: 93 (3 months * 31), 341 (11 months * 31), 589 (19 months * 31)
  • 731
Default: 7 days

If you specify a retention period that isn't valid, such as 94, Amazon RDS returns an error.

Parameter port : The port number that the DB instance uses for connections.

Valid Values: 1150-65535

Default: Inherits the value from the source DB instance.

Parameter preSignedUrl : When you are creating a read replica from one Amazon Web Services GovCloud (US) Region to another or from one China Amazon Web Services Region to another, the URL that contains a Signature Version 4 signed request for the CreateDBInstanceReadReplica API operation in the source Amazon Web Services Region that contains the source DB instance.

This setting applies only to Amazon Web Services GovCloud (US) Regions and China Amazon Web Services Regions. It's ignored in other Amazon Web Services Regions.

This setting applies only when replicating from a source DB instance. Source DB clusters aren't supported in Amazon Web Services GovCloud (US) Regions and China Amazon Web Services Regions.

You must specify this parameter when you create an encrypted read replica from another Amazon Web Services Region by using the Amazon RDS API. Don't specify PreSignedUrl when you are creating an encrypted read replica in the same Amazon Web Services Region.

The presigned URL must be a valid request for the CreateDBInstanceReadReplica API operation that can run in the source Amazon Web Services Region that contains the encrypted source DB instance. The presigned URL request must contain the following parameter values:

  • DestinationRegion - The Amazon Web Services Region that the encrypted read replica is created in. This Amazon Web Services Region is the same one where the CreateDBInstanceReadReplica operation is called that contains this presigned URL.

    For example, if you create an encrypted DB instance in the us-west-1 Amazon Web Services Region, from a source DB instance in the us-east-2 Amazon Web Services Region, then you call the CreateDBInstanceReadReplica operation in the us-east-1 Amazon Web Services Region and provide a presigned URL that contains a call to the CreateDBInstanceReadReplica operation in the us-west-2 Amazon Web Services Region. For this example, the DestinationRegion in the presigned URL must be set to the us-east-1 Amazon Web Services Region.

  • KmsKeyId - The KMS key identifier for the key to use to encrypt the read replica in the destination Amazon Web Services Region. This is the same identifier for both the CreateDBInstanceReadReplica operation that is called in the destination Amazon Web Services Region, and the operation contained in the presigned URL.
  • SourceDBInstanceIdentifier - The DB instance identifier for the encrypted DB instance to be replicated. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are creating an encrypted read replica from a DB instance in the us-west-2 Amazon Web Services Region, then your SourceDBInstanceIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:instance:mysql-instance1-20161115.
To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process. This setting doesn't apply to RDS Custom DB instances.

Parameter processorFeatures : The number of CPU cores and the number of threads per core for the DB instance class of the DB instance.

This setting doesn't apply to RDS Custom DB instances.

Parameter publiclyAccessible : Specifies whether the DB instance is publicly accessible.

When the DB cluster is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB cluster's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB cluster's VPC. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn't permitted if the security group assigned to the DB cluster doesn't permit it.

When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address.

For more information, see CreateDBInstance.

Parameter replicaMode : The open mode of the replica database.

This parameter is only supported for Db2 DB instances and Oracle DB instances.

Db2
Standby DB replicas are included in Db2 Advanced Edition (AE) and Db2 Standard Edition (SE). The main use case for standby replicas is cross-Region disaster recovery. Because it doesn't accept user connections, a standby replica can't serve a read-only workload.

You can create a combination of standby and read-only DB replicas for the same primary DB instance. For more information, see Working with replicas for Amazon RDS for Db2 in the Amazon RDS User Guide.

To create standby DB replicas for RDS for Db2, set this parameter to mounted.

Oracle
Mounted DB replicas are included in Oracle Database Enterprise Edition. The main use case for mounted replicas is cross-Region disaster recovery. The primary database doesn't use Active Data Guard to transmit information to the mounted replica. Because it doesn't accept user connections, a mounted replica can't serve a read-only workload.

You can create a combination of mounted and read-only DB replicas for the same primary DB instance. For more information, see Working with read replicas for Amazon RDS for Oracle in the Amazon RDS User Guide.

For RDS Custom, you must specify this parameter and set it to mounted. The value won't be set by default. After replica creation, you can manage the open mode manually.

Parameter sourceDBClusterIdentifier : The identifier of the Multi-AZ DB cluster that will act as the source for the read replica. Each DB cluster can have up to 15 read replicas.

Constraints:

  • Must be the identifier of an existing Multi-AZ DB cluster.
  • Can't be specified if the SourceDBInstanceIdentifier parameter is also specified.
  • The specified DB cluster must have automatic backups enabled, that is, its backup retention period must be greater than 0.
  • The source DB cluster must be in the same Amazon Web Services Region as the read replica. Cross-Region replication isn't supported.

Parameter sourceDBInstanceIdentifier : The identifier of the DB instance that will act as the source for the read replica. Each DB instance can have up to 15 read replicas, except for the following engines:

  • Db2 - Can have up to three replicas.
  • Oracle - Can have up to five read replicas.
  • SQL Server - Can have up to five read replicas.
Constraints:
  • Must be the identifier of an existing Db2, MariaDB, MySQL, Oracle, PostgreSQL, or SQL Server DB instance.
  • Can't be specified if the SourceDBClusterIdentifier parameter is also specified.
  • For the limitations of Oracle read replicas, see Version and licensing considerations for RDS for Oracle replicas in the Amazon RDS User Guide.
  • For the limitations of SQL Server read replicas, see Read replica limitations with SQL Server in the Amazon RDS User Guide.
  • The specified DB instance must have automatic backups enabled, that is, its backup retention period must be greater than 0.
  • If the source DB instance is in the same Amazon Web Services Region as the read replica, specify a valid DB instance identifier.
  • If the source DB instance is in a different Amazon Web Services Region from the read replica, specify a valid DB instance ARN. For more information, see Constructing an ARN for Amazon RDS in the Amazon RDS User Guide. This doesn't apply to SQL Server or RDS Custom, which don't support cross-Region replicas.

Parameter storageThroughput : Specifies the storage throughput value for the read replica.

This setting doesn't apply to RDS Custom or Amazon Aurora DB instances.

Parameter storageType : The storage type to associate with the read replica.

If you specify io1, io2, or gp3, you must also include a value for the Iops parameter.

Valid Values: gp2 | gp3 | io1 | io2 | standard

Default: io1 if the Iops parameter is specified. Otherwise, gp3.

Parameter tagSpecifications : Tags to assign to resources associated with the DB instance.

Valid Values:

  • auto-backup - The DB instance's automated backup.

Parameter upgradeStorageConfig : Whether to upgrade the storage file system configuration on the read replica. This option migrates the read replica from the old storage file system layout to the preferred layout.

Parameter useDefaultProcessorFeatures : Specifies whether the DB instance class of the DB instance uses its default processor features.

This setting doesn't apply to RDS Custom DB instances.

Parameter vpcSecurityGroupIds : A list of Amazon EC2 VPC security groups to associate with the read replica.

This setting doesn't apply to RDS Custom DB instances.

Default: The default EC2 VPC security group for the DB subnet group's VPC.

Implementation

Future<CreateDBInstanceReadReplicaResult> createDBInstanceReadReplica({
  required String dBInstanceIdentifier,
  List<AdditionalStorageVolume>? additionalStorageVolumes,
  int? allocatedStorage,
  bool? autoMinorVersionUpgrade,
  String? availabilityZone,
  String? backupTarget,
  String? cACertificateIdentifier,
  bool? copyTagsToSnapshot,
  String? customIamInstanceProfile,
  String? dBInstanceClass,
  String? dBParameterGroupName,
  String? dBSubnetGroupName,
  DatabaseInsightsMode? databaseInsightsMode,
  bool? dedicatedLogVolume,
  bool? deletionProtection,
  String? domain,
  String? domainAuthSecretArn,
  List<String>? domainDnsIps,
  String? domainFqdn,
  String? domainIAMRoleName,
  String? domainOu,
  List<String>? enableCloudwatchLogsExports,
  bool? enableCustomerOwnedIp,
  bool? enableIAMDatabaseAuthentication,
  bool? enablePerformanceInsights,
  int? iops,
  String? kmsKeyId,
  int? maxAllocatedStorage,
  int? monitoringInterval,
  String? monitoringRoleArn,
  bool? multiAZ,
  String? networkType,
  String? optionGroupName,
  String? performanceInsightsKMSKeyId,
  int? performanceInsightsRetentionPeriod,
  int? port,
  String? preSignedUrl,
  List<ProcessorFeature>? processorFeatures,
  bool? publiclyAccessible,
  ReplicaMode? replicaMode,
  String? sourceDBClusterIdentifier,
  String? sourceDBInstanceIdentifier,
  int? storageThroughput,
  String? storageType,
  List<TagSpecification>? tagSpecifications,
  List<Tag>? tags,
  bool? upgradeStorageConfig,
  bool? useDefaultProcessorFeatures,
  List<String>? vpcSecurityGroupIds,
}) async {
  final $request = <String, String>{
    'DBInstanceIdentifier': dBInstanceIdentifier,
    if (additionalStorageVolumes != null)
      if (additionalStorageVolumes.isEmpty)
        'AdditionalStorageVolumes': ''
      else
        for (var i1 = 0; i1 < additionalStorageVolumes.length; i1++)
          for (var e3 in additionalStorageVolumes[i1].toQueryMap().entries)
            'AdditionalStorageVolumes.member.${i1 + 1}.${e3.key}': e3.value,
    if (allocatedStorage != null)
      'AllocatedStorage': allocatedStorage.toString(),
    if (autoMinorVersionUpgrade != null)
      'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
    if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
    if (backupTarget != null) 'BackupTarget': backupTarget,
    if (cACertificateIdentifier != null)
      'CACertificateIdentifier': cACertificateIdentifier,
    if (copyTagsToSnapshot != null)
      'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
    if (customIamInstanceProfile != null)
      'CustomIamInstanceProfile': customIamInstanceProfile,
    if (dBInstanceClass != null) 'DBInstanceClass': dBInstanceClass,
    if (dBParameterGroupName != null)
      'DBParameterGroupName': dBParameterGroupName,
    if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
    if (databaseInsightsMode != null)
      'DatabaseInsightsMode': databaseInsightsMode.value,
    if (dedicatedLogVolume != null)
      'DedicatedLogVolume': dedicatedLogVolume.toString(),
    if (deletionProtection != null)
      'DeletionProtection': deletionProtection.toString(),
    if (domain != null) 'Domain': domain,
    if (domainAuthSecretArn != null)
      'DomainAuthSecretArn': domainAuthSecretArn,
    if (domainDnsIps != null)
      if (domainDnsIps.isEmpty)
        'DomainDnsIps': ''
      else
        for (var i1 = 0; i1 < domainDnsIps.length; i1++)
          'DomainDnsIps.member.${i1 + 1}': domainDnsIps[i1],
    if (domainFqdn != null) 'DomainFqdn': domainFqdn,
    if (domainIAMRoleName != null) 'DomainIAMRoleName': domainIAMRoleName,
    if (domainOu != null) 'DomainOu': domainOu,
    if (enableCloudwatchLogsExports != null)
      if (enableCloudwatchLogsExports.isEmpty)
        'EnableCloudwatchLogsExports': ''
      else
        for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
          'EnableCloudwatchLogsExports.member.${i1 + 1}':
              enableCloudwatchLogsExports[i1],
    if (enableCustomerOwnedIp != null)
      'EnableCustomerOwnedIp': enableCustomerOwnedIp.toString(),
    if (enableIAMDatabaseAuthentication != null)
      'EnableIAMDatabaseAuthentication':
          enableIAMDatabaseAuthentication.toString(),
    if (enablePerformanceInsights != null)
      'EnablePerformanceInsights': enablePerformanceInsights.toString(),
    if (iops != null) 'Iops': iops.toString(),
    if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
    if (maxAllocatedStorage != null)
      'MaxAllocatedStorage': maxAllocatedStorage.toString(),
    if (monitoringInterval != null)
      'MonitoringInterval': monitoringInterval.toString(),
    if (monitoringRoleArn != null) 'MonitoringRoleArn': monitoringRoleArn,
    if (multiAZ != null) 'MultiAZ': multiAZ.toString(),
    if (networkType != null) 'NetworkType': networkType,
    if (optionGroupName != null) 'OptionGroupName': optionGroupName,
    if (performanceInsightsKMSKeyId != null)
      'PerformanceInsightsKMSKeyId': performanceInsightsKMSKeyId,
    if (performanceInsightsRetentionPeriod != null)
      'PerformanceInsightsRetentionPeriod':
          performanceInsightsRetentionPeriod.toString(),
    if (port != null) 'Port': port.toString(),
    if (preSignedUrl != null) 'PreSignedUrl': preSignedUrl,
    if (processorFeatures != null)
      if (processorFeatures.isEmpty)
        'ProcessorFeatures': ''
      else
        for (var i1 = 0; i1 < processorFeatures.length; i1++)
          for (var e3 in processorFeatures[i1].toQueryMap().entries)
            'ProcessorFeatures.ProcessorFeature.${i1 + 1}.${e3.key}':
                e3.value,
    if (publiclyAccessible != null)
      'PubliclyAccessible': publiclyAccessible.toString(),
    if (replicaMode != null) 'ReplicaMode': replicaMode.value,
    if (sourceDBClusterIdentifier != null)
      'SourceDBClusterIdentifier': sourceDBClusterIdentifier,
    if (sourceDBInstanceIdentifier != null)
      'SourceDBInstanceIdentifier': sourceDBInstanceIdentifier,
    if (storageThroughput != null)
      'StorageThroughput': storageThroughput.toString(),
    if (storageType != null) 'StorageType': storageType,
    if (tagSpecifications != null)
      if (tagSpecifications.isEmpty)
        'TagSpecifications': ''
      else
        for (var i1 = 0; i1 < tagSpecifications.length; i1++)
          for (var e3 in tagSpecifications[i1].toQueryMap().entries)
            'TagSpecifications.item.${i1 + 1}.${e3.key}': e3.value,
    if (tags != null)
      if (tags.isEmpty)
        'Tags': ''
      else
        for (var i1 = 0; i1 < tags.length; i1++)
          for (var e3 in tags[i1].toQueryMap().entries)
            'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
    if (upgradeStorageConfig != null)
      'UpgradeStorageConfig': upgradeStorageConfig.toString(),
    if (useDefaultProcessorFeatures != null)
      'UseDefaultProcessorFeatures': useDefaultProcessorFeatures.toString(),
    if (vpcSecurityGroupIds != null)
      if (vpcSecurityGroupIds.isEmpty)
        'VpcSecurityGroupIds': ''
      else
        for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
          'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
              vpcSecurityGroupIds[i1],
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateDBInstanceReadReplica',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateDBInstanceReadReplicaResult',
  );
  return CreateDBInstanceReadReplicaResult.fromXml($result);
}