createEventSubscription method
Creates an RDS event notification subscription. This operation requires a topic Amazon Resource Name (ARN) created by either the RDS console, the SNS console, or the SNS API. To obtain an ARN with SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console.
You can specify the type of source (SourceType) that you want
to be notified of and provide a list of RDS sources
(SourceIds) that triggers the events. You can also provide a
list of event categories (EventCategories) for events that
you want to be notified of. For example, you can specify
SourceType = db-instance, SourceIds
= mydbinstance1, mydbinstance2 and
EventCategories = Availability,
Backup.
If you specify both the SourceType and
SourceIds, such as SourceType =
db-instance and SourceIds =
myDBInstance1, you are notified of all the
db-instance events for the specified source. If you specify a
SourceType but do not specify SourceIds, you
receive notice of the events for that source type for all your RDS
sources. If you don't specify either the SourceType or the
SourceIds, you are notified of events generated from all RDS
sources belonging to your customer account.
For more information about subscribing to an event for RDS DB engines, see Subscribing to Amazon RDS event notification in the Amazon RDS User Guide.
For more information about subscribing to an event for Aurora DB engines, see Subscribing to Amazon RDS event notification in the Amazon Aurora User Guide.
May throw EventSubscriptionQuotaExceededFault.
May throw SNSInvalidTopicFault.
May throw SNSNoAuthorizationFault.
May throw SNSTopicArnNotFoundFault.
May throw SourceNotFoundFault.
May throw SubscriptionAlreadyExistFault.
May throw SubscriptionCategoryNotFoundFault.
Parameter snsTopicArn :
The Amazon Resource Name (ARN) of the SNS topic created for event
notification. SNS automatically creates the ARN when you create a topic
and subscribe to it.
Parameter subscriptionName :
The name of the subscription.
Constraints: The name must be less than 255 characters.
Parameter enabled :
Specifies whether to activate the subscription. If the event notification
subscription isn't activated, the subscription is created but not active.
Parameter eventCategories :
A list of event categories for a particular source type
(SourceType) that you want to subscribe to. You can see a
list of the categories for a given source type in the "Amazon RDS event
categories and event messages" section of the
Amazon RDS User Guide or the
Amazon Aurora User Guide . You can also see this list by using
the DescribeEventCategories operation.
Parameter sourceIds :
The list of identifiers of the event sources for which events are
returned. If not specified, then all sources are included in the response.
An identifier must begin with a letter and must contain only ASCII
letters, digits, and hyphens. It can't end with a hyphen or contain two
consecutive hyphens.
Constraints:
-
If
SourceIdsare supplied,SourceTypemust also be provided. -
If the source type is a DB instance, a
DBInstanceIdentifiervalue must be supplied. -
If the source type is a DB cluster, a
DBClusterIdentifiervalue must be supplied. -
If the source type is a DB parameter group, a
DBParameterGroupNamevalue must be supplied. -
If the source type is a DB security group, a
DBSecurityGroupNamevalue must be supplied. -
If the source type is a DB snapshot, a
DBSnapshotIdentifiervalue must be supplied. -
If the source type is a DB cluster snapshot, a
DBClusterSnapshotIdentifiervalue must be supplied. -
If the source type is an RDS Proxy, a
DBProxyNamevalue must be supplied.
Parameter sourceType :
The type of source that is generating the events. For example, if you want
to be notified of events generated by a DB instance, you set this
parameter to db-instance. For RDS Proxy events, specify
db-proxy. If this value isn't specified, all events are
returned.
Valid Values: db-instance | db-cluster | db-parameter-group |
db-security-group | db-snapshot | db-cluster-snapshot | db-proxy |
zero-etl | custom-engine-version | blue-green-deployment
Implementation
Future<CreateEventSubscriptionResult> createEventSubscription({
required String snsTopicArn,
required String subscriptionName,
bool? enabled,
List<String>? eventCategories,
List<String>? sourceIds,
String? sourceType,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'SnsTopicArn': snsTopicArn,
'SubscriptionName': subscriptionName,
if (enabled != null) 'Enabled': enabled.toString(),
if (eventCategories != null)
if (eventCategories.isEmpty)
'EventCategories': ''
else
for (var i1 = 0; i1 < eventCategories.length; i1++)
'EventCategories.EventCategory.${i1 + 1}': eventCategories[i1],
if (sourceIds != null)
if (sourceIds.isEmpty)
'SourceIds': ''
else
for (var i1 = 0; i1 < sourceIds.length; i1++)
'SourceIds.SourceId.${i1 + 1}': sourceIds[i1],
if (sourceType != null) 'SourceType': sourceType,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CreateEventSubscription',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateEventSubscriptionResult',
);
return CreateEventSubscriptionResult.fromXml($result);
}