deleteBlueGreenDeployment method

Future<DeleteBlueGreenDeploymentResponse> deleteBlueGreenDeployment({
  1. required String blueGreenDeploymentIdentifier,
  2. bool? deleteTarget,
})

Deletes a blue/green deployment.

For more information, see Using Amazon RDS Blue/Green Deployments for database updates in the Amazon RDS User Guide and Using Amazon RDS Blue/Green Deployments for database updates in the Amazon Aurora User Guide.

May throw BlueGreenDeploymentNotFoundFault. May throw InvalidBlueGreenDeploymentStateFault.

Parameter blueGreenDeploymentIdentifier : The unique identifier of the blue/green deployment to delete. This parameter isn't case-sensitive.

Constraints:

  • Must match an existing blue/green deployment identifier.

Parameter deleteTarget : Specifies whether to delete the resources in the green environment. You can't specify this option if the blue/green deployment status is SWITCHOVER_COMPLETED.

Implementation

Future<DeleteBlueGreenDeploymentResponse> deleteBlueGreenDeployment({
  required String blueGreenDeploymentIdentifier,
  bool? deleteTarget,
}) async {
  final $request = <String, String>{
    'BlueGreenDeploymentIdentifier': blueGreenDeploymentIdentifier,
    if (deleteTarget != null) 'DeleteTarget': deleteTarget.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteBlueGreenDeployment',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteBlueGreenDeploymentResult',
  );
  return DeleteBlueGreenDeploymentResponse.fromXml($result);
}