deleteCustomDBEngineVersion method

Future<DBEngineVersion> deleteCustomDBEngineVersion({
  1. required String engine,
  2. required String engineVersion,
})

Deletes a custom engine version. To run this command, make sure you meet the following prerequisites:

  • The CEV must not be the default for RDS Custom. If it is, change the default before running this command.
  • The CEV must not be associated with an RDS Custom DB instance, RDS Custom instance snapshot, or automated backup of your RDS Custom instance.
Typically, deletion takes a few minutes. For more information, see Deleting a CEV in the Amazon RDS User Guide.

May throw CustomDBEngineVersionNotFoundFault. May throw InvalidCustomDBEngineVersionStateFault.

Parameter engine : The database engine.

RDS Custom for Oracle supports the following values:

  • custom-oracle-ee
  • custom-oracle-ee-cdb
  • custom-oracle-se2
  • custom-oracle-se2-cdb
RDS Custom for SQL Server supports the following values:
  • custom-sqlserver-ee
  • custom-sqlserver-se
  • ccustom-sqlserver-web
  • custom-sqlserver-dev
RDS for SQL Server supports only sqlserver-dev-ee.

Parameter engineVersion : The custom engine version (CEV) for your DB instance. This option is required for RDS Custom, but optional for Amazon RDS. The combination of Engine and EngineVersion is unique per customer per Amazon Web Services Region.

Implementation

Future<DBEngineVersion> deleteCustomDBEngineVersion({
  required String engine,
  required String engineVersion,
}) async {
  final $request = <String, String>{
    'Engine': engine,
    'EngineVersion': engineVersion,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteCustomDBEngineVersion',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteCustomDBEngineVersionResult',
  );
  return DBEngineVersion.fromXml($result);
}