deleteDBClusterSnapshot method
Future<DeleteDBClusterSnapshotResult>
deleteDBClusterSnapshot({
- required String dBClusterSnapshotIdentifier,
Deletes a DB cluster snapshot. If the snapshot is being copied, the copy operation is terminated. For more information on Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
May throw DBClusterSnapshotNotFoundFault.
May throw InvalidDBClusterSnapshotStateFault.
Parameter dBClusterSnapshotIdentifier :
The identifier of the DB cluster snapshot to delete.
Constraints: Must be the name of an existing DB cluster snapshot in the
available state.
Implementation
Future<DeleteDBClusterSnapshotResult> deleteDBClusterSnapshot({
required String dBClusterSnapshotIdentifier,
}) async {
final $request = <String, String>{
'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DeleteDBClusterSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DeleteDBClusterSnapshotResult',
);
return DeleteDBClusterSnapshotResult.fromXml($result);
}