deleteDBProxyEndpoint method

Future<DeleteDBProxyEndpointResponse> deleteDBProxyEndpoint({
  1. required String dBProxyEndpointName,
})

Deletes a DBProxyEndpoint. Doing so removes the ability to access the DB proxy using the endpoint that you defined. The endpoint that you delete might have provided capabilities such as read/write or read-only operations, or using a different VPC than the DB proxy's default VPC.

May throw DBProxyEndpointNotFoundFault. May throw InvalidDBProxyEndpointStateFault.

Parameter dBProxyEndpointName : The name of the DB proxy endpoint to delete.

Implementation

Future<DeleteDBProxyEndpointResponse> deleteDBProxyEndpoint({
  required String dBProxyEndpointName,
}) async {
  final $request = <String, String>{
    'DBProxyEndpointName': dBProxyEndpointName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeleteDBProxyEndpoint',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteDBProxyEndpointResult',
  );
  return DeleteDBProxyEndpointResponse.fromXml($result);
}