describeBlueGreenDeployments method

Future<DescribeBlueGreenDeploymentsResponse> describeBlueGreenDeployments({
  1. String? blueGreenDeploymentIdentifier,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
})

Describes one or more blue/green deployments.

For more information, see Using Amazon RDS Blue/Green Deployments for database updates in the Amazon RDS User Guide and Using Amazon RDS Blue/Green Deployments for database updates in the Amazon Aurora User Guide.

May throw BlueGreenDeploymentNotFoundFault.

Parameter blueGreenDeploymentIdentifier : The blue/green deployment identifier. If you specify this parameter, the response only includes information about the specific blue/green deployment. This parameter isn't case-sensitive.

Constraints:

  • Must match an existing blue/green deployment identifier.

Parameter filters : A filter that specifies one or more blue/green deployments to describe.

Valid Values:

  • blue-green-deployment-identifier - Accepts system-generated identifiers for blue/green deployments. The results list only includes information about the blue/green deployments with the specified identifiers.
  • blue-green-deployment-name - Accepts user-supplied names for blue/green deployments. The results list only includes information about the blue/green deployments with the specified names.
  • source - Accepts source databases for a blue/green deployment. The results list only includes information about the blue/green deployments with the specified source databases.
  • target - Accepts target databases for a blue/green deployment. The results list only includes information about the blue/green deployments with the specified target databases.

Parameter marker : An optional pagination token provided by a previous DescribeBlueGreenDeployments request. If you specify this parameter, the response only includes records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.

Default: 100

Constraints:

  • Must be a minimum of 20.
  • Can't exceed 100.

Implementation

Future<DescribeBlueGreenDeploymentsResponse> describeBlueGreenDeployments({
  String? blueGreenDeploymentIdentifier,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  _s.validateNumRange(
    'maxRecords',
    maxRecords,
    20,
    100,
  );
  final $request = <String, String>{
    if (blueGreenDeploymentIdentifier != null)
      'BlueGreenDeploymentIdentifier': blueGreenDeploymentIdentifier,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeBlueGreenDeployments',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeBlueGreenDeploymentsResult',
  );
  return DescribeBlueGreenDeploymentsResponse.fromXml($result);
}