describeCertificates method
Lists the set of certificate authority (CA) certificates provided by Amazon RDS for this Amazon Web Services account.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
May throw CertificateNotFoundFault.
Parameter certificateIdentifier :
The user-supplied certificate identifier. If this parameter is specified,
information for only the identified certificate is returned. This
parameter isn't case-sensitive.
Constraints:
- Must match an existing CertificateIdentifier.
Parameter filters :
This parameter isn't currently supported.
Parameter marker :
An optional pagination token provided by a previous
DescribeCertificates request. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<CertificateMessage> describeCertificates({
String? certificateIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (certificateIdentifier != null)
'CertificateIdentifier': certificateIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeCertificates',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeCertificatesResult',
);
return CertificateMessage.fromXml($result);
}