describeDBClusterAutomatedBackups method
Displays backups for both current and deleted DB clusters. For example,
use this operation to find details about automated backups for previously
deleted clusters. Current clusters are returned for both the
DescribeDBClusterAutomatedBackups and
DescribeDBClusters operations.
All parameters are optional.
May throw DBClusterAutomatedBackupNotFoundFault.
Parameter dBClusterIdentifier :
(Optional) The user-supplied DB cluster identifier. If this parameter is
specified, it must match the identifier of an existing DB cluster. It
returns information from the specific DB cluster's automated backup. This
parameter isn't case-sensitive.
Parameter dbClusterResourceId :
The resource ID of the DB cluster that is the source of the automated
backup. This parameter isn't case-sensitive.
Parameter filters :
A filter that specifies which resources to return based on status.
Supported filters are the following:
-
status-
retained- Automated backups for deleted clusters and after backup replication is stopped.
-
-
db-cluster-id- Accepts DB cluster identifiers and Amazon Resource Names (ARNs). The results list includes only information about the DB cluster automated backups identified by these ARNs. -
db-cluster-resource-id- Accepts DB resource identifiers and Amazon Resource Names (ARNs). The results list includes only information about the DB cluster resources identified by these ARNs.
Parameter marker :
The pagination token provided in the previous request. If this parameter
is specified the response includes only records beyond the marker, up to
MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Implementation
Future<DBClusterAutomatedBackupMessage> describeDBClusterAutomatedBackups({
String? dBClusterIdentifier,
String? dbClusterResourceId,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBClusterIdentifier != null)
'DBClusterIdentifier': dBClusterIdentifier,
if (dbClusterResourceId != null)
'DbClusterResourceId': dbClusterResourceId,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterAutomatedBackups',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterAutomatedBackupsResult',
);
return DBClusterAutomatedBackupMessage.fromXml($result);
}