describeDBClusterBacktracks method
Returns information about backtracks for a DB cluster.
For more information on Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide.
May throw DBClusterBacktrackNotFoundFault.
May throw DBClusterNotFoundFault.
Parameter dBClusterIdentifier :
The DB cluster identifier of the DB cluster to be described. This
parameter is stored as a lowercase string.
Constraints:
- Must contain from 1 to 63 alphanumeric characters or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-cluster1
Parameter backtrackIdentifier :
If specified, this value is the backtrack identifier of the backtrack to
be described.
Constraints:
- Must contain a valid universally unique identifier (UUID). For more information about UUIDs, see Universally unique identifier.
123e4567-e89b-12d3-a456-426655440000
Parameter filters :
A filter that specifies one or more DB clusters to describe. Supported
filters include the following:
-
db-cluster-backtrack-id- Accepts backtrack identifiers. The results list includes information about only the backtracks identified by these identifiers. -
db-cluster-backtrack-status- Accepts any of the following backtrack status values:-
applying -
completed -
failed -
pending
-
Parameter marker :
An optional pagination token provided by a previous
DescribeDBClusterBacktracks request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBClusterBacktrackMessage> describeDBClusterBacktracks({
required String dBClusterIdentifier,
String? backtrackIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
if (backtrackIdentifier != null)
'BacktrackIdentifier': backtrackIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterBacktracks',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterBacktracksResult',
);
return DBClusterBacktrackMessage.fromXml($result);
}