describeDBClusterEndpoints method

Future<DBClusterEndpointMessage> describeDBClusterEndpoints({
  1. String? dBClusterEndpointIdentifier,
  2. String? dBClusterIdentifier,
  3. List<Filter>? filters,
  4. String? marker,
  5. int? maxRecords,
})

Returns information about endpoints for an Amazon Aurora DB cluster.

May throw DBClusterNotFoundFault.

Parameter dBClusterEndpointIdentifier : The identifier of the endpoint to describe. This parameter is stored as a lowercase string.

Parameter dBClusterIdentifier : The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.

Parameter filters : A set of name-value pairs that define which endpoints to include in the output. The filters are specified as name-value pairs, in the format Name=endpoint_type,Values=endpoint_type1,endpoint_type2,.... Name can be one of: db-cluster-endpoint-type, db-cluster-endpoint-custom-type, db-cluster-endpoint-id, db-cluster-endpoint-status. Values for the db-cluster-endpoint-type filter can be one or more of: reader, writer, custom. Values for the db-cluster-endpoint-custom-type filter can be one or more of: reader, any. Values for the db-cluster-endpoint-status filter can be one or more of: available, creating, deleting, inactive, modifying.

Parameter marker : An optional pagination token provided by a previous DescribeDBClusterEndpoints request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.

Implementation

Future<DBClusterEndpointMessage> describeDBClusterEndpoints({
  String? dBClusterEndpointIdentifier,
  String? dBClusterIdentifier,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (dBClusterEndpointIdentifier != null)
      'DBClusterEndpointIdentifier': dBClusterEndpointIdentifier,
    if (dBClusterIdentifier != null)
      'DBClusterIdentifier': dBClusterIdentifier,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDBClusterEndpoints',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDBClusterEndpointsResult',
  );
  return DBClusterEndpointMessage.fromXml($result);
}