describeDBClusterParameters method
Returns the detailed parameter list for a particular DB cluster parameter group.
For more information on Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
May throw DBParameterGroupNotFoundFault.
Parameter dBClusterParameterGroupName :
The name of a specific DB cluster parameter group to return parameter
details for.
Constraints:
- If supplied, must match the name of an existing DBClusterParameterGroup.
Parameter filters :
A filter that specifies one or more DB cluster parameters to describe.
The only supported filter is parameter-name. The results list
only includes information about the DB cluster parameters with these
names.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBClusterParameters request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Parameter source :
A specific source to return parameters for.
Valid Values:
-
engine-default -
system -
user
Implementation
Future<DBClusterParameterGroupDetails> describeDBClusterParameters({
required String dBClusterParameterGroupName,
List<Filter>? filters,
String? marker,
int? maxRecords,
String? source,
}) async {
final $request = <String, String>{
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (source != null) 'Source': source,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBClusterParameters',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBClusterParametersResult',
);
return DBClusterParameterGroupDetails.fromXml($result);
}