describeDBEngineVersions method
Describes the properties of specific versions of DB engines.
Parameter dBParameterGroupFamily :
The name of a specific DB parameter group family to return details for.
Constraints:
- If supplied, must match an existing DB parameter group family.
Parameter defaultOnly :
Specifies whether to return only the default version of the specified
engine or the engine and major version combination.
Parameter engine :
The database engine to return version details for.
Valid Values:
-
aurora-mysql -
aurora-postgresql -
custom-oracle-ee -
custom-oracle-ee-cdb -
custom-oracle-se2 -
custom-oracle-se2-cdb -
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
Parameter engineVersion :
A specific database engine version to return details for.
Example: 5.1.49
Parameter filters :
A filter that specifies one or more DB engine versions to describe.
Supported filters:
-
db-parameter-group-family- Accepts parameter groups family names. The results list only includes information about the DB engine versions for these parameter group families. -
engine- Accepts engine names. The results list only includes information about the DB engine versions for these engines. -
engine-mode- Accepts DB engine modes. The results list only includes information about the DB engine versions for these engine modes. Valid DB engine modes are the following:-
global -
multimaster -
parallelquery -
provisioned -
serverless
-
-
engine-version- Accepts engine versions. The results list only includes information about the DB engine versions for these engine versions. -
status- Accepts engine version statuses. The results list only includes information about the DB engine versions for these statuses. Valid statuses are the following:-
available -
deprecated
-
Parameter includeAll :
Specifies whether to also list the engine versions that aren't available.
The default is to list only available engine versions.
Parameter listSupportedCharacterSets :
Specifies whether to list the supported character sets for each engine
version.
If this parameter is enabled and the requested engine supports the
CharacterSetName parameter for CreateDBInstance,
the response includes a list of supported character sets for each engine
version.
For RDS Custom, the default is not to list supported character sets. If you enable this parameter, RDS Custom returns no results.
Parameter listSupportedTimezones :
Specifies whether to list the supported time zones for each engine
version.
If this parameter is enabled and the requested engine supports the
TimeZone parameter for CreateDBInstance, the
response includes a list of supported time zones for each engine version.
For RDS Custom, the default is not to list supported time zones. If you enable this parameter, RDS Custom returns no results.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more than the
MaxRecords value is available, a pagination token called a
marker is included in the response so you can retrieve the remaining
results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBEngineVersionMessage> describeDBEngineVersions({
String? dBParameterGroupFamily,
bool? defaultOnly,
String? engine,
String? engineVersion,
List<Filter>? filters,
bool? includeAll,
bool? listSupportedCharacterSets,
bool? listSupportedTimezones,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBParameterGroupFamily != null)
'DBParameterGroupFamily': dBParameterGroupFamily,
if (defaultOnly != null) 'DefaultOnly': defaultOnly.toString(),
if (engine != null) 'Engine': engine,
if (engineVersion != null) 'EngineVersion': engineVersion,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (includeAll != null) 'IncludeAll': includeAll.toString(),
if (listSupportedCharacterSets != null)
'ListSupportedCharacterSets': listSupportedCharacterSets.toString(),
if (listSupportedTimezones != null)
'ListSupportedTimezones': listSupportedTimezones.toString(),
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBEngineVersions',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBEngineVersionsResult',
);
return DBEngineVersionMessage.fromXml($result);
}