describeDBInstances method
Describes provisioned RDS instances. This API supports pagination.
May throw DBInstanceNotFoundFault.
Parameter dBInstanceIdentifier :
The user-supplied instance identifier or the Amazon Resource Name (ARN) of
the DB instance. If this parameter is specified, information from only the
specific DB instance is returned. This parameter isn't case-sensitive.
Constraints:
- If supplied, must match the identifier of an existing DB instance.
Parameter filters :
A filter that specifies one or more DB instances to describe.
Supported Filters:
-
db-cluster-id- Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list only includes information about the DB instances associated with the DB clusters identified by these ARNs. -
db-instance-id- Accepts DB instance identifiers and DB instance Amazon Resource Names (ARNs). The results list only includes information about the DB instances identified by these ARNs. -
dbi-resource-id- Accepts DB instance resource identifiers. The results list only includes information about the DB instances identified by these DB instance resource identifiers. -
domain- Accepts Active Directory directory IDs. The results list only includes information about the DB instances associated with these domains. -
engine- Accepts engine names. The results list only includes information about the DB instances for these engines.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBInstances request. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBInstanceMessage> describeDBInstances({
String? dBInstanceIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBInstanceIdentifier != null)
'DBInstanceIdentifier': dBInstanceIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBInstances',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBInstancesResult',
);
return DBInstanceMessage.fromXml($result);
}