describeDBParameterGroups method
Returns a list of DBParameterGroup descriptions. If a
DBParameterGroupName is specified, the list will contain only
the description of the specified DB parameter group.
May throw DBParameterGroupNotFoundFault.
Parameter dBParameterGroupName :
The name of a specific DB parameter group to return details for.
Constraints:
- If supplied, must match the name of an existing DBClusterParameterGroup.
Parameter filters :
This parameter isn't currently supported.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBParameterGroups request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBParameterGroupsMessage> describeDBParameterGroups({
String? dBParameterGroupName,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBParameterGroupName != null)
'DBParameterGroupName': dBParameterGroupName,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBParameterGroups',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBParameterGroupsResult',
);
return DBParameterGroupsMessage.fromXml($result);
}