describeDBParameters method
Returns the detailed parameter list for a particular DB parameter group.
May throw DBParameterGroupNotFoundFault.
Parameter dBParameterGroupName :
The name of a specific DB parameter group to return details for.
Constraints:
- If supplied, must match the name of an existing DBParameterGroup.
Parameter filters :
A filter that specifies one or more DB parameters to describe.
The only supported filter is parameter-name. The results list
only includes information about the DB parameters with these names.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBParameters request. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Parameter source :
The parameter types to return.
Default: All parameter types returned
Valid Values: user | system | engine-default
Implementation
Future<DBParameterGroupDetails> describeDBParameters({
required String dBParameterGroupName,
List<Filter>? filters,
String? marker,
int? maxRecords,
String? source,
}) async {
final $request = <String, String>{
'DBParameterGroupName': dBParameterGroupName,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (source != null) 'Source': source,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBParameters',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBParametersResult',
);
return DBParameterGroupDetails.fromXml($result);
}