describeDBProxies method

Future<DescribeDBProxiesResponse> describeDBProxies({
  1. String? dBProxyName,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
})

Returns information about DB proxies.

May throw DBProxyNotFoundFault.

Parameter dBProxyName : The name of the DB proxy. If you omit this parameter, the output includes information about all DB proxies owned by your Amazon Web Services account ID.

Parameter filters : This parameter is not currently supported.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Implementation

Future<DescribeDBProxiesResponse> describeDBProxies({
  String? dBProxyName,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  _s.validateNumRange(
    'maxRecords',
    maxRecords,
    20,
    100,
  );
  final $request = <String, String>{
    if (dBProxyName != null) 'DBProxyName': dBProxyName,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDBProxies',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDBProxiesResult',
  );
  return DescribeDBProxiesResponse.fromXml($result);
}