describeDBProxyEndpoints method

Future<DescribeDBProxyEndpointsResponse> describeDBProxyEndpoints({
  1. String? dBProxyEndpointName,
  2. String? dBProxyName,
  3. List<Filter>? filters,
  4. String? marker,
  5. int? maxRecords,
})

Returns information about DB proxy endpoints.

May throw DBProxyEndpointNotFoundFault. May throw DBProxyNotFoundFault.

Parameter dBProxyEndpointName : The name of a DB proxy endpoint to describe. If you omit this parameter, the output includes information about all DB proxy endpoints associated with the specified proxy.

Parameter dBProxyName : The name of the DB proxy whose endpoints you want to describe. If you omit this parameter, the output includes information about all DB proxy endpoints associated with all your DB proxies.

Parameter filters : This parameter is not currently supported.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Implementation

Future<DescribeDBProxyEndpointsResponse> describeDBProxyEndpoints({
  String? dBProxyEndpointName,
  String? dBProxyName,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  _s.validateNumRange(
    'maxRecords',
    maxRecords,
    20,
    100,
  );
  final $request = <String, String>{
    if (dBProxyEndpointName != null)
      'DBProxyEndpointName': dBProxyEndpointName,
    if (dBProxyName != null) 'DBProxyName': dBProxyName,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDBProxyEndpoints',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDBProxyEndpointsResult',
  );
  return DescribeDBProxyEndpointsResponse.fromXml($result);
}