describeDBProxyTargets method

Future<DescribeDBProxyTargetsResponse> describeDBProxyTargets({
  1. required String dBProxyName,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
  5. String? targetGroupName,
})

Returns information about DBProxyTarget objects. This API supports pagination.

May throw DBProxyNotFoundFault. May throw DBProxyTargetGroupNotFoundFault. May throw DBProxyTargetNotFoundFault. May throw InvalidDBProxyStateFault.

Parameter dBProxyName : The identifier of the DBProxyTarget to describe.

Parameter filters : This parameter is not currently supported.

Parameter marker : An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Parameter targetGroupName : The identifier of the DBProxyTargetGroup to describe.

Implementation

Future<DescribeDBProxyTargetsResponse> describeDBProxyTargets({
  required String dBProxyName,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
  String? targetGroupName,
}) async {
  _s.validateNumRange(
    'maxRecords',
    maxRecords,
    20,
    100,
  );
  final $request = <String, String>{
    'DBProxyName': dBProxyName,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (targetGroupName != null) 'TargetGroupName': targetGroupName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDBProxyTargets',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDBProxyTargetsResult',
  );
  return DescribeDBProxyTargetsResponse.fromXml($result);
}