describeDBSecurityGroups method
Returns a list of DBSecurityGroup descriptions. If a
DBSecurityGroupName is specified, the list will contain only
the descriptions of the specified DB security group.
May throw DBSecurityGroupNotFoundFault.
Parameter dBSecurityGroupName :
The name of the DB security group to return details for.
Parameter filters :
This parameter isn't currently supported.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBSecurityGroups request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DBSecurityGroupMessage> describeDBSecurityGroups({
String? dBSecurityGroupName,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (dBSecurityGroupName != null)
'DBSecurityGroupName': dBSecurityGroupName,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBSecurityGroups',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBSecurityGroupsResult',
);
return DBSecurityGroupMessage.fromXml($result);
}