describeDBSnapshotAttributes method
- required String dBSnapshotIdentifier,
Returns a list of DB snapshot attribute names and values for a manual DB snapshot.
When sharing snapshots with other Amazon Web Services accounts,
DescribeDBSnapshotAttributes returns the restore
attribute and a list of IDs for the Amazon Web Services accounts that are
authorized to copy or restore the manual DB snapshot. If all
is included in the list of values for the restore attribute,
then the manual DB snapshot is public and can be copied or restored by all
Amazon Web Services accounts.
To add or remove access for an Amazon Web Services account to copy or
restore a manual DB snapshot, or to make the manual DB snapshot public or
private, use the ModifyDBSnapshotAttribute API action.
May throw DBSnapshotNotFoundFault.
Parameter dBSnapshotIdentifier :
The identifier for the DB snapshot to describe the attributes for.
Implementation
Future<DescribeDBSnapshotAttributesResult> describeDBSnapshotAttributes({
required String dBSnapshotIdentifier,
}) async {
final $request = <String, String>{
'DBSnapshotIdentifier': dBSnapshotIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBSnapshotAttributes',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBSnapshotAttributesResult',
);
return DescribeDBSnapshotAttributesResult.fromXml($result);
}