describeEngineDefaultParameters method

Future<DescribeEngineDefaultParametersResult> describeEngineDefaultParameters({
  1. required String dBParameterGroupFamily,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
})

Returns the default engine and system parameter information for the specified database engine.

Parameter dBParameterGroupFamily : The name of the DB parameter group family.

Valid Values:

  • aurora-mysql5.7
  • aurora-mysql8.0
  • aurora-postgresql10
  • aurora-postgresql11
  • aurora-postgresql12
  • aurora-postgresql13
  • aurora-postgresql14
  • custom-oracle-ee-19
  • custom-oracle-ee-cdb-19
  • db2-ae
  • db2-se
  • mariadb10.2
  • mariadb10.3
  • mariadb10.4
  • mariadb10.5
  • mariadb10.6
  • mysql5.7
  • mysql8.0
  • oracle-ee-19
  • oracle-ee-cdb-19
  • oracle-ee-cdb-21
  • oracle-se2-19
  • oracle-se2-cdb-19
  • oracle-se2-cdb-21
  • postgres10
  • postgres11
  • postgres12
  • postgres13
  • postgres14
  • sqlserver-ee-11.0
  • sqlserver-ee-12.0
  • sqlserver-ee-13.0
  • sqlserver-ee-14.0
  • sqlserver-ee-15.0
  • sqlserver-ex-11.0
  • sqlserver-ex-12.0
  • sqlserver-ex-13.0
  • sqlserver-ex-14.0
  • sqlserver-ex-15.0
  • sqlserver-se-11.0
  • sqlserver-se-12.0
  • sqlserver-se-13.0
  • sqlserver-se-14.0
  • sqlserver-se-15.0
  • sqlserver-web-11.0
  • sqlserver-web-12.0
  • sqlserver-web-13.0
  • sqlserver-web-14.0
  • sqlserver-web-15.0

Parameter filters : A filter that specifies one or more parameters to describe.

The only supported filter is parameter-name. The results list only includes information about the parameters with these names.

Parameter marker : An optional pagination token provided by a previous DescribeEngineDefaultParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.

Implementation

Future<DescribeEngineDefaultParametersResult>
    describeEngineDefaultParameters({
  required String dBParameterGroupFamily,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    'DBParameterGroupFamily': dBParameterGroupFamily,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeEngineDefaultParameters',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeEngineDefaultParametersResult',
  );
  return DescribeEngineDefaultParametersResult.fromXml($result);
}