describeEventCategories method

Future<EventCategoriesMessage> describeEventCategories({
  1. List<Filter>? filters,
  2. String? sourceType,
})

Displays a list of categories for all event source types, or, if specified, for a specified source type. You can also see this list in the "Amazon RDS event categories and event messages" section of the Amazon RDS User Guide or the Amazon Aurora User Guide .

Parameter filters : This parameter isn't currently supported.

Parameter sourceType : The type of source that is generating the events. For RDS Proxy events, specify db-proxy.

Valid Values: db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot | db-proxy

Implementation

Future<EventCategoriesMessage> describeEventCategories({
  List<Filter>? filters,
  String? sourceType,
}) async {
  final $request = <String, String>{
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (sourceType != null) 'SourceType': sourceType,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeEventCategories',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeEventCategoriesResult',
  );
  return EventCategoriesMessage.fromXml($result);
}