describeEventSubscriptions method

Future<EventSubscriptionsMessage> describeEventSubscriptions({
  1. List<Filter>? filters,
  2. String? marker,
  3. int? maxRecords,
  4. String? subscriptionName,
})

Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status.

If you specify a SubscriptionName, lists the description for that subscription.

May throw SubscriptionNotFoundFault.

Parameter filters : This parameter isn't currently supported.

Parameter marker : An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.

Parameter subscriptionName : The name of the RDS event notification subscription you want to describe.

Implementation

Future<EventSubscriptionsMessage> describeEventSubscriptions({
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
  String? subscriptionName,
}) async {
  final $request = <String, String>{
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (subscriptionName != null) 'SubscriptionName': subscriptionName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeEventSubscriptions',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeEventSubscriptionsResult',
  );
  return EventSubscriptionsMessage.fromXml($result);
}