describeOrderableDBInstanceOptions method

Future<OrderableDBInstanceOptionsMessage> describeOrderableDBInstanceOptions({
  1. required String engine,
  2. String? availabilityZoneGroup,
  3. String? dBInstanceClass,
  4. String? engineVersion,
  5. List<Filter>? filters,
  6. String? licenseModel,
  7. String? marker,
  8. int? maxRecords,
  9. bool? vpc,
})

Describes the orderable DB instance options for a specified DB engine.

Parameter engine : The name of the database engine to describe DB instance options for.

Valid Values:

  • aurora-mysql
  • aurora-postgresql
  • custom-oracle-ee
  • custom-oracle-ee-cdb
  • custom-oracle-se2
  • custom-oracle-se2-cdb
  • db2-ae
  • db2-se
  • mariadb
  • mysql
  • oracle-ee
  • oracle-ee-cdb
  • oracle-se2
  • oracle-se2-cdb
  • postgres
  • sqlserver-ee
  • sqlserver-se
  • sqlserver-ex
  • sqlserver-web

Parameter availabilityZoneGroup : The Availability Zone group associated with a Local Zone. Specify this parameter to retrieve available options for the Local Zones in the group.

Omit this parameter to show the available options in the specified Amazon Web Services Region.

This setting doesn't apply to RDS Custom DB instances.

Parameter dBInstanceClass : A filter to include only the available options for the specified DB instance class.

Parameter engineVersion : A filter to include only the available options for the specified engine version.

Parameter filters : This parameter isn't currently supported.

Parameter licenseModel : A filter to include only the available options for the specified license model.

RDS Custom supports only the BYOL licensing model.

Parameter marker : An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 1000.

Parameter vpc : Specifies whether to show only VPC or non-VPC offerings. RDS Custom supports only VPC offerings.

RDS Custom supports only VPC offerings. If you describe non-VPC offerings for RDS Custom, the output shows VPC offerings.

Implementation

Future<OrderableDBInstanceOptionsMessage> describeOrderableDBInstanceOptions({
  required String engine,
  String? availabilityZoneGroup,
  String? dBInstanceClass,
  String? engineVersion,
  List<Filter>? filters,
  String? licenseModel,
  String? marker,
  int? maxRecords,
  bool? vpc,
}) async {
  final $request = <String, String>{
    'Engine': engine,
    if (availabilityZoneGroup != null)
      'AvailabilityZoneGroup': availabilityZoneGroup,
    if (dBInstanceClass != null) 'DBInstanceClass': dBInstanceClass,
    if (engineVersion != null) 'EngineVersion': engineVersion,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (licenseModel != null) 'LicenseModel': licenseModel,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (vpc != null) 'Vpc': vpc.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeOrderableDBInstanceOptions',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeOrderableDBInstanceOptionsResult',
  );
  return OrderableDBInstanceOptionsMessage.fromXml($result);
}