describeTenantDatabases method

Future<TenantDatabasesMessage> describeTenantDatabases({
  1. String? dBInstanceIdentifier,
  2. List<Filter>? filters,
  3. String? marker,
  4. int? maxRecords,
  5. String? tenantDBName,
})

Describes the tenant databases in a DB instance that uses the multi-tenant configuration. Only RDS for Oracle CDB instances are supported.

May throw DBInstanceNotFoundFault.

Parameter dBInstanceIdentifier : The user-supplied DB instance identifier, which must match the identifier of an existing instance owned by the Amazon Web Services account. This parameter isn't case-sensitive.

Parameter filters : A filter that specifies one or more database tenants to describe.

Supported filters:

  • tenant-db-name - Tenant database names. The results list only includes information about the tenant databases that match these tenant DB names.
  • tenant-database-resource-id - Tenant database resource identifiers.
  • dbi-resource-id - DB instance resource identifiers. The results list only includes information about the tenants contained within the DB instances identified by these resource identifiers.

Parameter marker : An optional pagination token provided by a previous DescribeTenantDatabases request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Parameter tenantDBName : The user-supplied tenant database name, which must match the name of an existing tenant database on the specified DB instance owned by your Amazon Web Services account. This parameter isn’t case-sensitive.

Implementation

Future<TenantDatabasesMessage> describeTenantDatabases({
  String? dBInstanceIdentifier,
  List<Filter>? filters,
  String? marker,
  int? maxRecords,
  String? tenantDBName,
}) async {
  final $request = <String, String>{
    if (dBInstanceIdentifier != null)
      'DBInstanceIdentifier': dBInstanceIdentifier,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (tenantDBName != null) 'TenantDBName': tenantDBName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeTenantDatabases',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeTenantDatabasesResult',
  );
  return TenantDatabasesMessage.fromXml($result);
}