failoverGlobalCluster method
Promotes the specified secondary DB cluster to be the primary DB cluster in the global database cluster to fail over or switch over a global database. Switchover operations were previously called "managed planned failovers." How you use this operation depends on whether you are failing over or switching over your global database cluster:
-
Failing over - Specify the
AllowDataLossparameter and don't specify theSwitchoverparameter. -
Switching over - Specify the
Switchoverparameter or omit it, but don't specify theAllowDataLossparameter.
While failing over and switching over a global database cluster both change the primary DB cluster, you use these operations for different reasons:
-
Failing over - Use this operation to respond to an unplanned event,
such as a Regional disaster in the primary Region. Failing over can result
in a loss of write transaction data that wasn't replicated to the chosen
secondary before the failover event occurred. However, the recovery
process that promotes a DB instance on the chosen seconday DB cluster to
be the primary writer DB instance guarantees that the data is in a
transactionally consistent state.
For more information about failing over an Amazon Aurora global database, see Performing managed failovers for Aurora global databases in the Amazon Aurora User Guide.
-
Switching over - Use this operation on a healthy global database
cluster for planned events, such as Regional rotation or to fail back to
the original primary DB cluster after a failover operation. With this
operation, there is no data loss.
For more information about switching over an Amazon Aurora global database, see Performing switchovers for Aurora global databases in the Amazon Aurora User Guide.
May throw DBClusterNotFoundFault.
May throw GlobalClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidGlobalClusterStateFault.
Parameter globalClusterIdentifier :
The identifier of the global database cluster (Aurora global database)
this operation should apply to. The identifier is the unique key assigned
by the user when the Aurora global database is created. In other words,
it's the name of the Aurora global database.
Constraints:
- Must match the identifier of an existing global database cluster.
Parameter targetDbClusterIdentifier :
The identifier of the secondary Aurora DB cluster that you want to promote
to the primary for the global database cluster. Use the Amazon Resource
Name (ARN) for the identifier so that Aurora can locate the cluster in its
Amazon Web Services Region.
Parameter allowDataLoss :
Specifies whether to allow data loss for this global database cluster
operation. Allowing data loss triggers a global failover operation.
If you don't specify AllowDataLoss, the global database
cluster operation defaults to a switchover.
Constraints:
-
Can't be specified together with the
Switchoverparameter.
Parameter switchover :
Specifies whether to switch over this global database cluster.
Constraints:
-
Can't be specified together with the
AllowDataLossparameter.
Implementation
Future<FailoverGlobalClusterResult> failoverGlobalCluster({
required String globalClusterIdentifier,
required String targetDbClusterIdentifier,
bool? allowDataLoss,
bool? switchover,
}) async {
final $request = <String, String>{
'GlobalClusterIdentifier': globalClusterIdentifier,
'TargetDbClusterIdentifier': targetDbClusterIdentifier,
if (allowDataLoss != null) 'AllowDataLoss': allowDataLoss.toString(),
if (switchover != null) 'Switchover': switchover.toString(),
};
final $result = await _protocol.send(
$request,
action: 'FailoverGlobalCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'FailoverGlobalClusterResult',
);
return FailoverGlobalClusterResult.fromXml($result);
}