modifyActivityStream method
- AuditPolicyState? auditPolicyState,
- String? resourceArn,
Changes the audit policy state of a database activity stream to either locked (default) or unlocked. A locked policy is read-only, whereas an unlocked policy is read/write. If your activity stream is started and locked, you can unlock it, customize your audit policy, and then lock your activity stream. Restarting the activity stream isn't required. For more information, see Modifying a database activity stream in the Amazon RDS User Guide.
This operation is supported for RDS for Oracle and Microsoft SQL Server.
May throw DBInstanceNotFoundFault.
May throw InvalidDBInstanceStateFault.
May throw ResourceNotFoundFault.
Parameter auditPolicyState :
The audit policy state. When a policy is unlocked, it is read/write. When
it is locked, it is read-only. You can edit your audit policy only when
the activity stream is unlocked or stopped.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the RDS for Oracle or Microsoft SQL
Server DB instance. For example,
arn:aws:rds:us-east-1:12345667890:db:my-orcl-db.
Implementation
Future<ModifyActivityStreamResponse> modifyActivityStream({
AuditPolicyState? auditPolicyState,
String? resourceArn,
}) async {
final $request = <String, String>{
if (auditPolicyState != null) 'AuditPolicyState': auditPolicyState.value,
if (resourceArn != null) 'ResourceArn': resourceArn,
};
final $result = await _protocol.send(
$request,
action: 'ModifyActivityStream',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyActivityStreamResult',
);
return ModifyActivityStreamResponse.fromXml($result);
}