modifyDBClusterParameterGroup method
Modifies the parameters of a DB cluster parameter group. To modify more
than one parameter, submit a list of the following:
ParameterName, ParameterValue, and
ApplyMethod. A maximum of 20 parameters can be modified in a
single request.
For more information on Amazon Aurora DB clusters, see
What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
May throw DBParameterGroupNotFoundFault.
May throw InvalidDBParameterGroupStateFault.
Parameter dBClusterParameterGroupName :
The name of the DB cluster parameter group to modify.
Parameter parameters :
A list of parameters in the DB cluster parameter group to modify.
Valid Values (for the application method): immediate |
pending-reboot
When the application method is immediate, changes to dynamic
parameters are applied immediately to the DB clusters associated with the
parameter group. When the application method is
pending-reboot, changes to dynamic and static parameters are
applied after a reboot without failover to the DB clusters associated with
the parameter group.
Implementation
Future<DBClusterParameterGroupNameMessage> modifyDBClusterParameterGroup({
required String dBClusterParameterGroupName,
required List<Parameter> parameters,
}) async {
final $request = <String, String>{
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.Parameter.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'ModifyDBClusterParameterGroup',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyDBClusterParameterGroupResult',
);
return DBClusterParameterGroupNameMessage.fromXml($result);
}