modifyDBSnapshotAttribute method

Future<ModifyDBSnapshotAttributeResult> modifyDBSnapshotAttribute({
  1. required String attributeName,
  2. required String dBSnapshotIdentifier,
  3. List<String>? valuesToAdd,
  4. List<String>? valuesToRemove,
})

Adds an attribute and values to, or removes an attribute and values from, a manual DB snapshot.

To share a manual DB snapshot with other Amazon Web Services accounts, specify restore as the AttributeName and use the ValuesToAdd parameter to add a list of IDs of the Amazon Web Services accounts that are authorized to restore the manual DB snapshot. Uses the value all to make the manual DB snapshot public, which means it can be copied or restored by all Amazon Web Services accounts. If the manual DB snapshot is encrypted, it can be shared, but only by specifying a list of authorized Amazon Web Services account IDs for the ValuesToAdd parameter. You can't use all as a value for that parameter in this case.

To view which Amazon Web Services accounts have access to copy or restore a manual DB snapshot, or whether a manual DB snapshot public or private, use the DescribeDBSnapshotAttributes API operation. The accounts are returned as values for the restore attribute.

May throw DBSnapshotNotFoundFault. May throw InvalidDBSnapshotStateFault. May throw SharedSnapshotQuotaExceededFault.

Parameter attributeName : The name of the DB snapshot attribute to modify.

To manage authorization for other Amazon Web Services accounts to copy or restore a manual DB snapshot, set this value to restore.

Parameter dBSnapshotIdentifier : The identifier for the DB snapshot to modify the attributes for.

Parameter valuesToAdd : A list of DB snapshot attributes to add to the attribute specified by AttributeName.

To authorize other Amazon Web Services accounts to copy or restore a manual snapshot, set this list to include one or more Amazon Web Services account IDs, or all to make the manual DB snapshot restorable by any Amazon Web Services account. Do not add the all value for any manual DB snapshots that contain private information that you don't want available to all Amazon Web Services accounts.

Parameter valuesToRemove : A list of DB snapshot attributes to remove from the attribute specified by AttributeName.

To remove authorization for other Amazon Web Services accounts to copy or restore a manual snapshot, set this list to include one or more Amazon Web Services account identifiers, or all to remove authorization for any Amazon Web Services account to copy or restore the DB snapshot. If you specify all, an Amazon Web Services account whose account ID is explicitly added to the restore attribute can still copy or restore the manual DB snapshot.

Implementation

Future<ModifyDBSnapshotAttributeResult> modifyDBSnapshotAttribute({
  required String attributeName,
  required String dBSnapshotIdentifier,
  List<String>? valuesToAdd,
  List<String>? valuesToRemove,
}) async {
  final $request = <String, String>{
    'AttributeName': attributeName,
    'DBSnapshotIdentifier': dBSnapshotIdentifier,
    if (valuesToAdd != null)
      if (valuesToAdd.isEmpty)
        'ValuesToAdd': ''
      else
        for (var i1 = 0; i1 < valuesToAdd.length; i1++)
          'ValuesToAdd.AttributeValue.${i1 + 1}': valuesToAdd[i1],
    if (valuesToRemove != null)
      if (valuesToRemove.isEmpty)
        'ValuesToRemove': ''
      else
        for (var i1 = 0; i1 < valuesToRemove.length; i1++)
          'ValuesToRemove.AttributeValue.${i1 + 1}': valuesToRemove[i1],
  };
  final $result = await _protocol.send(
    $request,
    action: 'ModifyDBSnapshotAttribute',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ModifyDBSnapshotAttributeResult',
  );
  return ModifyDBSnapshotAttributeResult.fromXml($result);
}