modifyGlobalCluster method
Modifies a setting for an Amazon Aurora global database cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request. For more information on Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide.
May throw GlobalClusterAlreadyExistsFault.
May throw GlobalClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidGlobalClusterStateFault.
Parameter globalClusterIdentifier :
The cluster identifier for the global cluster to modify. This parameter
isn't case-sensitive.
Constraints:
- Must match the identifier of an existing global database cluster.
Parameter allowMajorVersionUpgrade :
Specifies whether to allow major version upgrades.
Constraints: Must be enabled if you specify a value for the
EngineVersion parameter that's a different major version than
the global cluster's current version.
If you upgrade the major version of a global database, the cluster and DB instance parameter groups are set to the default parameter groups for the new version. Apply any custom parameter groups after completing the upgrade.
Parameter deletionProtection :
Specifies whether to enable deletion protection for the global database
cluster. The global database cluster can't be deleted when deletion
protection is enabled.
Parameter engineVersion :
The version number of the database engine to which you want to upgrade.
To list all of the available engine versions for aurora-mysql
(for MySQL-based Aurora global databases), use the following command:
aws rds describe-db-engine-versions --engine aurora-mysql --query
'*[]|[?SupportsGlobalDatabases == true].[EngineVersion]'
To list all of the available engine versions for
aurora-postgresql (for PostgreSQL-based Aurora global
databases), use the following command:
aws rds describe-db-engine-versions --engine aurora-postgresql
--query '*[]|[?SupportsGlobalDatabases ==
true].[EngineVersion]'
Parameter newGlobalClusterIdentifier :
The new cluster identifier for the global database cluster. This value is
stored as a lowercase string.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- The first character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-cluster2
Implementation
Future<ModifyGlobalClusterResult> modifyGlobalCluster({
required String globalClusterIdentifier,
bool? allowMajorVersionUpgrade,
bool? deletionProtection,
String? engineVersion,
String? newGlobalClusterIdentifier,
}) async {
final $request = <String, String>{
'GlobalClusterIdentifier': globalClusterIdentifier,
if (allowMajorVersionUpgrade != null)
'AllowMajorVersionUpgrade': allowMajorVersionUpgrade.toString(),
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (engineVersion != null) 'EngineVersion': engineVersion,
if (newGlobalClusterIdentifier != null)
'NewGlobalClusterIdentifier': newGlobalClusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'ModifyGlobalCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyGlobalClusterResult',
);
return ModifyGlobalClusterResult.fromXml($result);
}