rebootDBShardGroup method

Future<DBShardGroup> rebootDBShardGroup({
  1. required String dBShardGroupIdentifier,
})

You might need to reboot your DB shard group, usually for maintenance reasons. For example, if you make certain modifications, reboot the DB shard group for the changes to take effect.

This operation applies only to Aurora Limitless Database DBb shard groups.

May throw DBShardGroupNotFoundFault. May throw InvalidDBShardGroupStateFault.

Parameter dBShardGroupIdentifier : The name of the DB shard group to reboot.

Implementation

Future<DBShardGroup> rebootDBShardGroup({
  required String dBShardGroupIdentifier,
}) async {
  final $request = <String, String>{
    'DBShardGroupIdentifier': dBShardGroupIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'RebootDBShardGroup',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RebootDBShardGroupResult',
  );
  return DBShardGroup.fromXml($result);
}