removeFromGlobalCluster method

Future<RemoveFromGlobalClusterResult> removeFromGlobalCluster({
  1. required String dbClusterIdentifier,
  2. required String globalClusterIdentifier,
})

Detaches an Aurora secondary cluster from an Aurora global database cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary cluster in a different Region.

May throw DBClusterNotFoundFault. May throw GlobalClusterNotFoundFault. May throw InvalidDBClusterStateFault. May throw InvalidGlobalClusterStateFault.

Parameter dbClusterIdentifier : The Amazon Resource Name (ARN) identifying the cluster that was detached from the Aurora global database cluster.

Parameter globalClusterIdentifier : The cluster identifier to detach from the Aurora global database cluster.

Implementation

Future<RemoveFromGlobalClusterResult> removeFromGlobalCluster({
  required String dbClusterIdentifier,
  required String globalClusterIdentifier,
}) async {
  final $request = <String, String>{
    'DbClusterIdentifier': dbClusterIdentifier,
    'GlobalClusterIdentifier': globalClusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'RemoveFromGlobalCluster',
    version: '2014-10-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RemoveFromGlobalClusterResult',
  );
  return RemoveFromGlobalClusterResult.fromXml($result);
}