resetDBClusterParameterGroup method
Modifies the parameters of a DB cluster parameter group to the default
value. To reset specific parameters submit a list of the following:
ParameterName and ApplyMethod. To reset the
entire DB cluster parameter group, specify the
DBClusterParameterGroupName and
ResetAllParameters parameters.
When resetting the entire group, dynamic parameters are updated
immediately and static parameters are set to pending-reboot
to take effect on the next DB instance restart or
RebootDBInstance request. You must call
RebootDBInstance for every DB instance in your DB cluster
that you want the updated static parameter to apply to.
For more information on Amazon Aurora DB clusters, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
May throw DBParameterGroupNotFoundFault.
May throw InvalidDBParameterGroupStateFault.
Parameter dBClusterParameterGroupName :
The name of the DB cluster parameter group to reset.
Parameter parameters :
A list of parameter names in the DB cluster parameter group to reset to
the default values. You can't use this parameter if the
ResetAllParameters parameter is enabled.
Parameter resetAllParameters :
Specifies whether to reset all parameters in the DB cluster parameter
group to their default values. You can't use this parameter if there is a
list of parameter names specified for the Parameters
parameter.
Implementation
Future<DBClusterParameterGroupNameMessage> resetDBClusterParameterGroup({
required String dBClusterParameterGroupName,
List<Parameter>? parameters,
bool? resetAllParameters,
}) async {
final $request = <String, String>{
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (parameters != null)
if (parameters.isEmpty)
'Parameters': ''
else
for (var i1 = 0; i1 < parameters.length; i1++)
for (var e3 in parameters[i1].toQueryMap().entries)
'Parameters.Parameter.${i1 + 1}.${e3.key}': e3.value,
if (resetAllParameters != null)
'ResetAllParameters': resetAllParameters.toString(),
};
final $result = await _protocol.send(
$request,
action: 'ResetDBClusterParameterGroup',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ResetDBClusterParameterGroupResult',
);
return DBClusterParameterGroupNameMessage.fromXml($result);
}