restoreDBInstanceFromDBSnapshot method
- required String dBInstanceIdentifier,
- List<
AdditionalStorageVolume> ? additionalStorageVolumes, - int? allocatedStorage,
- bool? autoMinorVersionUpgrade,
- String? availabilityZone,
- int? backupRetentionPeriod,
- String? backupTarget,
- String? cACertificateIdentifier,
- bool? copyTagsToSnapshot,
- String? customIamInstanceProfile,
- String? dBClusterSnapshotIdentifier,
- String? dBInstanceClass,
- String? dBName,
- String? dBParameterGroupName,
- String? dBSnapshotIdentifier,
- String? dBSubnetGroupName,
- bool? dedicatedLogVolume,
- bool? deletionProtection,
- String? domain,
- String? domainAuthSecretArn,
- List<
String> ? domainDnsIps, - String? domainFqdn,
- String? domainIAMRoleName,
- String? domainOu,
- List<
String> ? enableCloudwatchLogsExports, - bool? enableCustomerOwnedIp,
- bool? enableIAMDatabaseAuthentication,
- String? engine,
- String? engineLifecycleSupport,
- int? iops,
- String? licenseModel,
- bool? manageMasterUserPassword,
- String? masterUserSecretKmsKeyId,
- bool? multiAZ,
- String? networkType,
- String? optionGroupName,
- int? port,
- String? preferredBackupWindow,
- List<
ProcessorFeature> ? processorFeatures, - bool? publiclyAccessible,
- int? storageThroughput,
- String? storageType,
- List<
TagSpecification> ? tagSpecifications, - List<
Tag> ? tags, - String? tdeCredentialArn,
- String? tdeCredentialPassword,
- bool? useDefaultProcessorFeatures,
- List<
String> ? vpcSecurityGroupIds,
Creates a new DB instance from a DB snapshot. The target database is created from the source database restore point with most of the source's original configuration, including the default security group and DB parameter group. By default, the new DB instance is created as a Single-AZ deployment, except when the instance is a SQL Server instance that has an option group associated with mirroring. In this case, the instance becomes a Multi-AZ deployment, not a Single-AZ deployment.
If you want to replace your original DB instance with the new, restored DB
instance, then rename your original DB instance before you call the
RestoreDBInstanceFromDBSnapshot operation. RDS doesn't allow
two DB instances with the same name. After you have renamed your original
DB instance with a different identifier, then you can pass the original
name of the DB instance as the DBInstanceIdentifier in the
call to the RestoreDBInstanceFromDBSnapshot operation. The
result is that you replace the original DB instance with the DB instance
created from the snapshot.
If you are restoring from a shared manual DB snapshot, the
DBSnapshotIdentifier must be the ARN of the shared DB
snapshot.
To restore from a DB snapshot with an unsupported engine version, you must first upgrade the engine version of the snapshot. For more information about upgrading a RDS for MySQL DB snapshot engine version, see Upgrading a MySQL DB snapshot engine version. For more information about upgrading a RDS for PostgreSQL DB snapshot engine version, Upgrading a PostgreSQL DB snapshot engine version.
May throw AuthorizationNotFoundFault.
May throw BackupPolicyNotFoundFault.
May throw CertificateNotFoundFault.
May throw DBClusterSnapshotNotFoundFault.
May throw DBInstanceAlreadyExistsFault.
May throw DBParameterGroupNotFoundFault.
May throw DBSecurityGroupNotFoundFault.
May throw DBSnapshotNotFoundFault.
May throw DBSubnetGroupDoesNotCoverEnoughAZs.
May throw DBSubnetGroupNotFoundFault.
May throw DomainNotFoundFault.
May throw InstanceQuotaExceededFault.
May throw InsufficientDBInstanceCapacityFault.
May throw InvalidDBSnapshotStateFault.
May throw InvalidRestoreFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw NetworkTypeNotSupported.
May throw OptionGroupNotFoundFault.
May throw ProvisionedIopsNotAvailableInAZFault.
May throw StorageQuotaExceededFault.
May throw StorageTypeNotSupportedFault.
May throw TenantDatabaseQuotaExceededFault.
May throw VpcEncryptionControlViolationException.
Parameter dBInstanceIdentifier :
The name of the DB instance to create from the DB snapshot. This parameter
isn't case-sensitive.
Constraints:
- Must contain from 1 to 63 numbers, letters, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
my-snapshot-id
Parameter additionalStorageVolumes :
A list of additional storage volumes to create for the DB instance. You
can create up to three additional storage volumes using the names
rdsdbdata2, rdsdbdata3, and
rdsdbdata4. Additional storage volumes are supported for RDS
for Oracle and RDS for SQL Server DB instances only.
Parameter allocatedStorage :
The amount of storage (in gibibytes) to allocate initially for the DB
instance. Follow the allocation rules specified in CreateDBInstance.
This setting isn't valid for RDS for SQL Server.
Parameter autoMinorVersionUpgrade :
Specifies whether to automatically apply minor version upgrades to the DB
instance during the maintenance window.
If you restore an RDS Custom DB instance, you must disable this parameter.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
Parameter availabilityZone :
The Availability Zone (AZ) where the DB instance will be created.
Default: A random, system-chosen Availability Zone.
Constraint: You can't specify the AvailabilityZone parameter
if the DB instance is a Multi-AZ deployment.
Example: us-east-1a
Parameter backupRetentionPeriod :
The number of days to retain automated backups. Setting this parameter to
a positive number enables backups. Setting this parameter to 0 disables
automated backups.
This setting doesn't apply to Amazon Aurora DB instances. The retention
period for automated backups is managed by the DB cluster. For more
information, see ModifyDBCluster.
Default: Uses existing setting
Constraints:
- Must be a value from 0 to 35.
- Can't be set to 0 if the DB instance is a source to read replicas.
- Can't be set to 0 for an RDS Custom for Oracle DB instance.
Parameter backupTarget :
Specifies where automated backups and manual snapshots are stored for the
restored DB instance.
Possible values are local (Dedicated Local Zone),
outposts (Amazon Web Services Outposts), and
region (Amazon Web Services Region). The default is
region.
For more information, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.
Parameter cACertificateIdentifier :
The CA certificate identifier to use for the DB instance's server
certificate.
This setting doesn't apply to RDS Custom DB instances.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
Parameter copyTagsToSnapshot :
Specifies whether to copy all tags from the restored DB instance to
snapshots of the DB instance.
In most cases, tags aren't copied by default. However, when you restore a DB instance from a DB snapshot, RDS checks whether you specify new tags. If yes, the new tags are added to the restored DB instance. If there are no new tags, RDS looks for the tags from the source DB instance for the DB snapshot, and then adds those tags to the restored DB instance.
For more information, see Copying tags to DB instance snapshots in the Amazon RDS User Guide.
Parameter customIamInstanceProfile :
The instance profile associated with the underlying Amazon EC2 instance of
an RDS Custom DB instance. The instance profile must meet the following
requirements:
- The profile must exist in your account.
- The profile must have an IAM role that Amazon EC2 has permissions to assume.
-
The instance profile name and the associated IAM role name must start with
the prefix
AWSRDSCustom.
This setting is required for RDS Custom.
Parameter dBClusterSnapshotIdentifier :
The identifier for the Multi-AZ DB cluster snapshot to restore from.
For more information on Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide.
Constraints:
- Must match the identifier of an existing Multi-AZ DB cluster snapshot.
-
Can't be specified when
DBSnapshotIdentifieris specified. -
Must be specified when
DBSnapshotIdentifierisn't specified. -
If you are restoring from a shared manual Multi-AZ DB cluster snapshot,
the
DBClusterSnapshotIdentifiermust be the ARN of the shared snapshot. - Can't be the identifier of an Aurora DB cluster snapshot.
Parameter dBInstanceClass :
The compute and memory capacity of the Amazon RDS DB instance, for example
db.m4.large. Not all DB instance classes are available in all Amazon Web
Services Regions, or for all database engines. For the full list of DB
instance classes, and availability for your engine, see DB
Instance Class in the Amazon RDS User Guide.
Default: The same DBInstanceClass as the original DB instance.
Parameter dBName :
The name of the database for the restored DB instance.
This parameter only applies to RDS for Oracle and RDS for SQL Server DB instances. It doesn't apply to the other engines or to RDS Custom DB instances.
Parameter dBParameterGroupName :
The name of the DB parameter group to associate with this DB instance.
If you don't specify a value for DBParameterGroupName, then
RDS uses the default DBParameterGroup for the specified DB
engine.
This setting doesn't apply to RDS Custom.
Constraints:
- If supplied, must match the name of an existing DB parameter group.
- Must be 1 to 255 letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
Parameter dBSnapshotIdentifier :
The identifier for the DB snapshot to restore from.
Constraints:
- Must match the identifier of an existing DB snapshot.
-
Can't be specified when
DBClusterSnapshotIdentifieris specified. -
Must be specified when
DBClusterSnapshotIdentifierisn't specified. -
If you are restoring from a shared manual DB snapshot, the
DBSnapshotIdentifiermust be the ARN of the shared DB snapshot.
Parameter dBSubnetGroupName :
The name of the DB subnet group to use for the new instance.
Constraints:
- If supplied, must match the name of an existing DB subnet group.
mydbsubnetgroup
Parameter dedicatedLogVolume :
Specifies whether to enable a dedicated log volume (DLV) for the DB
instance.
Parameter deletionProtection :
Specifies whether to enable deletion protection for the DB instance. The
database can't be deleted when deletion protection is enabled. By default,
deletion protection isn't enabled. For more information, see
Deleting a DB Instance.
Parameter domain :
The Active Directory directory ID to restore the DB instance in. The
domain/ must be created prior to this operation. Currently, you can create
only Db2, MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances
in an Active Directory Domain.
For more information, see Kerberos Authentication in the Amazon RDS User Guide.
This setting doesn't apply to RDS Custom.
Parameter domainAuthSecretArn :
The ARN for the Secrets Manager secret with the credentials for the user
joining the domain.
Constraints:
- Can't be longer than 64 characters.
arn:aws:secretsmanager:region:account-number:secret:myselfmanagedADtestsecret-123456
Parameter domainDnsIps :
The IPv4 DNS IP addresses of your primary and secondary Active Directory
domain controllers.
Constraints:
- Two IP addresses must be provided. If there isn't a secondary domain controller, use the IP address of the primary domain controller for both entries in the list.
123.124.125.126,234.235.236.237
Parameter domainFqdn :
The fully qualified domain name (FQDN) of an Active Directory domain.
Constraints:
- Can't be longer than 64 characters.
mymanagedADtest.mymanagedAD.mydomain
Parameter domainIAMRoleName :
The name of the IAM role to use when making API calls to the Directory
Service.
This setting doesn't apply to RDS Custom DB instances.
Parameter domainOu :
The Active Directory organizational unit for your DB instance to join.
Constraints:
- Must be in the distinguished name format.
- Can't be longer than 64 characters.
OU=mymanagedADtestOU,DC=mymanagedADtest,DC=mymanagedAD,DC=mydomain
Parameter enableCloudwatchLogsExports :
The list of logs for the restored DB instance to export to CloudWatch
Logs. The values in the list depend on the DB engine. For more
information, see Publishing
Database Logs to Amazon CloudWatch Logs in the Amazon RDS User
Guide.
This setting doesn't apply to RDS Custom.
Parameter enableCustomerOwnedIp :
Specifies whether to enable a customer-owned IP address (CoIP) for an RDS
on Outposts DB instance.
A CoIP provides local or external connectivity to resources in your Outpost subnets through your on-premises network. For some use cases, a CoIP can provide lower latency for connections to the DB instance from outside of its virtual private cloud (VPC) on your local network.
This setting doesn't apply to RDS Custom.
For more information about RDS on Outposts, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.
For more information about CoIPs, see Customer-owned IP addresses in the Amazon Web Services Outposts User Guide.
Parameter enableIAMDatabaseAuthentication :
Specifies whether to enable mapping of Amazon Web Services Identity and
Access Management (IAM) accounts to database accounts. By default, mapping
is disabled.
For more information about IAM database authentication, see IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide.
This setting doesn't apply to RDS Custom.
Parameter engine :
The database engine to use for the new instance.
This setting doesn't apply to RDS Custom.
Default: The same as source
Constraint: Must be compatible with the engine of the source. For example, you can restore a MariaDB 10.1 DB instance from a MySQL 5.6 snapshot.
Valid Values:
-
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
Parameter engineLifecycleSupport :
The life cycle type for this DB instance.
You can use this setting to enroll your DB instance into Amazon RDS
Extended Support. With RDS Extended Support, you can run the selected
major engine version on your DB instance past the end of standard support
for that engine version. For more information, see Amazon
RDS Extended Support with Amazon RDS in the Amazon RDS User
Guide.
This setting applies only to RDS for MySQL and RDS for PostgreSQL. For Amazon Aurora DB instances, the life cycle type is managed by the DB cluster.
Valid Values: open-source-rds-extended-support |
open-source-rds-extended-support-disabled
Default: open-source-rds-extended-support
Parameter iops :
Specifies the amount of provisioned IOPS for the DB instance, expressed in
I/O operations per second. If this parameter isn't specified, the IOPS
value is taken from the backup. If this parameter is set to 0, the new
instance is converted to a non-PIOPS instance. The conversion takes
additional time, though your DB instance is available for connections
before the conversion starts.
The provisioned IOPS value must follow the requirements for your database engine. For more information, see Amazon RDS Provisioned IOPS storage in the Amazon RDS User Guide.
Constraints: Must be an integer greater than 1000.
Parameter licenseModel :
License model information for the restored DB instance.
This setting doesn't apply to Amazon Aurora or RDS Custom DB instances.
Valid Values:
-
RDS for Db2 -
bring-your-own-license | marketplace-license -
RDS for MariaDB -
general-public-license -
RDS for Microsoft SQL Server -
license-included -
RDS for MySQL -
general-public-license -
RDS for Oracle -
bring-your-own-license | license-included -
RDS for PostgreSQL -
postgresql-license
Parameter manageMasterUserPassword :
Specifies whether to manage the master user password with Amazon Web
Services Secrets Manager in the restored DB instance.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide.
Constraints:
- Applies to RDS for Oracle only.
Parameter masterUserSecretKmsKeyId :
The Amazon Web Services KMS key identifier to encrypt a secret that is
automatically generated and managed in Amazon Web Services Secrets
Manager.
This setting is valid only if the master user password is managed by RDS in Amazon Web Services Secrets Manager for the DB instance.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If you don't specify MasterUserSecretKmsKeyId, then the
aws/secretsmanager KMS key is used to encrypt the secret. If
the secret is in a different Amazon Web Services account, then you can't
use the aws/secretsmanager KMS key to encrypt the secret, and
you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Parameter multiAZ :
Specifies whether the DB instance is a Multi-AZ deployment.
This setting doesn't apply to RDS Custom.
Constraint: You can't specify the AvailabilityZone parameter
if the DB instance is a Multi-AZ deployment.
Parameter networkType :
The network type of the DB instance.
Valid Values:
-
IPV4 -
DUAL
DBSubnetGroup specified
for the DB instance. A DBSubnetGroup can support only the
IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon RDS User Guide.
Parameter optionGroupName :
The name of the option group to be used for the restored DB instance.
Permanent options, such as the TDE option for Oracle Advanced Security TDE, can't be removed from an option group, and that option group can't be removed from a DB instance after it is associated with a DB instance.
This setting doesn't apply to RDS Custom.
Parameter port :
The port number on which the database accepts connections.
Default: The same port as the original DB instance
Constraints: Value must be 1150-65535
Parameter preferredBackupWindow :
The daily time range during which automated backups are created if
automated backups are enabled, as determined by the
BackupRetentionPeriod parameter. Changing this parameter
doesn't result in an outage and the change is asynchronously applied as
soon as possible. The default is a 30-minute window selected at random
from an 8-hour block of time for each Amazon Web Services Region. For more
information, see Backup
window in the Amazon RDS User Guide.
This setting doesn't apply to Amazon Aurora DB instances. The daily time
range for creating automated backups is managed by the DB cluster. For
more information, see ModifyDBCluster.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
Parameter processorFeatures :
The number of CPU cores and the number of threads per core for the DB
instance class of the DB instance.
This setting doesn't apply to RDS Custom.
Parameter publiclyAccessible :
Specifies whether the DB instance is publicly accessible.
When the DB instance is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB instance's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB instance's VPC. Access to the DB instance is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB instance doesn't permit it.
When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address.
For more information, see CreateDBInstance.
Parameter storageThroughput :
Specifies the storage throughput value for the DB instance.
This setting doesn't apply to RDS Custom or Amazon Aurora.
Parameter storageType :
Specifies the storage type to be associated with the DB instance.
Valid Values: gp2 | gp3 | io1 | io2 | standard
If you specify io1, io2, or gp3,
you must also include a value for the Iops parameter.
Default: io1 if the Iops parameter is specified,
otherwise gp3
Parameter tagSpecifications :
Tags to assign to resources associated with the DB instance.
Valid Values:
-
auto-backup- The DB instance's automated backup.
Parameter tdeCredentialArn :
The ARN from the key store with which to associate the instance for TDE
encryption.
This setting doesn't apply to RDS Custom.
Parameter tdeCredentialPassword :
The password for the given ARN from the key store in order to access the
device.
This setting doesn't apply to RDS Custom.
Parameter useDefaultProcessorFeatures :
Specifies whether the DB instance class of the DB instance uses its
default processor features.
This setting doesn't apply to RDS Custom.
Parameter vpcSecurityGroupIds :
A list of EC2 VPC security groups to associate with this DB instance.
Default: The default EC2 VPC security group for the DB subnet group's VPC.
Implementation
Future<RestoreDBInstanceFromDBSnapshotResult>
restoreDBInstanceFromDBSnapshot({
required String dBInstanceIdentifier,
List<AdditionalStorageVolume>? additionalStorageVolumes,
int? allocatedStorage,
bool? autoMinorVersionUpgrade,
String? availabilityZone,
int? backupRetentionPeriod,
String? backupTarget,
String? cACertificateIdentifier,
bool? copyTagsToSnapshot,
String? customIamInstanceProfile,
String? dBClusterSnapshotIdentifier,
String? dBInstanceClass,
String? dBName,
String? dBParameterGroupName,
String? dBSnapshotIdentifier,
String? dBSubnetGroupName,
bool? dedicatedLogVolume,
bool? deletionProtection,
String? domain,
String? domainAuthSecretArn,
List<String>? domainDnsIps,
String? domainFqdn,
String? domainIAMRoleName,
String? domainOu,
List<String>? enableCloudwatchLogsExports,
bool? enableCustomerOwnedIp,
bool? enableIAMDatabaseAuthentication,
String? engine,
String? engineLifecycleSupport,
int? iops,
String? licenseModel,
bool? manageMasterUserPassword,
String? masterUserSecretKmsKeyId,
bool? multiAZ,
String? networkType,
String? optionGroupName,
int? port,
String? preferredBackupWindow,
List<ProcessorFeature>? processorFeatures,
bool? publiclyAccessible,
int? storageThroughput,
String? storageType,
List<TagSpecification>? tagSpecifications,
List<Tag>? tags,
String? tdeCredentialArn,
String? tdeCredentialPassword,
bool? useDefaultProcessorFeatures,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'DBInstanceIdentifier': dBInstanceIdentifier,
if (additionalStorageVolumes != null)
if (additionalStorageVolumes.isEmpty)
'AdditionalStorageVolumes': ''
else
for (var i1 = 0; i1 < additionalStorageVolumes.length; i1++)
for (var e3 in additionalStorageVolumes[i1].toQueryMap().entries)
'AdditionalStorageVolumes.member.${i1 + 1}.${e3.key}': e3.value,
if (allocatedStorage != null)
'AllocatedStorage': allocatedStorage.toString(),
if (autoMinorVersionUpgrade != null)
'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
if (backupRetentionPeriod != null)
'BackupRetentionPeriod': backupRetentionPeriod.toString(),
if (backupTarget != null) 'BackupTarget': backupTarget,
if (cACertificateIdentifier != null)
'CACertificateIdentifier': cACertificateIdentifier,
if (copyTagsToSnapshot != null)
'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
if (customIamInstanceProfile != null)
'CustomIamInstanceProfile': customIamInstanceProfile,
if (dBClusterSnapshotIdentifier != null)
'DBClusterSnapshotIdentifier': dBClusterSnapshotIdentifier,
if (dBInstanceClass != null) 'DBInstanceClass': dBInstanceClass,
if (dBName != null) 'DBName': dBName,
if (dBParameterGroupName != null)
'DBParameterGroupName': dBParameterGroupName,
if (dBSnapshotIdentifier != null)
'DBSnapshotIdentifier': dBSnapshotIdentifier,
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (dedicatedLogVolume != null)
'DedicatedLogVolume': dedicatedLogVolume.toString(),
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (domain != null) 'Domain': domain,
if (domainAuthSecretArn != null)
'DomainAuthSecretArn': domainAuthSecretArn,
if (domainDnsIps != null)
if (domainDnsIps.isEmpty)
'DomainDnsIps': ''
else
for (var i1 = 0; i1 < domainDnsIps.length; i1++)
'DomainDnsIps.member.${i1 + 1}': domainDnsIps[i1],
if (domainFqdn != null) 'DomainFqdn': domainFqdn,
if (domainIAMRoleName != null) 'DomainIAMRoleName': domainIAMRoleName,
if (domainOu != null) 'DomainOu': domainOu,
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (enableCustomerOwnedIp != null)
'EnableCustomerOwnedIp': enableCustomerOwnedIp.toString(),
if (enableIAMDatabaseAuthentication != null)
'EnableIAMDatabaseAuthentication':
enableIAMDatabaseAuthentication.toString(),
if (engine != null) 'Engine': engine,
if (engineLifecycleSupport != null)
'EngineLifecycleSupport': engineLifecycleSupport,
if (iops != null) 'Iops': iops.toString(),
if (licenseModel != null) 'LicenseModel': licenseModel,
if (manageMasterUserPassword != null)
'ManageMasterUserPassword': manageMasterUserPassword.toString(),
if (masterUserSecretKmsKeyId != null)
'MasterUserSecretKmsKeyId': masterUserSecretKmsKeyId,
if (multiAZ != null) 'MultiAZ': multiAZ.toString(),
if (networkType != null) 'NetworkType': networkType,
if (optionGroupName != null) 'OptionGroupName': optionGroupName,
if (port != null) 'Port': port.toString(),
if (preferredBackupWindow != null)
'PreferredBackupWindow': preferredBackupWindow,
if (processorFeatures != null)
if (processorFeatures.isEmpty)
'ProcessorFeatures': ''
else
for (var i1 = 0; i1 < processorFeatures.length; i1++)
for (var e3 in processorFeatures[i1].toQueryMap().entries)
'ProcessorFeatures.ProcessorFeature.${i1 + 1}.${e3.key}':
e3.value,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible.toString(),
if (storageThroughput != null)
'StorageThroughput': storageThroughput.toString(),
if (storageType != null) 'StorageType': storageType,
if (tagSpecifications != null)
if (tagSpecifications.isEmpty)
'TagSpecifications': ''
else
for (var i1 = 0; i1 < tagSpecifications.length; i1++)
for (var e3 in tagSpecifications[i1].toQueryMap().entries)
'TagSpecifications.item.${i1 + 1}.${e3.key}': e3.value,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (tdeCredentialArn != null) 'TdeCredentialArn': tdeCredentialArn,
if (tdeCredentialPassword != null)
'TdeCredentialPassword': tdeCredentialPassword,
if (useDefaultProcessorFeatures != null)
'UseDefaultProcessorFeatures': useDefaultProcessorFeatures.toString(),
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreDBInstanceFromDBSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreDBInstanceFromDBSnapshotResult',
);
return RestoreDBInstanceFromDBSnapshotResult.fromXml($result);
}