restoreDBInstanceToPointInTime method
- required String targetDBInstanceIdentifier,
- List<
AdditionalStorageVolume> ? additionalStorageVolumes, - int? allocatedStorage,
- bool? autoMinorVersionUpgrade,
- String? availabilityZone,
- int? backupRetentionPeriod,
- String? backupTarget,
- String? cACertificateIdentifier,
- bool? copyTagsToSnapshot,
- String? customIamInstanceProfile,
- String? dBInstanceClass,
- String? dBName,
- String? dBParameterGroupName,
- String? dBSubnetGroupName,
- bool? dedicatedLogVolume,
- bool? deletionProtection,
- String? domain,
- String? domainAuthSecretArn,
- List<
String> ? domainDnsIps, - String? domainFqdn,
- String? domainIAMRoleName,
- String? domainOu,
- List<
String> ? enableCloudwatchLogsExports, - bool? enableCustomerOwnedIp,
- bool? enableIAMDatabaseAuthentication,
- String? engine,
- String? engineLifecycleSupport,
- int? iops,
- String? licenseModel,
- bool? manageMasterUserPassword,
- String? masterUserSecretKmsKeyId,
- int? maxAllocatedStorage,
- bool? multiAZ,
- String? networkType,
- String? optionGroupName,
- int? port,
- String? preferredBackupWindow,
- List<
ProcessorFeature> ? processorFeatures, - bool? publiclyAccessible,
- DateTime? restoreTime,
- String? sourceDBInstanceAutomatedBackupsArn,
- String? sourceDBInstanceIdentifier,
- String? sourceDbiResourceId,
- int? storageThroughput,
- String? storageType,
- List<
TagSpecification> ? tagSpecifications, - List<
Tag> ? tags, - String? tdeCredentialArn,
- String? tdeCredentialPassword,
- bool? useDefaultProcessorFeatures,
- bool? useLatestRestorableTime,
- List<
String> ? vpcSecurityGroupIds,
Restores a DB instance to an arbitrary point in time. You can restore to
any point in time before the time identified by the
LatestRestorableTime property. You can restore to a point up
to the number of days specified by the BackupRetentionPeriod
property.
The target database is created with most of the original configuration, but in a system-selected Availability Zone, with the default security group, the default subnet group, and the default DB parameter group. By default, the new DB instance is created as a single-AZ deployment except when the instance is a SQL Server instance that has an option group that is associated with mirroring; in this case, the instance becomes a mirrored deployment and not a single-AZ deployment.
May throw AuthorizationNotFoundFault.
May throw BackupPolicyNotFoundFault.
May throw CertificateNotFoundFault.
May throw DBInstanceAlreadyExistsFault.
May throw DBInstanceAutomatedBackupNotFoundFault.
May throw DBInstanceNotFoundFault.
May throw DBParameterGroupNotFoundFault.
May throw DBSecurityGroupNotFoundFault.
May throw DBSubnetGroupDoesNotCoverEnoughAZs.
May throw DBSubnetGroupNotFoundFault.
May throw DomainNotFoundFault.
May throw InstanceQuotaExceededFault.
May throw InsufficientDBInstanceCapacityFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidRestoreFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw NetworkTypeNotSupported.
May throw OptionGroupNotFoundFault.
May throw PointInTimeRestoreNotEnabledFault.
May throw ProvisionedIopsNotAvailableInAZFault.
May throw StorageQuotaExceededFault.
May throw StorageTypeNotSupportedFault.
May throw TenantDatabaseQuotaExceededFault.
May throw VpcEncryptionControlViolationException.
Parameter targetDBInstanceIdentifier :
The name of the new DB instance to create.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
Parameter additionalStorageVolumes :
A list of additional storage volumes to restore to the DB instance. You
can restore up to three additional storage volumes using the names
rdsdbdata2, rdsdbdata3, and
rdsdbdata4. Additional storage volumes are supported for RDS
for Oracle and RDS for SQL Server DB instances only.
Parameter allocatedStorage :
The amount of storage (in gibibytes) to allocate initially for the DB
instance. Follow the allocation rules specified in
CreateDBInstance.
This setting isn't valid for RDS for SQL Server.
Parameter autoMinorVersionUpgrade :
Specifies whether minor version upgrades are applied automatically to the
DB instance during the maintenance window.
This setting doesn't apply to RDS Custom.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
Parameter availabilityZone :
The Availability Zone (AZ) where the DB instance will be created.
Default: A random, system-chosen Availability Zone.
Constraints:
-
You can't specify the
AvailabilityZoneparameter if the DB instance is a Multi-AZ deployment.
us-east-1a
Parameter backupRetentionPeriod :
The number of days to retain automated backups. Setting this parameter to
a positive number enables backups. Setting this parameter to 0 disables
automated backups.
This setting doesn't apply to Amazon Aurora DB instances. The retention
period for automated backups is managed by the DB cluster. For more
information, see ModifyDBCluster.
Default: Uses existing setting
Constraints:
- Must be a value from 0 to 35.
- Can't be set to 0 if the DB instance is a source to read replicas.
- Can't be set to 0 for an RDS Custom for Oracle DB instance.
Parameter backupTarget :
The location for storing automated backups and manual snapshots for the
restored DB instance.
Valid Values:
-
local(Dedicated Local Zone) -
outposts(Amazon Web Services Outposts) -
region(Amazon Web Services Region)
region
For more information, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.
Parameter cACertificateIdentifier :
The CA certificate identifier to use for the DB instance's server
certificate.
This setting doesn't apply to RDS Custom DB instances.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
Parameter copyTagsToSnapshot :
Specifies whether to copy all tags from the restored DB instance to
snapshots of the DB instance. By default, tags are not copied.
Parameter customIamInstanceProfile :
The instance profile associated with the underlying Amazon EC2 instance of
an RDS Custom DB instance. The instance profile must meet the following
requirements:
- The profile must exist in your account.
- The profile must have an IAM role that Amazon EC2 has permissions to assume.
-
The instance profile name and the associated IAM role name must start with
the prefix
AWSRDSCustom.
This setting is required for RDS Custom.
Parameter dBInstanceClass :
The compute and memory capacity of the Amazon RDS DB instance, for example
db.m4.large. Not all DB instance classes are available in all Amazon Web
Services Regions, or for all database engines. For the full list of DB
instance classes, and availability for your engine, see DB
Instance Class in the Amazon RDS User Guide.
Default: The same DB instance class as the original DB instance.
Parameter dBName :
The database name for the restored DB instance.
This parameter doesn't apply to the following DB instances:
- RDS Custom
- RDS for Db2
- RDS for MariaDB
- RDS for MySQL
Parameter dBParameterGroupName :
The name of the DB parameter group to associate with this DB instance.
If you do not specify a value for DBParameterGroupName, then
the default DBParameterGroup for the specified DB engine is
used.
This setting doesn't apply to RDS Custom.
Constraints:
- If supplied, must match the name of an existing DB parameter group.
- Must be 1 to 255 letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
Parameter dBSubnetGroupName :
The DB subnet group name to use for the new instance.
Constraints:
- If supplied, must match the name of an existing DB subnet group.
mydbsubnetgroup
Parameter dedicatedLogVolume :
Specifies whether to enable a dedicated log volume (DLV) for the DB
instance.
Parameter deletionProtection :
Specifies whether the DB instance has deletion protection enabled. The
database can't be deleted when deletion protection is enabled. By default,
deletion protection isn't enabled. For more information, see
Deleting a DB Instance.
Parameter domain :
The Active Directory directory ID to restore the DB instance in. Create
the domain before running this command. Currently, you can create only the
MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances in an
Active Directory Domain.
This setting doesn't apply to RDS Custom.
For more information, see Kerberos Authentication in the Amazon RDS User Guide.
Parameter domainAuthSecretArn :
The ARN for the Secrets Manager secret with the credentials for the user
joining the domain.
Constraints:
- Can't be longer than 64 characters.
arn:aws:secretsmanager:region:account-number:secret:myselfmanagedADtestsecret-123456
Parameter domainDnsIps :
The IPv4 DNS IP addresses of your primary and secondary Active Directory
domain controllers.
Constraints:
- Two IP addresses must be provided. If there isn't a secondary domain controller, use the IP address of the primary domain controller for both entries in the list.
123.124.125.126,234.235.236.237
Parameter domainFqdn :
The fully qualified domain name (FQDN) of an Active Directory domain.
Constraints:
- Can't be longer than 64 characters.
mymanagedADtest.mymanagedAD.mydomain
Parameter domainIAMRoleName :
The name of the IAM role to use when making API calls to the Directory
Service.
This setting doesn't apply to RDS Custom DB instances.
Parameter domainOu :
The Active Directory organizational unit for your DB instance to join.
Constraints:
- Must be in the distinguished name format.
- Can't be longer than 64 characters.
OU=mymanagedADtestOU,DC=mymanagedADtest,DC=mymanagedAD,DC=mydomain
Parameter enableCloudwatchLogsExports :
The list of logs that the restored DB instance is to export to CloudWatch
Logs. The values in the list depend on the DB engine being used. For more
information, see Publishing
Database Logs to Amazon CloudWatch Logs in the Amazon RDS User
Guide.
This setting doesn't apply to RDS Custom.
Parameter enableCustomerOwnedIp :
Specifies whether to enable a customer-owned IP address (CoIP) for an RDS
on Outposts DB instance.
A CoIP provides local or external connectivity to resources in your Outpost subnets through your on-premises network. For some use cases, a CoIP can provide lower latency for connections to the DB instance from outside of its virtual private cloud (VPC) on your local network.
This setting doesn't apply to RDS Custom.
For more information about RDS on Outposts, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.
For more information about CoIPs, see Customer-owned IP addresses in the Amazon Web Services Outposts User Guide.
Parameter enableIAMDatabaseAuthentication :
Specifies whether to enable mapping of Amazon Web Services Identity and
Access Management (IAM) accounts to database accounts. By default, mapping
isn't enabled.
This setting doesn't apply to RDS Custom.
For more information about IAM database authentication, see IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide.
Parameter engine :
The database engine to use for the new instance.
This setting doesn't apply to RDS Custom.
Valid Values:
-
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
Constraints:
- Must be compatible with the engine of the source.
Parameter engineLifecycleSupport :
The life cycle type for this DB instance.
You can use this setting to enroll your DB instance into Amazon RDS
Extended Support. With RDS Extended Support, you can run the selected
major engine version on your DB instance past the end of standard support
for that engine version. For more information, see Amazon
RDS Extended Support with Amazon RDS in the Amazon RDS User
Guide.
This setting applies only to RDS for MySQL and RDS for PostgreSQL. For Amazon Aurora DB instances, the life cycle type is managed by the DB cluster.
Valid Values: open-source-rds-extended-support |
open-source-rds-extended-support-disabled
Default: open-source-rds-extended-support
Parameter iops :
The amount of Provisioned IOPS (input/output operations per second) to
initially allocate for the DB instance.
This setting doesn't apply to SQL Server.
Constraints:
- Must be an integer greater than 1000.
Parameter licenseModel :
The license model information for the restored DB instance.
This setting doesn't apply to Amazon Aurora or RDS Custom DB instances.
Valid Values:
-
RDS for Db2 -
bring-your-own-license | marketplace-license -
RDS for MariaDB -
general-public-license -
RDS for Microsoft SQL Server -
license-included -
RDS for MySQL -
general-public-license -
RDS for Oracle -
bring-your-own-license | license-included -
RDS for PostgreSQL -
postgresql-license
Parameter manageMasterUserPassword :
Specifies whether to manage the master user password with Amazon Web
Services Secrets Manager in the restored DB instance.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide.
Constraints:
- Applies to RDS for Oracle only.
Parameter masterUserSecretKmsKeyId :
The Amazon Web Services KMS key identifier to encrypt a secret that is
automatically generated and managed in Amazon Web Services Secrets
Manager.
This setting is valid only if the master user password is managed by RDS in Amazon Web Services Secrets Manager for the DB instance.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If you don't specify MasterUserSecretKmsKeyId, then the
aws/secretsmanager KMS key is used to encrypt the secret. If
the secret is in a different Amazon Web Services account, then you can't
use the aws/secretsmanager KMS key to encrypt the secret, and
you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Parameter maxAllocatedStorage :
The upper limit in gibibytes (GiB) to which Amazon RDS can automatically
scale the storage of the DB instance.
For more information about this setting, including limitations that apply to it, see Managing capacity automatically with Amazon RDS storage autoscaling in the Amazon RDS User Guide.
This setting doesn't apply to RDS Custom.
Parameter multiAZ :
Secifies whether the DB instance is a Multi-AZ deployment.
This setting doesn't apply to RDS Custom.
Constraints:
-
You can't specify the
AvailabilityZoneparameter if the DB instance is a Multi-AZ deployment.
Parameter networkType :
The network type of the DB instance.
The network type is determined by the DBSubnetGroup specified
for the DB instance. A DBSubnetGroup can support only the
IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon RDS User Guide.
Valid Values:
-
IPV4 -
DUAL
Parameter optionGroupName :
The name of the option group to use for the restored DB instance.
Permanent options, such as the TDE option for Oracle Advanced Security TDE, can't be removed from an option group, and that option group can't be removed from a DB instance after it is associated with a DB instance
This setting doesn't apply to RDS Custom.
Parameter port :
The port number on which the database accepts connections.
Default: The same port as the original DB instance.
Constraints:
-
The value must be
1150-65535.
Parameter preferredBackupWindow :
The daily time range during which automated backups are created if
automated backups are enabled, as determined by the
BackupRetentionPeriod parameter. Changing this parameter
doesn't result in an outage and the change is asynchronously applied as
soon as possible. The default is a 30-minute window selected at random
from an 8-hour block of time for each Amazon Web Services Region. For more
information, see Backup
window in the Amazon RDS User Guide.
This setting doesn't apply to Amazon Aurora DB instances. The daily time
range for creating automated backups is managed by the DB cluster. For
more information, see ModifyDBCluster.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
Parameter processorFeatures :
The number of CPU cores and the number of threads per core for the DB
instance class of the DB instance.
This setting doesn't apply to RDS Custom.
Parameter publiclyAccessible :
Specifies whether the DB instance is publicly accessible.
When the DB cluster is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB cluster's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB cluster's VPC. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn't permitted if the security group assigned to the DB cluster doesn't permit it.
When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address.
For more information, see CreateDBInstance.
Parameter restoreTime :
The date and time to restore from.
Constraints:
- Must be a time in Universal Coordinated Time (UTC) format.
- Must be before the latest restorable time for the DB instance.
-
Can't be specified if the
UseLatestRestorableTimeparameter is enabled.
2009-09-07T23:45:00Z
Parameter sourceDBInstanceAutomatedBackupsArn :
The Amazon Resource Name (ARN) of the replicated automated backups from
which to restore, for example,
arn:aws:rds:us-east-1:123456789012:auto-backup:ab-L2IJCEXJP7XQ7HOJ4SIEXAMPLE.
This setting doesn't apply to RDS Custom.
Parameter sourceDBInstanceIdentifier :
The identifier of the source DB instance from which to restore.
Constraints:
- Must match the identifier of an existing DB instance.
Parameter sourceDbiResourceId :
The resource ID of the source DB instance from which to restore.
Parameter storageThroughput :
The storage throughput value for the DB instance.
This setting doesn't apply to RDS Custom or Amazon Aurora.
Parameter storageType :
The storage type to associate with the DB instance.
Valid Values: gp2 | gp3 | io1 | io2 | standard
Default: io1, if the Iops parameter is
specified. Otherwise, gp3.
Constraints:
-
If you specify
io1,io2, orgp3, you must also include a value for theIopsparameter.
Parameter tagSpecifications :
Tags to assign to resources associated with the DB instance.
Valid Values:
-
auto-backup- The DB instance's automated backup.
Parameter tdeCredentialArn :
The ARN from the key store with which to associate the instance for TDE
encryption.
This setting doesn't apply to RDS Custom.
Parameter tdeCredentialPassword :
The password for the given ARN from the key store in order to access the
device.
This setting doesn't apply to RDS Custom.
Parameter useDefaultProcessorFeatures :
Specifies whether the DB instance class of the DB instance uses its
default processor features.
This setting doesn't apply to RDS Custom.
Parameter useLatestRestorableTime :
Specifies whether the DB instance is restored from the latest backup time.
By default, the DB instance isn't restored from the latest backup time.
Constraints:
-
Can't be specified if the
RestoreTimeparameter is provided.
Parameter vpcSecurityGroupIds :
A list of EC2 VPC security groups to associate with this DB instance.
Default: The default EC2 VPC security group for the DB subnet group's VPC.
Implementation
Future<RestoreDBInstanceToPointInTimeResult> restoreDBInstanceToPointInTime({
required String targetDBInstanceIdentifier,
List<AdditionalStorageVolume>? additionalStorageVolumes,
int? allocatedStorage,
bool? autoMinorVersionUpgrade,
String? availabilityZone,
int? backupRetentionPeriod,
String? backupTarget,
String? cACertificateIdentifier,
bool? copyTagsToSnapshot,
String? customIamInstanceProfile,
String? dBInstanceClass,
String? dBName,
String? dBParameterGroupName,
String? dBSubnetGroupName,
bool? dedicatedLogVolume,
bool? deletionProtection,
String? domain,
String? domainAuthSecretArn,
List<String>? domainDnsIps,
String? domainFqdn,
String? domainIAMRoleName,
String? domainOu,
List<String>? enableCloudwatchLogsExports,
bool? enableCustomerOwnedIp,
bool? enableIAMDatabaseAuthentication,
String? engine,
String? engineLifecycleSupport,
int? iops,
String? licenseModel,
bool? manageMasterUserPassword,
String? masterUserSecretKmsKeyId,
int? maxAllocatedStorage,
bool? multiAZ,
String? networkType,
String? optionGroupName,
int? port,
String? preferredBackupWindow,
List<ProcessorFeature>? processorFeatures,
bool? publiclyAccessible,
DateTime? restoreTime,
String? sourceDBInstanceAutomatedBackupsArn,
String? sourceDBInstanceIdentifier,
String? sourceDbiResourceId,
int? storageThroughput,
String? storageType,
List<TagSpecification>? tagSpecifications,
List<Tag>? tags,
String? tdeCredentialArn,
String? tdeCredentialPassword,
bool? useDefaultProcessorFeatures,
bool? useLatestRestorableTime,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'TargetDBInstanceIdentifier': targetDBInstanceIdentifier,
if (additionalStorageVolumes != null)
if (additionalStorageVolumes.isEmpty)
'AdditionalStorageVolumes': ''
else
for (var i1 = 0; i1 < additionalStorageVolumes.length; i1++)
for (var e3 in additionalStorageVolumes[i1].toQueryMap().entries)
'AdditionalStorageVolumes.member.${i1 + 1}.${e3.key}': e3.value,
if (allocatedStorage != null)
'AllocatedStorage': allocatedStorage.toString(),
if (autoMinorVersionUpgrade != null)
'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
if (backupRetentionPeriod != null)
'BackupRetentionPeriod': backupRetentionPeriod.toString(),
if (backupTarget != null) 'BackupTarget': backupTarget,
if (cACertificateIdentifier != null)
'CACertificateIdentifier': cACertificateIdentifier,
if (copyTagsToSnapshot != null)
'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
if (customIamInstanceProfile != null)
'CustomIamInstanceProfile': customIamInstanceProfile,
if (dBInstanceClass != null) 'DBInstanceClass': dBInstanceClass,
if (dBName != null) 'DBName': dBName,
if (dBParameterGroupName != null)
'DBParameterGroupName': dBParameterGroupName,
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (dedicatedLogVolume != null)
'DedicatedLogVolume': dedicatedLogVolume.toString(),
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (domain != null) 'Domain': domain,
if (domainAuthSecretArn != null)
'DomainAuthSecretArn': domainAuthSecretArn,
if (domainDnsIps != null)
if (domainDnsIps.isEmpty)
'DomainDnsIps': ''
else
for (var i1 = 0; i1 < domainDnsIps.length; i1++)
'DomainDnsIps.member.${i1 + 1}': domainDnsIps[i1],
if (domainFqdn != null) 'DomainFqdn': domainFqdn,
if (domainIAMRoleName != null) 'DomainIAMRoleName': domainIAMRoleName,
if (domainOu != null) 'DomainOu': domainOu,
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (enableCustomerOwnedIp != null)
'EnableCustomerOwnedIp': enableCustomerOwnedIp.toString(),
if (enableIAMDatabaseAuthentication != null)
'EnableIAMDatabaseAuthentication':
enableIAMDatabaseAuthentication.toString(),
if (engine != null) 'Engine': engine,
if (engineLifecycleSupport != null)
'EngineLifecycleSupport': engineLifecycleSupport,
if (iops != null) 'Iops': iops.toString(),
if (licenseModel != null) 'LicenseModel': licenseModel,
if (manageMasterUserPassword != null)
'ManageMasterUserPassword': manageMasterUserPassword.toString(),
if (masterUserSecretKmsKeyId != null)
'MasterUserSecretKmsKeyId': masterUserSecretKmsKeyId,
if (maxAllocatedStorage != null)
'MaxAllocatedStorage': maxAllocatedStorage.toString(),
if (multiAZ != null) 'MultiAZ': multiAZ.toString(),
if (networkType != null) 'NetworkType': networkType,
if (optionGroupName != null) 'OptionGroupName': optionGroupName,
if (port != null) 'Port': port.toString(),
if (preferredBackupWindow != null)
'PreferredBackupWindow': preferredBackupWindow,
if (processorFeatures != null)
if (processorFeatures.isEmpty)
'ProcessorFeatures': ''
else
for (var i1 = 0; i1 < processorFeatures.length; i1++)
for (var e3 in processorFeatures[i1].toQueryMap().entries)
'ProcessorFeatures.ProcessorFeature.${i1 + 1}.${e3.key}':
e3.value,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible.toString(),
if (restoreTime != null) 'RestoreTime': _s.iso8601ToJson(restoreTime),
if (sourceDBInstanceAutomatedBackupsArn != null)
'SourceDBInstanceAutomatedBackupsArn':
sourceDBInstanceAutomatedBackupsArn,
if (sourceDBInstanceIdentifier != null)
'SourceDBInstanceIdentifier': sourceDBInstanceIdentifier,
if (sourceDbiResourceId != null)
'SourceDbiResourceId': sourceDbiResourceId,
if (storageThroughput != null)
'StorageThroughput': storageThroughput.toString(),
if (storageType != null) 'StorageType': storageType,
if (tagSpecifications != null)
if (tagSpecifications.isEmpty)
'TagSpecifications': ''
else
for (var i1 = 0; i1 < tagSpecifications.length; i1++)
for (var e3 in tagSpecifications[i1].toQueryMap().entries)
'TagSpecifications.item.${i1 + 1}.${e3.key}': e3.value,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (tdeCredentialArn != null) 'TdeCredentialArn': tdeCredentialArn,
if (tdeCredentialPassword != null)
'TdeCredentialPassword': tdeCredentialPassword,
if (useDefaultProcessorFeatures != null)
'UseDefaultProcessorFeatures': useDefaultProcessorFeatures.toString(),
if (useLatestRestorableTime != null)
'UseLatestRestorableTime': useLatestRestorableTime.toString(),
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreDBInstanceToPointInTime',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreDBInstanceToPointInTimeResult',
);
return RestoreDBInstanceToPointInTimeResult.fromXml($result);
}