switchoverReadReplica method
Future<SwitchoverReadReplicaResult>
switchoverReadReplica({
- required String dBInstanceIdentifier,
Switches over an Oracle standby database in an Oracle Data Guard environment, making it the new primary database. Issue this command in the Region that hosts the current standby database.
May throw DBInstanceNotFoundFault.
May throw InvalidDBInstanceStateFault.
Parameter dBInstanceIdentifier :
The DB instance identifier of the current standby database. This value is
stored as a lowercase string.
Constraints:
- Must match the identiļ¬er of an existing Oracle read replica DB instance.
Implementation
Future<SwitchoverReadReplicaResult> switchoverReadReplica({
required String dBInstanceIdentifier,
}) async {
final $request = <String, String>{
'DBInstanceIdentifier': dBInstanceIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'SwitchoverReadReplica',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'SwitchoverReadReplicaResult',
);
return SwitchoverReadReplicaResult.fromXml($result);
}