RdsData class
Amazon RDS provides an HTTP endpoint to run SQL statements on an Amazon Aurora DB cluster. To run these statements, you use the RDS Data API (Data API).
Constructors
- RdsData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchExecuteStatement(
{required String resourceArn, required String secretArn, required String sql, String? database, List< List< ? parameterSets, String? schema, String? transactionId}) → Future<SqlParameter> >BatchExecuteStatementResponse> - Runs a batch SQL statement over an array of data.
-
beginTransaction(
{required String resourceArn, required String secretArn, String? database, String? schema}) → Future< BeginTransactionResponse> - Starts a SQL transaction.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
commitTransaction(
{required String resourceArn, required String secretArn, required String transactionId}) → Future< CommitTransactionResponse> -
Ends a SQL transaction started with the
BeginTransactionoperation and commits the changes. -
executeSql(
{required String awsSecretStoreArn, required String dbClusterOrInstanceArn, required String sqlStatements, String? database, String? schema}) → Future< ExecuteSqlResponse> - Runs one or more SQL statements.
-
executeStatement(
{required String resourceArn, required String secretArn, required String sql, bool? continueAfterTimeout, String? database, RecordsFormatType? formatRecordsAs, bool? includeResultMetadata, List< SqlParameter> ? parameters, ResultSetOptions? resultSetOptions, String? schema, String? transactionId}) → Future<ExecuteStatementResponse> - Runs a SQL statement against a database.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rollbackTransaction(
{required String resourceArn, required String secretArn, required String transactionId}) → Future< RollbackTransactionResponse> - Performs a rollback of a transaction. Rolling back a transaction cancels its changes.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited