Redshift class

This is an interface reference for Amazon Redshift. It contains documentation for one of the programming or command line interfaces you can use to manage Amazon Redshift clusters. Note that Amazon Redshift is asynchronous, which means that some interfaces may require techniques, such as polling or asynchronous callback handlers, to determine when a command has been applied. In this reference, the parameter descriptions indicate whether a change is applied immediately, on the next instance reboot, or during the next maintenance window. For a summary of the Amazon Redshift cluster management interfaces, go to Using the Amazon Redshift Management Interfaces.

Constructors

Redshift({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptReservedNodeExchange({required String reservedNodeId, required String targetReservedNodeOfferingId}) Future<AcceptReservedNodeExchangeOutputMessage>
Exchanges a DC1 Reserved Node for a DC2 Reserved Node with no changes to the configuration (term, payment type, or number of nodes) and no additional costs.
addPartner({required String accountId, required String clusterIdentifier, required String databaseName, required String partnerName}) Future<PartnerIntegrationOutputMessage>
Adds a partner integration to a cluster. This operation authorizes a partner to push status updates for the specified database. To complete the integration, you also set up the integration on the partner website.
associateDataShareConsumer({required String dataShareArn, bool? allowWrites, bool? associateEntireAccount, String? consumerArn, String? consumerRegion}) Future<DataShare>
From a datashare consumer account, associates a datashare with the account (AssociateEntireAccount) or the specified namespace (ConsumerArn). If you make this association, the consumer can consume the datashare.
authorizeClusterSecurityGroupIngress({required String clusterSecurityGroupName, String? cidrip, String? eC2SecurityGroupName, String? eC2SecurityGroupOwnerId}) Future<AuthorizeClusterSecurityGroupIngressResult>
Adds an inbound (ingress) rule to an Amazon Redshift security group. Depending on whether the application accessing your cluster is running on the Internet or an Amazon EC2 instance, you can authorize inbound access to either a Classless Interdomain Routing (CIDR)/Internet Protocol (IP) range or to an Amazon EC2 security group. You can add as many as 20 ingress rules to an Amazon Redshift security group.
authorizeDataShare({required String consumerIdentifier, required String dataShareArn, bool? allowWrites}) Future<DataShare>
From a data producer account, authorizes the sharing of a datashare with one or more consumer accounts or managing entities. To authorize a datashare for a data consumer, the producer account must have the correct access permissions.
authorizeEndpointAccess({required String account, String? clusterIdentifier, List<String>? vpcIds}) Future<EndpointAuthorization>
Grants access to a cluster.
authorizeSnapshotAccess({required String accountWithRestoreAccess, String? snapshotArn, String? snapshotClusterIdentifier, String? snapshotIdentifier}) Future<AuthorizeSnapshotAccessResult>
Authorizes the specified Amazon Web Services account to restore the specified snapshot.
batchDeleteClusterSnapshots({required List<DeleteClusterSnapshotMessage> identifiers}) Future<BatchDeleteClusterSnapshotsResult>
Deletes a set of cluster snapshots.
batchModifyClusterSnapshots({required List<String> snapshotIdentifierList, bool? force, int? manualSnapshotRetentionPeriod}) Future<BatchModifyClusterSnapshotsOutputMessage>
Modifies the settings for a set of cluster snapshots.
cancelResize({required String clusterIdentifier}) Future<ResizeProgressMessage>
Cancels a resize operation for a cluster.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
copyClusterSnapshot({required String sourceSnapshotIdentifier, required String targetSnapshotIdentifier, int? manualSnapshotRetentionPeriod, String? sourceSnapshotClusterIdentifier}) Future<CopyClusterSnapshotResult>
Copies the specified automated cluster snapshot to a new manual cluster snapshot. The source must be an automated snapshot and it must be in the available state.
createAuthenticationProfile({required String authenticationProfileContent, required String authenticationProfileName}) Future<CreateAuthenticationProfileResult>
Creates an authentication profile with the specified parameters.
createCluster({required String clusterIdentifier, required String masterUsername, required String nodeType, String? additionalInfo, bool? allowVersionUpgrade, AquaConfigurationStatus? aquaConfigurationStatus, int? automatedSnapshotRetentionPeriod, String? availabilityZone, bool? availabilityZoneRelocation, String? catalogName, String? clusterParameterGroupName, List<String>? clusterSecurityGroups, String? clusterSubnetGroupName, String? clusterType, String? clusterVersion, String? dBName, String? defaultIamRoleArn, String? elasticIp, bool? encrypted, bool? enhancedVpcRouting, bool? extraComputeForAutomaticOptimization, String? hsmClientCertificateIdentifier, String? hsmConfigurationIdentifier, List<String>? iamRoles, String? ipAddressType, String? kmsKeyId, String? loadSampleData, String? maintenanceTrackName, bool? manageMasterPassword, int? manualSnapshotRetentionPeriod, String? masterPasswordSecretKmsKeyId, String? masterUserPassword, bool? multiAZ, int? numberOfNodes, int? port, String? preferredMaintenanceWindow, bool? publiclyAccessible, String? redshiftIdcApplicationArn, String? snapshotScheduleIdentifier, List<Tag>? tags, List<String>? vpcSecurityGroupIds}) Future<CreateClusterResult>
Creates a new cluster with the specified parameters.
createClusterParameterGroup({required String description, required String parameterGroupFamily, required String parameterGroupName, List<Tag>? tags}) Future<CreateClusterParameterGroupResult>
Creates an Amazon Redshift parameter group.
createClusterSecurityGroup({required String clusterSecurityGroupName, required String description, List<Tag>? tags}) Future<CreateClusterSecurityGroupResult>
Creates a new Amazon Redshift security group. You use security groups to control access to non-VPC clusters.
createClusterSnapshot({required String clusterIdentifier, required String snapshotIdentifier, int? manualSnapshotRetentionPeriod, List<Tag>? tags}) Future<CreateClusterSnapshotResult>
Creates a manual snapshot of the specified cluster. The cluster must be in the available state.
createClusterSubnetGroup({required String clusterSubnetGroupName, required String description, required List<String> subnetIds, List<Tag>? tags}) Future<CreateClusterSubnetGroupResult>
Creates a new Amazon Redshift subnet group. You must provide a list of one or more subnets in your existing Amazon Virtual Private Cloud (Amazon VPC) when creating Amazon Redshift subnet group.
createCustomDomainAssociation({required String clusterIdentifier, required String customDomainCertificateArn, required String customDomainName}) Future<CreateCustomDomainAssociationResult>
Used to create a custom domain name for a cluster. Properties include the custom domain name, the cluster the custom domain is associated with, and the certificate Amazon Resource Name (ARN).
createEndpointAccess({required String endpointName, required String subnetGroupName, String? clusterIdentifier, String? resourceOwner, List<String>? vpcSecurityGroupIds}) Future<EndpointAccess>
Creates a Redshift-managed VPC endpoint.
createEventSubscription({required String snsTopicArn, required String subscriptionName, bool? enabled, List<String>? eventCategories, String? severity, List<String>? sourceIds, String? sourceType, List<Tag>? tags}) Future<CreateEventSubscriptionResult>
Creates an Amazon Redshift event notification subscription. This action requires an ARN (Amazon Resource Name) of an Amazon SNS topic created by either the Amazon Redshift console, the Amazon SNS console, or the Amazon SNS API. To obtain an ARN with Amazon SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console.
createHsmClientCertificate({required String hsmClientCertificateIdentifier, List<Tag>? tags}) Future<CreateHsmClientCertificateResult>
Creates an HSM client certificate that an Amazon Redshift cluster will use to connect to the client's HSM in order to store and retrieve the keys used to encrypt the cluster databases.
createHsmConfiguration({required String description, required String hsmConfigurationIdentifier, required String hsmIpAddress, required String hsmPartitionName, required String hsmPartitionPassword, required String hsmServerPublicCertificate, List<Tag>? tags}) Future<CreateHsmConfigurationResult>
Creates an HSM configuration that contains the information required by an Amazon Redshift cluster to store and use database encryption keys in a Hardware Security Module (HSM). After creating the HSM configuration, you can specify it as a parameter when creating a cluster. The cluster will then store its encryption keys in the HSM.
createIntegration({required String integrationName, required String sourceArn, required String targetArn, Map<String, String>? additionalEncryptionContext, String? description, String? kMSKeyId, List<Tag>? tagList}) Future<Integration>
Creates a zero-ETL integration or S3 event integration with Amazon Redshift.
createRedshiftIdcApplication({required String iamRoleArn, required String idcDisplayName, required String idcInstanceArn, required String redshiftIdcApplicationName, ApplicationType? applicationType, List<AuthorizedTokenIssuer>? authorizedTokenIssuerList, String? identityNamespace, List<ServiceIntegrationsUnion>? serviceIntegrations, List<String>? ssoTagKeys, List<Tag>? tags}) Future<CreateRedshiftIdcApplicationResult>
Creates an Amazon Redshift application for use with IAM Identity Center.
createScheduledAction({required String iamRole, required String schedule, required String scheduledActionName, required ScheduledActionType targetAction, bool? enable, DateTime? endTime, String? scheduledActionDescription, DateTime? startTime}) Future<ScheduledAction>
Creates a scheduled action. A scheduled action contains a schedule and an Amazon Redshift API action. For example, you can create a schedule of when to run the ResizeCluster API operation.
createSnapshotCopyGrant({required String snapshotCopyGrantName, String? kmsKeyId, List<Tag>? tags}) Future<CreateSnapshotCopyGrantResult>
Creates a snapshot copy grant that permits Amazon Redshift to use an encrypted symmetric key from Key Management Service (KMS) to encrypt copied snapshots in a destination region.
createSnapshotSchedule({bool? dryRun, int? nextInvocations, List<String>? scheduleDefinitions, String? scheduleDescription, String? scheduleIdentifier, List<Tag>? tags}) Future<SnapshotSchedule>
Create a snapshot schedule that can be associated to a cluster and which overrides the default system backup schedule.
createTags({required String resourceName, required List<Tag> tags}) Future<void>
Adds tags to a cluster.
createUsageLimit({required int amount, required String clusterIdentifier, required UsageLimitFeatureType featureType, required UsageLimitLimitType limitType, UsageLimitBreachAction? breachAction, UsageLimitPeriod? period, List<Tag>? tags}) Future<UsageLimit>
Creates a usage limit for a specified Amazon Redshift feature on a cluster. The usage limit is identified by the returned usage limit identifier.
deauthorizeDataShare({required String consumerIdentifier, required String dataShareArn}) Future<DataShare>
From a datashare producer account, removes authorization from the specified datashare.
deleteAuthenticationProfile({required String authenticationProfileName}) Future<DeleteAuthenticationProfileResult>
Deletes an authentication profile.
deleteCluster({required String clusterIdentifier, String? finalClusterSnapshotIdentifier, int? finalClusterSnapshotRetentionPeriod, bool? skipFinalClusterSnapshot}) Future<DeleteClusterResult>
Deletes a previously provisioned cluster without its final snapshot being created. A successful response from the web service indicates that the request was received correctly. Use DescribeClusters to monitor the status of the deletion. The delete operation cannot be canceled or reverted once submitted. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.
deleteClusterParameterGroup({required String parameterGroupName}) Future<void>
Deletes a specified Amazon Redshift parameter group.
deleteClusterSecurityGroup({required String clusterSecurityGroupName}) Future<void>
Deletes an Amazon Redshift security group. For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.
deleteClusterSnapshot({required String snapshotIdentifier, String? snapshotClusterIdentifier}) Future<DeleteClusterSnapshotResult>
Deletes the specified manual snapshot. The snapshot must be in the available state, with no other users authorized to access the snapshot.
deleteClusterSubnetGroup({required String clusterSubnetGroupName}) Future<void>
Deletes the specified cluster subnet group.
deleteCustomDomainAssociation({required String clusterIdentifier, required String customDomainName}) Future<void>
Contains information about deleting a custom domain association for a cluster.
deleteEndpointAccess({required String endpointName}) Future<EndpointAccess>
Deletes a Redshift-managed VPC endpoint.
deleteEventSubscription({required String subscriptionName}) Future<void>
Deletes an Amazon Redshift event notification subscription.
deleteHsmClientCertificate({required String hsmClientCertificateIdentifier}) Future<void>
Deletes the specified HSM client certificate.
deleteHsmConfiguration({required String hsmConfigurationIdentifier}) Future<void>
Deletes the specified Amazon Redshift HSM configuration.
deleteIntegration({required String integrationArn}) Future<Integration>
Deletes a zero-ETL integration or S3 event integration with Amazon Redshift.
deletePartner({required String accountId, required String clusterIdentifier, required String databaseName, required String partnerName}) Future<PartnerIntegrationOutputMessage>
Deletes a partner integration from a cluster. Data can still flow to the cluster until the integration is deleted at the partner's website.
deleteRedshiftIdcApplication({required String redshiftIdcApplicationArn}) Future<void>
Deletes an Amazon Redshift IAM Identity Center application.
deleteResourcePolicy({required String resourceArn}) Future<void>
Deletes the resource policy for a specified resource.
deleteScheduledAction({required String scheduledActionName}) Future<void>
Deletes a scheduled action.
deleteSnapshotCopyGrant({required String snapshotCopyGrantName}) Future<void>
Deletes the specified snapshot copy grant.
deleteSnapshotSchedule({required String scheduleIdentifier}) Future<void>
Deletes a snapshot schedule.
deleteTags({required String resourceName, required List<String> tagKeys}) Future<void>
Deletes tags from a resource. You must provide the ARN of the resource from which you want to delete the tag or tags.
deleteUsageLimit({required String usageLimitId}) Future<void>
Deletes a usage limit from a cluster.
deregisterNamespace({required List<String> consumerIdentifiers, required NamespaceIdentifierUnion namespaceIdentifier}) Future<DeregisterNamespaceOutputMessage>
Deregisters a cluster or serverless namespace from the Amazon Web Services Glue Data Catalog.
describeAccountAttributes({List<String>? attributeNames}) Future<AccountAttributeList>
Returns a list of attributes attached to an account
describeAuthenticationProfiles({String? authenticationProfileName}) Future<DescribeAuthenticationProfilesResult>
Describes an authentication profile.
describeClusterDbRevisions({String? clusterIdentifier, String? marker, int? maxRecords}) Future<ClusterDbRevisionsMessage>
Returns an array of ClusterDbRevision objects.
describeClusterParameterGroups({String? marker, int? maxRecords, String? parameterGroupName, List<String>? tagKeys, List<String>? tagValues}) Future<ClusterParameterGroupsMessage>
Returns a list of Amazon Redshift parameter groups, including parameter groups you created and the default parameter group. For each parameter group, the response includes the parameter group name, description, and parameter group family name. You can optionally specify a name to retrieve the description of a specific parameter group.
describeClusterParameters({required String parameterGroupName, String? marker, int? maxRecords, String? source}) Future<ClusterParameterGroupDetails>
Returns a detailed list of parameters contained within the specified Amazon Redshift parameter group. For each parameter the response includes information such as parameter name, description, data type, value, whether the parameter value is modifiable, and so on.
describeClusters({String? clusterIdentifier, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues}) Future<ClustersMessage>
Returns properties of provisioned clusters including general cluster properties, cluster database properties, maintenance and backup properties, and security and access properties. This operation supports pagination. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.
describeClusterSecurityGroups({String? clusterSecurityGroupName, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues}) Future<ClusterSecurityGroupMessage>
Returns information about Amazon Redshift security groups. If the name of a security group is specified, the response will contain only information about only that security group.
describeClusterSnapshots({bool? clusterExists, String? clusterIdentifier, DateTime? endTime, String? marker, int? maxRecords, String? ownerAccount, String? snapshotArn, String? snapshotIdentifier, String? snapshotType, List<SnapshotSortingEntity>? sortingEntities, DateTime? startTime, List<String>? tagKeys, List<String>? tagValues}) Future<SnapshotMessage>
Returns one or more snapshot objects, which contain metadata about your cluster snapshots. By default, this operation returns information about all snapshots of all clusters that are owned by your Amazon Web Services account. No information is returned for snapshots owned by inactive Amazon Web Services accounts.
describeClusterSubnetGroups({String? clusterSubnetGroupName, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues}) Future<ClusterSubnetGroupMessage>
Returns one or more cluster subnet group objects, which contain metadata about your cluster subnet groups. By default, this operation returns information about all cluster subnet groups that are defined in your Amazon Web Services account.
describeClusterTracks({String? maintenanceTrackName, String? marker, int? maxRecords}) Future<TrackListMessage>
Returns a list of all the available maintenance tracks.
describeClusterVersions({String? clusterParameterGroupFamily, String? clusterVersion, String? marker, int? maxRecords}) Future<ClusterVersionsMessage>
Returns descriptions of the available Amazon Redshift cluster versions. You can call this operation even before creating any clusters to learn more about the Amazon Redshift versions. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.
describeCustomDomainAssociations({String? customDomainCertificateArn, String? customDomainName, String? marker, int? maxRecords}) Future<CustomDomainAssociationsMessage>
Contains information about custom domain associations for a cluster.
describeDataShares({String? dataShareArn, String? marker, int? maxRecords}) Future<DescribeDataSharesResult>
Shows the status of any inbound or outbound datashares available in the specified account.
describeDataSharesForConsumer({String? consumerArn, String? marker, int? maxRecords, DataShareStatusForConsumer? status}) Future<DescribeDataSharesForConsumerResult>
Returns a list of datashares where the account identifier being called is a consumer account identifier.
describeDataSharesForProducer({String? marker, int? maxRecords, String? producerArn, DataShareStatusForProducer? status}) Future<DescribeDataSharesForProducerResult>
Returns a list of datashares when the account identifier being called is a producer account identifier.
describeDefaultClusterParameters({required String parameterGroupFamily, String? marker, int? maxRecords}) Future<DescribeDefaultClusterParametersResult>
Returns a list of parameter settings for the specified parameter group family.
describeEndpointAccess({String? clusterIdentifier, String? endpointName, String? marker, int? maxRecords, String? resourceOwner, String? vpcId}) Future<EndpointAccessList>
Describes a Redshift-managed VPC endpoint.
describeEndpointAuthorization({String? account, String? clusterIdentifier, bool? grantee, String? marker, int? maxRecords}) Future<EndpointAuthorizationList>
Describes an endpoint authorization.
describeEventCategories({String? sourceType}) Future<EventCategoriesMessage>
Displays a list of event categories for all event source types, or for a specified source type. For a list of the event categories and source types, go to Amazon Redshift Event Notifications.
describeEvents({int? duration, DateTime? endTime, String? marker, int? maxRecords, String? sourceIdentifier, SourceType? sourceType, DateTime? startTime}) Future<EventsMessage>
Returns events related to clusters, security groups, snapshots, and parameter groups for the past 14 days. Events specific to a particular cluster, security group, snapshot or parameter group can be obtained by providing the name as a parameter. By default, the past hour of events are returned.
describeEventSubscriptions({String? marker, int? maxRecords, String? subscriptionName, List<String>? tagKeys, List<String>? tagValues}) Future<EventSubscriptionsMessage>
Lists descriptions of all the Amazon Redshift event notification subscriptions for a customer account. If you specify a subscription name, lists the description for that subscription.
describeHsmClientCertificates({String? hsmClientCertificateIdentifier, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues}) Future<HsmClientCertificateMessage>
Returns information about the specified HSM client certificate. If no certificate ID is specified, returns information about all the HSM certificates owned by your Amazon Web Services account.
describeHsmConfigurations({String? hsmConfigurationIdentifier, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues}) Future<HsmConfigurationMessage>
Returns information about the specified Amazon Redshift HSM configuration. If no configuration ID is specified, returns information about all the HSM configurations owned by your Amazon Web Services account.
describeInboundIntegrations({String? integrationArn, String? marker, int? maxRecords, String? targetArn}) Future<InboundIntegrationsMessage>
Returns a list of inbound integrations.
describeIntegrations({List<DescribeIntegrationsFilter>? filters, String? integrationArn, String? marker, int? maxRecords}) Future<IntegrationsMessage>
Describes one or more zero-ETL or S3 event integrations with Amazon Redshift.
describeLoggingStatus({required String clusterIdentifier}) Future<LoggingStatus>
Describes whether information, such as queries and connection attempts, is being logged for the specified Amazon Redshift cluster.
describeNodeConfigurationOptions({required ActionType actionType, String? clusterIdentifier, List<NodeConfigurationOptionsFilter>? filters, String? marker, int? maxRecords, String? ownerAccount, String? snapshotArn, String? snapshotIdentifier}) Future<NodeConfigurationOptionsMessage>
Returns properties of possible node configurations such as node type, number of nodes, and disk usage for the specified action type.
describeOrderableClusterOptions({String? clusterVersion, String? marker, int? maxRecords, String? nodeType}) Future<OrderableClusterOptionsMessage>
Returns a list of orderable cluster options. Before you create a new cluster you can use this operation to find what options are available, such as the EC2 Availability Zones (AZ) in the specific Amazon Web Services Region that you can specify, and the node types you can request. The node types differ by available storage, memory, CPU and price. With the cost involved you might want to obtain a list of cluster options in the specific region and specify values when creating a cluster. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.
describePartners({required String accountId, required String clusterIdentifier, String? databaseName, String? partnerName}) Future<DescribePartnersOutputMessage>
Returns information about the partner integrations defined for a cluster.
describeRedshiftIdcApplications({String? marker, int? maxRecords, String? redshiftIdcApplicationArn}) Future<DescribeRedshiftIdcApplicationsResult>
Lists the Amazon Redshift IAM Identity Center applications.
describeReservedNodeExchangeStatus({String? marker, int? maxRecords, String? reservedNodeExchangeRequestId, String? reservedNodeId}) Future<DescribeReservedNodeExchangeStatusOutputMessage>
Returns exchange status details and associated metadata for a reserved-node exchange. Statuses include such values as in progress and requested.
describeReservedNodeOfferings({String? marker, int? maxRecords, String? reservedNodeOfferingId}) Future<ReservedNodeOfferingsMessage>
Returns a list of the available reserved node offerings by Amazon Redshift with their descriptions including the node type, the fixed and recurring costs of reserving the node and duration the node will be reserved for you. These descriptions help you determine which reserve node offering you want to purchase. You then use the unique offering ID in you call to PurchaseReservedNodeOffering to reserve one or more nodes for your Amazon Redshift cluster.
describeReservedNodes({String? marker, int? maxRecords, String? reservedNodeId}) Future<ReservedNodesMessage>
Returns the descriptions of the reserved nodes.
describeResize({required String clusterIdentifier}) Future<ResizeProgressMessage>
Returns information about the last resize operation for the specified cluster. If no resize operation has ever been initiated for the specified cluster, a HTTP 404 error is returned. If a resize operation was initiated and completed, the status of the resize remains as SUCCEEDED until the next resize.
describeScheduledActions({bool? active, DateTime? endTime, List<ScheduledActionFilter>? filters, String? marker, int? maxRecords, String? scheduledActionName, DateTime? startTime, ScheduledActionTypeValues? targetActionType}) Future<ScheduledActionsMessage>
Describes properties of scheduled actions.
describeSnapshotCopyGrants({String? marker, int? maxRecords, String? snapshotCopyGrantName, List<String>? tagKeys, List<String>? tagValues}) Future<SnapshotCopyGrantMessage>
Returns a list of snapshot copy grants owned by the Amazon Web Services account in the destination region.
describeSnapshotSchedules({String? clusterIdentifier, String? marker, int? maxRecords, String? scheduleIdentifier, List<String>? tagKeys, List<String>? tagValues}) Future<DescribeSnapshotSchedulesOutputMessage>
Returns a list of snapshot schedules.
describeStorage() Future<CustomerStorageMessage>
Returns account level backups storage size and provisional storage.
describeTableRestoreStatus({String? clusterIdentifier, String? marker, int? maxRecords, String? tableRestoreRequestId}) Future<TableRestoreStatusMessage>
Lists the status of one or more table restore requests made using the RestoreTableFromClusterSnapshot API action. If you don't specify a value for the TableRestoreRequestId parameter, then DescribeTableRestoreStatus returns the status of all table restore requests ordered by the date and time of the request in ascending order. Otherwise DescribeTableRestoreStatus returns the status of the table specified by TableRestoreRequestId.
describeTags({String? marker, int? maxRecords, String? resourceName, String? resourceType, List<String>? tagKeys, List<String>? tagValues}) Future<TaggedResourceListMessage>
Returns a list of tags. You can return tags from a specific resource by specifying an ARN, or you can return all tags for a given type of resource, such as clusters, snapshots, and so on.
describeUsageLimits({String? clusterIdentifier, UsageLimitFeatureType? featureType, String? marker, int? maxRecords, List<String>? tagKeys, List<String>? tagValues, String? usageLimitId}) Future<UsageLimitList>
Shows usage limits on a cluster. Results are filtered based on the combination of input usage limit identifier, cluster identifier, and feature type parameters:
disableLogging({required String clusterIdentifier}) Future<LoggingStatus>
Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.
disableSnapshotCopy({required String clusterIdentifier}) Future<DisableSnapshotCopyResult>
Disables the automatic copying of snapshots from one region to another region for a specified cluster.
disassociateDataShareConsumer({required String dataShareArn, String? consumerArn, String? consumerRegion, bool? disassociateEntireAccount}) Future<DataShare>
From a datashare consumer account, remove association for the specified datashare.
enableLogging({required String clusterIdentifier, String? bucketName, LogDestinationType? logDestinationType, List<String>? logExports, String? s3KeyPrefix}) Future<LoggingStatus>
Starts logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.
enableSnapshotCopy({required String clusterIdentifier, required String destinationRegion, int? manualSnapshotRetentionPeriod, int? retentionPeriod, String? snapshotCopyGrantName}) Future<EnableSnapshotCopyResult>
Enables the automatic copy of snapshots from one region to another region for a specified cluster.
failoverPrimaryCompute({required String clusterIdentifier}) Future<FailoverPrimaryComputeResult>
Fails over the primary compute unit of the specified Multi-AZ cluster to another Availability Zone.
getClusterCredentials({required String dbUser, bool? autoCreate, String? clusterIdentifier, String? customDomainName, List<String>? dbGroups, String? dbName, int? durationSeconds}) Future<ClusterCredentials>
Returns a database user name and temporary password with temporary authorization to log on to an Amazon Redshift database. The action returns the database user name prefixed with IAM: if AutoCreate is False or IAMA: if AutoCreate is True. You can optionally specify one or more database user groups that the user will join at log on. By default, the temporary credentials expire in 900 seconds. You can optionally specify a duration between 900 seconds (15 minutes) and 3600 seconds (60 minutes). For more information, see Using IAM Authentication to Generate Database User Credentials in the Amazon Redshift Cluster Management Guide.
getClusterCredentialsWithIAM({String? clusterIdentifier, String? customDomainName, String? dbName, int? durationSeconds}) Future<ClusterExtendedCredentials>
Returns a database user name and temporary password with temporary authorization to log in to an Amazon Redshift database. The database user is mapped 1:1 to the source Identity and Access Management (IAM) identity. For more information about IAM identities, see IAM Identities (users, user groups, and roles) in the Amazon Web Services Identity and Access Management User Guide.
getIdentityCenterAuthToken({required List<String> clusterIds}) Future<GetIdentityCenterAuthTokenResponse>
Generates an encrypted authentication token that propagates the caller's Amazon Web Services IAM Identity Center identity to Amazon Redshift clusters. This API extracts the Amazon Web Services IAM Identity Center identity from enhanced credentials and creates a secure token that Amazon Redshift drivers can use for authentication.
getReservedNodeExchangeConfigurationOptions({required ReservedNodeExchangeActionType actionType, String? clusterIdentifier, String? marker, int? maxRecords, String? snapshotIdentifier}) Future<GetReservedNodeExchangeConfigurationOptionsOutputMessage>
Gets the configuration options for the reserved-node exchange. These options include information about the source reserved node and target reserved node offering. Details include the node type, the price, the node count, and the offering type.
getReservedNodeExchangeOfferings({required String reservedNodeId, String? marker, int? maxRecords}) Future<GetReservedNodeExchangeOfferingsOutputMessage>
Returns an array of DC2 ReservedNodeOfferings that matches the payment type, term, and usage price of the given DC1 reserved node.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyResult>
Get the resource policy for a specified resource.
listRecommendations({String? clusterIdentifier, String? marker, int? maxRecords, String? namespaceArn}) Future<ListRecommendationsResult>
List the Amazon Redshift Advisor recommendations for one or multiple Amazon Redshift clusters in an Amazon Web Services account.
modifyAquaConfiguration({required String clusterIdentifier, AquaConfigurationStatus? aquaConfigurationStatus}) Future<ModifyAquaOutputMessage>
This operation is retired. Calling this operation does not change AQUA configuration. Amazon Redshift automatically determines whether to use AQUA (Advanced Query Accelerator).
modifyAuthenticationProfile({required String authenticationProfileContent, required String authenticationProfileName}) Future<ModifyAuthenticationProfileResult>
Modifies an authentication profile.
modifyCluster({required String clusterIdentifier, bool? allowVersionUpgrade, int? automatedSnapshotRetentionPeriod, String? availabilityZone, bool? availabilityZoneRelocation, String? clusterParameterGroupName, List<String>? clusterSecurityGroups, String? clusterType, String? clusterVersion, String? elasticIp, bool? encrypted, bool? enhancedVpcRouting, bool? extraComputeForAutomaticOptimization, String? hsmClientCertificateIdentifier, String? hsmConfigurationIdentifier, String? ipAddressType, String? kmsKeyId, String? maintenanceTrackName, bool? manageMasterPassword, int? manualSnapshotRetentionPeriod, String? masterPasswordSecretKmsKeyId, String? masterUserPassword, bool? multiAZ, String? newClusterIdentifier, String? nodeType, int? numberOfNodes, int? port, String? preferredMaintenanceWindow, bool? publiclyAccessible, List<String>? vpcSecurityGroupIds}) Future<ModifyClusterResult>
Modifies the settings for a cluster.
modifyClusterDbRevision({required String clusterIdentifier, required String revisionTarget}) Future<ModifyClusterDbRevisionResult>
Modifies the database revision of a cluster. The database revision is a unique revision of the database running in a cluster.
modifyClusterIamRoles({required String clusterIdentifier, List<String>? addIamRoles, String? defaultIamRoleArn, List<String>? removeIamRoles}) Future<ModifyClusterIamRolesResult>
Modifies the list of Identity and Access Management (IAM) roles that can be used by the cluster to access other Amazon Web Services services.
modifyClusterMaintenance({required String clusterIdentifier, bool? deferMaintenance, int? deferMaintenanceDuration, DateTime? deferMaintenanceEndTime, String? deferMaintenanceIdentifier, DateTime? deferMaintenanceStartTime}) Future<ModifyClusterMaintenanceResult>
Modifies the maintenance settings of a cluster.
modifyClusterParameterGroup({required String parameterGroupName, required List<Parameter> parameters}) Future<ClusterParameterGroupNameMessage>
Modifies the parameters of a parameter group. For the parameters parameter, it can't contain ASCII characters.
modifyClusterSnapshot({required String snapshotIdentifier, bool? force, int? manualSnapshotRetentionPeriod}) Future<ModifyClusterSnapshotResult>
Modifies the settings for a snapshot.
modifyClusterSnapshotSchedule({required String clusterIdentifier, bool? disassociateSchedule, String? scheduleIdentifier}) Future<void>
Modifies a snapshot schedule for a cluster.
modifyClusterSubnetGroup({required String clusterSubnetGroupName, required List<String> subnetIds, String? description}) Future<ModifyClusterSubnetGroupResult>
Modifies a cluster subnet group to include the specified list of VPC subnets. The operation replaces the existing list of subnets with the new list of subnets.
modifyCustomDomainAssociation({required String clusterIdentifier, required String customDomainCertificateArn, required String customDomainName}) Future<ModifyCustomDomainAssociationResult>
Contains information for changing a custom domain association.
modifyEndpointAccess({required String endpointName, List<String>? vpcSecurityGroupIds}) Future<EndpointAccess>
Modifies a Redshift-managed VPC endpoint.
modifyEventSubscription({required String subscriptionName, bool? enabled, List<String>? eventCategories, String? severity, String? snsTopicArn, List<String>? sourceIds, String? sourceType}) Future<ModifyEventSubscriptionResult>
Modifies an existing Amazon Redshift event notification subscription.
modifyIntegration({required String integrationArn, String? description, String? integrationName}) Future<Integration>
Modifies a zero-ETL integration or S3 event integration with Amazon Redshift.
modifyLakehouseConfiguration({required String clusterIdentifier, String? catalogName, bool? dryRun, String? lakehouseIdcApplicationArn, LakehouseIdcRegistration? lakehouseIdcRegistration, LakehouseRegistration? lakehouseRegistration}) Future<LakehouseConfiguration>
Modifies the lakehouse configuration for a cluster. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
modifyRedshiftIdcApplication({required String redshiftIdcApplicationArn, List<AuthorizedTokenIssuer>? authorizedTokenIssuerList, String? iamRoleArn, String? idcDisplayName, String? identityNamespace, List<ServiceIntegrationsUnion>? serviceIntegrations}) Future<ModifyRedshiftIdcApplicationResult>
Changes an existing Amazon Redshift IAM Identity Center application.
modifyScheduledAction({required String scheduledActionName, bool? enable, DateTime? endTime, String? iamRole, String? schedule, String? scheduledActionDescription, DateTime? startTime, ScheduledActionType? targetAction}) Future<ScheduledAction>
Modifies a scheduled action.
modifySnapshotCopyRetentionPeriod({required String clusterIdentifier, required int retentionPeriod, bool? manual}) Future<ModifySnapshotCopyRetentionPeriodResult>
Modifies the number of days to retain snapshots in the destination Amazon Web Services Region after they are copied from the source Amazon Web Services Region. By default, this operation only changes the retention period of copied automated snapshots. The retention periods for both new and existing copied automated snapshots are updated with the new retention period. You can set the manual option to change only the retention periods of copied manual snapshots. If you set this option, only newly copied manual snapshots have the new retention period.
modifySnapshotSchedule({required List<String> scheduleDefinitions, required String scheduleIdentifier}) Future<SnapshotSchedule>
Modifies a snapshot schedule. Any schedule associated with a cluster is modified asynchronously.
modifyUsageLimit({required String usageLimitId, int? amount, UsageLimitBreachAction? breachAction}) Future<UsageLimit>
Modifies a usage limit in a cluster. You can't modify the feature type or period of a usage limit.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseCluster({required String clusterIdentifier}) Future<PauseClusterResult>
Pauses a cluster.
purchaseReservedNodeOffering({required String reservedNodeOfferingId, int? nodeCount}) Future<PurchaseReservedNodeOfferingResult>
Allows you to purchase reserved nodes. Amazon Redshift offers a predefined set of reserved node offerings. You can purchase one or more of the offerings. You can call the DescribeReservedNodeOfferings API to obtain the available reserved node offerings. You can call this API by providing a specific reserved node offering and the number of nodes you want to reserve.
putResourcePolicy({required String policy, required String resourceArn}) Future<PutResourcePolicyResult>
Updates the resource policy for a specified resource.
rebootCluster({required String clusterIdentifier}) Future<RebootClusterResult>
Reboots a cluster. This action is taken as soon as possible. It results in a momentary outage to the cluster, during which the cluster status is set to rebooting. A cluster event is created when the reboot is completed. Any pending cluster modifications (see ModifyCluster) are applied at this reboot. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.
registerNamespace({required List<String> consumerIdentifiers, required NamespaceIdentifierUnion namespaceIdentifier}) Future<RegisterNamespaceOutputMessage>
Registers a cluster or serverless namespace to the Amazon Web Services Glue Data Catalog.
rejectDataShare({required String dataShareArn}) Future<DataShare>
From a datashare consumer account, rejects the specified datashare.
resetClusterParameterGroup({required String parameterGroupName, List<Parameter>? parameters, bool? resetAllParameters}) Future<ClusterParameterGroupNameMessage>
Sets one or more parameters of the specified parameter group to their default values and sets the source values of the parameters to "engine-default". To reset the entire parameter group specify the ResetAllParameters parameter. For parameter changes to take effect you must reboot any associated clusters.
resizeCluster({required String clusterIdentifier, bool? classic, String? clusterType, String? nodeType, int? numberOfNodes, String? reservedNodeId, String? targetReservedNodeOfferingId}) Future<ResizeClusterResult>
Changes the size of the cluster. You can change the cluster's type, or change the number or type of nodes. The default behavior is to use the elastic resize method. With an elastic resize, your cluster is available for read and write operations more quickly than with the classic resize method.
restoreFromClusterSnapshot({required String clusterIdentifier, String? additionalInfo, bool? allowVersionUpgrade, AquaConfigurationStatus? aquaConfigurationStatus, int? automatedSnapshotRetentionPeriod, String? availabilityZone, bool? availabilityZoneRelocation, String? catalogName, String? clusterParameterGroupName, List<String>? clusterSecurityGroups, String? clusterSubnetGroupName, String? defaultIamRoleArn, String? elasticIp, bool? encrypted, bool? enhancedVpcRouting, String? hsmClientCertificateIdentifier, String? hsmConfigurationIdentifier, List<String>? iamRoles, String? ipAddressType, String? kmsKeyId, String? maintenanceTrackName, bool? manageMasterPassword, int? manualSnapshotRetentionPeriod, String? masterPasswordSecretKmsKeyId, bool? multiAZ, String? nodeType, int? numberOfNodes, String? ownerAccount, int? port, String? preferredMaintenanceWindow, bool? publiclyAccessible, String? redshiftIdcApplicationArn, String? reservedNodeId, String? snapshotArn, String? snapshotClusterIdentifier, String? snapshotIdentifier, String? snapshotScheduleIdentifier, String? targetReservedNodeOfferingId, List<String>? vpcSecurityGroupIds}) Future<RestoreFromClusterSnapshotResult>
Creates a new cluster from a snapshot. By default, Amazon Redshift creates the resulting cluster with the same configuration as the original cluster from which the snapshot was created, except that the new cluster is created with the default cluster security and parameter groups. After Amazon Redshift creates the cluster, you can use the ModifyCluster API to associate a different security group and different parameter group with the restored cluster. If you are using a DS node type, you can also choose to change to another DS node type of the same size during restore.
restoreTableFromClusterSnapshot({required String clusterIdentifier, required String newTableName, required String snapshotIdentifier, required String sourceDatabaseName, required String sourceTableName, bool? enableCaseSensitiveIdentifier, String? sourceSchemaName, String? targetDatabaseName, String? targetSchemaName}) Future<RestoreTableFromClusterSnapshotResult>
Creates a new table from a table in an Amazon Redshift cluster snapshot. You must create the new table within the Amazon Redshift cluster that the snapshot was taken from.
resumeCluster({required String clusterIdentifier}) Future<ResumeClusterResult>
Resumes a paused cluster.
revokeClusterSecurityGroupIngress({required String clusterSecurityGroupName, String? cidrip, String? eC2SecurityGroupName, String? eC2SecurityGroupOwnerId}) Future<RevokeClusterSecurityGroupIngressResult>
Revokes an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group. To add an ingress rule, see AuthorizeClusterSecurityGroupIngress. For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.
revokeEndpointAccess({String? account, String? clusterIdentifier, bool? force, List<String>? vpcIds}) Future<EndpointAuthorization>
Revokes access to a cluster.
revokeSnapshotAccess({required String accountWithRestoreAccess, String? snapshotArn, String? snapshotClusterIdentifier, String? snapshotIdentifier}) Future<RevokeSnapshotAccessResult>
Removes the ability of the specified Amazon Web Services account to restore the specified snapshot. If the account is currently restoring the snapshot, the restore will run to completion.
rotateEncryptionKey({required String clusterIdentifier}) Future<RotateEncryptionKeyResult>
Rotates the encryption keys for a cluster.
toString() String
A string representation of this object.
inherited
updatePartnerStatus({required String accountId, required String clusterIdentifier, required String databaseName, required String partnerName, required PartnerIntegrationStatus status, String? statusMessage}) Future<PartnerIntegrationOutputMessage>
Updates the status of a partner integration.

Operators

operator ==(Object other) bool
The equality operator.
inherited