addPartner method
Adds a partner integration to a cluster. This operation authorizes a partner to push status updates for the specified database. To complete the integration, you also set up the integration on the partner website.
May throw ClusterNotFoundFault.
May throw PartnerNotFoundFault.
May throw UnauthorizedPartnerIntegrationFault.
May throw UnsupportedOperationFault.
Parameter accountId :
The Amazon Web Services account ID that owns the cluster.
Parameter clusterIdentifier :
The cluster identifier of the cluster that receives data from the partner.
Parameter databaseName :
The name of the database that receives data from the partner.
Parameter partnerName :
The name of the partner that is authorized to send data.
Implementation
Future<PartnerIntegrationOutputMessage> addPartner({
required String accountId,
required String clusterIdentifier,
required String databaseName,
required String partnerName,
}) async {
final $request = <String, String>{
'AccountId': accountId,
'ClusterIdentifier': clusterIdentifier,
'DatabaseName': databaseName,
'PartnerName': partnerName,
};
final $result = await _protocol.send(
$request,
action: 'AddPartner',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'AddPartnerResult',
);
return PartnerIntegrationOutputMessage.fromXml($result);
}