createCustomDomainAssociation method

Future<CreateCustomDomainAssociationResult> createCustomDomainAssociation({
  1. required String clusterIdentifier,
  2. required String customDomainCertificateArn,
  3. required String customDomainName,
})

Used to create a custom domain name for a cluster. Properties include the custom domain name, the cluster the custom domain is associated with, and the certificate Amazon Resource Name (ARN).

May throw ClusterNotFoundFault. May throw CustomCnameAssociationFault. May throw UnsupportedOperationFault.

Parameter clusterIdentifier : The cluster identifier that the custom domain is associated with.

Parameter customDomainCertificateArn : The certificate Amazon Resource Name (ARN) for the custom domain name association.

Parameter customDomainName : The custom domain name for a custom domain association.

Implementation

Future<CreateCustomDomainAssociationResult> createCustomDomainAssociation({
  required String clusterIdentifier,
  required String customDomainCertificateArn,
  required String customDomainName,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
    'CustomDomainCertificateArn': customDomainCertificateArn,
    'CustomDomainName': customDomainName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'CreateCustomDomainAssociation',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateCustomDomainAssociationResult',
  );
  return CreateCustomDomainAssociationResult.fromXml($result);
}