deauthorizeDataShare method
From a datashare producer account, removes authorization from the specified datashare.
May throw InvalidDataShareFault.
Parameter consumerIdentifier :
The identifier of the data consumer that is to have authorization removed
from the datashare. This identifier is an Amazon Web Services account ID
or a keyword, such as ADX.
Parameter dataShareArn :
The namespace Amazon Resource Name (ARN) of the datashare to remove
authorization from.
Implementation
Future<DataShare> deauthorizeDataShare({
required String consumerIdentifier,
required String dataShareArn,
}) async {
final $request = <String, String>{
'ConsumerIdentifier': consumerIdentifier,
'DataShareArn': dataShareArn,
};
final $result = await _protocol.send(
$request,
action: 'DeauthorizeDataShare',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DeauthorizeDataShareResult',
);
return DataShare.fromXml($result);
}