deleteCustomDomainAssociation method
Contains information about deleting a custom domain association for a cluster.
May throw ClusterNotFoundFault.
May throw CustomCnameAssociationFault.
May throw CustomDomainAssociationNotFoundFault.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The identifier of the cluster to delete a custom domain association for.
Parameter customDomainName :
The custom domain name for the custom domain association.
Implementation
Future<void> deleteCustomDomainAssociation({
required String clusterIdentifier,
required String customDomainName,
}) async {
final $request = <String, String>{
'ClusterIdentifier': clusterIdentifier,
'CustomDomainName': customDomainName,
};
await _protocol.send(
$request,
action: 'DeleteCustomDomainAssociation',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}