describeDataShares method

Future<DescribeDataSharesResult> describeDataShares({
  1. String? dataShareArn,
  2. String? marker,
  3. int? maxRecords,
})

Shows the status of any inbound or outbound datashares available in the specified account.

May throw InvalidDataShareFault.

Parameter dataShareArn : The Amazon resource name (ARN) of the datashare to describe details of.

Parameter marker : An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataShares request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Parameter maxRecords : The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Implementation

Future<DescribeDataSharesResult> describeDataShares({
  String? dataShareArn,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (dataShareArn != null) 'DataShareArn': dataShareArn,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDataShares',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDataSharesResult',
  );
  return DescribeDataSharesResult.fromXml($result);
}