describeDataSharesForConsumer method
Returns a list of datashares where the account identifier being called is a consumer account identifier.
May throw InvalidNamespaceFault.
Parameter consumerArn :
The Amazon Resource Name (ARN) of the consumer namespace that returns in
the list of datashares.
Parameter marker :
An optional parameter that specifies the starting point to return a set of
response records. When the results of a
DescribeDataSharesForConsumer request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in the
Marker field of the response. You can retrieve the next set
of response records by providing the returned marker value in the
Marker parameter and retrying the request.
Parameter maxRecords :
The maximum number of response records to return in each call. If the
number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a
marker field of the response. You can retrieve the next set
of records by retrying the command with the returned marker value.
Parameter status :
An identifier giving the status of a datashare in the consumer cluster. If
this field is specified, Amazon Redshift returns the list of datashares
that have the specified status.
Implementation
Future<DescribeDataSharesForConsumerResult> describeDataSharesForConsumer({
String? consumerArn,
String? marker,
int? maxRecords,
DataShareStatusForConsumer? status,
}) async {
final $request = <String, String>{
if (consumerArn != null) 'ConsumerArn': consumerArn,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (status != null) 'Status': status.value,
};
final $result = await _protocol.send(
$request,
action: 'DescribeDataSharesForConsumer',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDataSharesForConsumerResult',
);
return DescribeDataSharesForConsumerResult.fromXml($result);
}