describeDataSharesForProducer method

Future<DescribeDataSharesForProducerResult> describeDataSharesForProducer({
  1. String? marker,
  2. int? maxRecords,
  3. String? producerArn,
  4. DataShareStatusForProducer? status,
})

Returns a list of datashares when the account identifier being called is a producer account identifier.

May throw InvalidNamespaceFault.

Parameter marker : An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataSharesForProducer request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Parameter maxRecords : The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Parameter producerArn : The Amazon Resource Name (ARN) of the producer namespace that returns in the list of datashares.

Parameter status : An identifier giving the status of a datashare in the producer. If this field is specified, Amazon Redshift returns the list of datashares that have the specified status.

Implementation

Future<DescribeDataSharesForProducerResult> describeDataSharesForProducer({
  String? marker,
  int? maxRecords,
  String? producerArn,
  DataShareStatusForProducer? status,
}) async {
  final $request = <String, String>{
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (producerArn != null) 'ProducerArn': producerArn,
    if (status != null) 'Status': status.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeDataSharesForProducer',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeDataSharesForProducerResult',
  );
  return DescribeDataSharesForProducerResult.fromXml($result);
}