describeEndpointAuthorization method

Future<EndpointAuthorizationList> describeEndpointAuthorization({
  1. String? account,
  2. String? clusterIdentifier,
  3. bool? grantee,
  4. String? marker,
  5. int? maxRecords,
})

Describes an endpoint authorization.

May throw ClusterNotFoundFault. May throw UnsupportedOperationFault.

Parameter account : The Amazon Web Services account ID of either the cluster owner (grantor) or grantee. If Grantee parameter is true, then the Account value is of the grantor.

Parameter clusterIdentifier : The cluster identifier of the cluster to access.

Parameter grantee : Indicates whether to check authorization from a grantor or grantee point of view. If true, Amazon Redshift returns endpoint authorizations that you've been granted. If false (default), checks authorization from a grantor point of view.

Parameter marker : An optional pagination token provided by a previous DescribeEndpointAuthorization request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a Marker is included in the response so that the remaining results can be retrieved.

Implementation

Future<EndpointAuthorizationList> describeEndpointAuthorization({
  String? account,
  String? clusterIdentifier,
  bool? grantee,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (account != null) 'Account': account,
    if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
    if (grantee != null) 'Grantee': grantee.toString(),
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeEndpointAuthorization',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeEndpointAuthorizationResult',
  );
  return EndpointAuthorizationList.fromXml($result);
}