describeInboundIntegrations method
Returns a list of inbound integrations.
May throw IntegrationNotFoundFault.
May throw InvalidNamespaceFault.
May throw UnsupportedOperationFault.
Parameter integrationArn :
The Amazon Resource Name (ARN) of the inbound integration.
Parameter marker :
An optional parameter that specifies the starting point to return a set of
response records. When the results of a DescribeInboundIntegrations
request exceed the value specified in MaxRecords, Amazon Web
Services returns a value in the Marker field of the response.
You can retrieve the next set of response records by providing the
returned marker value in the Marker parameter and retrying
the request.
Parameter maxRecords :
The maximum number of response records to return in each call. If the
number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a
marker field of the response. You can retrieve the next set
of records by retrying the command with the returned marker value.
Default: 100
Constraints: minimum 20, maximum 100.
Parameter targetArn :
The Amazon Resource Name (ARN) of the target of an inbound integration.
Implementation
Future<InboundIntegrationsMessage> describeInboundIntegrations({
String? integrationArn,
String? marker,
int? maxRecords,
String? targetArn,
}) async {
final $request = <String, String>{
if (integrationArn != null) 'IntegrationArn': integrationArn,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (targetArn != null) 'TargetArn': targetArn,
};
final $result = await _protocol.send(
$request,
action: 'DescribeInboundIntegrations',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeInboundIntegrationsResult',
);
return InboundIntegrationsMessage.fromXml($result);
}