describeIntegrations method

Future<IntegrationsMessage> describeIntegrations({
  1. List<DescribeIntegrationsFilter>? filters,
  2. String? integrationArn,
  3. String? marker,
  4. int? maxRecords,
})

Describes one or more zero-ETL or S3 event integrations with Amazon Redshift.

May throw IntegrationNotFoundFault. May throw UnsupportedOperationFault.

Parameter filters : A filter that specifies one or more resources to return.

Parameter integrationArn : The unique identifier of the integration.

Parameter marker : An optional pagination token provided by a previous DescribeIntegrations request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Parameter maxRecords : The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Default: 100

Constraints: minimum 20, maximum 100.

Implementation

Future<IntegrationsMessage> describeIntegrations({
  List<DescribeIntegrationsFilter>? filters,
  String? integrationArn,
  String? marker,
  int? maxRecords,
}) async {
  final $request = <String, String>{
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.DescribeIntegrationsFilter.${i1 + 1}.${e3.key}':
                e3.value,
    if (integrationArn != null) 'IntegrationArn': integrationArn,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeIntegrations',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeIntegrationsResult',
  );
  return IntegrationsMessage.fromXml($result);
}