describeLoggingStatus method
Describes whether information, such as queries and connection attempts, is being logged for the specified Amazon Redshift cluster.
May throw ClusterNotFoundFault.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The identifier of the cluster from which to get the logging status.
Example: examplecluster
Implementation
Future<LoggingStatus> describeLoggingStatus({
required String clusterIdentifier,
}) async {
final $request = <String, String>{
'ClusterIdentifier': clusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribeLoggingStatus',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeLoggingStatusResult',
);
return LoggingStatus.fromXml($result);
}