describePartners method

Future<DescribePartnersOutputMessage> describePartners({
  1. required String accountId,
  2. required String clusterIdentifier,
  3. String? databaseName,
  4. String? partnerName,
})

Returns information about the partner integrations defined for a cluster.

May throw ClusterNotFoundFault. May throw UnauthorizedPartnerIntegrationFault. May throw UnsupportedOperationFault.

Parameter accountId : The Amazon Web Services account ID that owns the cluster.

Parameter clusterIdentifier : The cluster identifier of the cluster whose partner integration is being described.

Parameter databaseName : The name of the database whose partner integration is being described. If database name is not specified, then all databases in the cluster are described.

Parameter partnerName : The name of the partner that is being described. If partner name is not specified, then all partner integrations are described.

Implementation

Future<DescribePartnersOutputMessage> describePartners({
  required String accountId,
  required String clusterIdentifier,
  String? databaseName,
  String? partnerName,
}) async {
  final $request = <String, String>{
    'AccountId': accountId,
    'ClusterIdentifier': clusterIdentifier,
    if (databaseName != null) 'DatabaseName': databaseName,
    if (partnerName != null) 'PartnerName': partnerName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribePartners',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribePartnersResult',
  );
  return DescribePartnersOutputMessage.fromXml($result);
}