describeReservedNodeExchangeStatus method
Returns exchange status details and associated metadata for a reserved-node exchange. Statuses include such values as in progress and requested.
May throw ReservedNodeExchangeNotFoundFault.
May throw ReservedNodeNotFoundFault.
May throw UnsupportedOperationFault.
Parameter marker :
An optional pagination token provided by a previous
DescribeReservedNodeExchangeStatus request. If this parameter
is specified, the response includes only records beyond the marker, up to
the value specified by the MaxRecords parameter. You can
retrieve the next set of response records by providing the returned marker
value in the Marker parameter and retrying the request.
Parameter maxRecords :
The maximum number of response records to return in each call. If the
number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a
Marker field of the response. You can retrieve the next set
of records by retrying the command with the returned marker value.
Parameter reservedNodeExchangeRequestId :
The identifier of the reserved-node exchange request.
Parameter reservedNodeId :
The identifier of the source reserved node in a reserved-node exchange
request.
Implementation
Future<DescribeReservedNodeExchangeStatusOutputMessage>
describeReservedNodeExchangeStatus({
String? marker,
int? maxRecords,
String? reservedNodeExchangeRequestId,
String? reservedNodeId,
}) async {
final $request = <String, String>{
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (reservedNodeExchangeRequestId != null)
'ReservedNodeExchangeRequestId': reservedNodeExchangeRequestId,
if (reservedNodeId != null) 'ReservedNodeId': reservedNodeId,
};
final $result = await _protocol.send(
$request,
action: 'DescribeReservedNodeExchangeStatus',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeReservedNodeExchangeStatusResult',
);
return DescribeReservedNodeExchangeStatusOutputMessage.fromXml($result);
}