describeReservedNodes method
Returns the descriptions of the reserved nodes.
May throw DependentServiceUnavailableFault.
May throw ReservedNodeNotFoundFault.
Parameter marker :
An optional parameter that specifies the starting point to return a set of
response records. When the results of a DescribeReservedNodes
request exceed the value specified in MaxRecords, Amazon Web
Services returns a value in the Marker field of the response.
You can retrieve the next set of response records by providing the
returned marker value in the Marker parameter and retrying
the request.
Parameter maxRecords :
The maximum number of response records to return in each call. If the
number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a
marker field of the response. You can retrieve the next set
of records by retrying the command with the returned marker value.
Default: 100
Constraints: minimum 20, maximum 100.
Parameter reservedNodeId :
Identifier for the node reservation.
Implementation
Future<ReservedNodesMessage> describeReservedNodes({
String? marker,
int? maxRecords,
String? reservedNodeId,
}) async {
final $request = <String, String>{
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (reservedNodeId != null) 'ReservedNodeId': reservedNodeId,
};
final $result = await _protocol.send(
$request,
action: 'DescribeReservedNodes',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeReservedNodesResult',
);
return ReservedNodesMessage.fromXml($result);
}