describeResize method
Returns information about the last resize operation for the specified
cluster. If no resize operation has ever been initiated for the specified
cluster, a HTTP 404 error is returned. If a resize operation
was initiated and completed, the status of the resize remains as
SUCCEEDED until the next resize.
A resize operation can be requested using ModifyCluster and specifying a different number or type of nodes for the cluster.
May throw ClusterNotFoundFault.
May throw ResizeNotFoundFault.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The unique identifier of a cluster whose resize progress you are
requesting. This parameter is case-sensitive.
By default, resize operations for all clusters defined for an Amazon Web Services account are returned.
Implementation
Future<ResizeProgressMessage> describeResize({
required String clusterIdentifier,
}) async {
final $request = <String, String>{
'ClusterIdentifier': clusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribeResize',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeResizeResult',
);
return ResizeProgressMessage.fromXml($result);
}