disableLogging method

Future<LoggingStatus> disableLogging({
  1. required String clusterIdentifier,
})

Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.

May throw ClusterNotFoundFault. May throw InvalidClusterStateFault. May throw UnsupportedOperationFault.

Parameter clusterIdentifier : The identifier of the cluster on which logging is to be stopped.

Example: examplecluster

Implementation

Future<LoggingStatus> disableLogging({
  required String clusterIdentifier,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DisableLogging',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DisableLoggingResult',
  );
  return LoggingStatus.fromXml($result);
}