disableSnapshotCopy method

Future<DisableSnapshotCopyResult> disableSnapshotCopy({
  1. required String clusterIdentifier,
})

Disables the automatic copying of snapshots from one region to another region for a specified cluster.

If your cluster and its snapshots are encrypted using an encrypted symmetric key from Key Management Service, use DeleteSnapshotCopyGrant to delete the grant that grants Amazon Redshift permission to the key in the destination region.

May throw ClusterNotFoundFault. May throw InvalidClusterStateFault. May throw SnapshotCopyAlreadyDisabledFault. May throw UnauthorizedOperation. May throw UnsupportedOperationFault.

Parameter clusterIdentifier : The unique identifier of the source cluster that you want to disable copying of snapshots to a destination region.

Constraints: Must be the valid name of an existing cluster that has cross-region snapshot copy enabled.

Implementation

Future<DisableSnapshotCopyResult> disableSnapshotCopy({
  required String clusterIdentifier,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DisableSnapshotCopy',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DisableSnapshotCopyResult',
  );
  return DisableSnapshotCopyResult.fromXml($result);
}