failoverPrimaryCompute method

Future<FailoverPrimaryComputeResult> failoverPrimaryCompute({
  1. required String clusterIdentifier,
})

Fails over the primary compute unit of the specified Multi-AZ cluster to another Availability Zone.

May throw ClusterNotFoundFault. May throw InvalidClusterStateFault. May throw UnauthorizedOperation. May throw UnsupportedOperationFault.

Parameter clusterIdentifier : The unique identifier of the cluster for which the primary compute unit will be failed over to another Availability Zone.

Implementation

Future<FailoverPrimaryComputeResult> failoverPrimaryCompute({
  required String clusterIdentifier,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'FailoverPrimaryCompute',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'FailoverPrimaryComputeResult',
  );
  return FailoverPrimaryComputeResult.fromXml($result);
}