getClusterCredentialsWithIAM method
Returns a database user name and temporary password with temporary authorization to log in to an Amazon Redshift database. The database user is mapped 1:1 to the source Identity and Access Management (IAM) identity. For more information about IAM identities, see IAM Identities (users, user groups, and roles) in the Amazon Web Services Identity and Access Management User Guide.
The Identity and Access Management (IAM) identity that runs this operation must have an IAM policy attached that allows access to all necessary actions and resources. For more information about permissions, see Using identity-based policies (IAM policies) in the Amazon Redshift Cluster Management Guide.
May throw ClusterNotFoundFault.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The unique identifier of the cluster that contains the database for which
you are requesting credentials.
Parameter customDomainName :
The custom domain name for the IAM message cluster credentials.
Parameter dbName :
The name of the database for which you are requesting credentials. If the
database name is specified, the IAM policy must allow access to the
resource dbname for the specified database name. If the
database name is not specified, access to all databases is allowed.
Parameter durationSeconds :
The number of seconds until the returned temporary password expires.
Range: 900-3600. Default: 900.
Implementation
Future<ClusterExtendedCredentials> getClusterCredentialsWithIAM({
String? clusterIdentifier,
String? customDomainName,
String? dbName,
int? durationSeconds,
}) async {
final $request = <String, String>{
if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
if (customDomainName != null) 'CustomDomainName': customDomainName,
if (dbName != null) 'DbName': dbName,
if (durationSeconds != null)
'DurationSeconds': durationSeconds.toString(),
};
final $result = await _protocol.send(
$request,
action: 'GetClusterCredentialsWithIAM',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetClusterCredentialsWithIAMResult',
);
return ClusterExtendedCredentials.fromXml($result);
}