modifyAuthenticationProfile method

Future<ModifyAuthenticationProfileResult> modifyAuthenticationProfile({
  1. required String authenticationProfileContent,
  2. required String authenticationProfileName,
})

Modifies an authentication profile.

May throw AuthenticationProfileNotFoundFault. May throw AuthenticationProfileQuotaExceededFault. May throw InvalidAuthenticationProfileRequestFault.

Parameter authenticationProfileContent : The new content of the authentication profile in JSON format. The maximum length of the JSON string is determined by a quota for your account.

Parameter authenticationProfileName : The name of the authentication profile to replace.

Implementation

Future<ModifyAuthenticationProfileResult> modifyAuthenticationProfile({
  required String authenticationProfileContent,
  required String authenticationProfileName,
}) async {
  final $request = <String, String>{
    'AuthenticationProfileContent': authenticationProfileContent,
    'AuthenticationProfileName': authenticationProfileName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ModifyAuthenticationProfile',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ModifyAuthenticationProfileResult',
  );
  return ModifyAuthenticationProfileResult.fromXml($result);
}