modifyClusterSnapshotSchedule method

Future<void> modifyClusterSnapshotSchedule({
  1. required String clusterIdentifier,
  2. bool? disassociateSchedule,
  3. String? scheduleIdentifier,
})

Modifies a snapshot schedule for a cluster.

May throw ClusterNotFoundFault. May throw InvalidClusterSnapshotScheduleStateFault. May throw SnapshotScheduleNotFoundFault.

Parameter clusterIdentifier : A unique identifier for the cluster whose snapshot schedule you want to modify.

Parameter disassociateSchedule : A boolean to indicate whether to remove the assoiciation between the cluster and the schedule.

Parameter scheduleIdentifier : A unique alphanumeric identifier for the schedule that you want to associate with the cluster.

Implementation

Future<void> modifyClusterSnapshotSchedule({
  required String clusterIdentifier,
  bool? disassociateSchedule,
  String? scheduleIdentifier,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
    if (disassociateSchedule != null)
      'DisassociateSchedule': disassociateSchedule.toString(),
    if (scheduleIdentifier != null) 'ScheduleIdentifier': scheduleIdentifier,
  };
  await _protocol.send(
    $request,
    action: 'ModifyClusterSnapshotSchedule',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
  );
}