modifyCustomDomainAssociation method
Contains information for changing a custom domain association.
May throw ClusterNotFoundFault.
May throw CustomCnameAssociationFault.
May throw CustomDomainAssociationNotFoundFault.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The identifier of the cluster to change a custom domain association for.
Parameter customDomainCertificateArn :
The certificate Amazon Resource Name (ARN) for the changed custom domain
association.
Parameter customDomainName :
The custom domain name for a changed custom domain association.
Implementation
Future<ModifyCustomDomainAssociationResult> modifyCustomDomainAssociation({
required String clusterIdentifier,
required String customDomainCertificateArn,
required String customDomainName,
}) async {
final $request = <String, String>{
'ClusterIdentifier': clusterIdentifier,
'CustomDomainCertificateArn': customDomainCertificateArn,
'CustomDomainName': customDomainName,
};
final $result = await _protocol.send(
$request,
action: 'ModifyCustomDomainAssociation',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyCustomDomainAssociationResult',
);
return ModifyCustomDomainAssociationResult.fromXml($result);
}