modifyUsageLimit method
Modifies a usage limit in a cluster. You can't modify the feature type or period of a usage limit.
May throw InvalidUsageLimitFault.
May throw UnsupportedOperationFault.
May throw UsageLimitNotFoundFault.
Parameter usageLimitId :
The identifier of the usage limit to modify.
Parameter amount :
The new limit amount. For more information about this parameter, see
UsageLimit.
Parameter breachAction :
The new action that Amazon Redshift takes when the limit is reached. For
more information about this parameter, see UsageLimit.
Implementation
Future<UsageLimit> modifyUsageLimit({
required String usageLimitId,
int? amount,
UsageLimitBreachAction? breachAction,
}) async {
final $request = <String, String>{
'UsageLimitId': usageLimitId,
if (amount != null) 'Amount': amount.toString(),
if (breachAction != null) 'BreachAction': breachAction.value,
};
final $result = await _protocol.send(
$request,
action: 'ModifyUsageLimit',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyUsageLimitResult',
);
return UsageLimit.fromXml($result);
}