revokeClusterSecurityGroupIngress method
Revokes an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group. To add an ingress rule, see AuthorizeClusterSecurityGroupIngress. For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.
May throw AuthorizationNotFoundFault.
May throw ClusterSecurityGroupNotFoundFault.
May throw InvalidClusterSecurityGroupStateFault.
Parameter clusterSecurityGroupName :
The name of the security Group from which to revoke the ingress rule.
Parameter cidrip :
The IP range for which to revoke access. This range must be a valid
Classless Inter-Domain Routing (CIDR) block of IP addresses. If
CIDRIP is specified, EC2SecurityGroupName and
EC2SecurityGroupOwnerId cannot be provided.
Parameter eC2SecurityGroupName :
The name of the EC2 Security Group whose access is to be revoked. If
EC2SecurityGroupName is specified,
EC2SecurityGroupOwnerId must also be provided and
CIDRIP cannot be provided.
Parameter eC2SecurityGroupOwnerId :
The Amazon Web Services account number of the owner of the security group
specified in the EC2SecurityGroupName parameter. The Amazon
Web Services access key ID is not an acceptable value. If
EC2SecurityGroupOwnerId is specified,
EC2SecurityGroupName must also be provided. and
CIDRIP cannot be provided.
Example: 111122223333
Implementation
Future<RevokeClusterSecurityGroupIngressResult>
revokeClusterSecurityGroupIngress({
required String clusterSecurityGroupName,
String? cidrip,
String? eC2SecurityGroupName,
String? eC2SecurityGroupOwnerId,
}) async {
final $request = <String, String>{
'ClusterSecurityGroupName': clusterSecurityGroupName,
if (cidrip != null) 'CIDRIP': cidrip,
if (eC2SecurityGroupName != null)
'EC2SecurityGroupName': eC2SecurityGroupName,
if (eC2SecurityGroupOwnerId != null)
'EC2SecurityGroupOwnerId': eC2SecurityGroupOwnerId,
};
final $result = await _protocol.send(
$request,
action: 'RevokeClusterSecurityGroupIngress',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RevokeClusterSecurityGroupIngressResult',
);
return RevokeClusterSecurityGroupIngressResult.fromXml($result);
}