rotateEncryptionKey method

Future<RotateEncryptionKeyResult> rotateEncryptionKey({
  1. required String clusterIdentifier,
})

Rotates the encryption keys for a cluster.

May throw ClusterNotFoundFault. May throw DependentServiceRequestThrottlingFault. May throw InvalidClusterStateFault. May throw UnsupportedOperationFault.

Parameter clusterIdentifier : The unique identifier of the cluster that you want to rotate the encryption keys for.

Constraints: Must be the name of valid cluster that has encryption enabled.

Implementation

Future<RotateEncryptionKeyResult> rotateEncryptionKey({
  required String clusterIdentifier,
}) async {
  final $request = <String, String>{
    'ClusterIdentifier': clusterIdentifier,
  };
  final $result = await _protocol.send(
    $request,
    action: 'RotateEncryptionKey',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'RotateEncryptionKeyResult',
  );
  return RotateEncryptionKeyResult.fromXml($result);
}