updatePartnerStatus method
Updates the status of a partner integration.
May throw ClusterNotFoundFault.
May throw PartnerNotFoundFault.
May throw UnauthorizedPartnerIntegrationFault.
May throw UnsupportedOperationFault.
Parameter accountId :
The Amazon Web Services account ID that owns the cluster.
Parameter clusterIdentifier :
The cluster identifier of the cluster whose partner integration status is
being updated.
Parameter databaseName :
The name of the database whose partner integration status is being
updated.
Parameter partnerName :
The name of the partner whose integration status is being updated.
Parameter status :
The value of the updated status.
Parameter statusMessage :
The status message provided by the partner.
Implementation
Future<PartnerIntegrationOutputMessage> updatePartnerStatus({
required String accountId,
required String clusterIdentifier,
required String databaseName,
required String partnerName,
required PartnerIntegrationStatus status,
String? statusMessage,
}) async {
final $request = <String, String>{
'AccountId': accountId,
'ClusterIdentifier': clusterIdentifier,
'DatabaseName': databaseName,
'PartnerName': partnerName,
'Status': status.value,
if (statusMessage != null) 'StatusMessage': statusMessage,
};
final $result = await _protocol.send(
$request,
action: 'UpdatePartnerStatus',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdatePartnerStatusResult',
);
return PartnerIntegrationOutputMessage.fromXml($result);
}