executeStatement method
Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL). This statement must be a single SQL statement. Depending on the authorization method, use one of the following combinations of request parameters:
-
Secrets Manager - when connecting to a cluster, provide the
secret-arnof a secret stored in Secrets Manager which hasusernameandpassword. The specified secret contains credentials to connect to thedatabaseyou specify. When you are connecting to a cluster, you also supply the database name, If you provide a cluster identifier (dbClusterIdentifier), it must match the cluster identifier stored in the secret. When you are connecting to a serverless workgroup, you also supply the database name. -
Temporary credentials - when connecting to your data warehouse, choose one
of the following options:
-
When connecting to a serverless workgroup, specify the workgroup name and
database name. The database user name is derived from the IAM identity.
For example,
arn:iam::123456789012:user:foohas the database user nameIAM:foo. Also, permission to call theredshift-serverless:GetCredentialsoperation is required. -
When connecting to a cluster as an IAM identity, specify the cluster
identifier and the database name. The database user name is derived from
the IAM identity. For example,
arn:iam::123456789012:user:foohas the database user nameIAM:foo. Also, permission to call theredshift:GetClusterCredentialsWithIAMoperation is required. -
When connecting to a cluster as a database user, specify the cluster
identifier, the database name, and the database user name. Also,
permission to call the
redshift:GetClusterCredentialsoperation is required.
-
When connecting to a serverless workgroup, specify the workgroup name and
database name. The database user name is derived from the IAM identity.
For example,
May throw ActiveSessionsExceededException.
May throw ActiveStatementsExceededException.
May throw ExecuteStatementException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter sql :
The SQL statement text to run.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Parameter clusterIdentifier :
The cluster identifier. This parameter is required when connecting to a
cluster and authenticating using either Secrets Manager or temporary
credentials.
Parameter database :
The name of the database. This parameter is required when authenticating
using either Secrets Manager or temporary credentials.
Parameter dbUser :
The database user name. This parameter is required when connecting to a
cluster as a database user and authenticating using temporary credentials.
Parameter parameters :
The parameters for the SQL statement.
Parameter resultFormat :
The data format of the result of the SQL statement. If no format is
specified, the default is JSON.
Parameter secretArn :
The name or ARN of the secret that enables access to the database. This
parameter is required when authenticating using Secrets Manager.
Parameter sessionId :
The session identifier of the query.
Parameter sessionKeepAliveSeconds :
The number of seconds to keep the session alive after the query finishes.
The maximum time a session can keep alive is 24 hours. After 24 hours, the
session is forced closed and the query is terminated.
Parameter statementName :
The name of the SQL statement. You can name the SQL statement when you
create it to identify the query.
Parameter withEvent :
A value that indicates whether to send an event to the Amazon EventBridge
event bus after the SQL statement runs.
Parameter workgroupName :
The serverless workgroup name or Amazon Resource Name (ARN). This
parameter is required when connecting to a serverless workgroup and
authenticating using either Secrets Manager or temporary credentials.
Implementation
Future<ExecuteStatementOutput> executeStatement({
required String sql,
String? clientToken,
String? clusterIdentifier,
String? database,
String? dbUser,
List<SqlParameter>? parameters,
ResultFormatString? resultFormat,
String? secretArn,
String? sessionId,
int? sessionKeepAliveSeconds,
String? statementName,
bool? withEvent,
String? workgroupName,
}) async {
_s.validateNumRange(
'sessionKeepAliveSeconds',
sessionKeepAliveSeconds,
0,
86400,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftData.ExecuteStatement'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Sql': sql,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
if (database != null) 'Database': database,
if (dbUser != null) 'DbUser': dbUser,
if (parameters != null) 'Parameters': parameters,
if (resultFormat != null) 'ResultFormat': resultFormat.value,
if (secretArn != null) 'SecretArn': secretArn,
if (sessionId != null) 'SessionId': sessionId,
if (sessionKeepAliveSeconds != null)
'SessionKeepAliveSeconds': sessionKeepAliveSeconds,
if (statementName != null) 'StatementName': statementName,
if (withEvent != null) 'WithEvent': withEvent,
if (workgroupName != null) 'WorkgroupName': workgroupName,
},
);
return ExecuteStatementOutput.fromJson(jsonResponse.body);
}