listTables method
List the tables in a database. If neither SchemaPattern nor
TablePattern are specified, then all tables in the database
are returned. A token is returned to page through the table list.
Depending on the authorization method, use one of the following
combinations of request parameters:
-
Secrets Manager - when connecting to a cluster, provide the
secret-arnof a secret stored in Secrets Manager which hasusernameandpassword. The specified secret contains credentials to connect to thedatabaseyou specify. When you are connecting to a cluster, you also supply the database name, If you provide a cluster identifier (dbClusterIdentifier), it must match the cluster identifier stored in the secret. When you are connecting to a serverless workgroup, you also supply the database name. -
Temporary credentials - when connecting to your data warehouse, choose one
of the following options:
-
When connecting to a serverless workgroup, specify the workgroup name and
database name. The database user name is derived from the IAM identity.
For example,
arn:iam::123456789012:user:foohas the database user nameIAM:foo. Also, permission to call theredshift-serverless:GetCredentialsoperation is required. -
When connecting to a cluster as an IAM identity, specify the cluster
identifier and the database name. The database user name is derived from
the IAM identity. For example,
arn:iam::123456789012:user:foohas the database user nameIAM:foo. Also, permission to call theredshift:GetClusterCredentialsWithIAMoperation is required. -
When connecting to a cluster as a database user, specify the cluster
identifier, the database name, and the database user name. Also,
permission to call the
redshift:GetClusterCredentialsoperation is required.
-
When connecting to a serverless workgroup, specify the workgroup name and
database name. The database user name is derived from the IAM identity.
For example,
May throw DatabaseConnectionException.
May throw InternalServerException.
May throw QueryTimeoutException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter database :
The name of the database that contains the tables to list. If
ConnectedDatabase is not specified, this is also the database
to connect to with your authentication credentials.
Parameter clusterIdentifier :
The cluster identifier. This parameter is required when connecting to a
cluster and authenticating using either Secrets Manager or temporary
credentials.
Parameter connectedDatabase :
A database name. The connected database is specified when you connect with
your authentication credentials.
Parameter dbUser :
The database user name. This parameter is required when connecting to a
cluster as a database user and authenticating using temporary credentials.
Parameter maxResults :
The maximum number of tables to return in the response. If more tables
exist than fit in one response, then NextToken is returned to
page through the results.
Parameter nextToken :
A value that indicates the starting point for the next set of response
records in a subsequent request. If a value is returned in a response, you
can retrieve the next set of records by providing this returned NextToken
value in the next NextToken parameter and retrying the command. If the
NextToken field is empty, all response records have been retrieved for the
request.
Parameter schemaPattern :
A pattern to filter results by schema name. Within a schema pattern, "%"
means match any substring of 0 or more characters and "_" means match any
one character. Only schema name entries matching the search pattern are
returned. If SchemaPattern is not specified, then all tables
that match TablePattern are returned. If neither
SchemaPattern or TablePattern are specified,
then all tables are returned.
Parameter secretArn :
The name or ARN of the secret that enables access to the database. This
parameter is required when authenticating using Secrets Manager.
Parameter tablePattern :
A pattern to filter results by table name. Within a table pattern, "%"
means match any substring of 0 or more characters and "_" means match any
one character. Only table name entries matching the search pattern are
returned. If TablePattern is not specified, then all tables
that match SchemaPatternare returned. If neither
SchemaPattern or TablePattern are specified,
then all tables are returned.
Parameter workgroupName :
The serverless workgroup name or Amazon Resource Name (ARN). This
parameter is required when connecting to a serverless workgroup and
authenticating using either Secrets Manager or temporary credentials.
Implementation
Future<ListTablesResponse> listTables({
required String database,
String? clusterIdentifier,
String? connectedDatabase,
String? dbUser,
int? maxResults,
String? nextToken,
String? schemaPattern,
String? secretArn,
String? tablePattern,
String? workgroupName,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftData.ListTables'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Database': database,
if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
if (connectedDatabase != null) 'ConnectedDatabase': connectedDatabase,
if (dbUser != null) 'DbUser': dbUser,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (schemaPattern != null) 'SchemaPattern': schemaPattern,
if (secretArn != null) 'SecretArn': secretArn,
if (tablePattern != null) 'TablePattern': tablePattern,
if (workgroupName != null) 'WorkgroupName': workgroupName,
},
);
return ListTablesResponse.fromJson(jsonResponse.body);
}