RedshiftServerless class

This is an interface reference for Amazon Redshift Serverless. It contains documentation for one of the programming or command line interfaces you can use to manage Amazon Redshift Serverless.

Amazon Redshift Serverless automatically provisions data warehouse capacity and intelligently scales the underlying resources based on workload demands. Amazon Redshift Serverless adjusts capacity in seconds to deliver consistently high performance and simplified operations for even the most demanding and volatile workloads. Amazon Redshift Serverless lets you focus on using your data to acquire new insights for your business and customers.

To learn more about Amazon Redshift Serverless, see What is Amazon Redshift Serverless?.

Constructors

RedshiftServerless({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
convertRecoveryPointToSnapshot({required String recoveryPointId, required String snapshotName, int? retentionPeriod, List<Tag>? tags}) Future<ConvertRecoveryPointToSnapshotResponse>
Converts a recovery point to a snapshot. For more information about recovery points and snapshots, see Working with snapshots and recovery points.
createCustomDomainAssociation({required String customDomainCertificateArn, required String customDomainName, required String workgroupName}) Future<CreateCustomDomainAssociationResponse>
Creates a custom domain association for Amazon Redshift Serverless.
createEndpointAccess({required String endpointName, required List<String> subnetIds, required String workgroupName, String? ownerAccount, List<String>? vpcSecurityGroupIds}) Future<CreateEndpointAccessResponse>
Creates an Amazon Redshift Serverless managed VPC endpoint.
createNamespace({required String namespaceName, String? adminPasswordSecretKmsKeyId, String? adminUserPassword, String? adminUsername, String? dbName, String? defaultIamRoleArn, List<String>? iamRoles, String? kmsKeyId, List<LogExport>? logExports, bool? manageAdminPassword, String? redshiftIdcApplicationArn, List<Tag>? tags}) Future<CreateNamespaceResponse>
Creates a namespace in Amazon Redshift Serverless.
createReservation({required int capacity, required String offeringId, String? clientToken}) Future<CreateReservationResponse>
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
createScheduledAction({required String namespaceName, required String roleArn, required Schedule schedule, required String scheduledActionName, required TargetAction targetAction, bool? enabled, DateTime? endTime, String? scheduledActionDescription, DateTime? startTime}) Future<CreateScheduledActionResponse>
Creates a scheduled action. A scheduled action contains a schedule and an Amazon Redshift API action. For example, you can create a schedule of when to run the CreateSnapshot API operation.
createSnapshot({required String namespaceName, required String snapshotName, int? retentionPeriod, List<Tag>? tags}) Future<CreateSnapshotResponse>
Creates a snapshot of all databases in a namespace. For more information about snapshots, see Working with snapshots and recovery points.
createSnapshotCopyConfiguration({required String destinationRegion, required String namespaceName, String? destinationKmsKeyId, int? snapshotRetentionPeriod}) Future<CreateSnapshotCopyConfigurationResponse>
Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region.
createUsageLimit({required int amount, required String resourceArn, required UsageLimitUsageType usageType, UsageLimitBreachAction? breachAction, UsageLimitPeriod? period}) Future<CreateUsageLimitResponse>
Creates a usage limit for a specified Amazon Redshift Serverless usage type. The usage limit is identified by the returned usage limit identifier.
createWorkgroup({required String namespaceName, required String workgroupName, int? baseCapacity, List<ConfigParameter>? configParameters, bool? enhancedVpcRouting, bool? extraComputeForAutomaticOptimization, String? ipAddressType, int? maxCapacity, int? port, PerformanceTarget? pricePerformanceTarget, bool? publiclyAccessible, List<String>? securityGroupIds, List<String>? subnetIds, List<Tag>? tags, String? trackName}) Future<CreateWorkgroupResponse>
Creates an workgroup in Amazon Redshift Serverless.
deleteCustomDomainAssociation({required String customDomainName, required String workgroupName}) Future<void>
Deletes a custom domain association for Amazon Redshift Serverless.
deleteEndpointAccess({required String endpointName}) Future<DeleteEndpointAccessResponse>
Deletes an Amazon Redshift Serverless managed VPC endpoint.
deleteNamespace({required String namespaceName, String? finalSnapshotName, int? finalSnapshotRetentionPeriod}) Future<DeleteNamespaceResponse>
Deletes a namespace from Amazon Redshift Serverless. Before you delete the namespace, you can create a final snapshot that has all of the data within the namespace.
deleteResourcePolicy({required String resourceArn}) Future<void>
Deletes the specified resource policy.
deleteScheduledAction({required String scheduledActionName}) Future<DeleteScheduledActionResponse>
Deletes a scheduled action.
deleteSnapshot({required String snapshotName}) Future<DeleteSnapshotResponse>
Deletes a snapshot from Amazon Redshift Serverless.
deleteSnapshotCopyConfiguration({required String snapshotCopyConfigurationId}) Future<DeleteSnapshotCopyConfigurationResponse>
Deletes a snapshot copy configuration
deleteUsageLimit({required String usageLimitId}) Future<DeleteUsageLimitResponse>
Deletes a usage limit from Amazon Redshift Serverless.
deleteWorkgroup({required String workgroupName}) Future<DeleteWorkgroupResponse>
Deletes a workgroup.
getCredentials({String? customDomainName, String? dbName, int? durationSeconds, String? workgroupName}) Future<GetCredentialsResponse>
Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless.
getCustomDomainAssociation({required String customDomainName, required String workgroupName}) Future<GetCustomDomainAssociationResponse>
Gets information about a specific custom domain association.
getEndpointAccess({required String endpointName}) Future<GetEndpointAccessResponse>
Returns information, such as the name, about a VPC endpoint.
getIdentityCenterAuthToken({required List<String> workgroupNames}) Future<GetIdentityCenterAuthTokenResponse>
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
getNamespace({required String namespaceName}) Future<GetNamespaceResponse>
Returns information about a namespace in Amazon Redshift Serverless.
getRecoveryPoint({required String recoveryPointId}) Future<GetRecoveryPointResponse>
Returns information about a recovery point.
getReservation({required String reservationId}) Future<GetReservationResponse>
Gets an Amazon Redshift Serverless reservation. A reservation gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
getReservationOffering({required String offeringId}) Future<GetReservationOfferingResponse>
Returns the reservation offering. The offering determines the payment schedule for the reservation.
getResourcePolicy({required String resourceArn}) Future<GetResourcePolicyResponse>
Returns a resource policy.
getScheduledAction({required String scheduledActionName}) Future<GetScheduledActionResponse>
Returns information about a scheduled action.
getSnapshot({String? ownerAccount, String? snapshotArn, String? snapshotName}) Future<GetSnapshotResponse>
Returns information about a specific snapshot.
getTableRestoreStatus({required String tableRestoreRequestId}) Future<GetTableRestoreStatusResponse>
Returns information about a TableRestoreStatus object.
getTrack({required String trackName}) Future<GetTrackResponse>
Get the Redshift Serverless version for a specified track.
getUsageLimit({required String usageLimitId}) Future<GetUsageLimitResponse>
Returns information about a usage limit.
getWorkgroup({required String workgroupName}) Future<GetWorkgroupResponse>
Returns information about a specific workgroup.
listCustomDomainAssociations({String? customDomainCertificateArn, String? customDomainName, int? maxResults, String? nextToken}) Future<ListCustomDomainAssociationsResponse>
Lists custom domain associations for Amazon Redshift Serverless.
listEndpointAccess({int? maxResults, String? nextToken, String? ownerAccount, String? vpcId, String? workgroupName}) Future<ListEndpointAccessResponse>
Returns an array of EndpointAccess objects and relevant information.
listManagedWorkgroups({int? maxResults, String? nextToken, String? sourceArn}) Future<ListManagedWorkgroupsResponse>
Returns information about a list of specified managed workgroups in your account.
listNamespaces({int? maxResults, String? nextToken}) Future<ListNamespacesResponse>
Returns information about a list of specified namespaces.
listRecoveryPoints({DateTime? endTime, int? maxResults, String? namespaceArn, String? namespaceName, String? nextToken, DateTime? startTime}) Future<ListRecoveryPointsResponse>
Returns an array of recovery points.
listReservationOfferings({int? maxResults, String? nextToken}) Future<ListReservationOfferingsResponse>
Returns the current reservation offerings in your account.
listReservations({int? maxResults, String? nextToken}) Future<ListReservationsResponse>
Returns a list of Reservation objects.
listScheduledActions({int? maxResults, String? namespaceName, String? nextToken}) Future<ListScheduledActionsResponse>
Returns a list of scheduled actions. You can use the flags to filter the list of returned scheduled actions.
listSnapshotCopyConfigurations({int? maxResults, String? namespaceName, String? nextToken}) Future<ListSnapshotCopyConfigurationsResponse>
Returns a list of snapshot copy configurations.
listSnapshots({DateTime? endTime, int? maxResults, String? namespaceArn, String? namespaceName, String? nextToken, String? ownerAccount, DateTime? startTime}) Future<ListSnapshotsResponse>
Returns a list of snapshots.
listTableRestoreStatus({int? maxResults, String? namespaceName, String? nextToken, String? workgroupName}) Future<ListTableRestoreStatusResponse>
Returns information about an array of TableRestoreStatus objects.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags assigned to a resource.
listTracks({int? maxResults, String? nextToken}) Future<ListTracksResponse>
List the Amazon Redshift Serverless versions.
listUsageLimits({int? maxResults, String? nextToken, String? resourceArn, UsageLimitUsageType? usageType}) Future<ListUsageLimitsResponse>
Lists all usage limits within Amazon Redshift Serverless.
listWorkgroups({int? maxResults, String? nextToken, String? ownerAccount}) Future<ListWorkgroupsResponse>
Returns information about a list of specified workgroups.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String policy, required String resourceArn}) Future<PutResourcePolicyResponse>
Creates or updates a resource policy. Currently, you can use policies to share snapshots across Amazon Web Services accounts.
restoreFromRecoveryPoint({required String namespaceName, required String recoveryPointId, required String workgroupName}) Future<RestoreFromRecoveryPointResponse>
Restore the data from a recovery point.
restoreFromSnapshot({required String namespaceName, required String workgroupName, String? adminPasswordSecretKmsKeyId, bool? manageAdminPassword, String? ownerAccount, String? snapshotArn, String? snapshotName}) Future<RestoreFromSnapshotResponse>
Restores a namespace from a snapshot.
restoreTableFromRecoveryPoint({required String namespaceName, required String newTableName, required String recoveryPointId, required String sourceDatabaseName, required String sourceTableName, required String workgroupName, bool? activateCaseSensitiveIdentifier, String? sourceSchemaName, String? targetDatabaseName, String? targetSchemaName}) Future<RestoreTableFromRecoveryPointResponse>
Restores a table from a recovery point to your Amazon Redshift Serverless instance. You can't use this operation to restore tables with interleaved sort keys.
restoreTableFromSnapshot({required String namespaceName, required String newTableName, required String snapshotName, required String sourceDatabaseName, required String sourceTableName, required String workgroupName, bool? activateCaseSensitiveIdentifier, String? sourceSchemaName, String? targetDatabaseName, String? targetSchemaName}) Future<RestoreTableFromSnapshotResponse>
Restores a table from a snapshot to your Amazon Redshift Serverless instance. You can't use this operation to restore tables with interleaved sort keys.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Assigns one or more tags to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag or set of tags from a resource.
updateCustomDomainAssociation({required String customDomainCertificateArn, required String customDomainName, required String workgroupName}) Future<UpdateCustomDomainAssociationResponse>
Updates an Amazon Redshift Serverless certificate associated with a custom domain.
updateEndpointAccess({required String endpointName, List<String>? vpcSecurityGroupIds}) Future<UpdateEndpointAccessResponse>
Updates an Amazon Redshift Serverless managed endpoint.
updateLakehouseConfiguration({required String namespaceName, String? catalogName, bool? dryRun, String? lakehouseIdcApplicationArn, LakehouseIdcRegistration? lakehouseIdcRegistration, LakehouseRegistration? lakehouseRegistration}) Future<UpdateLakehouseConfigurationResponse>
Modifies the lakehouse configuration for a namespace. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
updateNamespace({required String namespaceName, String? adminPasswordSecretKmsKeyId, String? adminUserPassword, String? adminUsername, String? defaultIamRoleArn, List<String>? iamRoles, String? kmsKeyId, List<LogExport>? logExports, bool? manageAdminPassword}) Future<UpdateNamespaceResponse>
Updates a namespace with the specified settings. Unless required, you can't update multiple parameters in one request. For example, you must specify both adminUsername and adminUserPassword to update either field, but you can't update both kmsKeyId and logExports in a single request.
updateScheduledAction({required String scheduledActionName, bool? enabled, DateTime? endTime, String? roleArn, Schedule? schedule, String? scheduledActionDescription, DateTime? startTime, TargetAction? targetAction}) Future<UpdateScheduledActionResponse>
Updates a scheduled action.
updateSnapshot({required String snapshotName, int? retentionPeriod}) Future<UpdateSnapshotResponse>
Updates a snapshot.
updateSnapshotCopyConfiguration({required String snapshotCopyConfigurationId, int? snapshotRetentionPeriod}) Future<UpdateSnapshotCopyConfigurationResponse>
Updates a snapshot copy configuration.
updateUsageLimit({required String usageLimitId, int? amount, UsageLimitBreachAction? breachAction}) Future<UpdateUsageLimitResponse>
Update a usage limit in Amazon Redshift Serverless. You can't update the usage type or period of a usage limit.
updateWorkgroup({required String workgroupName, int? baseCapacity, List<ConfigParameter>? configParameters, bool? enhancedVpcRouting, bool? extraComputeForAutomaticOptimization, String? ipAddressType, int? maxCapacity, int? port, PerformanceTarget? pricePerformanceTarget, bool? publiclyAccessible, List<String>? securityGroupIds, List<String>? subnetIds, String? trackName}) Future<UpdateWorkgroupResponse>
Updates a workgroup with the specified configuration settings. You can't update multiple parameters in one request. For example, you can update baseCapacity or port in a single request, but you can't update both in the same request.

Operators

operator ==(Object other) bool
The equality operator.
inherited