createCustomDomainAssociation method
Creates a custom domain association for Amazon Redshift Serverless.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter customDomainCertificateArn :
The custom domain name’s certificate Amazon resource name (ARN).
Parameter customDomainName :
The custom domain name to associate with the workgroup.
Parameter workgroupName :
The name of the workgroup associated with the database.
Implementation
Future<CreateCustomDomainAssociationResponse> createCustomDomainAssociation({
required String customDomainCertificateArn,
required String customDomainName,
required String workgroupName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftServerless.CreateCustomDomainAssociation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'customDomainCertificateArn': customDomainCertificateArn,
'customDomainName': customDomainName,
'workgroupName': workgroupName,
},
);
return CreateCustomDomainAssociationResponse.fromJson(jsonResponse.body);
}