deleteCustomDomainAssociation method

Future<void> deleteCustomDomainAssociation({
  1. required String customDomainName,
  2. required String workgroupName,
})

Deletes a custom domain association for Amazon Redshift Serverless.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter customDomainName : The custom domain name associated with the workgroup.

Parameter workgroupName : The name of the workgroup associated with the database.

Implementation

Future<void> deleteCustomDomainAssociation({
  required String customDomainName,
  required String workgroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RedshiftServerless.DeleteCustomDomainAssociation'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'customDomainName': customDomainName,
      'workgroupName': workgroupName,
    },
  );
}