listCustomDomainAssociations method

Future<ListCustomDomainAssociationsResponse> listCustomDomainAssociations({
  1. String? customDomainCertificateArn,
  2. String? customDomainName,
  3. int? maxResults,
  4. String? nextToken,
})

Lists custom domain associations for Amazon Redshift Serverless.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidPaginationException. May throw ThrottlingException. May throw ValidationException.

Parameter customDomainCertificateArn : The custom domain name’s certificate Amazon resource name (ARN).

Parameter customDomainName : The custom domain name associated with the workgroup.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.

Parameter nextToken : When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.

Implementation

Future<ListCustomDomainAssociationsResponse> listCustomDomainAssociations({
  String? customDomainCertificateArn,
  String? customDomainName,
  int? maxResults,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RedshiftServerless.ListCustomDomainAssociations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (customDomainCertificateArn != null)
        'customDomainCertificateArn': customDomainCertificateArn,
      if (customDomainName != null) 'customDomainName': customDomainName,
      if (maxResults != null) 'maxResults': maxResults,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListCustomDomainAssociationsResponse.fromJson(jsonResponse.body);
}