listScheduledActions method

Future<ListScheduledActionsResponse> listScheduledActions({
  1. int? maxResults,
  2. String? namespaceName,
  3. String? nextToken,
})

Returns a list of scheduled actions. You can use the flags to filter the list of returned scheduled actions.

May throw InternalServerException. May throw InvalidPaginationException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. Use nextToken to display the next page of results.

Parameter namespaceName : The name of namespace associated with the scheduled action to retrieve.

Parameter nextToken : If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.

Implementation

Future<ListScheduledActionsResponse> listScheduledActions({
  int? maxResults,
  String? namespaceName,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RedshiftServerless.ListScheduledActions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'maxResults': maxResults,
      if (namespaceName != null) 'namespaceName': namespaceName,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListScheduledActionsResponse.fromJson(jsonResponse.body);
}