listSnapshotCopyConfigurations method

Future<ListSnapshotCopyConfigurationsResponse> listSnapshotCopyConfigurations({
  1. int? maxResults,
  2. String? namespaceName,
  3. String? nextToken,
})

Returns a list of snapshot copy configurations.

May throw ConflictException. May throw InternalServerException. May throw InvalidPaginationException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter maxResults : An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.

Parameter namespaceName : The namespace from which to list all snapshot copy configurations.

Parameter nextToken : If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.

Implementation

Future<ListSnapshotCopyConfigurationsResponse>
    listSnapshotCopyConfigurations({
  int? maxResults,
  String? namespaceName,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RedshiftServerless.ListSnapshotCopyConfigurations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'maxResults': maxResults,
      if (namespaceName != null) 'namespaceName': namespaceName,
      if (nextToken != null) 'nextToken': nextToken,
    },
  );

  return ListSnapshotCopyConfigurationsResponse.fromJson(jsonResponse.body);
}