updateCustomDomainAssociation method

Future<UpdateCustomDomainAssociationResponse> updateCustomDomainAssociation({
  1. required String customDomainCertificateArn,
  2. required String customDomainName,
  3. required String workgroupName,
})

Updates an Amazon Redshift Serverless certificate associated with a custom domain.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter customDomainCertificateArn : The custom domain name’s certificate Amazon resource name (ARN). This is optional.

Parameter customDomainName : The custom domain name associated with the workgroup.

Parameter workgroupName : The name of the workgroup associated with the database.

Implementation

Future<UpdateCustomDomainAssociationResponse> updateCustomDomainAssociation({
  required String customDomainCertificateArn,
  required String customDomainName,
  required String workgroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RedshiftServerless.UpdateCustomDomainAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'customDomainCertificateArn': customDomainCertificateArn,
      'customDomainName': customDomainName,
      'workgroupName': workgroupName,
    },
  );

  return UpdateCustomDomainAssociationResponse.fromJson(jsonResponse.body);
}