copyProjectVersion method

Future<CopyProjectVersionResponse> copyProjectVersion({
  1. required String destinationProjectArn,
  2. required OutputConfig outputConfig,
  3. required String sourceProjectArn,
  4. required String sourceProjectVersionArn,
  5. required String versionName,
  6. String? kmsKeyId,
  7. Map<String, String>? tags,
})
Copies a version of an Amazon Rekognition Custom Labels model from a source project to a destination project. The source and destination projects can be in different AWS accounts but must be in the same AWS Region. You can't copy a model to another AWS service.

To copy a model version to a different AWS account, you need to create a resource-based policy known as a project policy. You attach the project policy to the source project by calling PutProjectPolicy. The project policy gives permission to copy the model version from a trusting AWS account to a trusted account.

For more information creating and attaching a project policy, see Attaching a project policy (SDK) in the Amazon Rekognition Custom Labels Developer Guide.

If you are copying a model version to a project in the same AWS account, you don't need to create a project policy.

To copy a model, the destination project, source project, and source model version must already exist. Copying a model version takes a while to complete. To get the current status, call DescribeProjectVersions and check the value of Status in the ProjectVersionDescription object. The copy operation has finished when the value of Status is COPYING_COMPLETED.

This operation requires permissions to perform the rekognition:CopyProjectVersion action.

May throw AccessDeniedException. May throw InternalServerError. May throw InvalidParameterException. May throw LimitExceededException. May throw ProvisionedThroughputExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException.

Parameter destinationProjectArn : The ARN of the project in the trusted AWS account that you want to copy the model version to.

Parameter outputConfig : The S3 bucket and folder location where the training output for the source model version is placed.

Parameter sourceProjectArn : The ARN of the source project in the trusting AWS account.

Parameter sourceProjectVersionArn : The ARN of the model version in the source project that you want to copy to a destination project.

Parameter versionName : A name for the version of the model that's copied to the destination project.

Parameter kmsKeyId : The identifier for your AWS Key Management Service key (AWS KMS key). You can supply the Amazon Resource Name (ARN) of your KMS key, the ID of your KMS key, an alias for your KMS key, or an alias ARN. The key is used to encrypt training results and manifest files written to the output Amazon S3 bucket (OutputConfig).

If you choose to use your own KMS key, you need the following permissions on the KMS key.

  • kms:CreateGrant
  • kms:DescribeKey
  • kms:GenerateDataKey
  • kms:Decrypt
If you don't specify a value for KmsKeyId, images copied into the service are encrypted using a key that AWS owns and manages.

Parameter tags : The key-value tags to assign to the model version.

Implementation

Future<CopyProjectVersionResponse> copyProjectVersion({
  required String destinationProjectArn,
  required OutputConfig outputConfig,
  required String sourceProjectArn,
  required String sourceProjectVersionArn,
  required String versionName,
  String? kmsKeyId,
  Map<String, String>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RekognitionService.CopyProjectVersion'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DestinationProjectArn': destinationProjectArn,
      'OutputConfig': outputConfig,
      'SourceProjectArn': sourceProjectArn,
      'SourceProjectVersionArn': sourceProjectVersionArn,
      'VersionName': versionName,
      if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
      if (tags != null) 'Tags': tags,
    },
  );

  return CopyProjectVersionResponse.fromJson(jsonResponse.body);
}