createStreamProcessor method
- required StreamProcessorInput input,
- required String name,
- required StreamProcessorOutput output,
- required String roleArn,
- required StreamProcessorSettings settings,
- StreamProcessorDataSharingPreference? dataSharingPreference,
- String? kmsKeyId,
- StreamProcessorNotificationChannel? notificationChannel,
- List<
RegionOfInterest> ? regionsOfInterest, - Map<
String, String> ? tags,
Creates an Amazon Rekognition stream processor that you can use to detect and recognize faces or to detect labels in a streaming video.
Amazon Rekognition Video is a consumer of live video from Amazon Kinesis Video Streams. There are two different settings for stream processors in Amazon Rekognition: detecting faces and detecting labels.
-
If you are creating a stream processor for detecting faces, you provide as
input a Kinesis video stream (
Input) and a Kinesis data stream (Output) stream for receiving the output. You must use theFaceSearchoption inSettings, specifying the collection that contains the faces you want to recognize. After you have finished analyzing a streaming video, use StopStreamProcessor to stop processing. -
If you are creating a stream processor to detect labels, you provide as
input a Kinesis video stream (
Input), Amazon S3 bucket information (Output), and an Amazon SNS topic ARN (NotificationChannel). You can also provide a KMS key ID to encrypt the data sent to your Amazon S3 bucket. You specify what you want to detect by using theConnectedHomeoption in settings, and selecting one of the following:PERSON,PET,PACKAGE,ALLYou can also specify where in the frame you want Amazon Rekognition to monitor withRegionsOfInterest. When you run the StartStreamProcessor operation on a label detection stream processor, you input start and stop information to determine the length of the processing time.
Name to assign an identifier for the stream processor.
You use Name to manage the stream processor. For example, you
can start processing the source video by calling
StartStreamProcessor with the Name field.
This operation requires permissions to perform the
rekognition:CreateStreamProcessor action. If you want to tag
your stream processor, you also require permission to perform the
rekognition:TagResource operation.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ProvisionedThroughputExceededException.
May throw ResourceInUseException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter input :
Kinesis video stream stream that provides the source streaming video. If
you are using the AWS CLI, the parameter name is
StreamProcessorInput. This is required for both face search
and label detection stream processors.
Parameter name :
An identifier you assign to the stream processor. You can use
Name to manage the stream processor. For example, you can get
the current status of the stream processor by calling
DescribeStreamProcessor. Name is idempotent. This is
required for both face search and label detection stream processors.
Parameter output :
Kinesis data stream stream or Amazon S3 bucket location to which Amazon
Rekognition Video puts the analysis results. If you are using the AWS CLI,
the parameter name is StreamProcessorOutput. This must be a
S3Destination of an Amazon S3 bucket that you own for a label
detection stream processor or a Kinesis data stream ARN for a face search
stream processor.
Parameter roleArn :
The Amazon Resource Number (ARN) of the IAM role that allows access to the
stream processor. The IAM role provides Rekognition read permissions for a
Kinesis stream. It also provides write permissions to an Amazon S3 bucket
and Amazon Simple Notification Service topic for a label detection stream
processor. This is required for both face search and label detection
stream processors.
Parameter settings :
Input parameters used in a streaming video analyzed by a stream processor.
You can use FaceSearch to recognize faces in a streaming
video, or you can use ConnectedHome to detect labels.
Parameter dataSharingPreference :
Shows whether you are sharing data with Rekognition to improve model
performance. You can choose this option at the account level or on a
per-stream basis. Note that if you opt out at the account level this
setting is ignored on individual streams.
Parameter kmsKeyId :
The identifier for your AWS Key Management Service key (AWS KMS key). This
is an optional parameter for label detection stream processors and should
not be used to create a face search stream processor. You can supply the
Amazon Resource Name (ARN) of your KMS key, the ID of your KMS key, an
alias for your KMS key, or an alias ARN. The key is used to encrypt
results and data published to your Amazon S3 bucket, which includes image
frames and hero images. Your source images are unaffected.
Parameter regionsOfInterest :
Specifies locations in the frames where Amazon Rekognition checks for
objects or people. You can specify up to 10 regions of interest, and each
region has either a polygon or a bounding box. This is an optional
parameter for label detection stream processors and should not be used to
create a face search stream processor.
Parameter tags :
A set of tags (key-value pairs) that you want to attach to the stream
processor.
Implementation
Future<CreateStreamProcessorResponse> createStreamProcessor({
required StreamProcessorInput input,
required String name,
required StreamProcessorOutput output,
required String roleArn,
required StreamProcessorSettings settings,
StreamProcessorDataSharingPreference? dataSharingPreference,
String? kmsKeyId,
StreamProcessorNotificationChannel? notificationChannel,
List<RegionOfInterest>? regionsOfInterest,
Map<String, String>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.CreateStreamProcessor'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Input': input,
'Name': name,
'Output': output,
'RoleArn': roleArn,
'Settings': settings,
if (dataSharingPreference != null)
'DataSharingPreference': dataSharingPreference,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (notificationChannel != null)
'NotificationChannel': notificationChannel,
if (regionsOfInterest != null) 'RegionsOfInterest': regionsOfInterest,
if (tags != null) 'Tags': tags,
},
);
return CreateStreamProcessorResponse.fromJson(jsonResponse.body);
}