deleteStreamProcessor method
Deletes the stream processor identified by Name. You assign
the value for Name when you create the stream processor with
CreateStreamProcessor. You might not be able to use the same name
for a stream processor for a few seconds after calling
DeleteStreamProcessor.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter name :
The name of the stream processor you want to delete.
Implementation
Future<void> deleteStreamProcessor({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.DeleteStreamProcessor'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
}