detectCustomLabels method
You specify which version of a model version to use by using the
ProjectVersionArn input parameter.
You pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.
For each object that the model version detects on an image, the API
returns a (CustomLabel) object in an array
(CustomLabels). Each CustomLabel object provides
the label name (Name), the level of confidence that the image
contains the object (Confidence), and object location
information, if it exists, for the label on the image
(Geometry).
To filter labels that are returned, specify a value for
MinConfidence. DetectCustomLabelsLabels only
returns labels with a confidence that's higher than the specified value.
The value of MinConfidence maps to the assumed threshold
values created during training. For more information, see Assumed
threshold in the Amazon Rekognition Custom Labels Developer Guide.
Amazon Rekognition Custom Labels metrics expresses an assumed threshold as
a floating point value between 0-1. The range of
MinConfidence normalizes the threshold value to a percentage
value (0-100). Confidence responses from DetectCustomLabels
are also returned as a percentage. You can use MinConfidence
to change the precision and recall or your model. For more information,
see Analyzing an image in the Amazon Rekognition Custom Labels
Developer Guide.
If you don't specify a value for MinConfidence,
DetectCustomLabels returns labels based on the assumed
threshold of each label.
This is a stateless API operation. That is, the operation does not persist any data.
This operation requires permissions to perform the
rekognition:DetectCustomLabels action.
For more information, see Analyzing an image in the Amazon Rekognition Custom Labels Developer Guide.
May throw AccessDeniedException.
May throw ImageTooLargeException.
May throw InternalServerError.
May throw InvalidImageFormatException.
May throw InvalidParameterException.
May throw InvalidS3ObjectException.
May throw LimitExceededException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ResourceNotReadyException.
May throw ThrottlingException.
Parameter projectVersionArn :
The ARN of the model version that you want to use. Only models associated
with Custom Labels projects accepted by the operation. If a provided ARN
refers to a model version associated with a project for a different
feature type, then an InvalidParameterException is returned.
Parameter maxResults :
Maximum number of results you want the service to return in the response.
The service returns the specified number of highest confidence labels
ranked from highest confidence to lowest.
Parameter minConfidence :
Specifies the minimum confidence level for the labels to return.
DetectCustomLabels doesn't return any labels with a
confidence value that's lower than this specified value. If you specify a
value of 0, DetectCustomLabels returns all labels, regardless
of the assumed threshold applied to each label. If you don't specify a
value for MinConfidence, DetectCustomLabels
returns labels based on the assumed threshold of each label.
Implementation
Future<DetectCustomLabelsResponse> detectCustomLabels({
required Image image,
required String projectVersionArn,
int? maxResults,
double? minConfidence,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1152921504606846976,
);
_s.validateNumRange(
'minConfidence',
minConfidence,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.DetectCustomLabels'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Image': image,
'ProjectVersionArn': projectVersionArn,
if (maxResults != null) 'MaxResults': maxResults,
if (minConfidence != null) 'MinConfidence': minConfidence,
},
);
return DetectCustomLabelsResponse.fromJson(jsonResponse.body);
}