detectFaces method
Detects faces within an image that is provided as input.
DetectFaces detects the 100 largest faces in the image. For
each face detected, the operation returns face details. These details
include a bounding box of the face, a confidence value (that the bounding
box contains a face), and a fixed set of attributes such as facial
landmarks (for example, coordinates of eye and mouth), pose, presence of
facial occlusion, and so on.
The face-detection algorithm is most effective on frontal faces. For non-frontal or obscured faces, the algorithm might not detect the faces or might detect faces with lower confidence.
You pass the input image either as base64-encoded image bytes or as a
reference to an image in an Amazon S3 bucket. If you use the AWS CLI to
call Amazon Rekognition operations, passing image bytes is not supported.
The image must be either a PNG or JPEG formatted file.
This operation requires permissions to perform the
rekognition:DetectFaces action.
May throw AccessDeniedException.
May throw ImageTooLargeException.
May throw InternalServerError.
May throw InvalidImageFormatException.
May throw InvalidParameterException.
May throw InvalidS3ObjectException.
May throw ProvisionedThroughputExceededException.
May throw ThrottlingException.
Parameter image :
The input image as base64-encoded bytes or an S3 object. If you use the
AWS CLI to call Amazon Rekognition operations, passing base64-encoded
image bytes is not supported.
If you are using an AWS SDK to call Amazon Rekognition, you might not need
to base64-encode image bytes passed using the Bytes field.
For more information, see Images in the Amazon Rekognition developer
guide.
Parameter attributes :
An array of facial attributes you want to be returned. A
DEFAULT subset of facial attributes -
BoundingBox, Confidence, Pose,
Quality, and Landmarks - will always be
returned. You can request for specific facial attributes (in addition to
the default list) - by using ["DEFAULT", "FACE_OCCLUDED"]
or just ["FACE_OCCLUDED"]. You can request for all facial
attributes by using ["ALL"]. Requesting more attributes may
increase response time.
If you provide both, ["ALL", "DEFAULT"], the service uses a
logical "AND" operator to determine which attributes to return (in this
case, all attributes).
Note that while the FaceOccluded and EyeDirection attributes are supported
when using DetectFaces, they aren't supported when analyzing
videos with StartFaceDetection and
GetFaceDetection.
Implementation
Future<DetectFacesResponse> detectFaces({
required Image image,
List<Attribute>? attributes,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.DetectFaces'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Image': image,
if (attributes != null)
'Attributes': attributes.map((e) => e.value).toList(),
},
);
return DetectFacesResponse.fromJson(jsonResponse.body);
}