detectLabels method
Detects instances of real-world entities within an image (JPEG or PNG) provided as input. This includes objects like flower, tree, and table; events like wedding, graduation, and birthday party; and concepts like landscape, evening, and nature.
For an example, see Analyzing images stored in an Amazon S3 bucket in the Amazon Rekognition Developer Guide.
You pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.
Optional Parameters
You can specify one or both of the GENERAL_LABELS and
IMAGE_PROPERTIES feature types when calling the DetectLabels
API. Including GENERAL_LABELS will ensure the response
includes the labels detected in the input image, while including
IMAGE_PROPERTIES will ensure the response includes
information about the image quality and color.
When using GENERAL_LABELS and/or
IMAGE_PROPERTIES you can provide filtering criteria to the
Settings parameter. You can filter with sets of individual labels or with
label categories. You can specify inclusive filters, exclusive filters, or
a combination of inclusive and exclusive filters. For more information on
filtering see Detecting
Labels in an Image.
When getting labels, you can specify MinConfidence to control
the confidence threshold for the labels returned. The default is 55%. You
can also add the MaxLabels parameter to limit the number of
labels returned. The default and upper limit is 1000 labels. These
arguments are only valid when supplying GENERAL_LABELS as a feature type.
Response Elements
For each object, scene, and concept the API returns one or more labels. The API returns the following types of information about labels:
- Name - The name of the detected label.
- Confidence - The level of confidence in the label assigned to a detected object.
- Parents - The ancestor labels for a detected label. DetectLabels returns a hierarchical taxonomy of detected labels. For example, a detected car might be assigned the label car. The label car has two parent labels: Vehicle (its parent) and Transportation (its grandparent). The response includes the all ancestors for a label, where every ancestor is a unique label. In the previous example, Car, Vehicle, and Transportation are returned as unique labels in the response.
- Aliases - Possible Aliases for the label.
- Categories - The label categories that the detected label belongs to.
- BoundingBox — Bounding boxes are described for all instances of detected common object labels, returned in an array of Instance objects. An Instance object contains a BoundingBox object, describing the location of the label on the input image. It also includes the confidence for the accuracy of the detected bounding box.
- Quality - Information about the Sharpness, Brightness, and Contrast of the input image, scored between 0 to 100. Image quality is returned for the entire image, as well as the background and the foreground.
- Dominant Color - An array of the dominant colors in the image.
- Foreground - Information about the sharpness, brightness, and dominant colors of the input image’s foreground.
- Background - Information about the sharpness, brightness, and dominant colors of the input image’s background.
{Name: lighthouse, Confidence: 98.4629}
{Name: rock,Confidence: 79.2097}
{Name: sea,Confidence: 75.061}
The list of labels can include multiple labels for the same object. For example, if the input image shows a flower (for example, a tulip), the operation might return the following three labels.
{Name: flower,Confidence: 99.0562}
{Name: plant,Confidence: 99.0562}
{Name: tulip,Confidence: 99.0562}
In this example, the detection algorithm more precisely identifies the flower as a tulip. This is a stateless API operation that doesn't return any data.
This operation requires permissions to perform the
rekognition:DetectLabels action.
May throw AccessDeniedException.
May throw ImageTooLargeException.
May throw InternalServerError.
May throw InvalidImageFormatException.
May throw InvalidParameterException.
May throw InvalidS3ObjectException.
May throw ProvisionedThroughputExceededException.
May throw ThrottlingException.
Parameter image :
The input image as base64-encoded bytes or an S3 object. If you use the
AWS CLI to call Amazon Rekognition operations, passing image bytes is not
supported. Images stored in an S3 Bucket do not need to be base64-encoded.
If you are using an AWS SDK to call Amazon Rekognition, you might not need
to base64-encode image bytes passed using the Bytes field.
For more information, see Images in the Amazon Rekognition developer
guide.
Parameter features :
A list of the types of analysis to perform. Specifying GENERAL_LABELS uses
the label detection feature, while specifying IMAGE_PROPERTIES returns
information regarding image color and quality. If no option is specified
GENERAL_LABELS is used by default.
Parameter maxLabels :
Maximum number of labels you want the service to return in the response.
The service returns the specified number of highest confidence labels.
Only valid when GENERAL_LABELS is specified as a feature type in the
Feature input parameter.
Parameter minConfidence :
Specifies the minimum confidence level for the labels to return. Amazon
Rekognition doesn't return any labels with confidence lower than this
specified value.
If MinConfidence is not specified, the operation returns
labels with a confidence values greater than or equal to 55 percent. Only
valid when GENERAL_LABELS is specified as a feature type in the Feature
input parameter.
Parameter settings :
A list of the filters to be applied to returned detected labels and image
properties. Specified filters can be inclusive, exclusive, or a
combination of both. Filters can be used for individual labels or label
categories. The exact label names or label categories must be supplied.
For a full list of labels and label categories, see Detecting
labels.
Implementation
Future<DetectLabelsResponse> detectLabels({
required Image image,
List<DetectLabelsFeatureName>? features,
int? maxLabels,
double? minConfidence,
DetectLabelsSettings? settings,
}) async {
_s.validateNumRange(
'maxLabels',
maxLabels,
0,
1152921504606846976,
);
_s.validateNumRange(
'minConfidence',
minConfidence,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.DetectLabels'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Image': image,
if (features != null) 'Features': features.map((e) => e.value).toList(),
if (maxLabels != null) 'MaxLabels': maxLabels,
if (minConfidence != null) 'MinConfidence': minConfidence,
if (settings != null) 'Settings': settings,
},
);
return DetectLabelsResponse.fromJson(jsonResponse.body);
}