getContentModeration method
Gets the inappropriate, unwanted, or offensive content analysis results for a Amazon Rekognition Video analysis started by StartContentModeration. For a list of moderation labels in Amazon Rekognition, see Using the image and video moderation APIs.
Amazon Rekognition Video inappropriate or offensive content detection in a
stored video is an asynchronous operation. You start analysis by calling
StartContentModeration which returns a job identifier
(JobId). When analysis finishes, Amazon Rekognition Video
publishes a completion status to the Amazon Simple Notification Service
topic registered in the initial call to
StartContentModeration. To get the results of the content
analysis, first check that the status value published to the Amazon SNS
topic is SUCCEEDED. If so, call
GetContentModeration and pass the job identifier
(JobId) from the initial call to
StartContentModeration.
For more information, see Working with Stored Videos in the Amazon Rekognition Devlopers Guide.
GetContentModeration returns detected inappropriate,
unwanted, or offensive content moderation labels, and the time they are
detected, in an array, ModerationLabels, of
ContentModerationDetection objects.
By default, the moderated labels are returned sorted by time, in
milliseconds from the start of the video. You can also sort them by
moderated label by specifying NAME for the
SortBy input parameter.
Since video analysis can return a large number of results, use the
MaxResults parameter to limit the number of labels returned
in a single call to GetContentModeration. If there are more
results than specified in MaxResults, the value of
NextToken in the operation response contains a pagination
token for getting the next set of results. To get the next page of
results, call GetContentModeration and populate the
NextToken request parameter with the value of
NextToken returned from the previous call to
GetContentModeration.
For more information, see moderating content in the Amazon Rekognition Developer Guide.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidPaginationTokenException.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter jobId :
The identifier for the inappropriate, unwanted, or offensive content
moderation job. Use JobId to identify the job in a subsequent
call to GetContentModeration.
Parameter aggregateBy :
Defines how to aggregate results of the StartContentModeration request.
Default aggregation option is TIMESTAMPS. SEGMENTS mode aggregates
moderation labels over time.
Parameter maxResults :
Maximum number of results to return per paginated call. The largest value
you can specify is 1000. If you specify a value greater than 1000, a
maximum of 1000 results is returned. The default value is 1000.
Parameter nextToken :
If the previous response was incomplete (because there is more data to
retrieve), Amazon Rekognition returns a pagination token in the response.
You can use this pagination token to retrieve the next set of content
moderation labels.
Parameter sortBy :
Sort to use for elements in the ModerationLabelDetections
array. Use TIMESTAMP to sort array elements by the time
labels are detected. Use NAME to alphabetically group
elements for a label together. Within each label group, the array element
are sorted by detection confidence. The default sort is by
TIMESTAMP.
Implementation
Future<GetContentModerationResponse> getContentModeration({
required String jobId,
ContentModerationAggregateBy? aggregateBy,
int? maxResults,
String? nextToken,
ContentModerationSortBy? sortBy,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.GetContentModeration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
if (aggregateBy != null) 'AggregateBy': aggregateBy.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
},
);
return GetContentModerationResponse.fromJson(jsonResponse.body);
}