stopStreamProcessor method

Future<void> stopStreamProcessor({
  1. required String name,
})

Stops a running stream processor that was created by CreateStreamProcessor.

May throw AccessDeniedException. May throw InternalServerError. May throw InvalidParameterException. May throw ProvisionedThroughputExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter name : The name of a stream processor created by CreateStreamProcessor.

Implementation

Future<void> stopStreamProcessor({
  required String name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'RekognitionService.StopStreamProcessor'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
    },
  );
}