Repostspace class

AWS re:Post Private is a private version of AWS re:Post for enterprises with Enterprise Support or Enterprise On-Ramp Support plans. It provides access to knowledge and experts to accelerate cloud adoption and increase developer productivity. With your organization-specific private re:Post, you can build an organization-specific developer community that drives efficiencies at scale and provides access to valuable knowledge resources. Additionally, re:Post Private centralizes trusted AWS technical content and offers private discussion forums to improve how your teams collaborate internally and with AWS to remove technical obstacles, accelerate innovation, and scale more efficiently in the cloud.

Constructors

Repostspace({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchAddChannelRoleToAccessors({required List<String> accessorIds, required String channelId, required ChannelRole channelRole, required String spaceId}) Future<BatchAddChannelRoleToAccessorsOutput>
Add role to multiple users or groups in a private re:Post channel.
batchAddRole({required List<String> accessorIds, required Role role, required String spaceId}) Future<BatchAddRoleOutput>
Add a role to multiple users or groups in a private re:Post.
batchRemoveChannelRoleFromAccessors({required List<String> accessorIds, required String channelId, required ChannelRole channelRole, required String spaceId}) Future<BatchRemoveChannelRoleFromAccessorsOutput>
Remove a role from multiple users or groups in a private re:Post channel.
batchRemoveRole({required List<String> accessorIds, required Role role, required String spaceId}) Future<BatchRemoveRoleOutput>
Remove a role from multiple users or groups in a private re:Post.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createChannel({required String channelName, required String spaceId, String? channelDescription}) Future<CreateChannelOutput>
Creates a channel in an AWS re:Post Private private re:Post.
createSpace({required String name, required String subdomain, required TierLevel tier, String? description, String? roleArn, SupportedEmailDomainsParameters? supportedEmailDomains, Map<String, String>? tags, String? userKMSKey}) Future<CreateSpaceOutput>
Creates an AWS re:Post Private private re:Post.
deleteSpace({required String spaceId}) Future<void>
Deletes an AWS re:Post Private private re:Post.
deregisterAdmin({required String adminId, required String spaceId}) Future<void>
Removes the user or group from the list of administrators of the private re:Post.
getChannel({required String channelId, required String spaceId}) Future<GetChannelOutput>
Displays information about a channel in a private re:Post.
getSpace({required String spaceId}) Future<GetSpaceOutput>
Displays information about the AWS re:Post Private private re:Post.
listChannels({required String spaceId, int? maxResults, String? nextToken}) Future<ListChannelsOutput>
Returns the list of channel within a private re:Post with some information about each channel.
listSpaces({int? maxResults, String? nextToken}) Future<ListSpacesOutput>
Returns a list of AWS re:Post Private private re:Posts in the account with some information about each private re:Post.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns the tags that are associated with the AWS re:Post Private resource specified by the resourceArn. The only resource that can be tagged is a private re:Post.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAdmin({required String adminId, required String spaceId}) Future<void>
Adds a user or group to the list of administrators of the private re:Post.
sendInvites({required List<String> accessorIds, required String body, required String spaceId, required String title}) Future<void>
Sends an invitation email to selected users and groups.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Associates tags with an AWS re:Post Private resource. Currently, the only resource that can be tagged is the private re:Post. If you specify a new tag key for the resource, the tag is appended to the list of tags that are associated with the resource. If you specify a tag key that’s already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the association of the tag with the AWS re:Post Private resource.
updateChannel({required String channelId, required String channelName, required String spaceId, String? channelDescription}) Future<void>
Modifies an existing channel.
updateSpace({required String spaceId, String? description, String? roleArn, SupportedEmailDomainsParameters? supportedEmailDomains, TierLevel? tier}) Future<void>
Modifies an existing AWS re:Post Private private re:Post.

Operators

operator ==(Object other) bool
The equality operator.
inherited