batchRemoveRole method
Remove a role from multiple users or groups in a private re:Post.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accessorIds :
The user or group accessor identifiers to remove the role from.
Parameter role :
The role to remove from the users or groups.
Parameter spaceId :
The unique ID of the private re:Post.
Implementation
Future<BatchRemoveRoleOutput> batchRemoveRole({
required List<String> accessorIds,
required Role role,
required String spaceId,
}) async {
final $payload = <String, dynamic>{
'accessorIds': accessorIds,
'role': role.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/spaces/${Uri.encodeComponent(spaceId)}/roles',
exceptionFnMap: _exceptionFns,
);
return BatchRemoveRoleOutput.fromJson(response);
}