updateSpace method

Future<void> updateSpace({
  1. required String spaceId,
  2. String? description,
  3. String? roleArn,
  4. SupportedEmailDomainsParameters? supportedEmailDomains,
  5. TierLevel? tier,
})

Modifies an existing AWS re:Post Private private re:Post.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter spaceId : The unique ID of this private re:Post.

Parameter description : A description for the private re:Post. This is used only to help you identify this private re:Post.

Parameter roleArn : The IAM role that grants permissions to the private re:Post to convert unanswered questions into AWS support tickets.

Parameter supportedEmailDomains :

Parameter tier : The pricing tier of this private re:Post.

Implementation

Future<void> updateSpace({
  required String spaceId,
  String? description,
  String? roleArn,
  SupportedEmailDomainsParameters? supportedEmailDomains,
  TierLevel? tier,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
    if (roleArn != null) 'roleArn': roleArn,
    if (supportedEmailDomains != null)
      'supportedEmailDomains': supportedEmailDomains,
    if (tier != null) 'tier': tier.value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/spaces/${Uri.encodeComponent(spaceId)}',
    exceptionFnMap: _exceptionFns,
  );
}