associateDefaultView method
Sets the specified view as the default for the Amazon Web Services Region in which you call this operation. When a user performs a Search that doesn't explicitly specify which view to use, then Amazon Web Services Resource Explorer automatically chooses this default view for searches performed in this Amazon Web Services Region.
If an Amazon Web Services Region doesn't have a default view configured,
then users must explicitly specify a view with every Search
operation performed in that Region.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter viewArn :
The Amazon
resource name (ARN) of the view to set as the default for the Amazon
Web Services Region and Amazon Web Services account in which you call this
operation. The specified view must already exist in the called Region.
Implementation
Future<AssociateDefaultViewOutput> associateDefaultView({
required String viewArn,
}) async {
final $payload = <String, dynamic>{
'ViewArn': viewArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/AssociateDefaultView',
exceptionFnMap: _exceptionFns,
);
return AssociateDefaultViewOutput.fromJson(response);
}