createIndex method
Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index. Resource Explorer begins discovering the resources in this Region and stores the details about the resources in the index so that they can be queried by using the Search operation. You can create only one index in a Region. For more details about what happens when you turn on Resource Explorer in an Amazon Web Services Region, see Turn on Resource Explorer to index your resources in an Amazon Web Services Region in the Amazon Web Services Resource Explorer User Guide.
If this is the first Amazon Web Services Region in which you've created an index for Resource Explorer, then this operation also creates a service-linked role in your Amazon Web Services account that allows Resource Explorer to enumerate your resources to populate the index.
-
Action:
resource-explorer-2:CreateIndexResource: The ARN of the index (as it will exist after the operation completes) in the Amazon Web Services Region and account in which you're trying to create the index. Use the wildcard character (
*) at the end of the string to match the eventual UUID. For example, the followingResourceelement restricts the role or user to creating an index in only theus-east-2Region of the specified account."Resource": "arn:aws:resource-explorer-2:us-west-2:<account-id>:index/*"Alternatively, you can use
"Resource": "*"to allow the role or user to create an index in any Region. -
Action:
iam:CreateServiceLinkedRoleResource: No specific resource (*).
This permission is required only the first time you create an index to turn on Resource Explorer in the account. Resource Explorer uses this to create the service-linked role needed to index the resources in your account. Resource Explorer uses the same service-linked role for all additional indexes you create afterwards.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clientToken :
This value helps ensure idempotency. Resource Explorer uses this value to
prevent the accidental creation of duplicate versions. We recommend that
you generate a UUID-type
value to ensure the uniqueness of your index.
Parameter tags :
The specified tags are attached only to the index created in this Amazon
Web Services Region. The tags aren't attached to any of the resources
listed in the index.
Implementation
Future<CreateIndexOutput> createIndex({
String? clientToken,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateIndex',
exceptionFnMap: _exceptionFns,
);
return CreateIndexOutput.fromJson(response);
}