createResourceExplorerSetup method

Future<CreateResourceExplorerSetupOutput> createResourceExplorerSetup({
  1. required List<String> regionList,
  2. required String viewName,
  3. List<String>? aggregatorRegions,
})

Creates a Resource Explorer setup configuration across multiple Amazon Web Services Regions. This operation sets up indexes and views in the specified Regions. This operation can also be used to set an aggregator Region for cross-Region resource search.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter regionList : A list of Amazon Web Services Regions where Resource Explorer should be configured. Each Region in the list will have a user-owned index created.

Parameter viewName : The name for the view to be created as part of the Resource Explorer setup. The view name must be unique within the Amazon Web Services account and Region.

Parameter aggregatorRegions : A list of Amazon Web Services Regions that should be configured as aggregator Regions. Aggregator Regions receive replicated index information from all other Regions where there is a user-owned index.

Implementation

Future<CreateResourceExplorerSetupOutput> createResourceExplorerSetup({
  required List<String> regionList,
  required String viewName,
  List<String>? aggregatorRegions,
}) async {
  final $payload = <String, dynamic>{
    'RegionList': regionList,
    'ViewName': viewName,
    if (aggregatorRegions != null) 'AggregatorRegions': aggregatorRegions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CreateResourceExplorerSetup',
    exceptionFnMap: _exceptionFns,
  );
  return CreateResourceExplorerSetupOutput.fromJson(response);
}