createView method

Future<CreateViewOutput> createView({
  1. required String viewName,
  2. String? clientToken,
  3. SearchFilter? filters,
  4. List<IncludedProperty>? includedProperties,
  5. String? scope,
  6. Map<String, String>? tags,
})

Creates a view that users can query by using the Search operation. Results from queries that you make using this view include only resources that match the view's Filters. For more information about Amazon Web Services Resource Explorer views, see Managing views in the Amazon Web Services Resource Explorer User Guide.

Only the principals with an IAM identity-based policy that grants Allow to the Search action on a Resource with the Amazon resource name (ARN) of this view can Search using views you create with this operation.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw UnauthorizedException. May throw ValidationException.

Parameter viewName : The name of the new view. This name appears in the list of views in Resource Explorer.

The name must be no more than 64 characters long, and can include letters, digits, and the dash (-) character. The name must be unique within its Amazon Web Services Region.

Parameter clientToken : This value helps ensure idempotency. Resource Explorer uses this value to prevent the accidental creation of duplicate versions. We recommend that you generate a UUID-type value to ensure the uniqueness of your views.

Parameter filters : An array of strings that specify which resources are included in the results of queries made using this view. When you use this view in a Search operation, the filter string is combined with the search's QueryString parameter using a logical AND operator.

For information about the supported syntax, see Search query reference for Resource Explorer in the Amazon Web Services Resource Explorer User Guide.

Parameter includedProperties : Specifies optional fields that you want included in search results from this view. It is a list of objects that each describe a field to include.

The default is an empty list, with no optional fields included in the results.

Parameter scope : The root ARN of the account, an organizational unit (OU), or an organization ARN. If left empty, the default is account.

Parameter tags : Tag key and value pairs that are attached to the view.

Implementation

Future<CreateViewOutput> createView({
  required String viewName,
  String? clientToken,
  SearchFilter? filters,
  List<IncludedProperty>? includedProperties,
  String? scope,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'ViewName': viewName,
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (filters != null) 'Filters': filters,
    if (includedProperties != null) 'IncludedProperties': includedProperties,
    if (scope != null) 'Scope': scope,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CreateView',
    exceptionFnMap: _exceptionFns,
  );
  return CreateViewOutput.fromJson(response);
}