deleteResourceExplorerSetup method

Future<DeleteResourceExplorerSetupOutput> deleteResourceExplorerSetup({
  1. bool? deleteInAllRegions,
  2. List<String>? regionList,
})

Deletes a Resource Explorer setup configuration. This operation removes indexes and views from the specified Regions or all Regions where Resource Explorer is configured.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter deleteInAllRegions : Specifies whether to delete Resource Explorer configuration from all Regions where it is currently enabled. If this parameter is set to true, a value for RegionList must not be provided. Otherwise, the operation fails with a ValidationException error.

Parameter regionList : A list of Amazon Web Services Regions from which to delete the Resource Explorer configuration. If not specified, the operation uses the DeleteInAllRegions parameter to determine scope.

Implementation

Future<DeleteResourceExplorerSetupOutput> deleteResourceExplorerSetup({
  bool? deleteInAllRegions,
  List<String>? regionList,
}) async {
  final $payload = <String, dynamic>{
    if (deleteInAllRegions != null) 'DeleteInAllRegions': deleteInAllRegions,
    if (regionList != null) 'RegionList': regionList,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteResourceExplorerSetup',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteResourceExplorerSetupOutput.fromJson(response);
}