deleteView method
Deletes the specified view.
If the specified view is the default view for its Amazon Web Services Region, then all Search operations in that Region must explicitly specify the view to use until you configure a new default by calling the AssociateDefaultView operation.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter viewArn :
The Amazon
resource name (ARN) of the view that you want to delete.
Implementation
Future<DeleteViewOutput> deleteView({
required String viewArn,
}) async {
final $payload = <String, dynamic>{
'ViewArn': viewArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteView',
exceptionFnMap: _exceptionFns,
);
return DeleteViewOutput.fromJson(response);
}