disassociateDefaultView method

Future<void> disassociateDefaultView()

After you call this operation, the affected Amazon Web Services Region no longer has a default view. All Search operations in that Region must explicitly specify a view or the operation fails. You can configure a new default by calling the AssociateDefaultView operation.

If an Amazon Web Services Region doesn't have a default view configured, then users must explicitly specify a view with every Search operation performed in that Region.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<void> disassociateDefaultView() async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/DisassociateDefaultView',
    exceptionFnMap: _exceptionFns,
  );
}