getDefaultView method

Future<GetDefaultViewOutput> getDefaultView()

Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation. You can then call GetView to retrieve the details of that view.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<GetDefaultViewOutput> getDefaultView() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/GetDefaultView',
    exceptionFnMap: _exceptionFns,
  );
  return GetDefaultViewOutput.fromJson(response);
}