getIndex method

Future<GetIndexOutput> getIndex()

Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<GetIndexOutput> getIndex() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/GetIndex',
    exceptionFnMap: _exceptionFns,
  );
  return GetIndexOutput.fromJson(response);
}