getResourceExplorerSetup method

Future<GetResourceExplorerSetupOutput> getResourceExplorerSetup({
  1. required String taskId,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves the status and details of a Resource Explorer setup operation. This operation returns information about the progress of creating or deleting Resource Explorer configurations across Regions.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter taskId : The unique identifier of the setup task to retrieve status information for. This ID is returned by CreateResourceExplorerSetup or DeleteResourceExplorerSetup operations.

Parameter maxResults : The maximum number of Region status results to return in a single response. Valid values are between 1 and 100.

Parameter nextToken : The pagination token from a previous GetResourceExplorerSetup response. Use this token to retrieve the next set of results.

Implementation

Future<GetResourceExplorerSetupOutput> getResourceExplorerSetup({
  required String taskId,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'TaskId': taskId,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetResourceExplorerSetup',
    exceptionFnMap: _exceptionFns,
  );
  return GetResourceExplorerSetupOutput.fromJson(response);
}