listIndexes method

Future<ListIndexesOutput> listIndexes({
  1. int? maxResults,
  2. String? nextToken,
  3. List<String>? regions,
  4. IndexType? type,
})

Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. The pagination tokens expire after 24 hours.

Parameter regions : If specified, limits the response to only information about the index in the specified list of Amazon Web Services Regions.

Parameter type : If specified, limits the output to only indexes of the specified Type, either LOCAL or AGGREGATOR.

Use this option to discover the aggregator index for your account.

Implementation

Future<ListIndexesOutput> listIndexes({
  int? maxResults,
  String? nextToken,
  List<String>? regions,
  IndexType? type,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
    if (regions != null) 'Regions': regions,
    if (type != null) 'Type': type.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListIndexes',
    exceptionFnMap: _exceptionFns,
  );
  return ListIndexesOutput.fromJson(response);
}