listIndexesForMembers method

Future<ListIndexesForMembersOutput> listIndexesForMembers({
  1. required List<String> accountIdList,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves a list of a member's indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer. Only the management account or a delegated administrator with service access enabled can invoke this API call.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter accountIdList : The account IDs will limit the output to only indexes from these accounts.

Parameter maxResults : The maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. The pagination tokens expire after 24 hours.

Implementation

Future<ListIndexesForMembersOutput> listIndexesForMembers({
  required List<String> accountIdList,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'AccountIdList': accountIdList,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListIndexesForMembers',
    exceptionFnMap: _exceptionFns,
  );
  return ListIndexesForMembersOutput.fromJson(response);
}