listServiceViews method

Future<ListServiceViewsOutput> listServiceViews({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all Resource Explorer service views available in the current Amazon Web Services account. This operation returns the ARNs of available service views.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of service view results to return in a single response. Valid values are between 1 and 50.

Parameter nextToken : The pagination token from a previous ListServiceViews response. Use this token to retrieve the next set of results.

Implementation

Future<ListServiceViewsOutput> listServiceViews({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListServiceViews',
    exceptionFnMap: _exceptionFns,
  );
  return ListServiceViewsOutput.fromJson(response);
}