listStreamingAccessForServices method

Future<ListStreamingAccessForServicesOutput> listStreamingAccessForServices({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data. Streaming access allows Amazon Web Services services to receive real-time updates about your resources as they are indexed by Resource Explorer.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter maxResults : The maximum number of streaming access entries to return in the response. If there are more results available, the response includes a NextToken value that you can use in a subsequent call to get the next set of results. The value must be between 1 and 50. If you don't specify a value, the default is 50.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. The pagination tokens expire after 24 hours.

Implementation

Future<ListStreamingAccessForServicesOutput> listStreamingAccessForServices({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListStreamingAccessForServices',
    exceptionFnMap: _exceptionFns,
  );
  return ListStreamingAccessForServicesOutput.fromJson(response);
}