updateView method
Modifies some of the details of a view. You can change the filter string and the list of included properties. You can't change the name of the view.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter viewArn :
The Amazon
resource name (ARN) of the view that you want to modify.
Parameter filters :
An array of strings that specify which resources are included in the
results of queries made using this view. When you use this view in a
Search operation, the filter string is combined with the search's
QueryString parameter using a logical AND
operator.
For information about the supported syntax, see Search query reference for Resource Explorer in the Amazon Web Services Resource Explorer User Guide.
Parameter includedProperties :
Specifies optional fields that you want included in search results from
this view. It is a list of objects that each describe a field to include.
The default is an empty list, with no optional fields included in the results.
Implementation
Future<UpdateViewOutput> updateView({
required String viewArn,
SearchFilter? filters,
List<IncludedProperty>? includedProperties,
}) async {
final $payload = <String, dynamic>{
'ViewArn': viewArn,
if (filters != null) 'Filters': filters,
if (includedProperties != null) 'IncludedProperties': includedProperties,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateView',
exceptionFnMap: _exceptionFns,
);
return UpdateViewOutput.fromJson(response);
}