getGroupQuery method
Retrieves the resource query associated with the specified resource group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:GetGroupQuery
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw MethodNotAllowedException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter group :
The name or the Amazon resource name (ARN) of the resource group to query.
Parameter groupName :
Don't use this parameter. Use Group instead.
Implementation
Future<GetGroupQueryOutput> getGroupQuery({
String? group,
String? groupName,
}) async {
final $payload = <String, dynamic>{
if (group != null) 'Group': group,
if (groupName != null) 'GroupName': groupName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/get-group-query',
exceptionFnMap: _exceptionFns,
);
return GetGroupQueryOutput.fromJson(response);
}