groupResources method

Future<GroupResourcesOutput> groupResources({
  1. required String group,
  2. required List<String> resourceArns,
})

Adds the specified resources to the specified group.

  • AWS::EC2::HostManagement
  • AWS::EC2::CapacityReservationPool
  • AWS::ResourceGroups::ApplicationGroup
Other resource group types and resource types are not currently supported by this operation. Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:GroupResources

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter group : The name or the Amazon resource name (ARN) of the resource group to add resources to.

Parameter resourceArns : The list of Amazon resource names (ARNs) of the resources to be added to the group.

Implementation

Future<GroupResourcesOutput> groupResources({
  required String group,
  required List<String> resourceArns,
}) async {
  final $payload = <String, dynamic>{
    'Group': group,
    'ResourceArns': resourceArns,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/group-resources',
    exceptionFnMap: _exceptionFns,
  );
  return GroupResourcesOutput.fromJson(response);
}