listGroupingStatuses method

Future<ListGroupingStatusesOutput> listGroupingStatuses({
  1. required String group,
  2. List<ListGroupingStatusesFilter>? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Returns the status of the last grouping or ungrouping action for each resource in the specified application group.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw TooManyRequestsException.

Parameter group : The application group identifier, expressed as an Amazon resource name (ARN) or the application group name.

Parameter filters : The filter name and value pair that is used to return more specific results from a list of resources.

Parameter maxResults : The maximum number of resources and their statuses returned in the response.

Parameter nextToken : The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.

Implementation

Future<ListGroupingStatusesOutput> listGroupingStatuses({
  required String group,
  List<ListGroupingStatusesFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $payload = <String, dynamic>{
    'Group': group,
    if (filters != null) 'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-grouping-statuses',
    exceptionFnMap: _exceptionFns,
  );
  return ListGroupingStatusesOutput.fromJson(response);
}