putGroupConfiguration method
Attaches a service configuration to the specified group. This occurs asynchronously, and can take time to complete. You can use GetGroupConfiguration to check the status of the update.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:PutGroupConfiguration
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw MethodNotAllowedException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter configuration :
The new configuration to associate with the specified group. A
configuration associates the resource group with an Amazon Web Services
service and specifies how the service can interact with the resources in
the group. A configuration is an array of GroupConfigurationItem
elements.
For information about the syntax of a service configuration, see Service configurations for Resource Groups.
Parameter group :
The name or Amazon resource name (ARN) of the resource group with the
configuration that you want to update.
Implementation
Future<void> putGroupConfiguration({
List<GroupConfigurationItem>? configuration,
String? group,
}) async {
final $payload = <String, dynamic>{
if (configuration != null) 'Configuration': configuration,
if (group != null) 'Group': group,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/put-group-configuration',
exceptionFnMap: _exceptionFns,
);
}