ungroupResources method

Future<UngroupResourcesOutput> ungroupResources({
  1. required String group,
  2. required List<String> resourceArns,
})

Removes the specified resources from the specified group. This operation works only with static groups that you populated using the GroupResources operation. It doesn't work with any resource groups that are automatically populated by tag-based or CloudFormation stack-based queries.

Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:UngroupResources

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter group : The name or the Amazon resource name (ARN) of the resource group from which to remove the resources.

Parameter resourceArns : The Amazon resource names (ARNs) of the resources to be removed from the group.

Implementation

Future<UngroupResourcesOutput> ungroupResources({
  required String group,
  required List<String> resourceArns,
}) async {
  final $payload = <String, dynamic>{
    'Group': group,
    'ResourceArns': resourceArns,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ungroup-resources',
    exceptionFnMap: _exceptionFns,
  );
  return UngroupResourcesOutput.fromJson(response);
}