untag method

Future<UntagOutput> untag({
  1. required String arn,
  2. required List<String> keys,
})

Deletes tags from a specified resource group.

Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:Untag

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter arn : The Amazon resource name (ARN) of the resource group from which to remove tags. The command removed both the specified keys and any values associated with those keys.

Parameter keys : The keys of the tags to be removed.

Implementation

Future<UntagOutput> untag({
  required String arn,
  required List<String> keys,
}) async {
  final $payload = <String, dynamic>{
    'Keys': keys,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/resources/${Uri.encodeComponent(arn)}/tags',
    exceptionFnMap: _exceptionFns,
  );
  return UntagOutput.fromJson(response);
}