updateAccountSettings method

Future<UpdateAccountSettingsOutput> updateAccountSettings({
  1. GroupLifecycleEventsDesiredStatus? groupLifecycleEventsDesiredStatus,
})

Turns on or turns off optional features in Resource Groups.

The preceding example shows that the request to turn on group lifecycle events is IN_PROGRESS. You can call the GetAccountSettings operation to check for completion by looking for GroupLifecycleEventsStatus to change to ACTIVE.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw TooManyRequestsException.

Parameter groupLifecycleEventsDesiredStatus : Specifies whether you want to turn group lifecycle events on or off.

You can't turn on group lifecycle events if your resource groups quota is greater than 2,000.

Implementation

Future<UpdateAccountSettingsOutput> updateAccountSettings({
  GroupLifecycleEventsDesiredStatus? groupLifecycleEventsDesiredStatus,
}) async {
  final $payload = <String, dynamic>{
    if (groupLifecycleEventsDesiredStatus != null)
      'GroupLifecycleEventsDesiredStatus':
          groupLifecycleEventsDesiredStatus.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-account-settings',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateAccountSettingsOutput.fromJson(response);
}