updateGroup method

Future<UpdateGroupOutput> updateGroup({
  1. int? criticality,
  2. String? description,
  3. String? displayName,
  4. String? group,
  5. String? groupName,
  6. String? owner,
})

Updates the description for an existing group. You cannot update the name of a resource group.

Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:UpdateGroup

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter criticality : The critical rank of the application group on a scale of 1 to 10, with a rank of 1 being the most critical, and a rank of 10 being least critical.

Parameter description : The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.

Parameter displayName : The name of the application group, which you can change at any time.

Parameter group : The name or the ARN of the resource group to update.

Parameter groupName : Don't use this parameter. Use Group instead.

Parameter owner : A name, email address or other identifier for the person or group who is considered as the owner of this application group within your organization.

Implementation

Future<UpdateGroupOutput> updateGroup({
  int? criticality,
  String? description,
  String? displayName,
  String? group,
  String? groupName,
  String? owner,
}) async {
  _s.validateNumRange(
    'criticality',
    criticality,
    1,
    10,
  );
  final $payload = <String, dynamic>{
    if (criticality != null) 'Criticality': criticality,
    if (description != null) 'Description': description,
    if (displayName != null) 'DisplayName': displayName,
    if (group != null) 'Group': group,
    if (groupName != null) 'GroupName': groupName,
    if (owner != null) 'Owner': owner,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/update-group',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateGroupOutput.fromJson(response);
}