updateGroupQuery method
Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:UpdateGroupQuery
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw MethodNotAllowedException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter resourceQuery :
The resource query to determine which Amazon Web Services resources are
members of this resource group.
Parameter group :
The name or the Amazon resource name (ARN) of the resource group to query.
Parameter groupName :
Don't use this parameter. Use Group instead.
Implementation
Future<UpdateGroupQueryOutput> updateGroupQuery({
required ResourceQuery resourceQuery,
String? group,
String? groupName,
}) async {
final $payload = <String, dynamic>{
'ResourceQuery': resourceQuery,
if (group != null) 'Group': group,
if (groupName != null) 'GroupName': groupName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/update-group-query',
exceptionFnMap: _exceptionFns,
);
return UpdateGroupQueryOutput.fromJson(response);
}