putAttributeMapping method
Put an entry in the attribute mapping rules that will be enforced by a given profile. A mapping specifies a certificate field and one or more specifiers that have contextual meanings.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter certificateField :
Fields (x509Subject, x509Issuer and x509SAN) within X.509 certificates.
Parameter mappingRules :
A list of mapping entries for every supported specifier or sub-field.
Parameter profileId :
The unique identifier of the profile.
Implementation
Future<PutAttributeMappingResponse> putAttributeMapping({
required CertificateField certificateField,
required List<MappingRule> mappingRules,
required String profileId,
}) async {
final $payload = <String, dynamic>{
'certificateField': certificateField.value,
'mappingRules': mappingRules,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/profiles/${Uri.encodeComponent(profileId)}/mappings',
exceptionFnMap: _exceptionFns,
);
return PutAttributeMappingResponse.fromJson(response);
}