putNotificationSettings method

Future<PutNotificationSettingsResponse> putNotificationSettings({
  1. required List<NotificationSetting> notificationSettings,
  2. required String trustAnchorId,
})

Attaches a list of notification settings to a trust anchor.

A notification setting includes information such as event name, threshold, status of the notification setting, and the channel to notify.

Required permissions: rolesanywhere:PutNotificationSettings.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter notificationSettings : A list of notification settings to be associated to the trust anchor.

Parameter trustAnchorId : The unique identifier of the trust anchor.

Implementation

Future<PutNotificationSettingsResponse> putNotificationSettings({
  required List<NotificationSetting> notificationSettings,
  required String trustAnchorId,
}) async {
  final $payload = <String, dynamic>{
    'notificationSettings': notificationSettings,
    'trustAnchorId': trustAnchorId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/put-notifications-settings',
    exceptionFnMap: _exceptionFns,
  );
  return PutNotificationSettingsResponse.fromJson(response);
}