deleteHealthCheck method
Deletes a health check.
If you're using Cloud Map and you configured Cloud Map to create a Route
53 health check when you register an instance, you can't use the Route 53
DeleteHealthCheck command to delete the health check. The
health check is deleted automatically when you deregister the instance;
there can be a delay of several hours before the health check is deleted
from Route 53.
May throw HealthCheckInUse.
May throw InvalidInput.
May throw NoSuchHealthCheck.
Parameter healthCheckId :
The ID of the health check that you want to delete.
Implementation
Future<void> deleteHealthCheck({
required String healthCheckId,
}) async {
await _protocol.send(
method: 'DELETE',
requestUri:
'/2013-04-01/healthcheck/${Uri.encodeComponent(healthCheckId)}',
exceptionFnMap: _exceptionFns,
);
}