deleteKeySigningKey method

Future<DeleteKeySigningKeyResponse> deleteKeySigningKey({
  1. required String hostedZoneId,
  2. required String name,
})

Deletes a key-signing key (KSK). Before you can delete a KSK, you must deactivate it. The KSK must be deactivated before you can delete it regardless of whether the hosted zone is enabled for DNSSEC signing.

You can use DeactivateKeySigningKey to deactivate the key before you delete it.

Use GetDNSSEC to verify that the KSK is in an INACTIVE status.

May throw ConcurrentModification. May throw InvalidInput. May throw InvalidKeySigningKeyStatus. May throw InvalidKMSArn. May throw InvalidSigningStatus. May throw NoSuchKeySigningKey.

Parameter hostedZoneId : A unique string used to identify a hosted zone.

Parameter name : A string used to identify a key-signing key (KSK).

Implementation

Future<DeleteKeySigningKeyResponse> deleteKeySigningKey({
  required String hostedZoneId,
  required String name,
}) async {
  final $result = await _protocol.send(
    method: 'DELETE',
    requestUri:
        '/2013-04-01/keysigningkey/${Uri.encodeComponent(hostedZoneId)}/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteKeySigningKeyResponse.fromXml($result.body);
}