deleteReusableDelegationSet method
Deletes a reusable delegation set. To verify that the reusable delegation set is not associated with any hosted zones, submit a GetReusableDelegationSet request and specify the ID of the reusable delegation set that you want to delete.
May throw DelegationSetInUse.
May throw DelegationSetNotReusable.
May throw InvalidInput.
May throw NoSuchDelegationSet.
Parameter id :
The ID of the reusable delegation set that you want to delete.
Implementation
Future<void> deleteReusableDelegationSet({
required String id,
}) async {
await _protocol.send(
method: 'DELETE',
requestUri: '/2013-04-01/delegationset/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}