getChange method

Future<GetChangeResponse> getChange({
  1. required String id,
})

Returns the current status of a change batch request. The status is one of the following values:

  • PENDING indicates that the changes in this request have not propagated to all Amazon Route 53 DNS servers managing the hosted zone. This is the initial status of all change batch requests.
  • INSYNC indicates that the changes have propagated to all Route 53 DNS servers managing the hosted zone.

May throw InvalidInput. May throw NoSuchChange.

Parameter id : The ID of the change batch request. The value that you specify here is the value that ChangeResourceRecordSets returned in the Id element when you submitted the request.

Implementation

Future<GetChangeResponse> getChange({
  required String id,
}) async {
  final $result = await _protocol.send(
    method: 'GET',
    requestUri: '/2013-04-01/change/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetChangeResponse.fromXml($result.body);
}