getDNSSEC method

Future<GetDNSSECResponse> getDNSSEC({
  1. required String hostedZoneId,
})

Returns information about DNSSEC for a specific hosted zone, including the key-signing keys (KSKs) in the hosted zone.

May throw InvalidArgument. May throw InvalidInput. May throw NoSuchHostedZone.

Parameter hostedZoneId : A unique string used to identify a hosted zone.

Implementation

Future<GetDNSSECResponse> getDNSSEC({
  required String hostedZoneId,
}) async {
  final $result = await _protocol.send(
    method: 'GET',
    requestUri:
        '/2013-04-01/hostedzone/${Uri.encodeComponent(hostedZoneId)}/dnssec',
    exceptionFnMap: _exceptionFns,
  );
  return GetDNSSECResponse.fromXml($result.body);
}