getGeoLocation method
Gets information about whether a specified geographic location is supported for Amazon Route 53 geolocation resource record sets.
Route 53 does not perform authorization for this API because it retrieves information that is already available to the public.
Use the following syntax to determine whether a continent is supported for geolocation:
GET /2013-04-01/geolocation?continentcode=two-letter abbreviation
for a continent
Use the following syntax to determine whether a country is supported for geolocation:
GET /2013-04-01/geolocation?countrycode=two-character country
code
Use the following syntax to determine whether a subdivision of a country is supported for geolocation:
GET /2013-04-01/geolocation?countrycode=two-character country
code&subdivisioncode=subdivision code
May throw InvalidInput.
May throw NoSuchGeoLocation.
Parameter continentCode :
For geolocation resource record sets, a two-letter abbreviation that
identifies a continent. Amazon Route 53 supports the following continent
codes:
- AF: Africa
- AN: Antarctica
- AS: Asia
- EU: Europe
- OC: Oceania
- NA: North America
- SA: South America
Parameter countryCode :
Amazon Route 53 uses the two-letter country codes that are specified in ISO standard
3166-1 alpha-2.
Route 53 also supports the country code UA for Ukraine.
Parameter subdivisionCode :
The code for the subdivision, such as a particular state within the United
States. For a list of US state abbreviations, see Appendix B: Two–Letter
State and Possession Abbreviations on the United States Postal Service
website. For a list of all supported subdivision codes, use the ListGeoLocations
API.
Implementation
Future<GetGeoLocationResponse> getGeoLocation({
String? continentCode,
String? countryCode,
String? subdivisionCode,
}) async {
final $query = <String, List<String>>{
if (continentCode != null) 'continentcode': [continentCode],
if (countryCode != null) 'countrycode': [countryCode],
if (subdivisionCode != null) 'subdivisioncode': [subdivisionCode],
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/2013-04-01/geolocation',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetGeoLocationResponse.fromXml($result.body);
}