updateHostedZoneFeatures method
Updates the features configuration for a hosted zone. This operation allows you to enable or disable specific features for your hosted zone, such as accelerated recovery.
Accelerated recovery enables you to update DNS records in your public hosted zone even when the us-east-1 region is unavailable.
May throw InvalidInput.
May throw LimitsExceeded.
May throw NoSuchHostedZone.
May throw PriorRequestNotComplete.
Parameter hostedZoneId :
The ID of the hosted zone for which you want to update features. This is
the unique identifier for your hosted zone.
Parameter enableAcceleratedRecovery :
Specifies whether to enable accelerated recovery for the hosted zone. Set
to true to enable accelerated recovery, or false
to disable it.
Implementation
Future<void> updateHostedZoneFeatures({
required String hostedZoneId,
bool? enableAcceleratedRecovery,
}) async {
await _protocol.send(
method: 'POST',
requestUri:
'/2013-04-01/hostedzone/${Uri.encodeComponent(hostedZoneId)}/features',
payload: UpdateHostedZoneFeaturesRequest(
hostedZoneId: hostedZoneId,
enableAcceleratedRecovery: enableAcceleratedRecovery)
.toXml('UpdateHostedZoneFeaturesRequest'),
exceptionFnMap: _exceptionFns,
);
}