associateDelegationSignerToDomain method

Future<AssociateDelegationSignerToDomainResponse> associateDelegationSignerToDomain({
  1. required String domainName,
  2. required DnssecSigningAttributes signingAttributes,
})

Creates a delegation signer (DS) record in the registry zone for this domain name.

Note that creating DS record at the registry impacts DNSSEC validation of your DNS records. This action may render your domain name unavailable on the internet if the steps are completed in the wrong order, or with incorrect timing. For more information about DNSSEC signing, see Configuring DNSSEC signing in the Route 53 developer guide.

May throw DnssecLimitExceeded. May throw DuplicateRequest. May throw InvalidInput. May throw OperationLimitExceeded. May throw TLDRulesViolation. May throw UnsupportedTLD.

Parameter domainName : The name of the domain.

Parameter signingAttributes : The information about a key, including the algorithm, public key-value, and flags.

Implementation

Future<AssociateDelegationSignerToDomainResponse>
    associateDelegationSignerToDomain({
  required String domainName,
  required DnssecSigningAttributes signingAttributes,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'Route53Domains_v20140515.AssociateDelegationSignerToDomain'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DomainName': domainName,
      'SigningAttributes': signingAttributes,
    },
  );

  return AssociateDelegationSignerToDomainResponse.fromJson(
      jsonResponse.body);
}