listPrices method

Future<ListPricesResponse> listPrices({
  1. String? marker,
  2. int? maxItems,
  3. String? tld,
})

Lists the following prices for either all the TLDs supported by Route 53, or the specified TLD:

  • Registration
  • Transfer
  • Owner change
  • Domain renewal
  • Domain restoration

May throw InvalidInput. May throw UnsupportedTLD.

Parameter marker : For an initial request for a list of prices, omit this element. If the number of prices that are not yet complete is greater than the value that you specified for MaxItems, you can use Marker to return additional prices. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.

Used only for all TLDs. If you specify a TLD, don't specify a Marker.

Parameter maxItems : Number of Prices to be returned.

Used only for all TLDs. If you specify a TLD, don't specify a MaxItems.

Parameter tld : The TLD for which you want to receive the pricing information. For example. .net.

If a Tld value is not provided, a list of prices for all TLDs supported by Route 53 is returned.

Implementation

Future<ListPricesResponse> listPrices({
  String? marker,
  int? maxItems,
  String? tld,
}) async {
  _s.validateNumRange(
    'maxItems',
    maxItems,
    0,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Domains_v20140515.ListPrices'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (marker != null) 'Marker': marker,
      if (maxItems != null) 'MaxItems': maxItems,
      if (tld != null) 'Tld': tld,
    },
  );

  return ListPricesResponse.fromJson(jsonResponse.body);
}