pushDomain method
Moves a domain from Amazon Web Services to another registrar.
Supported actions:
- Changes the IPS tags of a .uk domain, and pushes it to transit. Transit means that the domain is ready to be transferred to another registrar.
May throw InvalidInput.
May throw OperationLimitExceeded.
May throw TLDInMaintenance.
May throw UnsupportedTLD.
Parameter domainName :
Name of the domain.
Parameter target :
New IPS tag for the domain.
Implementation
Future<void> pushDomain({
required String domainName,
required String target,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Domains_v20140515.PushDomain'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainName': domainName,
'Target': target,
},
);
}