Route53GlobalResolver class
Amazon Route 53 Global Resolver is a global, internet-accessible DNS resolver that enables customers to resolve and forward traffic for both public and private domains while ensuring security and authenticity of queries over the internet. Route 53 Global Resolver supports DNS-over-port 53 (Do53), DNS-over-TLS (DoT), and DNS-over-HTTPS (DoH) protocols through global anycast IP addresses.
Constructors
- Route53GlobalResolver({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateHostedZone(
{required String hostedZoneId, required String name, required String resourceArn}) → Future< AssociateHostedZoneOutput> - Associates a Route 53 private hosted zone with a Route 53 Global Resolver resource. This allows the resolver to resolve DNS queries for the private hosted zone from anywhere globally.
-
batchCreateFirewallRule(
{required List< BatchCreateFirewallRuleInputItem> firewallRules}) → Future<BatchCreateFirewallRuleOutput> - Creates multiple DNS firewall rules in a single operation. This is more efficient than creating rules individually when you need to set up multiple rules at once.
-
batchDeleteFirewallRule(
{required List< BatchDeleteFirewallRuleInputItem> firewallRules}) → Future<BatchDeleteFirewallRuleOutput> - Deletes multiple DNS firewall rules in a single operation. This is more efficient than deleting rules individually.
-
batchUpdateFirewallRule(
{required List< BatchUpdateFirewallRuleInputItem> firewallRules}) → Future<BatchUpdateFirewallRuleOutput> - Updates multiple DNS firewall rules in a single operation. This is more efficient than updating rules individually.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessSource(
{required String cidr, required String dnsViewId, required DnsProtocol protocol, String? clientToken, IpAddressType? ipAddressType, String? name, Map< String, String> ? tags}) → Future<CreateAccessSourceOutput> - Creates an access source for a DNS view. Access sources define IP addresses or CIDR ranges that are allowed to send DNS queries to the Route 53 Global Resolver, along with the permitted DNS protocols.
-
createAccessToken(
{required String dnsViewId, String? clientToken, DateTime? expiresAt, String? name, Map< String, String> ? tags}) → Future<CreateAccessTokenOutput> - Creates an access token for a DNS view. Access tokens provide token-based authentication for DNS-over-HTTPS (DoH) and DNS-over-TLS (DoT) connections to the Route 53 Global Resolver.
-
createDNSView(
{required String globalResolverId, required String name, String? clientToken, String? description, DnsSecValidationType? dnssecValidation, EdnsClientSubnetType? ednsClientSubnet, FirewallRulesFailOpenType? firewallRulesFailOpen, Map< String, String> ? tags}) → Future<CreateDNSViewOutput> - Creates a DNS view within a Route 53 Global Resolver. A DNS view models end users, user groups, networks, and devices, and serves as a parent resource that holds configurations controlling access, authorization, DNS firewall rules, and forwarding rules.
-
createFirewallDomainList(
{required String globalResolverId, required String name, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateFirewallDomainListOutput> - Creates a firewall domain list. Domain lists are reusable sets of domain specifications that you use in DNS firewall rules to allow, block, or alert on DNS queries to specific domains.
-
createFirewallRule(
{required FirewallRuleAction action, required String dnsViewId, required String name, BlockOverrideDnsQueryType? blockOverrideDnsType, String? blockOverrideDomain, int? blockOverrideTtl, FirewallBlockResponse? blockResponse, String? clientToken, ConfidenceThreshold? confidenceThreshold, String? description, DnsAdvancedProtection? dnsAdvancedProtection, String? firewallDomainListId, int? priority, String? qType}) → Future< CreateFirewallRuleOutput> - Creates a DNS firewall rule. Firewall rules define actions (ALLOW, BLOCK, or ALERT) to take on DNS queries that match specified domain lists, managed domain lists, or advanced threat protections.
-
createGlobalResolver(
{required String name, required List< String> regions, String? clientToken, String? description, GlobalResolverIpAddressType? ipAddressType, String? observabilityRegion, Map<String, String> ? tags}) → Future<CreateGlobalResolverOutput> - Creates a new Route 53 Global Resolver instance. A Route 53 Global Resolver is a global, internet-accessible DNS resolver that provides secure DNS resolution for both public and private domains through global anycast IP addresses.
-
deleteAccessSource(
{required String accessSourceId}) → Future< DeleteAccessSourceOutput> - Deletes an access source. This operation cannot be undone.
-
deleteAccessToken(
{required String accessTokenId}) → Future< DeleteAccessTokenOutput> - Deletes an access token. This operation cannot be undone.
-
deleteDNSView(
{required String dnsViewId}) → Future< DeleteDNSViewOutput> - Deletes a DNS view. This operation cannot be undone.
-
deleteFirewallDomainList(
{required String firewallDomainListId}) → Future< DeleteFirewallDomainListOutput> - Deletes a firewall domain list. This operation cannot be undone.
-
deleteFirewallRule(
{required String firewallRuleId}) → Future< DeleteFirewallRuleOutput> - Deletes a DNS firewall rule. This operation cannot be undone.
-
deleteGlobalResolver(
{required String globalResolverId}) → Future< DeleteGlobalResolverOutput> - Deletes a Route 53 Global Resolver instance. This operation cannot be undone. All associated DNS views, access sources, tokens, and firewall rules are also deleted.
-
disableDNSView(
{required String dnsViewId}) → Future< DisableDNSViewOutput> - Disables a DNS view, preventing it from serving DNS queries.
-
disassociateHostedZone(
{required String hostedZoneId, required String resourceArn}) → Future< DisassociateHostedZoneOutput> - Disassociates a Route 53 private hosted zone from a Route 53 Global Resolver resource.
-
enableDNSView(
{required String dnsViewId}) → Future< EnableDNSViewOutput> - Enables a disabled DNS view, allowing it to serve DNS queries again.
-
getAccessSource(
{required String accessSourceId}) → Future< GetAccessSourceOutput> - Retrieves information about an access source.
-
getAccessToken(
{required String accessTokenId}) → Future< GetAccessTokenOutput> - Retrieves information about an access token.
-
getDNSView(
{required String dnsViewId}) → Future< GetDNSViewOutput> - Retrieves information about a DNS view.
-
getFirewallDomainList(
{required String firewallDomainListId}) → Future< GetFirewallDomainListOutput> - Retrieves information about a firewall domain list.
-
getFirewallRule(
{required String firewallRuleId}) → Future< GetFirewallRuleOutput> - Retrieves information about a DNS firewall rule.
-
getGlobalResolver(
{required String globalResolverId}) → Future< GetGlobalResolverOutput> - Retrieves information about a Route 53 Global Resolver instance.
-
getHostedZoneAssociation(
{required String hostedZoneAssociationId}) → Future< GetHostedZoneAssociationOutput> - Retrieves information about a hosted zone association.
-
getManagedFirewallDomainList(
{required String managedFirewallDomainListId}) → Future< GetManagedFirewallDomainListOutput> - Retrieves information about an Amazon Web Services-managed firewall domain list. Managed domain lists contain domains associated with malicious activity, content categories, or specific threats.
-
importFirewallDomains(
{required String domainFileUrl, required String firewallDomainListId, required String operation}) → Future< ImportFirewallDomainsOutput> - Imports a list of domains from an Amazon S3 file into a firewall domain list. The file should contain one domain per line.
-
listAccessSources(
{Map< String, List< ? filters, int? maxResults, String? nextToken}) → Future<String> >ListAccessSourcesOutput> - Lists all access sources with pagination support.
-
listAccessTokens(
{required String dnsViewId, Map< String, List< ? filters, int? maxResults, String? nextToken}) → Future<String> >ListAccessTokensOutput> - Lists all access tokens for a DNS view with pagination support.
-
listDNSViews(
{required String globalResolverId, int? maxResults, String? nextToken}) → Future< ListDNSViewsOutput> - Lists all DNS views for a Route 53 Global Resolver with pagination support.
-
listFirewallDomainLists(
{String? globalResolverId, int? maxResults, String? nextToken}) → Future< ListFirewallDomainListsOutput> - Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.
-
listFirewallDomains(
{required String firewallDomainListId, int? maxResults, String? nextToken}) → Future< ListFirewallDomainsOutput> - Lists all the domains in DNS Firewall domain list you have created.
-
listFirewallRules(
{required String dnsViewId, Map< String, List< ? filters, int? maxResults, String? nextToken}) → Future<String> >ListFirewallRulesOutput> - Lists all DNS firewall rules for a DNS view with pagination support.
-
listGlobalResolvers(
{int? maxResults, String? nextToken}) → Future< ListGlobalResolversOutput> - Lists all Route 53 Global Resolver instances in your account with pagination support.
-
listHostedZoneAssociations(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< ListHostedZoneAssociationsOutput> - Lists all hosted zone associations for a Route 53 Global Resolver resource with pagination support.
-
listManagedFirewallDomainLists(
{required String managedFirewallDomainListType, int? maxResults, String? nextToken}) → Future< ListManagedFirewallDomainListsOutput> -
Returns a paginated list of the Amazon Web Services Managed DNS Lists and
the categories for DNS Firewall. The categories are either
THREATorCONTENT. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags associated with a Route 53 Global Resolver resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds or updates tags for a Route 53 Global Resolver resource. Tags are key-value pairs that help you organize and identify your resources.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from a Route 53 Global Resolver resource.
-
updateAccessSource(
{required String accessSourceId, String? cidr, IpAddressType? ipAddressType, String? name, DnsProtocol? protocol}) → Future< UpdateAccessSourceOutput> - Updates the configuration of an access source.
-
updateAccessToken(
{required String accessTokenId, required String name}) → Future< UpdateAccessTokenOutput> - Updates the configuration of an access token.
-
updateDNSView(
{required String dnsViewId, String? description, DnsSecValidationType? dnssecValidation, EdnsClientSubnetType? ednsClientSubnet, FirewallRulesFailOpenType? firewallRulesFailOpen, String? name}) → Future< UpdateDNSViewOutput> - Updates the configuration of a DNS view.
-
updateFirewallDomains(
{required List< String> domains, required String firewallDomainListId, required String operation}) → Future<UpdateFirewallDomainsOutput> - Updates a DNS Firewall domain list from an array of specified domains.
-
updateFirewallRule(
{required String firewallRuleId, FirewallRuleAction? action, BlockOverrideDnsQueryType? blockOverrideDnsType, String? blockOverrideDomain, int? blockOverrideTtl, FirewallBlockResponse? blockResponse, String? clientToken, ConfidenceThreshold? confidenceThreshold, String? description, DnsAdvancedProtection? dnsAdvancedProtection, String? name, int? priority}) → Future< UpdateFirewallRuleOutput> - Updates the configuration of a DNS firewall rule.
-
updateGlobalResolver(
{required String globalResolverId, String? description, GlobalResolverIpAddressType? ipAddressType, String? name, String? observabilityRegion, List< String> ? regions}) → Future<UpdateGlobalResolverOutput> - Updates the configuration of a Route 53 Global Resolver instance. You can modify the name, description, and observability Region.
-
updateHostedZoneAssociation(
{required String hostedZoneAssociationId, String? name}) → Future< UpdateHostedZoneAssociationOutput> - Updates the configuration of a hosted zone association.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited