batchCreateFirewallRule method

Future<BatchCreateFirewallRuleOutput> batchCreateFirewallRule({
  1. required List<BatchCreateFirewallRuleInputItem> firewallRules,
})

Creates multiple DNS firewall rules in a single operation. This is more efficient than creating rules individually when you need to set up multiple rules at once.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter firewallRules : The BatchCreateFirewallRuleInputItem objects contain the information for each Firewall rule.

Implementation

Future<BatchCreateFirewallRuleOutput> batchCreateFirewallRule({
  required List<BatchCreateFirewallRuleInputItem> firewallRules,
}) async {
  final $payload = <String, dynamic>{
    'firewallRules': firewallRules,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/firewall-rules/batch-create',
    exceptionFnMap: _exceptionFns,
  );
  return BatchCreateFirewallRuleOutput.fromJson(response);
}