importFirewallDomains method

Future<ImportFirewallDomainsOutput> importFirewallDomains({
  1. required String domainFileUrl,
  2. required String firewallDomainListId,
  3. required String operation,
})

Imports a list of domains from an Amazon S3 file into a firewall domain list. The file should contain one domain per line.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainFileUrl : The fully qualified URL of the file in Amazon S3 that contains the list of domains to import. The file should contain one domain per line.

Parameter firewallDomainListId : ID of the DNS Firewall domain list that you want to import the domain list to.

Parameter operation : This value is REPLACE, and it updates the domain list to match the list of domains in the imported file.

Implementation

Future<ImportFirewallDomainsOutput> importFirewallDomains({
  required String domainFileUrl,
  required String firewallDomainListId,
  required String operation,
}) async {
  final $payload = <String, dynamic>{
    'domainFileUrl': domainFileUrl,
    'operation': operation,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/firewall-domain-lists/${Uri.encodeComponent(firewallDomainListId)}/domains/s3_file_url',
    exceptionFnMap: _exceptionFns,
  );
  return ImportFirewallDomainsOutput.fromJson(response);
}