listGlobalResolvers method

Future<ListGlobalResolversOutput> listGlobalResolvers({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all Route 53 Global Resolver instances in your account with pagination support.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of Route 53 Global Resolver instances to return in the response. Valid range is 1-100.

Parameter nextToken : The token for the next page of results. This value is returned in the response if there are more results to retrieve.

Implementation

Future<ListGlobalResolversOutput> listGlobalResolvers({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'next_token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/global-resolver',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListGlobalResolversOutput.fromJson(response);
}