listManagedFirewallDomainLists method

Future<ListManagedFirewallDomainListsOutput> listManagedFirewallDomainLists({
  1. required String managedFirewallDomainListType,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a paginated list of the Amazon Web Services Managed DNS Lists and the categories for DNS Firewall. The categories are either THREAT or CONTENT.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter managedFirewallDomainListType : The category of the Manage DNS list either THREAT or CONTENT.

Parameter maxResults : The maximum number of results to retrieve in a single call.

Parameter nextToken : A pagination token used for large sets of results that can't be returned in a single response.

Implementation

Future<ListManagedFirewallDomainListsOutput> listManagedFirewallDomainLists({
  required String managedFirewallDomainListType,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'next_token': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/list-managed-firewall-domain-lists/${Uri.encodeComponent(managedFirewallDomainListType)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListManagedFirewallDomainListsOutput.fromJson(response);
}