updateFirewallDomains method

Future<UpdateFirewallDomainsOutput> updateFirewallDomains({
  1. required List<String> domains,
  2. required String firewallDomainListId,
  3. required String operation,
})

Updates a DNS Firewall domain list from an array of specified domains.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domains : A list of the domains. You can add up to 1000 domains per request.

Parameter firewallDomainListId : The ID of the DNS Firewall domain list to which you want to add the domains.

Parameter operation : The operation for updating the domain list. The allowed values are ADD, REMOVE, and REPLACE.

Implementation

Future<UpdateFirewallDomainsOutput> updateFirewallDomains({
  required List<String> domains,
  required String firewallDomainListId,
  required String operation,
}) async {
  final $payload = <String, dynamic>{
    'domains': domains,
    'operation': operation,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/firewall-domain-lists/${Uri.encodeComponent(firewallDomainListId)}/domains',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateFirewallDomainsOutput.fromJson(response);
}