updateGlobalResolver method
Updates the configuration of a Route 53 Global Resolver instance. You can modify the name, description, and observability Region.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter globalResolverId :
The ID of the Global Resolver.
Parameter description :
The description of the Global Resolver.
Parameter ipAddressType :
The IP address type for the Global Resolver. Valid values are IPV4 or
DUAL_STACK for both IPv4 and IPv6 support.
Parameter name :
The name of the Global Resolver.
Parameter observabilityRegion :
The Amazon Web Services Regions in which the users' Global Resolver query
resolution logs will be propagated.
Parameter regions :
The list of Amazon Web Services Regions where the Global Resolver will
operate. The resolver will be distributed across these Regions to provide
global availability and low-latency DNS resolution.
Implementation
Future<UpdateGlobalResolverOutput> updateGlobalResolver({
required String globalResolverId,
String? description,
GlobalResolverIpAddressType? ipAddressType,
String? name,
String? observabilityRegion,
List<String>? regions,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (ipAddressType != null) 'ipAddressType': ipAddressType.value,
if (name != null) 'name': name,
if (observabilityRegion != null)
'observabilityRegion': observabilityRegion,
if (regions != null) 'regions': regions,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/global-resolver/${Uri.encodeComponent(globalResolverId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateGlobalResolverOutput.fromJson(response);
}