deleteProfile method

Future<DeleteProfileResponse> deleteProfile({
  1. required String profileId,
})

Deletes the specified Route 53 Profile. Before you can delete a profile, you must first disassociate it from all VPCs.

May throw AccessDeniedException. May throw ConflictException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter profileId : The ID of the Profile that you want to delete.

Implementation

Future<DeleteProfileResponse> deleteProfile({
  required String profileId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/profile/${Uri.encodeComponent(profileId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteProfileResponse.fromJson(response);
}