listProfiles method

Future<ListProfilesResponse> listProfiles({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all the Route 53 Profiles associated with your Amazon Web Services account.

May throw AccessDeniedException. May throw InvalidNextTokenException. May throw InvalidParameterException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of objects that you want to return for this request. If more objects are available, in the response, a NextToken value, which you can use in a subsequent call to get the next batch of objects, is provided.

If you don't specify a value for MaxResults, up to 100 objects are returned.

Parameter nextToken : For the first call to this list request, omit this value.

When you request a list of objects, at most the number of objects specified by MaxResults is returned. If more objects are available for retrieval, a NextToken value is returned in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request.

Implementation

Future<ListProfilesResponse> listProfiles({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/profiles',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListProfilesResponse.fromJson(response);
}