updateProfileResourceAssociation method

Future<UpdateProfileResourceAssociationResponse> updateProfileResourceAssociation({
  1. required String profileResourceAssociationId,
  2. String? name,
  3. String? resourceProperties,
})

Updates the specified Route 53 Profile resourse association.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceErrorException. May throw InvalidParameterException. May throw LimitExceededException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter profileResourceAssociationId : ID of the resource association.

Parameter name : Name of the resource association.

Parameter resourceProperties : If you are adding a DNS Firewall rule group, include also a priority. The priority indicates the processing order for the rule groups, starting with the priority assinged the lowest value.

The allowed values for priority are between 100 and 9900.

Implementation

Future<UpdateProfileResourceAssociationResponse>
    updateProfileResourceAssociation({
  required String profileResourceAssociationId,
  String? name,
  String? resourceProperties,
}) async {
  final $payload = <String, dynamic>{
    if (name != null) 'Name': name,
    if (resourceProperties != null) 'ResourceProperties': resourceProperties,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/profileresourceassociation/${Uri.encodeComponent(profileResourceAssociationId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateProfileResourceAssociationResponse.fromJson(response);
}