getRoutingControlState method
- required String routingControlArn,
Get the state for a routing control. A routing control is a simple on/off switch that you can use to route traffic to cells. When a routing control state is set to ON, traffic flows to a cell. When the state is set to OFF, traffic does not flow.
Before you can create a routing control, you must first create a cluster, and then host the control in a control panel on the cluster. For more information, see Create routing control structures in the Amazon Route 53 Application Recovery Controller Developer Guide. You access one of the endpoints for the cluster to get or update the routing control state to redirect traffic for your application.
You must specify Regional endpoints when you work with API cluster operations to get or update routing control states in Route 53 ARC.
To see a code example for getting a routing control state, including accessing Regional cluster endpoints in sequence, see API examples in the Amazon Route 53 Application Recovery Controller Developer Guide.
Learn more about working with routing controls in the following topics in the Amazon Route 53 Application Recovery Controller Developer Guide:
May throw AccessDeniedException.
May throw EndpointTemporarilyUnavailableException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter routingControlArn :
The Amazon Resource Name (ARN) for the routing control that you want to
get the state for.
Implementation
Future<GetRoutingControlStateResponse> getRoutingControlState({
required String routingControlArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ToggleCustomerAPI.GetRoutingControlState'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RoutingControlArn': routingControlArn,
},
);
return GetRoutingControlStateResponse.fromJson(jsonResponse.body);
}