Route53RecoveryControlConfig class
Recovery Control Configuration API Reference for Amazon Route 53 Application Recovery Controller
Constructors
- Route53RecoveryControlConfig({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCluster(
{required String clusterName, String? clientToken, NetworkType? networkType, Map< String, String> ? tags}) → Future<CreateClusterResponse> - Create a new cluster. A cluster is a set of redundant Regional endpoints against which you can run API calls to update or get the state of one or more routing controls. Each cluster has a name, status, Amazon Resource Name (ARN), and an array of the five cluster endpoints (one for each supported Amazon Web Services Region) that you can use with API calls to the cluster data plane.
-
createControlPanel(
{required String clusterArn, required String controlPanelName, String? clientToken, Map< String, String> ? tags}) → Future<CreateControlPanelResponse> - Creates a new control panel. A control panel represents a group of routing controls that can be changed together in a single transaction. You can use a control panel to centrally view the operational status of applications across your organization, and trigger multi-app failovers in a single transaction, for example, to fail over an Availability Zone or Amazon Web Services Region.
-
createRoutingControl(
{required String clusterArn, required String routingControlName, String? clientToken, String? controlPanelArn}) → Future< CreateRoutingControlResponse> - Creates a new routing control.
-
createSafetyRule(
{NewAssertionRule? assertionRule, String? clientToken, NewGatingRule? gatingRule, Map< String, String> ? tags}) → Future<CreateSafetyRuleResponse> - Creates a safety rule in a control panel. Safety rules let you add safeguards around changing routing control states, and for enabling and disabling routing controls, to help prevent unexpected outcomes.
-
deleteCluster(
{required String clusterArn}) → Future< void> - Delete a cluster.
-
deleteControlPanel(
{required String controlPanelArn}) → Future< void> - Deletes a control panel.
-
deleteRoutingControl(
{required String routingControlArn}) → Future< void> - Deletes a routing control.
-
deleteSafetyRule(
{required String safetyRuleArn}) → Future< void> - Deletes a safety rule. />
-
describeCluster(
{required String clusterArn}) → Future< DescribeClusterResponse> - Display the details about a cluster. The response includes the cluster name, endpoints, status, and Amazon Resource Name (ARN).
-
describeControlPanel(
{required String controlPanelArn}) → Future< DescribeControlPanelResponse> - Displays details about a control panel.
-
describeRoutingControl(
{required String routingControlArn}) → Future< DescribeRoutingControlResponse> - Displays details about a routing control. A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.
-
describeSafetyRule(
{required String safetyRuleArn}) → Future< DescribeSafetyRuleResponse> - Returns information about a safety rule.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> - Get information about the resource policy for a cluster.
-
listAssociatedRoute53HealthChecks(
{required String routingControlArn, int? maxResults, String? nextToken}) → Future< ListAssociatedRoute53HealthChecksResponse> - Returns an array of all Amazon Route 53 health checks associated with a specific routing control.
-
listClusters(
{int? maxResults, String? nextToken}) → Future< ListClustersResponse> - Returns an array of all the clusters in an account.
-
listControlPanels(
{String? clusterArn, int? maxResults, String? nextToken}) → Future< ListControlPanelsResponse> - Returns an array of control panels in an account or in a cluster.
-
listRoutingControls(
{required String controlPanelArn, int? maxResults, String? nextToken}) → Future< ListRoutingControlsResponse> - Returns an array of routing controls for a control panel. A routing control is an Amazon Route 53 Application Recovery Controller construct that has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.
-
listSafetyRules(
{required String controlPanelArn, int? maxResults, String? nextToken}) → Future< ListSafetyRulesResponse> - List the safety rules (the assertion rules and gating rules) that you've defined for the routing controls in a control panel.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds a tag to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from a resource.
-
updateCluster(
{required String clusterArn, required NetworkType networkType}) → Future< UpdateClusterResponse> - Updates an existing cluster. You can only update the network type of a cluster.
-
updateControlPanel(
{required String controlPanelArn, required String controlPanelName}) → Future< UpdateControlPanelResponse> - Updates a control panel. The only update you can make to a control panel is to change the name of the control panel.
-
updateRoutingControl(
{required String routingControlArn, required String routingControlName}) → Future< UpdateRoutingControlResponse> - Updates a routing control. You can only update the name of the routing control. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.
-
updateSafetyRule(
{AssertionRuleUpdate? assertionRuleUpdate, GatingRuleUpdate? gatingRuleUpdate}) → Future< UpdateSafetyRuleResponse> - Update a safety rule (an assertion rule or gating rule). You can only update the name and the waiting period for a safety rule. To make other updates, delete the safety rule and create a new one.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited