describeRoutingControl method

Future<DescribeRoutingControlResponse> describeRoutingControl({
  1. required String routingControlArn,
})

Displays details about a routing control. A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.

To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter routingControlArn : The Amazon Resource Name (ARN) of the routing control.

Implementation

Future<DescribeRoutingControlResponse> describeRoutingControl({
  required String routingControlArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/routingcontrol/${Uri.encodeComponent(routingControlArn)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeRoutingControlResponse.fromJson(response);
}