listRoutingControls method

Future<ListRoutingControlsResponse> listRoutingControls({
  1. required String controlPanelArn,
  2. int? maxResults,
  3. String? nextToken,
})

Returns an array of routing controls for a control panel. A routing control is an Amazon Route 53 Application Recovery Controller construct that has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter controlPanelArn : The Amazon Resource Name (ARN) of the control panel.

Parameter maxResults : The number of objects that you want to return with this call.

Parameter nextToken : The token that identifies which batch of results you want to see.

Implementation

Future<ListRoutingControlsResponse> listRoutingControls({
  required String controlPanelArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/controlpanel/${Uri.encodeComponent(controlPanelArn)}/routingcontrols',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListRoutingControlsResponse.fromJson(response);
}