updateControlPanel method
Updates a control panel. The only update you can make to a control panel is to change the name of the control panel.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter controlPanelArn :
The Amazon Resource Name (ARN) of the control panel.
Parameter controlPanelName :
The name of the control panel.
Implementation
Future<UpdateControlPanelResponse> updateControlPanel({
required String controlPanelArn,
required String controlPanelName,
}) async {
final $payload = <String, dynamic>{
'ControlPanelArn': controlPanelArn,
'ControlPanelName': controlPanelName,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/controlpanel',
exceptionFnMap: _exceptionFns,
);
return UpdateControlPanelResponse.fromJson(response);
}