updateRoutingControl method

Future<UpdateRoutingControlResponse> updateRoutingControl({
  1. required String routingControlArn,
  2. required String routingControlName,
})

Updates a routing control. You can only update the name of the routing control. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter routingControlArn : The Amazon Resource Name (ARN) of the routing control.

Parameter routingControlName : The name of the routing control.

Implementation

Future<UpdateRoutingControlResponse> updateRoutingControl({
  required String routingControlArn,
  required String routingControlName,
}) async {
  final $payload = <String, dynamic>{
    'RoutingControlArn': routingControlArn,
    'RoutingControlName': routingControlName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/routingcontrol',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateRoutingControlResponse.fromJson(response);
}