createCell method

Future<CreateCellResponse> createCell({
  1. required String cellName,
  2. List<String>? cells,
  3. Map<String, String>? tags,
})

Creates a cell in an account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter cellName : The name of the cell to create.

Parameter cells : A list of cell Amazon Resource Names (ARNs) contained within this cell, for use in nested cells. For example, Availability Zones within specific Amazon Web Services Regions.

Implementation

Future<CreateCellResponse> createCell({
  required String cellName,
  List<String>? cells,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'cellName': cellName,
    if (cells != null) 'cells': cells,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/cells',
    exceptionFnMap: _exceptionFns,
  );
  return CreateCellResponse.fromJson(response);
}