createCrossAccountAuthorization method

Future<CreateCrossAccountAuthorizationResponse> createCrossAccountAuthorization({
  1. required String crossAccountAuthorization,
})

Creates a cross-account readiness authorization. This lets you authorize another account to work with Route 53 Application Recovery Controller, for example, to check the readiness status of resources in a separate account.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter crossAccountAuthorization : The cross-account authorization.

Implementation

Future<CreateCrossAccountAuthorizationResponse>
    createCrossAccountAuthorization({
  required String crossAccountAuthorization,
}) async {
  final $payload = <String, dynamic>{
    'crossAccountAuthorization': crossAccountAuthorization,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/crossaccountauthorizations',
    exceptionFnMap: _exceptionFns,
  );
  return CreateCrossAccountAuthorizationResponse.fromJson(response);
}