createRecoveryGroup method

Future<CreateRecoveryGroupResponse> createRecoveryGroup({
  1. required String recoveryGroupName,
  2. List<String>? cells,
  3. Map<String, String>? tags,
})

Creates a recovery group in an account. A recovery group corresponds to an application and includes a list of the cells that make up the application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter recoveryGroupName : The name of the recovery group to create.

Parameter cells : A list of the cell Amazon Resource Names (ARNs) in the recovery group.

Implementation

Future<CreateRecoveryGroupResponse> createRecoveryGroup({
  required String recoveryGroupName,
  List<String>? cells,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'recoveryGroupName': recoveryGroupName,
    if (cells != null) 'cells': cells,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/recoverygroups',
    exceptionFnMap: _exceptionFns,
  );
  return CreateRecoveryGroupResponse.fromJson(response);
}