getCellReadinessSummary method

Future<GetCellReadinessSummaryResponse> getCellReadinessSummary({
  1. required String cellName,
  2. int? maxResults,
  3. String? nextToken,
})

Gets readiness for a cell. Aggregates the readiness of all the resources that are associated with the cell into a single value.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter cellName : The name of the cell.

Parameter maxResults : The number of objects that you want to return with this call.

Parameter nextToken : The token that identifies which batch of results you want to see.

Implementation

Future<GetCellReadinessSummaryResponse> getCellReadinessSummary({
  required String cellName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cellreadiness/${Uri.encodeComponent(cellName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetCellReadinessSummaryResponse.fromJson(response);
}