getRecoveryGroup method

Future<GetRecoveryGroupResponse> getRecoveryGroup({
  1. required String recoveryGroupName,
})

Gets details about a recovery group, including a list of the cells that are included in it.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter recoveryGroupName : The name of a recovery group.

Implementation

Future<GetRecoveryGroupResponse> getRecoveryGroup({
  required String recoveryGroupName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/recoverygroups/${Uri.encodeComponent(recoveryGroupName)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRecoveryGroupResponse.fromJson(response);
}