listResourceSets method
Lists the resource sets in an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The number of objects that you want to return with this call.
Parameter nextToken :
The token that identifies which batch of results you want to see.
Implementation
Future<ListResourceSetsResponse> listResourceSets({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/resourcesets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListResourceSetsResponse.fromJson(response);
}