updateResourceSet method

Future<UpdateResourceSetResponse> updateResourceSet({
  1. required String resourceSetName,
  2. required String resourceSetType,
  3. required List<Resource> resources,
})

Updates a resource set.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceSetName : Name of a resource set.

Parameter resourceSetType : The resource type of the resources in the resource set. Enter one of the following values for resource type:

AWS::ApiGateway::Stage, AWS::ApiGatewayV2::Stage, AWS::AutoScaling::AutoScalingGroup, AWS::CloudWatch::Alarm, AWS::EC2::CustomerGateway, AWS::DynamoDB::Table, AWS::EC2::Volume, AWS::ElasticLoadBalancing::LoadBalancer, AWS::ElasticLoadBalancingV2::LoadBalancer, AWS::Lambda::Function, AWS::MSK::Cluster, AWS::RDS::DBCluster, AWS::Route53::HealthCheck, AWS::SQS::Queue, AWS::SNS::Topic, AWS::SNS::Subscription, AWS::EC2::VPC, AWS::EC2::VPNConnection, AWS::EC2::VPNGateway, AWS::Route53RecoveryReadiness::DNSTargetResource

Parameter resources : A list of resource objects.

Implementation

Future<UpdateResourceSetResponse> updateResourceSet({
  required String resourceSetName,
  required String resourceSetType,
  required List<Resource> resources,
}) async {
  final $payload = <String, dynamic>{
    'resourceSetType': resourceSetType,
    'resources': resources,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/resourcesets/${Uri.encodeComponent(resourceSetName)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateResourceSetResponse.fromJson(response);
}