disassociateResolverQueryLogConfig method
Disassociates a VPC from a query logging configuration.
- The accounts that you shared the configuration with can disassociate VPCs from the configuration.
- You can stop sharing the configuration.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resolverQueryLogConfigId :
The ID of the query logging configuration that you want to disassociate a
specified VPC from.
Parameter resourceId :
The ID of the Amazon VPC that you want to disassociate from a specified
query logging configuration.
Implementation
Future<DisassociateResolverQueryLogConfigResponse>
disassociateResolverQueryLogConfig({
required String resolverQueryLogConfigId,
required String resourceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.DisassociateResolverQueryLogConfig'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResolverQueryLogConfigId': resolverQueryLogConfigId,
'ResourceId': resourceId,
},
);
return DisassociateResolverQueryLogConfigResponse.fromJson(
jsonResponse.body);
}