disassociateResolverRule method
Removes the association between a specified Resolver rule and a specified VPC.
May throw InternalServiceErrorException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resolverRuleId :
The ID of the Resolver rule that you want to disassociate from the
specified VPC.
Parameter vPCId :
The ID of the VPC that you want to disassociate the Resolver rule from.
Implementation
Future<DisassociateResolverRuleResponse> disassociateResolverRule({
required String resolverRuleId,
required String vPCId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.DisassociateResolverRule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResolverRuleId': resolverRuleId,
'VPCId': vPCId,
},
);
return DisassociateResolverRuleResponse.fromJson(jsonResponse.body);
}