getFirewallRuleGroupAssociation method

Future<GetFirewallRuleGroupAssociationResponse> getFirewallRuleGroupAssociation({
  1. required String firewallRuleGroupAssociationId,
})

Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter firewallRuleGroupAssociationId : The identifier of the FirewallRuleGroupAssociation.

Implementation

Future<GetFirewallRuleGroupAssociationResponse>
    getFirewallRuleGroupAssociation({
  required String firewallRuleGroupAssociationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Resolver.GetFirewallRuleGroupAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'FirewallRuleGroupAssociationId': firewallRuleGroupAssociationId,
    },
  );

  return GetFirewallRuleGroupAssociationResponse.fromJson(jsonResponse.body);
}