getOutpostResolver method

Future<GetOutpostResolverResponse> getOutpostResolver({
  1. required String id,
})

Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the Resolver on the Outpost.

Implementation

Future<GetOutpostResolverResponse> getOutpostResolver({
  required String id,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Resolver.GetOutpostResolver'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
    },
  );

  return GetOutpostResolverResponse.fromJson(jsonResponse.body);
}