getResolverQueryLogConfigAssociation method

Future<GetResolverQueryLogConfigAssociationResponse> getResolverQueryLogConfigAssociation({
  1. required String resolverQueryLogConfigAssociationId,
})

Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter resolverQueryLogConfigAssociationId : The ID of the Resolver query logging configuration association that you want to get information about.

Implementation

Future<GetResolverQueryLogConfigAssociationResponse>
    getResolverQueryLogConfigAssociation({
  required String resolverQueryLogConfigAssociationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Resolver.GetResolverQueryLogConfigAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResolverQueryLogConfigAssociationId':
          resolverQueryLogConfigAssociationId,
    },
  );

  return GetResolverQueryLogConfigAssociationResponse.fromJson(
      jsonResponse.body);
}