getResolverRuleAssociation method
Future<GetResolverRuleAssociationResponse>
getResolverRuleAssociation({
- required String resolverRuleAssociationId,
Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using AssociateResolverRule.
May throw InternalServiceErrorException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resolverRuleAssociationId :
The ID of the Resolver rule association that you want to get information
about.
Implementation
Future<GetResolverRuleAssociationResponse> getResolverRuleAssociation({
required String resolverRuleAssociationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.GetResolverRuleAssociation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResolverRuleAssociationId': resolverRuleAssociationId,
},
);
return GetResolverRuleAssociationResponse.fromJson(jsonResponse.body);
}