listFirewallDomainLists method
Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.
A single call to this list operation might return only a partial list of
the domain lists. For information, see MaxResults.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of objects that you want Resolver to return for this
request. If more objects are available, in the response, Resolver provides
a NextToken value that you can use in a subsequent call to
get the next batch of objects.
If you don't specify a value for MaxResults, Resolver returns
up to 100 objects.
Parameter nextToken :
For the first call to this list request, omit this value.
When you request a list of objects, Resolver returns at most the number of
objects specified in MaxResults. If more objects are
available for retrieval, Resolver returns a NextToken value
in the response. To retrieve the next batch of objects, use the token that
was returned for the prior request in your next request.
Implementation
Future<ListFirewallDomainListsResponse> listFirewallDomainLists({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.ListFirewallDomainLists'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListFirewallDomainListsResponse.fromJson(jsonResponse.body);
}