listFirewallRuleGroupAssociations method
Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.
A single call might return only a partial list of the associations. For
information, see MaxResults.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw ThrottlingException.
May throw ValidationException.
Parameter firewallRuleGroupId :
The unique identifier of the firewall rule group that you want to retrieve
the associations for. Leave this blank to retrieve associations for any
rule group.
Parameter maxResults :
The maximum number of objects that you want Resolver to return for this
request. If more objects are available, in the response, Resolver provides
a NextToken value that you can use in a subsequent call to
get the next batch of objects.
If you don't specify a value for MaxResults, Resolver returns
up to 100 objects.
Parameter nextToken :
For the first call to this list request, omit this value.
When you request a list of objects, Resolver returns at most the number of
objects specified in MaxResults. If more objects are
available for retrieval, Resolver returns a NextToken value
in the response. To retrieve the next batch of objects, use the token that
was returned for the prior request in your next request.
Parameter priority :
The setting that determines the processing order of the rule group among
the rule groups that are associated with a single VPC. DNS Firewall
filters VPC traffic starting from the rule group with the lowest numeric
priority setting.
Parameter status :
The association Status setting that you want DNS Firewall to
filter on for the list. If you don't specify this, then DNS Firewall
returns all associations, regardless of status.
Parameter vpcId :
The unique identifier of the VPC that you want to retrieve the
associations for. Leave this blank to retrieve associations for any VPC.
Implementation
Future<ListFirewallRuleGroupAssociationsResponse>
listFirewallRuleGroupAssociations({
String? firewallRuleGroupId,
int? maxResults,
String? nextToken,
int? priority,
FirewallRuleGroupAssociationStatus? status,
String? vpcId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.ListFirewallRuleGroupAssociations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (firewallRuleGroupId != null)
'FirewallRuleGroupId': firewallRuleGroupId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (priority != null) 'Priority': priority,
if (status != null) 'Status': status.value,
if (vpcId != null) 'VpcId': vpcId,
},
);
return ListFirewallRuleGroupAssociationsResponse.fromJson(
jsonResponse.body);
}