listOutpostResolvers method

Future<ListOutpostResolversResponse> listOutpostResolvers({
  1. int? maxResults,
  2. String? nextToken,
  3. String? outpostArn,
})

Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of Resolvers on the Outpost that you want to return in the response to a ListOutpostResolver request. If you don't specify a value for MaxResults, the request returns up to 100 Resolvers.

Parameter nextToken : For the first ListOutpostResolver request, omit this value.

Parameter outpostArn : The Amazon Resource Name (ARN) of the Outpost.

Implementation

Future<ListOutpostResolversResponse> listOutpostResolvers({
  int? maxResults,
  String? nextToken,
  String? outpostArn,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Resolver.ListOutpostResolvers'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (outpostArn != null) 'OutpostArn': outpostArn,
    },
  );

  return ListOutpostResolversResponse.fromJson(jsonResponse.body);
}