putResolverQueryLogConfigPolicy method
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidParameterException.
May throw InvalidPolicyDocument.
May throw InvalidRequestException.
May throw UnknownResourceException.
Parameter arn :
The Amazon Resource Name (ARN) of the account that you want to share rules
with.
Parameter resolverQueryLogConfigPolicy :
An Identity and Access Management policy statement that lists the query
logging configurations that you want to share with another Amazon Web
Services account and the operations that you want the account to be able
to perform. You can specify the following operations in the
Actions section of the statement:
-
route53resolver:AssociateResolverQueryLogConfig -
route53resolver:DisassociateResolverQueryLogConfig -
route53resolver:ListResolverQueryLogConfigs
Resource section of the statement, you specify the
ARNs for the query logging configurations that you want to share with the
account that you specified in Arn.
Implementation
Future<PutResolverQueryLogConfigPolicyResponse>
putResolverQueryLogConfigPolicy({
required String arn,
required String resolverQueryLogConfigPolicy,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.PutResolverQueryLogConfigPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Arn': arn,
'ResolverQueryLogConfigPolicy': resolverQueryLogConfigPolicy,
},
);
return PutResolverQueryLogConfigPolicyResponse.fromJson(jsonResponse.body);
}