updateFirewallConfig method
Future<UpdateFirewallConfigResponse>
updateFirewallConfig({
- required FirewallFailOpenStatus firewallFailOpen,
- required String resourceId,
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter firewallFailOpen :
Determines how Route 53 Resolver handles queries during failures, for
example when all traffic that is sent to DNS Firewall fails to receive a
reply.
- By default, fail open is disabled, which means the failure mode is closed. This approach favors security over availability. DNS Firewall blocks queries that it is unable to evaluate properly.
- If you enable this option, the failure mode is open. This approach favors availability over security. DNS Firewall allows queries to proceed if it is unable to properly evaluate them.
Parameter resourceId :
The ID of the VPC that the configuration is for.
Implementation
Future<UpdateFirewallConfigResponse> updateFirewallConfig({
required FirewallFailOpenStatus firewallFailOpen,
required String resourceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53Resolver.UpdateFirewallConfig'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FirewallFailOpen': firewallFailOpen.value,
'ResourceId': resourceId,
},
);
return UpdateFirewallConfigResponse.fromJson(jsonResponse.body);
}