updateOutpostResolver method

Future<UpdateOutpostResolverResponse> updateOutpostResolver({
  1. required String id,
  2. int? instanceCount,
  3. String? name,
  4. String? preferredInstanceType,
})

You can use UpdateOutpostResolver to update the instance count, type, or name of a Resolver on an Outpost.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter id : A unique string that identifies Resolver on an Outpost.

Parameter instanceCount : The Amazon EC2 instance count for a Resolver on the Outpost.

Parameter name : Name of the Resolver on the Outpost.

Parameter preferredInstanceType : Amazon EC2 instance type.

Implementation

Future<UpdateOutpostResolverResponse> updateOutpostResolver({
  required String id,
  int? instanceCount,
  String? name,
  String? preferredInstanceType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53Resolver.UpdateOutpostResolver'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      if (instanceCount != null) 'InstanceCount': instanceCount,
      if (name != null) 'Name': name,
      if (preferredInstanceType != null)
        'PreferredInstanceType': preferredInstanceType,
    },
  );

  return UpdateOutpostResolverResponse.fromJson(jsonResponse.body);
}