RtbFabric class

Amazon Web Services RTB Fabric provides secure, low-latency infrastructure for connecting real-time bidding (RTB) applications. Rather than hosting applications directly, RTB Fabric acts as the connecting fabric that enables your applications to communicate efficiently over private networks instead of the public internet. You maintain complete control over your applications, data, and bidding decisions, while RTB Fabric provides the underlying infrastructure for secure, reliable connectivity.

You can use these APIs to complete RTB Fabric tasks, such as setting up audit log ingestions or viewing user access. For more information about RTB Fabric, including the required permissions to use the service, see the Amazon Web Services RTB Fabric User Guide.

Constructors

RtbFabric({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Accepts a link request between gateways.
associateCertificate({required String acmCertificateArn, required String gatewayId, String? clientToken}) Future<AssociateCertificateResponse>
Associates an ACM certificate with a responder gateway.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
Creates an inbound external link.
Creates a new link between gateways.
createLinkRoutingRule({required RuleCondition conditions, required String gatewayId, required String linkId, required int priority, String? clientToken, Map<String, String>? tags}) Future<CreateLinkRoutingRuleResponse>
Creates a routing rule for a link.
Creates an outbound external link.
createRequesterGateway({required List<String> securityGroupIds, required List<String> subnetIds, required String vpcId, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateRequesterGatewayResponse>
Creates a requester gateway.
createResponderGateway({required int port, required Protocol protocol, required List<String> securityGroupIds, required List<String> subnetIds, required String vpcId, String? clientToken, String? description, String? domainName, GatewayType? gatewayType, ListenerConfig? listenerConfig, ManagedEndpointConfiguration? managedEndpointConfiguration, Map<String, String>? tags, TrustStoreConfiguration? trustStoreConfiguration}) Future<CreateResponderGatewayResponse>
Creates a responder gateway.
Deletes an inbound external link.
Deletes a link between gateways.
deleteLinkRoutingRule({required String gatewayId, required String linkId, required String ruleId}) Future<DeleteLinkRoutingRuleResponse>
Deletes a routing rule from a link.
Deletes an outbound external link.
deleteRequesterGateway({required String gatewayId}) Future<DeleteRequesterGatewayResponse>
Deletes a requester gateway.
deleteResponderGateway({required String gatewayId}) Future<DeleteResponderGatewayResponse>
Deletes a responder gateway.
disassociateCertificate({required String acmCertificateArn, required String gatewayId}) Future<DisassociateCertificateResponse>
Removes a certificate association from a responder gateway.
getCertificateAssociation({required String acmCertificateArn, required String gatewayId}) Future<GetCertificateAssociationResponse>
Retrieves the details of a certificate association with a responder gateway.
Retrieves information about an inbound external link.
Retrieves information about a link between gateways.
getLinkRoutingRule({required String gatewayId, required String linkId, required String ruleId}) Future<GetLinkRoutingRuleResponse>
Retrieves the details of a routing rule for a link.
Retrieves information about an outbound external link.
getRequesterGateway({required String gatewayId}) Future<GetRequesterGatewayResponse>
Retrieves information about a requester gateway.
getResponderGateway({required String gatewayId}) Future<GetResponderGatewayResponse>
Retrieves information about a responder gateway.
listCertificateAssociations({required String gatewayId, int? maxResults, String? nextToken}) Future<ListCertificateAssociationsResponse>
Lists the certificate associations for a responder gateway.
listLinkRoutingRules({required String gatewayId, required String linkId, int? maxResults, String? nextToken}) Future<ListLinkRoutingRulesResponse>
Lists the routing rules for a link.
Lists links associated with gateways.
listRequesterGateways({int? maxResults, String? nextToken}) Future<ListRequesterGatewaysResponse>
Lists requester gateways.
listResponderGateways({int? maxResults, String? nextToken}) Future<ListResponderGatewaysResponse>
Lists reponder gateways.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists tags for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Rejects a link request between gateways.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one or more tags (key-value pairs) to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag or tags from a resource.
Updates the configuration of a link between gateways.
updateLinkModuleFlow({required String gatewayId, required String linkId, required List<ModuleConfiguration> modules, String? clientToken}) Future<UpdateLinkModuleFlowResponse>
Updates a link module flow.
updateLinkRoutingRule({required RuleCondition conditions, required String gatewayId, required String linkId, required int priority, required String ruleId}) Future<UpdateLinkRoutingRuleResponse>
Updates a routing rule for a link.
updateRequesterGateway({required String gatewayId, String? clientToken, String? description}) Future<UpdateRequesterGatewayResponse>
Updates a requester gateway.
updateResponderGateway({required String gatewayId, required int port, required Protocol protocol, String? clientToken, String? description, String? domainName, ListenerConfig? listenerConfig, ManagedEndpointConfiguration? managedEndpointConfiguration, TrustStoreConfiguration? trustStoreConfiguration}) Future<UpdateResponderGatewayResponse>
Updates a responder gateway.

Operators

operator ==(Object other) bool
The equality operator.
inherited