createRequesterGateway method

Future<CreateRequesterGatewayResponse> createRequesterGateway({
  1. required List<String> securityGroupIds,
  2. required List<String> subnetIds,
  3. required String vpcId,
  4. String? clientToken,
  5. String? description,
  6. Map<String, String>? tags,
})

Creates a requester gateway.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter securityGroupIds : The unique identifiers of the security groups.

Parameter subnetIds : The unique identifiers of the subnets.

Parameter vpcId : The unique identifier of the Virtual Private Cloud (VPC).

Parameter clientToken : The unique client token.

Parameter description : An optional description for the requester gateway.

Parameter tags : A map of the key-value pairs of the tag or tags to assign to the resource.

Implementation

Future<CreateRequesterGatewayResponse> createRequesterGateway({
  required List<String> securityGroupIds,
  required List<String> subnetIds,
  required String vpcId,
  String? clientToken,
  String? description,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'securityGroupIds': securityGroupIds,
    'subnetIds': subnetIds,
    'vpcId': vpcId,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (description != null) 'description': description,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/requester-gateway',
    exceptionFnMap: _exceptionFns,
  );
  return CreateRequesterGatewayResponse.fromJson(response);
}