Rum class

With Amazon CloudWatch RUM, you can perform real-user monitoring to collect client-side data about your web application performance from actual user sessions in real time. The data collected includes page load times, client-side errors, and user behavior. When you view this data, you can see it all aggregated together and also see breakdowns by the browsers and devices that your customers use.

You can use the collected data to quickly identify and debug client-side performance issues. CloudWatch RUM helps you visualize anomalies in your application performance and find relevant debugging data such as error messages, stack traces, and user sessions. You can also use RUM to understand the range of end-user impact including the number of users, geolocations, and browsers used.

Constructors

Rum({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchCreateRumMetricDefinitions({required String appMonitorName, required MetricDestination destination, required List<MetricDefinitionRequest> metricDefinitions, String? destinationArn}) Future<BatchCreateRumMetricDefinitionsResponse>
Specifies the extended metrics and custom metrics that you want a CloudWatch RUM app monitor to send to a destination. Valid destinations include CloudWatch and Evidently.
batchDeleteRumMetricDefinitions({required String appMonitorName, required MetricDestination destination, required List<String> metricDefinitionIds, String? destinationArn}) Future<BatchDeleteRumMetricDefinitionsResponse>
Removes the specified metrics from being sent to an extended metrics destination.
batchGetRumMetricDefinitions({required String appMonitorName, required MetricDestination destination, String? destinationArn, int? maxResults, String? nextToken}) Future<BatchGetRumMetricDefinitionsResponse>
Retrieves the list of metrics and dimensions that a RUM app monitor is sending to a single destination.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAppMonitor({required String name, AppMonitorConfiguration? appMonitorConfiguration, CustomEvents? customEvents, bool? cwLogEnabled, DeobfuscationConfiguration? deobfuscationConfiguration, String? domain, List<String>? domainList, AppMonitorPlatform? platform, Map<String, String>? tags}) Future<CreateAppMonitorResponse>
Creates a Amazon CloudWatch RUM app monitor, which collects telemetry data from your application and sends that data to RUM. The data includes performance and reliability information such as page load time, client-side errors, and user behavior.
deleteAppMonitor({required String name}) Future<void>
Deletes an existing app monitor. This immediately stops the collection of data.
deleteResourcePolicy({required String name, String? policyRevisionId}) Future<DeleteResourcePolicyResponse>
Removes the association of a resource-based policy from an app monitor.
deleteRumMetricsDestination({required String appMonitorName, required MetricDestination destination, String? destinationArn}) Future<void>
Deletes a destination for CloudWatch RUM extended metrics, so that the specified app monitor stops sending extended metrics to that destination.
getAppMonitor({required String name}) Future<GetAppMonitorResponse>
Retrieves the complete configuration information for one app monitor.
getAppMonitorData({required String name, required TimeRange timeRange, List<QueryFilter>? filters, int? maxResults, String? nextToken}) Future<GetAppMonitorDataResponse>
Retrieves the raw performance events that RUM has collected from your web application, so that you can do your own processing or analysis of this data.
getResourcePolicy({required String name}) Future<GetResourcePolicyResponse>
Use this operation to retrieve information about a resource-based policy that is attached to an app monitor.
listAppMonitors({int? maxResults, String? nextToken}) Future<ListAppMonitorsResponse>
Returns a list of the Amazon CloudWatch RUM app monitors in the account.
listRumMetricsDestinations({required String appMonitorName, int? maxResults, String? nextToken}) Future<ListRumMetricsDestinationsResponse>
Returns a list of destinations that you have created to receive RUM extended metrics, for the specified app monitor.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Displays the tags associated with a CloudWatch RUM resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putResourcePolicy({required String name, required String policyDocument, String? policyRevisionId}) Future<PutResourcePolicyResponse>
Use this operation to assign a resource-based policy to a CloudWatch RUM app monitor to control access to it. Each app monitor can have one resource-based policy. The maximum size of the policy is 4 KB. To learn more about using resource policies with RUM, see Using resource-based policies with CloudWatch RUM.
putRumEvents({required AppMonitorDetails appMonitorDetails, required String batchId, required String id, required List<RumEvent> rumEvents, required UserDetails userDetails, String? alias}) Future<void>
Sends telemetry events about your application performance and user behavior to CloudWatch RUM. The code snippet that RUM generates for you to add to your application includes PutRumEvents operations to send this data to RUM.
putRumMetricsDestination({required String appMonitorName, required MetricDestination destination, String? destinationArn, String? iamRoleArn}) Future<void>
Creates or updates a destination to receive extended metrics from CloudWatch RUM. You can send extended metrics to CloudWatch or to a CloudWatch Evidently experiment.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM resource. Currently, the only resources that can be tagged app monitors.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from the specified resource.
updateAppMonitor({required String name, AppMonitorConfiguration? appMonitorConfiguration, CustomEvents? customEvents, bool? cwLogEnabled, DeobfuscationConfiguration? deobfuscationConfiguration, String? domain, List<String>? domainList}) Future<void>
Updates the configuration of an existing app monitor. When you use this operation, only the parts of the app monitor configuration that you specify in this operation are changed. For any parameters that you omit, the existing values are kept.
updateRumMetricDefinition({required String appMonitorName, required MetricDestination destination, required MetricDefinitionRequest metricDefinition, required String metricDefinitionId, String? destinationArn}) Future<void>
Modifies one existing metric definition for CloudWatch RUM extended metrics. For more information about extended metrics, see BatchCreateRumMetricsDefinitions.

Operators

operator ==(Object other) bool
The equality operator.
inherited