deleteRumMetricsDestination method

Future<void> deleteRumMetricsDestination({
  1. required String appMonitorName,
  2. required MetricDestination destination,
  3. String? destinationArn,
})

Deletes a destination for CloudWatch RUM extended metrics, so that the specified app monitor stops sending extended metrics to that destination.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter appMonitorName : The name of the app monitor that is sending metrics to the destination that you want to delete.

Parameter destination : The type of destination to delete. Valid values are CloudWatch and Evidently.

Parameter destinationArn : This parameter is required if Destination is Evidently. If Destination is CloudWatch, do not use this parameter. This parameter specifies the ARN of the Evidently experiment that corresponds to the destination to delete.

Implementation

Future<void> deleteRumMetricsDestination({
  required String appMonitorName,
  required MetricDestination destination,
  String? destinationArn,
}) async {
  final $query = <String, List<String>>{
    'destination': [destination.value],
    if (destinationArn != null) 'destinationArn': [destinationArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/rummetrics/${Uri.encodeComponent(appMonitorName)}/metricsdestination',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}