getResourcePolicy method
Use this operation to retrieve information about a resource-based policy that is attached to an app monitor.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw PolicyNotFoundException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the app monitor that is associated with the resource-based
policy that you want to view.
Implementation
Future<GetResourcePolicyResponse> getResourcePolicy({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/appmonitor/${Uri.encodeComponent(name)}/policy',
exceptionFnMap: _exceptionFns,
);
return GetResourcePolicyResponse.fromJson(response);
}