completeMultipartUpload method
- required String bucket,
- required String key,
- required String uploadId,
- String? checksumCRC32,
- String? checksumCRC32C,
- String? checksumCRC64NVME,
- String? checksumMD5,
- String? checksumSHA1,
- String? checksumSHA256,
- String? checksumSHA512,
- ChecksumType? checksumType,
- String? checksumXXHASH128,
- String? checksumXXHASH3,
- String? checksumXXHASH64,
- String? expectedBucketOwner,
- String? ifMatch,
- String? ifNoneMatch,
- int? mpuObjectSize,
- CompletedMultipartUpload? multipartUpload,
- RequestPayer? requestPayer,
- String? sSECustomerAlgorithm,
- String? sSECustomerKey,
- String? sSECustomerKeyMD5,
Completes a multipart upload by assembling previously uploaded parts.
You first initiate the multipart upload and then upload all parts using
the UploadPart
operation or the UploadPartCopy
operation. After successfully uploading all relevant parts of an upload,
you call this CompleteMultipartUpload operation to complete
the upload. Upon receiving this request, Amazon S3 concatenates all the
parts in ascending order by part number to create a new object. In the
CompleteMultipartUpload request, you must provide the parts list and
ensure that the parts list is complete. The CompleteMultipartUpload API
operation concatenates the parts that you provide in the list. For each
part in the list, you must provide the PartNumber value and
the ETag value that are returned after that part was
uploaded.
The processing of a CompleteMultipartUpload request could take several
minutes to finalize. After Amazon S3 begins processing the request, it
sends an HTTP response header that specifies a 200 OK
response. While processing is in progress, Amazon S3 periodically sends
white space characters to keep the connection from timing out. A request
could fail after the initial 200 OK response has been sent.
This means that a 200 OK response can contain either a
success or an error. The error response might be embedded in the 200
OK response. If you call this API operation directly, make sure to
design your application to parse the contents of the response and handle
it appropriately. If you use Amazon Web Services SDKs, SDKs handle this
condition. The SDKs detect the embedded error and apply error handling per
your configuration settings (including automatically retrying the request
as appropriate). If the condition persists, the SDKs throw an exception
(or, for the SDKs that don't use exceptions, they return an error).
Note that if CompleteMultipartUpload fails, applications
should be prepared to retry any failed requests (including 500 error
responses). For more information, see Amazon
S3 Error Best Practices.
For more information about multipart uploads, see Uploading
Objects Using Multipart Upload in the Amazon S3 User Guide.
- Permissions
-
-
General purpose bucket permissions - For information about
permissions required to use the multipart upload API, see Multipart
Upload and Permissions in the Amazon S3 User Guide.
If you provide an additional checksum value in your
MultipartUploadrequests and the object is encrypted with Key Management Service, you must have permission to use thekms:Decryptaction for theCompleteMultipartUploadrequest to succeed. -
Directory bucket permissions - To grant access to this API
operation on a directory bucket, we recommend that you use the
CreateSessionAPI operation for session-based authorization. Specifically, you grant thes3express:CreateSessionpermission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make theCreateSessionAPI call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make anotherCreateSessionAPI call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, seeCreateSession.If the object is encrypted with SSE-KMS, you must also have the
kms:GenerateDataKeyandkms:Decryptpermissions in IAM identity-based policies and KMS key policies for the KMS key.
-
General purpose bucket permissions - For information about
permissions required to use the multipart upload API, see Multipart
Upload and Permissions in the Amazon S3 User Guide.
- Special errors
-
-
Error Code:
EntityTooSmall- Description: Your proposed upload is smaller than the minimum allowed object size. Each part must be at least 5 MB in size, except the last part.
- HTTP Status Code: 400 Bad Request
-
Error Code:
InvalidPart- Description: One or more of the specified parts could not be found. The part might not have been uploaded, or the specified ETag might not have matched the uploaded part's ETag.
- HTTP Status Code: 400 Bad Request
-
Error Code:
InvalidPartOrder- Description: The list of parts was not in ascending order. The parts list must be specified in order by part number.
- HTTP Status Code: 400 Bad Request
-
Error Code:
NoSuchUpload- Description: The specified multipart upload does not exist. The upload ID might be invalid, or the multipart upload might have been aborted or completed.
- HTTP Status Code: 404 Not Found
-
Error Code:
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
CompleteMultipartUpload:
Parameter bucket :
Name of the bucket to which the multipart upload was initiated.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter key :
Object key for which the multipart upload was initiated.
Parameter uploadId :
ID for the initiated multipart upload.
Parameter checksumCRC32 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 32-bit CRC32 checksum of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumCRC32C :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 32-bit CRC32C checksum of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumCRC64NVME :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit CRC64NVME checksum of the object.
The CRC64NVME checksum is always a full object checksum. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumMD5 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit MD5 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA1 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 160-bit SHA1 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA256 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 256-bit SHA256 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA512 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 512-bit SHA512 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumType :
This header specifies the checksum type of the object, which determines
how part-level checksums are combined to create an object-level checksum
for multipart objects. You can use this header as a data integrity check
to verify that the checksum type that is received is the same checksum
that was specified. If the checksum type doesn’t match the checksum type
that was specified for the object during the
CreateMultipartUpload request, it’ll result in a
BadDigest error. For more information, see Checking object
integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH128 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit XXHASH128 checksum of the object.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH3 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH3 checksum of the object.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH64 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH64 checksum of the object.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter ifMatch :
Uploads the object only if the ETag (entity tag) value provided during the
WRITE operation matches the ETag of the object in S3. If the ETag values
do not match, the operation returns a 412 Precondition Failed
error.
If a conflicting operation occurs during the upload S3 returns a 409
ConditionalRequestConflict response. On a 409 failure you should
fetch the object's ETag, re-initiate the multipart upload with
CreateMultipartUpload, and re-upload each part.
Expects the ETag value as a string.
For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide.
Parameter ifNoneMatch :
Uploads the object only if the object key name does not already exist in
the bucket specified. Otherwise, Amazon S3 returns a 412
Precondition Failed error.
If a conflicting operation occurs during the upload S3 returns a 409
ConditionalRequestConflict response. On a 409 failure you should
re-initiate the multipart upload with CreateMultipartUpload
and re-upload each part.
Expects the '*' (asterisk) character.
For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide.
Parameter mpuObjectSize :
The expected total object size of the multipart upload request. If there’s
a mismatch between the specified object size value and the actual object
size value, it results in an HTTP 400 InvalidRequest error.
Parameter multipartUpload :
The container for the multipart upload request information.
Parameter sSECustomerAlgorithm :
The server-side encryption (SSE) algorithm used to encrypt the object.
This parameter is required only when the object was created using a
checksum algorithm or if your bucket policy requires the use of SSE-C. For
more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Parameter sSECustomerKey :
The server-side encryption (SSE) customer managed key. This parameter is
needed only when the object was created using a checksum algorithm. For
more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Parameter sSECustomerKeyMD5 :
The MD5 server-side encryption (SSE) customer managed key. This parameter
is needed only when the object was created using a checksum algorithm. For
more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Implementation
Future<CompleteMultipartUploadOutput> completeMultipartUpload({
required String bucket,
required String key,
required String uploadId,
String? checksumCRC32,
String? checksumCRC32C,
String? checksumCRC64NVME,
String? checksumMD5,
String? checksumSHA1,
String? checksumSHA256,
String? checksumSHA512,
ChecksumType? checksumType,
String? checksumXXHASH128,
String? checksumXXHASH3,
String? checksumXXHASH64,
String? expectedBucketOwner,
String? ifMatch,
String? ifNoneMatch,
int? mpuObjectSize,
CompletedMultipartUpload? multipartUpload,
RequestPayer? requestPayer,
String? sSECustomerAlgorithm,
String? sSECustomerKey,
String? sSECustomerKeyMD5,
}) async {
final headers = <String, String>{
if (checksumCRC32 != null)
'x-amz-checksum-crc32': checksumCRC32.toString(),
if (checksumCRC32C != null)
'x-amz-checksum-crc32c': checksumCRC32C.toString(),
if (checksumCRC64NVME != null)
'x-amz-checksum-crc64nvme': checksumCRC64NVME.toString(),
if (checksumMD5 != null) 'x-amz-checksum-md5': checksumMD5.toString(),
if (checksumSHA1 != null) 'x-amz-checksum-sha1': checksumSHA1.toString(),
if (checksumSHA256 != null)
'x-amz-checksum-sha256': checksumSHA256.toString(),
if (checksumSHA512 != null)
'x-amz-checksum-sha512': checksumSHA512.toString(),
if (checksumType != null) 'x-amz-checksum-type': checksumType.value,
if (checksumXXHASH128 != null)
'x-amz-checksum-xxhash128': checksumXXHASH128.toString(),
if (checksumXXHASH3 != null)
'x-amz-checksum-xxhash3': checksumXXHASH3.toString(),
if (checksumXXHASH64 != null)
'x-amz-checksum-xxhash64': checksumXXHASH64.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (ifMatch != null) 'If-Match': ifMatch.toString(),
if (ifNoneMatch != null) 'If-None-Match': ifNoneMatch.toString(),
if (mpuObjectSize != null)
'x-amz-mp-object-size': mpuObjectSize.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
if (sSECustomerAlgorithm != null)
'x-amz-server-side-encryption-customer-algorithm':
sSECustomerAlgorithm.toString(),
if (sSECustomerKey != null)
'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
if (sSECustomerKeyMD5 != null)
'x-amz-server-side-encryption-customer-key-MD5':
sSECustomerKeyMD5.toString(),
};
final $query = <String, List<String>>{
'uploadId': [uploadId],
};
final $result = await _protocol.sendRaw(
method: 'POST',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}',
queryParams: $query,
headers: headers,
payload: multipartUpload?.toXml('CompleteMultipartUpload'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return CompleteMultipartUploadOutput(
bucket: _s.extractXmlStringValue($elem, 'Bucket'),
checksumCRC32: _s.extractXmlStringValue($elem, 'ChecksumCRC32'),
checksumCRC32C: _s.extractXmlStringValue($elem, 'ChecksumCRC32C'),
checksumCRC64NVME: _s.extractXmlStringValue($elem, 'ChecksumCRC64NVME'),
checksumMD5: _s.extractXmlStringValue($elem, 'ChecksumMD5'),
checksumSHA1: _s.extractXmlStringValue($elem, 'ChecksumSHA1'),
checksumSHA256: _s.extractXmlStringValue($elem, 'ChecksumSHA256'),
checksumSHA512: _s.extractXmlStringValue($elem, 'ChecksumSHA512'),
checksumType: _s
.extractXmlStringValue($elem, 'ChecksumType')
?.let(ChecksumType.fromString),
checksumXXHASH128: _s.extractXmlStringValue($elem, 'ChecksumXXHASH128'),
checksumXXHASH3: _s.extractXmlStringValue($elem, 'ChecksumXXHASH3'),
checksumXXHASH64: _s.extractXmlStringValue($elem, 'ChecksumXXHASH64'),
eTag: _s.extractXmlStringValue($elem, 'ETag'),
key: _s.extractXmlStringValue($elem, 'Key'),
location: _s.extractXmlStringValue($elem, 'Location'),
bucketKeyEnabled: _s.extractHeaderBoolValue(
$result.headers, 'x-amz-server-side-encryption-bucket-key-enabled'),
expiration:
_s.extractHeaderStringValue($result.headers, 'x-amz-expiration'),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
sSEKMSKeyId: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-aws-kms-key-id'),
serverSideEncryption: _s
.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption')
?.let(ServerSideEncryption.fromString),
versionId:
_s.extractHeaderStringValue($result.headers, 'x-amz-version-id'),
);
}