deleteBucketWebsite method
200 OK response upon successfully deleting a
website configuration on the specified bucket. You will get a 200
OK response if the website configuration you are trying to delete
does not exist on the bucket. Amazon S3 returns a 404
response if the bucket specified in the request does not exist.
This DELETE action requires the S3:DeleteBucketWebsite
permission. By default, only the bucket owner can delete the website
configuration attached to a bucket. However, bucket owners can grant other
users permission to delete the website configuration by writing a bucket
policy granting them the S3:DeleteBucketWebsite permission.
For more information about hosting websites, see Hosting Websites on Amazon S3.
The following operations are related to DeleteBucketWebsite:
Parameter bucket :
The bucket name for which you want to remove the website configuration.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deleteBucketWebsite({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?website',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}