getBucketAnalyticsConfiguration method

Future<GetBucketAnalyticsConfigurationOutput> getBucketAnalyticsConfiguration({
  1. required String bucket,
  2. required String id,
  3. String? expectedBucketOwner,
})
This implementation of the GET action returns an analytics configuration (identified by the analytics configuration ID) from the bucket.

To use this operation, you must have permissions to perform the s3:GetAnalyticsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources in the Amazon S3 User Guide.

For information about Amazon S3 analytics feature, see Amazon S3 Analytics – Storage Class Analysis in the Amazon S3 User Guide.

The following operations are related to GetBucketAnalyticsConfiguration:

Parameter bucket : The name of the bucket from which an analytics configuration is retrieved.

Parameter id : The ID that identifies the analytics configuration.

Parameter expectedBucketOwner : The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Implementation

Future<GetBucketAnalyticsConfigurationOutput>
    getBucketAnalyticsConfiguration({
  required String bucket,
  required String id,
  String? expectedBucketOwner,
}) async {
  final headers = <String, String>{
    if (expectedBucketOwner != null)
      'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
  };
  final $query = <String, List<String>>{
    'id': [id],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri:
        '/${Uri.encodeComponent(bucket)}?analytics&x-id=GetBucketAnalyticsConfiguration',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return GetBucketAnalyticsConfigurationOutput(
    analyticsConfiguration: AnalyticsConfiguration.fromXml($elem),
  );
}