getBucketOwnershipControls method

Future<GetBucketOwnershipControlsOutput> getBucketOwnershipControls({
  1. required String bucket,
  2. String? expectedBucketOwner,
})
Retrieves OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:GetBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying permissions in a policy. For information about Amazon S3 Object Ownership, see Using Object Ownership.

The following operations are related to GetBucketOwnershipControls:

Parameter bucket : The name of the Amazon S3 bucket whose OwnershipControls you want to retrieve.

Parameter expectedBucketOwner : The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Implementation

Future<GetBucketOwnershipControlsOutput> getBucketOwnershipControls({
  required String bucket,
  String? expectedBucketOwner,
}) async {
  final headers = <String, String>{
    if (expectedBucketOwner != null)
      'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri: '/${Uri.encodeComponent(bucket)}?ownershipControls',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return GetBucketOwnershipControlsOutput(
    ownershipControls: OwnershipControls.fromXml($elem),
  );
}