getObject method

Future<GetObjectOutput> getObject({
  1. required String bucket,
  2. required String key,
  3. ChecksumMode? checksumMode,
  4. String? expectedBucketOwner,
  5. String? ifMatch,
  6. DateTime? ifModifiedSince,
  7. String? ifNoneMatch,
  8. DateTime? ifUnmodifiedSince,
  9. int? partNumber,
  10. String? range,
  11. RequestPayer? requestPayer,
  12. String? responseCacheControl,
  13. String? responseContentDisposition,
  14. String? responseContentEncoding,
  15. String? responseContentLanguage,
  16. String? responseContentType,
  17. DateTime? responseExpires,
  18. String? sSECustomerAlgorithm,
  19. String? sSECustomerKey,
  20. String? sSECustomerKeyMD5,
  21. String? versionId,
})

Retrieves an object from Amazon S3.

In the GetObject request, specify the full key name for the object.

General purpose buckets - Both the virtual-hosted-style requests and the path-style requests are supported. For a virtual hosted-style request example, if you have the object photos/2006/February/sample.jpg, specify the object key name as /photos/2006/February/sample.jpg. For a path-style request example, if you have the object photos/2006/February/sample.jpg in the bucket named examplebucket, specify the object key name as /examplebucket/photos/2006/February/sample.jpg. For more information about request types, see HTTP Host Header Bucket Specification in the Amazon S3 User Guide.

Directory buckets - Only virtual-hosted-style requests are supported. For a virtual hosted-style request example, if you have the object photos/2006/February/sample.jpg in the bucket named amzn-s3-demo-bucket--usw2-az1--x-s3, specify the object key name as /photos/2006/February/sample.jpg. Also, when you make requests to this API operation, your requests are sent to the Zonal endpoint. These endpoints support virtual-hosted-style requests in the format https://bucket-name.s3express-zone-id.region-code.amazonaws.com/key-name . Path-style requests are not supported. For more information about endpoints in Availability Zones, see Regional and Zonal endpoints for directory buckets in Availability Zones in the Amazon S3 User Guide. For more information about endpoints in Local Zones, see Concepts for directory buckets in Local Zones in the Amazon S3 User Guide.

Permissions
  • General purpose bucket permissions - You must have the required permissions in a policy. To use GetObject, you must have the READ access to the object (or version). If you grant READ access to the anonymous user, the GetObject operation returns the object without using an authorization header. For more information, see Specifying permissions in a policy in the Amazon S3 User Guide.

    If you include a versionId in your request header, you must have the s3:GetObjectVersion permission to access a specific version of an object. The s3:GetObject permission is not required in this scenario.

    If you request the current version of an object without a specific versionId in the request header, only the s3:GetObject permission is required. The s3:GetObjectVersion permission is not required in this scenario.

    If the object that you request doesn’t exist, the error that Amazon S3 returns depends on whether you also have the s3:ListBucket permission.

    • If you have the s3:ListBucket permission on the bucket, Amazon S3 returns an HTTP status code 404 Not Found error.
    • If you don’t have the s3:ListBucket permission, Amazon S3 returns an HTTP status code 403 Access Denied error.
  • Directory bucket permissions - To grant access to this API operation on a directory bucket, we recommend that you use the CreateSession API operation for session-based authorization. Specifically, you grant the s3express:CreateSession permission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make the CreateSession API call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make another CreateSession API call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, see CreateSession .

    If the object is encrypted using SSE-KMS, you must also have the kms:GenerateDataKey and kms:Decrypt permissions in IAM identity-based policies and KMS key policies for the KMS key.

Storage classes
If the object you are retrieving is stored in the S3 Glacier Flexible Retrieval storage class, the S3 Glacier Deep Archive storage class, the S3 Intelligent-Tiering Archive Access tier, or the S3 Intelligent-Tiering Deep Archive Access tier, before you can retrieve the object you must first restore a copy using RestoreObject. Otherwise, this operation returns an InvalidObjectState error. For information about restoring archived objects, see Restoring Archived Objects in the Amazon S3 User Guide.

Directory buckets - Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones. Unsupported storage class values won't write a destination object and will respond with the HTTP status code 400 Bad Request.

Encryption
Encryption request headers, like x-amz-server-side-encryption, should not be sent for the GetObject requests, if your object uses server-side encryption with Amazon S3 managed encryption keys (SSE-S3), server-side encryption with Key Management Service (KMS) keys (SSE-KMS), or dual-layer server-side encryption with Amazon Web Services KMS keys (DSSE-KMS). If you include the header in your GetObject requests for the object that uses these types of keys, you’ll get an HTTP 400 Bad Request error.

Directory buckets - For directory buckets, there are only two supported options for server-side encryption: SSE-S3 and SSE-KMS. SSE-C isn't supported. For more information, see Protecting data with server-side encryption in the Amazon S3 User Guide.

Overriding response header values through the request
There are times when you want to override certain response header values of a GetObject response. For example, you might override the Content-Disposition response header value through your GetObject request.

You can override values for a set of response headers. These modified response header values are included only in a successful response, that is, when the HTTP status code 200 OK is returned. The headers you can override using the following query parameters in the request are a subset of the headers that Amazon S3 accepts when you create an object.

The response headers that you can override for the GetObject response are Cache-Control, Content-Disposition, Content-Encoding, Content-Language, Content-Type, and Expires.

To override values for a set of response headers in the GetObject response, you can use the following query parameters in the request.

  • response-cache-control
  • response-content-disposition
  • response-content-encoding
  • response-content-language
  • response-content-type
  • response-expires
HTTP Host header syntax
Directory buckets - The HTTP Host header syntax is Bucket-name.s3express-zone-id.region-code.amazonaws.com.
The following operations are related to GetObject:

May throw InvalidObjectState. May throw NoSuchKey.

Parameter bucket : The bucket name containing the object.

Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.

Object Lambda access points - When you use this action with an Object Lambda access point, you must direct requests to the Object Lambda access point hostname. The Object Lambda access point hostname takes the form AccessPointName-AccountId.s3-object-lambda.Region.amazonaws.com. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see What is S3 on Outposts? in the Amazon S3 User Guide.

Parameter key : Key of the object to get.

Parameter checksumMode : To retrieve the checksum, this mode must be enabled.

Parameter expectedBucketOwner : The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Parameter ifMatch : Return the object only if its entity tag (ETag) is the same as the one specified in this header; otherwise, return a 412 Precondition Failed error.

If both of the If-Match and If-Unmodified-Since headers are present in the request as follows: If-Match condition evaluates to true, and; If-Unmodified-Since condition evaluates to false; then, S3 returns 200 OK and the data requested.

For more information about conditional requests, see RFC 7232.

Parameter ifModifiedSince : Return the object only if it has been modified since the specified time; otherwise, return a 304 Not Modified error.

If both of the If-None-Match and If-Modified-Since headers are present in the request as follows: If-None-Match condition evaluates to false, and; If-Modified-Since condition evaluates to true; then, S3 returns 304 Not Modified status code.

For more information about conditional requests, see RFC 7232.

Parameter ifNoneMatch : Return the object only if its entity tag (ETag) is different from the one specified in this header; otherwise, return a 304 Not Modified error.

If both of the If-None-Match and If-Modified-Since headers are present in the request as follows: If-None-Match condition evaluates to false, and; If-Modified-Since condition evaluates to true; then, S3 returns 304 Not Modified HTTP status code.

For more information about conditional requests, see RFC 7232.

Parameter ifUnmodifiedSince : Return the object only if it has not been modified since the specified time; otherwise, return a 412 Precondition Failed error.

If both of the If-Match and If-Unmodified-Since headers are present in the request as follows: If-Match condition evaluates to true, and; If-Unmodified-Since condition evaluates to false; then, S3 returns 200 OK and the data requested.

For more information about conditional requests, see RFC 7232.

Parameter partNumber : Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a 'ranged' GET request for the part specified. Useful for downloading just a part of an object.

Parameter range : Downloads the specified byte range of an object. For more information about the HTTP Range header, see https://www.rfc-editor.org/rfc/rfc9110.html#name-range.

Parameter responseCacheControl : Sets the Cache-Control header of the response.

Parameter responseContentDisposition : Sets the Content-Disposition header of the response.

Parameter responseContentEncoding : Sets the Content-Encoding header of the response.

Parameter responseContentLanguage : Sets the Content-Language header of the response.

Parameter responseContentType : Sets the Content-Type header of the response.

Parameter responseExpires : Sets the Expires header of the response.

Parameter sSECustomerAlgorithm : Specifies the algorithm to use when decrypting the object (for example, AES256).

If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

  • x-amz-server-side-encryption-customer-algorithm
  • x-amz-server-side-encryption-customer-key
  • x-amz-server-side-encryption-customer-key-MD5
For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide.

Parameter sSECustomerKey : Specifies the customer-provided encryption key that you originally provided for Amazon S3 to encrypt the data before storing it. This value is used to decrypt the object when recovering it and must match the one used when storing the data. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header.

If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

  • x-amz-server-side-encryption-customer-algorithm
  • x-amz-server-side-encryption-customer-key
  • x-amz-server-side-encryption-customer-key-MD5
For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide.

Parameter sSECustomerKeyMD5 : Specifies the 128-bit MD5 digest of the customer-provided encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you GET the object, you must use the following headers:

  • x-amz-server-side-encryption-customer-algorithm
  • x-amz-server-side-encryption-customer-key
  • x-amz-server-side-encryption-customer-key-MD5
For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide.

Parameter versionId : Version ID used to reference a specific version of the object.

By default, the GetObject operation returns the current version of an object. To return a different version, use the versionId subresource.

  • If you include a versionId in your request header, you must have the s3:GetObjectVersion permission to access a specific version of an object. The s3:GetObject permission is not required in this scenario.
  • If you request the current version of an object without a specific versionId in the request header, only the s3:GetObject permission is required. The s3:GetObjectVersion permission is not required in this scenario.
  • Directory buckets - S3 Versioning isn't enabled and supported for directory buckets. For this API operation, only the null value of the version ID is supported by directory buckets. You can only specify null to the versionId query parameter in the request.
For more information about versioning, see PutBucketVersioning.

Implementation

Future<GetObjectOutput> getObject({
  required String bucket,
  required String key,
  ChecksumMode? checksumMode,
  String? expectedBucketOwner,
  String? ifMatch,
  DateTime? ifModifiedSince,
  String? ifNoneMatch,
  DateTime? ifUnmodifiedSince,
  int? partNumber,
  String? range,
  RequestPayer? requestPayer,
  String? responseCacheControl,
  String? responseContentDisposition,
  String? responseContentEncoding,
  String? responseContentLanguage,
  String? responseContentType,
  DateTime? responseExpires,
  String? sSECustomerAlgorithm,
  String? sSECustomerKey,
  String? sSECustomerKeyMD5,
  String? versionId,
}) async {
  final headers = <String, String>{
    if (checksumMode != null) 'x-amz-checksum-mode': checksumMode.value,
    if (expectedBucketOwner != null)
      'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
    if (ifMatch != null) 'If-Match': ifMatch.toString(),
    if (ifModifiedSince != null)
      'If-Modified-Since': _s.rfc822ToJson(ifModifiedSince),
    if (ifNoneMatch != null) 'If-None-Match': ifNoneMatch.toString(),
    if (ifUnmodifiedSince != null)
      'If-Unmodified-Since': _s.rfc822ToJson(ifUnmodifiedSince),
    if (range != null) 'Range': range.toString(),
    if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
    if (sSECustomerAlgorithm != null)
      'x-amz-server-side-encryption-customer-algorithm':
          sSECustomerAlgorithm.toString(),
    if (sSECustomerKey != null)
      'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
    if (sSECustomerKeyMD5 != null)
      'x-amz-server-side-encryption-customer-key-MD5':
          sSECustomerKeyMD5.toString(),
  };
  final $query = <String, List<String>>{
    if (partNumber != null) 'partNumber': [partNumber.toString()],
    if (responseCacheControl != null)
      'response-cache-control': [responseCacheControl],
    if (responseContentDisposition != null)
      'response-content-disposition': [responseContentDisposition],
    if (responseContentEncoding != null)
      'response-content-encoding': [responseContentEncoding],
    if (responseContentLanguage != null)
      'response-content-language': [responseContentLanguage],
    if (responseContentType != null)
      'response-content-type': [responseContentType],
    if (responseExpires != null)
      'response-expires': [_s.rfc822ToJson(responseExpires).toString()],
    if (versionId != null) 'versionId': [versionId],
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri:
        '/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?x-id=GetObject',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return GetObjectOutput(
    body: await $result.stream.toBytes(),
    acceptRanges:
        _s.extractHeaderStringValue($result.headers, 'accept-ranges'),
    bucketKeyEnabled: _s.extractHeaderBoolValue(
        $result.headers, 'x-amz-server-side-encryption-bucket-key-enabled'),
    cacheControl:
        _s.extractHeaderStringValue($result.headers, 'Cache-Control'),
    checksumCRC32:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32'),
    checksumCRC32C:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32c'),
    checksumCRC64NVME: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-crc64nvme'),
    checksumMD5:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-md5'),
    checksumSHA1:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha1'),
    checksumSHA256:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha256'),
    checksumSHA512:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha512'),
    checksumType: _s
        .extractHeaderStringValue($result.headers, 'x-amz-checksum-type')
        ?.let(ChecksumType.fromString),
    checksumXXHASH128: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash128'),
    checksumXXHASH3: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash3'),
    checksumXXHASH64: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash64'),
    contentDisposition:
        _s.extractHeaderStringValue($result.headers, 'Content-Disposition'),
    contentEncoding:
        _s.extractHeaderStringValue($result.headers, 'Content-Encoding'),
    contentLanguage:
        _s.extractHeaderStringValue($result.headers, 'Content-Language'),
    contentLength:
        _s.extractHeaderIntValue($result.headers, 'Content-Length'),
    contentRange:
        _s.extractHeaderStringValue($result.headers, 'Content-Range'),
    contentType: _s.extractHeaderStringValue($result.headers, 'Content-Type'),
    deleteMarker:
        _s.extractHeaderBoolValue($result.headers, 'x-amz-delete-marker'),
    eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
    expiration:
        _s.extractHeaderStringValue($result.headers, 'x-amz-expiration'),
    expires: _s.extractHeaderStringValue($result.headers, 'Expires'),
    lastModified:
        _s.extractHeaderDateTimeValue($result.headers, 'Last-Modified'),
    metadata: _s.extractHeaderMapValues($result.headers, 'x-amz-meta-'),
    missingMeta:
        _s.extractHeaderIntValue($result.headers, 'x-amz-missing-meta'),
    objectLockLegalHoldStatus: _s
        .extractHeaderStringValue(
            $result.headers, 'x-amz-object-lock-legal-hold')
        ?.let(ObjectLockLegalHoldStatus.fromString),
    objectLockMode: _s
        .extractHeaderStringValue($result.headers, 'x-amz-object-lock-mode')
        ?.let(ObjectLockMode.fromString),
    objectLockRetainUntilDate: _s.extractHeaderDateTimeValue(
        $result.headers, 'x-amz-object-lock-retain-until-date',
        parser: _s.timeStampFromJson),
    partsCount:
        _s.extractHeaderIntValue($result.headers, 'x-amz-mp-parts-count'),
    replicationStatus: _s
        .extractHeaderStringValue($result.headers, 'x-amz-replication-status')
        ?.let(ReplicationStatus.fromString),
    requestCharged: _s
        .extractHeaderStringValue($result.headers, 'x-amz-request-charged')
        ?.let(RequestCharged.fromString),
    restore: _s.extractHeaderStringValue($result.headers, 'x-amz-restore'),
    sSECustomerAlgorithm: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-customer-algorithm'),
    sSECustomerKeyMD5: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-customer-key-MD5'),
    sSEKMSKeyId: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-aws-kms-key-id'),
    serverSideEncryption: _s
        .extractHeaderStringValue(
            $result.headers, 'x-amz-server-side-encryption')
        ?.let(ServerSideEncryption.fromString),
    storageClass: _s
        .extractHeaderStringValue($result.headers, 'x-amz-storage-class')
        ?.let(StorageClass.fromString),
    tagCount:
        _s.extractHeaderIntValue($result.headers, 'x-amz-tagging-count'),
    versionId:
        _s.extractHeaderStringValue($result.headers, 'x-amz-version-id'),
    websiteRedirectLocation: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-website-redirect-location'),
  );
}