getObjectLegalHold method
This functionality is not supported for Amazon S3 on Outposts.
The following action is related to GetObjectLegalHold:
Parameter bucket :
The bucket name containing the object whose legal hold status you want to
retrieve.
Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
Parameter key :
The key name for the object whose legal hold status you want to retrieve.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter versionId :
The version ID of the object whose legal hold status you want to retrieve.
Implementation
Future<GetObjectLegalHoldOutput> getObjectLegalHold({
required String bucket,
required String key,
String? expectedBucketOwner,
RequestPayer? requestPayer,
String? versionId,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (versionId != null) 'versionId': [versionId],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?legal-hold',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return GetObjectLegalHoldOutput(
legalHold: ObjectLockLegalHold.fromXml($elem),
);
}