headObject method

Future<HeadObjectOutput> headObject({
  1. required String bucket,
  2. required String key,
  3. ChecksumMode? checksumMode,
  4. String? expectedBucketOwner,
  5. String? ifMatch,
  6. DateTime? ifModifiedSince,
  7. String? ifNoneMatch,
  8. DateTime? ifUnmodifiedSince,
  9. int? partNumber,
  10. String? range,
  11. RequestPayer? requestPayer,
  12. String? responseCacheControl,
  13. String? responseContentDisposition,
  14. String? responseContentEncoding,
  15. String? responseContentLanguage,
  16. String? responseContentType,
  17. DateTime? responseExpires,
  18. String? sSECustomerAlgorithm,
  19. String? sSECustomerKey,
  20. String? sSECustomerKeyMD5,
  21. String? versionId,
})

The HEAD operation retrieves metadata from an object without returning the object itself. This operation is useful if you're interested only in an object's metadata. Request headers are limited to 8 KB in size. For more information, see Common Request Headers.

Permissions
  • General purpose bucket permissions - To use HEAD, you must have the s3:GetObject permission. You need the relevant read object (or version) permission for this operation. For more information, see Actions, resources, and condition keys for Amazon S3 in the Amazon S3 User Guide. For more information about the permissions to S3 API operations by S3 resource types, see Required permissions for Amazon S3 API operations in the Amazon S3 User Guide.

    If the object you request doesn't exist, the error that Amazon S3 returns depends on whether you also have the s3:ListBucket permission.

    • If you have the s3:ListBucket permission on the bucket, Amazon S3 returns an HTTP status code 404 Not Found error.
    • If you don’t have the s3:ListBucket permission, Amazon S3 returns an HTTP status code 403 Forbidden error.
  • Directory bucket permissions - To grant access to this API operation on a directory bucket, we recommend that you use the CreateSession API operation for session-based authorization. Specifically, you grant the s3express:CreateSession permission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make the CreateSession API call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make another CreateSession API call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, see CreateSession .

    If you enable x-amz-checksum-mode in the request and the object is encrypted with Amazon Web Services Key Management Service (Amazon Web Services KMS), you must also have the kms:GenerateDataKey and kms:Decrypt permissions in IAM identity-based policies and KMS key policies for the KMS key to retrieve the checksum of the object.

Encryption
If you encrypt an object by using server-side encryption with customer-provided encryption keys (SSE-C) when you store the object in Amazon S3, then when you retrieve the metadata from the object, you must use the following headers to provide the encryption key for the server to be able to retrieve the object's metadata. The headers are:
  • x-amz-server-side-encryption-customer-algorithm
  • x-amz-server-side-encryption-customer-key
  • x-amz-server-side-encryption-customer-key-MD5
For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide.
Versioning
  • If the current version of the object is a delete marker, Amazon S3 behaves as if the object was deleted and includes x-amz-delete-marker: true in the response.
  • If the specified version is a delete marker, the response returns a 405 Method Not Allowed error and the Last-Modified: timestamp response header.
HTTP Host header syntax
Directory buckets - The HTTP Host header syntax is Bucket-name.s3express-zone-id.region-code.amazonaws.com.
The following actions are related to HeadObject:

May throw NotFound.

Parameter bucket : The name of the bucket that contains the object.

Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see What is S3 on Outposts? in the Amazon S3 User Guide.

Parameter key : The object key.

Parameter checksumMode : To retrieve the checksum, this parameter must be enabled.

General purpose buckets - If you enable checksum mode and the object is uploaded with a checksum and encrypted with an Key Management Service (KMS) key, you must have permission to use the kms:Decrypt action to retrieve the checksum.

Directory buckets - If you enable ChecksumMode and the object is encrypted with Amazon Web Services Key Management Service (Amazon Web Services KMS), you must also have the kms:GenerateDataKey and kms:Decrypt permissions in IAM identity-based policies and KMS key policies for the KMS key to retrieve the checksum of the object.

Parameter expectedBucketOwner : The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Parameter ifMatch : Return the object only if its entity tag (ETag) is the same as the one specified; otherwise, return a 412 (precondition failed) error.

If both of the If-Match and If-Unmodified-Since headers are present in the request as follows:

  • If-Match condition evaluates to true, and;
  • If-Unmodified-Since condition evaluates to false;
Then Amazon S3 returns 200 OK and the data requested.

For more information about conditional requests, see RFC 7232.

Parameter ifModifiedSince : Return the object only if it has been modified since the specified time; otherwise, return a 304 (not modified) error.

If both of the If-None-Match and If-Modified-Since headers are present in the request as follows:

  • If-None-Match condition evaluates to false, and;
  • If-Modified-Since condition evaluates to true;
Then Amazon S3 returns the 304 Not Modified response code.

For more information about conditional requests, see RFC 7232.

Parameter ifNoneMatch : Return the object only if its entity tag (ETag) is different from the one specified; otherwise, return a 304 (not modified) error.

If both of the If-None-Match and If-Modified-Since headers are present in the request as follows:

  • If-None-Match condition evaluates to false, and;
  • If-Modified-Since condition evaluates to true;
Then Amazon S3 returns the 304 Not Modified response code.

For more information about conditional requests, see RFC 7232.

Parameter ifUnmodifiedSince : Return the object only if it has not been modified since the specified time; otherwise, return a 412 (precondition failed) error.

If both of the If-Match and If-Unmodified-Since headers are present in the request as follows:

  • If-Match condition evaluates to true, and;
  • If-Unmodified-Since condition evaluates to false;
Then Amazon S3 returns 200 OK and the data requested.

For more information about conditional requests, see RFC 7232.

Parameter partNumber : Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a 'ranged' HEAD request for the part specified. Useful querying about the size of the part and the number of parts in this object.

Parameter range : HeadObject returns only the metadata for an object. If the Range is satisfiable, only the ContentLength is affected in the response. If the Range is not satisfiable, S3 returns a 416 - Requested Range Not Satisfiable error.

Parameter responseCacheControl : Sets the Cache-Control header of the response.

Parameter responseContentDisposition : Sets the Content-Disposition header of the response.

Parameter responseContentEncoding : Sets the Content-Encoding header of the response.

Parameter responseContentLanguage : Sets the Content-Language header of the response.

Parameter responseContentType : Sets the Content-Type header of the response.

Parameter responseExpires : Sets the Expires header of the response.

Parameter sSECustomerAlgorithm : Specifies the algorithm to use when encrypting the object (for example, AES256).

Parameter sSECustomerKey : Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header.

Parameter sSECustomerKeyMD5 : Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

Parameter versionId : Version ID used to reference a specific version of the object.

Implementation

Future<HeadObjectOutput> headObject({
  required String bucket,
  required String key,
  ChecksumMode? checksumMode,
  String? expectedBucketOwner,
  String? ifMatch,
  DateTime? ifModifiedSince,
  String? ifNoneMatch,
  DateTime? ifUnmodifiedSince,
  int? partNumber,
  String? range,
  RequestPayer? requestPayer,
  String? responseCacheControl,
  String? responseContentDisposition,
  String? responseContentEncoding,
  String? responseContentLanguage,
  String? responseContentType,
  DateTime? responseExpires,
  String? sSECustomerAlgorithm,
  String? sSECustomerKey,
  String? sSECustomerKeyMD5,
  String? versionId,
}) async {
  final headers = <String, String>{
    if (checksumMode != null) 'x-amz-checksum-mode': checksumMode.value,
    if (expectedBucketOwner != null)
      'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
    if (ifMatch != null) 'If-Match': ifMatch.toString(),
    if (ifModifiedSince != null)
      'If-Modified-Since': _s.rfc822ToJson(ifModifiedSince),
    if (ifNoneMatch != null) 'If-None-Match': ifNoneMatch.toString(),
    if (ifUnmodifiedSince != null)
      'If-Unmodified-Since': _s.rfc822ToJson(ifUnmodifiedSince),
    if (range != null) 'Range': range.toString(),
    if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
    if (sSECustomerAlgorithm != null)
      'x-amz-server-side-encryption-customer-algorithm':
          sSECustomerAlgorithm.toString(),
    if (sSECustomerKey != null)
      'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
    if (sSECustomerKeyMD5 != null)
      'x-amz-server-side-encryption-customer-key-MD5':
          sSECustomerKeyMD5.toString(),
  };
  final $query = <String, List<String>>{
    if (partNumber != null) 'partNumber': [partNumber.toString()],
    if (responseCacheControl != null)
      'response-cache-control': [responseCacheControl],
    if (responseContentDisposition != null)
      'response-content-disposition': [responseContentDisposition],
    if (responseContentEncoding != null)
      'response-content-encoding': [responseContentEncoding],
    if (responseContentLanguage != null)
      'response-content-language': [responseContentLanguage],
    if (responseContentType != null)
      'response-content-type': [responseContentType],
    if (responseExpires != null)
      'response-expires': [_s.rfc822ToJson(responseExpires).toString()],
    if (versionId != null) 'versionId': [versionId],
  };
  final $result = await _protocol.sendRaw(
    method: 'HEAD',
    requestUri:
        '/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return HeadObjectOutput(
    acceptRanges:
        _s.extractHeaderStringValue($result.headers, 'accept-ranges'),
    archiveStatus: _s
        .extractHeaderStringValue($result.headers, 'x-amz-archive-status')
        ?.let(ArchiveStatus.fromString),
    bucketKeyEnabled: _s.extractHeaderBoolValue(
        $result.headers, 'x-amz-server-side-encryption-bucket-key-enabled'),
    cacheControl:
        _s.extractHeaderStringValue($result.headers, 'Cache-Control'),
    checksumCRC32:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32'),
    checksumCRC32C:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32c'),
    checksumCRC64NVME: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-crc64nvme'),
    checksumMD5:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-md5'),
    checksumSHA1:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha1'),
    checksumSHA256:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha256'),
    checksumSHA512:
        _s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha512'),
    checksumType: _s
        .extractHeaderStringValue($result.headers, 'x-amz-checksum-type')
        ?.let(ChecksumType.fromString),
    checksumXXHASH128: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash128'),
    checksumXXHASH3: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash3'),
    checksumXXHASH64: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-checksum-xxhash64'),
    contentDisposition:
        _s.extractHeaderStringValue($result.headers, 'Content-Disposition'),
    contentEncoding:
        _s.extractHeaderStringValue($result.headers, 'Content-Encoding'),
    contentLanguage:
        _s.extractHeaderStringValue($result.headers, 'Content-Language'),
    contentLength:
        _s.extractHeaderIntValue($result.headers, 'Content-Length'),
    contentRange:
        _s.extractHeaderStringValue($result.headers, 'Content-Range'),
    contentType: _s.extractHeaderStringValue($result.headers, 'Content-Type'),
    deleteMarker:
        _s.extractHeaderBoolValue($result.headers, 'x-amz-delete-marker'),
    eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
    expiration:
        _s.extractHeaderStringValue($result.headers, 'x-amz-expiration'),
    expires: _s.extractHeaderStringValue($result.headers, 'Expires'),
    lastModified:
        _s.extractHeaderDateTimeValue($result.headers, 'Last-Modified'),
    metadata: _s.extractHeaderMapValues($result.headers, 'x-amz-meta-'),
    missingMeta:
        _s.extractHeaderIntValue($result.headers, 'x-amz-missing-meta'),
    objectLockLegalHoldStatus: _s
        .extractHeaderStringValue(
            $result.headers, 'x-amz-object-lock-legal-hold')
        ?.let(ObjectLockLegalHoldStatus.fromString),
    objectLockMode: _s
        .extractHeaderStringValue($result.headers, 'x-amz-object-lock-mode')
        ?.let(ObjectLockMode.fromString),
    objectLockRetainUntilDate: _s.extractHeaderDateTimeValue(
        $result.headers, 'x-amz-object-lock-retain-until-date',
        parser: _s.timeStampFromJson),
    partsCount:
        _s.extractHeaderIntValue($result.headers, 'x-amz-mp-parts-count'),
    replicationStatus: _s
        .extractHeaderStringValue($result.headers, 'x-amz-replication-status')
        ?.let(ReplicationStatus.fromString),
    requestCharged: _s
        .extractHeaderStringValue($result.headers, 'x-amz-request-charged')
        ?.let(RequestCharged.fromString),
    restore: _s.extractHeaderStringValue($result.headers, 'x-amz-restore'),
    sSECustomerAlgorithm: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-customer-algorithm'),
    sSECustomerKeyMD5: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-customer-key-MD5'),
    sSEKMSKeyId: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-server-side-encryption-aws-kms-key-id'),
    serverSideEncryption: _s
        .extractHeaderStringValue(
            $result.headers, 'x-amz-server-side-encryption')
        ?.let(ServerSideEncryption.fromString),
    storageClass: _s
        .extractHeaderStringValue($result.headers, 'x-amz-storage-class')
        ?.let(StorageClass.fromString),
    tagCount:
        _s.extractHeaderIntValue($result.headers, 'x-amz-tagging-count'),
    versionId:
        _s.extractHeaderStringValue($result.headers, 'x-amz-version-id'),
    websiteRedirectLocation: _s.extractHeaderStringValue(
        $result.headers, 'x-amz-website-redirect-location'),
  );
}