listBucketAnalyticsConfigurations method
This action supports list pagination and does not return more than 100
configurations at a time. You should always check the
IsTruncated element in the response. If there are no more
configurations to list, IsTruncated is set to false. If there
are more configurations to list, IsTruncated is set to true,
and there will be a value in NextContinuationToken. You use
the NextContinuationToken value to continue the pagination of
the list by passing the value in continuation-token in the request to
GET the next page.
To use this operation, you must have permissions to perform the
s3:GetAnalyticsConfiguration action. The bucket owner has
this permission by default. The bucket owner can grant this permission to
others. For more information about permissions, see Permissions
Related to Bucket Subresource Operations and Managing
Access Permissions to Your Amazon S3 Resources.
For information about Amazon S3 analytics feature, see Amazon S3 Analytics – Storage Class Analysis.
The following operations are related to
ListBucketAnalyticsConfigurations:
Parameter bucket :
The name of the bucket from which analytics configurations are retrieved.
Parameter continuationToken :
The ContinuationToken that represents a placeholder from
where this request should begin.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<ListBucketAnalyticsConfigurationsOutput>
listBucketAnalyticsConfigurations({
required String bucket,
String? continuationToken,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $query = <String, List<String>>{
if (continuationToken != null) 'continuation-token': [continuationToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/${Uri.encodeComponent(bucket)}?analytics&x-id=ListBucketAnalyticsConfigurations',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListBucketAnalyticsConfigurationsOutput.fromXml($result.body);
}