listMultipartUploads method
This operation lists in-progress multipart uploads in a bucket. An
in-progress multipart upload is a multipart upload that has been initiated
by the CreateMultipartUpload request, but has not yet been
completed or aborted.
The ListMultipartUploads operation returns a maximum of 1,000
multipart uploads in the response. The limit of 1,000 multipart uploads is
also the default value. You can further limit the number of uploads in a
response by specifying the max-uploads request parameter. If
there are more than 1,000 multipart uploads that satisfy your
ListMultipartUploads request, the response returns an
IsTruncated element with the value of true, a
NextKeyMarker element, and a NextUploadIdMarker
element. To list the remaining multipart uploads, you need to make
subsequent ListMultipartUploads requests. In these requests,
include two query parameters: key-marker and
upload-id-marker. Set the value of key-marker to
the NextKeyMarker value from the previous response.
Similarly, set the value of upload-id-marker to the
NextUploadIdMarker value from the previous response.
For more information about multipart uploads, see Uploading
Objects Using Multipart Upload in the Amazon S3 User Guide.
- Permissions
-
- General purpose bucket permissions - For information about permissions required to use the multipart upload API, see Multipart Upload and Permissions in the Amazon S3 User Guide.
-
Directory bucket permissions - To grant access to this API
operation on a directory bucket, we recommend that you use the
CreateSessionAPI operation for session-based authorization. Specifically, you grant thes3express:CreateSessionpermission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make theCreateSessionAPI call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make anotherCreateSessionAPI call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, seeCreateSession.
- Sorting of multipart uploads in response
-
-
General purpose bucket - In the
ListMultipartUploadsresponse, the multipart uploads are sorted based on two criteria:- Key-based sorting - Multipart uploads are initially sorted in ascending order based on their object keys.
- Time-based sorting - For uploads that share the same object key, they are further sorted in ascending order based on the upload initiation time. Among uploads with the same key, the one that was initiated first will appear before the ones that were initiated later.
-
Directory bucket - In the
ListMultipartUploadsresponse, the multipart uploads aren't sorted lexicographically based on the object keys.
-
General purpose bucket - In the
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
ListMultipartUploads:
Parameter bucket :
The name of the bucket to which the multipart upload was initiated.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter delimiter :
Character you use to group keys.
All keys that contain the same string between the prefix, if specified,
and the first occurrence of the delimiter after the prefix are grouped
under a single result element, CommonPrefixes. If you don't
specify the prefix parameter, then the substring starts at the beginning
of the key. The keys that are grouped under CommonPrefixes
result element are not returned elsewhere in the response.
CommonPrefixes is filtered out from results if it is not
lexicographically greater than the key-marker.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter keyMarker :
Specifies the multipart upload after which listing should begin.
-
General purpose buckets - For general purpose buckets,
key-markeris an object key. Together withupload-id-marker, this parameter specifies the multipart upload after which listing should begin.If
upload-id-markeris not specified, only the keys lexicographically greater than the specifiedkey-markerwill be included in the list.If
upload-id-markeris specified, any multipart uploads for a key equal to thekey-markermight also be included, provided those multipart uploads have upload IDs lexicographically greater than the specifiedupload-id-marker. -
Directory buckets - For directory buckets,
key-markeris obfuscated and isn't a real object key. Theupload-id-markerparameter isn't supported by directory buckets. To list the additional multipart uploads, you only need to set the value ofkey-markerto theNextKeyMarkervalue from the previous response.In the
ListMultipartUploadsresponse, the multipart uploads aren't sorted lexicographically based on the object keys.
Parameter maxUploads :
Sets the maximum number of multipart uploads, from 1 to 1,000, to return
in the response body. 1,000 is the maximum number of uploads that can be
returned in a response.
Parameter prefix :
Lists in-progress uploads only for those keys that begin with the
specified prefix. You can use prefixes to separate a bucket into different
grouping of keys. (You can think of using prefix to make
groups in the same way that you'd use a folder in a file system.)
Parameter uploadIdMarker :
Together with key-marker, specifies the multipart upload after which
listing should begin. If key-marker is not specified, the upload-id-marker
parameter is ignored. Otherwise, any multipart uploads for a key equal to
the key-marker might be included in the list only if they have an upload
ID lexicographically greater than the specified
upload-id-marker.
Implementation
Future<ListMultipartUploadsOutput> listMultipartUploads({
required String bucket,
String? delimiter,
EncodingType? encodingType,
String? expectedBucketOwner,
String? keyMarker,
int? maxUploads,
String? prefix,
RequestPayer? requestPayer,
String? uploadIdMarker,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (delimiter != null) 'delimiter': [delimiter],
if (encodingType != null) 'encoding-type': [encodingType.value],
if (keyMarker != null) 'key-marker': [keyMarker],
if (maxUploads != null) 'max-uploads': [maxUploads.toString()],
if (prefix != null) 'prefix': [prefix],
if (uploadIdMarker != null) 'upload-id-marker': [uploadIdMarker],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/${Uri.encodeComponent(bucket)}?uploads',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListMultipartUploadsOutput(
bucket: _s.extractXmlStringValue($elem, 'Bucket'),
commonPrefixes: $elem
.findElements('CommonPrefixes')
.map(CommonPrefix.fromXml)
.toList(),
delimiter: _s.extractXmlStringValue($elem, 'Delimiter'),
encodingType: _s
.extractXmlStringValue($elem, 'EncodingType')
?.let(EncodingType.fromString),
isTruncated: _s.extractXmlBoolValue($elem, 'IsTruncated'),
keyMarker: _s.extractXmlStringValue($elem, 'KeyMarker'),
maxUploads: _s.extractXmlIntValue($elem, 'MaxUploads'),
nextKeyMarker: _s.extractXmlStringValue($elem, 'NextKeyMarker'),
nextUploadIdMarker: _s.extractXmlStringValue($elem, 'NextUploadIdMarker'),
prefix: _s.extractXmlStringValue($elem, 'Prefix'),
uploadIdMarker: _s.extractXmlStringValue($elem, 'UploadIdMarker'),
uploads:
$elem.findElements('Upload').map(MultipartUpload.fromXml).toList(),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
);
}