putBucketAnalyticsConfiguration method
You can choose to have storage class analysis export analysis reports sent
to a comma-separated values (CSV) flat file. See the
DataExport request element. Reports are updated daily and are
based on the object filters that you configure. When selecting data
export, you specify a destination bucket and an optional destination
prefix where the file is written. You can export the data to a destination
bucket in a different account. However, the destination bucket must be in
the same Region as the bucket that you are making the PUT analytics
configuration to. For more information, see Amazon
S3 Analytics – Storage Class Analysis.
To use this operation, you must have permissions to perform the
s3:PutAnalyticsConfiguration action. The bucket owner has
this permission by default. The bucket owner can grant this permission to
others. For more information about permissions, see Permissions
Related to Bucket Subresource Operations and Managing
Access Permissions to Your Amazon S3 Resources.
PutBucketAnalyticsConfiguration has the following special
errors:
-
- HTTP Error: HTTP 400 Bad Request
- Code: InvalidArgument
- Cause: Invalid argument.
-
- HTTP Error: HTTP 400 Bad Request
- Code: TooManyConfigurations
- Cause: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.
-
- HTTP Error: HTTP 403 Forbidden
- Code: AccessDenied
- Cause: You are not the owner of the specified bucket, or you do not have the s3:PutAnalyticsConfiguration bucket permission to set the configuration on the bucket.
PutBucketAnalyticsConfiguration:
- GetBucketAnalyticsConfiguration
- DeleteBucketAnalyticsConfiguration
- ListBucketAnalyticsConfigurations
Parameter analyticsConfiguration :
The configuration and any analyses for the analytics filter.
Parameter bucket :
The name of the bucket to which an analytics configuration is stored.
Parameter id :
The ID that identifies the analytics configuration.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketAnalyticsConfiguration({
required AnalyticsConfiguration analyticsConfiguration,
required String bucket,
required String id,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $query = <String, List<String>>{
'id': [id],
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?analytics',
queryParams: $query,
headers: headers,
payload: analyticsConfiguration.toXml('AnalyticsConfiguration'),
exceptionFnMap: _exceptionFns,
);
}