putBucketInventoryConfiguration method
This implementation of the PUT action adds an S3 Inventory
configuration (identified by the inventory ID) to the bucket. You can have
up to 1,000 inventory configurations per bucket.
Amazon S3 inventory generates inventories of the objects in the bucket on a daily or weekly basis, and the results are published to a flat file. The bucket that is inventoried is called the source bucket, and the bucket where the inventory flat file is stored is called the destination bucket. The destination bucket must be in the same Amazon Web Services Region as the source bucket.
When you configure an inventory for a source bucket, you specify the destination bucket where you want the inventory to be stored, and whether to generate the inventory daily or weekly. You can also configure what object metadata to include and whether to inventory all object versions or only current versions. For more information, see Amazon S3 Inventory in the Amazon S3 User Guide.
- Permissions
-
To use this operation, you must have permission to perform the
s3:PutInventoryConfigurationaction. The bucket owner has this permission by default and can grant this permission to others.The
s3:PutInventoryConfigurationpermission allows a user to create an S3 Inventory report that includes all object metadata fields available and to specify the destination bucket to store the inventory. A user with read access to objects in the destination bucket can also access all object metadata fields that are available in the inventory report.-
General purpose bucket permissions - The
s3:PutInventoryConfigurationpermission is required in a policy. For more information about general purpose buckets permissions, see Using Bucket Policies and User Policies in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation, you must have the
s3express:PutInventoryConfigurationpermission in an IAM identity-based policy instead of a bucket policy. For more information about directory bucket policies and permissions, see Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone in the Amazon S3 User Guide.
-
General purpose bucket permissions - The
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region-code.amazonaws.com.
PutBucketInventoryConfiguration has the following special
errors:
- HTTP 400 Bad Request Error
-
Code: InvalidArgument
Cause: Invalid Argument
- HTTP 400 Bad Request Error
-
Code: TooManyConfigurations
Cause: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.
- HTTP 403 Forbidden Error
-
Cause: You are not the owner of the specified bucket, or you do not
have the
s3:PutInventoryConfigurationbucket permission to set the configuration on the bucket.
PutBucketInventoryConfiguration:
- GetBucketInventoryConfiguration
- DeleteBucketInventoryConfiguration
- ListBucketInventoryConfigurations
Parameter bucket :
The name of the bucket where the inventory configuration will be stored.
Directory buckets - When you use this operation with a directory
bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name
. Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local Zone).
Bucket names must also follow the format
bucket-base-name--zone-id--x-s3 (for example,
DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide
Parameter id :
The ID used to identify the inventory configuration.
Parameter inventoryConfiguration :
Specifies the inventory configuration.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketInventoryConfiguration({
required String bucket,
required String id,
required InventoryConfiguration inventoryConfiguration,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $query = <String, List<String>>{
'id': [id],
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?inventory',
queryParams: $query,
headers: headers,
payload: inventoryConfiguration.toXml('InventoryConfiguration'),
exceptionFnMap: _exceptionFns,
);
}