putBucketVersioning method
You can set the versioning state with one of the following values:
Enabled—Enables versioning for the objects in the bucket. All objects added to the bucket receive a unique version ID.
Suspended—Disables versioning for the objects in the bucket. All objects added to the bucket receive the version ID null.
If the versioning state has never been set on a bucket, it has no versioning state; a GetBucketVersioning request does not return a versioning state value.
In order to enable MFA Delete, you must be the bucket owner. If you are
the bucket owner and want to enable MFA Delete in the bucket versioning
configuration, you must include the x-amz-mfa request header
and the Status and the MfaDelete request
elements in a request to set the versioning state of the bucket.
The following operations are related to PutBucketVersioning:
Parameter bucket :
The bucket name.
Parameter versioningConfiguration :
Container for setting the versioning state.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the request when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The Base64 encoded 128-bit
MD5digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter mfa :
The concatenation of the authentication device's serial number, a space,
and the value that is displayed on your authentication device. The serial
number is the number that uniquely identifies the MFA device. For physical
MFA devices, this is the unique serial number that's provided with the
device. For virtual MFA devices, the serial number is the device ARN. For
more information, see Enabling
versioning on buckets and Configuring
MFA delete in the Amazon Simple Storage Service User Guide.
Implementation
Future<void> putBucketVersioning({
required String bucket,
required VersioningConfiguration versioningConfiguration,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
String? mfa,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (mfa != null) 'x-amz-mfa': mfa.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?versioning',
headers: headers,
payload: versioningConfiguration.toXml('VersioningConfiguration'),
exceptionFnMap: _exceptionFns,
);
}