putBucketWebsite method
website subresource. To configure a bucket as a website, you
can add this subresource on the bucket with website configuration
information such as the file name of the index document and any redirect
rules. For more information, see Hosting
Websites on Amazon S3.
This PUT action requires the S3:PutBucketWebsite permission.
By default, only the bucket owner can configure the website attached to a
bucket; however, bucket owners can allow other users to set the website
configuration by writing a bucket policy that grants them the
S3:PutBucketWebsite permission.
To redirect all website requests sent to the bucket's website endpoint, you add a website configuration with the following elements. Because all requests are sent to another website, you don't need to provide index document name for the bucket.
-
WebsiteConfiguration -
RedirectAllRequestsTo -
HostName -
Protocol
-
WebsiteConfiguration -
IndexDocument -
Suffix -
ErrorDocument -
Key -
RoutingRules -
RoutingRule -
Condition -
HttpErrorCodeReturnedEquals -
KeyPrefixEquals -
Redirect -
Protocol -
HostName -
ReplaceKeyPrefixWith -
ReplaceKeyWith -
HttpRedirectCode
The maximum request length is limited to 128 KB.
Parameter bucket :
The bucket name.
Parameter websiteConfiguration :
Container for the request.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the request when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The Base64 encoded 128-bit MD5 digest of the data. You must
use this header as a message integrity check to verify that the request
body was not corrupted in transit. For more information, see RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketWebsite({
required String bucket,
required WebsiteConfiguration websiteConfiguration,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?website',
headers: headers,
payload: websiteConfiguration.toXml('WebsiteConfiguration'),
exceptionFnMap: _exceptionFns,
);
}