putObjectRetention method
s3:PutObjectRetention permission in order to place an Object
Retention configuration on objects. Bypassing a Governance Retention
configuration requires the s3:BypassGovernanceRetention
permission.
This functionality is not supported for Amazon S3 on Outposts.
Parameter bucket :
The bucket name that contains the object you want to apply this Object
Retention configuration to.
Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
Parameter key :
The key name for the object that you want to apply this Object Retention
configuration to.
Parameter bypassGovernanceRetention :
Indicates whether this action should bypass Governance-mode restrictions.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash for the request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter retention :
The container element for the Object Retention configuration.
Parameter versionId :
The version ID for the object that you want to apply this Object Retention
configuration to.
Implementation
Future<PutObjectRetentionOutput> putObjectRetention({
required String bucket,
required String key,
bool? bypassGovernanceRetention,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
RequestPayer? requestPayer,
ObjectLockRetention? retention,
String? versionId,
}) async {
final headers = <String, String>{
if (bypassGovernanceRetention != null)
'x-amz-bypass-governance-retention':
bypassGovernanceRetention.toString(),
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (versionId != null) 'versionId': [versionId],
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?retention',
queryParams: $query,
headers: headers,
payload: retention?.toXml('Retention'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return PutObjectRetentionOutput(
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
);
}