putObjectTagging method
You can associate tags with an object by sending a PUT request against the tagging subresource that is associated with the object. You can retrieve tags by sending a GET request. For more information, see GetObjectTagging.
For tagging-related restrictions related to characters and encodings, see Tag Restrictions. Note that Amazon S3 limits the maximum number of tags to 10 tags per object.
To use this operation, you must have permission to perform the
s3:PutObjectTagging action. By default, the bucket owner has
this permission and can grant this permission to others.
To put tags of any other version, use the versionId query
parameter. You also need permission for the
s3:PutObjectVersionTagging action.
PutObjectTagging has the following special errors. For more
Amazon S3 errors see, Error
Responses.
-
InvalidTag- The tag provided was not a valid tag. This error can occur if the tag did not pass input validation. For more information, see Object Tagging. -
MalformedXML- The XML provided does not match the schema. -
OperationAborted- A conflicting conditional action is currently in progress against this resource. Please try again. -
InternalError- The service was unable to apply the provided tag to the object.
PutObjectTagging:
Parameter bucket :
The bucket name containing the object.
Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter key :
Name of the object key.
Parameter tagging :
Container for the TagSet and Tag elements
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash for the request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter requestPayer :
Confirms that the requester knows that she or he will be charged for the
tagging object request. Bucket owners need not specify this parameter in
their requests.
Parameter versionId :
The versionId of the object that the tag-set will be added to.
Implementation
Future<PutObjectTaggingOutput> putObjectTagging({
required String bucket,
required String key,
required Tagging tagging,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
RequestPayer? requestPayer,
String? versionId,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (versionId != null) 'versionId': [versionId],
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?tagging',
queryParams: $query,
headers: headers,
payload: tagging.toXml('Tagging'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return PutObjectTaggingOutput(
versionId:
_s.extractHeaderStringValue($result.headers, 'x-amz-version-id'),
);
}