renameObject method

Future<void> renameObject({
  1. required String bucket,
  2. required String key,
  3. required String renameSource,
  4. String? clientToken,
  5. String? destinationIfMatch,
  6. DateTime? destinationIfModifiedSince,
  7. String? destinationIfNoneMatch,
  8. DateTime? destinationIfUnmodifiedSince,
  9. String? sourceIfMatch,
  10. DateTime? sourceIfModifiedSince,
  11. String? sourceIfNoneMatch,
  12. DateTime? sourceIfUnmodifiedSince,
})

Renames an existing object in a directory bucket that uses the S3 Express One Zone storage class. You can use RenameObject by specifying an existing object’s name as the source and the new name of the object as the destination within the same directory bucket. To prevent overwriting an object, you can use the If-None-Match conditional header.

  • If-None-Match - Renames the object only if an object with the specified name does not already exist in the directory bucket. If you don't want to overwrite an existing object, you can add the If-None-Match conditional header with the value ‘*’ in the RenameObject request. Amazon S3 then returns a 412 Precondition Failed error if the object with the specified name already exists. For more information, see RFC 7232.
Permissions
To grant access to the RenameObject operation on a directory bucket, we recommend that you use the CreateSession operation for session-based authorization. Specifically, you grant the s3express:CreateSession permission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make the CreateSession API call on the directory bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make another CreateSession API call to generate a new session token for use. The Amazon Web Services CLI and SDKs will create and manage your session including refreshing the session token automatically to avoid service interruptions when a session expires. In your bucket policy, you can specify the s3express:SessionMode condition key to control who can create a ReadWrite or ReadOnly session. A ReadWrite session is required for executing all the Zonal endpoint API operations, including RenameObject. For more information about authorization, see CreateSession . To learn more about Zonal endpoint API operations, see Authorizing Zonal endpoint API operations with CreateSession in the Amazon S3 User Guide.
HTTP Host header syntax
Directory buckets - The HTTP Host header syntax is Bucket-name.s3express-zone-id.region-code.amazonaws.com.

May throw IdempotencyParameterMismatch.

Parameter bucket : The bucket name of the directory bucket containing the object.

You must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Availability Zone. Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

Parameter key : Key name of the object to rename.

Parameter renameSource : Specifies the source for the rename operation. The value must be URL encoded.

Parameter clientToken : A unique string with a max of 64 ASCII characters in the ASCII range of 33

Parameter destinationIfMatch : Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The If-Match header field makes the request method conditional on ETags. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

Expects the ETag value as a string.

Parameter destinationIfModifiedSince : Renames the object if the destination exists and if it has been modified since the specified time.

Parameter destinationIfNoneMatch : Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with If-None-Match:*, the S3 API will return a 412 Precondition Failed error, preventing an overwrite. The If-None-Match header prevents overwrites of existing data by validating that there's not an object with the same key name already in your directory bucket.

Expects the * character (asterisk).

Parameter destinationIfUnmodifiedSince : Renames the object if it hasn't been modified since the specified time.

Parameter sourceIfMatch : Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag.

Parameter sourceIfModifiedSince : Renames the object if the source exists and if it has been modified since the specified time.

Parameter sourceIfNoneMatch : Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk (*) character is provided, the operation will fail and return a 412 Precondition Failed error.

Parameter sourceIfUnmodifiedSince : Renames the object if the source exists and hasn't been modified since the specified time.

Implementation

Future<void> renameObject({
  required String bucket,
  required String key,
  required String renameSource,
  String? clientToken,
  String? destinationIfMatch,
  DateTime? destinationIfModifiedSince,
  String? destinationIfNoneMatch,
  DateTime? destinationIfUnmodifiedSince,
  String? sourceIfMatch,
  DateTime? sourceIfModifiedSince,
  String? sourceIfNoneMatch,
  DateTime? sourceIfUnmodifiedSince,
}) async {
  clientToken ??= _s.generateIdempotencyToken();
  final headers = <String, String>{
    'x-amz-rename-source': renameSource.toString(),
    'x-amz-client-token': clientToken.toString(),
    if (destinationIfMatch != null) 'If-Match': destinationIfMatch.toString(),
    if (destinationIfModifiedSince != null)
      'If-Modified-Since': _s.rfc822ToJson(destinationIfModifiedSince),
    if (destinationIfNoneMatch != null)
      'If-None-Match': destinationIfNoneMatch.toString(),
    if (destinationIfUnmodifiedSince != null)
      'If-Unmodified-Since': _s.rfc822ToJson(destinationIfUnmodifiedSince),
    if (sourceIfMatch != null)
      'x-amz-rename-source-if-match': sourceIfMatch.toString(),
    if (sourceIfModifiedSince != null)
      'x-amz-rename-source-if-modified-since':
          _s.rfc822ToJson(sourceIfModifiedSince),
    if (sourceIfNoneMatch != null)
      'x-amz-rename-source-if-none-match': sourceIfNoneMatch.toString(),
    if (sourceIfUnmodifiedSince != null)
      'x-amz-rename-source-if-unmodified-since':
          _s.rfc822ToJson(sourceIfUnmodifiedSince),
  };
  await _protocol.send(
    method: 'PUT',
    requestUri:
        '/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?renameObject',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}