selectObjectContent method
- required String bucket,
- required String expression,
- required ExpressionType expressionType,
- required InputSerialization inputSerialization,
- required String key,
- required OutputSerialization outputSerialization,
- String? expectedBucketOwner,
- RequestProgress? requestProgress,
- String? sSECustomerAlgorithm,
- String? sSECustomerKey,
- String? sSECustomerKeyMD5,
- ScanRange? scanRange,
This functionality is not supported for Amazon S3 on Outposts.
For more information about Amazon S3 Select, see Selecting Content from Objects and SELECT Command in the Amazon S3 User Guide.
- Permissions
-
You must have the
s3:GetObjectpermission for this operation. Amazon S3 Select does not support anonymous access. For more information about permissions, see Specifying Permissions in a Policy in the Amazon S3 User Guide. - Object Data Formats
-
You can use Amazon S3 Select to query objects that have the following
format properties:
- CSV, JSON, and Parquet - Objects must be in CSV, JSON, or Parquet format.
- UTF-8 - UTF-8 is the only encoding type Amazon S3 Select supports.
- GZIP or BZIP2 - CSV and JSON files can be compressed using GZIP or BZIP2. GZIP and BZIP2 are the only compression formats that Amazon S3 Select supports for CSV and JSON files. Amazon S3 Select supports columnar compression for Parquet using GZIP or Snappy. Amazon S3 Select does not support whole-object compression for Parquet objects.
-
Server-side encryption - Amazon S3 Select supports querying objects
that are protected with server-side encryption.
For objects that are encrypted with customer-provided encryption keys (SSE-C), you must use HTTPS, and you must use the headers that are documented in the GetObject. For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide.
For objects that are encrypted with Amazon S3 managed keys (SSE-S3) and Amazon Web Services KMS keys (SSE-KMS), server-side encryption is handled transparently, so you don't need to specify anything. For more information about server-side encryption, including SSE-S3 and SSE-KMS, see Protecting Data Using Server-Side Encryption in the Amazon S3 User Guide.
- Working with the Response Body
-
Given the response size is unknown, Amazon S3 Select streams the response
as a series of messages and includes a
Transfer-Encodingheader withchunkedas its value in the response. For more information, see Appendix: SelectObjectContent Response. - GetObject Support
-
The
SelectObjectContentaction does not support the followingGetObjectfunctionality. For more information, see GetObject.-
Range: Although you can specify a scan range for an Amazon S3 Select request (see SelectObjectContentRequest - ScanRange in the request parameters), you cannot specify the range of bytes of an object to return. -
The
GLACIER,DEEP_ARCHIVE, andREDUCED_REDUNDANCYstorage classes, or theARCHIVE_ACCESSandDEEP_ARCHIVE_ACCESSaccess tiers of theINTELLIGENT_TIERINGstorage class: You cannot query objects in theGLACIER,DEEP_ARCHIVE, orREDUCED_REDUNDANCYstorage classes, nor objects in theARCHIVE_ACCESSorDEEP_ARCHIVE_ACCESSaccess tiers of theINTELLIGENT_TIERINGstorage class. For more information about storage classes, see Using Amazon S3 storage classes in the Amazon S3 User Guide.
-
- Special Errors
- For a list of special errors for this operation, see List of SELECT Object Content Error Codes
SelectObjectContent:
Parameter bucket :
The S3 bucket.
Parameter expression :
The expression that is used to query the object.
Parameter expressionType :
The type of the provided expression (for example, SQL).
Parameter inputSerialization :
Describes the format of the data in the object that is being queried.
Parameter key :
The object key.
Parameter outputSerialization :
Describes the format of the data that you want Amazon S3 to return in
response.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter requestProgress :
Specifies if periodic request progress information should be enabled.
Parameter sSECustomerAlgorithm :
The server-side encryption (SSE) algorithm used to encrypt the object.
This parameter is needed only when the object was created using a checksum
algorithm. For more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Parameter sSECustomerKey :
The server-side encryption (SSE) customer managed key. This parameter is
needed only when the object was created using a checksum algorithm. For
more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Parameter sSECustomerKeyMD5 :
The MD5 server-side encryption (SSE) customer managed key. This parameter
is needed only when the object was created using a checksum algorithm. For
more information, see Protecting
data using SSE-C keys in the Amazon S3 User Guide.
Parameter scanRange :
Specifies the byte range of the object to get the records from. A record
is processed when its first byte is contained by the range. This parameter
is optional, but when specified, it must not be empty. See RFC 2616,
Section 14.35.1 about how to specify the start and end of the range.
ScanRangemay be used in the following ways:
-
- process only the records starting between the bytes 50 and 100 (inclusive, counting from zero) -
- process only the records starting after the byte 50 -
- process only the records within the last 50 bytes of the file.
Implementation
Future<SelectObjectContentOutput> selectObjectContent({
required String bucket,
required String expression,
required ExpressionType expressionType,
required InputSerialization inputSerialization,
required String key,
required OutputSerialization outputSerialization,
String? expectedBucketOwner,
RequestProgress? requestProgress,
String? sSECustomerAlgorithm,
String? sSECustomerKey,
String? sSECustomerKeyMD5,
ScanRange? scanRange,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (sSECustomerAlgorithm != null)
'x-amz-server-side-encryption-customer-algorithm':
sSECustomerAlgorithm.toString(),
if (sSECustomerKey != null)
'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
if (sSECustomerKeyMD5 != null)
'x-amz-server-side-encryption-customer-key-MD5':
sSECustomerKeyMD5.toString(),
};
final $result = await _protocol.sendRaw(
method: 'POST',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?select&select-type=2',
headers: headers,
payload: SelectObjectContentRequest(
bucket: bucket,
expression: expression,
expressionType: expressionType,
inputSerialization: inputSerialization,
key: key,
outputSerialization: outputSerialization,
expectedBucketOwner: expectedBucketOwner,
requestProgress: requestProgress,
sSECustomerAlgorithm: sSECustomerAlgorithm,
sSECustomerKey: sSECustomerKey,
sSECustomerKeyMD5: sSECustomerKeyMD5,
scanRange: scanRange)
.toXml('SelectObjectContentRequest'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return SelectObjectContentOutput(
payload: SelectObjectContentEventStream.fromXml($elem),
);
}