updateObjectEncryption method
UpdateObjectEncryption operation to change encrypted objects
from server-side encryption with Amazon S3 managed keys (SSE-S3) to
server-side encryption with Key Management Service (KMS) keys (SSE-KMS),
or to apply S3 Bucket Keys. You can also use the
UpdateObjectEncryption operation to change the
customer-managed KMS key used to encrypt your data so that you can comply
with custom key-rotation standards.
Using the UpdateObjectEncryption operation, you can
atomically update the server-side encryption type of an existing object in
a general purpose bucket without any data movement. The
UpdateObjectEncryption operation uses envelope encryption to
re-encrypt the data key used to encrypt and decrypt your object with your
newly specified server-side encryption type. In other words, when you use
the UpdateObjectEncryption operation, your data isn't copied,
archived objects in the S3 Glacier Flexible Retrieval and S3 Glacier Deep
Archive storage classes aren't restored, and objects in the S3
Intelligent-Tiering storage class aren't moved between tiers.
Additionally, the UpdateObjectEncryption operation preserves
all object metadata properties, including the storage class, creation
date, last modified date, ETag, and checksum properties. For more
information, see
Updating server-side encryption for existing objects in the Amazon
S3 User Guide.
By default, all UpdateObjectEncryption requests that specify
a customer-managed KMS key are restricted to KMS keys that are owned by
the bucket owner's Amazon Web Services account. If you're using
Organizations, you can request the ability to use KMS keys owned by other
member accounts within your organization by contacting Amazon Web Services
Support.
- Permissions
-
-
To use the
UpdateObjectEncryptionoperation, you must have the following permissions:-
s3:PutObject -
s3:UpdateObjectEncryption -
kms:Encrypt -
kms:Decrypt -
kms:GenerateDataKey -
kms:ReEncrypt*
-
-
If you're using Organizations, to use this operation with customer-managed
KMS keys from other Amazon Web Services accounts within your organization,
you must have the
organizations:DescribeAccountpermission.
-
To use the
- Errors
-
-
You might receive an
InvalidRequesterror for several reasons. Depending on the reason for the error, you might receive one of the following messages:-
The
UpdateObjectEncryptionoperation doesn't supported unencrypted source objects. Only source objects encrypted with SSE-S3 or SSE-KMS are supported. -
The
UpdateObjectEncryptionoperation doesn't support source objects with the encryption type DSSE-KMS or SSE-C. Only source objects encrypted with SSE-S3 or SSE-KMS are supported. -
The
UpdateObjectEncryptionoperation doesn't support updating the encryption type to DSSE-KMS or SSE-C. Modify the request to specify SSE-KMS for the updated encryption type, and then try again. - Requests that modify an object encryption configuration require Amazon Web Services Signature Version 4. Modify the request to use Amazon Web Services Signature Version 4, and then try again.
-
Requests that modify an object encryption configuration require a valid
new encryption type. Valid values are
SSEKMS. Modify the request to specify SSE-KMS for the updated encryption type, and then try again. - Requests that modify an object's encryption type to SSE-KMS require an Amazon Web Services KMS key Amazon Resource Name (ARN). Modify the request to specify a KMS key ARN, and then try again.
- Requests that modify an object's encryption type to SSE-KMS require a valid Amazon Web Services KMS key Amazon Resource Name (ARN). Confirm that you have a correctly formatted KMS key ARN in your request, and then try again.
-
The
BucketKeyEnabledvalue isn't valid. Valid values aretrueorfalse. Modify the request to specify a valid value, and then try again.
-
The
-
You might receive an
AccessDeniederror for several reasons. Depending on the reason for the error, you might receive one of the following messages:- The Amazon Web Services KMS key in the request must be owned by the same account as the bucket. Modify the request to specify a KMS key from the same account, and then try again.
-
The bucket owner's account was approved to make
UpdateObjectEncryptionrequests that use any Amazon Web Services KMS key in their organization, but the bucket owner's account isn't part of an organization in Organizations. Make sure that the bucket owner's account and the specified KMS key belong to the same organization, and then try again. - The specified Amazon Web Services KMS key must be from the same organization in Organizations as the bucket. Specify a KMS key that belongs to the same organization as the bucket, and then try again.
-
The encryption type for the specified object can’t be updated because that
object is protected by S3 Object Lock. If the object has a governance-mode
retention period or a legal hold, you must first remove the Object Lock
status on the object before you issue your
UpdateObjectEncryptionrequest. You can't use theUpdateObjectEncryptionoperation with objects that have an Object Lock compliance mode retention period applied to them.
-
You might receive an
May throw AccessDenied.
May throw InvalidRequest.
May throw NoSuchKey.
Parameter bucket :
The name of the general purpose bucket that contains the specified object
key name.
When you use this operation with an access point attached to a general
purpose bucket, you must either provide the alias of the access point in
place of the bucket name or you must specify the access point Amazon
Resource Name (ARN). When using the access point ARN, you must direct
requests to the access point hostname. The access point hostname takes the
form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this operation with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see
Referencing access points in the Amazon S3 User Guide.
Parameter key :
The key name of the object that you want to update the server-side
encryption type for.
Parameter objectEncryption :
The updated server-side encryption type for this object. The
UpdateObjectEncryption operation supports the SSE-S3 and
SSE-KMS encryption types.
Valid Values: SSES3 | SSEKMS
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use an Amazon Web Services SDK. This header doesn't provide any
additional functionality if you don't use the SDK. When you send this
header, there must be a corresponding x-amz-checksum or
x-amz-trailer header sent. Otherwise, Amazon S3 fails the
request with the HTTP status code 400 Bad Request. For more
information, see
Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash for the request body. For requests made using the Amazon Web
Services Command Line Interface (CLI) or Amazon Web Services SDKs, this
field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide doesn't match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter versionId :
The version ID of the object that you want to update the server-side
encryption type for.
Implementation
Future<UpdateObjectEncryptionResponse> updateObjectEncryption({
required String bucket,
required String key,
required ObjectEncryption objectEncryption,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
RequestPayer? requestPayer,
String? versionId,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (versionId != null) 'versionId': [versionId],
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?encryption',
queryParams: $query,
headers: headers,
payload: objectEncryption.toXml('ObjectEncryption'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return UpdateObjectEncryptionResponse(
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
);
}