uploadPart method
- required String bucket,
- required String key,
- required int partNumber,
- required String uploadId,
- Uint8List? body,
- ChecksumAlgorithm? checksumAlgorithm,
- String? checksumCRC32,
- String? checksumCRC32C,
- String? checksumCRC64NVME,
- String? checksumMD5,
- String? checksumSHA1,
- String? checksumSHA256,
- String? checksumSHA512,
- String? checksumXXHASH128,
- String? checksumXXHASH3,
- String? checksumXXHASH64,
- int? contentLength,
- String? contentMD5,
- String? expectedBucketOwner,
- RequestPayer? requestPayer,
- String? sSECustomerAlgorithm,
- String? sSECustomerKey,
- String? sSECustomerKeyMD5,
Uploads a part in a multipart upload. You must initiate a multipart upload (see CreateMultipartUpload) before you can upload any part. In response to your initiate request, Amazon S3 returns an upload ID, a unique identifier that you must include in your upload part request.
Part numbers can be any number from 1 to 10,000, inclusive. A part number uniquely identifies a part and also defines its position within the object being created. If you upload a new part using the same part number that was used with a previous part, the previously uploaded part is overwritten.
For information about maximum and minimum part sizes and other multipart upload specifications, see Multipart upload limits in the Amazon S3 User Guide. For more information on multipart uploads, go to Multipart Upload Overview in the Amazon S3 User Guide .
- Permissions
-
-
General purpose bucket permissions - To perform a multipart upload
with encryption using an Key Management Service key, the requester must
have permission to the
kms:Decryptandkms:GenerateDataKeyactions on the key. The requester must also have permissions for thekms:GenerateDataKeyaction for theCreateMultipartUploadAPI. Then, the requester needs permissions for thekms:Decryptaction on theUploadPartandUploadPartCopyAPIs.These permissions are required because Amazon S3 must decrypt and read data from the encrypted file parts before it completes the multipart upload. For more information about KMS permissions, see Protecting data using server-side encryption with KMS in the Amazon S3 User Guide. For information about the permissions required to use the multipart upload API, see Multipart upload and permissions and Multipart upload API and permissions in the Amazon S3 User Guide.
-
Directory bucket permissions - To grant access to this API
operation on a directory bucket, we recommend that you use the
CreateSessionAPI operation for session-based authorization. Specifically, you grant thes3express:CreateSessionpermission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make theCreateSessionAPI call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make anotherCreateSessionAPI call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, seeCreateSession.If the object is encrypted with SSE-KMS, you must also have the
kms:GenerateDataKeyandkms:Decryptpermissions in IAM identity-based policies and KMS key policies for the KMS key.
-
General purpose bucket permissions - To perform a multipart upload
with encryption using an Key Management Service key, the requester must
have permission to the
- Data integrity
-
General purpose bucket - To ensure that data is not corrupted
traversing the network, specify the
Content-MD5header in the upload part request. Amazon S3 checks the part data against the provided MD5 value. If they do not match, Amazon S3 returns an error. If the upload request is signed with Signature Version 4, then Amazon Web Services S3 uses thex-amz-content-sha256header as a checksum instead ofContent-MD5. For more information see Authenticating Requests: Using the Authorization Header (Amazon Web Services Signature Version 4). - Encryption
-
-
General purpose bucket - Server-side encryption is for data
encryption at rest. Amazon S3 encrypts your data as it writes it to disks
in its data centers and decrypts it when you access it. You have mutually
exclusive options to protect data using server-side encryption in Amazon
S3, depending on how you choose to manage the encryption keys.
Specifically, the encryption key options are Amazon S3 managed keys
(SSE-S3), Amazon Web Services KMS keys (SSE-KMS), and Customer-Provided
Keys (SSE-C). Amazon S3 encrypts data with server-side encryption using
Amazon S3 managed keys (SSE-S3) by default. You can optionally tell Amazon
S3 to encrypt data at rest using server-side encryption with other key
options. The option you use depends on whether you want to use KMS keys
(SSE-KMS) or provide your own encryption key (SSE-C).
Server-side encryption is supported by the S3 Multipart Upload operations. Unless you are using a customer-provided encryption key (SSE-C), you don't need to specify the encryption parameters in each UploadPart request. Instead, you only need to specify the server-side encryption parameters in the initial Initiate Multipart request. For more information, see CreateMultipartUpload. If you request server-side encryption using a customer-provided encryption key (SSE-C) in your initiate multipart upload request, you must provide identical encryption information in each part upload using the following request headers.
- x-amz-server-side-encryption-customer-algorithm
- x-amz-server-side-encryption-customer-key
- x-amz-server-side-encryption-customer-key-MD5
-
Directory buckets - For directory buckets, there are only two
supported options for server-side encryption: server-side encryption with
Amazon S3 managed keys (SSE-S3) (
AES256) and server-side encryption with KMS keys (SSE-KMS) (aws:kms).
-
General purpose bucket - Server-side encryption is for data
encryption at rest. Amazon S3 encrypts your data as it writes it to disks
in its data centers and decrypts it when you access it. You have mutually
exclusive options to protect data using server-side encryption in Amazon
S3, depending on how you choose to manage the encryption keys.
Specifically, the encryption key options are Amazon S3 managed keys
(SSE-S3), Amazon Web Services KMS keys (SSE-KMS), and Customer-Provided
Keys (SSE-C). Amazon S3 encrypts data with server-side encryption using
Amazon S3 managed keys (SSE-S3) by default. You can optionally tell Amazon
S3 to encrypt data at rest using server-side encryption with other key
options. The option you use depends on whether you want to use KMS keys
(SSE-KMS) or provide your own encryption key (SSE-C).
- Special errors
-
-
Error Code:
NoSuchUpload- Description: The specified multipart upload does not exist. The upload ID might be invalid, or the multipart upload might have been aborted or completed.
- HTTP Status Code: 404 Not Found
- SOAP Fault Code Prefix: Client
-
Error Code:
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
UploadPart:
Parameter bucket :
The name of the bucket to which the multipart upload was initiated.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter key :
Object key for which the multipart upload was initiated.
Parameter partNumber :
Part number of part being uploaded. This is a positive integer between 1
and 10,000.
Parameter uploadId :
Upload ID identifying the multipart upload whose part is being uploaded.
Parameter body :
Object data.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
This checksum algorithm must be the same for all parts and it match the
checksum value supplied in the CreateMultipartUpload request.
Parameter checksumCRC32 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 32-bit CRC32 checksum of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumCRC32C :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 32-bit CRC32C checksum of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumCRC64NVME :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit CRC64NVME checksum of the part.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumMD5 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit MD5 digest of the part. For more
information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA1 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 160-bit SHA1 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA256 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 256-bit SHA256 digest of the object. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA512 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 512-bit SHA512 digest of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH128 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit XXHASH128 checksum of the part.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH3 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH3 checksum of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH64 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH64 checksum of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter contentLength :
Size of the body in bytes. This parameter is useful when the size of the
body cannot be determined automatically.
Parameter contentMD5 :
The Base64 encoded 128-bit MD5 digest of the part data. This parameter is
auto-populated when using the command from the CLI. This parameter is
required if object lock parameters are specified.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter sSECustomerAlgorithm :
Specifies the algorithm to use when encrypting the object (for example,
AES256).
Parameter sSECustomerKey :
Specifies the customer-provided encryption key for Amazon S3 to use in
encrypting data. This value is used to store the object and then it is
discarded; Amazon S3 does not store the encryption key. The key must be
appropriate for use with the algorithm specified in the
x-amz-server-side-encryption-customer-algorithm header. This
must be the same encryption key specified in the initiate multipart upload
request.
Parameter sSECustomerKeyMD5 :
Specifies the 128-bit MD5 digest of the encryption key according to RFC
1321. Amazon S3 uses this header for a message integrity check to ensure
that the encryption key was transmitted without error.
Implementation
Future<UploadPartOutput> uploadPart({
required String bucket,
required String key,
required int partNumber,
required String uploadId,
Uint8List? body,
ChecksumAlgorithm? checksumAlgorithm,
String? checksumCRC32,
String? checksumCRC32C,
String? checksumCRC64NVME,
String? checksumMD5,
String? checksumSHA1,
String? checksumSHA256,
String? checksumSHA512,
String? checksumXXHASH128,
String? checksumXXHASH3,
String? checksumXXHASH64,
int? contentLength,
String? contentMD5,
String? expectedBucketOwner,
RequestPayer? requestPayer,
String? sSECustomerAlgorithm,
String? sSECustomerKey,
String? sSECustomerKeyMD5,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (checksumCRC32 != null)
'x-amz-checksum-crc32': checksumCRC32.toString(),
if (checksumCRC32C != null)
'x-amz-checksum-crc32c': checksumCRC32C.toString(),
if (checksumCRC64NVME != null)
'x-amz-checksum-crc64nvme': checksumCRC64NVME.toString(),
if (checksumMD5 != null) 'x-amz-checksum-md5': checksumMD5.toString(),
if (checksumSHA1 != null) 'x-amz-checksum-sha1': checksumSHA1.toString(),
if (checksumSHA256 != null)
'x-amz-checksum-sha256': checksumSHA256.toString(),
if (checksumSHA512 != null)
'x-amz-checksum-sha512': checksumSHA512.toString(),
if (checksumXXHASH128 != null)
'x-amz-checksum-xxhash128': checksumXXHASH128.toString(),
if (checksumXXHASH3 != null)
'x-amz-checksum-xxhash3': checksumXXHASH3.toString(),
if (checksumXXHASH64 != null)
'x-amz-checksum-xxhash64': checksumXXHASH64.toString(),
if (contentLength != null) 'Content-Length': contentLength.toString(),
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
if (sSECustomerAlgorithm != null)
'x-amz-server-side-encryption-customer-algorithm':
sSECustomerAlgorithm.toString(),
if (sSECustomerKey != null)
'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
if (sSECustomerKeyMD5 != null)
'x-amz-server-side-encryption-customer-key-MD5':
sSECustomerKeyMD5.toString(),
};
final $query = <String, List<String>>{
'partNumber': [partNumber.toString()],
'uploadId': [uploadId],
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?x-id=UploadPart',
queryParams: $query,
headers: headers,
payload: body,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return UploadPartOutput(
bucketKeyEnabled: _s.extractHeaderBoolValue(
$result.headers, 'x-amz-server-side-encryption-bucket-key-enabled'),
checksumCRC32:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32'),
checksumCRC32C:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-crc32c'),
checksumCRC64NVME: _s.extractHeaderStringValue(
$result.headers, 'x-amz-checksum-crc64nvme'),
checksumMD5:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-md5'),
checksumSHA1:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha1'),
checksumSHA256:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha256'),
checksumSHA512:
_s.extractHeaderStringValue($result.headers, 'x-amz-checksum-sha512'),
checksumXXHASH128: _s.extractHeaderStringValue(
$result.headers, 'x-amz-checksum-xxhash128'),
checksumXXHASH3: _s.extractHeaderStringValue(
$result.headers, 'x-amz-checksum-xxhash3'),
checksumXXHASH64: _s.extractHeaderStringValue(
$result.headers, 'x-amz-checksum-xxhash64'),
eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
sSECustomerAlgorithm: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-customer-algorithm'),
sSECustomerKeyMD5: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-customer-key-MD5'),
sSEKMSKeyId: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-aws-kms-key-id'),
serverSideEncryption: _s
.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption')
?.let(ServerSideEncryption.fromString),
);
}