writeGetObjectResponse method
- required String requestRoute,
- required String requestToken,
- String? acceptRanges,
- Uint8List? body,
- bool? bucketKeyEnabled,
- String? cacheControl,
- String? checksumCRC32,
- String? checksumCRC32C,
- String? checksumCRC64NVME,
- String? checksumMD5,
- String? checksumSHA1,
- String? checksumSHA256,
- String? checksumSHA512,
- String? checksumXXHASH128,
- String? checksumXXHASH3,
- String? checksumXXHASH64,
- String? contentDisposition,
- String? contentEncoding,
- String? contentLanguage,
- int? contentLength,
- String? contentRange,
- String? contentType,
- bool? deleteMarker,
- String? eTag,
- String? errorCode,
- String? errorMessage,
- String? expiration,
- String? expires,
- DateTime? lastModified,
- Map<
String, String> ? metadata, - int? missingMeta,
- ObjectLockLegalHoldStatus? objectLockLegalHoldStatus,
- ObjectLockMode? objectLockMode,
- DateTime? objectLockRetainUntilDate,
- int? partsCount,
- ReplicationStatus? replicationStatus,
- RequestCharged? requestCharged,
- String? restore,
- String? sSECustomerAlgorithm,
- String? sSECustomerKeyMD5,
- String? sSEKMSKeyId,
- ServerSideEncryption? serverSideEncryption,
- int? statusCode,
- StorageClass? storageClass,
- int? tagCount,
- String? versionId,
GetObject operation when
using Object Lambda access points. For information about Object Lambda
access points, see Transforming
objects with Object Lambda access points in the Amazon S3 User
Guide.
This operation supports metadata that can be returned by GetObject,
in addition to RequestRoute, RequestToken,
StatusCode, ErrorCode, and
ErrorMessage. The GetObject response metadata is
supported so that the WriteGetObjectResponse caller,
typically an Lambda function, can provide the same metadata when it
internally invokes GetObject. When
WriteGetObjectResponse is called by a customer-owned Lambda
function, the metadata returned to the end user GetObject
call might differ from what Amazon S3 would normally return.
You can include any number of metadata headers. When including a metadata
header, it should be prefaced with x-amz-meta. For example,
x-amz-meta-my-custom-header: MyCustomValue. The primary use
case for this is to forward GetObject metadata.
Amazon Web Services provides some prebuilt Lambda functions that you can use with S3 Object Lambda to detect and redact personally identifiable information (PII) and decompress S3 objects. These Lambda functions are available in the Amazon Web Services Serverless Application Repository, and can be selected through the Amazon Web Services Management Console when you create your Object Lambda access point.
Example 1: PII Access Control - This Lambda function uses Amazon Comprehend, a natural language processing (NLP) service using machine learning to find insights and relationships in text. It automatically detects personally identifiable information (PII) such as names, addresses, dates, credit card numbers, and social security numbers from documents in your Amazon S3 bucket.
Example 2: PII Redaction - This Lambda function uses Amazon Comprehend, a natural language processing (NLP) service using machine learning to find insights and relationships in text. It automatically redacts personally identifiable information (PII) such as names, addresses, dates, credit card numbers, and social security numbers from documents in your Amazon S3 bucket.
Example 3: Decompression - The Lambda function S3ObjectLambdaDecompression, is equipped to decompress objects stored in S3 in one of six compressed file formats including bzip2, gzip, snappy, zlib, zstandard and ZIP.
For information on how to view and use these functions, see Using Amazon Web Services built Lambda functions in the Amazon S3 User Guide.
Parameter requestRoute :
Route prefix to the HTTP URL generated.
Parameter requestToken :
A single use encrypted token that maps WriteGetObjectResponse
to the end user GetObject request.
Parameter acceptRanges :
Indicates that a range of bytes was specified.
Parameter body :
The object data.
Parameter bucketKeyEnabled :
Indicates whether the object stored in Amazon S3 uses an S3 bucket key for
server-side encryption with Amazon Web Services KMS (SSE-KMS).
Parameter cacheControl :
Specifies caching behavior along the request/reply chain.
Parameter checksumCRC32 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This specifies the
Base64 encoded, 32-bit CRC32 checksum of the object returned
by the Object Lambda function. This may not match the checksum for the
object stored in Amazon S3. Amazon S3 will perform validation of the
checksum values only when the original GetObject request
required checksum validation. For more information about checksums, see Checking
object integrity in the Amazon S3 User Guide.
Only one checksum header can be specified at a time. If you supply multiple checksum headers, this request will fail.
Parameter checksumCRC32C :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This specifies the
Base64 encoded, 32-bit CRC32C checksum of the object returned
by the Object Lambda function. This may not match the checksum for the
object stored in Amazon S3. Amazon S3 will perform validation of the
checksum values only when the original GetObject request
required checksum validation. For more information about checksums, see Checking
object integrity in the Amazon S3 User Guide.
Only one checksum header can be specified at a time. If you supply multiple checksum headers, this request will fail.
Parameter checksumCRC64NVME :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit CRC64NVME checksum of the part.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumMD5 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit MD5 digest of the part. For more
information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumSHA1 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This specifies the
Base64 encoded, 160-bit SHA1 digest of the object returned by
the Object Lambda function. This may not match the checksum for the object
stored in Amazon S3. Amazon S3 will perform validation of the checksum
values only when the original GetObject request required
checksum validation. For more information about checksums, see Checking
object integrity in the Amazon S3 User Guide.
Only one checksum header can be specified at a time. If you supply multiple checksum headers, this request will fail.
Parameter checksumSHA256 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This specifies the
Base64 encoded, 256-bit SHA256 digest of the object returned
by the Object Lambda function. This may not match the checksum for the
object stored in Amazon S3. Amazon S3 will perform validation of the
checksum values only when the original GetObject request
required checksum validation. For more information about checksums, see Checking
object integrity in the Amazon S3 User Guide.
Only one checksum header can be specified at a time. If you supply multiple checksum headers, this request will fail.
Parameter checksumSHA512 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 512-bit SHA512 digest of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH128 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 128-bit XXHASH128 checksum of the part.
For more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH3 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH3 checksum of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter checksumXXHASH64 :
This header can be used as a data integrity check to verify that the data
received is the same data that was originally sent. This header specifies
the Base64 encoded, 64-bit XXHASH64 checksum of the part. For
more information, see Checking
object integrity in the Amazon S3 User Guide.
Parameter contentDisposition :
Specifies presentational information for the object.
Parameter contentEncoding :
Specifies what content encodings have been applied to the object and thus
what decoding mechanisms must be applied to obtain the media-type
referenced by the Content-Type header field.
Parameter contentLanguage :
The language the content is in.
Parameter contentLength :
The size of the content body in bytes.
Parameter contentRange :
The portion of the object returned in the response.
Parameter contentType :
A standard MIME type describing the format of the object data.
Parameter deleteMarker :
Specifies whether an object stored in Amazon S3 is (true) or
is not (false) a delete marker. To learn more about delete
markers, see Working
with delete markers.
Parameter eTag :
An opaque identifier assigned by a web server to a specific version of a
resource found at a URL.
Parameter errorCode :
A string that uniquely identifies an error condition. Returned in the
tag of the error XML response for a corresponding
GetObject call. Cannot be used with a successful
StatusCode header or when the transformed object is provided
in the body. All error codes from S3 are sentence-cased. The regular
expression (regex) value is "^[A-Z][a-zA-Z]+$".
Parameter errorMessage :
Contains a generic description of the error condition. Returned in the
Parameter expiration :
If the object expiration is configured (see PUT Bucket lifecycle), the
response includes this header. It includes the expiry-date
and rule-id key-value pairs that provide the object
expiration information. The value of the rule-id is
URL-encoded.
Parameter expires :
The date and time at which the object is no longer cacheable.
Parameter lastModified :
The date and time that the object was last modified.
Parameter metadata :
A map of metadata to store with the object in S3.
Parameter missingMeta :
Set to the number of metadata entries not returned in
x-amz-meta headers. This can happen if you create metadata
using an API like SOAP that supports more flexible metadata than the REST
API. For example, using SOAP, you can create metadata whose values are not
legal HTTP headers.
Parameter objectLockLegalHoldStatus :
Indicates whether an object stored in Amazon S3 has an active legal hold.
Parameter objectLockMode :
Indicates whether an object stored in Amazon S3 has Object Lock enabled.
For more information about S3 Object Lock, see Object
Lock.
Parameter objectLockRetainUntilDate :
The date and time when Object Lock is configured to expire.
Parameter partsCount :
The count of parts this object has.
Parameter replicationStatus :
Indicates if request involves bucket that is either a source or
destination in a Replication rule. For more information about S3
Replication, see Replication.
Parameter restore :
Provides information about object restoration operation and expiration
time of the restored object copy.
Parameter sSECustomerAlgorithm :
Encryption algorithm used if server-side encryption with a
customer-provided encryption key was specified for object stored in Amazon
S3.
Parameter sSECustomerKeyMD5 :
128-bit MD5 digest of customer-provided encryption key used in Amazon S3
to encrypt data stored in S3. For more information, see Protecting
data using server-side encryption with customer-provided encryption keys
(SSE-C).
Parameter sSEKMSKeyId :
If present, specifies the ID (Key ID, Key ARN, or Key Alias) of the Amazon
Web Services Key Management Service (Amazon Web Services KMS) symmetric
encryption customer managed key that was used for stored in Amazon S3
object.
Parameter serverSideEncryption :
The server-side encryption algorithm used when storing requested object in
Amazon S3 or Amazon FSx.
Parameter statusCode :
The integer status code for an HTTP response of a corresponding
GetObject request. The following is a list of status codes.
-
200 - OK
-
206 - Partial Content
-
304 - Not Modified
-
400 - Bad Request
-
401 - Unauthorized
-
403 - Forbidden
-
404 - Not Found
-
405 - Method Not Allowed
-
409 - Conflict
-
411 - Length Required
-
412 - Precondition Failed
-
416 - Range Not Satisfiable
-
500 - Internal Server Error
-
503 - Service Unavailable
Parameter storageClass :
Provides storage class information of the object. Amazon S3 returns this
header for all objects except for S3 Standard storage class objects.
For more information, see Storage
Classes.
Parameter tagCount :
The number of tags, if any, on the object.
Parameter versionId :
An ID used to reference a specific version of the object.
Implementation
Future<void> writeGetObjectResponse({
required String requestRoute,
required String requestToken,
String? acceptRanges,
Uint8List? body,
bool? bucketKeyEnabled,
String? cacheControl,
String? checksumCRC32,
String? checksumCRC32C,
String? checksumCRC64NVME,
String? checksumMD5,
String? checksumSHA1,
String? checksumSHA256,
String? checksumSHA512,
String? checksumXXHASH128,
String? checksumXXHASH3,
String? checksumXXHASH64,
String? contentDisposition,
String? contentEncoding,
String? contentLanguage,
int? contentLength,
String? contentRange,
String? contentType,
bool? deleteMarker,
String? eTag,
String? errorCode,
String? errorMessage,
String? expiration,
String? expires,
DateTime? lastModified,
Map<String, String>? metadata,
int? missingMeta,
ObjectLockLegalHoldStatus? objectLockLegalHoldStatus,
ObjectLockMode? objectLockMode,
DateTime? objectLockRetainUntilDate,
int? partsCount,
ReplicationStatus? replicationStatus,
RequestCharged? requestCharged,
String? restore,
String? sSECustomerAlgorithm,
String? sSECustomerKeyMD5,
String? sSEKMSKeyId,
ServerSideEncryption? serverSideEncryption,
int? statusCode,
StorageClass? storageClass,
int? tagCount,
String? versionId,
}) async {
final headers = <String, String>{
'x-amz-request-route': requestRoute.toString(),
'x-amz-request-token': requestToken.toString(),
if (acceptRanges != null)
'x-amz-fwd-header-accept-ranges': acceptRanges.toString(),
if (bucketKeyEnabled != null)
'x-amz-fwd-header-x-amz-server-side-encryption-bucket-key-enabled':
bucketKeyEnabled.toString(),
if (cacheControl != null)
'x-amz-fwd-header-Cache-Control': cacheControl.toString(),
if (checksumCRC32 != null)
'x-amz-fwd-header-x-amz-checksum-crc32': checksumCRC32.toString(),
if (checksumCRC32C != null)
'x-amz-fwd-header-x-amz-checksum-crc32c': checksumCRC32C.toString(),
if (checksumCRC64NVME != null)
'x-amz-fwd-header-x-amz-checksum-crc64nvme':
checksumCRC64NVME.toString(),
if (checksumMD5 != null)
'x-amz-fwd-header-x-amz-checksum-md5': checksumMD5.toString(),
if (checksumSHA1 != null)
'x-amz-fwd-header-x-amz-checksum-sha1': checksumSHA1.toString(),
if (checksumSHA256 != null)
'x-amz-fwd-header-x-amz-checksum-sha256': checksumSHA256.toString(),
if (checksumSHA512 != null)
'x-amz-fwd-header-x-amz-checksum-sha512': checksumSHA512.toString(),
if (checksumXXHASH128 != null)
'x-amz-fwd-header-x-amz-checksum-xxhash128':
checksumXXHASH128.toString(),
if (checksumXXHASH3 != null)
'x-amz-fwd-header-x-amz-checksum-xxhash3': checksumXXHASH3.toString(),
if (checksumXXHASH64 != null)
'x-amz-fwd-header-x-amz-checksum-xxhash64': checksumXXHASH64.toString(),
if (contentDisposition != null)
'x-amz-fwd-header-Content-Disposition': contentDisposition.toString(),
if (contentEncoding != null)
'x-amz-fwd-header-Content-Encoding': contentEncoding.toString(),
if (contentLanguage != null)
'x-amz-fwd-header-Content-Language': contentLanguage.toString(),
if (contentLength != null) 'Content-Length': contentLength.toString(),
if (contentRange != null)
'x-amz-fwd-header-Content-Range': contentRange.toString(),
if (contentType != null)
'x-amz-fwd-header-Content-Type': contentType.toString(),
if (deleteMarker != null)
'x-amz-fwd-header-x-amz-delete-marker': deleteMarker.toString(),
if (eTag != null) 'x-amz-fwd-header-ETag': eTag.toString(),
if (errorCode != null) 'x-amz-fwd-error-code': errorCode.toString(),
if (errorMessage != null)
'x-amz-fwd-error-message': errorMessage.toString(),
if (expiration != null)
'x-amz-fwd-header-x-amz-expiration': expiration.toString(),
if (expires != null) 'x-amz-fwd-header-Expires': expires.toString(),
if (lastModified != null)
'x-amz-fwd-header-Last-Modified': _s.rfc822ToJson(lastModified),
if (metadata != null)
...metadata.map((key, value) => MapEntry('x-amz-meta-$key', value)),
if (missingMeta != null)
'x-amz-fwd-header-x-amz-missing-meta': missingMeta.toString(),
if (objectLockLegalHoldStatus != null)
'x-amz-fwd-header-x-amz-object-lock-legal-hold':
objectLockLegalHoldStatus.value,
if (objectLockMode != null)
'x-amz-fwd-header-x-amz-object-lock-mode': objectLockMode.value,
if (objectLockRetainUntilDate != null)
'x-amz-fwd-header-x-amz-object-lock-retain-until-date':
_s.iso8601ToJson(objectLockRetainUntilDate),
if (partsCount != null)
'x-amz-fwd-header-x-amz-mp-parts-count': partsCount.toString(),
if (replicationStatus != null)
'x-amz-fwd-header-x-amz-replication-status': replicationStatus.value,
if (requestCharged != null)
'x-amz-fwd-header-x-amz-request-charged': requestCharged.value,
if (restore != null) 'x-amz-fwd-header-x-amz-restore': restore.toString(),
if (sSECustomerAlgorithm != null)
'x-amz-fwd-header-x-amz-server-side-encryption-customer-algorithm':
sSECustomerAlgorithm.toString(),
if (sSECustomerKeyMD5 != null)
'x-amz-fwd-header-x-amz-server-side-encryption-customer-key-MD5':
sSECustomerKeyMD5.toString(),
if (sSEKMSKeyId != null)
'x-amz-fwd-header-x-amz-server-side-encryption-aws-kms-key-id':
sSEKMSKeyId.toString(),
if (serverSideEncryption != null)
'x-amz-fwd-header-x-amz-server-side-encryption':
serverSideEncryption.value,
if (statusCode != null) 'x-amz-fwd-status': statusCode.toString(),
if (storageClass != null)
'x-amz-fwd-header-x-amz-storage-class': storageClass.value,
if (tagCount != null)
'x-amz-fwd-header-x-amz-tagging-count': tagCount.toString(),
if (versionId != null)
'x-amz-fwd-header-x-amz-version-id': versionId.toString(),
};
await _protocol.send(
method: 'POST',
requestUri: '/WriteGetObjectResponse',
headers: headers,
payload: body,
exceptionFnMap: _exceptionFns,
);
}