associateAccessGrantsIdentityCenter method
Associate your S3 Access Grants instance with an Amazon Web Services IAM Identity Center instance. Use this action if you want to create access grants for users or groups from your corporate identity directory. First, you must add your corporate identity directory to Amazon Web Services IAM Identity Center. Then, you can associate this IAM Identity Center instance with your S3 Access Grants instance.
- Permissions
-
You must have the
s3:AssociateAccessGrantsIdentityCenterpermission to use this operation. - Additional Permissions
-
You must also have the following permissions:
sso:CreateApplication,sso:PutApplicationGrant, andsso:PutApplicationAuthenticationMethod.
Parameter accountId :
The Amazon Web Services account ID of the S3 Access Grants instance.
Parameter identityCenterArn :
The Amazon Resource Name (ARN) of the Amazon Web Services IAM Identity
Center instance that you are associating with your S3 Access Grants
instance. An IAM Identity Center instance is your corporate identity
directory that you added to the IAM Identity Center. You can use the ListInstances
API operation to retrieve a list of your Identity Center instances and
their ARNs.
Implementation
Future<void> associateAccessGrantsIdentityCenter({
required String accountId,
required String identityCenterArn,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'POST',
requestUri: '/v20180820/accessgrantsinstance/identitycenter',
headers: headers,
payload: AssociateAccessGrantsIdentityCenterRequest(
accountId: accountId, identityCenterArn: identityCenterArn)
.toXml('AssociateAccessGrantsIdentityCenterRequest'),
exceptionFnMap: _exceptionFns,
);
}