createAccessPointForObjectLambda method
Creates an Object Lambda Access Point. For more information, see Transforming
objects with Object Lambda Access Points in the Amazon S3 User
Guide.
The following actions are related to
CreateAccessPointForObjectLambda:
Parameter accountId :
The Amazon Web Services account ID for owner of the specified Object
Lambda Access Point.
Parameter configuration :
Object Lambda Access Point configuration as a JSON document.
Parameter name :
The name you want to assign to this Object Lambda Access Point.
Implementation
Future<CreateAccessPointForObjectLambdaResult>
createAccessPointForObjectLambda({
required String accountId,
required ObjectLambdaConfiguration configuration,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'PUT',
requestUri:
'/v20180820/accesspointforobjectlambda/${Uri.encodeComponent(name)}',
headers: headers,
payload: CreateAccessPointForObjectLambdaRequest(
accountId: accountId, configuration: configuration, name: name)
.toXml('CreateAccessPointForObjectLambdaRequest'),
exceptionFnMap: _exceptionFns,
);
return CreateAccessPointForObjectLambdaResult.fromXml($result.body);
}