deleteAccessGrantsLocation method

Future<void> deleteAccessGrantsLocation({
  1. required String accessGrantsLocationId,
  2. required String accountId,
})

Deregisters a location from your S3 Access Grants instance. You can only delete a location registration from an S3 Access Grants instance if there are no grants associated with this location. See Delete a grant for information on how to delete grants. You need to have at least one registered location in your S3 Access Grants instance in order to create access grants.

Permissions
You must have the s3:DeleteAccessGrantsLocation permission to use this operation.

Parameter accessGrantsLocationId : The ID of the registered location that you are deregistering from your S3 Access Grants instance. S3 Access Grants assigned this ID when you registered the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.

Parameter accountId : The Amazon Web Services account ID of the S3 Access Grants instance.

Implementation

Future<void> deleteAccessGrantsLocation({
  required String accessGrantsLocationId,
  required String accountId,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  await _protocol.send(
    method: 'DELETE',
    requestUri:
        '/v20180820/accessgrantsinstance/location/${Uri.encodeComponent(accessGrantsLocationId)}',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}