deleteJobTagging method

Future<void> deleteJobTagging({
  1. required String accountId,
  2. required String jobId,
})

Removes the entire tag set from the specified S3 Batch Operations job.

Permissions
To use the DeleteJobTagging operation, you must have permission to perform the s3:DeleteJobTagging action. For more information, see Controlling access and labeling jobs using tags in the Amazon S3 User Guide.
Related actions include:

May throw InternalServiceException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter accountId : The Amazon Web Services account ID associated with the S3 Batch Operations job.

Parameter jobId : The ID for the S3 Batch Operations job whose tags you want to delete.

Implementation

Future<void> deleteJobTagging({
  required String accountId,
  required String jobId,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  await _protocol.send(
    method: 'DELETE',
    requestUri: '/v20180820/jobs/${Uri.encodeComponent(jobId)}/tagging',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
}