deletePublicAccessBlock method

Future<void> deletePublicAccessBlock({
  1. required String accountId,
})
Removes the PublicAccessBlock configuration for an Amazon Web Services account. This operation might be restricted when the account is managed by organization-level Block Public Access policies. You’ll get an Access Denied (403) error when the account is managed by organization-level Block Public Access policies. Organization-level policies override account-level settings, preventing direct account-level modifications. For more information, see Using Amazon S3 block public access.

Related actions include:

Parameter accountId : The account ID for the Amazon Web Services account whose PublicAccessBlock configuration you want to remove.

Implementation

Future<void> deletePublicAccessBlock({
  required String accountId,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  await _protocol.send(
    method: 'DELETE',
    requestUri: '/v20180820/configuration/publicAccessBlock',
    headers: headers,
    endpoint: _resolveEndpoint(
      requiresAccountId: true,
      accountId: accountId,
    ),
    hostPrefix: '{AccountId}.',
    exceptionFnMap: _exceptionFns,
  );
}