describeJob method

Future<DescribeJobResult> describeJob({
  1. required String accountId,
  2. required String jobId,
})

Retrieves the configuration parameters and status for a Batch Operations job. For more information, see S3 Batch Operations in the Amazon S3 User Guide.

Permissions
To use the DescribeJob operation, you must have permission to perform the s3:DescribeJob action.
Related actions include:

May throw BadRequestException. May throw InternalServiceException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter accountId : The Amazon Web Services account ID associated with the S3 Batch Operations job.

Parameter jobId : The ID for the job whose information you want to retrieve.

Implementation

Future<DescribeJobResult> describeJob({
  required String accountId,
  required String jobId,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  final $result = await _protocol.send(
    method: 'GET',
    requestUri: '/v20180820/jobs/${Uri.encodeComponent(jobId)}',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeJobResult.fromXml($result.body);
}