getAccessGrantsLocation method
Retrieves the details of a particular location registered in your S3 Access Grants instance.
- Permissions
-
You must have the
s3:GetAccessGrantsLocationpermission to use this operation.
Parameter accessGrantsLocationId :
The ID of the registered location that you are retrieving. S3 Access
Grants assigns this ID when you register the location. S3 Access Grants
assigns the ID default to the default location
s3:// and assigns an auto-generated ID to other locations
that you register.
Parameter accountId :
The Amazon Web Services account ID of the S3 Access Grants instance.
Implementation
Future<GetAccessGrantsLocationResult> getAccessGrantsLocation({
required String accessGrantsLocationId,
required String accountId,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/v20180820/accessgrantsinstance/location/${Uri.encodeComponent(accessGrantsLocationId)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetAccessGrantsLocationResult.fromXml($result.body);
}