getAccessPoint method
Returns configuration information about the specified access point.
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following actions are related to GetAccessPoint:
Parameter accountId :
The Amazon Web Services account ID for the account that owns the specified
access point.
Parameter name :
The name of the access point whose configuration information you want to
retrieve.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the access point accessed in the
format
arn:aws:s3-outposts:.
For example, to access the access point reports-ap through
Outpost my-outpost owned by account 123456789012
in Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/accesspoint/reports-ap.
The value must be URL encoded.
Implementation
Future<GetAccessPointResult> getAccessPoint({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/accesspoint/${Uri.encodeComponent(name)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetAccessPointResult.fromXml($result.body);
}