getAccessPointConfigurationForObjectLambda method

Future<GetAccessPointConfigurationForObjectLambdaResult> getAccessPointConfigurationForObjectLambda({
  1. required String accountId,
  2. required String name,
})
Returns configuration for an Object Lambda Access Point.

The following actions are related to GetAccessPointConfigurationForObjectLambda:

Parameter accountId : The account ID for the account that owns the specified Object Lambda Access Point.

Parameter name : The name of the Object Lambda Access Point you want to return the configuration for.

Implementation

Future<GetAccessPointConfigurationForObjectLambdaResult>
    getAccessPointConfigurationForObjectLambda({
  required String accountId,
  required String name,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  final $result = await _protocol.send(
    method: 'GET',
    requestUri:
        '/v20180820/accesspointforobjectlambda/${Uri.encodeComponent(name)}/configuration',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return GetAccessPointConfigurationForObjectLambdaResult.fromXml(
      $result.body);
}