getAccessPointPolicyStatus method
Indicates whether the specified access point currently has a policy that
allows public access. For more information about public access through
access points, see Managing
Data Access with Amazon S3 access points in the Amazon S3 User
Guide.
Parameter accountId :
The account ID for the account that owns the specified access point.
Parameter name :
The name of the access point whose policy status you want to retrieve.
Implementation
Future<GetAccessPointPolicyStatusResult> getAccessPointPolicyStatus({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/v20180820/accesspoint/${Uri.encodeComponent(name)}/policyStatus',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetAccessPointPolicyStatusResult.fromXml($result.body);
}