getBucket method
Gets an Amazon S3 on Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide.
If you are using an identity other than the root user of the Amazon Web
Services account that owns the Outposts bucket, the calling identity must
have the s3-outposts:GetBucket permissions on the specified
Outposts bucket and belong to the Outposts bucket owner's account in order
to use this action. Only users from Outposts bucket owner account with the
right permissions can perform actions on an Outposts bucket.
If you don't have s3-outposts:GetBucket permissions or you're
not using an identity that belongs to the bucket owner's account, Amazon
S3 returns a 403 Access Denied error.
The following actions are related to GetBucket for Amazon S3
on Outposts:
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter bucket :
Specifies the bucket.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Implementation
Future<GetBucketResult> getBucket({
required String accountId,
required String bucket,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/bucket/${Uri.encodeComponent(bucket)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetBucketResult.fromXml($result.body);
}