getBucketTagging method
To use this action, you must have permission to perform the
GetBucketTagging action. By default, the bucket owner has
this permission and can grant this permission to others.
GetBucketTagging has the following special error:
-
Error code:
NoSuchTagSetError- Description: There is no tag set associated with the bucket.
x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following actions are related to GetBucketTagging:
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter bucket :
Specifies the bucket.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Implementation
Future<GetBucketTaggingResult> getBucketTagging({
required String accountId,
required String bucket,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/bucket/tagging',
headers: headers,
endpoint: _resolveEndpoint(
requiresAccountId: true,
accountId: accountId,
bucket: bucket,
),
hostPrefix: '{AccountId}.',
exceptionFnMap: _exceptionFns,
);
return GetBucketTaggingResult.fromXml($result.body);
}