getMultiRegionAccessPointPolicy method

Future<GetMultiRegionAccessPointPolicyResult> getMultiRegionAccessPointPolicy({
  1. required String accountId,
  2. required String name,
})
Returns the access control policy of the specified Multi-Region Access Point.

This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.

The following actions are related to GetMultiRegionAccessPointPolicy:

Parameter accountId : The Amazon Web Services account ID for the owner of the Multi-Region Access Point.

Parameter name : Specifies the Multi-Region Access Point. The name of the Multi-Region Access Point is different from the alias. For more information about the distinction between the name and the alias of an Multi-Region Access Point, see Rules for naming Amazon S3 Multi-Region Access Points in the Amazon S3 User Guide.

Implementation

Future<GetMultiRegionAccessPointPolicyResult>
    getMultiRegionAccessPointPolicy({
  required String accountId,
  required String name,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  final $result = await _protocol.send(
    method: 'GET',
    requestUri:
        '/v20180820/mrap/instances/${name.split('/').map(Uri.encodeComponent).join('/')}/policy',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return GetMultiRegionAccessPointPolicyResult.fromXml($result.body);
}