getMultiRegionAccessPointPolicyStatus method
Indicates whether the specified Multi-Region Access Point has an access
control policy that allows public access.
This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
The following actions are related to
GetMultiRegionAccessPointPolicyStatus:
Parameter accountId :
The Amazon Web Services account ID for the owner of the Multi-Region
Access Point.
Parameter name :
Specifies the Multi-Region Access Point. The name of the Multi-Region
Access Point is different from the alias. For more information about the
distinction between the name and the alias of an Multi-Region Access
Point, see Rules
for naming Amazon S3 Multi-Region Access Points in the Amazon S3
User Guide.
Implementation
Future<GetMultiRegionAccessPointPolicyStatusResult>
getMultiRegionAccessPointPolicyStatus({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/v20180820/mrap/instances/${name.split('/').map(Uri.encodeComponent).join('/')}/policystatus',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetMultiRegionAccessPointPolicyStatusResult.fromXml($result.body);
}