getStorageLensGroup method

Future<GetStorageLensGroupResult> getStorageLensGroup({
  1. required String accountId,
  2. required String name,
})

Retrieves the Storage Lens group configuration details.

To use this operation, you must have the permission to perform the s3:GetStorageLensGroup action. For more information about the required Storage Lens Groups permissions, see Setting account permissions to use S3 Storage Lens groups.

For information about Storage Lens groups errors, see List of Amazon S3 Storage Lens error codes.

Parameter accountId : The Amazon Web Services account ID associated with the Storage Lens group that you're trying to retrieve the details for.

Parameter name : The name of the Storage Lens group that you're trying to retrieve the configuration details for.

Implementation

Future<GetStorageLensGroupResult> getStorageLensGroup({
  required String accountId,
  required String name,
}) async {
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  final $result = await _protocol.sendRaw(
    method: 'GET',
    requestUri: '/v20180820/storagelensgroup/${Uri.encodeComponent(name)}',
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  final $elem = await _s.xmlFromResponse($result);
  return GetStorageLensGroupResult(
    storageLensGroup: StorageLensGroup.fromXml($elem),
  );
}