listMultiRegionAccessPoints method

Future<ListMultiRegionAccessPointsResult> listMultiRegionAccessPoints({
  1. required String accountId,
  2. int? maxResults,
  3. String? nextToken,
})
Returns a list of the Multi-Region Access Points currently associated with the specified Amazon Web Services account. Each call can return up to 100 Multi-Region Access Points, the maximum number of Multi-Region Access Points that can be associated with a single account.

This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.

The following actions are related to ListMultiRegionAccessPoint:

Parameter accountId : The Amazon Web Services account ID for the owner of the Multi-Region Access Point.

Parameter maxResults : Not currently used. Do not use this parameter.

Parameter nextToken : Not currently used. Do not use this parameter.

Implementation

Future<ListMultiRegionAccessPointsResult> listMultiRegionAccessPoints({
  required String accountId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    1000,
  );
  final headers = <String, String>{
    'x-amz-account-id': accountId.toString(),
  };
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final $result = await _protocol.send(
    method: 'GET',
    requestUri: '/v20180820/mrap/instances',
    queryParams: $query,
    headers: headers,
    exceptionFnMap: _exceptionFns,
  );
  return ListMultiRegionAccessPointsResult.fromXml($result.body);
}