listRegionalBuckets method
Returns a list of all Outposts buckets in an Outpost that are owned by the
authenticated sender of the request. For more information, see Using
Amazon S3 on Outposts in the Amazon S3 User Guide.
For an example of the request syntax for Amazon S3 on Outposts that uses
the S3 on Outposts endpoint hostname prefix and
x-amz-outpost-id in your request, see the Examples
section.
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter maxResults :
Parameter nextToken :
Parameter outpostId :
The ID of the Outposts resource.
Implementation
Future<ListRegionalBucketsResult> listRegionalBuckets({
required String accountId,
int? maxResults,
String? nextToken,
String? outpostId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
if (outpostId != null) 'x-amz-outpost-id': outpostId.toString(),
};
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/bucket',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListRegionalBucketsResult.fromXml($result.body);
}