listStorageLensGroups method
Lists all the Storage Lens groups in the specified home Region.
To use this operation, you must have the permission to perform the
s3:ListStorageLensGroups action. For more information about
the required Storage Lens Groups permissions, see Setting
account permissions to use S3 Storage Lens groups.
For information about Storage Lens groups errors, see List of Amazon S3 Storage Lens error codes.
Parameter accountId :
The Amazon Web Services account ID that owns the Storage Lens groups.
Parameter nextToken :
The token for the next set of results, or null if there are
no more results.
Implementation
Future<ListStorageLensGroupsResult> listStorageLensGroups({
required String accountId,
String? nextToken,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $query = <String, List<String>>{
if (nextToken != null) 'nextToken': [nextToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/storagelensgroup',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListStorageLensGroupsResult.fromXml($result.body);
}