putBucketPolicy method
If you are using an identity other than the root user of the Amazon Web
Services account that owns the Outposts bucket, the calling identity must
have the PutBucketPolicy permissions on the specified
Outposts bucket and belong to the bucket owner's account in order to use
this action.
If you don't have PutBucketPolicy permissions, Amazon S3
returns a 403 Access Denied error. If you have the correct
permissions, but you're not using an identity that belongs to the bucket
owner's account, Amazon S3 returns a 405 Method Not Allowed
error.
For more information about bucket policies, see Using
Bucket Policies and User Policies.
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following actions are related to PutBucketPolicy:
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter bucket :
Specifies the bucket.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Parameter policy :
The bucket policy as a JSON document.
Parameter confirmRemoveSelfBucketAccess :
Set this parameter to true to confirm that you want to remove your
permissions to change this bucket policy in the future.
Implementation
Future<void> putBucketPolicy({
required String accountId,
required String bucket,
required String policy,
bool? confirmRemoveSelfBucketAccess,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
if (confirmRemoveSelfBucketAccess != null)
'x-amz-confirm-remove-self-bucket-access':
confirmRemoveSelfBucketAccess.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/v20180820/bucket/policy',
headers: headers,
payload: PutBucketPolicyRequest(
accountId: accountId,
bucket: bucket,
policy: policy,
confirmRemoveSelfBucketAccess: confirmRemoveSelfBucketAccess)
.toXml('PutBucketPolicyRequest'),
endpoint: _resolveEndpoint(
requiresAccountId: true,
accountId: accountId,
bucket: bucket,
),
hostPrefix: '{AccountId}.',
exceptionFnMap: _exceptionFns,
);
}