putBucketTagging method
Use tags to organize your Amazon Web Services bill to reflect your own
cost structure. To do this, sign up to get your Amazon Web Services
account bill with tag key values included. Then, to see the cost of
combined resources, organize your billing information according to
resources with the same tag key values. For example, you can tag several
resources with a specific application name, and then organize your billing
information to see the total cost of that application across several
services. For more information, see Cost
allocation and tagging.
To use this action, you must have permissions to perform the
s3-outposts:PutBucketTagging action. The Outposts bucket
owner has this permission by default and can grant this permission to
others. For more information about permissions, see
Permissions Related to Bucket Subresource Operations and Managing
access permissions to your Amazon S3 resources.
PutBucketTagging has the following special errors:
-
Error code:
InvalidTagError- Description: The tag provided was not a valid tag. This error can occur if the tag did not pass input validation. For information about tag restrictions, see User-Defined Tag Restrictions and Amazon Web Services-Generated Cost Allocation Tag Restrictions.
-
Error code:
MalformedXMLError- Description: The XML provided does not match the schema.
-
Error code:
OperationAbortedError- Description: A conflicting conditional action is currently in progress against this resource. Try again.
-
Error code:
InternalError- Description: The service was unable to apply the provided tag to the bucket.
x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following actions are related to PutBucketTagging:
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter bucket :
The Amazon Resource Name (ARN) of the bucket.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Parameter tagging :
Implementation
Future<void> putBucketTagging({
required String accountId,
required String bucket,
required Tagging tagging,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/v20180820/bucket/${Uri.encodeComponent(bucket)}/tagging',
headers: headers,
payload: tagging.toXml('Tagging'),
exceptionFnMap: _exceptionFns,
);
}