putBucketVersioning method
You can set the versioning state to one of the following:
- Enabled - Enables versioning for the objects in the bucket. All objects added to the bucket receive a unique version ID.
-
Suspended - Suspends versioning for the objects in the bucket. All
objects added to the bucket receive the version ID
null.
When you enable S3 Versioning, for each object in your bucket, you have a current version and zero or more noncurrent versions. You can configure your bucket S3 Lifecycle rules to expire noncurrent versions after a specified time period. For more information, see Creating and managing a lifecycle configuration for your S3 on Outposts bucket in the Amazon S3 User Guide.
If you have an object expiration lifecycle configuration in your non-versioned bucket and you want to maintain the same permanent delete behavior when you enable versioning, you must add a noncurrent expiration policy. The noncurrent expiration lifecycle configuration will manage the deletes of the noncurrent object versions in the version-enabled bucket. For more information, see Versioning in the Amazon S3 User Guide.
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following operations are related to PutBucketVersioning
for S3 on Outposts.
Parameter accountId :
The Amazon Web Services account ID of the S3 on Outposts bucket.
Parameter bucket :
The S3 on Outposts bucket to set the versioning state for.
Parameter versioningConfiguration :
The root-level tag for the VersioningConfiguration
parameters.
Parameter mfa :
The concatenation of the authentication device's serial number, a space,
and the value that is displayed on your authentication device.
Implementation
Future<void> putBucketVersioning({
required String accountId,
required String bucket,
required VersioningConfiguration versioningConfiguration,
String? mfa,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
if (mfa != null) 'x-amz-mfa': mfa.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/v20180820/bucket/${Uri.encodeComponent(bucket)}/versioning',
headers: headers,
payload: versioningConfiguration.toXml('VersioningConfiguration'),
exceptionFnMap: _exceptionFns,
);
}