updateJobPriority method
Updates an existing S3 Batch Operations job's priority. For more information, see S3 Batch Operations in the Amazon S3 User Guide.
- Permissions
-
To use the
UpdateJobPriorityoperation, you must have permission to perform thes3:UpdateJobPriorityaction.
May throw BadRequestException.
May throw InternalServiceException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter accountId :
The Amazon Web Services account ID associated with the S3 Batch Operations
job.
Parameter jobId :
The ID for the job whose priority you want to update.
Parameter priority :
The priority you want to assign to this job.
Implementation
Future<UpdateJobPriorityResult> updateJobPriority({
required String accountId,
required String jobId,
required int priority,
}) async {
_s.validateNumRange(
'priority',
priority,
0,
2147483647,
isRequired: true,
);
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $query = <String, List<String>>{
'priority': [priority.toString()],
};
final $result = await _protocol.send(
method: 'POST',
requestUri: '/v20180820/jobs/${Uri.encodeComponent(jobId)}/priority',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return UpdateJobPriorityResult.fromXml($result.body);
}