updateStorageLensGroup method
Updates the existing Storage Lens group.
To use this operation, you must have the permission to perform the
s3:UpdateStorageLensGroup action. For more information about
the required Storage Lens Groups permissions, see Setting
account permissions to use S3 Storage Lens groups.
For information about Storage Lens groups errors, see List of Amazon S3 Storage Lens error codes.
Parameter accountId :
The Amazon Web Services account ID of the Storage Lens group owner.
Parameter name :
The name of the Storage Lens group that you want to update.
Parameter storageLensGroup :
The JSON file that contains the Storage Lens group configuration.
Implementation
Future<void> updateStorageLensGroup({
required String accountId,
required String name,
required StorageLensGroup storageLensGroup,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/v20180820/storagelensgroup/${Uri.encodeComponent(name)}',
headers: headers,
payload: UpdateStorageLensGroupRequest(
accountId: accountId,
name: name,
storageLensGroup: storageLensGroup)
.toXml('UpdateStorageLensGroupRequest'),
exceptionFnMap: _exceptionFns,
);
}