deleteFileSystem method
Deletes an S3 File System. You can optionally force deletion of a file system that has pending export data.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter fileSystemId :
The ID or Amazon Resource Name (ARN) of the S3 File System to delete.
Parameter forceDelete :
If true, allows deletion of a file system that contains data pending
export to S3. If false (the default), the deletion will fail if there is
data that has not yet been exported to the S3 bucket. Use this parameter
with caution as it may result in data loss.
Implementation
Future<void> deleteFileSystem({
required String fileSystemId,
bool? forceDelete,
}) async {
final $query = <String, List<String>>{
if (forceDelete != null) 'forceDelete': [forceDelete.toString()],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/file-systems/${Uri.encodeComponent(fileSystemId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}