listFileSystems method

Future<ListFileSystemsResponse> listFileSystems({
  1. String? bucket,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a list of all S3 File Systems owned by the account with optional filtering by bucket.

May throw InternalServerException. May throw ValidationException.

Parameter bucket : Optional filter to list only file systems associated with the specified S3 bucket Amazon Resource Name (ARN). If provided, only file systems that provide access to this bucket will be returned in the response.

Parameter maxResults : The maximum number of file systems to return in a single response. If not specified, up to 100 file systems are returned.

Parameter nextToken : A pagination token returned from a previous call to continue listing file systems.

Implementation

Future<ListFileSystemsResponse> listFileSystems({
  String? bucket,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (bucket != null) 'bucket': [bucket],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/file-systems',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListFileSystemsResponse.fromJson(response);
}