updateMountTarget method

Future<UpdateMountTargetResponse> updateMountTarget({
  1. required String mountTargetId,
  2. required List<String> securityGroups,
})

Updates the mount target resource, specifically security group configurations.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter mountTargetId : The ID of the mount target to update.

Parameter securityGroups : An array of VPC security group IDs to associate with the mount target's network interface. This replaces the existing security groups. All security groups must belong to the same VPC as the mount target's subnet.

Implementation

Future<UpdateMountTargetResponse> updateMountTarget({
  required String mountTargetId,
  required List<String> securityGroups,
}) async {
  final $payload = <String, dynamic>{
    'securityGroups': securityGroups,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/mount-targets/${Uri.encodeComponent(mountTargetId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateMountTargetResponse.fromJson(response);
}