deleteTableBucketPolicy method
Deletes a table bucket policy. For more information, see Deleting a table bucket policy in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:DeleteTableBucketPolicypermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket.
Implementation
Future<void> deleteTableBucketPolicy({
required String tableBucketARN,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/buckets/${Uri.encodeComponent(tableBucketARN)}/policy',
exceptionFnMap: _exceptionFns,
);
}