deleteTableBucketReplication method

Future<void> deleteTableBucketReplication({
  1. required String tableBucketARN,
  2. String? versionToken,
})

Deletes the replication configuration for a table bucket. After deletion, new table updates will no longer be replicated to destination buckets, though existing replicated tables will remain in destination buckets.

Permissions
You must have the s3tables:DeleteTableBucketReplication permission to use this operation.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableBucketARN : The Amazon Resource Name (ARN) of the table bucket.

Parameter versionToken : A version token from a previous GetTableBucketReplication call. Use this token to ensure you're deleting the expected version of the configuration.

Implementation

Future<void> deleteTableBucketReplication({
  required String tableBucketARN,
  String? versionToken,
}) async {
  final $query = <String, List<String>>{
    'tableBucketARN': [tableBucketARN],
    if (versionToken != null) 'versionToken': [versionToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/table-bucket-replication',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}