deleteTableReplication method

Future<void> deleteTableReplication({
  1. required String tableArn,
  2. required String versionToken,
})

Deletes the replication configuration for a specific table. After deletion, new updates to this table will no longer be replicated to destination tables, though existing replicated copies will remain in destination buckets.

Permissions
You must have the s3tables:DeleteTableReplication permission to use this operation.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableArn : The Amazon Resource Name (ARN) of the table.

Parameter versionToken : A version token from a previous GetTableReplication call. Use this token to ensure you're deleting the expected version of the configuration.

Implementation

Future<void> deleteTableReplication({
  required String tableArn,
  required String versionToken,
}) async {
  final $query = <String, List<String>>{
    'tableArn': [tableArn],
    'versionToken': [versionToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/table-replication',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}