getTableBucket method

Future<GetTableBucketResponse> getTableBucket({
  1. required String tableBucketARN,
})

Gets details on a table bucket. For more information, see Viewing details about an Amazon S3 table bucket in the Amazon Simple Storage Service User Guide.

Permissions
You must have the s3tables:GetTableBucket permission to use this operation.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableBucketARN : The Amazon Resource Name (ARN) of the table bucket.

Implementation

Future<GetTableBucketResponse> getTableBucket({
  required String tableBucketARN,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/buckets/${Uri.encodeComponent(tableBucketARN)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetTableBucketResponse.fromJson(response);
}