getTableBucketPolicy method

Future<GetTableBucketPolicyResponse> getTableBucketPolicy({
  1. required String tableBucketARN,
})

Gets details about a table bucket policy. For more information, see Viewing a table bucket policy in the Amazon Simple Storage Service User Guide.

Permissions
You must have the s3tables:GetTableBucketPolicy permission to use this operation.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableBucketARN : The Amazon Resource Name (ARN) of the table bucket.

Implementation

Future<GetTableBucketPolicyResponse> getTableBucketPolicy({
  required String tableBucketARN,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/buckets/${Uri.encodeComponent(tableBucketARN)}/policy',
    exceptionFnMap: _exceptionFns,
  );
  return GetTableBucketPolicyResponse.fromJson(response);
}