getTableMaintenanceConfiguration method

Future<GetTableMaintenanceConfigurationResponse> getTableMaintenanceConfiguration({
  1. required String name,
  2. required String namespace,
  3. required String tableBucketARN,
})

Gets details about the maintenance configuration of a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

Permissions
  • You must have the s3tables:GetTableMaintenanceConfiguration permission to use this operation.
  • You must have the s3tables:GetTableData permission to use set the compaction strategy to sort or zorder.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter name : The name of the table.

Parameter namespace : The namespace associated with the table.

Parameter tableBucketARN : The Amazon Resource Name (ARN) of the table bucket.

Implementation

Future<GetTableMaintenanceConfigurationResponse>
    getTableMaintenanceConfiguration({
  required String name,
  required String namespace,
  required String tableBucketARN,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/tables/${Uri.encodeComponent(tableBucketARN)}/${Uri.encodeComponent(namespace)}/${Uri.encodeComponent(name)}/maintenance',
    exceptionFnMap: _exceptionFns,
  );
  return GetTableMaintenanceConfigurationResponse.fromJson(response);
}