getTableRecordExpirationConfiguration method

Future<GetTableRecordExpirationConfigurationResponse> getTableRecordExpirationConfiguration({
  1. required String tableArn,
})

Retrieves the expiration configuration settings for records in a table, and the status of the configuration. If the status of the configuration is enabled, records expire and are automatically removed from the table after the specified number of days.

Permissions
You must have the s3tables:GetTableRecordExpirationConfiguration permission to use this operation.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableArn : The Amazon Resource Name (ARN) of the table.

Implementation

Future<GetTableRecordExpirationConfigurationResponse>
    getTableRecordExpirationConfiguration({
  required String tableArn,
}) async {
  final $query = <String, List<String>>{
    'tableArn': [tableArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/table-record-expiration',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetTableRecordExpirationConfigurationResponse.fromJson(response);
}