getTableRecordExpirationJobStatus method

Future<GetTableRecordExpirationJobStatusResponse> getTableRecordExpirationJobStatus({
  1. required String tableArn,
})

Retrieves the status, metrics, and details of the latest record expiration job for a table. This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.

Permissions
You must have the s3tables:GetTableRecordExpirationJobStatus permission to use this operation.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableArn : The Amazon Resource Name (ARN) of the table.

Implementation

Future<GetTableRecordExpirationJobStatusResponse>
    getTableRecordExpirationJobStatus({
  required String tableArn,
}) async {
  final $query = <String, List<String>>{
    'tableArn': [tableArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/table-record-expiration-job-status',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetTableRecordExpirationJobStatusResponse.fromJson(response);
}