getTableReplicationStatus method
Retrieves the replication status for a table, including the status of replication to each destination. This operation provides visibility into replication health and progress.
- Permissions
-
You must have the
s3tables:GetTableReplicationStatuspermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tableArn :
The Amazon Resource Name (ARN) of the table.
Implementation
Future<GetTableReplicationStatusResponse> getTableReplicationStatus({
required String tableArn,
}) async {
final $query = <String, List<String>>{
'tableArn': [tableArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/replication-status',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetTableReplicationStatusResponse.fromJson(response);
}