listTables method

Future<ListTablesResponse> listTables({
  1. required String tableBucketARN,
  2. String? continuationToken,
  3. int? maxTables,
  4. String? namespace,
  5. String? prefix,
})

List tables in the given table bucket. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.

Permissions
You must have the s3tables:ListTables permission to use this operation.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableBucketARN : The Amazon resource Name (ARN) of the table bucket.

Parameter continuationToken : ContinuationToken indicates to Amazon S3 that the list is being continued on this bucket with a token. ContinuationToken is obfuscated and is not a real key. You can use this ContinuationToken for pagination of the list results.

Parameter maxTables : The maximum number of tables to return.

Parameter namespace : The namespace of the tables.

Parameter prefix : The prefix of the tables.

Implementation

Future<ListTablesResponse> listTables({
  required String tableBucketARN,
  String? continuationToken,
  int? maxTables,
  String? namespace,
  String? prefix,
}) async {
  _s.validateNumRange(
    'maxTables',
    maxTables,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (continuationToken != null) 'continuationToken': [continuationToken],
    if (maxTables != null) 'maxTables': [maxTables.toString()],
    if (namespace != null) 'namespace': [namespace],
    if (prefix != null) 'prefix': [prefix],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/tables/${Uri.encodeComponent(tableBucketARN)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListTablesResponse.fromJson(response);
}