putTableBucketMaintenanceConfiguration method

Future<void> putTableBucketMaintenanceConfiguration({
  1. required String tableBucketARN,
  2. required TableBucketMaintenanceType type,
  3. required TableBucketMaintenanceConfigurationValue value,
})

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.

Permissions
You must have the s3tables:PutTableBucketMaintenanceConfiguration permission to use this operation.

May throw BadRequestException. May throw ConflictException. May throw ForbiddenException. May throw InternalServerErrorException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableBucketARN : The Amazon Resource Name (ARN) of the table bucket associated with the maintenance configuration.

Parameter type : The type of the maintenance configuration.

Parameter value : Defines the values of the maintenance configuration for the table bucket.

Implementation

Future<void> putTableBucketMaintenanceConfiguration({
  required String tableBucketARN,
  required TableBucketMaintenanceType type,
  required TableBucketMaintenanceConfigurationValue value,
}) async {
  final $payload = <String, dynamic>{
    'value': value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/buckets/${Uri.encodeComponent(tableBucketARN)}/maintenance/${Uri.encodeComponent(type.value)}',
    exceptionFnMap: _exceptionFns,
  );
}