putTableRecordExpirationConfiguration method

Future<void> putTableRecordExpirationConfiguration({
  1. required String tableArn,
  2. required TableRecordExpirationConfigurationValue value,
})

Creates or updates the expiration configuration settings for records in a table, including the status of the configuration. If you enable record expiration for a table, records expire and are automatically removed from the table after the number of days that you specify.

Permissions
You must have the s3tables:PutTableRecordExpirationConfiguration permission to use this operation.

May throw BadRequestException. May throw ForbiddenException. May throw InternalServerErrorException. May throw MethodNotAllowedException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter tableArn : The Amazon Resource Name (ARN) of the table.

Parameter value : The record expiration configuration to apply to the table, including the status (enabled or disabled) and retention period in days.

Implementation

Future<void> putTableRecordExpirationConfiguration({
  required String tableArn,
  required TableRecordExpirationConfigurationValue value,
}) async {
  final $query = <String, List<String>>{
    'tableArn': [tableArn],
  };
  final $payload = <String, dynamic>{
    'value': value,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/table-record-expiration',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}