S3Vectors class

Amazon S3 vector buckets are a bucket type to store and search vectors with sub-second search times. They are designed to provide dedicated API operations for you to interact with vectors to do similarity search. Within a vector bucket, you use a vector index to organize and logically group your vector data. When you make a write or read request, you direct it to a single vector index. You store your vector data as vectors. A vector contains a key (a name that you assign), a multi-dimensional vector, and, optionally, metadata that describes a vector. The key uniquely identifies the vector in a vector index.

Constructors

S3Vectors({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createIndex({required DataType dataType, required int dimension, required DistanceMetric distanceMetric, required String indexName, EncryptionConfiguration? encryptionConfiguration, MetadataConfiguration? metadataConfiguration, Map<String, String>? tags, String? vectorBucketArn, String? vectorBucketName}) Future<CreateIndexOutput>
Creates a vector index within a vector bucket. To specify the vector bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
createVectorBucket({required String vectorBucketName, EncryptionConfiguration? encryptionConfiguration, Map<String, String>? tags}) Future<CreateVectorBucketOutput>
Creates a vector bucket in the Amazon Web Services Region that you want your bucket to be in.
deleteIndex({String? indexArn, String? indexName, String? vectorBucketName}) Future<void>
Deletes a vector index. To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).
deleteVectorBucket({String? vectorBucketArn, String? vectorBucketName}) Future<void>
Deletes a vector bucket. All vector indexes in the vector bucket must be deleted before the vector bucket can be deleted. To perform this operation, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
deleteVectorBucketPolicy({String? vectorBucketArn, String? vectorBucketName}) Future<void>
Deletes a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
deleteVectors({required List<String> keys, String? indexArn, String? indexName, String? vectorBucketName}) Future<void>
Deletes one or more vectors in a vector index. To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).
getIndex({String? indexArn, String? indexName, String? vectorBucketName}) Future<GetIndexOutput>
Returns vector index attributes. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
getVectorBucket({String? vectorBucketArn, String? vectorBucketName}) Future<GetVectorBucketOutput>
Returns vector bucket attributes. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
getVectorBucketPolicy({String? vectorBucketArn, String? vectorBucketName}) Future<GetVectorBucketPolicyOutput>
Gets details about a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
getVectors({required List<String> keys, String? indexArn, String? indexName, bool? returnData, bool? returnMetadata, String? vectorBucketName}) Future<GetVectorsOutput>
Returns vector attributes. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
listIndexes({int? maxResults, String? nextToken, String? prefix, String? vectorBucketArn, String? vectorBucketName}) Future<ListIndexesOutput>
Returns a list of all the vector indexes within the specified vector bucket. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists all of the tags applied to a specified Amazon S3 Vectors resource. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.
listVectorBuckets({int? maxResults, String? nextToken, String? prefix}) Future<ListVectorBucketsOutput>
Returns a list of all the vector buckets that are owned by the authenticated sender of the request.
listVectors({String? indexArn, String? indexName, int? maxResults, String? nextToken, bool? returnData, bool? returnMetadata, int? segmentCount, int? segmentIndex, String? vectorBucketName}) Future<ListVectorsOutput>
List vectors in the specified vector index. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putVectorBucketPolicy({required String policy, String? vectorBucketArn, String? vectorBucketName}) Future<void>
Creates a bucket policy for a vector bucket. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
putVectors({required List<PutInputVector> vectors, String? indexArn, String? indexName, String? vectorBucketName}) Future<void>
Adds one or more vectors to a vector index. To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
queryVectors({required VectorData queryVector, required int topK, Document? filter, String? indexArn, String? indexName, bool? returnDistance, bool? returnMetadata, String? vectorBucketName}) Future<QueryVectorsOutput>
Performs an approximate nearest neighbor search query in a vector index using a query vector. By default, it returns the keys of approximate nearest neighbors. You can optionally include the computed distance (between the query vector and each vector in the response), the vector data, and metadata of each vector in the response.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Applies one or more user-defined tags to an Amazon S3 Vectors resource or updates existing tags. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified user-defined tags from an Amazon S3 Vectors resource. You can pass one or more tag keys.

Operators

operator ==(Object other) bool
The equality operator.
inherited