deleteIndex method

Future<void> deleteIndex({
  1. String? indexArn,
  2. String? indexName,
  3. String? vectorBucketName,
})

Deletes a vector index. To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).

Permissions
You must have the s3vectors:DeleteIndex permission to use this operation.

May throw NotFoundException. May throw ServiceUnavailableException.

Parameter indexArn : The ARN of the vector index to delete.

Parameter indexName : The name of the vector index to delete.

Parameter vectorBucketName : The name of the vector bucket that contains the vector index.

Implementation

Future<void> deleteIndex({
  String? indexArn,
  String? indexName,
  String? vectorBucketName,
}) async {
  final $payload = <String, dynamic>{
    if (indexArn != null) 'indexArn': indexArn,
    if (indexName != null) 'indexName': indexName,
    if (vectorBucketName != null) 'vectorBucketName': vectorBucketName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteIndex',
    exceptionFnMap: _exceptionFns,
  );
}