deleteVectorBucket method
Deletes a vector bucket. All vector indexes in the vector bucket must be deleted before the vector bucket can be deleted. To perform this operation, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
- Permissions
-
You must have the
s3vectors:DeleteVectorBucketpermission to use this operation.
May throw ConflictException.
May throw NotFoundException.
May throw ServiceUnavailableException.
Parameter vectorBucketArn :
The ARN of the vector bucket to delete.
Parameter vectorBucketName :
The name of the vector bucket to delete.
Implementation
Future<void> deleteVectorBucket({
String? vectorBucketArn,
String? vectorBucketName,
}) async {
final $payload = <String, dynamic>{
if (vectorBucketArn != null) 'vectorBucketArn': vectorBucketArn,
if (vectorBucketName != null) 'vectorBucketName': vectorBucketName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteVectorBucket',
exceptionFnMap: _exceptionFns,
);
}