deleteVectorBucketPolicy method

Future<void> deleteVectorBucketPolicy({
  1. String? vectorBucketArn,
  2. String? vectorBucketName,
})

Deletes a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).

Permissions
You must have the s3vectors:DeleteVectorBucketPolicy permission to use this operation.

May throw NotFoundException. May throw ServiceUnavailableException.

Parameter vectorBucketArn : The ARN of the vector bucket to delete the policy from.

Parameter vectorBucketName : The name of the vector bucket to delete the policy from.

Implementation

Future<void> deleteVectorBucketPolicy({
  String? vectorBucketArn,
  String? vectorBucketName,
}) async {
  final $payload = <String, dynamic>{
    if (vectorBucketArn != null) 'vectorBucketArn': vectorBucketArn,
    if (vectorBucketName != null) 'vectorBucketName': vectorBucketName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/DeleteVectorBucketPolicy',
    exceptionFnMap: _exceptionFns,
  );
}