createEdgeDeploymentStage method
Creates a new stage in an existing edge deployment plan.
May throw ResourceLimitExceeded.
Parameter edgeDeploymentPlanName :
The name of the edge deployment plan.
Parameter stages :
List of stages to be added to the edge deployment plan.
Implementation
Future<void> createEdgeDeploymentStage({
required String edgeDeploymentPlanName,
required List<DeploymentStage> stages,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateEdgeDeploymentStage'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EdgeDeploymentPlanName': edgeDeploymentPlanName,
'Stages': stages,
},
);
}