createFeatureGroup method
- required String eventTimeFeatureName,
- required List<
FeatureDefinition> featureDefinitions, - required String featureGroupName,
- required String recordIdentifierFeatureName,
- String? description,
- OfflineStoreConfig? offlineStoreConfig,
- OnlineStoreConfig? onlineStoreConfig,
- String? roleArn,
- List<
Tag> ? tags, - ThroughputConfig? throughputConfig,
Create a new FeatureGroup. A FeatureGroup is a
group of Features defined in the FeatureStore to
describe a Record.
The FeatureGroup defines the schema and features contained in
the FeatureGroup. A FeatureGroup definition is
composed of a list of Features, a
RecordIdentifierFeatureName, an
EventTimeFeatureName and configurations for its
OnlineStore and OfflineStore. Check Amazon
Web Services service quotas to see the FeatureGroups
quota for your Amazon Web Services account.
Note that it can take approximately 10-15 minutes to provision an
OnlineStore FeatureGroup with the
InMemory StorageType.
May throw ResourceInUse.
May throw ResourceLimitExceeded.
Parameter eventTimeFeatureName :
The name of the feature that stores the EventTime of a
Record in a FeatureGroup.
An EventTime is a point in time when a new event occurs that
corresponds to the creation or update of a Record in a
FeatureGroup. All Records in the
FeatureGroup must have a corresponding
EventTime.
An EventTime can be a String or
Fractional.
-
Fractional:EventTimefeature values must be a Unix timestamp in seconds. -
String:EventTimefeature values must be an ISO-8601 string in the format. The following formats are supportedyyyy-MM-dd'T'HH:mm:ssZandyyyy-MM-dd'T'HH:mm:ss.SSSZwhereyyyy,MM, andddrepresent the year, month, and day respectively andHH,mm,ss, and if applicable,SSSrepresent the hour, month, second and milliseconds respsectively.'T'andZare constants.
Parameter featureDefinitions :
A list of Feature names and types. Name and
Type is compulsory per Feature.
Valid feature FeatureTypes are Integral,
Fractional and String.
FeatureNames cannot be any of the following:
is_deleted, write_time,
api_invocation_time
You can create up to 2,500 FeatureDefinitions per
FeatureGroup.
Parameter featureGroupName :
The name of the FeatureGroup. The name must be unique within
an Amazon Web Services Region in an Amazon Web Services account.
The name:
- Must start with an alphanumeric character.
- Can only include alphanumeric characters, underscores, and hyphens. Spaces are not allowed.
Parameter recordIdentifierFeatureName :
The name of the Feature whose value uniquely identifies a
Record defined in the FeatureStore. Only the
latest record per identifier value will be stored in the
OnlineStore. RecordIdentifierFeatureName must be
one of feature definitions' names.
You use the RecordIdentifierFeatureName to access data in a
FeatureStore.
This name:
- Must start with an alphanumeric character.
- Can only contains alphanumeric characters, hyphens, underscores. Spaces are not allowed.
Parameter description :
A free-form description of a FeatureGroup.
Parameter offlineStoreConfig :
Use this to configure an OfflineFeatureStore. This parameter
allows you to specify:
-
The Amazon Simple Storage Service (Amazon S3) location of an
OfflineStore. - A configuration for an Amazon Web Services Glue or Amazon Web Services Hive data catalog.
-
An KMS encryption key to encrypt the Amazon S3 location used for
OfflineStore. If KMS encryption key is not specified, by default we encrypt all data at rest using Amazon Web Services KMS key. By defining your bucket-level key for SSE, you can reduce Amazon Web Services KMS requests costs by up to 99 percent. - Format for the offline store table. Supported formats are Glue (Default) and Apache Iceberg.
Parameter onlineStoreConfig :
You can turn the OnlineStore on or off by specifying
True for the EnableOnlineStore flag in
OnlineStoreConfig.
You can also include an Amazon Web Services KMS key ID
(KMSKeyId) for at-rest encryption of the
OnlineStore.
The default value is False.
Parameter roleArn :
The Amazon Resource Name (ARN) of the IAM execution role used to persist
data into the OfflineStore if an
OfflineStoreConfig is provided.
Parameter tags :
Tags used to identify Features in each
FeatureGroup.
Implementation
Future<CreateFeatureGroupResponse> createFeatureGroup({
required String eventTimeFeatureName,
required List<FeatureDefinition> featureDefinitions,
required String featureGroupName,
required String recordIdentifierFeatureName,
String? description,
OfflineStoreConfig? offlineStoreConfig,
OnlineStoreConfig? onlineStoreConfig,
String? roleArn,
List<Tag>? tags,
ThroughputConfig? throughputConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateFeatureGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EventTimeFeatureName': eventTimeFeatureName,
'FeatureDefinitions': featureDefinitions,
'FeatureGroupName': featureGroupName,
'RecordIdentifierFeatureName': recordIdentifierFeatureName,
if (description != null) 'Description': description,
if (offlineStoreConfig != null)
'OfflineStoreConfig': offlineStoreConfig,
if (onlineStoreConfig != null) 'OnlineStoreConfig': onlineStoreConfig,
if (roleArn != null) 'RoleArn': roleArn,
if (tags != null) 'Tags': tags,
if (throughputConfig != null) 'ThroughputConfig': throughputConfig,
},
);
return CreateFeatureGroupResponse.fromJson(jsonResponse.body);
}