createInferenceExperiment method
- required String endpointName,
- required List<
ModelVariantConfig> modelVariants, - required String name,
- required String roleArn,
- required ShadowModeConfig shadowModeConfig,
- required InferenceExperimentType type,
- InferenceExperimentDataStorageConfig? dataStorageConfig,
- String? description,
- String? kmsKey,
- InferenceExperimentSchedule? schedule,
- List<
Tag> ? tags,
Creates an inference experiment using the configurations specified in the request.
Use this API to setup and schedule an experiment to compare model variants on a Amazon SageMaker inference endpoint. For more information about inference experiments, see Shadow tests.
Amazon SageMaker begins your experiment at the scheduled time and routes traffic to your endpoint's model variants based on your specified configuration.
While the experiment is in progress or after it has concluded, you can view metrics that compare your model variants. For more information, see View, monitor, and edit shadow tests.
May throw ResourceInUse.
May throw ResourceLimitExceeded.
Parameter endpointName :
The name of the Amazon SageMaker endpoint on which you want to run the
inference experiment.
Parameter modelVariants :
An array of ModelVariantConfig objects. There is one for each
variant in the inference experiment. Each ModelVariantConfig
object in the array describes the infrastructure configuration for the
corresponding variant.
Parameter name :
The name for the inference experiment.
Parameter roleArn :
The ARN of the IAM role that Amazon SageMaker can assume to access model
artifacts and container images, and manage Amazon SageMaker Inference
endpoints for model deployment.
Parameter shadowModeConfig :
The configuration of ShadowMode inference experiment type.
Use this field to specify a production variant which takes all the
inference requests, and a shadow variant to which Amazon SageMaker
replicates a percentage of the inference requests. For the shadow variant
also specify the percentage of requests that Amazon SageMaker replicates.
Parameter type :
The type of the inference experiment that you want to run. The following
types of experiments are possible:
-
ShadowMode: You can use this type to validate a shadow variant. For more information, see Shadow tests.
Parameter dataStorageConfig :
The Amazon S3 location and configuration for storing inference request and
response data.
This is an optional parameter that you can use for data capture. For more information, see Capture data.
Parameter description :
A description for the inference experiment.
Parameter kmsKey :
The Amazon Web Services Key Management Service (Amazon Web Services KMS)
key that Amazon SageMaker uses to encrypt data on the storage volume
attached to the ML compute instance that hosts the endpoint. The
KmsKey can be any of the following formats:
-
KMS key ID
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS key
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab" -
KMS key Alias
"alias/ExampleAlias" -
Amazon Resource Name (ARN) of a KMS key Alias
"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"
kms:Encrypt.
If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS
key for Amazon S3 for your role's account. Amazon SageMaker uses
server-side encryption with KMS managed keys for
OutputDataConfig. If you use a bucket policy with an
s3:PutObject permission that only allows objects with
server-side encryption, set the condition key of
s3:x-amz-server-side-encryption to "aws:kms".
For more information, see KMS
managed Encryption Keys in the Amazon Simple Storage Service
Developer Guide.
The KMS key policy must grant permission to the IAM role that you specify
in your CreateEndpoint and UpdateEndpoint
requests. For more information, see Using
Key Policies in Amazon Web Services KMS in the Amazon Web Services
Key Management Service Developer Guide.
Parameter schedule :
The duration for which you want the inference experiment to run. If you
don't specify this field, the experiment automatically starts immediately
upon creation and concludes after 7 days.
Parameter tags :
Array of key-value pairs. You can use tags to categorize your Amazon Web
Services resources in different ways, for example, by purpose, owner, or
environment. For more information, see Tagging
your Amazon Web Services Resources.
Implementation
Future<CreateInferenceExperimentResponse> createInferenceExperiment({
required String endpointName,
required List<ModelVariantConfig> modelVariants,
required String name,
required String roleArn,
required ShadowModeConfig shadowModeConfig,
required InferenceExperimentType type,
InferenceExperimentDataStorageConfig? dataStorageConfig,
String? description,
String? kmsKey,
InferenceExperimentSchedule? schedule,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateInferenceExperiment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EndpointName': endpointName,
'ModelVariants': modelVariants,
'Name': name,
'RoleArn': roleArn,
'ShadowModeConfig': shadowModeConfig,
'Type': type.value,
if (dataStorageConfig != null) 'DataStorageConfig': dataStorageConfig,
if (description != null) 'Description': description,
if (kmsKey != null) 'KmsKey': kmsKey,
if (schedule != null) 'Schedule': schedule,
if (tags != null) 'Tags': tags,
},
);
return CreateInferenceExperimentResponse.fromJson(jsonResponse.body);
}