createModel method
Creates a model in SageMaker. In the request, you name the model and describe a primary container. For the primary container, you specify the Docker image that contains inference code, artifacts (from prior training), and a custom environment map that the inference code uses when you deploy the model for predictions.
Use this API to create a model if you want to use SageMaker hosting services or run a batch transform job.
To host your model, you create an endpoint configuration with the
CreateEndpointConfig API, and then create an endpoint with
the CreateEndpoint API. SageMaker then deploys all of the
containers that you defined for the model in the hosting environment.
To run a batch transform using your model, you start a job with the
CreateTransformJob API. SageMaker uses your model and your
dataset to get inferences which are then saved to a specified S3 location.
In the request, you also provide an IAM role that SageMaker can assume to access model artifacts and docker image for deployment on ML compute hosting instances or for batch transform jobs. In addition, you also use the IAM role to manage permissions the inference code needs. For example, if the inference code access any other Amazon Web Services resources, you grant necessary permissions via this role.
May throw ResourceLimitExceeded.
Parameter modelName :
The name of the new model.
Parameter containers :
Specifies the containers in the inference pipeline.
Parameter enableNetworkIsolation :
Isolates the model container. No inbound or outbound network calls can be
made to or from the model container.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the IAM role that SageMaker can assume
to access model artifacts and docker image for deployment on ML compute
instances or for batch transform jobs. Deploying on ML compute instances
is part of model hosting. For more information, see SageMaker
Roles.
Parameter inferenceExecutionConfig :
Specifies details of how containers in a multi-container endpoint are
called.
Parameter primaryContainer :
The location of the primary docker image containing inference code,
associated artifacts, and custom environment map that the inference code
uses when the model is deployed for predictions.
Parameter tags :
An array of key-value pairs. You can use tags to categorize your Amazon
Web Services resources in different ways, for example, by purpose, owner,
or environment. For more information, see Tagging
Amazon Web Services Resources.
Parameter vpcConfig :
A VpcConfig
object that specifies the VPC that you want your model to connect to.
Control access to and from your model container by configuring the VPC.
VpcConfig is used in hosting services and in batch transform.
For more information, see Protect
Endpoints by Using an Amazon Virtual Private Cloud and Protect
Data in Batch Transform Jobs by Using an Amazon Virtual Private Cloud.
Implementation
Future<CreateModelOutput> createModel({
required String modelName,
List<ContainerDefinition>? containers,
bool? enableNetworkIsolation,
String? executionRoleArn,
InferenceExecutionConfig? inferenceExecutionConfig,
ContainerDefinition? primaryContainer,
List<Tag>? tags,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateModel'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ModelName': modelName,
if (containers != null) 'Containers': containers,
if (enableNetworkIsolation != null)
'EnableNetworkIsolation': enableNetworkIsolation,
if (executionRoleArn != null) 'ExecutionRoleArn': executionRoleArn,
if (inferenceExecutionConfig != null)
'InferenceExecutionConfig': inferenceExecutionConfig,
if (primaryContainer != null) 'PrimaryContainer': primaryContainer,
if (tags != null) 'Tags': tags,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return CreateModelOutput.fromJson(jsonResponse.body);
}