createModelPackageGroup method

Future<CreateModelPackageGroupOutput> createModelPackageGroup({
  1. required String modelPackageGroupName,
  2. ManagedConfiguration? managedConfiguration,
  3. String? modelPackageGroupDescription,
  4. List<Tag>? tags,
})

Creates a model group. A model group contains a group of model versions.

May throw ResourceLimitExceeded.

Parameter modelPackageGroupName : The name of the model group.

Parameter managedConfiguration : The managed configuration of the model package group.

Parameter modelPackageGroupDescription : A description for the model group.

Parameter tags : A list of key value pairs associated with the model group. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.

Implementation

Future<CreateModelPackageGroupOutput> createModelPackageGroup({
  required String modelPackageGroupName,
  ManagedConfiguration? managedConfiguration,
  String? modelPackageGroupDescription,
  List<Tag>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.CreateModelPackageGroup'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ModelPackageGroupName': modelPackageGroupName,
      if (managedConfiguration != null)
        'ManagedConfiguration': managedConfiguration,
      if (modelPackageGroupDescription != null)
        'ModelPackageGroupDescription': modelPackageGroupDescription,
      if (tags != null) 'Tags': tags,
    },
  );

  return CreateModelPackageGroupOutput.fromJson(jsonResponse.body);
}