createMonitoringSchedule method
Creates a schedule that regularly starts Amazon SageMaker AI Processing Jobs to monitor the data captured for an Amazon SageMaker AI Endpoint.
May throw ResourceInUse.
May throw ResourceLimitExceeded.
Parameter monitoringScheduleConfig :
The configuration object that specifies the monitoring schedule and
defines the monitoring job.
Parameter monitoringScheduleName :
The name of the monitoring schedule. The name must be unique within an
Amazon Web Services Region within an Amazon Web Services account.
Parameter tags :
(Optional) An array of key-value pairs. For more information, see Using
Cost Allocation Tags in the Amazon Web Services Billing and Cost
Management User Guide.
Implementation
Future<CreateMonitoringScheduleResponse> createMonitoringSchedule({
required MonitoringScheduleConfig monitoringScheduleConfig,
required String monitoringScheduleName,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateMonitoringSchedule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MonitoringScheduleConfig': monitoringScheduleConfig,
'MonitoringScheduleName': monitoringScheduleName,
if (tags != null) 'Tags': tags,
},
);
return CreateMonitoringScheduleResponse.fromJson(jsonResponse.body);
}