createNotebookInstance method
- required InstanceType instanceType,
- required String notebookInstanceName,
- required String roleArn,
- List<
NotebookInstanceAcceleratorType> ? acceleratorTypes, - List<
String> ? additionalCodeRepositories, - String? defaultCodeRepository,
- DirectInternetAccess? directInternetAccess,
- InstanceMetadataServiceConfiguration? instanceMetadataServiceConfiguration,
- IPAddressType? ipAddressType,
- String? kmsKeyId,
- String? lifecycleConfigName,
- String? platformIdentifier,
- RootAccess? rootAccess,
- List<
String> ? securityGroupIds, - String? subnetId,
- List<
Tag> ? tags, - int? volumeSizeInGB,
Creates an SageMaker AI notebook instance. A notebook instance is a machine learning (ML) compute instance running on a Jupyter notebook.
In a CreateNotebookInstance request, specify the type of ML
compute instance that you want to run. SageMaker AI launches the instance,
installs common libraries that you can use to explore datasets for model
training, and attaches an ML storage volume to the notebook instance.
SageMaker AI also provides a set of example notebooks. Each notebook demonstrates how to use SageMaker AI with a specific algorithm or with a machine learning framework.
After receiving the request, SageMaker AI does the following:
- Creates a network interface in the SageMaker AI VPC.
-
(Option) If you specified
SubnetId, SageMaker AI creates a network interface in your own VPC, which is inferred from the subnet ID that you provide in the input. When creating this network interface, SageMaker AI attaches the security group that you specified in the request to the network interface that it creates in your VPC. -
Launches an EC2 instance of the type specified in the request in the
SageMaker AI VPC. If you specified
SubnetIdof your VPC, SageMaker AI specifies both network interfaces when launching this instance. This enables inbound traffic from your own VPC to the notebook instance, assuming that the security groups allow it.
After SageMaker AI creates the notebook instance, you can connect to the Jupyter server and work in Jupyter notebooks. For example, you can write code to explore a dataset that you can use for model training, train a model, host models by creating SageMaker AI endpoints, and validate hosted models.
For more information, see How It Works.
May throw ResourceLimitExceeded.
Parameter instanceType :
The type of ML compute instance to launch for the notebook instance.
Parameter notebookInstanceName :
The name of the new notebook instance.
Parameter roleArn :
When you send any requests to Amazon Web Services resources from the
notebook instance, SageMaker AI assumes this role to perform tasks on your
behalf. You must grant this role necessary permissions so SageMaker AI can
perform these tasks. The policy must allow the SageMaker AI service
principal (sagemaker.amazonaws.com) permissions to assume this role. For
more information, see SageMaker
AI Roles.
Parameter acceleratorTypes :
This parameter is no longer supported. Elastic Inference (EI) is no longer
available.
This parameter was used to specify a list of EI instance types to associate with this notebook instance.
Parameter additionalCodeRepositories :
An array of up to three Git repositories to associate with the notebook
instance. These can be either the names of Git repositories stored as
resources in your account, or the URL of Git repositories in Amazon
Web Services CodeCommit or in any other Git repository. These
repositories are cloned at the same level as the default repository of
your notebook instance. For more information, see Associating
Git Repositories with SageMaker AI Notebook Instances.
Parameter defaultCodeRepository :
A Git repository to associate with the notebook instance as its default
code repository. This can be either the name of a Git repository stored as
a resource in your account, or the URL of a Git repository in Amazon
Web Services CodeCommit or in any other Git repository. When you open
a notebook instance, it opens in the directory that contains this
repository. For more information, see Associating
Git Repositories with SageMaker AI Notebook Instances.
Parameter directInternetAccess :
Sets whether SageMaker AI provides internet access to the notebook
instance. If you set this to Disabled this notebook instance
is able to access resources only in your VPC, and is not be able to
connect to SageMaker AI training and endpoint services unless you
configure a NAT Gateway in your VPC.
For more information, see Notebook
Instances Are Internet-Enabled by Default. You can set the value of
this parameter to Disabled only if you set a value for the
SubnetId parameter.
Parameter instanceMetadataServiceConfiguration :
Information on the IMDS configuration of the notebook instance
Parameter ipAddressType :
The IP address type for the notebook instance. Specify ipv4
for IPv4-only connectivity or dualstack for both IPv4 and
IPv6 connectivity. When you specify dualstack, the subnet
must support IPv6 CIDR blocks. If not specified, defaults to
ipv4.
Parameter kmsKeyId :
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management
Service key that SageMaker AI uses to encrypt data on the storage volume
attached to your notebook instance. The KMS key you provide must be
enabled. For information, see Enabling
and Disabling Keys in the Amazon Web Services Key Management
Service Developer Guide.
Parameter lifecycleConfigName :
The name of a lifecycle configuration to associate with the notebook
instance. For information about lifestyle configurations, see Step
2.1: (Optional) Customize a Notebook Instance.
Parameter platformIdentifier :
The platform identifier of the notebook instance runtime environment. The
default value is notebook-al2023-v1.
Parameter rootAccess :
Whether root access is enabled or disabled for users of the notebook
instance. The default value is Enabled.
Parameter securityGroupIds :
The VPC security group IDs, in the form sg-xxxxxxxx. The security groups
must be for the same VPC as specified in the subnet.
Parameter subnetId :
The ID of the subnet in a VPC to which you would like to have a
connectivity from your ML compute instance.
Parameter tags :
An array of key-value pairs. You can use tags to categorize your Amazon
Web Services resources in different ways, for example, by purpose, owner,
or environment. For more information, see Tagging
Amazon Web Services Resources.
Parameter volumeSizeInGB :
The size, in GB, of the ML storage volume to attach to the notebook
instance. The default value is 5 GB.
Implementation
Future<CreateNotebookInstanceOutput> createNotebookInstance({
required InstanceType instanceType,
required String notebookInstanceName,
required String roleArn,
List<NotebookInstanceAcceleratorType>? acceleratorTypes,
List<String>? additionalCodeRepositories,
String? defaultCodeRepository,
DirectInternetAccess? directInternetAccess,
InstanceMetadataServiceConfiguration? instanceMetadataServiceConfiguration,
IPAddressType? ipAddressType,
String? kmsKeyId,
String? lifecycleConfigName,
String? platformIdentifier,
RootAccess? rootAccess,
List<String>? securityGroupIds,
String? subnetId,
List<Tag>? tags,
int? volumeSizeInGB,
}) async {
_s.validateNumRange(
'volumeSizeInGB',
volumeSizeInGB,
5,
16384,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateNotebookInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceType': instanceType.value,
'NotebookInstanceName': notebookInstanceName,
'RoleArn': roleArn,
if (acceleratorTypes != null)
'AcceleratorTypes': acceleratorTypes.map((e) => e.value).toList(),
if (additionalCodeRepositories != null)
'AdditionalCodeRepositories': additionalCodeRepositories,
if (defaultCodeRepository != null)
'DefaultCodeRepository': defaultCodeRepository,
if (directInternetAccess != null)
'DirectInternetAccess': directInternetAccess.value,
if (instanceMetadataServiceConfiguration != null)
'InstanceMetadataServiceConfiguration':
instanceMetadataServiceConfiguration,
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (lifecycleConfigName != null)
'LifecycleConfigName': lifecycleConfigName,
if (platformIdentifier != null)
'PlatformIdentifier': platformIdentifier,
if (rootAccess != null) 'RootAccess': rootAccess.value,
if (securityGroupIds != null) 'SecurityGroupIds': securityGroupIds,
if (subnetId != null) 'SubnetId': subnetId,
if (tags != null) 'Tags': tags,
if (volumeSizeInGB != null) 'VolumeSizeInGB': volumeSizeInGB,
},
);
return CreateNotebookInstanceOutput.fromJson(jsonResponse.body);
}