createPresignedDomainUrl method
Creates a URL for a specified UserProfile in a Domain. When accessed in a web browser, the user will be automatically signed in to the domain, and granted access to all of the Apps and files associated with the Domain's Amazon Elastic File System volume. This operation can only be called when the authentication mode equals IAM.
The IAM role or user passed to this API defines the permissions to access the app. Once the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request and WebSocket frame that attempts to connect to the app.
You can restrict access to this API and to the URL that it returns to a list of IP addresses, Amazon VPCs or Amazon VPC Endpoints that you specify. For more information, see Connect to Amazon SageMaker AI Studio Through an Interface VPC Endpoint .
-
The URL that you get from a call to
CreatePresignedDomainUrlhas a default timeout of 5 minutes. You can configure this value usingExpiresInSeconds. If you try to use the URL after the timeout limit expires, you are directed to the Amazon Web Services console sign-in page. - The JupyterLab session default expiration time is 12 hours. You can configure this value using SessionExpirationDurationInSeconds.
May throw ResourceNotFound.
Parameter domainId :
The domain ID.
Parameter userProfileName :
The name of the UserProfile to sign-in as.
Parameter expiresInSeconds :
The number of seconds until the pre-signed URL expires. This value
defaults to 300.
Parameter landingUri :
The landing page that the user is directed to when accessing the presigned
URL. Using this value, users can access Studio or Studio Classic, even if
it is not the default experience for the domain. The supported values are:
-
studio::relative/path: Directs users to the relative path in Studio. -
app:JupyterServer:relative/path: Directs users to the relative path in the Studio Classic application. -
app:JupyterLab:relative/path: Directs users to the relative path in the JupyterLab application. -
app:RStudioServerPro:relative/path: Directs users to the relative path in the RStudio application. -
app:CodeEditor:relative/path: Directs users to the relative path in the Code Editor, based on Code-OSS, Visual Studio Code - Open Source application. -
app:Canvas:relative/path: Directs users to the relative path in the Canvas application.
Parameter sessionExpirationDurationInSeconds :
The session expiration duration in seconds. This value defaults to 43200.
Parameter spaceName :
The name of the space.
Implementation
Future<CreatePresignedDomainUrlResponse> createPresignedDomainUrl({
required String domainId,
required String userProfileName,
int? expiresInSeconds,
String? landingUri,
int? sessionExpirationDurationInSeconds,
String? spaceName,
}) async {
_s.validateNumRange(
'expiresInSeconds',
expiresInSeconds,
5,
300,
);
_s.validateNumRange(
'sessionExpirationDurationInSeconds',
sessionExpirationDurationInSeconds,
1800,
43200,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreatePresignedDomainUrl'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainId': domainId,
'UserProfileName': userProfileName,
if (expiresInSeconds != null) 'ExpiresInSeconds': expiresInSeconds,
if (landingUri != null) 'LandingUri': landingUri,
if (sessionExpirationDurationInSeconds != null)
'SessionExpirationDurationInSeconds':
sessionExpirationDurationInSeconds,
if (spaceName != null) 'SpaceName': spaceName,
},
);
return CreatePresignedDomainUrlResponse.fromJson(jsonResponse.body);
}