createTrainingJob method
- required OutputDataConfig outputDataConfig,
- required String roleArn,
- required String trainingJobName,
- AlgorithmSpecification? algorithmSpecification,
- CheckpointConfig? checkpointConfig,
- DebugHookConfig? debugHookConfig,
- List<
DebugRuleConfiguration> ? debugRuleConfigurations, - bool? enableInterContainerTrafficEncryption,
- bool? enableManagedSpotTraining,
- bool? enableNetworkIsolation,
- Map<
String, String> ? environment, - ExperimentConfig? experimentConfig,
- Map<
String, String> ? hyperParameters, - InfraCheckConfig? infraCheckConfig,
- List<
Channel> ? inputDataConfig, - MlflowConfig? mlflowConfig,
- ModelPackageConfig? modelPackageConfig,
- ProfilerConfig? profilerConfig,
- List<
ProfilerRuleConfiguration> ? profilerRuleConfigurations, - RemoteDebugConfig? remoteDebugConfig,
- ResourceConfig? resourceConfig,
- RetryStrategy? retryStrategy,
- ServerlessJobConfig? serverlessJobConfig,
- SessionChainingConfig? sessionChainingConfig,
- StoppingCondition? stoppingCondition,
- List<
Tag> ? tags, - TensorBoardOutputConfig? tensorBoardOutputConfig,
- VpcConfig? vpcConfig,
Starts a model training job. After training completes, SageMaker saves the resulting model artifacts to an Amazon S3 location that you specify.
If you choose to host your model using SageMaker hosting services, you can use the resulting model artifacts as part of the model. You can also use the artifacts in a machine learning service other than SageMaker, provided that you know how to use them for inference.
In the request body, you provide the following:
-
AlgorithmSpecification- Identifies the training algorithm to use. -
HyperParameters- Specify these algorithm-specific parameters to enable the estimation of model parameters during training. Hyperparameters can be tuned to optimize this learning process. For a list of hyperparameters for each training algorithm provided by SageMaker, see Algorithms. -
InputDataConfig- Describes the input required by the training job and the Amazon S3, EFS, or FSx location where it is stored. -
OutputDataConfig- Identifies the Amazon S3 bucket where you want SageMaker to save the results of model training. -
ResourceConfig- Identifies the resources, ML compute instances, and ML storage volumes to deploy for model training. In distributed training, you specify more than one instance. -
EnableManagedSpotTraining- Optimize the cost of training machine learning models by up to 80% by using Amazon EC2 Spot instances. For more information, see Managed Spot Training. -
RoleArn- The Amazon Resource Name (ARN) that SageMaker assumes to perform tasks on your behalf during model training. You must grant this role the necessary permissions so that SageMaker can successfully complete model training. -
StoppingCondition- To help cap training costs, useMaxRuntimeInSecondsto set a time limit for training. UseMaxWaitTimeInSecondsto specify how long a managed spot training job has to complete. -
Environment- The environment variables to set in the Docker container. -
RetryStrategy- The number of times to retry the job when the job fails due to anInternalServerError.
May throw ResourceInUse.
May throw ResourceLimitExceeded.
May throw ResourceNotFound.
Parameter outputDataConfig :
Specifies the path to the S3 location where you want to store model
artifacts. SageMaker creates subfolders for the artifacts.
Parameter roleArn :
The Amazon Resource Name (ARN) of an IAM role that SageMaker can assume to
perform tasks on your behalf.
During model training, SageMaker needs your permission to read input data from an S3 bucket, download a Docker image that contains training code, write model artifacts to an S3 bucket, write logs to Amazon CloudWatch Logs, and publish metrics to Amazon CloudWatch. You grant permissions for all of these tasks to an IAM role. For more information, see SageMaker Roles.
Parameter trainingJobName :
The name of the training job. The name must be unique within an Amazon Web
Services Region in an Amazon Web Services account.
Parameter algorithmSpecification :
The registry path of the Docker image that contains the training algorithm
and algorithm-specific metadata, including the input mode. For more
information about algorithms provided by SageMaker, see Algorithms.
For information about providing your own algorithms, see Using
Your Own Algorithms with Amazon SageMaker.
Parameter checkpointConfig :
Contains information about the output location for managed spot training
checkpoint data.
Parameter debugRuleConfigurations :
Configuration information for Amazon SageMaker Debugger rules for
debugging output tensors.
Parameter enableInterContainerTrafficEncryption :
To encrypt all communications between ML compute instances in distributed
training, choose True. Encryption provides greater security
for distributed training, but training might take longer. How long it
takes depends on the amount of communication between compute instances,
especially if you use a deep learning algorithm in distributed training.
For more information, see Protect
Communications Between ML Compute Instances in a Distributed Training
Job.
Parameter enableManagedSpotTraining :
To train models using managed spot training, choose True.
Managed spot training provides a fully managed and scalable infrastructure
for training machine learning models. this option is useful when training
jobs can be interrupted and when there is flexibility when the training
job is run.
The complete and intermediate results of jobs are stored in an Amazon S3 bucket, and can be used as a starting point to train models incrementally. Amazon SageMaker provides metrics and logs in CloudWatch. They can be used to see when managed spot training jobs are running, interrupted, resumed, or completed.
Parameter enableNetworkIsolation :
Isolates the training container. No inbound or outbound network calls can
be made, except for calls between peers within a training cluster for
distributed training. If you enable network isolation for training jobs
that are configured to use a VPC, SageMaker downloads and uploads customer
data and model artifacts through the specified VPC, but the training
container does not have network access.
Parameter environment :
The environment variables to set in the Docker container.
Parameter hyperParameters :
Algorithm-specific parameters that influence the quality of the model. You
set hyperparameters before you start the learning process. For a list of
hyperparameters for each training algorithm provided by SageMaker, see Algorithms.
You can specify a maximum of 100 hyperparameters. Each hyperparameter is a
key-value pair. Each key and value is limited to 256 characters, as
specified by the Length Constraint.
Parameter infraCheckConfig :
Contains information about the infrastructure health check configuration
for the training job.
Parameter inputDataConfig :
An array of Channel objects. Each channel is a named input
source. InputDataConfig describes the input data and its
location.
Algorithms can accept input data from one or more channels. For example,
an algorithm might have two channels of input data,
training_data and validation_data. The
configuration for each channel provides the S3, EFS, or FSx location where
the input data is stored. It also provides information about the stored
data: the MIME type, compression method, and whether the data is wrapped
in RecordIO format.
Depending on the input mode that the algorithm supports, SageMaker either copies input data files from an S3 bucket to a local directory in the Docker container, or makes it available as input streams. For example, if you specify an EFS location, input data files are available as input streams. They do not need to be downloaded.
Your input must be in the same Amazon Web Services region as your training job.
Parameter mlflowConfig :
The MLflow configuration using SageMaker managed MLflow.
Parameter modelPackageConfig :
The configuration for the model package.
Parameter profilerRuleConfigurations :
Configuration information for Amazon SageMaker Debugger rules for
profiling system and framework metrics.
Parameter remoteDebugConfig :
Configuration for remote debugging. To learn more about the remote
debugging functionality of SageMaker, see Access
a training container through Amazon Web Services Systems Manager (SSM) for
remote debugging.
Parameter resourceConfig :
The resources, including the ML compute instances and ML storage volumes,
to use for model training.
ML storage volumes store model artifacts and incremental states. Training
algorithms might also use ML storage volumes for scratch space. If you
want SageMaker to use the ML storage volume to store the training data,
choose File as the TrainingInputMode in the
algorithm specification. For distributed training algorithms, specify an
instance count greater than 1.
Parameter retryStrategy :
The number of times to retry the job when the job fails due to an
InternalServerError.
Parameter serverlessJobConfig :
The configuration for serverless training jobs.
Parameter sessionChainingConfig :
Contains information about attribute-based access control (ABAC) for the
training job.
Parameter stoppingCondition :
Specifies a limit to how long a model training job can run. It also
specifies how long a managed Spot training job has to complete. When the
job reaches the time limit, SageMaker ends the training job. Use this API
to cap model training costs.
To stop a job, SageMaker sends the algorithm the SIGTERM
signal, which delays job termination for 120 seconds. Algorithms can use
this 120-second window to save the model artifacts, so the results of
training are not lost.
Parameter tags :
An array of key-value pairs. You can use tags to categorize your Amazon
Web Services resources in different ways, for example, by purpose, owner,
or environment. For more information, see Tagging
Amazon Web Services Resources.
Parameter vpcConfig :
A VpcConfig
object that specifies the VPC that you want your training job to connect
to. Control access to and from your training container by configuring the
VPC. For more information, see Protect
Training Jobs by Using an Amazon Virtual Private Cloud.
Implementation
Future<CreateTrainingJobResponse> createTrainingJob({
required OutputDataConfig outputDataConfig,
required String roleArn,
required String trainingJobName,
AlgorithmSpecification? algorithmSpecification,
CheckpointConfig? checkpointConfig,
DebugHookConfig? debugHookConfig,
List<DebugRuleConfiguration>? debugRuleConfigurations,
bool? enableInterContainerTrafficEncryption,
bool? enableManagedSpotTraining,
bool? enableNetworkIsolation,
Map<String, String>? environment,
ExperimentConfig? experimentConfig,
Map<String, String>? hyperParameters,
InfraCheckConfig? infraCheckConfig,
List<Channel>? inputDataConfig,
MlflowConfig? mlflowConfig,
ModelPackageConfig? modelPackageConfig,
ProfilerConfig? profilerConfig,
List<ProfilerRuleConfiguration>? profilerRuleConfigurations,
RemoteDebugConfig? remoteDebugConfig,
ResourceConfig? resourceConfig,
RetryStrategy? retryStrategy,
ServerlessJobConfig? serverlessJobConfig,
SessionChainingConfig? sessionChainingConfig,
StoppingCondition? stoppingCondition,
List<Tag>? tags,
TensorBoardOutputConfig? tensorBoardOutputConfig,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.CreateTrainingJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OutputDataConfig': outputDataConfig,
'RoleArn': roleArn,
'TrainingJobName': trainingJobName,
if (algorithmSpecification != null)
'AlgorithmSpecification': algorithmSpecification,
if (checkpointConfig != null) 'CheckpointConfig': checkpointConfig,
if (debugHookConfig != null) 'DebugHookConfig': debugHookConfig,
if (debugRuleConfigurations != null)
'DebugRuleConfigurations': debugRuleConfigurations,
if (enableInterContainerTrafficEncryption != null)
'EnableInterContainerTrafficEncryption':
enableInterContainerTrafficEncryption,
if (enableManagedSpotTraining != null)
'EnableManagedSpotTraining': enableManagedSpotTraining,
if (enableNetworkIsolation != null)
'EnableNetworkIsolation': enableNetworkIsolation,
if (environment != null) 'Environment': environment,
if (experimentConfig != null) 'ExperimentConfig': experimentConfig,
if (hyperParameters != null) 'HyperParameters': hyperParameters,
if (infraCheckConfig != null) 'InfraCheckConfig': infraCheckConfig,
if (inputDataConfig != null) 'InputDataConfig': inputDataConfig,
if (mlflowConfig != null) 'MlflowConfig': mlflowConfig,
if (modelPackageConfig != null)
'ModelPackageConfig': modelPackageConfig,
if (profilerConfig != null) 'ProfilerConfig': profilerConfig,
if (profilerRuleConfigurations != null)
'ProfilerRuleConfigurations': profilerRuleConfigurations,
if (remoteDebugConfig != null) 'RemoteDebugConfig': remoteDebugConfig,
if (resourceConfig != null) 'ResourceConfig': resourceConfig,
if (retryStrategy != null) 'RetryStrategy': retryStrategy,
if (serverlessJobConfig != null)
'ServerlessJobConfig': serverlessJobConfig,
if (sessionChainingConfig != null)
'SessionChainingConfig': sessionChainingConfig,
if (stoppingCondition != null) 'StoppingCondition': stoppingCondition,
if (tags != null) 'Tags': tags,
if (tensorBoardOutputConfig != null)
'TensorBoardOutputConfig': tensorBoardOutputConfig,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return CreateTrainingJobResponse.fromJson(jsonResponse.body);
}