deleteEdgeDeploymentPlan method
Deletes an edge deployment plan if (and only if) all the stages in the plan are inactive or there are no stages in the plan.
May throw ResourceInUse.
Parameter edgeDeploymentPlanName :
The name of the edge deployment plan to delete.
Implementation
Future<void> deleteEdgeDeploymentPlan({
required String edgeDeploymentPlanName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteEdgeDeploymentPlan'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EdgeDeploymentPlanName': edgeDeploymentPlanName,
},
);
}