deleteEdgeDeploymentStage method
Delete a stage in an edge deployment plan if (and only if) the stage is inactive.
May throw ResourceInUse.
Parameter edgeDeploymentPlanName :
The name of the edge deployment plan from which the stage will be deleted.
Parameter stageName :
The name of the stage.
Implementation
Future<void> deleteEdgeDeploymentStage({
required String edgeDeploymentPlanName,
required String stageName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteEdgeDeploymentStage'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EdgeDeploymentPlanName': edgeDeploymentPlanName,
'StageName': stageName,
},
);
}