deleteFeatureGroup method
Delete the FeatureGroup and any data that was written to the
OnlineStore of the FeatureGroup. Data cannot be
accessed from the OnlineStore immediately after
DeleteFeatureGroup is called.
Data written into the OfflineStore will not be deleted. The
Amazon Web Services Glue database and tables that are automatically
created for your OfflineStore are not deleted.
Note that it can take approximately 10-15 minutes to delete an
OnlineStore FeatureGroup with the
InMemory StorageType.
May throw ResourceNotFound.
Parameter featureGroupName :
The name of the FeatureGroup you want to delete. The name
must be unique within an Amazon Web Services Region in an Amazon Web
Services account.
Implementation
Future<void> deleteFeatureGroup({
required String featureGroupName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteFeatureGroup'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FeatureGroupName': featureGroupName,
},
);
}