deleteHubContent method

Future<void> deleteHubContent({
  1. required String hubContentName,
  2. required HubContentType hubContentType,
  3. required String hubContentVersion,
  4. required String hubName,
})

Delete the contents of a hub.

May throw ResourceInUse. May throw ResourceNotFound.

Parameter hubContentName : The name of the content that you want to delete from a hub.

Parameter hubContentType : The type of content that you want to delete from a hub.

Parameter hubContentVersion : The version of the content that you want to delete from a hub.

Parameter hubName : The name of the hub that you want to delete content in.

Implementation

Future<void> deleteHubContent({
  required String hubContentName,
  required HubContentType hubContentType,
  required String hubContentVersion,
  required String hubName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DeleteHubContent'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'HubContentName': hubContentName,
      'HubContentType': hubContentType.value,
      'HubContentVersion': hubContentVersion,
      'HubName': hubName,
    },
  );
}