deleteHyperParameterTuningJob method

Future<void> deleteHyperParameterTuningJob({
  1. required String hyperParameterTuningJobName,
})

Deletes a hyperparameter tuning job. The DeleteHyperParameterTuningJob API deletes only the tuning job entry that was created in SageMaker when you called the CreateHyperParameterTuningJob API. It does not delete training jobs, artifacts, or the IAM role that you specified when creating the model.

Parameter hyperParameterTuningJobName : The name of the hyperparameter tuning job that you want to delete.

Implementation

Future<void> deleteHyperParameterTuningJob({
  required String hyperParameterTuningJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DeleteHyperParameterTuningJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'HyperParameterTuningJobName': hyperParameterTuningJobName,
    },
  );
}