deleteModelPackage method
Deletes a model package.
A model package is used to create SageMaker models or list on Amazon Web Services Marketplace. Buyers can subscribe to model packages listed on Amazon Web Services Marketplace to create models in SageMaker.
May throw ConflictException.
Parameter modelPackageName :
The name or Amazon Resource Name (ARN) of the model package to delete.
When you specify a name, the name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
Implementation
Future<void> deleteModelPackage({
required String modelPackageName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteModelPackage'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ModelPackageName': modelPackageName,
},
);
}