deleteProcessingJob method

Future<void> deleteProcessingJob({
  1. required String processingJobName,
})

Deletes a processing job. After Amazon SageMaker deletes a processing job, all of the metadata for the processing job is lost. You can delete only processing jobs that are in a terminal state (Stopped, Failed, or Completed). You cannot delete a job that is in the InProgress or Stopping state. After deleting the job, you can reuse its name to create another processing job.

May throw ResourceInUse. May throw ResourceNotFound.

Parameter processingJobName : The name of the processing job to delete.

Implementation

Future<void> deleteProcessingJob({
  required String processingJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DeleteProcessingJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ProcessingJobName': processingJobName,
    },
  );
}