deleteStudioLifecycleConfig method

Future<void> deleteStudioLifecycleConfig({
  1. required String studioLifecycleConfigName,
})

Deletes the Amazon SageMaker AI Studio Lifecycle Configuration. In order to delete the Lifecycle Configuration, there must be no running apps using the Lifecycle Configuration. You must also remove the Lifecycle Configuration from UserSettings in all Domains and UserProfiles.

May throw ResourceInUse. May throw ResourceNotFound.

Parameter studioLifecycleConfigName : The name of the Amazon SageMaker AI Studio Lifecycle Configuration to delete.

Implementation

Future<void> deleteStudioLifecycleConfig({
  required String studioLifecycleConfigName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DeleteStudioLifecycleConfig'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'StudioLifecycleConfigName': studioLifecycleConfigName,
    },
  );
}