describeClusterNode method
Retrieves information of a node (also called a instance interchangeably) of a SageMaker HyperPod cluster.
May throw ResourceNotFound.
Parameter clusterName :
The string name or the Amazon Resource Name (ARN) of the SageMaker
HyperPod cluster in which the node is.
Parameter nodeId :
The ID of the SageMaker HyperPod cluster node.
Parameter nodeLogicalId :
The logical identifier of the node to describe. You can specify either
NodeLogicalId or InstanceId, but not both.
NodeLogicalId can be used to describe nodes that are still
being provisioned and don't yet have an InstanceId assigned.
Implementation
Future<DescribeClusterNodeResponse> describeClusterNode({
required String clusterName,
String? nodeId,
String? nodeLogicalId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DescribeClusterNode'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ClusterName': clusterName,
if (nodeId != null) 'NodeId': nodeId,
if (nodeLogicalId != null) 'NodeLogicalId': nodeLogicalId,
},
);
return DescribeClusterNodeResponse.fromJson(jsonResponse.body);
}