describeEdgeDeploymentPlan method

Future<DescribeEdgeDeploymentPlanResponse> describeEdgeDeploymentPlan({
  1. required String edgeDeploymentPlanName,
  2. int? maxResults,
  3. String? nextToken,
})

Describes an edge deployment plan with deployment status per stage.

May throw ResourceNotFound.

Parameter edgeDeploymentPlanName : The name of the deployment plan to describe.

Parameter maxResults : The maximum number of results to select (50 by default).

Parameter nextToken : If the edge deployment plan has enough stages to require tokening, then this is the response from the last list of stages returned.

Implementation

Future<DescribeEdgeDeploymentPlanResponse> describeEdgeDeploymentPlan({
  required String edgeDeploymentPlanName,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    10,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DescribeEdgeDeploymentPlan'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EdgeDeploymentPlanName': edgeDeploymentPlanName,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeEdgeDeploymentPlanResponse.fromJson(jsonResponse.body);
}