describeInferenceRecommendationsJob method

Future<DescribeInferenceRecommendationsJobResponse> describeInferenceRecommendationsJob({
  1. required String jobName,
})

Provides the results of the Inference Recommender job. One or more recommendation jobs are returned.

May throw ResourceNotFound.

Parameter jobName : The name of the job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Implementation

Future<DescribeInferenceRecommendationsJobResponse>
    describeInferenceRecommendationsJob({
  required String jobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.DescribeInferenceRecommendationsJob'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'JobName': jobName,
    },
  );

  return DescribeInferenceRecommendationsJobResponse.fromJson(
      jsonResponse.body);
}