listInferenceExperiments method

Future<ListInferenceExperimentsResponse> listInferenceExperiments({
  1. DateTime? creationTimeAfter,
  2. DateTime? creationTimeBefore,
  3. DateTime? lastModifiedTimeAfter,
  4. DateTime? lastModifiedTimeBefore,
  5. int? maxResults,
  6. String? nameContains,
  7. String? nextToken,
  8. SortInferenceExperimentsBy? sortBy,
  9. SortOrder? sortOrder,
  10. InferenceExperimentStatus? statusEquals,
  11. InferenceExperimentType? type,
})

Returns the list of all inference experiments.

Parameter creationTimeAfter : Selects inference experiments which were created after this timestamp.

Parameter creationTimeBefore : Selects inference experiments which were created before this timestamp.

Parameter lastModifiedTimeAfter : Selects inference experiments which were last modified after this timestamp.

Parameter lastModifiedTimeBefore : Selects inference experiments which were last modified before this timestamp.

Parameter maxResults : The maximum number of results to select.

Parameter nameContains : Selects inference experiments whose names contain this name.

Parameter nextToken : The response from the last list when returning a list large enough to need tokening.

Parameter sortBy : The column by which to sort the listed inference experiments.

Parameter sortOrder : The direction of sorting (ascending or descending).

Parameter statusEquals : Selects inference experiments which are in this status. For the possible statuses, see DescribeInferenceExperiment.

Parameter type : Selects inference experiments of this type. For the possible types of inference experiments, see CreateInferenceExperiment.

Implementation

Future<ListInferenceExperimentsResponse> listInferenceExperiments({
  DateTime? creationTimeAfter,
  DateTime? creationTimeBefore,
  DateTime? lastModifiedTimeAfter,
  DateTime? lastModifiedTimeBefore,
  int? maxResults,
  String? nameContains,
  String? nextToken,
  SortInferenceExperimentsBy? sortBy,
  SortOrder? sortOrder,
  InferenceExperimentStatus? statusEquals,
  InferenceExperimentType? type,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.ListInferenceExperiments'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (creationTimeAfter != null)
        'CreationTimeAfter': unixTimestampToJson(creationTimeAfter),
      if (creationTimeBefore != null)
        'CreationTimeBefore': unixTimestampToJson(creationTimeBefore),
      if (lastModifiedTimeAfter != null)
        'LastModifiedTimeAfter': unixTimestampToJson(lastModifiedTimeAfter),
      if (lastModifiedTimeBefore != null)
        'LastModifiedTimeBefore': unixTimestampToJson(lastModifiedTimeBefore),
      if (maxResults != null) 'MaxResults': maxResults,
      if (nameContains != null) 'NameContains': nameContains,
      if (nextToken != null) 'NextToken': nextToken,
      if (sortBy != null) 'SortBy': sortBy.value,
      if (sortOrder != null) 'SortOrder': sortOrder.value,
      if (statusEquals != null) 'StatusEquals': statusEquals.value,
      if (type != null) 'Type': type.value,
    },
  );

  return ListInferenceExperimentsResponse.fromJson(jsonResponse.body);
}