listPartnerApps method

Future<ListPartnerAppsResponse> listPartnerApps({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all of the SageMaker Partner AI Apps in an account.

Parameter maxResults : This parameter defines the maximum number of results that can be returned in a single response. The MaxResults parameter is an upper bound, not a target. If there are more results available than the value specified, a NextToken is provided in the response. The NextToken indicates that the user should get the next set of results by providing this token as a part of a subsequent call. The default value for MaxResults is 10.

Parameter nextToken : If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.

Implementation

Future<ListPartnerAppsResponse> listPartnerApps({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.ListPartnerApps'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListPartnerAppsResponse.fromJson(jsonResponse.body);
}