listResourceCatalogs method
Lists Amazon SageMaker Catalogs based on given filters and orders. The
maximum number of ResourceCatalogs viewable is 1000.
Parameter creationTimeAfter :
Use this parameter to search for ResourceCatalogs created
after a specific date and time.
Parameter creationTimeBefore :
Use this parameter to search for ResourceCatalogs created
before a specific date and time.
Parameter maxResults :
The maximum number of results returned by
ListResourceCatalogs.
Parameter nameContains :
A string that partially matches one or more ResourceCatalogs
names. Filters ResourceCatalog by name.
Parameter nextToken :
A token to resume pagination of ListResourceCatalogs results.
Parameter sortBy :
The value on which the resource catalog list is sorted.
Parameter sortOrder :
The order in which the resource catalogs are listed.
Implementation
Future<ListResourceCatalogsResponse> listResourceCatalogs({
DateTime? creationTimeAfter,
DateTime? creationTimeBefore,
int? maxResults,
String? nameContains,
String? nextToken,
ResourceCatalogSortBy? sortBy,
ResourceCatalogSortOrder? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.ListResourceCatalogs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (creationTimeAfter != null)
'CreationTimeAfter': unixTimestampToJson(creationTimeAfter),
if (creationTimeBefore != null)
'CreationTimeBefore': unixTimestampToJson(creationTimeBefore),
if (maxResults != null) 'MaxResults': maxResults,
if (nameContains != null) 'NameContains': nameContains,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
if (sortOrder != null) 'SortOrder': sortOrder.value,
},
);
return ListResourceCatalogsResponse.fromJson(jsonResponse.body);
}