retryPipelineExecution method

Future<RetryPipelineExecutionResponse> retryPipelineExecution({
  1. required String pipelineExecutionArn,
  2. String? clientRequestToken,
  3. ParallelismConfiguration? parallelismConfiguration,
})

Retry the execution of the pipeline.

May throw ConflictException. May throw ResourceLimitExceeded. May throw ResourceNotFound.

Parameter pipelineExecutionArn : The Amazon Resource Name (ARN) of the pipeline execution.

Parameter clientRequestToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than once.

Parameter parallelismConfiguration : This configuration, if specified, overrides the parallelism configuration of the parent pipeline.

Implementation

Future<RetryPipelineExecutionResponse> retryPipelineExecution({
  required String pipelineExecutionArn,
  String? clientRequestToken,
  ParallelismConfiguration? parallelismConfiguration,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.RetryPipelineExecution'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'PipelineExecutionArn': pipelineExecutionArn,
      'ClientRequestToken':
          clientRequestToken ?? _s.generateIdempotencyToken(),
      if (parallelismConfiguration != null)
        'ParallelismConfiguration': parallelismConfiguration,
    },
  );

  return RetryPipelineExecutionResponse.fromJson(jsonResponse.body);
}