sendPipelineExecutionStepSuccess method

Future<SendPipelineExecutionStepSuccessResponse> sendPipelineExecutionStepSuccess({
  1. required String callbackToken,
  2. String? clientRequestToken,
  3. List<OutputParameter>? outputParameters,
})

Notifies the pipeline that the execution of a callback step succeeded and provides a list of the step's output parameters. When a callback step is run, the pipeline generates a callback token and includes the token in a message sent to Amazon Simple Queue Service (Amazon SQS).

May throw ConflictException. May throw ResourceLimitExceeded. May throw ResourceNotFound.

Parameter callbackToken : The pipeline generated token from the Amazon SQS queue.

Parameter clientRequestToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.

Parameter outputParameters : A list of the output parameters of the callback step.

Implementation

Future<SendPipelineExecutionStepSuccessResponse>
    sendPipelineExecutionStepSuccess({
  required String callbackToken,
  String? clientRequestToken,
  List<OutputParameter>? outputParameters,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.SendPipelineExecutionStepSuccess'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CallbackToken': callbackToken,
      'ClientRequestToken':
          clientRequestToken ?? _s.generateIdempotencyToken(),
      if (outputParameters != null) 'OutputParameters': outputParameters,
    },
  );

  return SendPipelineExecutionStepSuccessResponse.fromJson(jsonResponse.body);
}