stopTransformJob method

Future<void> stopTransformJob({
  1. required String transformJobName,
})

Stops a batch transform job.

When Amazon SageMaker receives a StopTransformJob request, the status of the job changes to Stopping. After Amazon SageMaker stops the job, the status is set to Stopped. When you stop a batch transform job before it is completed, Amazon SageMaker doesn't store the job's output in Amazon S3.

May throw ResourceNotFound.

Parameter transformJobName : The name of the batch transform job to stop.

Implementation

Future<void> stopTransformJob({
  required String transformJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.StopTransformJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TransformJobName': transformJobName,
    },
  );
}