updateMlflowApp method

Future<UpdateMlflowAppResponse> updateMlflowApp({
  1. required String arn,
  2. AccountDefaultStatus? accountDefaultStatus,
  3. String? artifactStoreUri,
  4. List<String>? defaultDomainIdList,
  5. ModelRegistrationMode? modelRegistrationMode,
  6. String? name,
  7. String? weeklyMaintenanceWindowStart,
})

Updates an MLflow App.

May throw ConflictException. May throw ResourceNotFound.

Parameter arn : The ARN of the MLflow App to update.

Parameter accountDefaultStatus : Indicates whether this this MLflow App is the default for the account.

Parameter artifactStoreUri : The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow App.

Parameter defaultDomainIdList : List of SageMaker Domain IDs for which this MLflow App is the default.

Parameter modelRegistrationMode : Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to AutoModelRegistrationEnabled. To disable automatic model registration, set this value to AutoModelRegistrationDisabled. If not specified, AutomaticModelRegistration defaults to AutoModelRegistrationEnabled

Parameter name : The name of the MLflow App to update.

Parameter weeklyMaintenanceWindowStart : The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.

Implementation

Future<UpdateMlflowAppResponse> updateMlflowApp({
  required String arn,
  AccountDefaultStatus? accountDefaultStatus,
  String? artifactStoreUri,
  List<String>? defaultDomainIdList,
  ModelRegistrationMode? modelRegistrationMode,
  String? name,
  String? weeklyMaintenanceWindowStart,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SageMaker.UpdateMlflowApp'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Arn': arn,
      if (accountDefaultStatus != null)
        'AccountDefaultStatus': accountDefaultStatus.value,
      if (artifactStoreUri != null) 'ArtifactStoreUri': artifactStoreUri,
      if (defaultDomainIdList != null)
        'DefaultDomainIdList': defaultDomainIdList,
      if (modelRegistrationMode != null)
        'ModelRegistrationMode': modelRegistrationMode.value,
      if (name != null) 'Name': name,
      if (weeklyMaintenanceWindowStart != null)
        'WeeklyMaintenanceWindowStart': weeklyMaintenanceWindowStart,
    },
  );

  return UpdateMlflowAppResponse.fromJson(jsonResponse.body);
}