updateMonitoringSchedule method
Future<UpdateMonitoringScheduleResponse>
updateMonitoringSchedule({
- required MonitoringScheduleConfig monitoringScheduleConfig,
- required String monitoringScheduleName,
Updates a previously created schedule.
May throw ResourceLimitExceeded.
May throw ResourceNotFound.
Parameter monitoringScheduleConfig :
The configuration object that specifies the monitoring schedule and
defines the monitoring job.
Parameter monitoringScheduleName :
The name of the monitoring schedule. The name must be unique within an
Amazon Web Services Region within an Amazon Web Services account.
Implementation
Future<UpdateMonitoringScheduleResponse> updateMonitoringSchedule({
required MonitoringScheduleConfig monitoringScheduleConfig,
required String monitoringScheduleName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.UpdateMonitoringSchedule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MonitoringScheduleConfig': monitoringScheduleConfig,
'MonitoringScheduleName': monitoringScheduleName,
},
);
return UpdateMonitoringScheduleResponse.fromJson(jsonResponse.body);
}