updateNotebookInstance method
- required String notebookInstanceName,
- List<
NotebookInstanceAcceleratorType> ? acceleratorTypes, - List<
String> ? additionalCodeRepositories, - String? defaultCodeRepository,
- bool? disassociateAcceleratorTypes,
- bool? disassociateAdditionalCodeRepositories,
- bool? disassociateDefaultCodeRepository,
- bool? disassociateLifecycleConfig,
- InstanceMetadataServiceConfiguration? instanceMetadataServiceConfiguration,
- InstanceType? instanceType,
- IPAddressType? ipAddressType,
- String? lifecycleConfigName,
- String? platformIdentifier,
- String? roleArn,
- RootAccess? rootAccess,
- int? volumeSizeInGB,
Updates a notebook instance. NotebookInstance updates include upgrading or downgrading the ML compute instance used for your notebook instance to accommodate changes in your workload requirements.
May throw ResourceLimitExceeded.
Parameter notebookInstanceName :
The name of the notebook instance to update.
Parameter acceleratorTypes :
This parameter is no longer supported. Elastic Inference (EI) is no longer
available.
This parameter was used to specify a list of the EI instance types to associate with this notebook instance.
Parameter additionalCodeRepositories :
An array of up to three Git repositories to associate with the notebook
instance. These can be either the names of Git repositories stored as
resources in your account, or the URL of Git repositories in Amazon
Web Services CodeCommit or in any other Git repository. These
repositories are cloned at the same level as the default repository of
your notebook instance. For more information, see Associating
Git Repositories with SageMaker AI Notebook Instances.
Parameter defaultCodeRepository :
The Git repository to associate with the notebook instance as its default
code repository. This can be either the name of a Git repository stored as
a resource in your account, or the URL of a Git repository in Amazon
Web Services CodeCommit or in any other Git repository. When you open
a notebook instance, it opens in the directory that contains this
repository. For more information, see Associating
Git Repositories with SageMaker AI Notebook Instances.
Parameter disassociateAcceleratorTypes :
This parameter is no longer supported. Elastic Inference (EI) is no longer
available.
This parameter was used to specify a list of the EI instance types to remove from this notebook instance.
Parameter disassociateAdditionalCodeRepositories :
A list of names or URLs of the default Git repositories to remove from
this notebook instance. This operation is idempotent. If you specify a Git
repository that is not associated with the notebook instance when you call
this method, it does not throw an error.
Parameter disassociateDefaultCodeRepository :
The name or URL of the default Git repository to remove from this notebook
instance. This operation is idempotent. If you specify a Git repository
that is not associated with the notebook instance when you call this
method, it does not throw an error.
Parameter disassociateLifecycleConfig :
Set to true to remove the notebook instance lifecycle
configuration currently associated with the notebook instance. This
operation is idempotent. If you specify a lifecycle configuration that is
not associated with the notebook instance when you call this method, it
does not throw an error.
Parameter instanceMetadataServiceConfiguration :
Information on the IMDS configuration of the notebook instance
Parameter instanceType :
The Amazon ML compute instance type.
Parameter ipAddressType :
The IP address type for the notebook instance. Specify ipv4
for IPv4-only connectivity or dualstack for both IPv4 and
IPv6 connectivity. The notebook instance must be stopped before updating
this setting. When you specify dualstack, the subnet must
support IPv6 addressing.
Parameter lifecycleConfigName :
The name of a lifecycle configuration to associate with the notebook
instance. For information about lifestyle configurations, see Step
2.1: (Optional) Customize a Notebook Instance.
Parameter platformIdentifier :
The platform identifier of the notebook instance runtime environment.
Parameter roleArn :
The Amazon Resource Name (ARN) of the IAM role that SageMaker AI can
assume to access the notebook instance. For more information, see SageMaker
AI Roles.
Parameter rootAccess :
Whether root access is enabled or disabled for users of the notebook
instance. The default value is Enabled.
Parameter volumeSizeInGB :
The size, in GB, of the ML storage volume to attach to the notebook
instance. The default value is 5 GB. ML storage volumes are encrypted, so
SageMaker AI can't determine the amount of available free space on the
volume. Because of this, you can increase the volume size when you update
a notebook instance, but you can't decrease the volume size. If you want
to decrease the size of the ML storage volume in use, create a new
notebook instance with the desired size.
Implementation
Future<void> updateNotebookInstance({
required String notebookInstanceName,
List<NotebookInstanceAcceleratorType>? acceleratorTypes,
List<String>? additionalCodeRepositories,
String? defaultCodeRepository,
bool? disassociateAcceleratorTypes,
bool? disassociateAdditionalCodeRepositories,
bool? disassociateDefaultCodeRepository,
bool? disassociateLifecycleConfig,
InstanceMetadataServiceConfiguration? instanceMetadataServiceConfiguration,
InstanceType? instanceType,
IPAddressType? ipAddressType,
String? lifecycleConfigName,
String? platformIdentifier,
String? roleArn,
RootAccess? rootAccess,
int? volumeSizeInGB,
}) async {
_s.validateNumRange(
'volumeSizeInGB',
volumeSizeInGB,
5,
16384,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.UpdateNotebookInstance'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'NotebookInstanceName': notebookInstanceName,
if (acceleratorTypes != null)
'AcceleratorTypes': acceleratorTypes.map((e) => e.value).toList(),
if (additionalCodeRepositories != null)
'AdditionalCodeRepositories': additionalCodeRepositories,
if (defaultCodeRepository != null)
'DefaultCodeRepository': defaultCodeRepository,
if (disassociateAcceleratorTypes != null)
'DisassociateAcceleratorTypes': disassociateAcceleratorTypes,
if (disassociateAdditionalCodeRepositories != null)
'DisassociateAdditionalCodeRepositories':
disassociateAdditionalCodeRepositories,
if (disassociateDefaultCodeRepository != null)
'DisassociateDefaultCodeRepository':
disassociateDefaultCodeRepository,
if (disassociateLifecycleConfig != null)
'DisassociateLifecycleConfig': disassociateLifecycleConfig,
if (instanceMetadataServiceConfiguration != null)
'InstanceMetadataServiceConfiguration':
instanceMetadataServiceConfiguration,
if (instanceType != null) 'InstanceType': instanceType.value,
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (lifecycleConfigName != null)
'LifecycleConfigName': lifecycleConfigName,
if (platformIdentifier != null)
'PlatformIdentifier': platformIdentifier,
if (roleArn != null) 'RoleArn': roleArn,
if (rootAccess != null) 'RootAccess': rootAccess.value,
if (volumeSizeInGB != null) 'VolumeSizeInGB': volumeSizeInGB,
},
);
}