describeHumanLoop method

Future<DescribeHumanLoopResponse> describeHumanLoop({
  1. required String humanLoopName,
})

Returns information about the specified human loop. If the human loop was deleted, this operation will return a ResourceNotFoundException error.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter humanLoopName : The name of the human loop that you want information about.

Implementation

Future<DescribeHumanLoopResponse> describeHumanLoop({
  required String humanLoopName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/human-loops/${Uri.encodeComponent(humanLoopName)}',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeHumanLoopResponse.fromJson(response);
}