sage_maker_a2i_runtime_2019_11_07 library
Classes
- AwsClientCredentials
- AWS credentials.
- SageMakerA2iRuntime
- Amazon Augmented AI (Amazon A2I) adds the benefit of human judgment to any machine learning application. When an AI application can't evaluate data with a high degree of confidence, human reviewers can take over. This human review is called a human review workflow. To create and start a human review workflow, you need three resources: a worker task template, a flow definition, and a human loop.