SageMakerFeatureStoreRuntime class

Contains all data plane API operations and data types for the Amazon SageMaker Feature Store. Use this API to put, delete, and retrieve (get) features from a feature store.

Use the following operations to configure your OnlineStore and OfflineStore features, and to create and manage feature groups:

Constructors

SageMakerFeatureStoreRuntime({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetRecord({required List<BatchGetRecordIdentifier> identifiers, ExpirationTimeResponse? expirationTimeResponse}) Future<BatchGetRecordResponse>
Retrieves a batch of Records from a FeatureGroup.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteRecord({required String eventTime, required String featureGroupName, required String recordIdentifierValueAsString, DeletionMode? deletionMode, List<TargetStore>? targetStores}) Future<void>
Deletes a Record from a FeatureGroup in the OnlineStore. Feature Store supports both SoftDelete and HardDelete. For SoftDelete (default), feature columns are set to null and the record is no longer retrievable by GetRecord or BatchGetRecord. For HardDelete, the complete Record is removed from the OnlineStore. In both cases, Feature Store appends the deleted record marker to the OfflineStore. The deleted record marker is a record with the same RecordIdentifer as the original, but with is_deleted value set to True, EventTime set to the delete input EventTime, and other feature values set to null.
getRecord({required String featureGroupName, required String recordIdentifierValueAsString, ExpirationTimeResponse? expirationTimeResponse, List<String>? featureNames}) Future<GetRecordResponse>
Use for OnlineStore serving from a FeatureStore. Only the latest records stored in the OnlineStore can be retrieved. If no Record with RecordIdentifierValue is found, then an empty result is returned.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putRecord({required String featureGroupName, required List<FeatureValue> record, List<TargetStore>? targetStores, TtlDuration? ttlDuration}) Future<void>
The PutRecord API is used to ingest a list of Records into your feature group.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited