SageMakerGeospatial class

Provides APIs for creating and managing SageMaker geospatial resources.

Constructors

SageMakerGeospatial({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteEarthObservationJob({required String arn}) Future<void>
Use this operation to delete an Earth Observation job.
deleteVectorEnrichmentJob({required String arn}) Future<void>
Use this operation to delete a Vector Enrichment job.
exportEarthObservationJob({required String arn, required String executionRoleArn, required OutputConfigInput outputConfig, String? clientToken, bool? exportSourceImages}) Future<ExportEarthObservationJobOutput>
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
exportVectorEnrichmentJob({required String arn, required String executionRoleArn, required ExportVectorEnrichmentJobOutputConfig outputConfig, String? clientToken}) Future<ExportVectorEnrichmentJobOutput>
Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.
getEarthObservationJob({required String arn}) Future<GetEarthObservationJobOutput>
Get the details for a previously initiated Earth Observation job.
getRasterDataCollection({required String arn}) Future<GetRasterDataCollectionOutput>
Use this operation to get details of a specific raster data collection.
getTile({required String arn, required List<String> imageAssets, required TargetOptions target, required int x, required int y, required int z, String? executionRoleArn, bool? imageMask, OutputType? outputDataType, String? outputFormat, String? propertyFilters, String? timeRangeFilter}) Future<GetTileOutput>
Gets a web mercator tile for the given Earth Observation job.
getVectorEnrichmentJob({required String arn}) Future<GetVectorEnrichmentJobOutput>
Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN).
listEarthObservationJobs({int? maxResults, String? nextToken, String? sortBy, SortOrder? sortOrder, EarthObservationJobStatus? statusEquals}) Future<ListEarthObservationJobOutput>
Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account.
listRasterDataCollections({int? maxResults, String? nextToken}) Future<ListRasterDataCollectionsOutput>
Use this operation to get raster data collections.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags attached to the resource.
listVectorEnrichmentJobs({int? maxResults, String? nextToken, String? sortBy, SortOrder? sortOrder, String? statusEquals}) Future<ListVectorEnrichmentJobOutput>
Retrieves a list of vector enrichment jobs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchRasterDataCollection({required String arn, required RasterDataCollectionQueryWithBandFilterInput rasterDataCollectionQuery, String? nextToken}) Future<SearchRasterDataCollectionOutput>
Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.
startEarthObservationJob({required String executionRoleArn, required InputConfigInput inputConfig, required JobConfigInput jobConfig, required String name, String? clientToken, String? kmsKeyId, Map<String, String>? tags}) Future<StartEarthObservationJobOutput>
Use this operation to create an Earth observation job.
startVectorEnrichmentJob({required String executionRoleArn, required VectorEnrichmentJobInputConfig inputConfig, required VectorEnrichmentJobConfig jobConfig, required String name, String? clientToken, String? kmsKeyId, Map<String, String>? tags}) Future<StartVectorEnrichmentJobOutput>
Creates a Vector Enrichment job for the supplied job type. Currently, there are two supported job types: reverse geocoding and map matching.
stopEarthObservationJob({required String arn}) Future<void>
Use this operation to stop an existing earth observation job.
stopVectorEnrichmentJob({required String arn}) Future<void>
Stops the Vector Enrichment job for a given job ARN.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
The resource you want to tag.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
The resource you want to untag.

Operators

operator ==(Object other) bool
The equality operator.
inherited