exportEarthObservationJob method
Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The input Amazon Resource Name (ARN) of the Earth Observation job being
exported.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the IAM role that you specified for the
job.
Parameter outputConfig :
An object containing information about the output file.
Parameter clientToken :
A unique token that guarantees that the call to this API is idempotent.
Parameter exportSourceImages :
The source images provided to the Earth Observation job being exported.
Implementation
Future<ExportEarthObservationJobOutput> exportEarthObservationJob({
required String arn,
required String executionRoleArn,
required OutputConfigInput outputConfig,
String? clientToken,
bool? exportSourceImages,
}) async {
final $payload = <String, dynamic>{
'Arn': arn,
'ExecutionRoleArn': executionRoleArn,
'OutputConfig': outputConfig,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (exportSourceImages != null) 'ExportSourceImages': exportSourceImages,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/export-earth-observation-job',
exceptionFnMap: _exceptionFns,
);
return ExportEarthObservationJobOutput.fromJson(response);
}