exportVectorEnrichmentJob method

Future<ExportVectorEnrichmentJobOutput> exportVectorEnrichmentJob({
  1. required String arn,
  2. required String executionRoleArn,
  3. required ExportVectorEnrichmentJobOutputConfig outputConfig,
  4. String? clientToken,
})

Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the Vector Enrichment job.

Parameter executionRoleArn : The Amazon Resource Name (ARN) of the IAM rolewith permission to upload to the location in OutputConfig.

Parameter outputConfig : Output location information for exporting Vector Enrichment Job results.

Parameter clientToken : A unique token that guarantees that the call to this API is idempotent.

Implementation

Future<ExportVectorEnrichmentJobOutput> exportVectorEnrichmentJob({
  required String arn,
  required String executionRoleArn,
  required ExportVectorEnrichmentJobOutputConfig outputConfig,
  String? clientToken,
}) async {
  final $payload = <String, dynamic>{
    'Arn': arn,
    'ExecutionRoleArn': executionRoleArn,
    'OutputConfig': outputConfig,
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/export-vector-enrichment-jobs',
    exceptionFnMap: _exceptionFns,
  );
  return ExportVectorEnrichmentJobOutput.fromJson(response);
}