searchRasterDataCollection method

Future<SearchRasterDataCollectionOutput> searchRasterDataCollection({
  1. required String arn,
  2. required RasterDataCollectionQueryWithBandFilterInput rasterDataCollectionQuery,
  3. String? nextToken,
})

Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter arn : The Amazon Resource Name (ARN) of the raster data collection.

Parameter rasterDataCollectionQuery : RasterDataCollectionQuery consisting of AreaOfInterest(AOI), PropertyFilters and TimeRangeFilterInput used in SearchRasterDataCollection.

Parameter nextToken : If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results.

Implementation

Future<SearchRasterDataCollectionOutput> searchRasterDataCollection({
  required String arn,
  required RasterDataCollectionQueryWithBandFilterInput
      rasterDataCollectionQuery,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'Arn': arn,
    'RasterDataCollectionQuery': rasterDataCollectionQuery,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/search-raster-data-collection',
    exceptionFnMap: _exceptionFns,
  );
  return SearchRasterDataCollectionOutput.fromJson(response);
}