startEarthObservationJob method
Use this operation to create an Earth observation job.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the IAM role that you specified for the
job.
Parameter inputConfig :
Input configuration information for the Earth Observation job.
Parameter jobConfig :
An object containing information about the job configuration.
Parameter name :
The name of the Earth Observation job.
Parameter clientToken :
A unique token that guarantees that the call to this API is idempotent.
Parameter kmsKeyId :
The Key Management Service key ID for server-side encryption.
Parameter tags :
Each tag consists of a key and a value.
Implementation
Future<StartEarthObservationJobOutput> startEarthObservationJob({
required String executionRoleArn,
required InputConfigInput inputConfig,
required JobConfigInput jobConfig,
required String name,
String? clientToken,
String? kmsKeyId,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'ExecutionRoleArn': executionRoleArn,
'InputConfig': inputConfig,
'JobConfig': jobConfig,
'Name': name,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/earth-observation-jobs',
exceptionFnMap: _exceptionFns,
);
return StartEarthObservationJobOutput.fromJson(response);
}