startVectorEnrichmentJob method

Future<StartVectorEnrichmentJobOutput> startVectorEnrichmentJob({
  1. required String executionRoleArn,
  2. required VectorEnrichmentJobInputConfig inputConfig,
  3. required VectorEnrichmentJobConfig jobConfig,
  4. required String name,
  5. String? clientToken,
  6. String? kmsKeyId,
  7. Map<String, String>? tags,
})

Creates a Vector Enrichment job for the supplied job type. Currently, there are two supported job types: reverse geocoding and map matching.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter executionRoleArn : The Amazon Resource Name (ARN) of the IAM role that you specified for the job.

Parameter inputConfig : Input configuration information for the Vector Enrichment job.

Parameter jobConfig : An object containing information about the job configuration.

Parameter name : The name of the Vector Enrichment job.

Parameter clientToken : A unique token that guarantees that the call to this API is idempotent.

Parameter kmsKeyId : The Key Management Service key ID for server-side encryption.

Parameter tags : Each tag consists of a key and a value.

Implementation

Future<StartVectorEnrichmentJobOutput> startVectorEnrichmentJob({
  required String executionRoleArn,
  required VectorEnrichmentJobInputConfig inputConfig,
  required VectorEnrichmentJobConfig jobConfig,
  required String name,
  String? clientToken,
  String? kmsKeyId,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'ExecutionRoleArn': executionRoleArn,
    'InputConfig': inputConfig,
    'JobConfig': jobConfig,
    'Name': name,
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/vector-enrichment-jobs',
    exceptionFnMap: _exceptionFns,
  );
  return StartVectorEnrichmentJobOutput.fromJson(response);
}