SageMakerRuntime class

The Amazon SageMaker AI runtime API.

Constructors

SageMakerRuntime({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
invokeEndpoint({required Uint8List body, required String endpointName, String? accept, String? contentType, String? customAttributes, String? enableExplanations, String? inferenceComponentName, String? inferenceId, String? sessionId, String? targetContainerHostname, String? targetModel, String? targetVariant}) Future<InvokeEndpointOutput>
After you deploy a model into production using Amazon SageMaker AI hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint.
invokeEndpointAsync({required String endpointName, required String inputLocation, String? accept, String? contentType, String? customAttributes, String? filename, String? inferenceId, int? invocationTimeoutSeconds, int? requestTTLSeconds, String? s3OutputPathExtension}) Future<InvokeEndpointAsyncOutput>
After you deploy a model into production using Amazon SageMaker AI hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint in an asynchronous manner.
invokeEndpointWithResponseStream({required Uint8List body, required String endpointName, String? accept, String? contentType, String? customAttributes, String? inferenceComponentName, String? inferenceId, String? sessionId, String? targetContainerHostname, String? targetVariant}) Future<InvokeEndpointWithResponseStreamOutput>
Invokes a model at the specified endpoint to return the inference response as a stream. The inference stream provides the response payload incrementally as a series of parts. Before you can get an inference stream, you must have access to a model that's deployed using Amazon SageMaker AI hosting services, and the container for that model must support inference streaming.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited