invokeEndpoint method
After you deploy a model into production using Amazon SageMaker AI hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint.
For an overview of Amazon SageMaker AI, see How It Works.
Amazon SageMaker AI strips all POST headers except those supported by the API. Amazon SageMaker AI might add additional headers. You should not rely on the behavior of headers outside those enumerated in the request syntax.
Calls to InvokeEndpoint are authenticated by using Amazon Web
Services Signature Version 4. For information, see Authenticating
Requests (Amazon Web Services Signature Version 4) in the Amazon S3
API Reference.
A customer's model containers must respond to requests within 60 seconds. The model itself can have a maximum processing time of 60 seconds before responding to invocations. If your model is going to take 50-60 seconds of processing time, the SDK socket timeout should be set to be 70 seconds.
May throw InternalDependencyException.
May throw InternalFailure.
May throw ModelError.
May throw ModelNotReadyException.
May throw ServiceUnavailable.
May throw ValidationError.
Parameter body :
Provides input data, in the format specified in the
ContentType request header. Amazon SageMaker AI passes all of
the data in the body to the model.
For information about the format of the request body, see Common Data Formats-Inference.
Parameter endpointName :
The name of the endpoint that you specified when you created the endpoint
using the CreateEndpoint
API.
Parameter accept :
The desired MIME type of the inference response from the model container.
Parameter contentType :
The MIME type of the input data in the request body.
Parameter customAttributes :
Provides additional information about a request for an inference submitted
to a model hosted at an Amazon SageMaker AI endpoint. The information is
an opaque value that is forwarded verbatim. You could use this value, for
example, to provide an ID that you can use to track a request or to
provide other metadata that a service endpoint was programmed to process.
The value must consist of no more than 1024 visible US-ASCII characters as
specified in Section
3.3.6. Field Value Components of the Hypertext Transfer Protocol
(HTTP/1.1).
The code in your model is responsible for setting or updating any custom
attributes in the response. If your code does not set this value in the
response, an empty value is returned. For example, if a custom attribute
represents the trace ID, your model can prepend the custom attribute with
Trace ID: in your post-processing function.
This feature is currently supported in the Amazon Web Services SDKs but not in the Amazon SageMaker AI Python SDK.
Parameter enableExplanations :
An optional JMESPath expression used to override the
EnableExplanations parameter of the
ClarifyExplainerConfig API. See the EnableExplanations
section in the developer guide for more information.
Parameter inferenceComponentName :
If the endpoint hosts one or more inference components, this parameter
specifies the name of inference component to invoke.
Parameter inferenceId :
If you provide a value, it is added to the captured data when you enable
data capture on the endpoint. For information about data capture, see Capture
Data.
Parameter sessionId :
Creates a stateful session or identifies an existing one. You can do one
of the following:
-
Create a stateful session by specifying the value
NEW_SESSION. - Send your request to an existing stateful session by specifying the ID of that session.
NewSessionId response parameter.
For any subsequent request where you specify that session ID, SageMaker AI
routes the request to the same instance that supports the session.
Parameter targetContainerHostname :
If the endpoint hosts multiple containers and is configured to use direct
invocation, this parameter specifies the host name of the container to
invoke.
Parameter targetModel :
The model to request for inference when invoking a multi-model endpoint.
Parameter targetVariant :
Specify the production variant to send the inference request to when
invoking an endpoint that is running two or more variants. Note that this
parameter overrides the default behavior for the endpoint, which is to
distribute the invocation traffic based on the variant weights.
For information about how to use variant targeting to perform a/b testing, see Test models in production
Implementation
Future<InvokeEndpointOutput> invokeEndpoint({
required Uint8List body,
required String endpointName,
String? accept,
String? contentType,
String? customAttributes,
String? enableExplanations,
String? inferenceComponentName,
String? inferenceId,
String? sessionId,
String? targetContainerHostname,
String? targetModel,
String? targetVariant,
}) async {
final headers = <String, String>{
if (accept != null) 'Accept': accept.toString(),
if (contentType != null) 'Content-Type': contentType.toString(),
if (customAttributes != null)
'X-Amzn-SageMaker-Custom-Attributes': customAttributes.toString(),
if (enableExplanations != null)
'X-Amzn-SageMaker-Enable-Explanations': enableExplanations.toString(),
if (inferenceComponentName != null)
'X-Amzn-SageMaker-Inference-Component':
inferenceComponentName.toString(),
if (inferenceId != null)
'X-Amzn-SageMaker-Inference-Id': inferenceId.toString(),
if (sessionId != null)
'X-Amzn-SageMaker-Session-Id': sessionId.toString(),
if (targetContainerHostname != null)
'X-Amzn-SageMaker-Target-Container-Hostname':
targetContainerHostname.toString(),
if (targetModel != null)
'X-Amzn-SageMaker-Target-Model': targetModel.toString(),
if (targetVariant != null)
'X-Amzn-SageMaker-Target-Variant': targetVariant.toString(),
};
final response = await _protocol.sendRaw(
payload: body,
method: 'POST',
requestUri: '/endpoints/${Uri.encodeComponent(endpointName)}/invocations',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return InvokeEndpointOutput(
body: await response.stream.toBytes(),
closedSessionId: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-Closed-Session-Id'),
contentType:
_s.extractHeaderStringValue(response.headers, 'Content-Type'),
customAttributes: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-Custom-Attributes'),
invokedProductionVariant: _s.extractHeaderStringValue(
response.headers, 'x-Amzn-Invoked-Production-Variant'),
newSessionId: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-New-Session-Id'),
);
}