invokeEndpointAsync method
After you deploy a model into production using Amazon SageMaker AI hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint in an asynchronous manner.
Inference requests sent to this API are enqueued for asynchronous processing. The processing of the inference request may or may not complete before you receive a response from this API. The response from this API will not contain the result of the inference request but contain information about where you can locate it.
Amazon SageMaker AI strips all POST headers except those supported by the API. Amazon SageMaker AI might add additional headers. You should not rely on the behavior of headers outside those enumerated in the request syntax.
Calls to InvokeEndpointAsync are authenticated by using
Amazon Web Services Signature Version 4. For information, see Authenticating
Requests (Amazon Web Services Signature Version 4) in the Amazon S3
API Reference.
May throw InternalFailure.
May throw ServiceUnavailable.
May throw ValidationError.
Parameter endpointName :
The name of the endpoint that you specified when you created the endpoint
using the CreateEndpoint
API.
Parameter inputLocation :
The Amazon S3 URI where the inference request payload is stored.
Parameter accept :
The desired MIME type of the inference response from the model container.
Parameter contentType :
The MIME type of the input data in the request body.
Parameter customAttributes :
Provides additional information about a request for an inference submitted
to a model hosted at an Amazon SageMaker AI endpoint. The information is
an opaque value that is forwarded verbatim. You could use this value, for
example, to provide an ID that you can use to track a request or to
provide other metadata that a service endpoint was programmed to process.
The value must consist of no more than 1024 visible US-ASCII characters as
specified in Section
3.3.6. Field Value Components of the Hypertext Transfer Protocol
(HTTP/1.1).
The code in your model is responsible for setting or updating any custom
attributes in the response. If your code does not set this value in the
response, an empty value is returned. For example, if a custom attribute
represents the trace ID, your model can prepend the custom attribute with
Trace ID: in your post-processing function.
This feature is currently supported in the Amazon Web Services SDKs but not in the Amazon SageMaker AI Python SDK.
Parameter filename :
The filename for the inference response payload stored in Amazon S3. If
not specified, Amazon SageMaker AI generates a filename based on the
inference ID.
Parameter inferenceId :
The identifier for the inference request. Amazon SageMaker AI will
generate an identifier for you if none is specified.
Parameter invocationTimeoutSeconds :
Maximum amount of time in seconds a request can be processed before it is
marked as expired. The default is 15 minutes, or 900 seconds.
Parameter requestTTLSeconds :
Maximum age in seconds a request can be in the queue before it is marked
as expired. The default is 6 hours, or 21,600 seconds.
Parameter s3OutputPathExtension :
The path extension that is appended to the Amazon S3 output path where the
inference response payload is stored.
Implementation
Future<InvokeEndpointAsyncOutput> invokeEndpointAsync({
required String endpointName,
required String inputLocation,
String? accept,
String? contentType,
String? customAttributes,
String? filename,
String? inferenceId,
int? invocationTimeoutSeconds,
int? requestTTLSeconds,
String? s3OutputPathExtension,
}) async {
_s.validateNumRange(
'invocationTimeoutSeconds',
invocationTimeoutSeconds,
1,
3600,
);
_s.validateNumRange(
'requestTTLSeconds',
requestTTLSeconds,
60,
21600,
);
final headers = <String, String>{
'X-Amzn-SageMaker-InputLocation': inputLocation.toString(),
if (accept != null) 'X-Amzn-SageMaker-Accept': accept.toString(),
if (contentType != null)
'X-Amzn-SageMaker-Content-Type': contentType.toString(),
if (customAttributes != null)
'X-Amzn-SageMaker-Custom-Attributes': customAttributes.toString(),
if (filename != null) 'X-Amzn-SageMaker-Filename': filename.toString(),
if (inferenceId != null)
'X-Amzn-SageMaker-Inference-Id': inferenceId.toString(),
if (invocationTimeoutSeconds != null)
'X-Amzn-SageMaker-InvocationTimeoutSeconds':
invocationTimeoutSeconds.toString(),
if (requestTTLSeconds != null)
'X-Amzn-SageMaker-RequestTTLSeconds': requestTTLSeconds.toString(),
if (s3OutputPathExtension != null)
'X-Amzn-SageMaker-S3OutputPathExtension':
s3OutputPathExtension.toString(),
};
final response = await _protocol.sendRaw(
payload: null,
method: 'POST',
requestUri:
'/endpoints/${Uri.encodeComponent(endpointName)}/async-invocations',
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return InvokeEndpointAsyncOutput(
inferenceId: $json['InferenceId'] as String?,
failureLocation: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-FailureLocation'),
outputLocation: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-OutputLocation'),
);
}