invokeEndpointWithResponseStream method
Invokes a model at the specified endpoint to return the inference response as a stream. The inference stream provides the response payload incrementally as a series of parts. Before you can get an inference stream, you must have access to a model that's deployed using Amazon SageMaker AI hosting services, and the container for that model must support inference streaming.
For more information that can help you use this API, see the following sections in the Amazon SageMaker AI Developer Guide:
- For information about how to add streaming support to a model, see How Containers Serve Requests.
- For information about how to process the streaming response, see Invoke real-time endpoints.
sagemaker:InvokeEndpoint action. For more information about
Amazon SageMaker AI actions for IAM policies, see Actions,
resources, and condition keys for Amazon SageMaker AI in the IAM
Service Authorization Reference.
Amazon SageMaker AI strips all POST headers except those supported by the API. Amazon SageMaker AI might add additional headers. You should not rely on the behavior of headers outside those enumerated in the request syntax.
Calls to InvokeEndpointWithResponseStream are authenticated
by using Amazon Web Services Signature Version 4. For information, see Authenticating
Requests (Amazon Web Services Signature Version 4) in the Amazon S3
API Reference.
May throw InternalFailure.
May throw InternalStreamFailure.
May throw ModelError.
May throw ModelStreamError.
May throw ServiceUnavailable.
May throw ValidationError.
Parameter body :
Provides input data, in the format specified in the
ContentType request header. Amazon SageMaker AI passes all of
the data in the body to the model.
For information about the format of the request body, see Common Data Formats-Inference.
Parameter endpointName :
The name of the endpoint that you specified when you created the endpoint
using the CreateEndpoint
API.
Parameter accept :
The desired MIME type of the inference response from the model container.
Parameter contentType :
The MIME type of the input data in the request body.
Parameter customAttributes :
Provides additional information about a request for an inference submitted
to a model hosted at an Amazon SageMaker AI endpoint. The information is
an opaque value that is forwarded verbatim. You could use this value, for
example, to provide an ID that you can use to track a request or to
provide other metadata that a service endpoint was programmed to process.
The value must consist of no more than 1024 visible US-ASCII characters as
specified in Section
3.3.6. Field Value Components of the Hypertext Transfer Protocol
(HTTP/1.1).
The code in your model is responsible for setting or updating any custom
attributes in the response. If your code does not set this value in the
response, an empty value is returned. For example, if a custom attribute
represents the trace ID, your model can prepend the custom attribute with
Trace ID: in your post-processing function.
This feature is currently supported in the Amazon Web Services SDKs but not in the Amazon SageMaker AI Python SDK.
Parameter inferenceComponentName :
If the endpoint hosts one or more inference components, this parameter
specifies the name of inference component to invoke for a streaming
response.
Parameter inferenceId :
An identifier that you assign to your request.
Parameter sessionId :
The ID of a stateful session to handle your request.
You can't create a stateful session by using the
InvokeEndpointWithResponseStream action. Instead, you can
create one by using the InvokeEndpoint action. In
your request, you specify NEW_SESSION for the
SessionId request parameter. The response to that request
provides the session ID for the NewSessionId response
parameter.
Parameter targetContainerHostname :
If the endpoint hosts multiple containers and is configured to use direct
invocation, this parameter specifies the host name of the container to
invoke.
Parameter targetVariant :
Specify the production variant to send the inference request to when
invoking an endpoint that is running two or more variants. Note that this
parameter overrides the default behavior for the endpoint, which is to
distribute the invocation traffic based on the variant weights.
For information about how to use variant targeting to perform a/b testing, see Test models in production
Implementation
Future<InvokeEndpointWithResponseStreamOutput>
invokeEndpointWithResponseStream({
required Uint8List body,
required String endpointName,
String? accept,
String? contentType,
String? customAttributes,
String? inferenceComponentName,
String? inferenceId,
String? sessionId,
String? targetContainerHostname,
String? targetVariant,
}) async {
final headers = <String, String>{
if (accept != null) 'X-Amzn-SageMaker-Accept': accept.toString(),
if (contentType != null) 'Content-Type': contentType.toString(),
if (customAttributes != null)
'X-Amzn-SageMaker-Custom-Attributes': customAttributes.toString(),
if (inferenceComponentName != null)
'X-Amzn-SageMaker-Inference-Component':
inferenceComponentName.toString(),
if (inferenceId != null)
'X-Amzn-SageMaker-Inference-Id': inferenceId.toString(),
if (sessionId != null)
'X-Amzn-SageMaker-Session-Id': sessionId.toString(),
if (targetContainerHostname != null)
'X-Amzn-SageMaker-Target-Container-Hostname':
targetContainerHostname.toString(),
if (targetVariant != null)
'X-Amzn-SageMaker-Target-Variant': targetVariant.toString(),
};
final response = await _protocol.sendRaw(
payload: body,
method: 'POST',
requestUri:
'/endpoints/${Uri.encodeComponent(endpointName)}/invocations-response-stream',
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return InvokeEndpointWithResponseStreamOutput(
body: ResponseStream.fromJson($json),
contentType: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-Content-Type'),
customAttributes: _s.extractHeaderStringValue(
response.headers, 'X-Amzn-SageMaker-Custom-Attributes'),
invokedProductionVariant: _s.extractHeaderStringValue(
response.headers, 'x-Amzn-Invoked-Production-Variant'),
);
}