SagemakerEdge class

SageMaker Edge Manager dataplane service for communicating with active agents.

Constructors

SagemakerEdge({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getDeployments({required String deviceFleetName, required String deviceName}) Future<GetDeploymentsResult>
Use to get the active deployments from a device.
getDeviceRegistration({required String deviceFleetName, required String deviceName}) Future<GetDeviceRegistrationResult>
Use to check if a device is registered with SageMaker Edge Manager.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendHeartbeat({required String agentVersion, required String deviceFleetName, required String deviceName, List<EdgeMetric>? agentMetrics, DeploymentResult? deploymentResult, List<Model>? models}) Future<void>
Use to get the current status of devices registered on SageMaker Edge Manager.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited