getDeployments method

Future<GetDeploymentsResult> getDeployments({
  1. required String deviceFleetName,
  2. required String deviceName,
})

Use to get the active deployments from a device.

May throw InternalServiceException.

Parameter deviceFleetName : The name of the fleet that the device belongs to.

Parameter deviceName : The unique name of the device you want to get the configuration of active deployments from.

Implementation

Future<GetDeploymentsResult> getDeployments({
  required String deviceFleetName,
  required String deviceName,
}) async {
  final $payload = <String, dynamic>{
    'DeviceFleetName': deviceFleetName,
    'DeviceName': deviceName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetDeployments',
    exceptionFnMap: _exceptionFns,
  );
  return GetDeploymentsResult.fromJson(response);
}