getDeviceRegistration method

Future<GetDeviceRegistrationResult> getDeviceRegistration({
  1. required String deviceFleetName,
  2. required String deviceName,
})

Use to check if a device is registered with SageMaker Edge Manager.

May throw InternalServiceException.

Parameter deviceFleetName : The name of the fleet that the device belongs to.

Parameter deviceName : The unique name of the device you want to get the registration status from.

Implementation

Future<GetDeviceRegistrationResult> getDeviceRegistration({
  required String deviceFleetName,
  required String deviceName,
}) async {
  final $payload = <String, dynamic>{
    'DeviceFleetName': deviceFleetName,
    'DeviceName': deviceName,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/GetDeviceRegistration',
    exceptionFnMap: _exceptionFns,
  );
  return GetDeviceRegistrationResult.fromJson(response);
}