createSecret method
Creates a new secret. A secret can be a password, a set of credentials such as a user name and password, an OAuth token, or other secret information that you store in an encrypted form in Secrets Manager. The secret also includes the connection information to access a database or other service, which Secrets Manager doesn't encrypt. A secret in Secrets Manager consists of both the protected secret data and the important information needed to manage the secret.
For secrets that use managed rotation, you need to create the secret through the managing service. For more information, see Secrets Manager secrets managed by other Amazon Web Services services.
For information about creating a secret in the console, see Create a secret.
To create a secret, you can provide the secret value to be encrypted in
either the SecretString parameter or the
SecretBinary parameter, but not both. If you include
SecretString or SecretBinary then Secrets
Manager creates an initial secret version and automatically attaches the
staging label AWSCURRENT to it.
For database credentials you want to rotate, for Secrets Manager to be
able to rotate the secret, you must make sure the JSON you store in the
SecretString matches the JSON
structure of a database secret.
If you don't specify an KMS encryption key, Secrets Manager uses the
Amazon Web Services managed key aws/secretsmanager. If this
key doesn't already exist in your account, then Secrets Manager creates it
for you automatically. All users and roles in the Amazon Web Services
account automatically have access to use aws/secretsmanager.
Creating aws/secretsmanager can result in a one-time
significant delay in returning the result.
If the secret is in a different Amazon Web Services account from the
credentials calling the API, then you can't use
aws/secretsmanager to encrypt the secret, and you must create
and use a customer managed KMS key.
Secrets Manager generates a CloudTrail log entry when you call this
action. Do not include sensitive information in request parameters except
SecretBinary or SecretString because it might be
logged. For more information, see Logging
Secrets Manager events with CloudTrail.
Required permissions: secretsmanager:CreateSecret. If
you include tags in the secret, you also need
secretsmanager:TagResource. To add replica Regions, you must
also have secretsmanager:ReplicateSecretToRegions. For more
information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
To encrypt the secret with a KMS key other than
aws/secretsmanager, you need kms:GenerateDataKey
and kms:Decrypt permission to the key.
May throw DecryptionFailure.
May throw EncryptionFailure.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw MalformedPolicyDocumentException.
May throw PreconditionNotMetException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
Parameter name :
The name of the new secret.
The secret name can contain ASCII letters, numbers, and the following characters: /_+=.@-
Do not end your secret name with a hyphen followed by six characters. If you do so, you risk confusion and unexpected results when searching for a secret by partial ARN. Secrets Manager automatically adds a hyphen and six random characters after the secret name at the end of the ARN.
Parameter addReplicaRegions :
A list of Regions and KMS keys to replicate secrets.
Parameter clientRequestToken :
If you include SecretString or SecretBinary,
then Secrets Manager creates an initial version for the secret, and this
parameter specifies the unique identifier for the new version.
If you generate a raw HTTP request to the Secrets Manager service
endpoint, then you must generate a ClientRequestToken and
include it in the request.
This value helps ensure idempotency. Secrets Manager uses this value to prevent the accidental creation of duplicate versions if there are failures and retries during a rotation. We recommend that you generate a UUID-type value to ensure uniqueness of your versions within the specified secret.
-
If the
ClientRequestTokenvalue isn't already associated with a version of the secret then a new version of the secret is created. -
If a version with this value already exists and the version
SecretStringandSecretBinaryvalues are the same as those in the request, then the request is ignored. -
If a version with this value already exists and that version's
SecretStringandSecretBinaryvalues are different from those in the request, then the request fails because you cannot modify an existing version. Instead, use PutSecretValue to create a new version.
VersionId of the new version.
Parameter description :
The description of the secret.
Parameter forceOverwriteReplicaSecret :
Specifies whether to overwrite a secret with the same name in the
destination Region. By default, secrets aren't overwritten.
Parameter kmsKeyId :
The ARN, key ID, or alias of the KMS key that Secrets Manager uses to
encrypt the secret value in the secret. An alias is always prefixed by
alias/, for example alias/aws/secretsmanager.
For more information, see About
aliases.
To use a KMS key in a different account, use the key ARN or the alias ARN.
If you don't specify this value, then Secrets Manager uses the key
aws/secretsmanager. If that key doesn't yet exist, then
Secrets Manager creates it for you automatically the first time it
encrypts the secret value.
If the secret is in a different Amazon Web Services account from the
credentials calling the API, then you can't use
aws/secretsmanager to encrypt the secret, and you must create
and use a customer managed KMS key.
Parameter secretBinary :
The binary data to encrypt and store in the new version of the secret. We
recommend that you store your binary data in a file and then pass the
contents of the file as a parameter.
Either SecretString or SecretBinary must have a
value, but not both.
This parameter is not available in the Secrets Manager console.
Sensitive: This field contains sensitive information, so the service does not include it in CloudTrail log entries. If you create your own log entries, you must also avoid logging the information in this field.
Parameter secretString :
The text data to encrypt and store in this new version of the secret. We
recommend you use a JSON structure of key/value pairs for your secret
value.
Either SecretString or SecretBinary must have a
value, but not both.
If you create a secret by using the Secrets Manager console then Secrets
Manager puts the protected secret text in only the
SecretString parameter. The Secrets Manager console stores
the information as a JSON structure of key/value pairs that a Lambda
rotation function can parse.
Sensitive: This field contains sensitive information, so the service does not include it in CloudTrail log entries. If you create your own log entries, you must also avoid logging the information in this field.
Parameter tags :
A list of tags to attach to the secret. Each tag is a key and value pair
of strings in a JSON text string, for example:
[{"Key":"CostCenter","Value":"12345"},{"Key":"environment","Value":"production"}]
Secrets Manager tag key names are case sensitive. A tag with the key "ABC" is a different tag from one with key "abc".
If you check tags in permissions policies as part of your security
strategy, then adding or removing a tag can change permissions. If the
completion of this operation would result in you losing your permissions
for this secret, then Secrets Manager blocks the operation and returns an
Access Denied error. For more information, see Control
access to secrets using tags and Limit
access to identities with tags that match secrets' tags.
For information about how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters. If your command-line tool or SDK requires quotation marks around the parameter, you should use single quotes to avoid confusion with the double quotes required in the JSON text.
For tag quotas and naming restrictions, see Service quotas for Tagging in the Amazon Web Services General Reference guide.
Parameter type :
The exact string that identifies the partner that holds the external
secret. For more information, see Using
Secrets Manager managed external secrets.
Implementation
Future<CreateSecretResponse> createSecret({
required String name,
List<ReplicaRegionType>? addReplicaRegions,
String? clientRequestToken,
String? description,
bool? forceOverwriteReplicaSecret,
String? kmsKeyId,
Uint8List? secretBinary,
String? secretString,
List<Tag>? tags,
String? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.CreateSecret'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (addReplicaRegions != null) 'AddReplicaRegions': addReplicaRegions,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (forceOverwriteReplicaSecret != null)
'ForceOverwriteReplicaSecret': forceOverwriteReplicaSecret,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (secretBinary != null) 'SecretBinary': base64Encode(secretBinary),
if (secretString != null) 'SecretString': secretString,
if (tags != null) 'Tags': tags,
if (type != null) 'Type': type,
},
);
return CreateSecretResponse.fromJson(jsonResponse.body);
}