listSecrets method
Lists the secrets that are stored by Secrets Manager in the Amazon Web Services account, not including secrets that are marked for deletion. To see secrets marked for deletion, use the Secrets Manager console.
All Secrets Manager operations are eventually consistent. ListSecrets might not reflect changes from the last five minutes. You can get more recent information for a specific secret by calling DescribeSecret.
To list the versions of a secret, use ListSecretVersionIds.
To retrieve the values for the secrets, call BatchGetSecretValue or GetSecretValue.
For information about finding secrets in the console, see Find secrets in Secrets Manager.
Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions: secretsmanager:ListSecrets. For
more information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw InvalidRequestException.
Parameter filters :
The filters to apply to the list of secrets.
Parameter includePlannedDeletion :
Specifies whether to include secrets scheduled for deletion. By default,
secrets scheduled for deletion aren't included.
Parameter maxResults :
The number of results to include in the response.
If there are more results available, in the response, Secrets Manager
includes NextToken. To get the next results, call
ListSecrets again with the value from NextToken.
Parameter nextToken :
A token that indicates where the output should continue from, if a
previous call did not show all results. To get the next results, call
ListSecrets again with this value.
Parameter sortBy :
If not specified, secrets are listed by CreatedDate.
Parameter sortOrder :
Secrets are listed by CreatedDate.
Implementation
Future<ListSecretsResponse> listSecrets({
List<Filter>? filters,
bool? includePlannedDeletion,
int? maxResults,
String? nextToken,
SortByType? sortBy,
SortOrderType? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.ListSecrets'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (includePlannedDeletion != null)
'IncludePlannedDeletion': includePlannedDeletion,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
if (sortOrder != null) 'SortOrder': sortOrder.value,
},
);
return ListSecretsResponse.fromJson(jsonResponse.body);
}