removeRegionsFromReplication method

Future<RemoveRegionsFromReplicationResponse> removeRegionsFromReplication({
  1. required List<String> removeReplicaRegions,
  2. required String secretId,
})

For a secret that is replicated to other Regions, deletes the secret replicas from the Regions you specify.

Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.

Required permissions: secretsmanager:RemoveRegionsFromReplication. For more information, see IAM policy actions for Secrets Manager and Authentication and access control in Secrets Manager.

May throw InternalServiceError. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter removeReplicaRegions : The Regions of the replicas to remove.

Parameter secretId : The ARN or name of the secret.

Implementation

Future<RemoveRegionsFromReplicationResponse> removeRegionsFromReplication({
  required List<String> removeReplicaRegions,
  required String secretId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'secretsmanager.RemoveRegionsFromReplication'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RemoveReplicaRegions': removeReplicaRegions,
      'SecretId': secretId,
    },
  );

  return RemoveRegionsFromReplicationResponse.fromJson(jsonResponse.body);
}