restoreSecret method
Cancels the scheduled deletion of a secret by removing the
DeletedDate time stamp. You can access a secret again after
it has been restored.
Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions: secretsmanager:RestoreSecret.
For more information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter secretId :
The ARN or name of the secret to restore.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Implementation
Future<RestoreSecretResponse> restoreSecret({
required String secretId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.RestoreSecret'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
},
);
return RestoreSecretResponse.fromJson(jsonResponse.body);
}