stopReplicationToReplica method

Future<StopReplicationToReplicaResponse> stopReplicationToReplica({
  1. required String secretId,
})

Removes the link between the replica secret and the primary secret and promotes the replica to a primary secret in the replica Region.

You must call this operation from the Region in which you want to promote the replica to a primary secret.

Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.

Required permissions: secretsmanager:StopReplicationToReplica. For more information, see IAM policy actions for Secrets Manager and Authentication and access control in Secrets Manager.

May throw InternalServiceError. May throw InvalidParameterException. May throw InvalidRequestException. May throw ResourceNotFoundException.

Parameter secretId : The name of the secret or the replica ARN. The replica ARN is the same as the original primary secret ARN expect the Region is changed to the replica Region.

Implementation

Future<StopReplicationToReplicaResponse> stopReplicationToReplica({
  required String secretId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'secretsmanager.StopReplicationToReplica'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'SecretId': secretId,
    },
  );

  return StopReplicationToReplicaResponse.fromJson(jsonResponse.body);
}