updateSecret method
Modifies the details of a secret, including metadata and the secret value. To change the secret value, you can also use PutSecretValue.
To change the rotation configuration of a secret, use RotateSecret instead.
To change a secret so that it is managed by another service, you need to recreate the secret in that service. See Secrets Manager secrets managed by other Amazon Web Services services.
We recommend you avoid calling UpdateSecret at a sustained
rate of more than once every 10 minutes. When you call
UpdateSecret to update the secret value, Secrets Manager
creates a new version of the secret. Secrets Manager removes outdated
versions when there are more than 100, but it does not remove versions
created less than 24 hours ago. If you update the secret value more than
once every 10 minutes, you create more versions than Secrets Manager
removes, and you will reach the quota for secret versions.
If you include SecretString or SecretBinary to
create a new secret version, Secrets Manager automatically moves the
staging label AWSCURRENT to the new version. Then it attaches
the label AWSPREVIOUS to the version that
AWSCURRENT was removed from.
If you call this operation with a ClientRequestToken that
matches an existing version's VersionId, the operation
results in an error. You can't modify an existing version, you can only
create a new version. To remove a version, remove all staging labels from
it. See UpdateSecretVersionStage.
Secrets Manager generates a CloudTrail log entry when you call this
action. Do not include sensitive information in request parameters except
SecretBinary or SecretString because it might be
logged. For more information, see Logging
Secrets Manager events with CloudTrail.
Required permissions: secretsmanager:UpdateSecret.
For more information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager. If you use a customer managed
key, you must also have kms:GenerateDataKey,
kms:Encrypt, and kms:Decrypt permissions on the
key. If you change the KMS key and you don't have kms:Encrypt
permission to the new key, Secrets Manager does not re-encrypt existing
secret versions with the new key. For more information, see
Secret encryption and decryption.
May throw DecryptionFailure.
May throw EncryptionFailure.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw MalformedPolicyDocumentException.
May throw PreconditionNotMetException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
Parameter secretId :
The ARN or name of the secret.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Parameter clientRequestToken :
If you include SecretString or SecretBinary,
then Secrets Manager creates a new version for the secret, and this
parameter specifies the unique identifier for the new version.
If you generate a raw HTTP request to the Secrets Manager service
endpoint, then you must generate a ClientRequestToken and
include it in the request.
This value helps ensure idempotency. Secrets Manager uses this value to prevent the accidental creation of duplicate versions if there are failures and retries during a rotation. We recommend that you generate a UUID-type value to ensure uniqueness of your versions within the specified secret.
Parameter description :
The description of the secret.
Parameter kmsKeyId :
The ARN, key ID, or alias of the KMS key that Secrets Manager uses to
encrypt new secret versions as well as any existing versions with the
staging labels AWSCURRENT, AWSPENDING, or
AWSPREVIOUS. If you don't have kms:Encrypt
permission to the new key, Secrets Manager does not re-encrypt existing
secret versions with the new key. For more information about versions and
staging labels, see Concepts:
Version.
A key alias is always prefixed by alias/, for example
alias/aws/secretsmanager. For more information, see About
aliases.
If you set this to an empty string, Secrets Manager uses the Amazon Web
Services managed key aws/secretsmanager. If this key doesn't
already exist in your account, then Secrets Manager creates it for you
automatically. All users and roles in the Amazon Web Services account
automatically have access to use aws/secretsmanager. Creating
aws/secretsmanager can result in a one-time significant delay
in returning the result.
Parameter secretBinary :
The binary data to encrypt and store in the new version of the secret. We
recommend that you store your binary data in a file and then pass the
contents of the file as a parameter.
Either SecretBinary or SecretString must have a
value, but not both.
You can't access this parameter in the Secrets Manager console.
Sensitive: This field contains sensitive information, so the service does not include it in CloudTrail log entries. If you create your own log entries, you must also avoid logging the information in this field.
Parameter secretString :
The text data to encrypt and store in the new version of the secret. We
recommend you use a JSON structure of key/value pairs for your secret
value.
Either SecretBinary or SecretString must have a
value, but not both.
Sensitive: This field contains sensitive information, so the service does not include it in CloudTrail log entries. If you create your own log entries, you must also avoid logging the information in this field.
Parameter type :
The exact string that identifies the third-party partner that holds the
external secret. For more information, see Managed
external secret partners.
Implementation
Future<UpdateSecretResponse> updateSecret({
required String secretId,
String? clientRequestToken,
String? description,
String? kmsKeyId,
Uint8List? secretBinary,
String? secretString,
String? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.UpdateSecret'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (secretBinary != null) 'SecretBinary': base64Encode(secretBinary),
if (secretString != null) 'SecretString': secretString,
if (type != null) 'Type': type,
},
);
return UpdateSecretResponse.fromJson(jsonResponse.body);
}