updateSecretVersionStage method
Modifies the staging labels attached to a version of a secret. Secrets Manager uses staging labels to track a version as it progresses through the secret rotation process. Each staging label can be attached to only one version at a time. To add a staging label to a version when it is already attached to another version, Secrets Manager first removes it from the other version first and then attaches it to this one. For more information about versions and staging labels, see Concepts: Version.
The staging labels that you specify in the VersionStage
parameter are added to the existing list of staging labels for the
version.
You can move the AWSCURRENT staging label to this version by
including it in this call.
If this action results in the last label being removed from a version,
then the version is considered to be 'deprecated' and can be deleted by
Secrets Manager.
Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions:
secretsmanager:UpdateSecretVersionStage. For more
information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter secretId :
The ARN or the name of the secret with the version and staging labelsto
modify.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Parameter versionStage :
The staging label to add to this version.
Parameter moveToVersionId :
The ID of the version to add the staging label to. To remove a label from
a version, then do not specify this parameter.
If the staging label is already attached to a different version of the
secret, then you must also specify the RemoveFromVersionId
parameter.
Parameter removeFromVersionId :
The ID of the version that the staging label is to be removed from. If the
staging label you are trying to attach to one version is already attached
to a different version, then you must include this parameter and specify
the version that the label is to be removed from. If the label is attached
and you either do not specify this parameter, or the version ID does not
match, then the operation fails.
Implementation
Future<UpdateSecretVersionStageResponse> updateSecretVersionStage({
required String secretId,
required String versionStage,
String? moveToVersionId,
String? removeFromVersionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.UpdateSecretVersionStage'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
'VersionStage': versionStage,
if (moveToVersionId != null) 'MoveToVersionId': moveToVersionId,
if (removeFromVersionId != null)
'RemoveFromVersionId': removeFromVersionId,
},
);
return UpdateSecretVersionStageResponse.fromJson(jsonResponse.body);
}