batchDeleteCodeReviews method
Deletes one or more code reviews from an agent space.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the code reviews to
delete.
Parameter codeReviewIds :
The list of code review identifiers to delete.
Implementation
Future<BatchDeleteCodeReviewsOutput> batchDeleteCodeReviews({
required String agentSpaceId,
required List<String> codeReviewIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'codeReviewIds': codeReviewIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchDeleteCodeReviews',
exceptionFnMap: _exceptionFns,
);
return BatchDeleteCodeReviewsOutput.fromJson(response);
}