batchDeletePentests method

Future<BatchDeletePentestsOutput> batchDeletePentests({
  1. required String agentSpaceId,
  2. required List<String> pentestIds,
})

Deletes one or more pentests from an agent space.

Parameter agentSpaceId : The unique identifier of the agent space that contains the pentests to delete.

Parameter pentestIds : The list of pentest identifiers to delete.

Implementation

Future<BatchDeletePentestsOutput> batchDeletePentests({
  required String agentSpaceId,
  required List<String> pentestIds,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'pentestIds': pentestIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/BatchDeletePentests',
    exceptionFnMap: _exceptionFns,
  );
  return BatchDeletePentestsOutput.fromJson(response);
}