batchGetArtifactMetadata method

Future<BatchGetArtifactMetadataOutput> batchGetArtifactMetadata({
  1. required String agentSpaceId,
  2. required List<String> artifactIds,
})

Retrieves metadata for one or more artifacts in an agent space.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter agentSpaceId : The unique identifier of the agent space that contains the artifacts.

Parameter artifactIds : The list of artifact identifiers to retrieve metadata for.

Implementation

Future<BatchGetArtifactMetadataOutput> batchGetArtifactMetadata({
  required String agentSpaceId,
  required List<String> artifactIds,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'artifactIds': artifactIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/BatchGetArtifactMetadata',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetArtifactMetadataOutput.fromJson(response);
}