batchGetCodeReviews method

Future<BatchGetCodeReviewsOutput> batchGetCodeReviews({
  1. required String agentSpaceId,
  2. required List<String> codeReviewIds,
})

Retrieves information about one or more code reviews in an agent space.

Parameter agentSpaceId : The unique identifier of the agent space that contains the code reviews.

Parameter codeReviewIds : The list of code review identifiers to retrieve.

Implementation

Future<BatchGetCodeReviewsOutput> batchGetCodeReviews({
  required String agentSpaceId,
  required List<String> codeReviewIds,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'codeReviewIds': codeReviewIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/BatchGetCodeReviews',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetCodeReviewsOutput.fromJson(response);
}