batchGetFindings method

Future<BatchGetFindingsOutput> batchGetFindings({
  1. required String agentSpaceId,
  2. required List<String> findingIds,
})

Retrieves information about one or more security findings in an agent space.

Parameter agentSpaceId : The unique identifier of the agent space that contains the findings.

Parameter findingIds : The list of finding identifiers to retrieve.

Implementation

Future<BatchGetFindingsOutput> batchGetFindings({
  required String agentSpaceId,
  required List<String> findingIds,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'findingIds': findingIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/BatchGetFindings',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetFindingsOutput.fromJson(response);
}