batchGetPentestJobs method

Future<BatchGetPentestJobsOutput> batchGetPentestJobs({
  1. required String agentSpaceId,
  2. required List<String> pentestJobIds,
})

Retrieves information about one or more pentest jobs in an agent space.

Parameter agentSpaceId : The unique identifier of the agent space that contains the pentest jobs.

Parameter pentestJobIds : The list of pentest job identifiers to retrieve.

Implementation

Future<BatchGetPentestJobsOutput> batchGetPentestJobs({
  required String agentSpaceId,
  required List<String> pentestJobIds,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'pentestJobIds': pentestJobIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/BatchGetPentestJobs',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetPentestJobsOutput.fromJson(response);
}