createApplication method

Future<CreateApplicationResponse> createApplication({
  1. String? defaultKmsKeyId,
  2. String? idcInstanceArn,
  3. String? roleArn,
  4. Map<String, String>? tags,
})

Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.

Parameter defaultKmsKeyId : The identifier of the default AWS KMS key to use for encrypting data in the application.

Parameter idcInstanceArn : The Amazon Resource Name (ARN) of the IAM Identity Center instance to associate with the application.

Parameter roleArn : The Amazon Resource Name (ARN) of the IAM role to associate with the application.

Parameter tags : The tags to associate with the application.

Implementation

Future<CreateApplicationResponse> createApplication({
  String? defaultKmsKeyId,
  String? idcInstanceArn,
  String? roleArn,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    if (defaultKmsKeyId != null) 'defaultKmsKeyId': defaultKmsKeyId,
    if (idcInstanceArn != null) 'idcInstanceArn': idcInstanceArn,
    if (roleArn != null) 'roleArn': roleArn,
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/CreateApplication',
    exceptionFnMap: _exceptionFns,
  );
  return CreateApplicationResponse.fromJson(response);
}