deleteTargetDomain method
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
Parameter targetDomainId :
The unique identifier of the target domain to delete.
Implementation
Future<DeleteTargetDomainOutput> deleteTargetDomain({
required String targetDomainId,
}) async {
final $payload = <String, dynamic>{
'targetDomainId': targetDomainId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteTargetDomain',
exceptionFnMap: _exceptionFns,
);
return DeleteTargetDomainOutput.fromJson(response);
}