listCodeReviewJobTasks method

Future<ListCodeReviewJobTasksOutput> listCodeReviewJobTasks({
  1. required String agentSpaceId,
  2. String? categoryName,
  3. String? codeReviewJobId,
  4. int? maxResults,
  5. String? nextToken,
  6. StepName? stepName,
})

Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.

Parameter agentSpaceId : The unique identifier of the agent space.

Parameter categoryName : Filter tasks by category name.

Parameter codeReviewJobId : The unique identifier of the code review job to list tasks for.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Parameter stepName : Filter tasks by step name.

Implementation

Future<ListCodeReviewJobTasksOutput> listCodeReviewJobTasks({
  required String agentSpaceId,
  String? categoryName,
  String? codeReviewJobId,
  int? maxResults,
  String? nextToken,
  StepName? stepName,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    if (categoryName != null) 'categoryName': categoryName,
    if (codeReviewJobId != null) 'codeReviewJobId': codeReviewJobId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (stepName != null) 'stepName': stepName.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListCodeReviewJobTasks',
    exceptionFnMap: _exceptionFns,
  );
  return ListCodeReviewJobTasksOutput.fromJson(response);
}