listCodeReviewJobsForCodeReview method

Future<ListCodeReviewJobsForCodeReviewOutput> listCodeReviewJobsForCodeReview({
  1. required String agentSpaceId,
  2. required String codeReviewId,
  3. int? maxResults,
  4. String? nextToken,
})

Returns a paginated list of code review job summaries for the specified code review configuration.

Parameter agentSpaceId : The unique identifier of the agent space.

Parameter codeReviewId : The unique identifier of the code review to list jobs for.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Implementation

Future<ListCodeReviewJobsForCodeReviewOutput>
    listCodeReviewJobsForCodeReview({
  required String agentSpaceId,
  required String codeReviewId,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'codeReviewId': codeReviewId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListCodeReviewJobsForCodeReview',
    exceptionFnMap: _exceptionFns,
  );
  return ListCodeReviewJobsForCodeReviewOutput.fromJson(response);
}