listCodeReviews method

Future<ListCodeReviewsOutput> listCodeReviews({
  1. required String agentSpaceId,
  2. int? maxResults,
  3. String? nextToken,
})

Returns a paginated list of code review summaries for the specified agent space.

Parameter agentSpaceId : The unique identifier of the agent space to list code reviews for.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Implementation

Future<ListCodeReviewsOutput> listCodeReviews({
  required String agentSpaceId,
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListCodeReviews',
    exceptionFnMap: _exceptionFns,
  );
  return ListCodeReviewsOutput.fromJson(response);
}