listDiscoveredEndpoints method

Future<ListDiscoveredEndpointsOutput> listDiscoveredEndpoints({
  1. required String agentSpaceId,
  2. required String pentestJobId,
  3. int? maxResults,
  4. String? nextToken,
  5. String? prefix,
})

Returns a paginated list of endpoints discovered during a pentest job execution.

Parameter agentSpaceId : The unique identifier of the agent space.

Parameter pentestJobId : The unique identifier of the pentest job to list discovered endpoints for.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Parameter prefix : A prefix to filter discovered endpoints by URI.

Implementation

Future<ListDiscoveredEndpointsOutput> listDiscoveredEndpoints({
  required String agentSpaceId,
  required String pentestJobId,
  int? maxResults,
  String? nextToken,
  String? prefix,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'pentestJobId': pentestJobId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (prefix != null) 'prefix': prefix,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListDiscoveredEndpoints',
    exceptionFnMap: _exceptionFns,
  );
  return ListDiscoveredEndpointsOutput.fromJson(response);
}