listIntegratedResources method

Future<ListIntegratedResourcesOutput> listIntegratedResources({
  1. required String agentSpaceId,
  2. String? integrationId,
  3. int? maxResults,
  4. String? nextToken,
  5. ResourceType? resourceType,
})

Lists the integrated resources for an agent space, optionally filtered by integration or resource type.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter agentSpaceId : The unique identifier of the agent space to list integrated resources for.

Parameter integrationId : The unique identifier of the integration to filter by.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Parameter resourceType : The type of resource to filter by.

Implementation

Future<ListIntegratedResourcesOutput> listIntegratedResources({
  required String agentSpaceId,
  String? integrationId,
  int? maxResults,
  String? nextToken,
  ResourceType? resourceType,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    if (integrationId != null) 'integrationId': integrationId,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (resourceType != null) 'resourceType': resourceType.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListIntegratedResources',
    exceptionFnMap: _exceptionFns,
  );
  return ListIntegratedResourcesOutput.fromJson(response);
}