listIntegrations method
Lists the integrations in your account, optionally filtered by provider or provider type.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
A filter to apply to the list of integrations.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request. For
subsequent calls, use the nextToken value returned from the previous
request.
Implementation
Future<ListIntegrationsOutput> listIntegrations({
IntegrationFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListIntegrations',
exceptionFnMap: _exceptionFns,
);
return ListIntegrationsOutput.fromJson(response);
}