listPentestJobsForPentest method
Returns a paginated list of pentest job summaries for the specified pentest configuration.
Parameter agentSpaceId :
The unique identifier of the agent space.
Parameter pentestId :
The unique identifier of the pentest to list jobs for.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request. For
subsequent calls, use the nextToken value returned from the previous
request.
Implementation
Future<ListPentestJobsForPentestOutput> listPentestJobsForPentest({
required String agentSpaceId,
required String pentestId,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'pentestId': pentestId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListPentestJobsForPentest',
exceptionFnMap: _exceptionFns,
);
return ListPentestJobsForPentestOutput.fromJson(response);
}