listTargetDomains method

Future<ListTargetDomainsOutput> listTargetDomains({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a paginated list of target domain summaries in your account.

Parameter maxResults : The maximum number of results to return in a single call.

Parameter nextToken : A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Implementation

Future<ListTargetDomainsOutput> listTargetDomains({
  int? maxResults,
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListTargetDomains',
    exceptionFnMap: _exceptionFns,
  );
  return ListTargetDomainsOutput.fromJson(response);
}