startCodeReviewJob method

Future<StartCodeReviewJobOutput> startCodeReviewJob({
  1. required String agentSpaceId,
  2. required String codeReviewId,
})

Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.

Parameter agentSpaceId : The unique identifier of the agent space.

Parameter codeReviewId : The unique identifier of the code review to start a job for.

Implementation

Future<StartCodeReviewJobOutput> startCodeReviewJob({
  required String agentSpaceId,
  required String codeReviewId,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'codeReviewId': codeReviewId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/StartCodeReviewJob',
    exceptionFnMap: _exceptionFns,
  );
  return StartCodeReviewJobOutput.fromJson(response);
}