stopCodeReviewJob method
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
Parameter agentSpaceId :
The unique identifier of the agent space.
Parameter codeReviewJobId :
The unique identifier of the code review job to stop.
Implementation
Future<void> stopCodeReviewJob({
required String agentSpaceId,
required String codeReviewJobId,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'codeReviewJobId': codeReviewJobId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StopCodeReviewJob',
exceptionFnMap: _exceptionFns,
);
}