stopPentestJob method

Future<void> stopPentestJob({
  1. required String agentSpaceId,
  2. required String pentestJobId,
})

Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.

Parameter agentSpaceId : The unique identifier of the agent space.

Parameter pentestJobId : The unique identifier of the pentest job to stop.

Implementation

Future<void> stopPentestJob({
  required String agentSpaceId,
  required String pentestJobId,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'pentestJobId': pentestJobId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/StopPentestJob',
    exceptionFnMap: _exceptionFns,
  );
}