updateCodeReview method

Future<UpdateCodeReviewOutput> updateCodeReview({
  1. required String agentSpaceId,
  2. required String codeReviewId,
  3. Assets? assets,
  4. CodeRemediationStrategy? codeRemediationStrategy,
  5. CloudWatchLog? logConfig,
  6. String? serviceRole,
  7. String? title,
})

Updates an existing code review configuration.

Parameter agentSpaceId : The unique identifier of the agent space that contains the code review.

Parameter codeReviewId : The unique identifier of the code review to update.

Parameter assets : The updated assets for the code review.

Parameter codeRemediationStrategy : The updated code remediation strategy for the code review.

Parameter logConfig : The updated CloudWatch Logs configuration for the code review.

Parameter serviceRole : The updated IAM service role for the code review.

Parameter title : The updated title of the code review.

Implementation

Future<UpdateCodeReviewOutput> updateCodeReview({
  required String agentSpaceId,
  required String codeReviewId,
  Assets? assets,
  CodeRemediationStrategy? codeRemediationStrategy,
  CloudWatchLog? logConfig,
  String? serviceRole,
  String? title,
}) async {
  final $payload = <String, dynamic>{
    'agentSpaceId': agentSpaceId,
    'codeReviewId': codeReviewId,
    if (assets != null) 'assets': assets,
    if (codeRemediationStrategy != null)
      'codeRemediationStrategy': codeRemediationStrategy.value,
    if (logConfig != null) 'logConfig': logConfig,
    if (serviceRole != null) 'serviceRole': serviceRole,
    if (title != null) 'title': title,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/UpdateCodeReview',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateCodeReviewOutput.fromJson(response);
}