verifyTargetDomain method

Future<VerifyTargetDomainOutput> verifyTargetDomain({
  1. required String targetDomainId,
})

Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.

Parameter targetDomainId : The unique identifier of the target domain to verify.

Implementation

Future<VerifyTargetDomainOutput> verifyTargetDomain({
  required String targetDomainId,
}) async {
  final $payload = <String, dynamic>{
    'targetDomainId': targetDomainId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/VerifyTargetDomain',
    exceptionFnMap: _exceptionFns,
  );
  return VerifyTargetDomainOutput.fromJson(response);
}