SecurityHub class

Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.

Security Hub CSPM collects security data across Amazon Web Services accounts, Amazon Web Services services, and supported third-party products and helps you analyze your security trends and identify the highest priority security issues.

To help you manage the security state of your organization, Security Hub CSPM supports multiple security standards. These include the Amazon Web Services Foundational Security Best Practices (FSBP) standard developed by Amazon Web Services, and external compliance frameworks such as the Center for Internet Security (CIS), the Payment Card Industry Data Security Standard (PCI DSS), and the National Institute of Standards and Technology (NIST). Each standard includes several security controls, each of which represents a security best practice. Security Hub CSPM runs checks against security controls and generates control findings to help you assess your compliance against security best practices.

In addition to generating control findings, Security Hub CSPM also receives findings from other Amazon Web Services services, such as Amazon GuardDuty and Amazon Inspector, and supported third-party products. This gives you a single pane of glass into a variety of security-related issues. You can also send Security Hub CSPM findings to other Amazon Web Services services and supported third-party products.

Security Hub CSPM offers automation features that help you triage and remediate security issues. For example, you can use automation rules to automatically update critical findings when a security check fails. You can also leverage the integration with Amazon EventBridge to trigger automatic responses to specific findings.

This guide, the Security Hub CSPM API Reference, provides information about the Security Hub CSPM API. This includes supported resources, HTTP methods, parameters, and schemas. If you're new to Security Hub CSPM, you might find it helpful to also review the Security Hub CSPM User Guide . The user guide explains key concepts and provides procedures that demonstrate how to use Security Hub CSPM features. It also provides information about topics such as integrating Security Hub CSPM with other Amazon Web Services services.

In addition to interacting with Security Hub CSPM by making calls to the Security Hub CSPM API, you can use a current version of an Amazon Web Services command line tool or SDK. Amazon Web Services provides tools and SDKs that consist of libraries and sample code for various languages and platforms, such as PowerShell, Java, Go, Python, C++, and .NET. These tools and SDKs provide convenient, programmatic access to Security Hub CSPM and other Amazon Web Services services . They also handle tasks such as signing requests, managing errors, and retrying requests automatically. For information about installing and using the Amazon Web Services tools and SDKs, see Tools to Build on Amazon Web Services.

With the exception of operations that are related to central configuration, Security Hub CSPM API requests are executed only in the Amazon Web Services Region that is currently active or in the specific Amazon Web Services Region that you specify in your request. Any configuration or settings change that results from the operation is applied only to that Region. To make the same change in other Regions, call the same API operation in each Region in which you want to apply the change. When you use central configuration, API requests for enabling Security Hub CSPM, standards, and controls are executed in the home Region and all linked Regions. For a list of central configuration operations, see the Central configuration terms and concepts section of the Security Hub CSPM User Guide.

The following throttling limits apply to Security Hub CSPM API operations.

  • BatchEnableStandards - RateLimit of 1 request per second. BurstLimit of 1 request per second.
  • GetFindings - RateLimit of 3 requests per second. BurstLimit of 6 requests per second.
  • BatchImportFindings - RateLimit of 10 requests per second. BurstLimit of 30 requests per second.
  • BatchUpdateFindings - RateLimit of 10 requests per second. BurstLimit of 30 requests per second.
  • UpdateStandardsControl - RateLimit of 1 request per second. BurstLimit of 5 requests per second.
  • All other operations - RateLimit of 10 requests per second. BurstLimit of 30 requests per second.

Constructors

SecurityHub({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptAdministratorInvitation({required String administratorId, required String invitationId}) Future<void>
This operation is only used by member accounts that are not added through Organizations.
acceptInvitation({required String invitationId, required String masterId}) Future<void>
This method is deprecated. Instead, use AcceptAdministratorInvitation.
batchDeleteAutomationRules({required List<String> automationRulesArns}) Future<BatchDeleteAutomationRulesResponse>
Deletes one or more automation rules.
batchDisableStandards({required List<String> standardsSubscriptionArns}) Future<BatchDisableStandardsResponse>
Disables the standards specified by the provided StandardsSubscriptionArns.
batchEnableStandards({required List<StandardsSubscriptionRequest> standardsSubscriptionRequests}) Future<BatchEnableStandardsResponse>
Enables the standards specified by the provided StandardsArn. To obtain the ARN for a standard, use the DescribeStandards operation.
batchGetAutomationRules({required List<String> automationRulesArns}) Future<BatchGetAutomationRulesResponse>
Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).
batchGetConfigurationPolicyAssociations({required List<ConfigurationPolicyAssociation> configurationPolicyAssociationIdentifiers}) Future<BatchGetConfigurationPolicyAssociationsResponse>
Returns associations between an Security Hub CSPM configuration and a batch of target accounts, organizational units, or the root. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region. A configuration can refer to a configuration policy or to a self-managed configuration.
batchGetSecurityControls({required List<String> securityControlIds}) Future<BatchGetSecurityControlsResponse>
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region.
batchGetStandardsControlAssociations({required List<StandardsControlAssociationId> standardsControlAssociationIds}) Future<BatchGetStandardsControlAssociationsResponse>
For a batch of security controls and standards, identifies whether each control is currently enabled or disabled in a standard.
batchImportFindings({required List<AwsSecurityFinding> findings}) Future<BatchImportFindingsResponse>
Imports security findings generated by a finding provider into Security Hub CSPM. This action is requested by the finding provider to import its findings into Security Hub CSPM.
batchUpdateAutomationRules({required List<UpdateAutomationRulesRequestItem> updateAutomationRulesRequestItems}) Future<BatchUpdateAutomationRulesResponse>
Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.
batchUpdateFindings({required List<AwsSecurityFindingIdentifier> findingIdentifiers, int? confidence, int? criticality, NoteUpdate? note, List<RelatedFinding>? relatedFindings, SeverityUpdate? severity, List<String>? types, Map<String, String>? userDefinedFields, VerificationState? verificationState, WorkflowUpdate? workflow}) Future<BatchUpdateFindingsResponse>
Used by Security Hub CSPM customers to update information about their investigation into one or more findings. Requested by administrator accounts or member accounts. Administrator accounts can update findings for their account and their member accounts. A member account can update findings only for their own account. Administrator and member accounts can use this operation to update the following fields and objects for one or more findings:
batchUpdateFindingsV2({String? comment, List<OcsfFindingIdentifier>? findingIdentifiers, List<String>? metadataUids, int? severityId, int? statusId}) Future<BatchUpdateFindingsV2Response>
Updates information about a customer's investigation into a finding. Delegated administrator accounts can update findings for their account and their member accounts. Member accounts can update findings for their own account.
batchUpdateStandardsControlAssociations({required List<StandardsControlAssociationUpdate> standardsControlAssociationUpdates}) Future<BatchUpdateStandardsControlAssociationsResponse>
For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createActionTarget({required String description, required String id, required String name}) Future<CreateActionTargetResponse>
Creates a custom action target in Security Hub CSPM.
createAggregatorV2({required String regionLinkingMode, String? clientToken, List<String>? linkedRegions, Map<String, String>? tags}) Future<CreateAggregatorV2Response>
Enables aggregation across Amazon Web Services Regions.
createAutomationRule({required List<AutomationRulesAction> actions, required AutomationRulesFindingFilters criteria, required String description, required String ruleName, required int ruleOrder, bool? isTerminal, RuleStatus? ruleStatus, Map<String, String>? tags}) Future<CreateAutomationRuleResponse>
Creates an automation rule based on input parameters.
createAutomationRuleV2({required List<AutomationRulesActionV2> actions, required Criteria criteria, required String description, required String ruleName, required double ruleOrder, String? clientToken, RuleStatusV2? ruleStatus, Map<String, String>? tags}) Future<CreateAutomationRuleV2Response>
Creates a V2 automation rule.
createConfigurationPolicy({required Policy configurationPolicy, required String name, String? description, Map<String, String>? tags}) Future<CreateConfigurationPolicyResponse>
Creates a configuration policy with the defined configuration. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
createConnectorV2({required String name, required ProviderConfiguration provider, String? clientToken, String? description, String? kmsKeyArn, Map<String, String>? tags}) Future<CreateConnectorV2Response>
Grants permission to create a connectorV2 based on input parameters.
createFindingAggregator({required String regionLinkingMode, List<String>? regions}) Future<CreateFindingAggregatorResponse>
For information about how cross-Region aggregation works, see Understanding cross-Region aggregation in Security Hub CSPM in the Security Hub CSPM User Guide.
createInsight({required AwsSecurityFindingFilters filters, required String groupByAttribute, required String name}) Future<CreateInsightResponse>
Creates a custom insight in Security Hub CSPM. An insight is a consolidation of findings that relate to a security issue that requires attention or remediation.
createMembers({required List<AccountDetails> accountDetails}) Future<CreateMembersResponse>
Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account. If you are integrated with Organizations, then the administrator account is designated by the organization management account.
createTicketV2({required String connectorId, required String findingMetadataUid, String? clientToken, TicketCreationMode? mode}) Future<CreateTicketV2Response>
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.
declineInvitations({required List<String> accountIds}) Future<DeclineInvitationsResponse>
A prospective member account uses this operation to decline an invitation to become a member.
deleteActionTarget({required String actionTargetArn}) Future<DeleteActionTargetResponse>
Deletes a custom action target from Security Hub CSPM.
deleteAggregatorV2({required String aggregatorV2Arn}) Future<void>
Deletes the Aggregator V2.
deleteAutomationRuleV2({required String identifier}) Future<void>
Deletes a V2 automation rule.
deleteConfigurationPolicy({required String identifier}) Future<void>
Deletes a configuration policy. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region. For the deletion to succeed, you must first disassociate a configuration policy from target accounts, organizational units, or the root by invoking the StartConfigurationPolicyDisassociation operation.
deleteConnectorV2({required String connectorId}) Future<void>
Grants permission to delete a connectorV2.
deleteFindingAggregator({required String findingAggregatorArn}) Future<void>
When you stop cross-Region aggregation, findings that were already replicated and sent to the home Region are still visible from the home Region. However, new findings and finding updates are no longer replicated and sent to the home Region.
deleteInsight({required String insightArn}) Future<DeleteInsightResponse>
Deletes the insight specified by the InsightArn.
deleteInvitations({required List<String> accountIds}) Future<DeleteInvitationsResponse>
A Security Hub CSPM administrator account can use this operation to delete invitations sent to one or more prospective member accounts.
deleteMembers({required List<String> accountIds}) Future<DeleteMembersResponse>
Deletes the specified member accounts from Security Hub CSPM.
describeActionTargets({List<String>? actionTargetArns, int? maxResults, String? nextToken}) Future<DescribeActionTargetsResponse>
Returns a list of the custom action targets in Security Hub CSPM in your account.
describeHub({String? hubArn}) Future<DescribeHubResponse>
Returns details about the Hub resource in your account, including the HubArn and the time when you enabled Security Hub CSPM.
describeOrganizationConfiguration() Future<DescribeOrganizationConfigurationResponse>
Returns information about the way your organization is configured in Security Hub CSPM. Only the Security Hub CSPM administrator account can invoke this operation.
describeProducts({int? maxResults, String? nextToken, String? productArn}) Future<DescribeProductsResponse>
Returns information about product integrations in Security Hub CSPM.
describeProductsV2({int? maxResults, String? nextToken}) Future<DescribeProductsV2Response>
Gets information about the product integration.
describeSecurityHubV2() Future<DescribeSecurityHubV2Response>
Returns details about the service resource in your account.
describeStandards({int? maxResults, String? nextToken}) Future<DescribeStandardsResponse>
Returns a list of the available standards in Security Hub CSPM.
describeStandardsControls({required String standardsSubscriptionArn, int? maxResults, String? nextToken}) Future<DescribeStandardsControlsResponse>
Returns a list of security standards controls.
disableImportFindingsForProduct({required String productSubscriptionArn}) Future<void>
Disables the integration of the specified product with Security Hub CSPM. After the integration is disabled, findings from that product are no longer sent to Security Hub CSPM.
disableOrganizationAdminAccount({required String adminAccountId, SecurityHubFeature? feature}) Future<void>
Disables a Security Hub CSPM administrator account. Can only be called by the organization management account.
disableSecurityHub() Future<void>
Disables Security Hub CSPM in your account only in the current Amazon Web Services Region. To disable Security Hub CSPM in all Regions, you must submit one request per Region where you have enabled Security Hub CSPM.
disableSecurityHubV2() Future<void>
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
disassociateFromAdministratorAccount() Future<void>
Disassociates the current Security Hub CSPM member account from the associated administrator account.
disassociateFromMasterAccount() Future<void>
This method is deprecated. Instead, use DisassociateFromAdministratorAccount.
disassociateMembers({required List<String> accountIds}) Future<void>
Disassociates the specified member accounts from the associated administrator account.
enableImportFindingsForProduct({required String productArn}) Future<EnableImportFindingsForProductResponse>
Enables the integration of a partner product with Security Hub CSPM. Integrated products send findings to Security Hub CSPM.
enableOrganizationAdminAccount({required String adminAccountId, SecurityHubFeature? feature}) Future<EnableOrganizationAdminAccountResponse>
Designates the Security Hub CSPM administrator account for an organization. Can only be called by the organization management account.
enableSecurityHub({ControlFindingGenerator? controlFindingGenerator, bool? enableDefaultStandards, Map<String, String>? tags}) Future<void>
Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request.
enableSecurityHubV2({Map<String, String>? tags}) Future<EnableSecurityHubV2Response>
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.
generateRecommendedPolicyV2({required String metadataUid}) Future<void>
Begins the recommended policy generation to remediate a Security Hub finding. GenerateRecommendedPolicyV2 only supports findings for unused permissions.
getAdministratorAccount() Future<GetAdministratorAccountResponse>
Provides the details for the Security Hub CSPM administrator account for the current member account.
getAggregatorV2({required String aggregatorV2Arn}) Future<GetAggregatorV2Response>
Returns the configuration of the specified Aggregator V2.
getAutomationRuleV2({required String identifier}) Future<GetAutomationRuleV2Response>
Returns an automation rule for the V2 service.
getConfigurationPolicy({required String identifier}) Future<GetConfigurationPolicyResponse>
Provides information about a configuration policy. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
getConfigurationPolicyAssociation({required Target target}) Future<GetConfigurationPolicyAssociationResponse>
Returns the association between a configuration and a target account, organizational unit, or the root. The configuration can be a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
getConnectorV2({required String connectorId}) Future<GetConnectorV2Response>
Grants permission to retrieve details for a connectorV2 based on connector id.
getEnabledStandards({int? maxResults, String? nextToken, List<String>? standardsSubscriptionArns}) Future<GetEnabledStandardsResponse>
Returns a list of the standards that are currently enabled.
getFindingAggregator({required String findingAggregatorArn}) Future<GetFindingAggregatorResponse>
May throw AccessDeniedException. May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.
getFindingHistory({required AwsSecurityFindingIdentifier findingIdentifier, DateTime? endTime, int? maxResults, String? nextToken, DateTime? startTime}) Future<GetFindingHistoryResponse>
Returns the history of a Security Hub CSPM finding. The history includes changes made to any fields in the Amazon Web Services Security Finding Format (ASFF) except top-level timestamp fields, such as the CreatedAt and UpdatedAt fields.
getFindings({AwsSecurityFindingFilters? filters, int? maxResults, String? nextToken, List<SortCriterion>? sortCriteria}) Future<GetFindingsResponse>
Returns a list of findings that match the specified criteria.
getFindingStatisticsV2({required List<GroupByRule> groupByRules, int? maxStatisticResults, FindingScopes? scopes, SortOrder? sortOrder}) Future<GetFindingStatisticsV2Response>
Returns aggregated statistical data about findings.
getFindingsTrendsV2({required DateTime endTime, required DateTime startTime, FindingsTrendsFilters? filters, int? maxResults, String? nextToken}) Future<GetFindingsTrendsV2Response>
Returns findings trend data based on the specified criteria. This operation helps you analyze patterns and changes in findings over time.
getFindingsV2({OcsfFindingFilters? filters, int? maxResults, String? nextToken, FindingScopes? scopes, List<SortCriterion>? sortCriteria}) Future<GetFindingsV2Response>
Returns a list of findings that match the specified criteria.
getInsightResults({required String insightArn}) Future<GetInsightResultsResponse>
Lists the results of the Security Hub CSPM insight specified by the insight ARN.
getInsights({List<String>? insightArns, int? maxResults, String? nextToken}) Future<GetInsightsResponse>
Lists and describes insights for the specified insight ARNs.
getInvitationsCount() Future<GetInvitationsCountResponse>
May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException.
getMasterAccount() Future<GetMasterAccountResponse>
This method is deprecated. Instead, use GetAdministratorAccount.
getMembers({required List<String> accountIds}) Future<GetMembersResponse>
Returns the details for the Security Hub CSPM member accounts for the specified account IDs.
getRecommendedPolicyV2({required String metadataUid, int? maxResults, String? nextToken}) Future<GetRecommendedPolicyV2Response>
Retrieves the recommended policy to remediate a Security Hub finding. GetRecommendedPolicyV2 only supports findings for unused permissions.
getResourcesStatisticsV2({required List<ResourceGroupByRule> groupByRules, int? maxStatisticResults, ResourceScopes? scopes, SortOrder? sortOrder}) Future<GetResourcesStatisticsV2Response>
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
getResourcesTrendsV2({required DateTime endTime, required DateTime startTime, ResourcesTrendsFilters? filters, int? maxResults, String? nextToken}) Future<GetResourcesTrendsV2Response>
Returns resource trend data based on the specified criteria. This operation helps you analyze patterns and changes in resource compliance over time.
getResourcesV2({ResourcesFilters? filters, int? maxResults, String? nextToken, ResourceScopes? scopes, List<SortCriterion>? sortCriteria}) Future<GetResourcesV2Response>
Returns a list of resources.
getSecurityControlDefinition({required String securityControlId}) Future<GetSecurityControlDefinitionResponse>
Retrieves the definition of a security control. The definition includes the control title, description, Region availability, parameter definitions, and other details.
inviteMembers({required List<String> accountIds}) Future<InviteMembersResponse>
This operation is only used to invite accounts that don't belong to an Amazon Web Services organization. Organization accounts don't receive invitations.
listAggregatorsV2({int? maxResults, String? nextToken}) Future<ListAggregatorsV2Response>
Retrieves a list of V2 aggregators.
listAutomationRules({int? maxResults, String? nextToken}) Future<ListAutomationRulesResponse>
A list of automation rules and their metadata for the calling account.
listAutomationRulesV2({int? maxResults, String? nextToken}) Future<ListAutomationRulesV2Response>
Returns a list of automation rules and metadata for the calling account.
listConfigurationPolicies({int? maxResults, String? nextToken}) Future<ListConfigurationPoliciesResponse>
Lists the configuration policies that the Security Hub CSPM delegated administrator has created for your organization. Only the delegated administrator can invoke this operation from the home Region.
listConfigurationPolicyAssociations({AssociationFilters? filters, int? maxResults, String? nextToken}) Future<ListConfigurationPolicyAssociationsResponse>
Provides information about the associations for your configuration policies and self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
listConnectorsV2({ConnectorStatus? connectorStatus, int? maxResults, String? nextToken, ConnectorProviderName? providerName}) Future<ListConnectorsV2Response>
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
listEnabledProductsForImport({int? maxResults, String? nextToken}) Future<ListEnabledProductsForImportResponse>
Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security Hub CSPM.
listFindingAggregators({int? maxResults, String? nextToken}) Future<ListFindingAggregatorsResponse>
If cross-Region aggregation is enabled, then ListFindingAggregators returns the Amazon Resource Name (ARN) of the finding aggregator. You can run this operation from any Amazon Web Services Region.
listInvitations({int? maxResults, String? nextToken}) Future<ListInvitationsResponse>
Only accounts that are managed by invitation can use this operation. Accounts that are managed using the integration with Organizations don't receive invitations.
listMembers({int? maxResults, String? nextToken, bool? onlyAssociated}) Future<ListMembersResponse>
Lists details about all member accounts for the current Security Hub CSPM administrator account.
listOrganizationAdminAccounts({SecurityHubFeature? feature, int? maxResults, String? nextToken}) Future<ListOrganizationAdminAccountsResponse>
Lists the Security Hub CSPM administrator accounts. Can only be called by the organization management account.
listSecurityControlDefinitions({int? maxResults, String? nextToken, String? standardsArn}) Future<ListSecurityControlDefinitionsResponse>
Lists all of the security controls that apply to a specified standard.
listStandardsControlAssociations({required String securityControlId, int? maxResults, String? nextToken}) Future<ListStandardsControlAssociationsResponse>
Specifies whether a control is currently enabled or disabled in each enabled standard in the calling account.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Returns a list of tags associated with a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerConnectorV2({required String authCode, required String authState}) Future<RegisterConnectorV2Response>
Grants permission to complete the authorization based on input parameters.
startConfigurationPolicyAssociation({required String configurationPolicyIdentifier, required Target target}) Future<StartConfigurationPolicyAssociationResponse>
Associates a target account, organizational unit, or the root with a specified configuration. The target can be associated with a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
startConfigurationPolicyDisassociation({required String configurationPolicyIdentifier, Target? target}) Future<void>
Disassociates a target account, organizational unit, or the root from a specified configuration. When you disassociate a configuration from its target, the target inherits the configuration of the closest parent. If there’s no configuration to inherit, the target retains its settings but becomes a self-managed account. A target can be disassociated from a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds one or more tags to a resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from a resource.
updateActionTarget({required String actionTargetArn, String? description, String? name}) Future<void>
Updates the name and description of a custom action target in Security Hub CSPM.
updateAggregatorV2({required String aggregatorV2Arn, required String regionLinkingMode, List<String>? linkedRegions}) Future<UpdateAggregatorV2Response>
Udpates the configuration for the Aggregator V2.
updateAutomationRuleV2({required String identifier, List<AutomationRulesActionV2>? actions, Criteria? criteria, String? description, String? ruleName, double? ruleOrder, RuleStatusV2? ruleStatus}) Future<void>
Updates a V2 automation rule.
updateConfigurationPolicy({required String identifier, Policy? configurationPolicy, String? description, String? name, String? updatedReason}) Future<UpdateConfigurationPolicyResponse>
Updates a configuration policy. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
updateConnectorV2({required String connectorId, String? description, ProviderUpdateConfiguration? provider}) Future<void>
Grants permission to update a connectorV2 based on its id and input parameters.
updateFindingAggregator({required String findingAggregatorArn, required String regionLinkingMode, List<String>? regions}) Future<UpdateFindingAggregatorResponse>
You can invoke this operation from the current home Region only.
updateFindings({required AwsSecurityFindingFilters filters, NoteUpdate? note, RecordState? recordState}) Future<void>
UpdateFindings is a deprecated operation. Instead of UpdateFindings, use the BatchUpdateFindings operation.
updateInsight({required String insightArn, AwsSecurityFindingFilters? filters, String? groupByAttribute, String? name}) Future<void>
Updates the Security Hub CSPM insight identified by the specified insight ARN.
updateOrganizationConfiguration({required bool autoEnable, AutoEnableStandards? autoEnableStandards, OrganizationConfiguration? organizationConfiguration}) Future<void>
Updates the configuration of your organization in Security Hub CSPM. Only the Security Hub CSPM administrator account can invoke this operation.
updateSecurityControl({required Map<String, ParameterConfiguration> parameters, required String securityControlId, String? lastUpdateReason}) Future<void>
Updates the properties of a security control.
updateSecurityHubConfiguration({bool? autoEnableControls, ControlFindingGenerator? controlFindingGenerator}) Future<void>
Updates configuration options for Security Hub CSPM.
updateStandardsControl({required String standardsControlArn, ControlStatus? controlStatus, String? disabledReason}) Future<void>
Used to control whether an individual security standard control is enabled or disabled.

Operators

operator ==(Object other) bool
The equality operator.
inherited