batchGetStandardsControlAssociations method

Future<BatchGetStandardsControlAssociationsResponse> batchGetStandardsControlAssociations({
  1. required List<StandardsControlAssociationId> standardsControlAssociationIds,
})

For a batch of security controls and standards, identifies whether each control is currently enabled or disabled in a standard.

Calls to this operation return a RESOURCE_NOT_FOUND_EXCEPTION error when the standard subscription for the association has a NOT_READY_FOR_UPDATES value for StandardsControlsUpdatable.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException.

Parameter standardsControlAssociationIds : An array with one or more objects that includes a security control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. This field is used to query the enablement status of a control in a specified standard. The security control ID or ARN is the same across standards.

Implementation

Future<BatchGetStandardsControlAssociationsResponse>
    batchGetStandardsControlAssociations({
  required List<StandardsControlAssociationId> standardsControlAssociationIds,
}) async {
  final $payload = <String, dynamic>{
    'StandardsControlAssociationIds': standardsControlAssociationIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/associations/batchGet',
    exceptionFnMap: _exceptionFns,
  );
  return BatchGetStandardsControlAssociationsResponse.fromJson(response);
}