batchUpdateAutomationRules method

Future<BatchUpdateAutomationRulesResponse> batchUpdateAutomationRules({
  1. required List<UpdateAutomationRulesRequestItem> updateAutomationRulesRequestItems,
})

Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter updateAutomationRulesRequestItems : An array of ARNs for the rules that are to be updated. Optionally, you can also include RuleStatus and RuleOrder.

Implementation

Future<BatchUpdateAutomationRulesResponse> batchUpdateAutomationRules({
  required List<UpdateAutomationRulesRequestItem>
      updateAutomationRulesRequestItems,
}) async {
  final $payload = <String, dynamic>{
    'UpdateAutomationRulesRequestItems': updateAutomationRulesRequestItems,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/automationrules/update',
    exceptionFnMap: _exceptionFns,
  );
  return BatchUpdateAutomationRulesResponse.fromJson(response);
}