batchUpdateFindings method
Used by Security Hub CSPM customers to update information about their investigation into one or more findings. Requested by administrator accounts or member accounts. Administrator accounts can update findings for their account and their member accounts. A member account can update findings only for their own account. Administrator and member accounts can use this operation to update the following fields and objects for one or more findings:
-
Confidence -
Criticality -
Note -
RelatedFindings -
Severity -
Types -
UserDefinedFields -
VerificationState -
Workflow
UpdatedAt field of the finding. Also note
that it can take several minutes for Security Hub CSPM to process your
request and update each finding specified in the request.
You can configure IAM policies to restrict access to fields and field values. For example, you might not want member accounts to be able to suppress findings or change the finding severity. For more information see Configuring access to BatchUpdateFindings in the Security Hub CSPM User Guide.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter findingIdentifiers :
The list of findings to update. BatchUpdateFindings can be
used to update up to 100 findings at a time.
For each finding, the list provides the finding identifier and the ARN of the finding provider.
Parameter confidence :
The updated value for the finding confidence. Confidence is defined as the
likelihood that a finding accurately identifies the behavior or issue that
it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
Parameter criticality :
The updated value for the level of importance assigned to the resources
associated with the findings.
A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources.
Parameter relatedFindings :
A list of findings that are related to the updated findings.
Parameter severity :
Used to update the finding severity.
Parameter types :
One or more finding types in the format of namespace/category/classifier
that classify a finding.
Valid namespace values are as follows.
- Software and Configuration Checks
- TTPs
- Effects
- Unusual Behaviors
- Sensitive Data Identifications
Parameter userDefinedFields :
A list of name/value string pairs associated with the finding. These are
custom, user-defined fields added to a finding.
Parameter verificationState :
Indicates the veracity of a finding.
The available values for VerificationState are as follows.
-
UNKNOWN– The default disposition of a security finding -
TRUE_POSITIVE– The security finding is confirmed -
FALSE_POSITIVE– The security finding was determined to be a false alarm -
BENIGN_POSITIVE– A special case ofTRUE_POSITIVEwhere the finding doesn't pose any threat, is expected, or both
Parameter workflow :
Used to update the workflow status of a finding.
The workflow status indicates the progress of the investigation into the finding.
Implementation
Future<BatchUpdateFindingsResponse> batchUpdateFindings({
required List<AwsSecurityFindingIdentifier> findingIdentifiers,
int? confidence,
int? criticality,
NoteUpdate? note,
List<RelatedFinding>? relatedFindings,
SeverityUpdate? severity,
List<String>? types,
Map<String, String>? userDefinedFields,
VerificationState? verificationState,
WorkflowUpdate? workflow,
}) async {
_s.validateNumRange(
'confidence',
confidence,
0,
100,
);
_s.validateNumRange(
'criticality',
criticality,
0,
100,
);
final $payload = <String, dynamic>{
'FindingIdentifiers': findingIdentifiers,
if (confidence != null) 'Confidence': confidence,
if (criticality != null) 'Criticality': criticality,
if (note != null) 'Note': note,
if (relatedFindings != null) 'RelatedFindings': relatedFindings,
if (severity != null) 'Severity': severity,
if (types != null) 'Types': types,
if (userDefinedFields != null) 'UserDefinedFields': userDefinedFields,
if (verificationState != null)
'VerificationState': verificationState.value,
if (workflow != null) 'Workflow': workflow,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/findings/batchupdate',
exceptionFnMap: _exceptionFns,
);
return BatchUpdateFindingsResponse.fromJson(response);
}