createAggregatorV2 method

Future<CreateAggregatorV2Response> createAggregatorV2({
  1. required String regionLinkingMode,
  2. String? clientToken,
  3. List<String>? linkedRegions,
  4. Map<String, String>? tags,
})

Enables aggregation across Amazon Web Services Regions.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter regionLinkingMode : Determines how Regions are linked to an Aggregator V2.

Parameter clientToken : A unique identifier used to ensure idempotency.

Parameter linkedRegions : The list of Regions that are linked to the aggregation Region.

Parameter tags : A list of key-value pairs to be applied to the AggregatorV2.

Implementation

Future<CreateAggregatorV2Response> createAggregatorV2({
  required String regionLinkingMode,
  String? clientToken,
  List<String>? linkedRegions,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'RegionLinkingMode': regionLinkingMode,
    'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (linkedRegions != null) 'LinkedRegions': linkedRegions,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/aggregatorv2/create',
    exceptionFnMap: _exceptionFns,
  );
  return CreateAggregatorV2Response.fromJson(response);
}