createMembers method
Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account. If you are integrated with Organizations, then the administrator account is designated by the organization management account.
CreateMembers is always used to add accounts that are not
organization members.
For accounts that are managed using Organizations,
CreateMembers is only used in the following cases:
- Security Hub CSPM is not configured to automatically add new organization accounts.
- The account was disassociated or deleted in Security Hub CSPM.
EnableSecurityHub operation.
For accounts that are not organization members, you create the account
association and then send an invitation to the member account. To send the
invitation, you use the InviteMembers operation. If the
account owner accepts the invitation, the account becomes a member account
in Security Hub CSPM.
Accounts that are managed using Organizations don't receive an invitation. They automatically become a member account in Security Hub CSPM.
- If the organization account does not have Security Hub CSPM enabled, then Security Hub CSPM and the default standards are automatically enabled. Note that Security Hub CSPM cannot be enabled automatically for the organization management account. The organization management account must enable Security Hub CSPM before the administrator account enables it as a member account.
- For organization accounts that already have Security Hub CSPM enabled, Security Hub CSPM does not make any other changes to those accounts. It does not change their enabled standards or controls.
To remove the association between the administrator and member accounts,
use the DisassociateFromMasterAccount or
DisassociateMembers operation.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceConflictException.
Parameter accountDetails :
The list of accounts to associate with the Security Hub CSPM administrator
account. For each account, the list includes the account ID and optionally
the email address.
Implementation
Future<CreateMembersResponse> createMembers({
required List<AccountDetails> accountDetails,
}) async {
final $payload = <String, dynamic>{
'AccountDetails': accountDetails,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/members',
exceptionFnMap: _exceptionFns,
);
return CreateMembersResponse.fromJson(response);
}