declineInvitations method

Future<DeclineInvitationsResponse> declineInvitations({
  1. required List<String> accountIds,
})
Declines invitations to become a Security Hub CSPM member account.

A prospective member account uses this operation to decline an invitation to become a member.

Only member accounts that aren't part of an Amazon Web Services organization should use this operation. Organization accounts don't receive invitations.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw ResourceNotFoundException.

Parameter accountIds : The list of prospective member account IDs for which to decline an invitation.

Implementation

Future<DeclineInvitationsResponse> declineInvitations({
  required List<String> accountIds,
}) async {
  final $payload = <String, dynamic>{
    'AccountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/invitations/decline',
    exceptionFnMap: _exceptionFns,
  );
  return DeclineInvitationsResponse.fromJson(response);
}