deleteActionTarget method

Future<DeleteActionTargetResponse> deleteActionTarget({
  1. required String actionTargetArn,
})

Deletes a custom action target from Security Hub CSPM.

Deleting a custom action target does not affect any findings or insights that were already sent to Amazon CloudWatch Events using the custom action.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw ResourceNotFoundException.

Parameter actionTargetArn : The Amazon Resource Name (ARN) of the custom action target to delete.

Implementation

Future<DeleteActionTargetResponse> deleteActionTarget({
  required String actionTargetArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/actionTargets/${actionTargetArn.split('/').map(Uri.encodeComponent).join('/')}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteActionTargetResponse.fromJson(response);
}