deleteFindingAggregator method
Deletes a finding aggregator. When you delete the finding aggregator, you
stop cross-Region aggregation. Finding replication stops occurring from
the linked Regions to the home Region.
When you stop cross-Region aggregation, findings that were already replicated and sent to the home Region are still visible from the home Region. However, new findings and finding updates are no longer replicated and sent to the home Region.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter findingAggregatorArn :
The ARN of the finding aggregator to delete. To obtain the ARN, use
ListFindingAggregators.
Implementation
Future<void> deleteFindingAggregator({
required String findingAggregatorArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/findingAggregator/delete/${findingAggregatorArn.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
}