deleteInvitations method
Deletes invitations to become a Security Hub CSPM member account.
A Security Hub CSPM administrator account can use this operation to delete invitations sent to one or more prospective member accounts.
This operation is only used to delete invitations that are sent to prospective member accounts that aren't part of an Amazon Web Services organization. Organization accounts don't receive invitations.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter accountIds :
The list of member account IDs that received the invitations you want to
delete.
Implementation
Future<DeleteInvitationsResponse> deleteInvitations({
required List<String> accountIds,
}) async {
final $payload = <String, dynamic>{
'AccountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/invitations/delete',
exceptionFnMap: _exceptionFns,
);
return DeleteInvitationsResponse.fromJson(response);
}