deleteMembers method

Future<DeleteMembersResponse> deleteMembers({
  1. required List<String> accountIds,
})

Deletes the specified member accounts from Security Hub CSPM.

You can invoke this API only to delete accounts that became members through invitation. You can't invoke this API to delete accounts that belong to an Organizations organization.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter accountIds : The list of account IDs for the member accounts to delete.

Implementation

Future<DeleteMembersResponse> deleteMembers({
  required List<String> accountIds,
}) async {
  final $payload = <String, dynamic>{
    'AccountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/members/delete',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteMembersResponse.fromJson(response);
}