describeProducts method
Returns information about product integrations in Security Hub CSPM.
You can optionally provide an integration ARN. If you provide an integration ARN, then the results only include that integration.
If you don't provide an integration ARN, then the results include all of the available product integrations.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token that is required for pagination. On your first call to the
DescribeProducts operation, set the value of this parameter
to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
Parameter productArn :
The ARN of the integration to return.
Implementation
Future<DescribeProductsResponse> describeProducts({
int? maxResults,
String? nextToken,
String? productArn,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
if (productArn != null) 'ProductArn': [productArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/products',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeProductsResponse.fromJson(response);
}