describeProductsV2 method

Future<DescribeProductsV2Response> describeProductsV2({
  1. int? maxResults,
  2. String? nextToken,
})

Gets information about the product integration.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return.

Parameter nextToken : The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

Implementation

Future<DescribeProductsV2Response> describeProductsV2({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'MaxResults': [maxResults.toString()],
    if (nextToken != null) 'NextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/productsV2',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribeProductsV2Response.fromJson(response);
}