disableImportFindingsForProduct method

Future<void> disableImportFindingsForProduct({
  1. required String productSubscriptionArn,
})

Disables the integration of the specified product with Security Hub CSPM. After the integration is disabled, findings from that product are no longer sent to Security Hub CSPM.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter productSubscriptionArn : The ARN of the integrated product to disable the integration for.

Implementation

Future<void> disableImportFindingsForProduct({
  required String productSubscriptionArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/productSubscriptions/${productSubscriptionArn.split('/').map(Uri.encodeComponent).join('/')}',
    exceptionFnMap: _exceptionFns,
  );
}