disassociateFromAdministratorAccount method

Future<void> disassociateFromAdministratorAccount()

Disassociates the current Security Hub CSPM member account from the associated administrator account.

This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Implementation

Future<void> disassociateFromAdministratorAccount() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/administrator/disassociate',
    exceptionFnMap: _exceptionFns,
  );
}