disassociateMembers method

Future<void> disassociateMembers({
  1. required List<String> accountIds,
})

Disassociates the specified member accounts from the associated administrator account.

Can be used to disassociate both accounts that are managed using Organizations and accounts that were invited manually.

May throw AccessDeniedException. May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter accountIds : The account IDs of the member accounts to disassociate from the administrator account.

Implementation

Future<void> disassociateMembers({
  required List<String> accountIds,
}) async {
  final $payload = <String, dynamic>{
    'AccountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/members/disassociate',
    exceptionFnMap: _exceptionFns,
  );
}