enableImportFindingsForProduct method

Future<EnableImportFindingsForProductResponse> enableImportFindingsForProduct({
  1. required String productArn,
})

Enables the integration of a partner product with Security Hub CSPM. Integrated products send findings to Security Hub CSPM.

When you enable a product integration, a permissions policy that grants permission for the product to send findings to Security Hub CSPM is applied.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceConflictException.

Parameter productArn : The ARN of the product to enable the integration for.

Implementation

Future<EnableImportFindingsForProductResponse>
    enableImportFindingsForProduct({
  required String productArn,
}) async {
  final $payload = <String, dynamic>{
    'ProductArn': productArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/productSubscriptions',
    exceptionFnMap: _exceptionFns,
  );
  return EnableImportFindingsForProductResponse.fromJson(response);
}