enableSecurityHubV2 method

Future<EnableSecurityHubV2Response> enableSecurityHubV2({
  1. Map<String, String>? tags,
})

Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter tags : The tags to add to the hub V2 resource when you enable Security Hub.

Implementation

Future<EnableSecurityHubV2Response> enableSecurityHubV2({
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/hubv2',
    exceptionFnMap: _exceptionFns,
  );
  return EnableSecurityHubV2Response.fromJson(response);
}