getAdministratorAccount method
Provides the details for the Security Hub CSPM administrator account for the current member account.
Can be used by both member accounts that are managed using Organizations and accounts that were invited manually.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Implementation
Future<GetAdministratorAccountResponse> getAdministratorAccount() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/administrator',
exceptionFnMap: _exceptionFns,
);
return GetAdministratorAccountResponse.fromJson(response);
}