getConfigurationPolicyAssociation method
Future<GetConfigurationPolicyAssociationResponse>
getConfigurationPolicyAssociation({
- required Target target,
Returns the association between a configuration and a target account, organizational unit, or the root. The configuration can be a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter target :
The target account ID, organizational unit ID, or the root ID to retrieve
the association for.
Implementation
Future<GetConfigurationPolicyAssociationResponse>
getConfigurationPolicyAssociation({
required Target target,
}) async {
final $payload = <String, dynamic>{
'Target': target,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/configurationPolicyAssociation/get',
exceptionFnMap: _exceptionFns,
);
return GetConfigurationPolicyAssociationResponse.fromJson(response);
}