getFindingAggregator method

Future<GetFindingAggregatorResponse> getFindingAggregator({
  1. required String findingAggregatorArn,
})
Returns the current configuration in the calling account for cross-Region aggregation. A finding aggregator is a resource that establishes the home Region and any linked Regions.

May throw AccessDeniedException. May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter findingAggregatorArn : The ARN of the finding aggregator to return details for. To obtain the ARN, use ListFindingAggregators.

Implementation

Future<GetFindingAggregatorResponse> getFindingAggregator({
  required String findingAggregatorArn,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/findingAggregator/get/${findingAggregatorArn.split('/').map(Uri.encodeComponent).join('/')}',
    exceptionFnMap: _exceptionFns,
  );
  return GetFindingAggregatorResponse.fromJson(response);
}