getInvitationsCount method

Future<GetInvitationsCountResponse> getInvitationsCount()
Returns the count of all Security Hub CSPM membership invitations that were sent to the calling member account, not including the currently accepted invitation.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException.

Implementation

Future<GetInvitationsCountResponse> getInvitationsCount() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/invitations/count',
    exceptionFnMap: _exceptionFns,
  );
  return GetInvitationsCountResponse.fromJson(response);
}