getMembers method

Future<GetMembersResponse> getMembers({
  1. required List<String> accountIds,
})

Returns the details for the Security Hub CSPM member accounts for the specified account IDs.

An administrator account can be either the delegated Security Hub CSPM administrator account for an organization or an administrator account that enabled Security Hub CSPM manually.

The results include both member accounts that are managed using Organizations and accounts that were invited manually.

May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter accountIds : The list of account IDs for the Security Hub CSPM member accounts to return the details for.

Implementation

Future<GetMembersResponse> getMembers({
  required List<String> accountIds,
}) async {
  final $payload = <String, dynamic>{
    'AccountIds': accountIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/members/get',
    exceptionFnMap: _exceptionFns,
  );
  return GetMembersResponse.fromJson(response);
}