getSecurityControlDefinition method
Future<GetSecurityControlDefinitionResponse>
getSecurityControlDefinition({
- required String securityControlId,
Retrieves the definition of a security control. The definition includes the control title, description, Region availability, parameter definitions, and other details.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter securityControlId :
The ID of the security control to retrieve the definition for. This field
doesn’t accept an Amazon Resource Name (ARN).
Implementation
Future<GetSecurityControlDefinitionResponse> getSecurityControlDefinition({
required String securityControlId,
}) async {
final $query = <String, List<String>>{
'SecurityControlId': [securityControlId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/securityControl/definition',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetSecurityControlDefinitionResponse.fromJson(response);
}