listAutomationRulesV2 method
Returns a list of automation rules and metadata for the calling account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token required for pagination. On your first call, set the value of
this parameter to NULL. For subsequent calls, to continue
listing data, set the value of this parameter to the value returned in the
previous response.
Implementation
Future<ListAutomationRulesV2Response> listAutomationRulesV2({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/automationrulesv2/list',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAutomationRulesV2Response.fromJson(response);
}