listConfigurationPolicies method
Lists the configuration policies that the Security Hub CSPM delegated administrator has created for your organization. Only the delegated administrator can invoke this operation from the home Region.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter maxResults :
The maximum number of results that's returned by
ListConfigurationPolicies in each page of the response. When
this parameter is used, ListConfigurationPolicies returns the
specified number of results in a single page and a NextToken
response element. You can see the remaining results of the initial request
by sending another ListConfigurationPolicies request with the
returned NextToken value. A valid range for
MaxResults is between 1 and 100.
Parameter nextToken :
The NextToken value that's returned from a previous paginated
ListConfigurationPolicies request where
MaxResults was used but the results exceeded the value of
that parameter. Pagination continues from the MaxResults was
used but the results exceeded the value of that parameter. Pagination
continues from the end of the previous response that returned the
NextToken value. This value is null when there
are no more results to return.
Implementation
Future<ListConfigurationPoliciesResponse> listConfigurationPolicies({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/configurationPolicy/list',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListConfigurationPoliciesResponse.fromJson(response);
}