untagResource method
Removes one or more tags from a resource.
May throw InternalException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The ARN of the resource to remove the tags from.
Parameter tagKeys :
The tag keys associated with the tags to remove from the resource. You can
remove up to 50 tags at a time.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}