updateSecurityControl method

Future<void> updateSecurityControl({
  1. required Map<String, ParameterConfiguration> parameters,
  2. required String securityControlId,
  3. String? lastUpdateReason,
})

Updates the properties of a security control.

May throw AccessDeniedException. May throw InternalException. May throw InvalidAccessException. May throw InvalidInputException. May throw LimitExceededException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter parameters : An object that specifies which security control parameters to update.

Parameter securityControlId : The Amazon Resource Name (ARN) or ID of the control to update.

Parameter lastUpdateReason : The most recent reason for updating the properties of the security control. This field accepts alphanumeric characters in addition to white spaces, dashes, and underscores.

Implementation

Future<void> updateSecurityControl({
  required Map<String, ParameterConfiguration> parameters,
  required String securityControlId,
  String? lastUpdateReason,
}) async {
  final $payload = <String, dynamic>{
    'Parameters': parameters,
    'SecurityControlId': securityControlId,
    if (lastUpdateReason != null) 'LastUpdateReason': lastUpdateReason,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/securityControl/update',
    exceptionFnMap: _exceptionFns,
  );
}