SecurityIR class

This guide documents the action and response elements for use of the service.

Constructors

SecurityIR({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetMemberAccountDetails({required List<String> accountIds, required String membershipId}) Future<BatchGetMemberAccountDetailsResponse>
Provides information on whether the supplied account IDs are associated with a membership.
cancelMembership({required String membershipId}) Future<CancelMembershipResponse>
Cancels an existing membership.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
closeCase({required String caseId}) Future<CloseCaseResponse>
Closes an existing case.
createCase({required String description, required EngagementType engagementType, required List<String> impactedAccounts, required DateTime reportedIncidentStartDate, required ResolverType resolverType, required String title, required List<Watcher> watchers, String? clientToken, List<ImpactedAwsRegion>? impactedAwsRegions, List<String>? impactedServices, Map<String, String>? tags, List<ThreatActorIp>? threatActorIpAddresses}) Future<CreateCaseResponse>
Creates a new case.
createCaseComment({required String body, required String caseId, String? clientToken}) Future<CreateCaseCommentResponse>
Adds a comment to an existing case.
createMembership({required List<IncidentResponder> incidentResponseTeam, required String membershipName, String? clientToken, bool? coverEntireOrganization, List<OptInFeature>? optInFeatures, Map<String, String>? tags}) Future<CreateMembershipResponse>
Creates a new membership.
getCase({required String caseId}) Future<GetCaseResponse>
Returns the attributes of a case.
getCaseAttachmentDownloadUrl({required String attachmentId, required String caseId}) Future<GetCaseAttachmentDownloadUrlResponse>
Returns a Pre-Signed URL for uploading attachments into a case.
getCaseAttachmentUploadUrl({required String caseId, required int contentLength, required String fileName, String? clientToken}) Future<GetCaseAttachmentUploadUrlResponse>
Uploads an attachment to a case.
getMembership({required String membershipId}) Future<GetMembershipResponse>
Returns the attributes of a membership.
listCaseEdits({required String caseId, int? maxResults, String? nextToken}) Future<ListCaseEditsResponse>
Views the case history for edits made to a designated case.
listCases({int? maxResults, String? nextToken}) Future<ListCasesResponse>
Lists all cases the requester has access to.
listComments({required String caseId, int? maxResults, String? nextToken}) Future<ListCommentsResponse>
Returns comments for a designated case.
listInvestigations({required String caseId, int? maxResults, String? nextToken}) Future<ListInvestigationsResponse>
Investigation performed by an agent for a security incident...
listMemberships({int? maxResults, String? nextToken}) Future<ListMembershipsResponse>
Returns the memberships that the calling principal can access.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Returns currently configured tags on a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendFeedback({required String caseId, required String resultId, required UsefulnessRating usefulness, String? comment}) Future<void>
Send feedback based on response investigation action
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds a tag(s) to a designated resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a tag(s) from a designate resource.
updateCase({required String caseId, DateTime? actualIncidentStartDate, List<CaseMetadataEntry>? caseMetadata, String? description, EngagementType? engagementType, List<String>? impactedAccountsToAdd, List<String>? impactedAccountsToDelete, List<ImpactedAwsRegion>? impactedAwsRegionsToAdd, List<ImpactedAwsRegion>? impactedAwsRegionsToDelete, List<String>? impactedServicesToAdd, List<String>? impactedServicesToDelete, DateTime? reportedIncidentStartDate, List<ThreatActorIp>? threatActorIpAddressesToAdd, List<ThreatActorIp>? threatActorIpAddressesToDelete, String? title, List<Watcher>? watchersToAdd, List<Watcher>? watchersToDelete}) Future<void>
Updates an existing case.
updateCaseComment({required String body, required String caseId, required String commentId}) Future<UpdateCaseCommentResponse>
Updates an existing case comment.
updateCaseStatus({required String caseId, required SelfManagedCaseStatus caseStatus}) Future<UpdateCaseStatusResponse>
Updates the state transitions for a designated cases.
updateMembership({required String membershipId, List<IncidentResponder>? incidentResponseTeam, MembershipAccountsConfigurationsUpdate? membershipAccountsConfigurationsUpdate, String? membershipName, List<OptInFeature>? optInFeatures, bool? undoMembershipCancellation}) Future<void>
Updates membership configuration.
updateResolverType({required String caseId, required ResolverType resolverType}) Future<UpdateResolverTypeResponse>
Updates the resolver type for a case.

Operators

operator ==(Object other) bool
The equality operator.
inherited