listInvestigations method

Future<ListInvestigationsResponse> listInvestigations({
  1. required String caseId,
  2. int? maxResults,
  3. String? nextToken,
})

Investigation performed by an agent for a security incident...

Parameter caseId : Investigation performed by an agent for a security incident per caseID

Parameter maxResults : Investigation performed by an agent for a security incident request, returning max results

Parameter nextToken : Investigation performed by an agent for a security incident request

Implementation

Future<ListInvestigationsResponse> listInvestigations({
  required String caseId,
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/v1/cases/${Uri.encodeComponent(caseId)}/list-investigations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListInvestigationsResponse.fromJson(response);
}