createAwsLogSource method

Future<CreateAwsLogSourceResponse> createAwsLogSource({
  1. required List<AwsLogSourceConfiguration> sources,
})

Adds a natively supported Amazon Web Services service as an Amazon Security Lake source. Enables source types for member accounts in required Amazon Web Services Regions, based on the parameters you specify. You can choose any source type in any Region for either accounts that are part of a trusted organization or standalone accounts. Once you add an Amazon Web Services service as a source, Security Lake starts collecting logs and events from it.

You can use this API only to enable natively supported Amazon Web Services services as a source. Use CreateCustomLogSource to enable data collection from a custom source.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter sources : Specify the natively-supported Amazon Web Services service to add as a source in Security Lake.

Implementation

Future<CreateAwsLogSourceResponse> createAwsLogSource({
  required List<AwsLogSourceConfiguration> sources,
}) async {
  final $payload = <String, dynamic>{
    'sources': sources,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/datalake/logsources/aws',
    exceptionFnMap: _exceptionFns,
  );
  return CreateAwsLogSourceResponse.fromJson(response);
}