createDataLakeOrganizationConfiguration method

Future<void> createDataLakeOrganizationConfiguration({
  1. List<DataLakeAutoEnableNewAccountConfiguration>? autoEnableNewAccount,
})

Automatically enables Amazon Security Lake for new member accounts in your organization. Security Lake is not automatically enabled for any existing member accounts in your organization.

This operation merges the new data lake organization configuration with the existing configuration for Security Lake in your organization. If you want to create a new data lake organization configuration, you must delete the existing one using DeleteDataLakeOrganizationConfiguration.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter autoEnableNewAccount : Enable Security Lake with the specified configuration settings, to begin collecting security data for new accounts in your organization.

Implementation

Future<void> createDataLakeOrganizationConfiguration({
  List<DataLakeAutoEnableNewAccountConfiguration>? autoEnableNewAccount,
}) async {
  final $payload = <String, dynamic>{
    if (autoEnableNewAccount != null)
      'autoEnableNewAccount': autoEnableNewAccount,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/datalake/organization/configuration',
    exceptionFnMap: _exceptionFns,
  );
}