createSubscriberNotification method

Future<CreateSubscriberNotificationResponse> createSubscriberNotification({
  1. required NotificationConfiguration configuration,
  2. required String subscriberId,
})

Notifies the subscriber when new data is written to the data lake for the sources that the subscriber consumes in Security Lake. You can create only one subscriber notification per subscriber.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter configuration : Specify the configuration using which you want to create the subscriber notification.

Parameter subscriberId : The subscriber ID for the notification subscription.

Implementation

Future<CreateSubscriberNotificationResponse> createSubscriberNotification({
  required NotificationConfiguration configuration,
  required String subscriberId,
}) async {
  final $payload = <String, dynamic>{
    'configuration': configuration,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/v1/subscribers/${Uri.encodeComponent(subscriberId)}/notification',
    exceptionFnMap: _exceptionFns,
  );
  return CreateSubscriberNotificationResponse.fromJson(response);
}