deleteAwsLogSource method

Future<DeleteAwsLogSourceResponse> deleteAwsLogSource({
  1. required List<AwsLogSourceConfiguration> sources,
})

Removes a natively supported Amazon Web Services service as an Amazon Security Lake source. You can remove a source for one or more Regions. When you remove the source, Security Lake stops collecting data from that source in the specified Regions and accounts, and subscribers can no longer consume new data from the source. However, subscribers can still consume data that Security Lake collected from the source before removal.

You can choose any source type in any Amazon Web Services Region for either accounts that are part of a trusted organization or standalone accounts.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter sources : Specify the natively-supported Amazon Web Services service to remove as a source in Security Lake.

Implementation

Future<DeleteAwsLogSourceResponse> deleteAwsLogSource({
  required List<AwsLogSourceConfiguration> sources,
}) async {
  final $payload = <String, dynamic>{
    'sources': sources,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/datalake/logsources/aws/delete',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteAwsLogSourceResponse.fromJson(response);
}