deleteCustomLogSource method

Future<void> deleteCustomLogSource({
  1. required String sourceName,
  2. String? sourceVersion,
})

Removes a custom log source from Amazon Security Lake, to stop sending data from the custom source to Security Lake.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter sourceName : The source name of custom log source that you want to delete.

Parameter sourceVersion : The source version for the third-party custom source. You can limit the custom source removal to the specified source version.

Implementation

Future<void> deleteCustomLogSource({
  required String sourceName,
  String? sourceVersion,
}) async {
  final $query = <String, List<String>>{
    if (sourceVersion != null) 'sourceVersion': [sourceVersion],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v1/datalake/logsources/custom/${Uri.encodeComponent(sourceName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}