deleteDataLake method

Future<void> deleteDataLake({
  1. required List<String> regions,
})

When you disable Amazon Security Lake from your account, Security Lake is disabled in all Amazon Web Services Regions and it stops collecting data from your sources. Also, this API automatically takes steps to remove the account from Security Lake. However, Security Lake retains all of your existing settings and the resources that it created in your Amazon Web Services account in the current Amazon Web Services Region.

The DeleteDataLake operation does not delete the data that is stored in your Amazon S3 bucket, which is owned by your Amazon Web Services account. For more information, see the Amazon Security Lake User Guide.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter regions : The list of Regions where Security Lake is enabled.

Implementation

Future<void> deleteDataLake({
  required List<String> regions,
}) async {
  final $payload = <String, dynamic>{
    'regions': regions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/datalake/delete',
    exceptionFnMap: _exceptionFns,
  );
}