deleteDataLakeOrganizationConfiguration method

Future<void> deleteDataLakeOrganizationConfiguration({
  1. List<DataLakeAutoEnableNewAccountConfiguration>? autoEnableNewAccount,
})

Turns off automatic enablement of Amazon Security Lake for member accounts that are added to an organization in Organizations. Only the delegated Security Lake administrator for an organization can perform this operation. If the delegated Security Lake administrator performs this operation, new member accounts won't automatically contribute data to the data lake.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter autoEnableNewAccount : Turns off automatic enablement of Security Lake for member accounts that are added to an organization.

Implementation

Future<void> deleteDataLakeOrganizationConfiguration({
  List<DataLakeAutoEnableNewAccountConfiguration>? autoEnableNewAccount,
}) async {
  final $payload = <String, dynamic>{
    if (autoEnableNewAccount != null)
      'autoEnableNewAccount': autoEnableNewAccount,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v1/datalake/organization/configuration/delete',
    exceptionFnMap: _exceptionFns,
  );
}