getDataLakeOrganizationConfiguration method
Retrieves the configuration that will be automatically set up for accounts added to the organization after the organization has onboarded to Amazon Security Lake. This API does not take input parameters.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Implementation
Future<GetDataLakeOrganizationConfigurationResponse>
getDataLakeOrganizationConfiguration() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/datalake/organization/configuration',
exceptionFnMap: _exceptionFns,
);
return GetDataLakeOrganizationConfigurationResponse.fromJson(response);
}