getSubscriber method

Future<GetSubscriberResponse> getSubscriber({
  1. required String subscriberId,
})

Retrieves the subscription information for the specified subscription ID. You can get information about a specific subscriber.

May throw AccessDeniedException. May throw BadRequestException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter subscriberId : A value created by Amazon Security Lake that uniquely identifies your GetSubscriber API request.

Implementation

Future<GetSubscriberResponse> getSubscriber({
  required String subscriberId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/subscribers/${Uri.encodeComponent(subscriberId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSubscriberResponse.fromJson(response);
}