listDataLakeExceptions method
Lists the Amazon Security Lake exceptions that you can use to find the source of problems and fix them.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter maxResults :
Lists the maximum number of failures in Security Lake.
Parameter nextToken :
Lists if there are more results available. The value of nextToken is a
unique pagination token for each page. Repeat the call using the returned
token to retrieve the next page. Keep all other arguments unchanged.
Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.
Parameter regions :
The Amazon Web Services Regions from which exceptions are retrieved.
Implementation
Future<ListDataLakeExceptionsResponse> listDataLakeExceptions({
int? maxResults,
String? nextToken,
List<String>? regions,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (regions != null) 'regions': regions,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/datalake/exceptions',
exceptionFnMap: _exceptionFns,
);
return ListDataLakeExceptionsResponse.fromJson(response);
}