updateDataLakeExceptionSubscription method
Updates the specified notification subscription in Amazon Security Lake for the organization you specify.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter notificationEndpoint :
The account that is subscribed to receive exception notifications.
Parameter subscriptionProtocol :
The subscription protocol to which exception messages are posted.
Parameter exceptionTimeToLive :
The time-to-live (TTL) for the exception message to remain. It is the
duration of time until which the exception message remains.
Implementation
Future<void> updateDataLakeExceptionSubscription({
required String notificationEndpoint,
required String subscriptionProtocol,
int? exceptionTimeToLive,
}) async {
final $payload = <String, dynamic>{
'notificationEndpoint': notificationEndpoint,
'subscriptionProtocol': subscriptionProtocol,
if (exceptionTimeToLive != null)
'exceptionTimeToLive': exceptionTimeToLive,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/v1/datalake/exceptions/subscription',
exceptionFnMap: _exceptionFns,
);
}