createPortfolioShare method

Future<CreatePortfolioShareOutput> createPortfolioShare({
  1. required String portfolioId,
  2. String? acceptLanguage,
  3. String? accountId,
  4. OrganizationNode? organizationNode,
  5. bool? sharePrincipals,
  6. bool? shareTagOptions,
})

Shares the specified portfolio with the specified account or organization node. Shares to an organization node can only be created by the management account of an organization or by a delegated administrator. You can share portfolios to an organization, an organizational unit, or a specific account.

Note that if a delegated admin is de-registered, they can no longer create portfolio shares.

AWSOrganizationsAccess must be enabled in order to create a portfolio share to an organization node.

You can't share a shared resource, including portfolios that contain a shared product.

If the portfolio share with the specified account or organization node already exists, this action will have no effect and will not return an error. To update an existing share, you must use the UpdatePortfolioShare API instead.

May throw InvalidParametersException. May throw InvalidStateException. May throw LimitExceededException. May throw OperationNotSupportedException. May throw ResourceNotFoundException.

Parameter portfolioId : The portfolio identifier.

Parameter acceptLanguage : The language code.

  • jp - Japanese
  • zh - Chinese

Parameter accountId : The Amazon Web Services account ID. For example, 123456789012.

Parameter organizationNode : The organization node to whom you are going to share. When you pass OrganizationNode, it creates PortfolioShare for all of the Amazon Web Services accounts that are associated to the OrganizationNode. The output returns a PortfolioShareToken, which enables the administrator to monitor the status of the PortfolioShare creation process.

Parameter sharePrincipals : This parameter is only supported for portfolios with an OrganizationalNode Type of ORGANIZATION or ORGANIZATIONAL_UNIT.

Enables or disables Principal sharing when creating the portfolio share. If you do not provide this flag, principal sharing is disabled.

When you enable Principal Name Sharing for a portfolio share, the share recipient account end users with a principal that matches any of the associated IAM patterns can provision products from the portfolio. Once shared, the share recipient can view associations of PrincipalType: IAM_PATTERN on their portfolio. You can create the principals in the recipient account before or after creating the share.

Parameter shareTagOptions : Enables or disables TagOptions sharing when creating the portfolio share. If this flag is not provided, TagOptions sharing is disabled.

Implementation

Future<CreatePortfolioShareOutput> createPortfolioShare({
  required String portfolioId,
  String? acceptLanguage,
  String? accountId,
  OrganizationNode? organizationNode,
  bool? sharePrincipals,
  bool? shareTagOptions,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWS242ServiceCatalogService.CreatePortfolioShare'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'PortfolioId': portfolioId,
      if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
      if (accountId != null) 'AccountId': accountId,
      if (organizationNode != null) 'OrganizationNode': organizationNode,
      if (sharePrincipals != null) 'SharePrincipals': sharePrincipals,
      if (shareTagOptions != null) 'ShareTagOptions': shareTagOptions,
    },
  );

  return CreatePortfolioShareOutput.fromJson(jsonResponse.body);
}