deletePortfolio method
Deletes the specified portfolio.
You cannot delete a portfolio if it was shared with you or if it has associated products, users, constraints, or shared accounts.
A delegated admin is authorized to invoke this command.
May throw InvalidParametersException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw TagOptionNotMigratedException.
Parameter id :
The portfolio identifier.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Implementation
Future<void> deletePortfolio({
required String id,
String? acceptLanguage,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWS242ServiceCatalogService.DeletePortfolio'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
},
);
}