deleteProvisionedProductPlan method
Deletes the specified plan.
May throw InvalidParametersException.
May throw ResourceNotFoundException.
Parameter planId :
The plan identifier.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Parameter ignoreErrors :
If set to true, Service Catalog stops managing the specified provisioned
product even if it cannot delete the underlying resources.
Implementation
Future<void> deleteProvisionedProductPlan({
required String planId,
String? acceptLanguage,
bool? ignoreErrors,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWS242ServiceCatalogService.DeleteProvisionedProductPlan'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PlanId': planId,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
if (ignoreErrors != null) 'IgnoreErrors': ignoreErrors,
},
);
}