deleteServiceAction method

Future<void> deleteServiceAction({
  1. required String id,
  2. String? acceptLanguage,
  3. String? idempotencyToken,
})

Deletes a self-service action.

May throw InvalidParametersException. May throw ResourceInUseException. May throw ResourceNotFoundException.

Parameter id : The self-service action identifier. For example, act-fs7abcd89wxyz.

Parameter acceptLanguage : The language code.

  • jp - Japanese
  • zh - Chinese

Parameter idempotencyToken : A unique identifier that you provide to ensure idempotency. If multiple requests from the same Amazon Web Services account use the same idempotency token, the same response is returned for each repeated request.

Implementation

Future<void> deleteServiceAction({
  required String id,
  String? acceptLanguage,
  String? idempotencyToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWS242ServiceCatalogService.DeleteServiceAction'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
      'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
    },
  );
}