describeServiceActionExecutionParameters method
Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.
May throw InvalidParametersException.
May throw ResourceNotFoundException.
Parameter provisionedProductId :
The identifier of the provisioned product.
Parameter serviceActionId :
The self-service action identifier.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Implementation
Future<DescribeServiceActionExecutionParametersOutput>
describeServiceActionExecutionParameters({
required String provisionedProductId,
required String serviceActionId,
String? acceptLanguage,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.DescribeServiceActionExecutionParameters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ProvisionedProductId': provisionedProductId,
'ServiceActionId': serviceActionId,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
},
);
return DescribeServiceActionExecutionParametersOutput.fromJson(
jsonResponse.body);
}