disassociateServiceActionFromProvisioningArtifact method

Future<void> disassociateServiceActionFromProvisioningArtifact({
  1. required String productId,
  2. required String provisioningArtifactId,
  3. required String serviceActionId,
  4. String? acceptLanguage,
  5. String? idempotencyToken,
})

Disassociates the specified self-service action association from the specified provisioning artifact.

May throw InvalidParametersException. May throw ResourceNotFoundException.

Parameter productId : The product identifier. For example, prod-abcdzk7xy33qa.

Parameter provisioningArtifactId : The identifier of the provisioning artifact. For example, pa-4abcdjnxjj6ne.

Parameter serviceActionId : The self-service action identifier. For example, act-fs7abcd89wxyz.

Parameter acceptLanguage : The language code.

  • jp - Japanese
  • zh - Chinese

Parameter idempotencyToken : A unique identifier that you provide to ensure idempotency. If multiple requests from the same Amazon Web Services account use the same idempotency token, the same response is returned for each repeated request.

Implementation

Future<void> disassociateServiceActionFromProvisioningArtifact({
  required String productId,
  required String provisioningArtifactId,
  required String serviceActionId,
  String? acceptLanguage,
  String? idempotencyToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWS242ServiceCatalogService.DisassociateServiceActionFromProvisioningArtifact'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ProductId': productId,
      'ProvisioningArtifactId': provisioningArtifactId,
      'ServiceActionId': serviceActionId,
      if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
      'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
    },
  );
}