executeProvisionedProductPlan method
Provisions or modifies a product based on the resource changes for the specified plan.
May throw InvalidParametersException.
May throw InvalidStateException.
May throw ResourceNotFoundException.
Parameter planId :
The plan identifier.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Parameter idempotencyToken :
A unique identifier that you provide to ensure idempotency. If multiple
requests differ only by the idempotency token, the same response is
returned for each repeated request.
Implementation
Future<ExecuteProvisionedProductPlanOutput> executeProvisionedProductPlan({
required String planId,
String? acceptLanguage,
String? idempotencyToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.ExecuteProvisionedProductPlan'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PlanId': planId,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
},
);
return ExecuteProvisionedProductPlanOutput.fromJson(jsonResponse.body);
}