listLaunchPaths method

Future<ListLaunchPathsOutput> listLaunchPaths({
  1. required String productId,
  2. String? acceptLanguage,
  3. int? pageSize,
  4. String? pageToken,
})

Lists the paths to the specified product. A path describes how the user gets access to a specified product and is necessary when provisioning a product. A path also determines the constraints that are put on a product. A path is dependent on a specific product, porfolio, and principal.

May throw InvalidParametersException. May throw ResourceNotFoundException.

Parameter productId : The product identifier.

Parameter acceptLanguage : The language code.

  • jp - Japanese
  • zh - Chinese

Parameter pageSize : The maximum number of items to return with this call.

Parameter pageToken : The page token for the next set of results. To retrieve the first set of results, use null.

Implementation

Future<ListLaunchPathsOutput> listLaunchPaths({
  required String productId,
  String? acceptLanguage,
  int? pageSize,
  String? pageToken,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    0,
    20,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWS242ServiceCatalogService.ListLaunchPaths'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ProductId': productId,
      if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
      if (pageSize != null) 'PageSize': pageSize,
      if (pageToken != null) 'PageToken': pageToken,
    },
  );

  return ListLaunchPathsOutput.fromJson(jsonResponse.body);
}