listProvisioningArtifactsForServiceAction method
Future<ListProvisioningArtifactsForServiceActionOutput>
listProvisioningArtifactsForServiceAction({})
Lists all provisioning artifacts (also known as versions) for the specified self-service action.
May throw InvalidParametersException.
May throw ResourceNotFoundException.
Parameter serviceActionId :
The self-service action identifier. For example,
act-fs7abcd89wxyz.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Parameter pageSize :
The maximum number of items to return with this call.
Parameter pageToken :
The page token for the next set of results. To retrieve the first set of
results, use null.
Implementation
Future<ListProvisioningArtifactsForServiceActionOutput>
listProvisioningArtifactsForServiceAction({
required String serviceActionId,
String? acceptLanguage,
int? pageSize,
String? pageToken,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
0,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.ListProvisioningArtifactsForServiceAction'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServiceActionId': serviceActionId,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
if (pageSize != null) 'PageSize': pageSize,
if (pageToken != null) 'PageToken': pageToken,
},
);
return ListProvisioningArtifactsForServiceActionOutput.fromJson(
jsonResponse.body);
}