listServiceActionsForProvisioningArtifact method
Future<ListServiceActionsForProvisioningArtifactOutput>
listServiceActionsForProvisioningArtifact({})
Returns a paginated list of self-service actions associated with the specified Product ID and Provisioning Artifact ID.
May throw InvalidParametersException.
May throw ResourceNotFoundException.
Parameter productId :
The product identifier. For example, prod-abcdzk7xy33qa.
Parameter provisioningArtifactId :
The identifier of the provisioning artifact. For example,
pa-4abcdjnxjj6ne.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Parameter pageSize :
The maximum number of items to return with this call.
Parameter pageToken :
The page token for the next set of results. To retrieve the first set of
results, use null.
Implementation
Future<ListServiceActionsForProvisioningArtifactOutput>
listServiceActionsForProvisioningArtifact({
required String productId,
required String provisioningArtifactId,
String? acceptLanguage,
int? pageSize,
String? pageToken,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
0,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.ListServiceActionsForProvisioningArtifact'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ProductId': productId,
'ProvisioningArtifactId': provisioningArtifactId,
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
if (pageSize != null) 'PageSize': pageSize,
if (pageToken != null) 'PageToken': pageToken,
},
);
return ListServiceActionsForProvisioningArtifactOutput.fromJson(
jsonResponse.body);
}