notifyUpdateProvisionedProductEngineWorkflowResult method
Notifies the result of the update engine execution.
May throw InvalidParametersException.
May throw ResourceNotFoundException.
Parameter recordId :
The identifier of the record.
Parameter status :
The status of the update engine execution.
Parameter workflowToken :
The encrypted contents of the update engine execution payload that Service
Catalog sends after the Terraform product update workflow starts.
Parameter failureReason :
The reason why the update engine execution failed.
Parameter idempotencyToken :
The idempotency token that identifies the update engine execution.
Parameter outputs :
The output of the update engine execution.
Implementation
Future<void> notifyUpdateProvisionedProductEngineWorkflowResult({
required String recordId,
required EngineWorkflowStatus status,
required String workflowToken,
String? failureReason,
String? idempotencyToken,
List<RecordOutput>? outputs,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.NotifyUpdateProvisionedProductEngineWorkflowResult'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RecordId': recordId,
'Status': status.value,
'WorkflowToken': workflowToken,
if (failureReason != null) 'FailureReason': failureReason,
'IdempotencyToken': idempotencyToken ?? _s.generateIdempotencyToken(),
if (outputs != null) 'Outputs': outputs,
},
);
}