searchProvisionedProducts method
Gets information about the provisioned products that meet the specified criteria.
May throw InvalidParametersException.
Parameter acceptLanguage :
The language code.
-
jp- Japanese -
zh- Chinese
Parameter accessLevelFilter :
The access level to use to obtain results. The default is
Account.
Parameter filters :
The search filters.
When the key is SearchQuery, the searchable fields are
arn, createdTime, id,
lastRecordId, idempotencyToken,
name, physicalId, productId,
provisioningArtifactId, type,
status, tags, userArn,
userArnSession, lastProvisioningRecordId,
lastSuccessfulProvisioningRecordId, productName,
and provisioningArtifactName.
Example: "SearchQuery":["status:AVAILABLE"]
Parameter pageSize :
The maximum number of items to return with this call.
Parameter pageToken :
The page token for the next set of results. To retrieve the first set of
results, use null.
Parameter sortBy :
The sort field. If no value is specified, the results are not sorted. The
valid values are arn, id, name, and
lastRecordId.
Parameter sortOrder :
The sort order. If no value is specified, the results are not sorted.
Implementation
Future<SearchProvisionedProductsOutput> searchProvisionedProducts({
String? acceptLanguage,
AccessLevelFilter? accessLevelFilter,
Map<ProvisionedProductViewFilterBy, List<String>>? filters,
int? pageSize,
String? pageToken,
String? sortBy,
SortOrder? sortOrder,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWS242ServiceCatalogService.SearchProvisionedProducts'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (acceptLanguage != null) 'AcceptLanguage': acceptLanguage,
if (accessLevelFilter != null) 'AccessLevelFilter': accessLevelFilter,
if (filters != null)
'Filters': filters.map((k, e) => MapEntry(k.value, e)),
if (pageSize != null) 'PageSize': pageSize,
if (pageToken != null) 'PageToken': pageToken,
if (sortBy != null) 'SortBy': sortBy,
if (sortOrder != null) 'SortOrder': sortOrder.value,
},
);
return SearchProvisionedProductsOutput.fromJson(jsonResponse.body);
}