ServiceCatalogAppRegistry class

Amazon Web Services Service Catalog AppRegistry enables organizations to understand the application context of their Amazon Web Services resources. AppRegistry provides a repository of your applications, their resources, and the application metadata that you use within your enterprise.

Constructors

ServiceCatalogAppRegistry({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateAttributeGroup({required String application, required String attributeGroup}) Future<AssociateAttributeGroupResponse>
Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.
associateResource({required String application, required String resource, required ResourceType resourceType, List<AssociationOption>? options}) Future<AssociateResourceResponse>
Associates a resource with an application. The resource can be specified by its ARN or name. The application can be specified by ARN, ID, or name.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createApplication({required String name, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateApplicationResponse>
Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.
createAttributeGroup({required String attributes, required String name, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateAttributeGroupResponse>
Creates a new attribute group as a container for user-defined attributes. This feature enables users to have full control over their cloud application's metadata in a rich machine-readable format to facilitate integration with automated workflows and third-party tools.
deleteApplication({required String application}) Future<DeleteApplicationResponse>
Deletes an application that is specified either by its application ID, name, or ARN. All associated attribute groups and resources must be disassociated from it before deleting an application.
deleteAttributeGroup({required String attributeGroup}) Future<DeleteAttributeGroupResponse>
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
disassociateAttributeGroup({required String application, required String attributeGroup}) Future<DisassociateAttributeGroupResponse>
Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application's metadata. This operation reverts AssociateAttributeGroup.
disassociateResource({required String application, required String resource, required ResourceType resourceType}) Future<DisassociateResourceResponse>
Disassociates a resource from application. Both the resource and the application can be specified either by ID or name.
getApplication({required String application}) Future<GetApplicationResponse>
Retrieves metadata information about one of your applications. The application can be specified by its ARN, ID, or name (which is unique within one account in one region at a given point in time). Specify by ARN or ID in automated workflows if you want to make sure that the exact same application is returned or a ResourceNotFoundException is thrown, avoiding the ABA addressing problem.
getAssociatedResource({required String application, required String resource, required ResourceType resourceType, int? maxResults, String? nextToken, List<ResourceItemStatus>? resourceTagStatus}) Future<GetAssociatedResourceResponse>
Gets the resource associated with the application.
getAttributeGroup({required String attributeGroup}) Future<GetAttributeGroupResponse>
Retrieves an attribute group by its ARN, ID, or name. The attribute group can be specified by its ARN, ID, or name.
getConfiguration() Future<GetConfigurationResponse>
Retrieves a TagKey configuration from an account.
listApplications({int? maxResults, String? nextToken}) Future<ListApplicationsResponse>
Retrieves a list of all of your applications. Results are paginated.
listAssociatedAttributeGroups({required String application, int? maxResults, String? nextToken}) Future<ListAssociatedAttributeGroupsResponse>
Lists all attribute groups that are associated with specified application. Results are paginated.
listAssociatedResources({required String application, int? maxResults, String? nextToken}) Future<ListAssociatedResourcesResponse>
Lists all of the resources that are associated with the specified application. Results are paginated.
listAttributeGroups({int? maxResults, String? nextToken}) Future<ListAttributeGroupsResponse>
Lists all attribute groups which you have access to. Results are paginated.
listAttributeGroupsForApplication({required String application, int? maxResults, String? nextToken}) Future<ListAttributeGroupsForApplicationResponse>
Lists the details of all attribute groups associated with a specific application. The results display in pages.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists all of the tags on the resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putConfiguration({required AppRegistryConfiguration configuration}) Future<void>
Associates a TagKey configuration to an account.
syncResource({required String resource, required ResourceType resourceType}) Future<SyncResourceResponse>
Syncs the resource with current AppRegistry records.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Assigns one or more tags (key-value pairs) to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a resource.
updateApplication({required String application, String? description, String? name}) Future<UpdateApplicationResponse>
Updates an existing application with new attributes.
updateAttributeGroup({required String attributeGroup, String? attributes, String? description, String? name}) Future<UpdateAttributeGroupResponse>
Updates an existing attribute group with new details.

Operators

operator ==(Object other) bool
The equality operator.
inherited