getApplication method

Future<GetApplicationResponse> getApplication({
  1. required String application,
})

Retrieves metadata information about one of your applications. The application can be specified by its ARN, ID, or name (which is unique within one account in one region at a given point in time). Specify by ARN or ID in automated workflows if you want to make sure that the exact same application is returned or a ResourceNotFoundException is thrown, avoiding the ABA addressing problem.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter application : The name, ID, or ARN of the application.

Implementation

Future<GetApplicationResponse> getApplication({
  required String application,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/applications/${Uri.encodeComponent(application)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetApplicationResponse.fromJson(response);
}