updateApplication method
Updates an existing application with new attributes.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter application :
The name, ID, or ARN of the application that will be updated.
Parameter description :
The new description of the application.
Parameter name :
Deprecated: The new name of the application. The name must be unique in
the region in which you are updating the application. Please do not use
this field as we have stopped supporting name updates.
Implementation
Future<UpdateApplicationResponse> updateApplication({
required String application,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/applications/${Uri.encodeComponent(application)}',
exceptionFnMap: _exceptionFns,
);
return UpdateApplicationResponse.fromJson(response);
}