updateAttributeGroup method
Updates an existing attribute group with new details.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter attributeGroup :
The name, ID, or ARN of the attribute group that holds the attributes to
describe the application.
Parameter attributes :
A JSON string in the form of nested key-value pairs that represent the
attributes in the group and describes an application and its components.
Parameter description :
The description of the attribute group that the user provides.
Parameter name :
Deprecated: The new name of the attribute group. The name must be unique
in the region in which you are updating the attribute group. Please do not
use this field as we have stopped supporting name updates.
Implementation
Future<UpdateAttributeGroupResponse> updateAttributeGroup({
required String attributeGroup,
String? attributes,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (attributes != null) 'attributes': attributes,
if (description != null) 'description': description,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/attribute-groups/${Uri.encodeComponent(attributeGroup)}',
exceptionFnMap: _exceptionFns,
);
return UpdateAttributeGroupResponse.fromJson(response);
}