deregisterInstance method

Future<DeregisterInstanceResponse> deregisterInstance({
  1. required String instanceId,
  2. required String serviceId,
})

Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map created for the specified instance.

May throw DuplicateRequest. May throw InstanceNotFound. May throw InvalidInput. May throw ResourceInUse. May throw ServiceNotFound.

Parameter instanceId : The value that you specified for Id in the RegisterInstance request.

Parameter serviceId : The ID or Amazon Resource Name (ARN) of the service that the instance is associated with. If the namespace associated with the service is shared with your account, specify the service ARN. For more information about shared namespaces, see Cross-account Cloud Map namespace sharing in the Cloud Map Developer Guide.

Implementation

Future<DeregisterInstanceResponse> deregisterInstance({
  required String instanceId,
  required String serviceId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53AutoNaming_v20170314.DeregisterInstance'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InstanceId': instanceId,
      'ServiceId': serviceId,
    },
  );

  return DeregisterInstanceResponse.fromJson(jsonResponse.body);
}