getInstance method
Gets information about a specified instance.
May throw InstanceNotFound.
May throw InvalidInput.
May throw ServiceNotFound.
Parameter instanceId :
The ID of the instance that you want to get information about.
Parameter serviceId :
The ID or Amazon Resource Name (ARN) of the service that the instance is
associated with. For services created in a shared namespace, specify the
service ARN. For more information about shared namespaces, see Cross-account
Cloud Map namespace sharing in the Cloud Map Developer Guide.
Implementation
Future<GetInstanceResponse> getInstance({
required String instanceId,
required String serviceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53AutoNaming_v20170314.GetInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceId': instanceId,
'ServiceId': serviceId,
},
);
return GetInstanceResponse.fromJson(jsonResponse.body);
}