registerInstance method
Creates or updates one or more records and, optionally, creates a health
check based on the settings in a specified service. When you submit a
RegisterInstance request, the following occurs:
-
For each DNS record that you define in the service that's specified by
ServiceId, a record is created or updated in the hosted zone that's associated with the corresponding namespace. -
If the service includes
HealthCheckConfig, a health check is created based on the settings in the health check configuration. - The health check, if any, is associated with each of the new or updated records.
When Cloud Map receives a DNS query for the specified DNS name, it returns the applicable value:
- If the health check is healthy: returns all the records
- If the health check is unhealthy: returns the applicable value for the last healthy instance
- If you didn't specify a health check configuration: returns all the records
May throw DuplicateRequest.
May throw InvalidInput.
May throw ResourceInUse.
May throw ResourceLimitExceeded.
May throw ServiceNotFound.
Parameter attributes :
A string map that contains the following information for the service that
you specify in ServiceId:
- The attributes that apply to the records that are defined in the service.
- For each attribute, the applicable value.
- AWS_ALIAS_DNS_NAME
-
If you want Cloud Map to create an Amazon Route 53 alias record that
routes traffic to an Elastic Load Balancing load balancer, specify the DNS
name that's associated with the load balancer. For information about how
to get the DNS name, see "DNSName" in the topic AliasTarget
in the Route 53 API Reference.
Note the following:
-
The configuration for the service that's specified by
ServiceIdmust include settings for anArecord, anAAAArecord, or both. -
In the service that's specified by
ServiceId, the value ofRoutingPolicymust beWEIGHTED. -
If the service that's specified by
ServiceIdincludesHealthCheckConfigsettings, Cloud Map will create the Route 53 health check, but it doesn't associate the health check with the alias record. - Cloud Map currently doesn't support creating alias records that route traffic to Amazon Web Services resources other than Elastic Load Balancing load balancers.
-
If you specify a value for
AWS_ALIAS_DNS_NAME, don't specify values for any of theAWS_INSTANCEattributes. -
The
AWS_ALIAS_DNS_NAMEis not supported in the GovCloud (US) Regions.
-
The configuration for the service that's specified by
- AWS_EC2_INSTANCE_ID
-
HTTP namespaces only. The Amazon EC2 instance ID for the instance.
If the
AWS_EC2_INSTANCE_IDattribute is specified, then the only other attribute that can be specified isAWS_INIT_HEALTH_STATUS. When theAWS_EC2_INSTANCE_IDattribute is specified, then theAWS_INSTANCE_IPV4attribute will be filled out with the primary private IPv4 address. - AWS_INIT_HEALTH_STATUS
-
If the service configuration includes
HealthCheckCustomConfig, you can optionally useAWS_INIT_HEALTH_STATUSto specify the initial status of the custom health check,HEALTHYorUNHEALTHY. If you don't specify a value forAWS_INIT_HEALTH_STATUS, the initial status isHEALTHY. - AWS_INSTANCE_CNAME
-
If the service configuration includes a
CNAMErecord, the domain name that you want Route 53 to return in response to DNS queries (for example,example.com).This value is required if the service specified by
ServiceIdincludes settings for anCNAMErecord. - AWS_INSTANCE_IPV4
-
If the service configuration includes an
Arecord, the IPv4 address that you want Route 53 to return in response to DNS queries (for example,192.0.2.44).This value is required if the service specified by
ServiceIdincludes settings for anArecord. If the service includes settings for anSRVrecord, you must specify a value forAWS_INSTANCE_IPV4,AWS_INSTANCE_IPV6, or both. - AWS_INSTANCE_IPV6
-
If the service configuration includes an
AAAArecord, the IPv6 address that you want Route 53 to return in response to DNS queries (for example,2001:0db8:85a3:0000:0000:abcd:0001:2345).This value is required if the service specified by
ServiceIdincludes settings for anAAAArecord. If the service includes settings for anSRVrecord, you must specify a value forAWS_INSTANCE_IPV4,AWS_INSTANCE_IPV6, or both. - AWS_INSTANCE_PORT
-
If the service includes an
SRVrecord, the value that you want Route 53 to return for the port.If the service includes
HealthCheckConfig, the port on the endpoint that you want Route 53 to send requests to.This value is required if you specified settings for an
SRVrecord or a Route 53 health check when you created the service. - Custom attributes
- You can add up to 30 custom attributes. For each key-value pair, the maximum length of the attribute name is 255 characters, and the maximum length of the attribute value is 1,024 characters. The total size of all provided attributes (sum of all keys and values) must not exceed 5,000 characters.
Parameter instanceId :
An identifier that you want to associate with the instance. Note the
following:
-
If the service that's specified by
ServiceIdincludes settings for anSRVrecord, the value ofInstanceIdis automatically included as part of the value for theSRVrecord. For more information, see DnsRecord > Type. - You can use this value to update an existing instance.
- To register a new instance, you must specify a value that's unique among instances that you register by using the same service.
-
If you specify an existing
InstanceIdandServiceId, Cloud Map updates the existing DNS records, if any. If there's also an existing health check, Cloud Map deletes the old health check and creates a new one.
Parameter serviceId :
The ID or Amazon Resource Name (ARN) of the service that you want to use
for settings for the instance. For services created in a shared namespace,
specify the service ARN. For more information about shared namespaces, see
Cross-account
Cloud Map namespace sharing in the Cloud Map Developer Guide.
Parameter creatorRequestId :
A unique string that identifies the request and that allows failed
RegisterInstance requests to be retried without the risk of
executing the operation twice. You must use a unique
CreatorRequestId string every time you submit a
RegisterInstance request if you're registering additional
instances for the same namespace and service.
CreatorRequestId can be any unique string (for example, a
date/time stamp).
Implementation
Future<RegisterInstanceResponse> registerInstance({
required Map<String, String> attributes,
required String instanceId,
required String serviceId,
String? creatorRequestId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53AutoNaming_v20170314.RegisterInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Attributes': attributes,
'InstanceId': instanceId,
'ServiceId': serviceId,
'CreatorRequestId': creatorRequestId ?? _s.generateIdempotencyToken(),
},
);
return RegisterInstanceResponse.fromJson(jsonResponse.body);
}