updateHttpNamespace method

Future<UpdateHttpNamespaceResponse> updateHttpNamespace({
  1. required String id,
  2. required HttpNamespaceChange namespace,
  3. String? updaterRequestId,
})

Updates an HTTP namespace.

May throw DuplicateRequest. May throw InvalidInput. May throw NamespaceNotFound. May throw ResourceInUse.

Parameter id : The ID or Amazon Resource Name (ARN) of the namespace that you want to update.

Parameter namespace : Updated properties for the the HTTP namespace.

Parameter updaterRequestId : A unique string that identifies the request and that allows failed UpdateHttpNamespace requests to be retried without the risk of running the operation twice. UpdaterRequestId can be any unique string (for example, a date/timestamp).

Implementation

Future<UpdateHttpNamespaceResponse> updateHttpNamespace({
  required String id,
  required HttpNamespaceChange namespace,
  String? updaterRequestId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53AutoNaming_v20170314.UpdateHttpNamespace'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'Namespace': namespace,
      'UpdaterRequestId': updaterRequestId ?? _s.generateIdempotencyToken(),
    },
  );

  return UpdateHttpNamespaceResponse.fromJson(jsonResponse.body);
}