updatePrivateDnsNamespace method

Future<UpdatePrivateDnsNamespaceResponse> updatePrivateDnsNamespace({
  1. required String id,
  2. required PrivateDnsNamespaceChange namespace,
  3. String? updaterRequestId,
})

Updates a private DNS namespace.

May throw DuplicateRequest. May throw InvalidInput. May throw NamespaceNotFound. May throw ResourceInUse.

Parameter id : The ID or Amazon Resource Name (ARN) of the namespace that you want to update.

Parameter namespace : Updated properties for the private DNS namespace.

Parameter updaterRequestId : A unique string that identifies the request and that allows failed UpdatePrivateDnsNamespace requests to be retried without the risk of running the operation twice. UpdaterRequestId can be any unique string (for example, a date/timestamp).

Implementation

Future<UpdatePrivateDnsNamespaceResponse> updatePrivateDnsNamespace({
  required String id,
  required PrivateDnsNamespaceChange namespace,
  String? updaterRequestId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Route53AutoNaming_v20170314.UpdatePrivateDnsNamespace'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'Namespace': namespace,
      'UpdaterRequestId': updaterRequestId ?? _s.generateIdempotencyToken(),
    },
  );

  return UpdatePrivateDnsNamespaceResponse.fromJson(jsonResponse.body);
}