ServiceQuotas class
With Service Quotas, you can view and manage your quotas easily as your Amazon Web Services workloads grow. Quotas, also referred to as limits, are the maximum number of resources that you can create in your Amazon Web Services account. For more information, see the Service Quotas User Guide.
You need Amazon Web Services CLI version 2.13.20 or higher to view and
manage resource-level quotas such as Instances per domain for
Amazon OpenSearch Service.
Constructors
- ServiceQuotas({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateServiceQuotaTemplate(
) → Future< void> - Associates your quota request template with your organization. When a new Amazon Web Services account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createSupportCase(
{required String requestId}) → Future< void> -
Creates a Support case for an existing quota increase request. This call
only creates a Support case if the request has a
Pendingstatus. -
deleteServiceQuotaIncreaseRequestFromTemplate(
{required String awsRegion, required String quotaCode, required String serviceCode}) → Future< void> - Deletes the quota increase request for the specified quota from your quota request template.
-
disassociateServiceQuotaTemplate(
) → Future< void> - Disables your quota request template. After a template is disabled, the quota increase requests in the template are not applied to new Amazon Web Services accounts in your organization. Disabling a quota request template does not apply its quota increase requests.
-
getAssociationForServiceQuotaTemplate(
) → Future< GetAssociationForServiceQuotaTemplateResponse> - Retrieves the status of the association for the quota request template.
-
getAutoManagementConfiguration(
) → Future< GetAutoManagementConfigurationResponse> - Retrieves information about your Service Quotas Automatic Management configuration. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
-
getAWSDefaultServiceQuota(
{required String quotaCode, required String serviceCode}) → Future< GetAWSDefaultServiceQuotaResponse> - Retrieves the default value for the specified quota. The default value does not reflect any quota increases.
-
getQuotaUtilizationReport(
{required String reportId, int? maxResults, String? nextToken}) → Future< GetQuotaUtilizationReportResponse> - Retrieves the quota utilization report for your Amazon Web Services account. This operation returns paginated results showing your quota usage across all Amazon Web Services services, sorted by utilization percentage in descending order (highest utilization first).
-
getRequestedServiceQuotaChange(
{required String requestId}) → Future< GetRequestedServiceQuotaChangeResponse> - Retrieves information about the specified quota increase request.
-
getServiceQuota(
{required String quotaCode, required String serviceCode, String? contextId}) → Future< GetServiceQuotaResponse> - Retrieves the applied quota value for the specified account-level or resource-level quota. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.
-
getServiceQuotaIncreaseRequestFromTemplate(
{required String awsRegion, required String quotaCode, required String serviceCode}) → Future< GetServiceQuotaIncreaseRequestFromTemplateResponse> - Retrieves information about the specified quota increase request in your quota request template.
-
listAWSDefaultServiceQuotas(
{required String serviceCode, int? maxResults, String? nextToken}) → Future< ListAWSDefaultServiceQuotasResponse> - Lists the default values for the quotas for the specified Amazon Web Services service. A default value does not reflect any quota increases.
-
listRequestedServiceQuotaChangeHistory(
{int? maxResults, String? nextToken, AppliedLevelEnum? quotaRequestedAtLevel, String? serviceCode, RequestStatus? status}) → Future< ListRequestedServiceQuotaChangeHistoryResponse> - Retrieves the quota increase requests for the specified Amazon Web Services service. Filter responses to return quota requests at either the account level, resource level, or all levels. Responses include any open or closed requests within 90 days.
-
listRequestedServiceQuotaChangeHistoryByQuota(
{required String quotaCode, required String serviceCode, int? maxResults, String? nextToken, AppliedLevelEnum? quotaRequestedAtLevel, RequestStatus? status}) → Future< ListRequestedServiceQuotaChangeHistoryByQuotaResponse> - Retrieves the quota increase requests for the specified quota. Filter responses to return quota requests at either the account level, resource level, or all levels.
-
listServiceQuotaIncreaseRequestsInTemplate(
{String? awsRegion, int? maxResults, String? nextToken, String? serviceCode}) → Future< ListServiceQuotaIncreaseRequestsInTemplateResponse> - Lists the quota increase requests in the specified quota request template.
-
listServiceQuotas(
{required String serviceCode, int? maxResults, String? nextToken, AppliedLevelEnum? quotaAppliedAtLevel, String? quotaCode}) → Future< ListServiceQuotasResponse> - Lists the applied quota values for the specified Amazon Web Services service. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved. Filter responses to return applied quota values at either the account level, resource level, or all levels.
-
listServices(
{int? maxResults, String? nextToken}) → Future< ListServicesResponse> - Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Returns a list of the tags assigned to the specified applied quota.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putServiceQuotaIncreaseRequestIntoTemplate(
{required String awsRegion, required double desiredValue, required String quotaCode, required String serviceCode}) → Future< PutServiceQuotaIncreaseRequestIntoTemplateResponse> - Adds a quota increase request to your quota request template.
-
requestServiceQuotaIncrease(
{required double desiredValue, required String quotaCode, required String serviceCode, String? contextId, bool? supportCaseAllowed}) → Future< RequestServiceQuotaIncreaseResponse> - Submits a quota increase request for the specified quota at the account or resource level.
-
startAutoManagement(
{required OptInLevel optInLevel, required OptInType optInType, Map< String, List< ? exclusionList, String? notificationArn}) → Future<String> >void> - Starts Service Quotas Automatic Management for an Amazon Web Services account, including notification preferences and excluded quotas configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
-
startQuotaUtilizationReport(
) → Future< StartQuotaUtilizationReportResponse> - Initiates the generation of a quota utilization report for your Amazon Web Services account. This asynchronous operation analyzes your quota usage across all Amazon Web Services services and returns a unique report identifier that you can use to retrieve the results.
-
stopAutoManagement(
) → Future< void> - Stops Service Quotas Automatic Management for an Amazon Web Services account and removes all associated configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Adds tags to the specified applied quota. You can include one or more tags to add to the quota.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes tags from the specified applied quota. You can specify one or more tags to remove.
-
updateAutoManagement(
{Map< String, List< ? exclusionList, String? notificationArn, OptInType? optInType}) → Future<String> >void> - Updates your Service Quotas Automatic Management configuration, including notification preferences and excluded quotas. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited