associateServiceQuotaTemplate method

Future<void> associateServiceQuotaTemplate()

Associates your quota request template with your organization. When a new Amazon Web Services account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.

May throw AccessDeniedException. May throw AWSServiceAccessNotEnabledException. May throw DependencyAccessDeniedException. May throw NoAvailableOrganizationException. May throw OrganizationNotInAllFeaturesModeException. May throw ServiceException. May throw TemplatesNotAvailableInRegionException. May throw TooManyRequestsException.

Implementation

Future<void> associateServiceQuotaTemplate() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ServiceQuotasV20190624.AssociateServiceQuotaTemplate'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );
}