createSupportCase method

Future<void> createSupportCase({
  1. required String requestId,
})

Creates a Support case for an existing quota increase request. This call only creates a Support case if the request has a Pending status.

May throw AccessDeniedException. May throw DependencyAccessDeniedException. May throw IllegalArgumentException. May throw InvalidResourceStateException. May throw NoSuchResourceException. May throw ResourceAlreadyExistsException. May throw ServiceException. May throw TooManyRequestsException.

Parameter requestId : The ID of the pending quota increase request for which you want to open a Support case.

Implementation

Future<void> createSupportCase({
  required String requestId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ServiceQuotasV20190624.CreateSupportCase'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'RequestId': requestId,
    },
  );
}