getAutoManagementConfiguration method

Future<GetAutoManagementConfigurationResponse> getAutoManagementConfiguration()

Retrieves information about your Service Quotas Automatic Management configuration. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.

May throw AccessDeniedException. May throw IllegalArgumentException. May throw NoSuchResourceException. May throw ServiceException. May throw TooManyRequestsException.

Implementation

Future<GetAutoManagementConfigurationResponse>
    getAutoManagementConfiguration() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ServiceQuotasV20190624.GetAutoManagementConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );

  return GetAutoManagementConfigurationResponse.fromJson(jsonResponse.body);
}