listServiceQuotaIncreaseRequestsInTemplate method

Future<ListServiceQuotaIncreaseRequestsInTemplateResponse> listServiceQuotaIncreaseRequestsInTemplate({
  1. String? awsRegion,
  2. int? maxResults,
  3. String? nextToken,
  4. String? serviceCode,
})

Lists the quota increase requests in the specified quota request template.

May throw AccessDeniedException. May throw AWSServiceAccessNotEnabledException. May throw DependencyAccessDeniedException. May throw IllegalArgumentException. May throw NoAvailableOrganizationException. May throw ServiceException. May throw TemplatesNotAvailableInRegionException. May throw TooManyRequestsException.

Parameter awsRegion : Specifies the Amazon Web Services Region for which you made the request.

Parameter maxResults : Specifies the maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results.

Parameter nextToken : Specifies a value for receiving additional results after you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from.

Parameter serviceCode : Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.

Implementation

Future<ListServiceQuotaIncreaseRequestsInTemplateResponse>
    listServiceQuotaIncreaseRequestsInTemplate({
  String? awsRegion,
  int? maxResults,
  String? nextToken,
  String? serviceCode,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'ServiceQuotasV20190624.ListServiceQuotaIncreaseRequestsInTemplate'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (awsRegion != null) 'AwsRegion': awsRegion,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
      if (serviceCode != null) 'ServiceCode': serviceCode,
    },
  );

  return ListServiceQuotaIncreaseRequestsInTemplateResponse.fromJson(
      jsonResponse.body);
}