startQuotaUtilizationReport method
Initiates the generation of a quota utilization report for your Amazon Web Services account. This asynchronous operation analyzes your quota usage across all Amazon Web Services services and returns a unique report identifier that you can use to retrieve the results.
The report generation process may take several seconds to complete,
depending on the number of quotas in your account. Use the
GetQuotaUtilizationReport operation to check the status and
retrieve the results when the report is ready.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw InvalidPaginationTokenException.
May throw NoSuchResourceException.
May throw ServiceException.
May throw TooManyRequestsException.
Implementation
Future<StartQuotaUtilizationReportResponse>
startQuotaUtilizationReport() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.StartQuotaUtilizationReport'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return StartQuotaUtilizationReportResponse.fromJson(jsonResponse.body);
}