stopAutoManagement method
Stops Service Quotas Automatic Management for an Amazon Web Services account and removes all associated configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw NoSuchResourceException.
May throw ServiceException.
May throw TooManyRequestsException.
Implementation
Future<void> stopAutoManagement() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.StopAutoManagement'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}