updateAutoManagement method

Future<void> updateAutoManagement({
  1. Map<String, List<String>>? exclusionList,
  2. String? notificationArn,
  3. OptInType? optInType,
})

Updates your Service Quotas Automatic Management configuration, including notification preferences and excluded quotas. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.

May throw AccessDeniedException. May throw IllegalArgumentException. May throw NoSuchResourceException. May throw ServiceException. May throw TooManyRequestsException.

Parameter exclusionList : List of Amazon Web Services services you want to exclude from Automatic Management. You won't be notified of Service Quotas utilization for Amazon Web Services services added to the Automatic Management exclusion list.

Parameter notificationArn : The User Notifications Amazon Resource Name (ARN) for Automatic Management notifications you want to update.

Parameter optInType : Information on the opt-in type for your Automatic Management configuration. There are two modes: Notify only and Notify and Auto-Adjust. Currently, only NotifyOnly is available.

Implementation

Future<void> updateAutoManagement({
  Map<String, List<String>>? exclusionList,
  String? notificationArn,
  OptInType? optInType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'ServiceQuotasV20190624.UpdateAutoManagement'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (exclusionList != null) 'ExclusionList': exclusionList,
      if (notificationArn != null) 'NotificationArn': notificationArn,
      if (optInType != null) 'OptInType': optInType.value,
    },
  );
}