createConfigurationSetEventDestination method

Future<void> createConfigurationSetEventDestination({
  1. required String configurationSetName,
  2. required EventDestination eventDestination,
})

Creates a configuration set event destination. An event destination is the Amazon Web Services service to which Amazon SES publishes the email sending events associated with a configuration set. For information about using configuration sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

May throw ConfigurationSetDoesNotExistException. May throw EventDestinationAlreadyExistsException. May throw InvalidCloudWatchDestinationException. May throw InvalidFirehoseDestinationException. May throw InvalidSNSDestinationException. May throw LimitExceededException.

Parameter configurationSetName : The name of the configuration set that the event destination should be associated with.

Parameter eventDestination : An object that describes the Amazon Web Services service that email sending event where information is published.

Implementation

Future<void> createConfigurationSetEventDestination({
  required String configurationSetName,
  required EventDestination eventDestination,
}) async {
  final $request = <String, String>{
    'ConfigurationSetName': configurationSetName,
    for (var e1 in eventDestination.toQueryMap().entries)
      'EventDestination.${e1.key}': e1.value,
  };
  await _protocol.send(
    $request,
    action: 'CreateConfigurationSetEventDestination',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateConfigurationSetEventDestinationResult',
  );
}