createReceiptFilter method

Future<void> createReceiptFilter({
  1. required ReceiptFilter filter,
})

Creates a new IP address filter.

For information about setting up IP address filters, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

May throw AlreadyExistsException. May throw LimitExceededException.

Parameter filter : A data structure that describes the IP address filter to create, which consists of a name, an IP address range, and whether to allow or block mail from it.

Implementation

Future<void> createReceiptFilter({
  required ReceiptFilter filter,
}) async {
  final $request = <String, String>{
    for (var e1 in filter.toQueryMap().entries) 'Filter.${e1.key}': e1.value,
  };
  await _protocol.send(
    $request,
    action: 'CreateReceiptFilter',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateReceiptFilterResult',
  );
}