createReceiptRuleSet method

Future<void> createReceiptRuleSet({
  1. required String ruleSetName,
})

Creates an empty receipt rule set.

For information about setting up receipt rule sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

May throw AlreadyExistsException. May throw LimitExceededException.

Parameter ruleSetName : The name of the rule set to create. The name must meet the following requirements:

  • Contain only ASCII letters (a-z, A-Z), numbers (0-9), underscores (_), or dashes (-).
  • Start and end with a letter or number.
  • Contain 64 characters or fewer.

Implementation

Future<void> createReceiptRuleSet({
  required String ruleSetName,
}) async {
  final $request = <String, String>{
    'RuleSetName': ruleSetName,
  };
  await _protocol.send(
    $request,
    action: 'CreateReceiptRuleSet',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'CreateReceiptRuleSetResult',
  );
}