deleteIdentity method

Future<void> deleteIdentity({
  1. required String identity,
})

Deletes the specified identity (an email address or a domain) from the list of verified identities.

You can execute this operation no more than once per second.

Parameter identity : The identity to be removed from the list of identities for the Amazon Web Services account.

Implementation

Future<void> deleteIdentity({
  required String identity,
}) async {
  final $request = <String, String>{
    'Identity': identity,
  };
  await _protocol.send(
    $request,
    action: 'DeleteIdentity',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeleteIdentityResult',
  );
}