getIdentityNotificationAttributes method
Given a list of verified identities (email addresses and/or domains), returns a structure describing identity notification attributes.
This operation is throttled at one request per second and can only get notification attributes for up to 100 identities at a time.
For more information about using notifications with Amazon SES, see the Amazon SES Developer Guide.
Parameter identities :
A list of one or more identities. You can specify an identity by using its
name or by using its Amazon Resource Name (ARN). Examples:
user@example.com, example.com,
arn:aws:ses:us-east-1:123456789012:identity/example.com.
Implementation
Future<GetIdentityNotificationAttributesResponse>
getIdentityNotificationAttributes({
required List<String> identities,
}) async {
final $request = <String, String>{
if (identities.isEmpty)
'Identities': ''
else
for (var i1 = 0; i1 < identities.length; i1++)
'Identities.member.${i1 + 1}': identities[i1],
};
final $result = await _protocol.send(
$request,
action: 'GetIdentityNotificationAttributes',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetIdentityNotificationAttributesResult',
);
return GetIdentityNotificationAttributesResponse.fromXml($result);
}