listIdentityPolicies method
Returns a list of sending authorization policies that are attached to the
given identity (an email address or a domain). This operation returns only
a list. To get the actual policy content, use
GetIdentityPolicies.
Sending authorization is a feature that enables an identity owner to
authorize other senders to use its identities. For information about using
sending authorization, see the Amazon
SES Developer Guide.
You can execute this operation no more than once per second.
Parameter identity :
The identity that is associated with the policy for which the policies are
listed. You can specify an identity by using its name or by using its
Amazon Resource Name (ARN). Examples: user@example.com,
example.com,
arn:aws:ses:us-east-1:123456789012:identity/example.com.
To successfully call this operation, you must own the identity.
Implementation
Future<ListIdentityPoliciesResponse> listIdentityPolicies({
required String identity,
}) async {
final $request = <String, String>{
'Identity': identity,
};
final $result = await _protocol.send(
$request,
action: 'ListIdentityPolicies',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListIdentityPoliciesResult',
);
return ListIdentityPoliciesResponse.fromXml($result);
}