listReceiptRuleSets method

Future<ListReceiptRuleSetsResponse> listReceiptRuleSets({
  1. String? nextToken,
})

Lists the receipt rule sets that exist under your Amazon Web Services account in the current Amazon Web Services Region. If there are additional receipt rule sets to be retrieved, you receive a NextToken that you can provide to the next call to ListReceiptRuleSets to retrieve the additional entries.

For information about managing receipt rule sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

Parameter nextToken : A token returned from a previous call to ListReceiptRuleSets to indicate the position in the receipt rule set list.

Implementation

Future<ListReceiptRuleSetsResponse> listReceiptRuleSets({
  String? nextToken,
}) async {
  final $request = <String, String>{
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListReceiptRuleSets',
    version: '2010-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListReceiptRuleSetsResult',
  );
  return ListReceiptRuleSetsResponse.fromXml($result);
}