reorderReceiptRuleSet method
Reorders the receipt rules within a receipt rule set. For information about managing receipt rule sets, see the Amazon SES Developer Guide.
You can execute this operation no more than once per second.
May throw RuleDoesNotExistException.
May throw RuleSetDoesNotExistException.
Parameter ruleNames :
The specified receipt rule set's receipt rules, in order.
Parameter ruleSetName :
The name of the receipt rule set to reorder.
Implementation
Future<void> reorderReceiptRuleSet({
required List<String> ruleNames,
required String ruleSetName,
}) async {
final $request = <String, String>{
if (ruleNames.isEmpty)
'RuleNames': ''
else
for (var i1 = 0; i1 < ruleNames.length; i1++)
'RuleNames.member.${i1 + 1}': ruleNames[i1],
'RuleSetName': ruleSetName,
};
await _protocol.send(
$request,
action: 'ReorderReceiptRuleSet',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ReorderReceiptRuleSetResult',
);
}