setIdentityHeadersInNotificationsEnabled method
Given an identity (an email address or a domain), sets whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type.
You can execute this operation no more than once per second.
For more information about using notifications with Amazon SES, see the Amazon SES Developer Guide.
Parameter enabled :
Sets whether Amazon SES includes the original email headers in Amazon SNS
notifications of the specified notification type. A value of
true specifies that Amazon SES includes headers in
notifications, and a value of false specifies that Amazon SES
does not include headers in notifications.
This value can only be set when NotificationType is already
set to use a particular Amazon SNS topic.
Parameter identity :
The identity for which to enable or disable headers in notifications.
Examples: user@example.com, example.com.
Parameter notificationType :
The notification type for which to enable or disable headers in
notifications.
Implementation
Future<void> setIdentityHeadersInNotificationsEnabled({
required bool enabled,
required String identity,
required NotificationType notificationType,
}) async {
final $request = <String, String>{
'Enabled': enabled.toString(),
'Identity': identity,
'NotificationType': notificationType.value,
};
await _protocol.send(
$request,
action: 'SetIdentityHeadersInNotificationsEnabled',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'SetIdentityHeadersInNotificationsEnabledResult',
);
}