setIdentityMailFromDomain method
Enables or disables the custom MAIL FROM domain setup for a verified identity (an email address or a domain). You can execute this operation no more than once per second.
Parameter identity :
The verified identity.
Parameter behaviorOnMXFailure :
The action for Amazon SES to take if it cannot successfully read the
required MX record when you send an email. If you choose
UseDefaultValue, Amazon SES uses amazonses.com (or a
subdomain of that) as the MAIL FROM domain. If you choose
RejectMessage, Amazon SES returns a
MailFromDomainNotVerified error and not send the email.
The action specified in BehaviorOnMXFailure is taken when the
custom MAIL FROM domain setup is in the Pending,
Failed, and TemporaryFailure states.
Parameter mailFromDomain :
The custom MAIL FROM domain for the verified identity to use. The MAIL
FROM domain must 1) be a subdomain of the verified identity, 2) not be
used in a "From" address if the MAIL FROM domain is the destination of
email feedback forwarding (for more information, see the Amazon SES
Developer Guide), and 3) not be used to receive emails. A value of
null disables the custom MAIL FROM setting for the identity.
Implementation
Future<void> setIdentityMailFromDomain({
required String identity,
BehaviorOnMXFailure? behaviorOnMXFailure,
String? mailFromDomain,
}) async {
final $request = <String, String>{
'Identity': identity,
if (behaviorOnMXFailure != null)
'BehaviorOnMXFailure': behaviorOnMXFailure.value,
if (mailFromDomain != null) 'MailFromDomain': mailFromDomain,
};
await _protocol.send(
$request,
action: 'SetIdentityMailFromDomain',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'SetIdentityMailFromDomainResult',
);
}