updateConfigurationSetEventDestination method
- required String configurationSetName,
- required EventDestination eventDestination,
Updates the event destination of a configuration set. Event destinations are associated with configuration sets, which enable you to publish email sending events to Amazon CloudWatch, Amazon Kinesis Firehose, or Amazon Simple Notification Service (Amazon SNS). For information about using configuration sets, see Monitoring Your Amazon SES Sending Activity in the Amazon SES Developer Guide. You can execute this operation no more than once per second.
May throw ConfigurationSetDoesNotExistException.
May throw EventDestinationDoesNotExistException.
May throw InvalidCloudWatchDestinationException.
May throw InvalidFirehoseDestinationException.
May throw InvalidSNSDestinationException.
Parameter configurationSetName :
The name of the configuration set that contains the event destination.
Parameter eventDestination :
The event destination object.
Implementation
Future<void> updateConfigurationSetEventDestination({
required String configurationSetName,
required EventDestination eventDestination,
}) async {
final $request = <String, String>{
'ConfigurationSetName': configurationSetName,
for (var e1 in eventDestination.toQueryMap().entries)
'EventDestination.${e1.key}': e1.value,
};
await _protocol.send(
$request,
action: 'UpdateConfigurationSetEventDestination',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdateConfigurationSetEventDestinationResult',
);
}