updateConfigurationSetReputationMetricsEnabled method
Enables or disables the publishing of reputation metrics for emails sent using a specific configuration set in a given Amazon Web Services Region. Reputation metrics include bounce and complaint rates. These metrics are published to Amazon CloudWatch. By using CloudWatch, you can create alarms when bounce or complaint rates exceed certain thresholds.
You can execute this operation no more than once per second.
May throw ConfigurationSetDoesNotExistException.
Parameter configurationSetName :
The name of the configuration set to update.
Parameter enabled :
Describes whether or not Amazon SES publishes reputation metrics for the
configuration set, such as bounce and complaint rates, to Amazon
CloudWatch.
Implementation
Future<void> updateConfigurationSetReputationMetricsEnabled({
required String configurationSetName,
required bool enabled,
}) async {
final $request = <String, String>{
'ConfigurationSetName': configurationSetName,
'Enabled': enabled.toString(),
};
await _protocol.send(
$request,
action: 'UpdateConfigurationSetReputationMetricsEnabled',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}