updateReceiptRule method
Updates a receipt rule.
For information about managing receipt rules, see the Amazon SES Developer Guide.
You can execute this operation no more than once per second.
May throw InvalidLambdaFunctionException.
May throw InvalidS3ConfigurationException.
May throw InvalidSnsTopicException.
May throw LimitExceededException.
May throw RuleDoesNotExistException.
May throw RuleSetDoesNotExistException.
Parameter rule :
A data structure that contains the updated receipt rule information.
Parameter ruleSetName :
The name of the receipt rule set that the receipt rule belongs to.
Implementation
Future<void> updateReceiptRule({
required ReceiptRule rule,
required String ruleSetName,
}) async {
final $request = <String, String>{
for (var e1 in rule.toQueryMap().entries) 'Rule.${e1.key}': e1.value,
'RuleSetName': ruleSetName,
};
await _protocol.send(
$request,
action: 'UpdateReceiptRule',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdateReceiptRuleResult',
);
}