batchGetMetricData method
Future<BatchGetMetricDataResponse>
batchGetMetricData({
- required List<
BatchGetMetricDataQuery> queries,
Retrieves batches of metric data collected based on your sending activity.
You can execute this operation no more than 16 times per second, and with at most 160 queries from the batches per second (cumulative).
May throw BadRequestException.
May throw InternalServiceErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter queries :
A list of queries for metrics to be retrieved.
Implementation
Future<BatchGetMetricDataResponse> batchGetMetricData({
required List<BatchGetMetricDataQuery> queries,
}) async {
final $payload = <String, dynamic>{
'Queries': queries,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/metrics/batch',
exceptionFnMap: _exceptionFns,
);
return BatchGetMetricDataResponse.fromJson(response);
}