createCustomVerificationEmailTemplate method
Creates a new custom verification email template.
For more information about custom verification email templates, see Using custom verification email templates in the Amazon SES Developer Guide.
You can execute this operation no more than once per second.
May throw AlreadyExistsException.
May throw BadRequestException.
May throw LimitExceededException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter failureRedirectionURL :
The URL that the recipient of the verification email is sent to if his or
her address is not successfully verified.
Parameter fromEmailAddress :
The email address that the custom verification email is sent from.
Parameter successRedirectionURL :
The URL that the recipient of the verification email is sent to if his or
her address is successfully verified.
Parameter templateContent :
The content of the custom verification email. The total size of the email
must be less than 10 MB. The message body may contain HTML, with some
limitations. For more information, see Custom
verification email frequently asked questions in the Amazon SES
Developer Guide.
Parameter templateName :
The name of the custom verification email template.
Parameter templateSubject :
The subject line of the custom verification email.
Parameter tags :
An array of objects that define the tags (keys and values) to associate
with the custom verification email template.
Implementation
Future<void> createCustomVerificationEmailTemplate({
required String failureRedirectionURL,
required String fromEmailAddress,
required String successRedirectionURL,
required String templateContent,
required String templateName,
required String templateSubject,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'FailureRedirectionURL': failureRedirectionURL,
'FromEmailAddress': fromEmailAddress,
'SuccessRedirectionURL': successRedirectionURL,
'TemplateContent': templateContent,
'TemplateName': templateName,
'TemplateSubject': templateSubject,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/custom-verification-email-templates',
exceptionFnMap: _exceptionFns,
);
}