createDedicatedIpPool method

Future<void> createDedicatedIpPool({
  1. required String poolName,
  2. ScalingMode? scalingMode,
  3. List<Tag>? tags,
})

Create a new pool of dedicated IP addresses. A pool can include one or more dedicated IP addresses that are associated with your Amazon Web Services account. You can associate a pool with a configuration set. When you send an email that uses that configuration set, the message is sent from one of the addresses in the associated pool.

May throw AlreadyExistsException. May throw BadRequestException. May throw ConcurrentModificationException. May throw LimitExceededException. May throw TooManyRequestsException.

Parameter poolName : The name of the dedicated IP pool.

Parameter scalingMode : The type of scaling mode.

Parameter tags : An object that defines the tags (keys and values) that you want to associate with the pool.

Implementation

Future<void> createDedicatedIpPool({
  required String poolName,
  ScalingMode? scalingMode,
  List<Tag>? tags,
}) async {
  final $payload = <String, dynamic>{
    'PoolName': poolName,
    if (scalingMode != null) 'ScalingMode': scalingMode.value,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v2/email/dedicated-ip-pools',
    exceptionFnMap: _exceptionFns,
  );
}