deleteConfigurationSet method

Future<void> deleteConfigurationSet({
  1. required String configurationSetName,
})

Delete an existing configuration set.

Configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.

May throw BadRequestException. May throw ConcurrentModificationException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter configurationSetName : The name of the configuration set.

Implementation

Future<void> deleteConfigurationSet({
  required String configurationSetName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}',
    exceptionFnMap: _exceptionFns,
  );
}