deleteConfigurationSetEventDestination method

Future<void> deleteConfigurationSetEventDestination({
  1. required String configurationSetName,
  2. required String eventDestinationName,
})

Delete an event destination.

Events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon EventBridge and associate a rule to send the event to the specified target.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter configurationSetName : The name of the configuration set that contains the event destination to delete.

Parameter eventDestinationName : The name of the event destination to delete.

Implementation

Future<void> deleteConfigurationSetEventDestination({
  required String configurationSetName,
  required String eventDestinationName,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}/event-destinations/${Uri.encodeComponent(eventDestinationName)}',
    exceptionFnMap: _exceptionFns,
  );
}