deleteTenantResourceAssociation method
Delete an association between a tenant and a resource.
When you delete a tenant-resource association, the resource itself is not deleted, only its association with the specific tenant is removed. After removal, the resource will no longer be available for use with that tenant's email sending operations.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to remove from the tenant
association.
Parameter tenantName :
The name of the tenant to remove the resource association from.
Implementation
Future<void> deleteTenantResourceAssociation({
required String resourceArn,
required String tenantName,
}) async {
final $payload = <String, dynamic>{
'ResourceArn': resourceArn,
'TenantName': tenantName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/tenants/resources/delete',
exceptionFnMap: _exceptionFns,
);
}