getConfigurationSetEventDestinations method
Future<GetConfigurationSetEventDestinationsResponse>
getConfigurationSetEventDestinations({
- required String configurationSetName,
Retrieve a list of event destinations that are associated with a configuration set.
Events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon EventBridge and associate a rule to send the event to the specified target.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter configurationSetName :
The name of the configuration set that contains the event destination.
Implementation
Future<GetConfigurationSetEventDestinationsResponse>
getConfigurationSetEventDestinations({
required String configurationSetName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}/event-destinations',
exceptionFnMap: _exceptionFns,
);
return GetConfigurationSetEventDestinationsResponse.fromJson(response);
}