getEmailAddressInsights method

Future<GetEmailAddressInsightsResponse> getEmailAddressInsights({
  1. required String emailAddress,
})

Provides validation insights about a specific email address, including syntax validation, DNS record checks, mailbox existence, and other deliverability factors.

May throw BadRequestException. May throw TooManyRequestsException.

Parameter emailAddress : The email address to analyze for validation insights.

Implementation

Future<GetEmailAddressInsightsResponse> getEmailAddressInsights({
  required String emailAddress,
}) async {
  final $payload = <String, dynamic>{
    'EmailAddress': emailAddress,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v2/email/email-address-insights',
    exceptionFnMap: _exceptionFns,
  );
  return GetEmailAddressInsightsResponse.fromJson(response);
}