getMessageInsights method

Future<GetMessageInsightsResponse> getMessageInsights({
  1. required String messageId,
})

Provides information about a specific message, including the from address, the subject, the recipient address, email tags, as well as events associated with the message.

You can execute this operation no more than once per second.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter messageId : A MessageId is a unique identifier for a message, and is returned when sending emails through Amazon SES.

Implementation

Future<GetMessageInsightsResponse> getMessageInsights({
  required String messageId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v2/email/insights/${Uri.encodeComponent(messageId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMessageInsightsResponse.fromJson(response);
}