listMultiRegionEndpoints method

Future<ListMultiRegionEndpointsResponse> listMultiRegionEndpoints({
  1. String? nextToken,
  2. int? pageSize,
})

List the multi-region endpoints (global-endpoints).

Only multi-region endpoints (global-endpoints) whose primary region is the AWS-Region where operation is executed will be listed.

May throw BadRequestException. May throw TooManyRequestsException.

Parameter nextToken : A token returned from a previous call to ListMultiRegionEndpoints to indicate the position in the list of multi-region endpoints (global-endpoints).

Parameter pageSize : The number of results to show in a single call to ListMultiRegionEndpoints. If the number of results is larger than the number you specified in this parameter, the response includes a NextToken element that you can use to retrieve the next page of results.

Implementation

Future<ListMultiRegionEndpointsResponse> listMultiRegionEndpoints({
  String? nextToken,
  int? pageSize,
}) async {
  _s.validateNumRange(
    'pageSize',
    pageSize,
    1,
    1000,
  );
  final $query = <String, List<String>>{
    if (nextToken != null) 'NextToken': [nextToken],
    if (pageSize != null) 'PageSize': [pageSize.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v2/email/multi-region-endpoints',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListMultiRegionEndpointsResponse.fromJson(response);
}