putAccountDetails method

Future<void> putAccountDetails({
  1. required MailType mailType,
  2. required String websiteURL,
  3. List<String>? additionalContactEmailAddresses,
  4. ContactLanguage? contactLanguage,
  5. bool? productionAccessEnabled,
  6. String? useCaseDescription,
})

Update your Amazon SES account details.

May throw BadRequestException. May throw ConflictException. May throw TooManyRequestsException.

Parameter mailType : The type of email your account will send.

Parameter websiteURL : The URL of your website. This information helps us better understand the type of content that you plan to send.

Parameter additionalContactEmailAddresses : Additional email addresses that you would like to be notified regarding Amazon SES matters.

Parameter contactLanguage : The language you would prefer to be contacted with.

Parameter productionAccessEnabled : Indicates whether or not your account should have production access in the current Amazon Web Services Region.

If the value is false, then your account is in the sandbox. When your account is in the sandbox, you can only send email to verified identities.

If the value is true, then your account has production access. When your account has production access, you can send email to any address. The sending quota and maximum sending rate for your account vary based on your specific use case.

Parameter useCaseDescription : A description of the types of email that you plan to send.

Implementation

Future<void> putAccountDetails({
  required MailType mailType,
  required String websiteURL,
  List<String>? additionalContactEmailAddresses,
  ContactLanguage? contactLanguage,
  bool? productionAccessEnabled,
  String? useCaseDescription,
}) async {
  final $payload = <String, dynamic>{
    'MailType': mailType.value,
    'WebsiteURL': websiteURL,
    if (additionalContactEmailAddresses != null)
      'AdditionalContactEmailAddresses': additionalContactEmailAddresses,
    if (contactLanguage != null) 'ContactLanguage': contactLanguage.value,
    if (productionAccessEnabled != null)
      'ProductionAccessEnabled': productionAccessEnabled,
    if (useCaseDescription != null) 'UseCaseDescription': useCaseDescription,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/v2/email/account/details',
    exceptionFnMap: _exceptionFns,
  );
}