putAccountVdmAttributes method

Future<void> putAccountVdmAttributes({
  1. required VdmAttributes vdmAttributes,
})

Update your Amazon SES account VDM attributes.

You can execute this operation no more than once per second.

May throw BadRequestException. May throw TooManyRequestsException.

Parameter vdmAttributes : The VDM attributes that you wish to apply to your Amazon SES account.

Implementation

Future<void> putAccountVdmAttributes({
  required VdmAttributes vdmAttributes,
}) async {
  final $payload = <String, dynamic>{
    'VdmAttributes': vdmAttributes,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/v2/email/account/vdm',
    exceptionFnMap: _exceptionFns,
  );
}