putConfigurationSetArchivingOptions method

Future<void> putConfigurationSetArchivingOptions({
  1. required String configurationSetName,
  2. String? archiveArn,
})

Associate the configuration set with a MailManager archive. When you send email using the SendEmail or SendBulkEmail operations the message as it will be given to the receiving SMTP server will be archived, along with the recipient information.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter configurationSetName : The name of the configuration set to associate with a MailManager archive.

Parameter archiveArn : The Amazon Resource Name (ARN) of the MailManager archive that the Amazon SES API v2 sends email to.

Implementation

Future<void> putConfigurationSetArchivingOptions({
  required String configurationSetName,
  String? archiveArn,
}) async {
  final $payload = <String, dynamic>{
    if (archiveArn != null) 'ArchiveArn': archiveArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}/archiving-options',
    exceptionFnMap: _exceptionFns,
  );
}