putConfigurationSetVdmOptions method

Future<void> putConfigurationSetVdmOptions({
  1. required String configurationSetName,
  2. VdmOptions? vdmOptions,
})

Specify VDM preferences for email that you send using the configuration set.

You can execute this operation no more than once per second.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter configurationSetName : The name of the configuration set.

Parameter vdmOptions : The VDM options to apply to the configuration set.

Implementation

Future<void> putConfigurationSetVdmOptions({
  required String configurationSetName,
  VdmOptions? vdmOptions,
}) async {
  final $payload = <String, dynamic>{
    if (vdmOptions != null) 'VdmOptions': vdmOptions,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}/vdm-options',
    exceptionFnMap: _exceptionFns,
  );
}