putEmailIdentityConfigurationSetAttributes method
Used to associate a configuration set with an email identity.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter emailIdentity :
The email address or domain to associate with a configuration set.
Parameter configurationSetName :
The configuration set to associate with an email identity.
Implementation
Future<void> putEmailIdentityConfigurationSetAttributes({
required String emailIdentity,
String? configurationSetName,
}) async {
final $payload = <String, dynamic>{
if (configurationSetName != null)
'ConfigurationSetName': configurationSetName,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v2/email/identities/${Uri.encodeComponent(emailIdentity)}/configuration-set',
exceptionFnMap: _exceptionFns,
);
}