updateConfigurationSetEventDestination method

Future<void> updateConfigurationSetEventDestination({
  1. required String configurationSetName,
  2. required EventDestinationDefinition eventDestination,
  3. required String eventDestinationName,
})

Update the configuration of an event destination for a configuration set.

Events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon EventBridge and associate a rule to send the event to the specified target.

May throw BadRequestException. May throw NotFoundException. May throw TooManyRequestsException.

Parameter configurationSetName : The name of the configuration set that contains the event destination to modify.

Parameter eventDestination : An object that defines the event destination.

Parameter eventDestinationName : The name of the event destination.

Implementation

Future<void> updateConfigurationSetEventDestination({
  required String configurationSetName,
  required EventDestinationDefinition eventDestination,
  required String eventDestinationName,
}) async {
  final $payload = <String, dynamic>{
    'EventDestination': eventDestination,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/v2/email/configuration-sets/${Uri.encodeComponent(configurationSetName)}/event-destinations/${Uri.encodeComponent(eventDestinationName)}',
    exceptionFnMap: _exceptionFns,
  );
}