updateReputationEntityPolicy method
Update the reputation management policy for a reputation entity. The policy determines how the entity responds to reputation findings, such as automatically pausing sending when certain thresholds are exceeded.
Reputation management policies are Amazon Web Services Amazon SES-managed (predefined policies). You can select from none, standard, and strict policies.
May throw BadRequestException.
May throw ConflictException.
May throw TooManyRequestsException.
Parameter reputationEntityPolicy :
The Amazon Resource Name (ARN) of the reputation management policy to
apply to this entity. This is an Amazon Web Services Amazon SES-managed
policy.
Parameter reputationEntityReference :
The unique identifier for the reputation entity. For resource-type
entities, this is the Amazon Resource Name (ARN) of the resource.
Parameter reputationEntityType :
The type of reputation entity. Currently, only RESOURCE type
entities are supported.
Implementation
Future<void> updateReputationEntityPolicy({
required String reputationEntityPolicy,
required String reputationEntityReference,
required ReputationEntityType reputationEntityType,
}) async {
final $payload = <String, dynamic>{
'ReputationEntityPolicy': reputationEntityPolicy,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v2/email/reputation/entities/${Uri.encodeComponent(reputationEntityType.value)}/${Uri.encodeComponent(reputationEntityReference)}/policy',
exceptionFnMap: _exceptionFns,
);
}