listMapRuns method
Lists all Map Runs that were started by a given state machine execution.
Use this API action to obtain Map Run ARNs, and then call
DescribeMapRun to obtain more information, if needed.
May throw ExecutionDoesNotExist.
May throw InvalidArn.
May throw InvalidToken.
Parameter executionArn :
The Amazon Resource Name (ARN) of the execution for which the Map Runs
must be listed.
Parameter maxResults :
The maximum number of results that are returned per call. You can use
nextToken to obtain further pages of results. The default is
100 and the maximum allowed page size is 1000. A value of 0 uses the
default.
This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.
Parameter nextToken :
If nextToken is returned, there are more results available.
The value of nextToken is a unique pagination token for each
page. Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token expires
after 24 hours. Using an expired pagination token will return an HTTP
400 InvalidToken error.
Implementation
Future<ListMapRunsOutput> listMapRuns({
required String executionArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.ListMapRuns'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'executionArn': executionArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListMapRunsOutput.fromJson(jsonResponse.body);
}