sfn_2016_11_23 library

Classes

AwsClientCredentials
AWS credentials.
Sfn
With Step Functions, you can create workflows, also called state machines, to build distributed applications, automate processes, orchestrate microservices, and create data and machine learning pipelines.