Shield class
This is the Shield Advanced API Reference. This guide is for developers who need detailed information about the Shield Advanced API actions, data types, and errors. For detailed information about WAF and Shield Advanced features and an overview of how to use the WAF and Shield Advanced APIs, see the WAF and Shield Developer Guide.
Constructors
- Shield({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateDRTLogBucket(
{required String logBucket}) → Future< void> - Authorizes the Shield Response Team (SRT) to access the specified Amazon S3 bucket containing log data such as Application Load Balancer access logs, CloudFront logs, or logs from third party sources. You can associate up to 10 Amazon S3 buckets with your subscription.
-
associateDRTRole(
{required String roleArn}) → Future< void> - Authorizes the Shield Response Team (SRT) using the specified role, to access your Amazon Web Services account to assist with DDoS attack mitigation during potential attacks. This enables the SRT to inspect your WAF configuration and create or update WAF rules and web ACLs.
-
associateHealthCheck(
{required String healthCheckArn, required String protectionId}) → Future< void> - Adds health-based detection to the Shield Advanced protection for a resource. Shield Advanced health-based detection uses the health of your Amazon Web Services resource to improve responsiveness and accuracy in attack detection and response.
-
associateProactiveEngagementDetails(
{required List< EmergencyContact> emergencyContactList}) → Future<void> - Initializes proactive engagement and sets the list of contacts for the Shield Response Team (SRT) to use. You must provide at least one phone number in the emergency contact list.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createProtection(
{required String name, required String resourceArn, List< Tag> ? tags}) → Future<CreateProtectionResponse> - Enables Shield Advanced for a specific Amazon Web Services resource. The resource can be an Amazon CloudFront distribution, Amazon Route 53 hosted zone, Global Accelerator standard accelerator, Elastic IP Address, Application Load Balancer, or a Classic Load Balancer. You can protect Amazon EC2 instances and Network Load Balancers by association with protected Amazon EC2 Elastic IP addresses.
-
createProtectionGroup(
{required ProtectionGroupAggregation aggregation, required ProtectionGroupPattern pattern, required String protectionGroupId, List< String> ? members, ProtectedResourceType? resourceType, List<Tag> ? tags}) → Future<void> - Creates a grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.
-
createSubscription(
) → Future< void> -
Activates Shield Advanced for an account.
When you initially create a subscription, your subscription is set to be
automatically renewed at the end of the existing subscription period. You
can change this by submitting an
UpdateSubscriptionrequest. -
deleteProtection(
{required String protectionId}) → Future< void> - Deletes an Shield Advanced Protection.
-
deleteProtectionGroup(
{required String protectionGroupId}) → Future< void> - Removes the specified protection group.
-
deleteSubscription(
) → Future< void> - Removes Shield Advanced from an account. Shield Advanced requires a 1-year subscription commitment. You cannot delete a subscription prior to the completion of that commitment.
-
describeAttack(
{required String attackId}) → Future< DescribeAttackResponse> - Describes the details of a DDoS attack.
-
describeAttackStatistics(
) → Future< DescribeAttackStatisticsResponse> - Provides information about the number and type of attacks Shield has detected in the last year for all resources that belong to your account, regardless of whether you've defined Shield protections for them. This operation is available to Shield customers as well as to Shield Advanced customers.
-
describeDRTAccess(
) → Future< DescribeDRTAccessResponse> - Returns the current role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your Amazon Web Services account while assisting with attack mitigation.
-
describeEmergencyContactSettings(
) → Future< DescribeEmergencyContactSettingsResponse> - A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.
-
describeProtection(
{String? protectionId, String? resourceArn}) → Future< DescribeProtectionResponse> - Lists the details of a Protection object.
-
describeProtectionGroup(
{required String protectionGroupId}) → Future< DescribeProtectionGroupResponse> - Returns the specification for the specified protection group.
-
describeSubscription(
) → Future< DescribeSubscriptionResponse> - Provides details about the Shield Advanced subscription for an account.
-
disableApplicationLayerAutomaticResponse(
{required String resourceArn}) → Future< void> - Disable the Shield Advanced automatic application layer DDoS mitigation feature for the protected resource. This stops Shield Advanced from creating, verifying, and applying WAF rules for attacks that it detects for the resource.
-
disableProactiveEngagement(
) → Future< void> - Removes authorization from the Shield Response Team (SRT) to notify contacts about escalations to the SRT and to initiate proactive customer support.
-
disassociateDRTLogBucket(
{required String logBucket}) → Future< void> - Removes the Shield Response Team's (SRT) access to the specified Amazon S3 bucket containing the logs that you shared previously.
-
disassociateDRTRole(
) → Future< void> - Removes the Shield Response Team's (SRT) access to your Amazon Web Services account.
-
disassociateHealthCheck(
{required String healthCheckArn, required String protectionId}) → Future< void> - Removes health-based detection from the Shield Advanced protection for a resource. Shield Advanced health-based detection uses the health of your Amazon Web Services resource to improve responsiveness and accuracy in attack detection and response.
-
enableApplicationLayerAutomaticResponse(
{required ResponseAction action, required String resourceArn}) → Future< void> - Enable the Shield Advanced automatic application layer DDoS mitigation for the protected resource. This causes Shield Advanced to create, verify, and apply WAF rules for DDoS attacks that it detects for the resource. Shield Advanced applies the rules in a Shield rule group inside the web ACL that you've associated with the resource. For information about how automatic mitigation works and the requirements for using it, see Shield Advanced automatic application layer DDoS mitigation. To use this feature, you must associate a web ACL with the protected resource. The web ACL must be created using the latest version of WAF (v2). You can associate the web ACL through the Shield Advanced console at https://console.aws.amazon.com/wafv2/shieldv2#/. For more information, see Getting Started with Shield Advanced. You can also associate the web ACL to the resource through the WAF console or the WAF API, but you must manage Shield Advanced automatic mitigation through Shield Advanced. For information about WAF, see WAF Developer Guide.
-
enableProactiveEngagement(
) → Future< void> - Authorizes the Shield Response Team (SRT) to use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
-
getSubscriptionState(
) → Future< GetSubscriptionStateResponse> -
Returns the
SubscriptionState, eitherActiveorInactive. -
listAttacks(
{TimeRange? endTime, int? maxResults, String? nextToken, List< String> ? resourceArns, TimeRange? startTime}) → Future<ListAttacksResponse> - Returns all ongoing DDoS attacks or all DDoS attacks during a specified time period.
-
listProtectionGroups(
{InclusionProtectionGroupFilters? inclusionFilters, int? maxResults, String? nextToken}) → Future< ListProtectionGroupsResponse> - Retrieves ProtectionGroup objects for the account. You can retrieve all protection groups or you can provide filtering criteria and retrieve just the subset of protection groups that match the criteria.
-
listProtections(
{InclusionProtectionFilters? inclusionFilters, int? maxResults, String? nextToken}) → Future< ListProtectionsResponse> - Retrieves Protection objects for the account. You can retrieve all protections or you can provide filtering criteria and retrieve just the subset of protections that match the criteria.
-
listResourcesInProtectionGroup(
{required String protectionGroupId, int? maxResults, String? nextToken}) → Future< ListResourcesInProtectionGroupResponse> - Retrieves the resources that are included in the protection group.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in Shield.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Adds or updates tags for a resource in Shield.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes tags from a resource in Shield.
-
updateApplicationLayerAutomaticResponse(
{required ResponseAction action, required String resourceArn}) → Future< void> - Updates an existing Shield Advanced automatic application layer DDoS mitigation configuration for the specified resource.
-
updateEmergencyContactSettings(
{List< EmergencyContact> ? emergencyContactList}) → Future<void> - Updates the details of the list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.
-
updateProtectionGroup(
{required ProtectionGroupAggregation aggregation, required ProtectionGroupPattern pattern, required String protectionGroupId, List< String> ? members, ProtectedResourceType? resourceType}) → Future<void> - Updates an existing protection group. A protection group is a grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.
-
updateSubscription(
{AutoRenew? autoRenew}) → Future< void> - Updates the details of an existing subscription. Only enter values for parameters you want to change. Empty parameters are not updated.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited