associateDRTLogBucket method

Future<void> associateDRTLogBucket({
  1. required String logBucket,
})

Authorizes the Shield Response Team (SRT) to access the specified Amazon S3 bucket containing log data such as Application Load Balancer access logs, CloudFront logs, or logs from third party sources. You can associate up to 10 Amazon S3 buckets with your subscription.

To use the services of the SRT and make an AssociateDRTLogBucket request, you must be subscribed to the Business Support plan or the Enterprise Support plan.

May throw AccessDeniedForDependencyException. May throw InternalErrorException. May throw InvalidOperationException. May throw InvalidParameterException. May throw LimitsExceededException. May throw NoAssociatedRoleException. May throw OptimisticLockException. May throw ResourceNotFoundException.

Parameter logBucket : The Amazon S3 bucket that contains the logs that you want to share.

Implementation

Future<void> associateDRTLogBucket({
  required String logBucket,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSShield_20160616.AssociateDRTLogBucket'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LogBucket': logBucket,
    },
  );
}