createSubscription method

Future<void> createSubscription()

Activates Shield Advanced for an account. When you initially create a subscription, your subscription is set to be automatically renewed at the end of the existing subscription period. You can change this by submitting an UpdateSubscription request.

May throw InternalErrorException. May throw ResourceAlreadyExistsException.

Implementation

Future<void> createSubscription() async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSShield_20160616.CreateSubscription'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
  );
}