describeEmergencyContactSettings method
A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.
May throw InternalErrorException.
May throw ResourceNotFoundException.
Implementation
Future<DescribeEmergencyContactSettingsResponse>
describeEmergencyContactSettings() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSShield_20160616.DescribeEmergencyContactSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return DescribeEmergencyContactSettingsResponse.fromJson(jsonResponse.body);
}