untagResource method

Future<void> untagResource({
  1. required String resourceARN,
  2. required List<String> tagKeys,
})

Removes tags from a resource in Shield.

May throw InternalErrorException. May throw InvalidParameterException. May throw InvalidResourceException. May throw ResourceNotFoundException.

Parameter resourceARN : The Amazon Resource Name (ARN) of the resource that you want to remove tags from.

Parameter tagKeys : The tag key for each tag that you want to remove from the resource.

Implementation

Future<void> untagResource({
  required String resourceARN,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSShield_20160616.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceARN': resourceARN,
      'TagKeys': tagKeys,
    },
  );
}