updateApplicationLayerAutomaticResponse method

Future<void> updateApplicationLayerAutomaticResponse({
  1. required ResponseAction action,
  2. required String resourceArn,
})

Updates an existing Shield Advanced automatic application layer DDoS mitigation configuration for the specified resource.

May throw InternalErrorException. May throw InvalidOperationException. May throw InvalidParameterException. May throw OptimisticLockException. May throw ResourceNotFoundException.

Parameter action : Specifies the action setting that Shield Advanced should use in the WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.

Parameter resourceArn : The ARN (Amazon Resource Name) of the resource.

Implementation

Future<void> updateApplicationLayerAutomaticResponse({
  required ResponseAction action,
  required String resourceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSShield_20160616.UpdateApplicationLayerAutomaticResponse'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Action': action,
      'ResourceArn': resourceArn,
    },
  );
}