updateEmergencyContactSettings method
Updates the details of the list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw OptimisticLockException.
May throw ResourceNotFoundException.
Parameter emergencyContactList :
A list of email addresses and phone numbers that the Shield Response Team
(SRT) can use to contact you if you have proactive engagement enabled, for
escalations to the SRT and to initiate proactive customer support.
If you have proactive engagement enabled, the contact list must include at least one phone number.
Implementation
Future<void> updateEmergencyContactSettings({
List<EmergencyContact>? emergencyContactList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSShield_20160616.UpdateEmergencyContactSettings'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (emergencyContactList != null)
'EmergencyContactList': emergencyContactList,
},
);
}