Signer class
AWS Signer is a fully managed code-signing service to help you ensure the trust and integrity of your code.
Signer supports the following applications:
With code signing for AWS Lambda, you can sign AWS Lambda deployment packages. Integrated support is provided for Amazon S3, Amazon CloudWatch, and AWS CloudTrail. In order to sign code, you create a signing profile and then use Signer to sign Lambda zip files in S3.
With code signing for IoT, you can sign code for any IoT device that is supported by AWS. IoT code signing is available for Amazon FreeRTOS and AWS IoT Device Management, and is integrated with AWS Certificate Manager (ACM). In order to sign code, you import a third-party code-signing certificate using ACM, and use that to sign updates in Amazon FreeRTOS and AWS IoT Device Management.
With Signer and the Notation CLI from the Notary Project, you can sign container images stored in a container registry such as Amazon Elastic Container Registry (ECR). The signatures are stored in the registry alongside the images, where they are available for verifying image authenticity and integrity.
For more information about Signer, see the AWS Signer Developer Guide.
Constructors
- Signer({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addProfilePermission(
{required String action, required String principal, required String profileName, required String statementId, String? profileVersion, String? revisionId}) → Future< AddProfilePermissionResponse> - Adds cross-account permissions to a signing profile.
-
cancelSigningProfile(
{required String profileName}) → Future< void> -
Changes the state of an
ACTIVEsigning profile toCANCELED. A canceled profile is still viewable with theListSigningProfilesoperation, but it cannot perform new signing jobs. See Data Retention for more information on scheduled deletion of a canceled signing profile. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
describeSigningJob(
{required String jobId}) → Future< DescribeSigningJobResponse> -
Returns information about a specific code signing job. You specify the job
by using the
jobIdvalue that is returned by the StartSigningJob operation. -
getRevocationStatus(
{required List< String> certificateHashes, required String jobArn, required String platformId, required String profileVersionArn, required DateTime signatureTimestamp}) → Future<GetRevocationStatusResponse> - Retrieves the revocation status of one or more of the signing profile, signing job, and signing certificate.
-
getSigningPlatform(
{required String platformId}) → Future< GetSigningPlatformResponse> - Returns information on a specific signing platform.
-
getSigningProfile(
{required String profileName, String? profileOwner}) → Future< GetSigningProfileResponse> - Returns information on a specific signing profile.
-
listProfilePermissions(
{required String profileName, String? nextToken}) → Future< ListProfilePermissionsResponse> - Lists the cross-account permissions associated with a signing profile.
-
listSigningJobs(
{bool? isRevoked, String? jobInvoker, int? maxResults, String? nextToken, String? platformId, String? requestedBy, DateTime? signatureExpiresAfter, DateTime? signatureExpiresBefore, SigningStatus? status}) → Future< ListSigningJobsResponse> -
Lists all your signing jobs. You can use the
maxResultsparameter to limit the number of signing jobs that are returned in the response. If additional jobs remain to be listed, AWS Signer returns anextTokenvalue. Use this value in subsequent calls toListSigningJobsto fetch the remaining values. You can continue callingListSigningJobswith yourmaxResultsparameter and with new values that Signer returns in thenextTokenparameter until all of your signing jobs have been returned. -
listSigningPlatforms(
{String? category, int? maxResults, String? nextToken, String? partner, String? target}) → Future< ListSigningPlatformsResponse> -
Lists all signing platforms available in AWS Signer that match the request
parameters. If additional jobs remain to be listed, Signer returns a
nextTokenvalue. Use this value in subsequent calls toListSigningJobsto fetch the remaining values. You can continue callingListSigningJobswith yourmaxResultsparameter and with new values that Signer returns in thenextTokenparameter until all of your signing jobs have been returned. -
listSigningProfiles(
{bool? includeCanceled, int? maxResults, String? nextToken, String? platformId, List< SigningProfileStatus> ? statuses}) → Future<ListSigningProfilesResponse> -
Lists all available signing profiles in your AWS account. Returns only
profiles with an
ACTIVEstatus unless theincludeCanceledrequest field is set totrue. If additional jobs remain to be listed, AWS Signer returns anextTokenvalue. Use this value in subsequent calls toListSigningJobsto fetch the remaining values. You can continue callingListSigningJobswith yourmaxResultsparameter and with new values that Signer returns in thenextTokenparameter until all of your signing jobs have been returned. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of the tags associated with a signing profile resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putSigningProfile(
{required String platformId, required String profileName, SigningPlatformOverrides? overrides, SignatureValidityPeriod? signatureValidityPeriod, SigningMaterial? signingMaterial, Map< String, String> ? signingParameters, Map<String, String> ? tags}) → Future<PutSigningProfileResponse> - Creates a signing profile. A signing profile is a code-signing template that can be used to carry out a pre-defined signing job.
-
removeProfilePermission(
{required String profileName, required String revisionId, required String statementId}) → Future< RemoveProfilePermissionResponse> - Removes cross-account permissions from a signing profile.
-
revokeSignature(
{required String jobId, required String reason, String? jobOwner}) → Future< void> -
Changes the state of a signing job to
REVOKED. This indicates that the signature is no longer valid. -
revokeSigningProfile(
{required DateTime effectiveTime, required String profileName, required String profileVersion, required String reason}) → Future< void> -
Changes the state of a signing profile to
REVOKED. This indicates that signatures generated using the signing profile after an effective start date are no longer valid. A revoked profile is still viewable with theListSigningProfilesoperation, but it cannot perform new signing jobs. See Data Retention for more information on scheduled deletion of a revoked signing profile. -
signPayload(
{required Uint8List payload, required String payloadFormat, required String profileName, String? profileOwner}) → Future< SignPayloadResponse> - Signs a binary payload and returns a signature envelope.
-
startSigningJob(
{required Destination destination, required String profileName, required Source source, String? clientRequestToken, String? profileOwner}) → Future< StartSigningJobResponse> -
Initiates a signing job to be performed on the code provided. Signing jobs
are viewable by the
ListSigningJobsoperation. Note the following requirements: -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds one or more tags to a signing profile. Tags are labels that you can use to identify and organize your AWS resources. Each tag consists of a key and an optional value. To specify the signing profile, use its Amazon Resource Name (ARN). To specify the tag, use a key-value pair.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from a signing profile. To remove the tags, specify a list of tag keys.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited