listSigningPlatforms method
Lists all signing platforms available in AWS Signer that match the request
parameters. If additional jobs remain to be listed, Signer returns a
nextToken value. Use this value in subsequent calls to
ListSigningJobs to fetch the remaining values. You can
continue calling ListSigningJobs with your
maxResults parameter and with new values that Signer returns
in the nextToken parameter until all of your signing jobs
have been returned.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter category :
The category type of a signing platform.
Parameter maxResults :
The maximum number of results to be returned by this operation.
Parameter nextToken :
Value for specifying the next set of paginated results to return. After
you receive a response with truncated results, use this parameter in a
subsequent request. Set it to the value of nextToken from the
response that you just received.
Parameter partner :
Any partner entities connected to a signing platform.
Parameter target :
The validation template that is used by the target signing platform.
Implementation
Future<ListSigningPlatformsResponse> listSigningPlatforms({
String? category,
int? maxResults,
String? nextToken,
String? partner,
String? target,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $query = <String, List<String>>{
if (category != null) 'category': [category],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (partner != null) 'partner': [partner],
if (target != null) 'target': [target],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/signing-platforms',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSigningPlatformsResponse.fromJson(response);
}