removeProfilePermission method

Future<RemoveProfilePermissionResponse> removeProfilePermission({
  1. required String profileName,
  2. required String revisionId,
  3. required String statementId,
})

Removes cross-account permissions from a signing profile.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter profileName : A human-readable name for the signing profile with permissions to be removed.

Parameter revisionId : An identifier for the current revision of the signing profile permissions.

Parameter statementId : A unique identifier for the cross-account permissions statement.

Implementation

Future<RemoveProfilePermissionResponse> removeProfilePermission({
  required String profileName,
  required String revisionId,
  required String statementId,
}) async {
  final $query = <String, List<String>>{
    'revisionId': [revisionId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/signing-profiles/${Uri.encodeComponent(profileName)}/permissions/${Uri.encodeComponent(statementId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return RemoveProfilePermissionResponse.fromJson(response);
}