revokeSignature method

Future<void> revokeSignature({
  1. required String jobId,
  2. required String reason,
  3. String? jobOwner,
})

Changes the state of a signing job to REVOKED. This indicates that the signature is no longer valid.

May throw AccessDeniedException. May throw InternalServiceErrorException. May throw ResourceNotFoundException. May throw TooManyRequestsException. May throw ValidationException.

Parameter jobId : ID of the signing job to be revoked.

Parameter reason : The reason for revoking the signing job.

Parameter jobOwner : AWS account ID of the job owner.

Implementation

Future<void> revokeSignature({
  required String jobId,
  required String reason,
  String? jobOwner,
}) async {
  final $payload = <String, dynamic>{
    'reason': reason,
    if (jobOwner != null) 'jobOwner': jobOwner,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri: '/signing-jobs/${Uri.encodeComponent(jobId)}/revoke',
    exceptionFnMap: _exceptionFns,
  );
}