untagResource method
Removes one or more tags from a signing profile. To remove the tags, specify a list of tag keys.
May throw BadRequestException.
May throw InternalServiceErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) for the signing profile.
Parameter tagKeys :
A list of tag keys to be removed from the signing profile.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}