getRevocationStatus method
Retrieves the revocation status for a signed artifact by checking if the signing profile, job, or certificate has been revoked.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter certificateHashes :
List of certificate hashes to check for revocation.
Parameter jobArn :
The ARN of the signing job that produced the signature.
Parameter platformId :
The platform identifier for the signing platform used.
Parameter profileVersionArn :
The ARN of the signing profile version used to sign the artifact.
Parameter signatureTimestamp :
The timestamp when the artifact was signed, in ISO 8601 format.
Implementation
Future<GetRevocationStatusResponse> getRevocationStatus({
required List<String> certificateHashes,
required String jobArn,
required String platformId,
required String profileVersionArn,
required DateTime signatureTimestamp,
}) async {
final $query = <String, List<String>>{
'certificateHashes': certificateHashes,
'jobArn': [jobArn],
'platformId': [platformId],
'profileVersionArn': [profileVersionArn],
'signatureTimestamp': [_s.iso8601ToJson(signatureTimestamp).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/revocations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetRevocationStatusResponse.fromJson(response);
}