SimSpaceWeaver class

SimSpace Weaver (SimSpace Weaver) is a service that you can use to build and run large-scale spatial simulations in the Amazon Web Services Cloud. For example, you can create crowd simulations, large real-world environments, and immersive and interactive experiences. For more information about SimSpace Weaver, see the SimSpace Weaver User Guide .

This API reference describes the API operations and data types that you can use to communicate directly with SimSpace Weaver.

SimSpace Weaver also provides the SimSpace Weaver app SDK, which you use for app development. The SimSpace Weaver app SDK API reference is included in the SimSpace Weaver app SDK documentation. This documentation is part of the SimSpace Weaver app SDK distributable package.

Constructors

SimSpaceWeaver({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createSnapshot({required S3Destination destination, required String simulation}) Future<void>
Creates a snapshot of the specified simulation. A snapshot is a file that contains simulation state data at a specific time. The state data saved in a snapshot includes entity data from the State Fabric, the simulation configuration specified in the schema, and the clock tick number. You can use the snapshot to initialize a new simulation. For more information about snapshots, see Snapshots in the SimSpace Weaver User Guide.
deleteApp({required String app, required String domain, required String simulation}) Future<void>
Deletes the instance of the given custom app.
deleteSimulation({required String simulation}) Future<void>
Deletes all SimSpace Weaver resources assigned to the given simulation.
describeApp({required String app, required String domain, required String simulation}) Future<DescribeAppOutput>
Returns the state of the given custom app.
describeSimulation({required String simulation}) Future<DescribeSimulationOutput>
Returns the current state of the given simulation.
listApps({required String simulation, String? domain, int? maxResults, String? nextToken}) Future<ListAppsOutput>
Lists all custom apps or service apps for the given simulation and domain.
listSimulations({int? maxResults, String? nextToken}) Future<ListSimulationsOutput>
Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists all tags on a SimSpace Weaver resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startApp({required String domain, required String name, required String simulation, String? clientToken, String? description, LaunchOverrides? launchOverrides}) Future<StartAppOutput>
Starts a custom app with the configuration specified in the simulation schema.
startClock({required String simulation}) Future<void>
Starts the simulation clock.
startSimulation({required String name, required String roleArn, String? clientToken, String? description, String? maximumDuration, S3Location? schemaS3Location, S3Location? snapshotS3Location, Map<String, String>? tags}) Future<StartSimulationOutput>
Starts a simulation with the given name. You must choose to start your simulation from a schema or from a snapshot. For more information about the schema, see the schema reference in the SimSpace Weaver User Guide. For more information about snapshots, see Snapshots in the SimSpace Weaver User Guide.
stopApp({required String app, required String domain, required String simulation}) Future<void>
Stops the given custom app and shuts down all of its allocated compute resources.
stopClock({required String simulation}) Future<void>
Stops the simulation clock.
stopSimulation({required String simulation}) Future<void>
Stops the given simulation.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds tags to a SimSpace Weaver resource. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes tags from a SimSpace Weaver resource. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.

Operators

operator ==(Object other) bool
The equality operator.
inherited