createSnapshot method
Creates a snapshot of the specified simulation. A snapshot is a file that contains simulation state data at a specific time. The state data saved in a snapshot includes entity data from the State Fabric, the simulation configuration specified in the schema, and the clock tick number. You can use the snapshot to initialize a new simulation. For more information about snapshots, see Snapshots in the SimSpace Weaver User Guide.
You specify a Destination when you create a snapshot. The
Destination is the name of an Amazon S3 bucket and an
optional ObjectKeyPrefix. The ObjectKeyPrefix is
usually the name of a folder in the bucket. SimSpace Weaver creates a
snapshot folder inside the Destination and
places the snapshot file there.
The snapshot file is an Amazon S3 object. It has an object key with the
form:
object-key-prefix/snapshot/simulation-name-YYMMdd-HHmm-ss.zip,
where:
-
YYis the 2-digit year -
MMis the 2-digit month -
ddis the 2-digit day of the month -
HHis the 2-digit hour (24-hour clock) -
mmis the 2-digit minutes -
ssis the 2-digit seconds
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter destination :
The Amazon S3 bucket and optional folder (object key prefix) where
SimSpace Weaver creates the snapshot file.
The Amazon S3 bucket must be in the same Amazon Web Services Region as the simulation.
Parameter simulation :
The name of the simulation.
Implementation
Future<void> createSnapshot({
required S3Destination destination,
required String simulation,
}) async {
final $payload = <String, dynamic>{
'Destination': destination,
'Simulation': simulation,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/createsnapshot',
exceptionFnMap: _exceptionFns,
);
}