listSimulations method

Future<ListSimulationsOutput> listSimulations({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter maxResults : The maximum number of simulations to list.

Parameter nextToken : If SimSpace Weaver returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn't valid, then you receive an HTTP 400 ValidationException error.

Implementation

Future<ListSimulationsOutput> listSimulations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1152921504606846976,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/listsimulations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSimulationsOutput.fromJson(response);
}