SimpleDBV2 class

Amazon SimpleDB is a web service providing the core database functions of data indexing and querying in the cloud. By offloading the time and effort associated with building and operating a web-scale database, SimpleDB provides developers the freedom to focus on application development. A traditional, clustered relational database requires a sizable upfront capital outlay, is complex to design, and often requires extensive and repetitive database administration. Amazon SimpleDB is dramatically simpler, requiring no schema, automatically indexing your data and providing a simple API for storage and access. This approach eliminates the administrative burden of data modeling, index maintenance, and performance tuning. Developers gain access to this functionality within Amazon's proven computing environment, are able to scale instantly, and pay only for what they use.

Constructors

SimpleDBV2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getExport({required String exportArn}) Future<GetExportResponse>
Returns information for an existing domain export.
listExports({String? domainName, int? maxResults, String? nextToken}) Future<ListExportsResponse>
Lists all exports that were created. The results are paginated and can be filtered by domain name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startDomainExport({required String domainName, required String s3Bucket, String? clientToken, String? s3BucketOwner, String? s3KeyPrefix, S3SseAlgorithm? s3SseAlgorithm, String? s3SseKmsKeyId}) Future<StartDomainExportResponse>
Initiates the export of a SimpleDB domain to an S3 bucket.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited