describeDevice method

Future<DescribeDeviceOutput> describeDevice({
  1. required String managedDeviceId,
})

Checks device-specific information, such as the device type, software version, IP addresses, and lock status.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter managedDeviceId : The ID of the device that you are checking the information of.

Implementation

Future<DescribeDeviceOutput> describeDevice({
  required String managedDeviceId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/managed-device/${Uri.encodeComponent(managedDeviceId)}/describe',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDeviceOutput.fromJson(response);
}