describeDeviceEc2Instances method

Future<DescribeDeviceEc2Output> describeDeviceEc2Instances({
  1. required List<String> instanceIds,
  2. required String managedDeviceId,
})

Checks the current state of the Amazon EC2 instances. The output is similar to describeDevice, but the results are sourced from the device cache in the Amazon Web Services Cloud and include a subset of the available fields.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceIds : A list of instance IDs associated with the managed device.

Parameter managedDeviceId : The ID of the managed device.

Implementation

Future<DescribeDeviceEc2Output> describeDeviceEc2Instances({
  required List<String> instanceIds,
  required String managedDeviceId,
}) async {
  final $payload = <String, dynamic>{
    'instanceIds': instanceIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/managed-device/${Uri.encodeComponent(managedDeviceId)}/resources/ec2/describe',
    exceptionFnMap: _exceptionFns,
  );
  return DescribeDeviceEc2Output.fromJson(response);
}