describeReturnShippingLabel method

Future<DescribeReturnShippingLabelResult> describeReturnShippingLabel({
  1. required String jobId,
})

Information on the shipping label of a Snow device that is being returned to Amazon Web Services.

May throw ConflictException. May throw InvalidJobStateException. May throw InvalidResourceException.

Parameter jobId : The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000.

Implementation

Future<DescribeReturnShippingLabelResult> describeReturnShippingLabel({
  required String jobId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'AWSIESnowballJobManagementService.DescribeReturnShippingLabel'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'JobId': jobId,
    },
  );

  return DescribeReturnShippingLabelResult.fromJson(jsonResponse.body);
}