listPickupLocations method

Future<ListPickupLocationsResult> listPickupLocations({
  1. int? maxResults,
  2. String? nextToken,
})

A list of locations from which the customer can choose to pickup a device.

May throw InvalidResourceException.

Parameter maxResults : The maximum number of locations to list per page.

Parameter nextToken : HTTP requests are stateless. To identify what object comes "next" in the list of ListPickupLocationsRequest objects, you have the option of specifying NextToken as the starting point for your returned list.

Implementation

Future<ListPickupLocationsResult> listPickupLocations({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSIESnowballJobManagementService.ListPickupLocations'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListPickupLocationsResult.fromJson(jsonResponse.body);
}