confirmSubscription method
Verifies an endpoint owner's intent to receive messages by validating the
token sent to the endpoint by an earlier Subscribe action. If
the token is valid, the action creates a new subscription and returns its
Amazon Resource Name (ARN). This call requires an AWS signature only when
the AuthenticateOnUnsubscribe flag is set to "true".
May throw AuthorizationErrorException.
May throw FilterPolicyLimitExceededException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
May throw ReplayLimitExceededException.
May throw SubscriptionLimitExceededException.
Parameter token :
Short-lived token sent to an endpoint during the Subscribe
action.
Parameter topicArn :
The ARN of the topic for which you wish to confirm a subscription.
Parameter authenticateOnUnsubscribe :
Disallows unauthenticated unsubscribes of the subscription. If the value
of this parameter is true and the request has an Amazon Web
Services signature, then only the topic owner and the subscription owner
can unsubscribe the endpoint. The unsubscribe action requires Amazon Web
Services authentication.
Implementation
Future<ConfirmSubscriptionResponse> confirmSubscription({
required String token,
required String topicArn,
String? authenticateOnUnsubscribe,
}) async {
final $request = <String, String>{
'Token': token,
'TopicArn': topicArn,
if (authenticateOnUnsubscribe != null)
'AuthenticateOnUnsubscribe': authenticateOnUnsubscribe,
};
final $result = await _protocol.send(
$request,
action: 'ConfirmSubscription',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ConfirmSubscriptionResult',
);
return ConfirmSubscriptionResponse.fromXml($result);
}