deleteTopic method
Deletes a topic and all its subscriptions. Deleting a topic might prevent some messages previously sent to the topic from being delivered to subscribers. This action is idempotent, so deleting a topic that does not exist does not result in an error.
May throw AuthorizationErrorException.
May throw ConcurrentAccessException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw InvalidStateException.
May throw NotFoundException.
May throw StaleTagException.
May throw TagPolicyException.
Parameter topicArn :
The ARN of the topic you want to delete.
Implementation
Future<void> deleteTopic({
required String topicArn,
}) async {
final $request = <String, String>{
'TopicArn': topicArn,
};
await _protocol.send(
$request,
action: 'DeleteTopic',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}