getPlatformApplicationAttributes method
Future<GetPlatformApplicationAttributesResponse>
getPlatformApplicationAttributes({
- required String platformApplicationArn,
Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications.
May throw AuthorizationErrorException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
Parameter platformApplicationArn :
PlatformApplicationArn for
GetPlatformApplicationAttributesInput.
Implementation
Future<GetPlatformApplicationAttributesResponse>
getPlatformApplicationAttributes({
required String platformApplicationArn,
}) async {
final $request = <String, String>{
'PlatformApplicationArn': platformApplicationArn,
};
final $result = await _protocol.send(
$request,
action: 'GetPlatformApplicationAttributes',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetPlatformApplicationAttributesResult',
);
return GetPlatformApplicationAttributesResponse.fromXml($result);
}