getTopicAttributes method

Future<GetTopicAttributesResponse> getTopicAttributes({
  1. required String topicArn,
})

Returns all of the properties of a topic. Topic properties returned might differ based on the authorization of the user.

May throw AuthorizationErrorException. May throw InternalErrorException. May throw InvalidParameterException. May throw InvalidSecurityException. May throw NotFoundException.

Parameter topicArn : The ARN of the topic whose properties you want to get.

Implementation

Future<GetTopicAttributesResponse> getTopicAttributes({
  required String topicArn,
}) async {
  final $request = <String, String>{
    'TopicArn': topicArn,
  };
  final $result = await _protocol.send(
    $request,
    action: 'GetTopicAttributes',
    version: '2010-03-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'GetTopicAttributesResult',
  );
  return GetTopicAttributesResponse.fromXml($result);
}