listPlatformApplications method
Lists the platform application objects for the supported push notification
services, such as APNS and GCM (Firebase Cloud Messaging). The results for
ListPlatformApplications are paginated and return a limited
list of applications, up to 100. If additional records are available after
the first page results, then a NextToken string will be returned. To
receive the next page, you call ListPlatformApplications
using the NextToken string received from the previous call. When there are
no more records to return, NextToken will be null. For more
information, see Using
Amazon SNS Mobile Push Notifications.
This action is throttled at 15 transactions per second (TPS).
May throw AuthorizationErrorException.
May throw InternalErrorException.
May throw InvalidParameterException.
Parameter nextToken :
NextToken string is used when calling
ListPlatformApplications action to retrieve additional
records that are available after the first page results.
Implementation
Future<ListPlatformApplicationsResponse> listPlatformApplications({
String? nextToken,
}) async {
final $request = <String, String>{
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListPlatformApplications',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListPlatformApplicationsResult',
);
return ListPlatformApplicationsResponse.fromXml($result);
}