listSubscriptionsByTopic method
Returns a list of the subscriptions to a specific topic. Each call returns
a limited list of subscriptions, up to 100. If there are more
subscriptions, a NextToken is also returned. Use the
NextToken parameter in a new
ListSubscriptionsByTopic call to get further results.
This action is throttled at 30 transactions per second (TPS).
May throw AuthorizationErrorException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
Parameter topicArn :
The ARN of the topic for which you wish to find subscriptions.
Parameter nextToken :
Token returned by the previous ListSubscriptionsByTopic
request.
Implementation
Future<ListSubscriptionsByTopicResponse> listSubscriptionsByTopic({
required String topicArn,
String? nextToken,
}) async {
final $request = <String, String>{
'TopicArn': topicArn,
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListSubscriptionsByTopic',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListSubscriptionsByTopicResult',
);
return ListSubscriptionsByTopicResponse.fromXml($result);
}