optInPhoneNumber method
Use this request to opt in a phone number that is opted out, which enables you to resume sending SMS messages to the number.
You can opt in a phone number only once every 30 days.
May throw AuthorizationErrorException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw ThrottledException.
Parameter phoneNumber :
The phone number to opt in. Use E.164 format.
Implementation
Future<void> optInPhoneNumber({
required String phoneNumber,
}) async {
final $request = <String, String>{
'phoneNumber': phoneNumber,
};
await _protocol.send(
$request,
action: 'OptInPhoneNumber',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'OptInPhoneNumberResult',
);
}