removePermission method
Removes a statement from a topic's access control policy.
May throw AuthorizationErrorException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
Parameter label :
The unique label of the statement you want to remove.
Parameter topicArn :
The ARN of the topic whose access control policy you wish to modify.
Implementation
Future<void> removePermission({
required String label,
required String topicArn,
}) async {
final $request = <String, String>{
'Label': label,
'TopicArn': topicArn,
};
await _protocol.send(
$request,
action: 'RemovePermission',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}