setSubscriptionAttributes method
Allows a subscription owner to set an attribute of the subscription to a new value.
May throw AuthorizationErrorException.
May throw FilterPolicyLimitExceededException.
May throw InternalErrorException.
May throw InvalidParameterException.
May throw NotFoundException.
May throw ReplayLimitExceededException.
Parameter attributeName :
A map of attributes with their corresponding values.
The following lists the names, descriptions, and values of the special request parameters that this action uses:
-
DeliveryPolicy– The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints. -
FilterPolicy– The simple JSON object that lets your subscriber receive only a subset of messages, rather than receiving every message published to the topic. -
FilterPolicyScope– This attribute lets you choose the filtering scope by using one of the following string value types:-
MessageAttributes(default) – The filter is applied on the message attributes. -
MessageBody– The filter is applied on the message body.
-
-
RawMessageDelivery– When set totrue, enables raw message delivery to Amazon SQS or HTTP/S endpoints. This eliminates the need for the endpoints to process JSON formatting, which is otherwise created for Amazon SNS metadata. -
RedrivePolicy– When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing.
-
SubscriptionRoleArn– The ARN of the IAM role that has the following:- Permission to write to the Firehose delivery stream
- Amazon SNS listed as a trusted entity
Parameter subscriptionArn :
The ARN of the subscription to modify.
Parameter attributeValue :
The new value for the attribute in JSON format.
Implementation
Future<void> setSubscriptionAttributes({
required String attributeName,
required String subscriptionArn,
String? attributeValue,
}) async {
final $request = <String, String>{
'AttributeName': attributeName,
'SubscriptionArn': subscriptionArn,
if (attributeValue != null) 'AttributeValue': attributeValue,
};
await _protocol.send(
$request,
action: 'SetSubscriptionAttributes',
version: '2010-03-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}