untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Remove tags from the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide.

May throw AuthorizationErrorException. May throw ConcurrentAccessException. May throw InvalidParameterException. May throw ResourceNotFoundException. May throw StaleTagException. May throw TagLimitExceededException. May throw TagPolicyException.

Parameter resourceArn : The ARN of the topic from which to remove tags.

Parameter tagKeys : The list of tag keys to remove from the specified topic.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final $request = <String, String>{
    'ResourceArn': resourceArn,
    if (tagKeys.isEmpty)
      'TagKeys': ''
    else
      for (var i1 = 0; i1 < tagKeys.length; i1++)
        'TagKeys.member.${i1 + 1}': tagKeys[i1],
  };
  await _protocol.send(
    $request,
    action: 'UntagResource',
    version: '2010-03-31',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'UntagResourceResult',
  );
}