changeMessageVisibility method
Changes the visibility timeout of a specified message in a queue to a new value. The default visibility timeout for a message is 30 seconds. The minimum is 0 seconds. The maximum is 12 hours. For more information, see Visibility Timeout in the Amazon SQS Developer Guide.
For example, if the default timeout for a queue is 60 seconds, 15 seconds
have elapsed since you received the message, and you send a
ChangeMessageVisibility call with VisibilityTimeout set to 10
seconds, the 10 seconds begin to count from the time that you make the
ChangeMessageVisibility call. Thus, any attempt to change the
visibility timeout or to delete that message 10 seconds after you
initially change the visibility timeout (a total of 25 seconds) might
result in an error.
An Amazon SQS message has three basic states:
- Sent to a queue by a producer.
- Received from the queue by a consumer.
- Deleted from the queue.
Limits that apply to in flight messages are unrelated to the unlimited number of stored messages.
For most standard queues (depending on queue traffic and message backlog),
there can be a maximum of approximately 120,000 in flight messages
(received from a queue by a consumer, but not yet deleted from the queue).
If you reach this limit, Amazon SQS returns the OverLimit
error message. To avoid reaching the limit, you should delete messages
from the queue after they're processed. You can also increase the number
of queues you use to process your messages. To request a limit increase,
file
a support request.
For FIFO queues, there can be a maximum of 120,000 in flight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns no error messages.
Unlike with a queue, when you change the visibility timeout for a specific
message the timeout value is applied immediately but isn't saved in memory
for that message. If you don't delete a message after it is received, the
visibility timeout for the message reverts to the original timeout value
(not to the value you set using the ChangeMessageVisibility
action) the next time the message is received.
May throw InvalidAddress.
May throw InvalidSecurity.
May throw MessageNotInflight.
May throw QueueDoesNotExist.
May throw ReceiptHandleIsInvalid.
May throw RequestThrottled.
May throw UnsupportedOperation.
Parameter queueUrl :
The URL of the Amazon SQS queue whose message's visibility is changed.
Queue URLs and names are case-sensitive.
Parameter receiptHandle :
The receipt handle associated with the message, whose visibility timeout
is changed. This parameter is returned by the ReceiveMessage
action.
Parameter visibilityTimeout :
The new value for the message's visibility timeout (in seconds). Values
range: 0 to 43200. Maximum: 12 hours.
Implementation
Future<void> changeMessageVisibility({
required String queueUrl,
required String receiptHandle,
required int visibilityTimeout,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonSQS.ChangeMessageVisibility'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'QueueUrl': queueUrl,
'ReceiptHandle': receiptHandle,
'VisibilityTimeout': visibilityTimeout,
},
);
}