purgeQueue method
Deletes available messages in a queue (including in-flight messages)
specified by the QueueURL parameter.
The message deletion process takes up to 60 seconds. We recommend waiting
for 60 seconds regardless of your queue's size.
Messages sent to the queue before you call PurgeQueue
might be received but are deleted within the next minute.
Messages sent to the queue after you call PurgeQueue
might be deleted while the queue is being purged.
May throw InvalidAddress.
May throw InvalidSecurity.
May throw PurgeQueueInProgress.
May throw QueueDoesNotExist.
May throw RequestThrottled.
May throw UnsupportedOperation.
Parameter queueUrl :
The URL of the queue from which the PurgeQueue action deletes
messages.
Queue URLs and names are case-sensitive.
Implementation
Future<void> purgeQueue({
required String queueUrl,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonSQS.PurgeQueue'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'QueueUrl': queueUrl,
},
);
}