untagQueue method

Future<void> untagQueue({
  1. required String queueUrl,
  2. required List<String> tagKeys,
})

Remove cost allocation tags from the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.

May throw InvalidAddress. May throw InvalidSecurity. May throw QueueDoesNotExist. May throw RequestThrottled. May throw UnsupportedOperation.

Parameter queueUrl : The URL of the queue.

Parameter tagKeys : The list of tags to be removed from the specified queue.

Implementation

Future<void> untagQueue({
  required String queueUrl,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AmazonSQS.UntagQueue'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'QueueUrl': queueUrl,
      'TagKeys': tagKeys,
    },
  );
}