Ssm class
Amazon Web Services Systems Manager is the operations hub for your Amazon Web Services applications and resources and a secure end-to-end management solution for hybrid cloud environments that enables safe and secure operations at scale.
This reference is intended to be used with the Amazon Web Services Systems Manager User Guide. To get started, see Setting up Amazon Web Services Systems Manager.
Related resources
- For information about each of the tools that comprise Systems Manager, see Using Systems Manager tools in the Amazon Web Services Systems Manager User Guide.
- For details about predefined runbooks for Automation, a tool in Amazon Web Services Systems Manager, see the Systems Manager Automation Runbook Reference .
- For information about AppConfig, a tool in Systems Manager, see the AppConfig User Guide and the AppConfig API Reference .
- For information about Incident Manager, a tool in Systems Manager, see the Systems Manager Incident Manager User Guide and the Systems Manager Incident Manager API Reference .
Constructors
- Ssm({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTagsToResource(
{required String resourceId, required ResourceTypeForTagging resourceType, required List< Tag> tags}) → Future<void> - Adds or overwrites one or more tags for the specified resource. Tags are metadata that you can assign to your automations, documents, managed nodes, maintenance windows, Parameter Store parameters, and patch baselines. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. Each tag consists of a key and an optional value, both of which you define. For example, you could define a set of tags for your account's managed nodes that helps you track each node's owner and stack level. For example:
-
associateOpsItemRelatedItem(
{required String associationType, required String opsItemId, required String resourceType, required String resourceUri}) → Future< AssociateOpsItemRelatedItemResponse> - Associates a related item to a Systems Manager OpsCenter OpsItem. For example, you can associate an Incident Manager incident or analysis with an OpsItem. Incident Manager and OpsCenter are tools in Amazon Web Services Systems Manager.
-
cancelCommand(
{required String commandId, List< String> ? instanceIds}) → Future<void> - Attempts to cancel the command specified by the Command ID. There is no guarantee that the command will be terminated and the underlying process stopped.
-
cancelMaintenanceWindowExecution(
{required String windowExecutionId}) → Future< CancelMaintenanceWindowExecutionResult> - Stops a maintenance window execution that is already in progress and cancels any tasks in the window that haven't already starting running. Tasks already in progress will continue to completion.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createActivation(
{required String iamRole, String? defaultInstanceName, String? description, DateTime? expirationDate, int? registrationLimit, List< RegistrationMetadataItem> ? registrationMetadata, List<Tag> ? tags}) → Future<CreateActivationResult> - Generates an activation code and activation ID you can use to register your on-premises servers, edge devices, or virtual machine (VM) with Amazon Web Services Systems Manager. Registering these machines with Systems Manager makes it possible to manage them using Systems Manager tools. You use the activation code and ID when installing SSM Agent on machines in your hybrid environment. For more information about requirements for managing on-premises machines using Systems Manager, see Using Amazon Web Services Systems Manager in hybrid and multicloud environments in the Amazon Web Services Systems Manager User Guide.
-
createAssociation(
{required String name, AlarmConfiguration? alarmConfiguration, bool? applyOnlyAtCronInterval, String? associationDispatchAssumeRole, String? associationName, String? automationTargetParameterName, List< String> ? calendarNames, AssociationComplianceSeverity? complianceSeverity, String? documentVersion, int? duration, String? instanceId, String? maxConcurrency, String? maxErrors, InstanceAssociationOutputLocation? outputLocation, Map<String, List< ? parameters, String? scheduleExpression, int? scheduleOffset, AssociationSyncCompliance? syncCompliance, List<String> >Tag> ? tags, List<TargetLocation> ? targetLocations, List<Map< ? targetMaps, List<String, List< >String> >Target> ? targets}) → Future<CreateAssociationResult> - A State Manager association defines the state that you want to maintain on your managed nodes. For example, an association can specify that anti-virus software must be installed and running on your managed nodes, or that certain ports must be closed. For static targets, the association specifies a schedule for when the configuration is reapplied. For dynamic targets, such as an Amazon Web Services resource group or an Amazon Web Services autoscaling group, State Manager, a tool in Amazon Web Services Systems Manager applies the configuration when new managed nodes are added to the group. The association also specifies actions to take when applying the configuration. For example, an association for anti-virus software might run once a day. If the software isn't installed, then State Manager installs it. If the software is installed, but the service isn't running, then the association might instruct State Manager to start the service.
-
createAssociationBatch(
{required List< CreateAssociationBatchRequestEntry> entries, String? associationDispatchAssumeRole}) → Future<CreateAssociationBatchResult> - Associates the specified Amazon Web Services Systems Manager document (SSM document) with the specified managed nodes or targets.
-
createDocument(
{required String content, required String name, List< AttachmentsSource> ? attachments, String? displayName, DocumentFormat? documentFormat, DocumentType? documentType, List<DocumentRequires> ? requires, List<Tag> ? tags, String? targetType, String? versionName}) → Future<CreateDocumentResult> - Creates a Amazon Web Services Systems Manager (SSM document). An SSM document defines the actions that Systems Manager performs on your managed nodes. For more information about SSM documents, including information about supported schemas, features, and syntax, see Amazon Web Services Systems Manager Documents in the Amazon Web Services Systems Manager User Guide.
-
createMaintenanceWindow(
{required bool allowUnassociatedTargets, required int cutoff, required int duration, required String name, required String schedule, String? clientToken, String? description, String? endDate, int? scheduleOffset, String? scheduleTimezone, String? startDate, List< Tag> ? tags}) → Future<CreateMaintenanceWindowResult> - Creates a new maintenance window.
-
createOpsItem(
{required String description, required String source, required String title, String? accountId, DateTime? actualEndTime, DateTime? actualStartTime, String? category, List< OpsItemNotification> ? notifications, Map<String, OpsItemDataValue> ? operationalData, String? opsItemType, DateTime? plannedEndTime, DateTime? plannedStartTime, int? priority, String? severity, List<Tag> ? tags}) → Future<CreateOpsItemResponse> - Creates a new OpsItem. You must have permission in Identity and Access Management (IAM) to create a new OpsItem. For more information, see Set up OpsCenter in the Amazon Web Services Systems Manager User Guide.
-
createOpsMetadata(
{required String resourceId, Map< String, MetadataValue> ? metadata, List<Tag> ? tags}) → Future<CreateOpsMetadataResult> - If you create a new application in Application Manager, Amazon Web Services Systems Manager calls this API operation to specify information about the new application, including the application type.
-
createPatchBaseline(
{required String name, PatchRuleGroup? approvalRules, List< String> ? approvedPatches, PatchComplianceLevel? approvedPatchesComplianceLevel, bool? approvedPatchesEnableNonSecurity, PatchComplianceStatus? availableSecurityUpdatesComplianceStatus, String? clientToken, String? description, PatchFilterGroup? globalFilters, OperatingSystem? operatingSystem, List<String> ? rejectedPatches, PatchAction? rejectedPatchesAction, List<PatchSource> ? sources, List<Tag> ? tags}) → Future<CreatePatchBaselineResult> - Creates a patch baseline.
-
createResourceDataSync(
{required String syncName, ResourceDataSyncS3Destination? s3Destination, ResourceDataSyncSource? syncSource, String? syncType}) → Future< void> -
A resource data sync helps you view data from multiple sources in a single
location. Amazon Web Services Systems Manager offers two types of resource
data sync:
SyncToDestinationandSyncFromSource. -
deleteActivation(
{required String activationId}) → Future< void> - Deletes an activation. You aren't required to delete an activation. If you delete an activation, you can no longer use it to register additional managed nodes. Deleting an activation doesn't de-register managed nodes. You must manually de-register managed nodes.
-
deleteAssociation(
{String? associationId, String? instanceId, String? name}) → Future< void> -
Disassociates the specified Amazon Web Services Systems Manager document
(SSM document) from the specified managed node. If you created the
association by using the
Targetsparameter, then you must delete the association by using the association ID. -
deleteDocument(
{required String name, String? documentVersion, bool? force, String? versionName}) → Future< void> - Deletes the Amazon Web Services Systems Manager document (SSM document) and all managed node associations to the document.
-
deleteInventory(
{required String typeName, String? clientToken, bool? dryRun, InventorySchemaDeleteOption? schemaDeleteOption}) → Future< DeleteInventoryResult> - Delete a custom inventory type or the data associated with a custom Inventory type. Deleting a custom inventory type is also referred to as deleting a custom inventory schema.
-
deleteMaintenanceWindow(
{required String windowId}) → Future< DeleteMaintenanceWindowResult> - Deletes a maintenance window.
-
deleteOpsItem(
{required String opsItemId}) → Future< void> - Delete an OpsItem. You must have permission in Identity and Access Management (IAM) to delete an OpsItem.
-
deleteOpsMetadata(
{required String opsMetadataArn}) → Future< void> - Delete OpsMetadata related to an application.
-
deleteParameter(
{required String name}) → Future< void> - Delete a parameter from the system. After deleting a parameter, wait for at least 30 seconds to create a parameter with the same name.
-
deleteParameters(
{required List< String> names}) → Future<DeleteParametersResult> - Delete a list of parameters. After deleting a parameter, wait for at least 30 seconds to create a parameter with the same name.
-
deletePatchBaseline(
{required String baselineId}) → Future< DeletePatchBaselineResult> - Deletes a patch baseline.
-
deleteResourceDataSync(
{required String syncName, String? syncType}) → Future< void> - Deletes a resource data sync configuration. After the configuration is deleted, changes to data on managed nodes are no longer synced to or from the target. Deleting a sync configuration doesn't delete data.
-
deleteResourcePolicy(
{required String policyHash, required String policyId, required String resourceArn}) → Future< void> - Deletes a Systems Manager resource policy. A resource policy helps you to define the IAM entity (for example, an Amazon Web Services account) that can manage your Systems Manager resources. The following resources support Systems Manager resource policies.
-
deregisterManagedInstance(
{required String instanceId}) → Future< void> - Removes the server or virtual machine from the list of registered servers.
-
deregisterPatchBaselineForPatchGroup(
{required String baselineId, required String patchGroup}) → Future< DeregisterPatchBaselineForPatchGroupResult> - Removes a patch group from a patch baseline.
-
deregisterTargetFromMaintenanceWindow(
{required String windowId, required String windowTargetId, bool? safe}) → Future< DeregisterTargetFromMaintenanceWindowResult> - Removes a target from a maintenance window.
-
deregisterTaskFromMaintenanceWindow(
{required String windowId, required String windowTaskId}) → Future< DeregisterTaskFromMaintenanceWindowResult> - Removes a task from a maintenance window.
-
describeActivations(
{List< DescribeActivationsFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeActivationsResult> - Describes details about the activation, such as the date and time the activation was created, its expiration date, the Identity and Access Management (IAM) role assigned to the managed nodes in the activation, and the number of nodes registered by using this activation.
-
describeAssociation(
{String? associationId, String? associationVersion, String? instanceId, String? name}) → Future< DescribeAssociationResult> -
Describes the association for the specified target or managed node. If you
created the association by using the
Targetsparameter, then you must retrieve the association by using the association ID. -
describeAssociationExecutions(
{required String associationId, List< AssociationExecutionFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeAssociationExecutionsResult> - Views all executions for a specific association ID.
-
describeAssociationExecutionTargets(
{required String associationId, required String executionId, List< AssociationExecutionTargetsFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeAssociationExecutionTargetsResult> - Views information about a specific execution of a specific association.
-
describeAutomationExecutions(
{List< AutomationExecutionFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeAutomationExecutionsResult> - Provides details about all active and terminated Automation executions.
-
describeAutomationStepExecutions(
{required String automationExecutionId, List< StepExecutionFilter> ? filters, int? maxResults, String? nextToken, bool? reverseOrder}) → Future<DescribeAutomationStepExecutionsResult> - Information about all active and terminated step executions in an Automation workflow.
-
describeAvailablePatches(
{List< PatchOrchestratorFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeAvailablePatchesResult> - Lists all patches eligible to be included in a patch baseline.
-
describeDocument(
{required String name, String? documentVersion, String? versionName}) → Future< DescribeDocumentResult> - Describes the specified Amazon Web Services Systems Manager document (SSM document).
-
describeDocumentPermission(
{required String name, required DocumentPermissionType permissionType, int? maxResults, String? nextToken}) → Future< DescribeDocumentPermissionResponse> - Describes the permissions for a Amazon Web Services Systems Manager document (SSM document). If you created the document, you are the owner. If a document is shared, it can either be shared privately (by specifying a user's Amazon Web Services account ID) or publicly (All).
-
describeEffectiveInstanceAssociations(
{required String instanceId, int? maxResults, String? nextToken}) → Future< DescribeEffectiveInstanceAssociationsResult> - All associations for the managed nodes.
-
describeEffectivePatchesForPatchBaseline(
{required String baselineId, int? maxResults, String? nextToken}) → Future< DescribeEffectivePatchesForPatchBaselineResult> - Retrieves the current effective patches (the patch and the approval state) for the specified patch baseline. Applies to patch baselines for Windows only.
-
describeInstanceAssociationsStatus(
{required String instanceId, int? maxResults, String? nextToken}) → Future< DescribeInstanceAssociationsStatusResult> - The status of the associations for the managed nodes.
-
describeInstanceInformation(
{List< InstanceInformationStringFilter> ? filters, List<InstanceInformationFilter> ? instanceInformationFilterList, int? maxResults, String? nextToken}) → Future<DescribeInstanceInformationResult> - Provides information about one or more of your managed nodes, including the operating system platform, SSM Agent version, association status, and IP address. This operation does not return information for nodes that are either Stopped or Terminated.
-
describeInstancePatches(
{required String instanceId, List< PatchOrchestratorFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeInstancePatchesResult> - Retrieves information about the patches on the specified managed node and their state relative to the patch baseline being used for the node.
-
describeInstancePatchStates(
{required List< String> instanceIds, int? maxResults, String? nextToken}) → Future<DescribeInstancePatchStatesResult> - Retrieves the high-level patch state of one or more managed nodes.
-
describeInstancePatchStatesForPatchGroup(
{required String patchGroup, List< InstancePatchStateFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeInstancePatchStatesForPatchGroupResult> - Retrieves the high-level patch state for the managed nodes in the specified patch group.
-
describeInstanceProperties(
{List< InstancePropertyStringFilter> ? filtersWithOperator, List<InstancePropertyFilter> ? instancePropertyFilterList, int? maxResults, String? nextToken}) → Future<DescribeInstancePropertiesResult> - An API operation used by the Systems Manager console to display information about Systems Manager managed nodes.
-
describeInventoryDeletions(
{String? deletionId, int? maxResults, String? nextToken}) → Future< DescribeInventoryDeletionsResult> - Describes a specific delete inventory operation.
-
describeMaintenanceWindowExecutions(
{required String windowId, List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowExecutionsResult> - Lists the executions of a maintenance window. This includes information about when the maintenance window was scheduled to be active, and information about tasks registered and run with the maintenance window.
-
describeMaintenanceWindowExecutionTaskInvocations(
{required String taskId, required String windowExecutionId, List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowExecutionTaskInvocationsResult> - Retrieves the individual task executions (one per target) for a particular task run as part of a maintenance window execution.
-
describeMaintenanceWindowExecutionTasks(
{required String windowExecutionId, List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowExecutionTasksResult> - For a given maintenance window execution, lists the tasks that were run.
-
describeMaintenanceWindows(
{List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowsResult> - Retrieves the maintenance windows in an Amazon Web Services account.
-
describeMaintenanceWindowSchedule(
{List< PatchOrchestratorFilter> ? filters, int? maxResults, String? nextToken, MaintenanceWindowResourceType? resourceType, List<Target> ? targets, String? windowId}) → Future<DescribeMaintenanceWindowScheduleResult> - Retrieves information about upcoming executions of a maintenance window.
-
describeMaintenanceWindowsForTarget(
{required MaintenanceWindowResourceType resourceType, required List< Target> targets, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowsForTargetResult> - Retrieves information about the maintenance window targets or tasks that a managed node is associated with.
-
describeMaintenanceWindowTargets(
{required String windowId, List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowTargetsResult> - Lists the targets registered with the maintenance window.
-
describeMaintenanceWindowTasks(
{required String windowId, List< MaintenanceWindowFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeMaintenanceWindowTasksResult> - Lists the tasks in a maintenance window.
-
describeOpsItems(
{int? maxResults, String? nextToken, List< OpsItemFilter> ? opsItemFilters}) → Future<DescribeOpsItemsResponse> - Query a set of OpsItems. You must have permission in Identity and Access Management (IAM) to query a list of OpsItems. For more information, see Set up OpsCenter in the Amazon Web Services Systems Manager User Guide.
-
describeParameters(
{List< ParametersFilter> ? filters, int? maxResults, String? nextToken, List<ParameterStringFilter> ? parameterFilters, }) → Future<DescribeParametersResult> - Lists the parameters in your Amazon Web Services account or the parameters shared with you when you enable the Shared option.
-
describePatchBaselines(
{List< PatchOrchestratorFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribePatchBaselinesResult> - Lists the patch baselines in your Amazon Web Services account.
-
describePatchGroups(
{List< PatchOrchestratorFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribePatchGroupsResult> - Lists all patch groups that have been registered with patch baselines.
-
describePatchGroupState(
{required String patchGroup}) → Future< DescribePatchGroupStateResult> - Returns high-level aggregated patch compliance state information for a patch group.
-
describePatchProperties(
{required OperatingSystem operatingSystem, required PatchProperty property, int? maxResults, String? nextToken, PatchSet? patchSet}) → Future< DescribePatchPropertiesResult> - Lists the properties of available patches organized by product, product family, classification, severity, and other properties of available patches. You can use the reported properties in the filters you specify in requests for operations such as CreatePatchBaseline, UpdatePatchBaseline, DescribeAvailablePatches, and DescribePatchBaselines.
-
describeSessions(
{required SessionState state, List< SessionFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeSessionsResponse> - Retrieves a list of all active sessions (both connected and disconnected) or terminated sessions from the past 30 days.
-
disassociateOpsItemRelatedItem(
{required String associationId, required String opsItemId}) → Future< void> - Deletes the association between an OpsItem and a related item. For example, this API operation can delete an Incident Manager incident from an OpsItem. Incident Manager is a tool in Amazon Web Services Systems Manager.
-
getAccessToken(
{required String accessRequestId}) → Future< GetAccessTokenResponse> - Returns a credentials set to be used with just-in-time node access.
-
getAutomationExecution(
{required String automationExecutionId}) → Future< GetAutomationExecutionResult> - Get detailed information about a particular Automation execution.
-
getCalendarState(
{required List< String> calendarNames, String? atTime}) → Future<GetCalendarStateResponse> -
Gets the state of a Amazon Web Services Systems Manager change calendar at
the current time or a specified time. If you specify a time,
GetCalendarStatereturns the state of the calendar at that specific time, and returns the next time that the change calendar state will transition. If you don't specify a time,GetCalendarStateuses the current time. Change Calendar entries have two possible states:OPENorCLOSED. -
getCommandInvocation(
{required String commandId, required String instanceId, String? pluginName}) → Future< GetCommandInvocationResult> - Returns detailed information about command execution for an invocation or plugin. The Run Command API follows an eventual consistency model, due to the distributed nature of the system supporting the API. This means that the result of an API command you run that affects your resources might not be immediately visible to all subsequent commands you run. You should keep this in mind when you carry out an API command that immediately follows a previous API command.
-
getConnectionStatus(
{required String target}) → Future< GetConnectionStatusResponse> - Retrieves the Session Manager connection status for a managed node to determine whether it is running and ready to receive Session Manager connections.
-
getDefaultPatchBaseline(
{OperatingSystem? operatingSystem}) → Future< GetDefaultPatchBaselineResult> - Retrieves the default patch baseline. Amazon Web Services Systems Manager supports creating multiple default patch baselines. For example, you can create a default patch baseline for each operating system.
-
getDeployablePatchSnapshotForInstance(
{required String instanceId, required String snapshotId, BaselineOverride? baselineOverride, bool? useS3DualStackEndpoint}) → Future< GetDeployablePatchSnapshotForInstanceResult> -
Retrieves the current snapshot for the patch baseline the managed node
uses. This API is primarily used by the
AWS-RunPatchBaselineSystems Manager document (SSM document). -
getDocument(
{required String name, DocumentFormat? documentFormat, String? documentVersion, String? versionName}) → Future< GetDocumentResult> - Gets the contents of the specified Amazon Web Services Systems Manager document (SSM document).
-
getExecutionPreview(
{required String executionPreviewId}) → Future< GetExecutionPreviewResponse> - Initiates the process of retrieving an existing preview that shows the effects that running a specified Automation runbook would have on the targeted resources.
-
getInventory(
{List< InventoryAggregator> ? aggregators, List<InventoryFilter> ? filters, int? maxResults, String? nextToken, List<ResultAttribute> ? resultAttributes}) → Future<GetInventoryResult> -
Query inventory information. This includes managed node status, such as
StoppedorTerminated. -
getInventorySchema(
{bool? aggregator, int? maxResults, String? nextToken, bool? subType, String? typeName}) → Future< GetInventorySchemaResult> - Return a list of inventory type names for the account, or return a list of attribute names for a specific Inventory item type.
-
getMaintenanceWindow(
{required String windowId}) → Future< GetMaintenanceWindowResult> - Retrieves a maintenance window.
-
getMaintenanceWindowExecution(
{required String windowExecutionId}) → Future< GetMaintenanceWindowExecutionResult> - Retrieves details about a specific a maintenance window execution.
-
getMaintenanceWindowExecutionTask(
{required String taskId, required String windowExecutionId}) → Future< GetMaintenanceWindowExecutionTaskResult> - Retrieves the details about a specific task run as part of a maintenance window execution.
-
getMaintenanceWindowExecutionTaskInvocation(
{required String invocationId, required String taskId, required String windowExecutionId}) → Future< GetMaintenanceWindowExecutionTaskInvocationResult> - Retrieves information about a specific task running on a specific target.
-
getMaintenanceWindowTask(
{required String windowId, required String windowTaskId}) → Future< GetMaintenanceWindowTaskResult> - Retrieves the details of a maintenance window task. To retrieve a list of tasks in a maintenance window, instead use the DescribeMaintenanceWindowTasks command.
-
getOpsItem(
{required String opsItemId, String? opsItemArn}) → Future< GetOpsItemResponse> - Get information about an OpsItem by using the ID. You must have permission in Identity and Access Management (IAM) to view information about an OpsItem. For more information, see Set up OpsCenter in the Amazon Web Services Systems Manager User Guide.
-
getOpsMetadata(
{required String opsMetadataArn, int? maxResults, String? nextToken}) → Future< GetOpsMetadataResult> - View operational metadata related to an application in Application Manager.
-
getOpsSummary(
{List< OpsAggregator> ? aggregators, List<OpsFilter> ? filters, int? maxResults, String? nextToken, List<OpsResultAttribute> ? resultAttributes, String? syncName}) → Future<GetOpsSummaryResult> - View a summary of operations metadata (OpsData) based on specified filters and aggregators. OpsData can include information about Amazon Web Services Systems Manager OpsCenter operational workitems (OpsItems) as well as information about any Amazon Web Services resource or service configured to report OpsData to Amazon Web Services Systems Manager Explorer.
-
getParameter(
{required String name, bool? withDecryption}) → Future< GetParameterResult> - Get information about a single parameter by specifying the parameter name.
-
getParameterHistory(
{required String name, int? maxResults, String? nextToken, bool? withDecryption}) → Future< GetParameterHistoryResult> - Retrieves the history of all changes to a parameter.
-
getParameters(
{required List< String> names, bool? withDecryption}) → Future<GetParametersResult> -
Get information about one or more parameters by specifying multiple
parameter names.
Parameter names can't contain spaces. The service removes any spaces
specified for the beginning or end of a parameter name. If the specified
name for a parameter contains spaces between characters, the request fails
with a
ValidationExceptionerror. -
getParametersByPath(
{required String path, int? maxResults, String? nextToken, List< ParameterStringFilter> ? parameterFilters, bool? recursive, bool? withDecryption}) → Future<GetParametersByPathResult> - Retrieve information about one or more parameters under a specified level in a hierarchy.
-
getPatchBaseline(
{required String baselineId}) → Future< GetPatchBaselineResult> - Retrieves information about a patch baseline.
-
getPatchBaselineForPatchGroup(
{required String patchGroup, OperatingSystem? operatingSystem}) → Future< GetPatchBaselineForPatchGroupResult> - Retrieves the patch baseline that should be used for the specified patch group.
-
getResourcePolicies(
{required String resourceArn, int? maxResults, String? nextToken}) → Future< GetResourcePoliciesResponse> -
Returns an array of the
Policyobject. -
getServiceSetting(
{required String settingId}) → Future< GetServiceSettingResult> -
ServiceSettingis an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting offalse. This means the user can't use this feature unless they change the setting totrueand intentionally opt in for a paid feature. -
labelParameterVersion(
{required List< String> labels, required String name, int? parameterVersion}) → Future<LabelParameterVersionResult> - A parameter label is a user-defined alias to help you manage different versions of a parameter. When you modify a parameter, Amazon Web Services Systems Manager automatically saves a new version and increments the version number by one. A label can help you remember the purpose of a parameter when there are multiple versions.
-
listAssociations(
{List< AssociationFilter> ? associationFilterList, int? maxResults, String? nextToken}) → Future<ListAssociationsResult> - Returns all State Manager associations in the current Amazon Web Services account and Amazon Web Services Region. You can limit the results to a specific State Manager association document or managed node by specifying a filter. State Manager is a tool in Amazon Web Services Systems Manager.
-
listAssociationVersions(
{required String associationId, int? maxResults, String? nextToken}) → Future< ListAssociationVersionsResult> - Retrieves all versions of an association for a specific association ID.
-
listCommandInvocations(
{String? commandId, bool? details, List< CommandFilter> ? filters, String? instanceId, int? maxResults, String? nextToken}) → Future<ListCommandInvocationsResult> -
An invocation is copy of a command sent to a specific managed node. A
command can apply to one or more managed nodes. A command invocation
applies to one managed node. For example, if a user runs
SendCommandagainst three managed nodes, then a command invocation is created for each requested managed node ID.ListCommandInvocationsprovide status about command execution. -
listCommands(
{String? commandId, List< CommandFilter> ? filters, String? instanceId, int? maxResults, String? nextToken}) → Future<ListCommandsResult> - Lists the commands requested by users of the Amazon Web Services account.
-
listComplianceItems(
{List< ComplianceStringFilter> ? filters, int? maxResults, String? nextToken, List<String> ? resourceIds, List<String> ? resourceTypes}) → Future<ListComplianceItemsResult> - For a specified resource ID, this API operation returns a list of compliance statuses for different resource types. Currently, you can only specify one resource ID per call. List results depend on the criteria specified in the filter.
-
listComplianceSummaries(
{List< ComplianceStringFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListComplianceSummariesResult> - Returns a summary count of compliant and non-compliant resources for a compliance type. For example, this call can return State Manager associations, patches, or custom compliance types according to the filter criteria that you specify.
-
listDocumentMetadataHistory(
{required DocumentMetadataEnum metadata, required String name, String? documentVersion, int? maxResults, String? nextToken}) → Future< ListDocumentMetadataHistoryResponse> -
May throw
InternalServerError. May throwInvalidDocument. May throwInvalidDocumentVersion. May throwInvalidNextToken. -
listDocuments(
{List< DocumentFilter> ? documentFilterList, List<DocumentKeyValuesFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListDocumentsResult> - Returns all Systems Manager (SSM) documents in the current Amazon Web Services account and Amazon Web Services Region. You can limit the results of this request by using a filter.
-
listDocumentVersions(
{required String name, int? maxResults, String? nextToken}) → Future< ListDocumentVersionsResult> - List all versions for a document.
-
listInventoryEntries(
{required String instanceId, required String typeName, List< InventoryFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListInventoryEntriesResult> - A list of inventory items returned by the request.
-
listNodes(
{List< NodeFilter> ? filters, int? maxResults, String? nextToken, String? syncName}) → Future<ListNodesResult> - Takes in filters and returns a list of managed nodes matching the filter criteria.
-
listNodesSummary(
{required List< NodeAggregator> aggregators, List<NodeFilter> ? filters, int? maxResults, String? nextToken, String? syncName}) → Future<ListNodesSummaryResult> - Generates a summary of managed instance/node metadata based on the filters and aggregators you specify. Results are grouped by the input aggregator you specify.
-
listOpsItemEvents(
{List< OpsItemEventFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListOpsItemEventsResponse> - Returns a list of all OpsItem events in the current Amazon Web Services Region and Amazon Web Services account. You can limit the results to events associated with specific OpsItems by specifying a filter.
-
listOpsItemRelatedItems(
{List< OpsItemRelatedItemsFilter> ? filters, int? maxResults, String? nextToken, String? opsItemId}) → Future<ListOpsItemRelatedItemsResponse> - Lists all related-item resources associated with a Systems Manager OpsCenter OpsItem. OpsCenter is a tool in Amazon Web Services Systems Manager.
-
listOpsMetadata(
{List< OpsMetadataFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListOpsMetadataResult> - Amazon Web Services Systems Manager calls this API operation when displaying all Application Manager OpsMetadata objects or blobs.
-
listResourceComplianceSummaries(
{List< ComplianceStringFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListResourceComplianceSummariesResult> - Returns a resource-level summary count. The summary includes information about compliant and non-compliant statuses and detailed compliance-item severity counts, according to the filter criteria you specify.
-
listResourceDataSync(
{int? maxResults, String? nextToken, String? syncType}) → Future< ListResourceDataSyncResult> - Lists your resource data sync configurations. Includes information about the last time a sync attempted to start, the last sync status, and the last time a sync successfully completed.
-
listTagsForResource(
{required String resourceId, required ResourceTypeForTagging resourceType}) → Future< ListTagsForResourceResult> - Returns a list of the tags assigned to the specified resource.
-
modifyDocumentPermission(
{required String name, required DocumentPermissionType permissionType, List< String> ? accountIdsToAdd, List<String> ? accountIdsToRemove, }) → Future<void> - Shares a Amazon Web Services Systems Manager document (SSM document)publicly or privately. If you share a document privately, you must specify the Amazon Web Services user IDs for those people who can use the document. If you share a document publicly, you must specify All as the account ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putComplianceItems(
{required String complianceType, required ComplianceExecutionSummary executionSummary, required List< ComplianceItemEntry> items, required String resourceId, required String resourceType, String? itemContentHash, ComplianceUploadType? uploadType}) → Future<void> - Registers a compliance type and other compliance details on a designated resource. This operation lets you register custom compliance details with a resource. This call overwrites existing compliance information on the resource, so you must provide a full list of compliance items each time that you send the request.
-
putInventory(
{required String instanceId, required List< InventoryItem> items}) → Future<PutInventoryResult> - Bulk update custom inventory items on one or more managed nodes. The request adds an inventory item, if it doesn't already exist, or updates an inventory item, if it does exist.
-
putParameter(
{required String name, required String value, String? allowedPattern, String? dataType, String? description, String? keyId, bool? overwrite, String? policies, List< Tag> ? tags, ParameterTier? tier, ParameterType? type}) → Future<PutParameterResult> - Create or update a parameter in Parameter Store.
-
putResourcePolicy(
{required String policy, required String resourceArn, String? policyHash, String? policyId}) → Future< PutResourcePolicyResponse> - Creates or updates a Systems Manager resource policy. A resource policy helps you to define the IAM entity (for example, an Amazon Web Services account) that can manage your Systems Manager resources. The following resources support Systems Manager resource policies.
-
registerDefaultPatchBaseline(
{required String baselineId}) → Future< RegisterDefaultPatchBaselineResult> - Defines the default patch baseline for the relevant operating system.
-
registerPatchBaselineForPatchGroup(
{required String baselineId, required String patchGroup}) → Future< RegisterPatchBaselineForPatchGroupResult> - Registers a patch baseline for a patch group.
-
registerTargetWithMaintenanceWindow(
{required MaintenanceWindowResourceType resourceType, required List< Target> targets, required String windowId, String? clientToken, String? description, String? name, String? ownerInformation}) → Future<RegisterTargetWithMaintenanceWindowResult> - Registers a target with a maintenance window.
-
registerTaskWithMaintenanceWindow(
{required String taskArn, required MaintenanceWindowTaskType taskType, required String windowId, AlarmConfiguration? alarmConfiguration, String? clientToken, MaintenanceWindowTaskCutoffBehavior? cutoffBehavior, String? description, LoggingInfo? loggingInfo, String? maxConcurrency, String? maxErrors, String? name, int? priority, String? serviceRoleArn, List< Target> ? targets, MaintenanceWindowTaskInvocationParameters? taskInvocationParameters, Map<String, MaintenanceWindowTaskParameterValueExpression> ? taskParameters}) → Future<RegisterTaskWithMaintenanceWindowResult> - Adds a new task to a maintenance window.
-
removeTagsFromResource(
{required String resourceId, required ResourceTypeForTagging resourceType, required List< String> tagKeys}) → Future<void> - Removes tag keys from the specified resource.
-
resetServiceSetting(
{required String settingId}) → Future< ResetServiceSettingResult> -
ServiceSettingis an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of "false". This means the user can't use this feature unless they change the setting to "true" and intentionally opt in for a paid feature. -
resumeSession(
{required String sessionId}) → Future< ResumeSessionResponse> - Reconnects a session to a managed node after it has been disconnected. Connections can be resumed for disconnected sessions, but not terminated sessions.
-
sendAutomationSignal(
{required String automationExecutionId, required SignalType signalType, Map< String, List< ? payload}) → Future<String> >void> - Sends a signal to an Automation execution to change the current behavior or status of the execution.
-
sendCommand(
{required String documentName, AlarmConfiguration? alarmConfiguration, CloudWatchOutputConfig? cloudWatchOutputConfig, String? comment, String? documentHash, DocumentHashType? documentHashType, String? documentVersion, List< String> ? instanceIds, String? maxConcurrency, String? maxErrors, NotificationConfig? notificationConfig, String? outputS3BucketName, String? outputS3KeyPrefix, String? outputS3Region, Map<String, List< ? parameters, String? serviceRoleArn, List<String> >Target> ? targets, int? timeoutSeconds}) → Future<SendCommandResult> - Runs commands on one or more managed nodes.
-
startAccessRequest(
{required String reason, required List< Target> targets, List<Tag> ? tags}) → Future<StartAccessRequestResponse> - Starts the workflow for just-in-time node access sessions.
-
startAssociationsOnce(
{required List< String> associationIds}) → Future<void> - Runs an association immediately and only one time. This operation can be helpful when troubleshooting associations.
-
startAutomationExecution(
{required String documentName, AlarmConfiguration? alarmConfiguration, String? clientToken, String? documentVersion, String? maxConcurrency, String? maxErrors, ExecutionMode? mode, Map< String, List< ? parameters, List<String> >Tag> ? tags, List<TargetLocation> ? targetLocations, String? targetLocationsURL, List<Map< ? targetMaps, String? targetParameterName, List<String, List< >String> >Target> ? targets}) → Future<StartAutomationExecutionResult> - Initiates execution of an Automation runbook.
-
startChangeRequestExecution(
{required String documentName, required List< Runbook> runbooks, bool? autoApprove, String? changeDetails, String? changeRequestName, String? clientToken, String? documentVersion, Map<String, List< ? parameters, DateTime? scheduledEndTime, DateTime? scheduledTime, List<String> >Tag> ? tags}) → Future<StartChangeRequestExecutionResult> -
May throw
AutomationDefinitionNotApprovedException. May throwAutomationDefinitionNotFoundException. May throwAutomationDefinitionVersionNotFoundException. May throwAutomationExecutionLimitExceededException. May throwIdempotentParameterMismatch. May throwInternalServerError. May throwInvalidAutomationExecutionParametersException. May throwNoLongerSupportedException. -
startExecutionPreview(
{required String documentName, String? documentVersion, ExecutionInputs? executionInputs}) → Future< StartExecutionPreviewResponse> - Initiates the process of creating a preview showing the effects that running a specified Automation runbook would have on the targeted resources.
-
startSession(
{required String target, String? documentName, Map< String, List< ? parameters, String? reason}) → Future<String> >StartSessionResponse> - Initiates a connection to a target (for example, a managed node) for a Session Manager session. Returns a URL and token that can be used to open a WebSocket connection for sending input and receiving outputs.
-
stopAutomationExecution(
{required String automationExecutionId, StopType? type}) → Future< void> - Stop an Automation that is currently running.
-
terminateSession(
{required String sessionId}) → Future< TerminateSessionResponse> - Permanently ends a session and closes the data connection between the Session Manager client and SSM Agent on the managed node. A terminated session can't be resumed.
-
toString(
) → String -
A string representation of this object.
inherited
-
unlabelParameterVersion(
{required List< String> labels, required String name, required int parameterVersion}) → Future<UnlabelParameterVersionResult> - Remove a label or labels from a parameter.
-
updateAssociation(
{required String associationId, AlarmConfiguration? alarmConfiguration, bool? applyOnlyAtCronInterval, String? associationDispatchAssumeRole, String? associationName, String? associationVersion, String? automationTargetParameterName, List< String> ? calendarNames, AssociationComplianceSeverity? complianceSeverity, String? documentVersion, int? duration, String? maxConcurrency, String? maxErrors, String? name, InstanceAssociationOutputLocation? outputLocation, Map<String, List< ? parameters, String? scheduleExpression, int? scheduleOffset, AssociationSyncCompliance? syncCompliance, List<String> >TargetLocation> ? targetLocations, List<Map< ? targetMaps, List<String, List< >String> >Target> ? targets}) → Future<UpdateAssociationResult> -
Updates an association. You can update the association name and version,
the document version, schedule, parameters, and Amazon Simple Storage
Service (Amazon S3) output. When you call
UpdateAssociation, the system removes all optional parameters from the request and overwrites the association with null values for those parameters. This is by design. You must specify all optional parameters in the call, even if you are not changing the parameters. This includes theNameparameter. Before calling this API action, we recommend that you call the DescribeAssociation API operation and make a note of all optional parameters required for yourUpdateAssociationcall. -
updateAssociationStatus(
{required AssociationStatus associationStatus, required String instanceId, required String name}) → Future< UpdateAssociationStatusResult> - Updates the status of the Amazon Web Services Systems Manager document (SSM document) associated with the specified managed node.
-
updateDocument(
{required String content, required String name, List< AttachmentsSource> ? attachments, String? displayName, DocumentFormat? documentFormat, String? documentVersion, String? targetType, String? versionName}) → Future<UpdateDocumentResult> - Updates one or more values for an SSM document.
-
updateDocumentDefaultVersion(
{required String documentVersion, required String name}) → Future< UpdateDocumentDefaultVersionResult> - Set the default version of a document.
-
updateDocumentMetadata(
{required DocumentReviews documentReviews, required String name, String? documentVersion}) → Future< void> -
May throw
InternalServerError. May throwInvalidDocument. May throwInvalidDocumentOperation. May throwInvalidDocumentVersion. May throwTooManyUpdates. -
updateMaintenanceWindow(
{required String windowId, bool? allowUnassociatedTargets, int? cutoff, String? description, int? duration, bool? enabled, String? endDate, String? name, bool? replace, String? schedule, int? scheduleOffset, String? scheduleTimezone, String? startDate}) → Future< UpdateMaintenanceWindowResult> - Updates an existing maintenance window. Only specified parameters are modified.
-
updateMaintenanceWindowTarget(
{required String windowId, required String windowTargetId, String? description, String? name, String? ownerInformation, bool? replace, List< Target> ? targets}) → Future<UpdateMaintenanceWindowTargetResult> - Modifies the target of an existing maintenance window. You can change the following:
-
updateMaintenanceWindowTask(
{required String windowId, required String windowTaskId, AlarmConfiguration? alarmConfiguration, MaintenanceWindowTaskCutoffBehavior? cutoffBehavior, String? description, LoggingInfo? loggingInfo, String? maxConcurrency, String? maxErrors, String? name, int? priority, bool? replace, String? serviceRoleArn, List< Target> ? targets, String? taskArn, MaintenanceWindowTaskInvocationParameters? taskInvocationParameters, Map<String, MaintenanceWindowTaskParameterValueExpression> ? taskParameters}) → Future<UpdateMaintenanceWindowTaskResult> - Modifies a task assigned to a maintenance window. You can't change the task type, but you can change the following values:
-
updateManagedInstanceRole(
{required String iamRole, required String instanceId}) → Future< void> - Changes the Identity and Access Management (IAM) role that is assigned to the on-premises server, edge device, or virtual machines (VM). IAM roles are first assigned to these hybrid nodes during the activation process. For more information, see CreateActivation.
-
updateOpsItem(
{required String opsItemId, DateTime? actualEndTime, DateTime? actualStartTime, String? category, String? description, List< OpsItemNotification> ? notifications, Map<String, OpsItemDataValue> ? operationalData, List<String> ? operationalDataToDelete, String? opsItemArn, DateTime? plannedEndTime, DateTime? plannedStartTime, int? priority, String? severity, OpsItemStatus? status, String? title}) → Future<void> - Edit or change an OpsItem. You must have permission in Identity and Access Management (IAM) to update an OpsItem. For more information, see Set up OpsCenter in the Amazon Web Services Systems Manager User Guide.
-
updateOpsMetadata(
{required String opsMetadataArn, List< String> ? keysToDelete, Map<String, MetadataValue> ? metadataToUpdate}) → Future<UpdateOpsMetadataResult> - Amazon Web Services Systems Manager calls this API operation when you edit OpsMetadata in Application Manager.
-
updatePatchBaseline(
{required String baselineId, PatchRuleGroup? approvalRules, List< String> ? approvedPatches, PatchComplianceLevel? approvedPatchesComplianceLevel, bool? approvedPatchesEnableNonSecurity, PatchComplianceStatus? availableSecurityUpdatesComplianceStatus, String? description, PatchFilterGroup? globalFilters, String? name, List<String> ? rejectedPatches, PatchAction? rejectedPatchesAction, bool? replace, List<PatchSource> ? sources}) → Future<UpdatePatchBaselineResult> - Modifies an existing patch baseline. Fields not specified in the request are left unchanged.
-
updateResourceDataSync(
{required String syncName, required ResourceDataSyncSource syncSource, required String syncType}) → Future< void> -
Update a resource data sync. After you create a resource data sync for a
Region, you can't change the account options for that sync. For example,
if you create a sync in the us-east-2 (Ohio) Region and you choose the
Include only the current accountoption, you can't edit that sync later and choose theInclude all accounts from my Organizations configurationoption. Instead, you must delete the first resource data sync, and create a new one. -
updateServiceSetting(
{required String settingId, required String settingValue}) → Future< void> -
ServiceSettingis an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of "false". This means the user can't use this feature unless they change the setting to "true" and intentionally opt in for a paid feature.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited