createAssociation method

Future<CreateAssociationResult> createAssociation({
  1. required String name,
  2. AlarmConfiguration? alarmConfiguration,
  3. bool? applyOnlyAtCronInterval,
  4. String? associationDispatchAssumeRole,
  5. String? associationName,
  6. String? automationTargetParameterName,
  7. List<String>? calendarNames,
  8. AssociationComplianceSeverity? complianceSeverity,
  9. String? documentVersion,
  10. int? duration,
  11. String? instanceId,
  12. String? maxConcurrency,
  13. String? maxErrors,
  14. InstanceAssociationOutputLocation? outputLocation,
  15. Map<String, List<String>>? parameters,
  16. String? scheduleExpression,
  17. int? scheduleOffset,
  18. AssociationSyncCompliance? syncCompliance,
  19. List<Tag>? tags,
  20. List<TargetLocation>? targetLocations,
  21. List<Map<String, List<String>>>? targetMaps,
  22. List<Target>? targets,
})

A State Manager association defines the state that you want to maintain on your managed nodes. For example, an association can specify that anti-virus software must be installed and running on your managed nodes, or that certain ports must be closed. For static targets, the association specifies a schedule for when the configuration is reapplied. For dynamic targets, such as an Amazon Web Services resource group or an Amazon Web Services autoscaling group, State Manager, a tool in Amazon Web Services Systems Manager applies the configuration when new managed nodes are added to the group. The association also specifies actions to take when applying the configuration. For example, an association for anti-virus software might run once a day. If the software isn't installed, then State Manager installs it. If the software is installed, but the service isn't running, then the association might instruct State Manager to start the service.

May throw AssociationAlreadyExists. May throw AssociationLimitExceeded. May throw InternalServerError. May throw InvalidDocument. May throw InvalidDocumentVersion. May throw InvalidInstanceId. May throw InvalidOutputLocation. May throw InvalidParameters. May throw InvalidSchedule. May throw InvalidTag. May throw InvalidTarget. May throw InvalidTargetMaps. May throw UnsupportedPlatformType.

Parameter name : The name of the SSM Command document or Automation runbook that contains the configuration information for the managed node.

You can specify Amazon Web Services-predefined documents, documents you created, or a document that is shared with you from another Amazon Web Services account.

For Systems Manager documents (SSM documents) that are shared with you from other Amazon Web Services accounts, you must specify the complete SSM document ARN, in the following format:

arn:partition:ssm:region:account-id:document/document-name

For example:

arn:aws:ssm:us-east-2:12345678912:document/My-Shared-Document

For Amazon Web Services-predefined documents and SSM documents you created in your account, you only need to specify the document name. For example, AWS-ApplyPatchBaseline or My-Document.

Parameter applyOnlyAtCronInterval : By default, when you create a new association, the system runs it immediately after it is created and then according to the schedule you specified and when target changes are detected. Specify true for ApplyOnlyAtCronIntervalif you want the association to run only according to the schedule you specified.

For more information, see Understanding when associations are applied to resources and >About target updates with Automation runbooks in the Amazon Web Services Systems Manager User Guide.

This parameter isn't supported for rate expressions.

Parameter associationDispatchAssumeRole : A role used by association to take actions on your behalf. State Manager will assume this role and call required APIs when dispatching configurations to nodes. If not specified, service-linked role for Systems Manager will be used by default.

Service-linked role support in State Manager is being phased out. Associations relying on service-linked role may require updates in the future to continue functioning properly.

Parameter associationName : Specify a descriptive name for the association.

Parameter automationTargetParameterName : Choose the parameter that will define how your automation will branch out. This target is required for associations that use an Automation runbook and target resources by using rate controls. Automation is a tool in Amazon Web Services Systems Manager.

Parameter calendarNames : The names of Amazon Resource Names (ARNs) of the Change Calendar type documents you want to gate your associations under. The associations only run when that change calendar is open. For more information, see Amazon Web Services Systems Manager Change Calendar in the Amazon Web Services Systems Manager User Guide.

Parameter complianceSeverity : The severity level to assign to the association.

Parameter documentVersion : The document version you want to associate with the targets. Can be a specific version or the default version.

Parameter duration : The number of hours the association can run before it is canceled. Duration applies to associations that are currently running, and any pending and in progress commands on all targets. If a target was taken offline for the association to run, it is made available again immediately, without a reboot.

The Duration parameter applies only when both these conditions are true:

  • The association for which you specify a duration is cancelable according to the parameters of the SSM command document or Automation runbook associated with this execution.
  • The command specifies the ApplyOnlyAtCronInterval parameter, which means that the association doesn't run immediately after it is created, but only according to the specified schedule.

Parameter instanceId : The managed node ID.

Parameter maxConcurrency : The maximum number of targets allowed to run the association at the same time. You can specify a number, for example 10, or a percentage of the target set, for example 10%. The default value is 100%, which means all targets run the association at the same time.

If a new managed node starts and attempts to run an association while Systems Manager is running MaxConcurrency associations, the association is allowed to run. During the next association interval, the new managed node will process its association within the limit specified for MaxConcurrency.

Parameter maxErrors : The number of errors that are allowed before the system stops sending requests to run the association on additional targets. You can specify either an absolute number of errors, for example 10, or a percentage of the target set, for example 10%. If you specify 3, for example, the system stops sending requests when the fourth error is received. If you specify 0, then the system stops sending requests after the first error is returned. If you run an association on 50 managed nodes and set MaxError to 10%, then the system stops sending the request when the sixth error is received.

Executions that are already running an association when MaxErrors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set MaxConcurrency to 1 so that executions proceed one at a time.

Parameter outputLocation : An Amazon Simple Storage Service (Amazon S3) bucket where you want to store the output details of the request.

Parameter parameters : The parameters for the runtime configuration of the document.

Parameter scheduleExpression : A cron expression when the association will be applied to the targets.

Parameter scheduleOffset : Number of days to wait after the scheduled day to run an association. For example, if you specified a cron schedule of cron(0 0 ? * THU#2 *), you could specify an offset of 3 to run the association each Sunday after the second Thursday of the month. For more information about cron schedules for associations, see Reference: Cron and rate expressions for Systems Manager in the Amazon Web Services Systems Manager User Guide.

Parameter syncCompliance : The mode for generating association compliance. You can specify AUTO or MANUAL. In AUTO mode, the system uses the status of the association execution to determine the compliance status. If the association execution runs successfully, then the association is COMPLIANT. If the association execution doesn't run successfully, the association is NON-COMPLIANT.

In MANUAL mode, you must specify the AssociationId as a parameter for the PutComplianceItems API operation. In this case, compliance data isn't managed by State Manager. It is managed by your direct call to the PutComplianceItems API operation.

By default, all associations use AUTO mode.

Parameter tags : Adds or overwrites one or more tags for a State Manager association. Tags are metadata that you can assign to your Amazon Web Services resources. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. Each tag consists of a key and an optional value, both of which you define.

Parameter targetLocations : A location is a combination of Amazon Web Services Regions and Amazon Web Services accounts where you want to run the association. Use this action to create an association in multiple Regions and multiple accounts.

Parameter targetMaps : A key-value mapping of document parameters to target resources. Both Targets and TargetMaps can't be specified together.

Parameter targets : The targets for the association. You can target managed nodes by using tags, Amazon Web Services resource groups, all managed nodes in an Amazon Web Services account, or individual managed node IDs. You can target all managed nodes in an Amazon Web Services account by specifying the InstanceIds key with a value of *. For more information about choosing targets for an association, see Understanding targets and rate controls in State Manager associations in the Amazon Web Services Systems Manager User Guide.

Implementation

Future<CreateAssociationResult> createAssociation({
  required String name,
  AlarmConfiguration? alarmConfiguration,
  bool? applyOnlyAtCronInterval,
  String? associationDispatchAssumeRole,
  String? associationName,
  String? automationTargetParameterName,
  List<String>? calendarNames,
  AssociationComplianceSeverity? complianceSeverity,
  String? documentVersion,
  int? duration,
  String? instanceId,
  String? maxConcurrency,
  String? maxErrors,
  InstanceAssociationOutputLocation? outputLocation,
  Map<String, List<String>>? parameters,
  String? scheduleExpression,
  int? scheduleOffset,
  AssociationSyncCompliance? syncCompliance,
  List<Tag>? tags,
  List<TargetLocation>? targetLocations,
  List<Map<String, List<String>>>? targetMaps,
  List<Target>? targets,
}) async {
  _s.validateNumRange(
    'duration',
    duration,
    1,
    24,
  );
  _s.validateNumRange(
    'scheduleOffset',
    scheduleOffset,
    1,
    6,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.CreateAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (alarmConfiguration != null)
        'AlarmConfiguration': alarmConfiguration,
      if (applyOnlyAtCronInterval != null)
        'ApplyOnlyAtCronInterval': applyOnlyAtCronInterval,
      if (associationDispatchAssumeRole != null)
        'AssociationDispatchAssumeRole': associationDispatchAssumeRole,
      if (associationName != null) 'AssociationName': associationName,
      if (automationTargetParameterName != null)
        'AutomationTargetParameterName': automationTargetParameterName,
      if (calendarNames != null) 'CalendarNames': calendarNames,
      if (complianceSeverity != null)
        'ComplianceSeverity': complianceSeverity.value,
      if (documentVersion != null) 'DocumentVersion': documentVersion,
      if (duration != null) 'Duration': duration,
      if (instanceId != null) 'InstanceId': instanceId,
      if (maxConcurrency != null) 'MaxConcurrency': maxConcurrency,
      if (maxErrors != null) 'MaxErrors': maxErrors,
      if (outputLocation != null) 'OutputLocation': outputLocation,
      if (parameters != null) 'Parameters': parameters,
      if (scheduleExpression != null)
        'ScheduleExpression': scheduleExpression,
      if (scheduleOffset != null) 'ScheduleOffset': scheduleOffset,
      if (syncCompliance != null) 'SyncCompliance': syncCompliance.value,
      if (tags != null) 'Tags': tags,
      if (targetLocations != null) 'TargetLocations': targetLocations,
      if (targetMaps != null) 'TargetMaps': targetMaps,
      if (targets != null) 'Targets': targets,
    },
  );

  return CreateAssociationResult.fromJson(jsonResponse.body);
}