createMaintenanceWindow method
Creates a new maintenance window.
May throw IdempotentParameterMismatch.
May throw InternalServerError.
May throw ResourceLimitExceededException.
Parameter allowUnassociatedTargets :
Enables a maintenance window task to run on managed nodes, even if you
haven't registered those nodes as targets. If enabled, then you must
specify the unregistered managed nodes (by node ID) when you register a
task with the maintenance window.
If you don't enable this option, then you must specify previously-registered targets when you register a task with the maintenance window.
Parameter cutoff :
The number of hours before the end of the maintenance window that Amazon
Web Services Systems Manager stops scheduling new tasks for execution.
Parameter duration :
The duration of the maintenance window in hours.
Parameter name :
The name of the maintenance window.
Parameter schedule :
The schedule of the maintenance window in the form of a cron or rate
expression.
Parameter clientToken :
User-provided idempotency token.
Parameter description :
An optional description for the maintenance window. We recommend
specifying a description to help you organize your maintenance windows.
Parameter endDate :
The date and time, in ISO-8601 Extended format, for when you want the
maintenance window to become inactive. EndDate allows you to
set a date and time in the future when the maintenance window will no
longer run.
Parameter scheduleOffset :
The number of days to wait after the date and time specified by a cron
expression before running the maintenance window.
For example, the following cron expression schedules a maintenance window to run on the third Tuesday of every month at 11:30 PM.
cron(30 23 ? * TUE#3 *)
If the schedule offset is 2, the maintenance window won't run
until two days later.
Parameter scheduleTimezone :
The time zone that the scheduled maintenance window executions are based
on, in Internet Assigned Numbers Authority (IANA) format. For example:
"America/Los_Angeles", "UTC", or "Asia/Seoul". For more information, see
the Time Zone Database on
the IANA website.
Parameter startDate :
The date and time, in ISO-8601 Extended format, for when you want the
maintenance window to become active. StartDate allows you to
delay activation of the maintenance window until the specified future
date.
Parameter tags :
Optional metadata that you assign to a resource. Tags enable you to
categorize a resource in different ways, such as by purpose, owner, or
environment. For example, you might want to tag a maintenance window to
identify the type of tasks it will run, the types of targets, and the
environment it will run in. In this case, you could specify the following
key-value pairs:
-
Key=TaskType,Value=AgentUpdate -
Key=OS,Value=Windows -
Key=Environment,Value=Production
Implementation
Future<CreateMaintenanceWindowResult> createMaintenanceWindow({
required bool allowUnassociatedTargets,
required int cutoff,
required int duration,
required String name,
required String schedule,
String? clientToken,
String? description,
String? endDate,
int? scheduleOffset,
String? scheduleTimezone,
String? startDate,
List<Tag>? tags,
}) async {
_s.validateNumRange(
'cutoff',
cutoff,
0,
23,
isRequired: true,
);
_s.validateNumRange(
'duration',
duration,
1,
24,
isRequired: true,
);
_s.validateNumRange(
'scheduleOffset',
scheduleOffset,
1,
6,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.CreateMaintenanceWindow'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AllowUnassociatedTargets': allowUnassociatedTargets,
'Cutoff': cutoff,
'Duration': duration,
'Name': name,
'Schedule': schedule,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (endDate != null) 'EndDate': endDate,
if (scheduleOffset != null) 'ScheduleOffset': scheduleOffset,
if (scheduleTimezone != null) 'ScheduleTimezone': scheduleTimezone,
if (startDate != null) 'StartDate': startDate,
if (tags != null) 'Tags': tags,
},
);
return CreateMaintenanceWindowResult.fromJson(jsonResponse.body);
}