createPatchBaseline method

Future<CreatePatchBaselineResult> createPatchBaseline({
  1. required String name,
  2. PatchRuleGroup? approvalRules,
  3. List<String>? approvedPatches,
  4. PatchComplianceLevel? approvedPatchesComplianceLevel,
  5. bool? approvedPatchesEnableNonSecurity,
  6. PatchComplianceStatus? availableSecurityUpdatesComplianceStatus,
  7. String? clientToken,
  8. String? description,
  9. PatchFilterGroup? globalFilters,
  10. OperatingSystem? operatingSystem,
  11. List<String>? rejectedPatches,
  12. PatchAction? rejectedPatchesAction,
  13. List<PatchSource>? sources,
  14. List<Tag>? tags,
})

Creates a patch baseline.

May throw IdempotentParameterMismatch. May throw InternalServerError. May throw ResourceLimitExceededException.

Parameter name : The name of the patch baseline.

Parameter approvalRules : A set of rules used to include patches in the baseline.

Parameter approvedPatches : A list of explicitly approved patches for the baseline.

For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.

Parameter approvedPatchesComplianceLevel : Defines the compliance level for approved patches. When an approved patch is reported as missing, this value describes the severity of the compliance violation. The default value is UNSPECIFIED.

Parameter approvedPatchesEnableNonSecurity : Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes. The default value is false. Applies to Linux managed nodes only.

Parameter availableSecurityUpdatesComplianceStatus : Indicates the status you want to assign to security patches that are available but not approved because they don't meet the installation criteria specified in the patch baseline.

Example scenario: Security patches that you might want installed can be skipped if you have specified a long period to wait after a patch is released before installation. If an update to the patch is released during your specified waiting period, the waiting period for installing the patch starts over. If the waiting period is too long, multiple versions of the patch could be released but never installed.

Supported for Windows Server managed nodes only.

Parameter clientToken : User-provided idempotency token.

Parameter description : A description of the patch baseline.

Parameter globalFilters : A set of global filters used to include patches in the baseline.

Parameter operatingSystem : Defines the operating system the patch baseline applies to. The default value is WINDOWS.

Parameter rejectedPatches : A list of explicitly rejected patches for the baseline.

For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.

Parameter rejectedPatchesAction : The action for Patch Manager to take on patches included in the RejectedPackages list.

ALLOW_AS_DEPENDENCY
Linux and macOS: A package in the rejected patches list is installed only if it is a dependency of another package. It is considered compliant with the patch baseline, and its status is reported as INSTALLED_OTHER. This is the default action if no option is specified.

Windows Server: Windows Server doesn't support the concept of package dependencies. If a package in the rejected patches list and already installed on the node, its status is reported as INSTALLED_OTHER. Any package not already installed on the node is skipped. This is the default action if no option is specified.

BLOCK
All OSs: Packages in the rejected patches list, and packages that include them as dependencies, aren't installed by Patch Manager under any circumstances.

State value assignment for patch compliance:

  • If a package was installed before it was added to the rejected patches list, or is installed outside of Patch Manager afterward, it's considered noncompliant with the patch baseline and its status is reported as INSTALLED_REJECTED.
  • If an update attempts to install a dependency package that is now rejected by the baseline, when previous versions of the package were not rejected, the package being updated is reported as MISSING for SCAN operations and as FAILED for INSTALL operations.

Parameter sources : Information about the patches to use to update the managed nodes, including target operating systems and source repositories. Applies to Linux managed nodes only.

Parameter tags : Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a patch baseline to identify the severity level of patches it specifies and the operating system family it applies to. In this case, you could specify the following key-value pairs:

  • Key=PatchSeverity,Value=Critical
  • Key=OS,Value=Windows

Implementation

Future<CreatePatchBaselineResult> createPatchBaseline({
  required String name,
  PatchRuleGroup? approvalRules,
  List<String>? approvedPatches,
  PatchComplianceLevel? approvedPatchesComplianceLevel,
  bool? approvedPatchesEnableNonSecurity,
  PatchComplianceStatus? availableSecurityUpdatesComplianceStatus,
  String? clientToken,
  String? description,
  PatchFilterGroup? globalFilters,
  OperatingSystem? operatingSystem,
  List<String>? rejectedPatches,
  PatchAction? rejectedPatchesAction,
  List<PatchSource>? sources,
  List<Tag>? tags,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.CreatePatchBaseline'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Name': name,
      if (approvalRules != null) 'ApprovalRules': approvalRules,
      if (approvedPatches != null) 'ApprovedPatches': approvedPatches,
      if (approvedPatchesComplianceLevel != null)
        'ApprovedPatchesComplianceLevel':
            approvedPatchesComplianceLevel.value,
      if (approvedPatchesEnableNonSecurity != null)
        'ApprovedPatchesEnableNonSecurity': approvedPatchesEnableNonSecurity,
      if (availableSecurityUpdatesComplianceStatus != null)
        'AvailableSecurityUpdatesComplianceStatus':
            availableSecurityUpdatesComplianceStatus.value,
      'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
      if (description != null) 'Description': description,
      if (globalFilters != null) 'GlobalFilters': globalFilters,
      if (operatingSystem != null) 'OperatingSystem': operatingSystem.value,
      if (rejectedPatches != null) 'RejectedPatches': rejectedPatches,
      if (rejectedPatchesAction != null)
        'RejectedPatchesAction': rejectedPatchesAction.value,
      if (sources != null) 'Sources': sources,
      if (tags != null) 'Tags': tags,
    },
  );

  return CreatePatchBaselineResult.fromJson(jsonResponse.body);
}