createResourceDataSync method

Future<void> createResourceDataSync({
  1. required String syncName,
  2. ResourceDataSyncS3Destination? s3Destination,
  3. ResourceDataSyncSource? syncSource,
  4. String? syncType,
})

A resource data sync helps you view data from multiple sources in a single location. Amazon Web Services Systems Manager offers two types of resource data sync: SyncToDestination and SyncFromSource.

You can configure Systems Manager Inventory to use the SyncToDestination type to synchronize Inventory data from multiple Amazon Web Services Regions to a single Amazon Simple Storage Service (Amazon S3) bucket. For more information, see Creating a resource data sync for Inventory in the Amazon Web Services Systems Manager User Guide.

You can configure Systems Manager Explorer to use the SyncFromSource type to synchronize operational work items (OpsItems) and operational data (OpsData) from multiple Amazon Web Services Regions to a single Amazon S3 bucket. This type can synchronize OpsItems and OpsData from multiple Amazon Web Services accounts and Amazon Web Services Regions or EntireOrganization by using Organizations. For more information, see Setting up Systems Manager Explorer to display data from multiple accounts and Regions in the Amazon Web Services Systems Manager User Guide.

A resource data sync is an asynchronous operation that returns immediately. After a successful initial sync is completed, the system continuously syncs data. To check the status of a sync, use the ListResourceDataSync.

May throw InternalServerError. May throw ResourceDataSyncAlreadyExistsException. May throw ResourceDataSyncCountExceededException. May throw ResourceDataSyncInvalidConfigurationException.

Parameter syncName : A name for the configuration.

Parameter s3Destination : Amazon S3 configuration details for the sync. This parameter is required if the SyncType value is SyncToDestination.

Parameter syncSource : Specify information about the data sources to synchronize. This parameter is required if the SyncType value is SyncFromSource.

Parameter syncType : Specify SyncToDestination to create a resource data sync that synchronizes data to an S3 bucket for Inventory. If you specify SyncToDestination, you must provide a value for S3Destination. Specify SyncFromSource to synchronize data from a single account and multiple Regions, or multiple Amazon Web Services accounts and Amazon Web Services Regions, as listed in Organizations for Explorer. If you specify SyncFromSource, you must provide a value for SyncSource. The default value is SyncToDestination.

Implementation

Future<void> createResourceDataSync({
  required String syncName,
  ResourceDataSyncS3Destination? s3Destination,
  ResourceDataSyncSource? syncSource,
  String? syncType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.CreateResourceDataSync'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'SyncName': syncName,
      if (s3Destination != null) 'S3Destination': s3Destination,
      if (syncSource != null) 'SyncSource': syncSource,
      if (syncType != null) 'SyncType': syncType,
    },
  );
}