deleteActivation method

Future<void> deleteActivation({
  1. required String activationId,
})

Deletes an activation. You aren't required to delete an activation. If you delete an activation, you can no longer use it to register additional managed nodes. Deleting an activation doesn't de-register managed nodes. You must manually de-register managed nodes.

May throw InternalServerError. May throw InvalidActivation. May throw InvalidActivationId. May throw TooManyUpdates.

Parameter activationId : The ID of the activation that you want to delete.

Implementation

Future<void> deleteActivation({
  required String activationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.DeleteActivation'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ActivationId': activationId,
    },
  );
}