deleteAssociation method

Future<void> deleteAssociation({
  1. String? associationId,
  2. String? instanceId,
  3. String? name,
})

Disassociates the specified Amazon Web Services Systems Manager document (SSM document) from the specified managed node. If you created the association by using the Targets parameter, then you must delete the association by using the association ID.

When you disassociate a document from a managed node, it doesn't change the configuration of the node. To change the configuration state of a managed node after you disassociate a document, you must create a new document with the desired configuration and associate it with the node.

May throw AssociationDoesNotExist. May throw InternalServerError. May throw InvalidDocument. May throw InvalidInstanceId. May throw TooManyUpdates.

Parameter associationId : The association ID that you want to delete.

Parameter instanceId : The managed node ID.

Parameter name : The name of the SSM document.

Implementation

Future<void> deleteAssociation({
  String? associationId,
  String? instanceId,
  String? name,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.DeleteAssociation'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (associationId != null) 'AssociationId': associationId,
      if (instanceId != null) 'InstanceId': instanceId,
      if (name != null) 'Name': name,
    },
  );
}