deleteOpsItem method
Delete an OpsItem. You must have permission in Identity and Access Management (IAM) to delete an OpsItem.
- Deleting an OpsItem is irreversible. You can't restore a deleted OpsItem.
- This operation uses an eventual consistency model, which means the system can take a few minutes to complete this operation. If you delete an OpsItem and immediately call, for example, GetOpsItem, the deleted OpsItem might still appear in the response.
- This operation is idempotent. The system doesn't throw an exception if you repeatedly call this operation for the same OpsItem. If the first call is successful, all additional calls return the same successful response as the first call.
- This operation doesn't support cross-account calls. A delegated administrator or management account can't delete OpsItems in other accounts, even if OpsCenter has been set up for cross-account administration. For more information about cross-account administration, see Setting up OpsCenter to centrally manage OpsItems across accounts in the Systems Manager User Guide.
May throw InternalServerError.
May throw OpsItemInvalidParameterException.
Parameter opsItemId :
The ID of the OpsItem that you want to delete.
Implementation
Future<void> deleteOpsItem({
required String opsItemId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.DeleteOpsItem'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OpsItemId': opsItemId,
},
);
}