deleteResourceDataSync method

Future<void> deleteResourceDataSync({
  1. required String syncName,
  2. String? syncType,
})

Deletes a resource data sync configuration. After the configuration is deleted, changes to data on managed nodes are no longer synced to or from the target. Deleting a sync configuration doesn't delete data.

May throw InternalServerError. May throw ResourceDataSyncInvalidConfigurationException. May throw ResourceDataSyncNotFoundException.

Parameter syncName : The name of the configuration to delete.

Parameter syncType : Specify the type of resource data sync to delete.

Implementation

Future<void> deleteResourceDataSync({
  required String syncName,
  String? syncType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.DeleteResourceDataSync'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'SyncName': syncName,
      if (syncType != null) 'SyncType': syncType,
    },
  );
}