describeMaintenanceWindowTasks method
Lists the tasks in a maintenance window.
May throw DoesNotExistException.
May throw InternalServerError.
Parameter windowId :
The ID of the maintenance window whose tasks should be retrieved.
Parameter filters :
Optional filters used to narrow down the scope of the returned tasks. The
supported filter keys are WindowTaskId, TaskArn,
Priority, and TaskType.
Parameter maxResults :
The maximum number of items to return for this call. The call also returns
a token that you can specify in a subsequent call to get the next set of
results.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<DescribeMaintenanceWindowTasksResult> describeMaintenanceWindowTasks({
required String windowId,
List<MaintenanceWindowFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
10,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.DescribeMaintenanceWindowTasks'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WindowId': windowId,
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeMaintenanceWindowTasksResult.fromJson(jsonResponse.body);
}