describePatchBaselines method
Lists the patch baselines in your Amazon Web Services account.
May throw InternalServerError.
Parameter filters :
Each element in the array is a structure containing a key-value pair.
Supported keys for DescribePatchBaselines include the
following:
-
NAME_PREFIXSample values:
AWS-|My- -
OWNERSample values:
AWS|Self -
OPERATING_SYSTEMSample values:
AMAZON_LINUX|SUSE|WINDOWS
Parameter maxResults :
The maximum number of patch baselines to return (per page).
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<DescribePatchBaselinesResult> describePatchBaselines({
List<PatchOrchestratorFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.DescribePatchBaselines'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribePatchBaselinesResult.fromJson(jsonResponse.body);
}