disassociateOpsItemRelatedItem method

Future<void> disassociateOpsItemRelatedItem({
  1. required String associationId,
  2. required String opsItemId,
})

Deletes the association between an OpsItem and a related item. For example, this API operation can delete an Incident Manager incident from an OpsItem. Incident Manager is a tool in Amazon Web Services Systems Manager.

May throw InternalServerError. May throw OpsItemConflictException. May throw OpsItemInvalidParameterException. May throw OpsItemNotFoundException. May throw OpsItemRelatedItemAssociationNotFoundException.

Parameter associationId : The ID of the association for which you want to delete an association between the OpsItem and a related item.

Parameter opsItemId : The ID of the OpsItem for which you want to delete an association between the OpsItem and a related item.

Implementation

Future<void> disassociateOpsItemRelatedItem({
  required String associationId,
  required String opsItemId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.DisassociateOpsItemRelatedItem'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AssociationId': associationId,
      'OpsItemId': opsItemId,
    },
  );
}