getConnectionStatus method
Retrieves the Session Manager connection status for a managed node to determine whether it is running and ready to receive Session Manager connections.
May throw InternalServerError.
Parameter target :
The managed node ID.
Implementation
Future<GetConnectionStatusResponse> getConnectionStatus({
required String target,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.GetConnectionStatus'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Target': target,
},
);
return GetConnectionStatusResponse.fromJson(jsonResponse.body);
}