getExecutionPreview method

Future<GetExecutionPreviewResponse> getExecutionPreview({
  1. required String executionPreviewId,
})

Initiates the process of retrieving an existing preview that shows the effects that running a specified Automation runbook would have on the targeted resources.

May throw InternalServerError. May throw ResourceNotFoundException.

Parameter executionPreviewId : The ID of the existing execution preview.

Implementation

Future<GetExecutionPreviewResponse> getExecutionPreview({
  required String executionPreviewId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.GetExecutionPreview'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ExecutionPreviewId': executionPreviewId,
    },
  );

  return GetExecutionPreviewResponse.fromJson(jsonResponse.body);
}