getServiceSetting method
ServiceSetting is an account-level setting for an Amazon Web
Services service. This setting defines how a user interacts with or uses a
service or a feature of a service. For example, if an Amazon Web Services
service charges money to the account based on feature or service usage,
then the Amazon Web Services service team might create a default setting
of false. This means the user can't use this feature unless
they change the setting to true and intentionally opt in for
a paid feature.
Services map a SettingId object to a setting value. Amazon
Web Services services teams define the default value for a
SettingId. You can't create a new SettingId, but
you can overwrite the default value if you have the
ssm:UpdateServiceSetting permission for the setting. Use the
UpdateServiceSetting API operation to change the default setting.
Or use the ResetServiceSetting to change the value back to the
original value defined by the Amazon Web Services service team.
Query the current service setting for the Amazon Web Services account.
May throw InternalServerError.
May throw ServiceSettingNotFound.
Parameter settingId :
The ID of the service setting to get. The setting ID can be one of the
following.
-
/ssm/appmanager/appmanager-enabled -
/ssm/automation/customer-script-log-destination -
/ssm/automation/customer-script-log-group-name - /ssm/automation/enable-adaptive-concurrency
-
/ssm/documents/console/public-sharing-permission -
/ssm/managed-instance/activation-tier -
/ssm/managed-instance/default-ec2-instance-management-role -
/ssm/opsinsights/opscenter -
/ssm/parameter-store/default-parameter-tier -
/ssm/parameter-store/high-throughput-enabled
Implementation
Future<GetServiceSettingResult> getServiceSetting({
required String settingId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.GetServiceSetting'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SettingId': settingId,
},
);
return GetServiceSettingResult.fromJson(jsonResponse.body);
}