registerPatchBaselineForPatchGroup method
Registers a patch baseline for a patch group.
May throw AlreadyExistsException.
May throw DoesNotExistException.
May throw InternalServerError.
May throw InvalidResourceId.
May throw ResourceLimitExceededException.
Parameter baselineId :
The ID of the patch baseline to register with the patch group.
Parameter patchGroup :
The name of the patch group to be registered with the patch baseline.
Implementation
Future<RegisterPatchBaselineForPatchGroupResult>
registerPatchBaselineForPatchGroup({
required String baselineId,
required String patchGroup,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.RegisterPatchBaselineForPatchGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'BaselineId': baselineId,
'PatchGroup': patchGroup,
},
);
return RegisterPatchBaselineForPatchGroupResult.fromJson(jsonResponse.body);
}