sendCommand method

Future<SendCommandResult> sendCommand({
  1. required String documentName,
  2. AlarmConfiguration? alarmConfiguration,
  3. CloudWatchOutputConfig? cloudWatchOutputConfig,
  4. String? comment,
  5. String? documentHash,
  6. DocumentHashType? documentHashType,
  7. String? documentVersion,
  8. List<String>? instanceIds,
  9. String? maxConcurrency,
  10. String? maxErrors,
  11. NotificationConfig? notificationConfig,
  12. String? outputS3BucketName,
  13. String? outputS3KeyPrefix,
  14. String? outputS3Region,
  15. Map<String, List<String>>? parameters,
  16. String? serviceRoleArn,
  17. List<Target>? targets,
  18. int? timeoutSeconds,
})

Runs commands on one or more managed nodes.

May throw DuplicateInstanceId. May throw InternalServerError. May throw InvalidDocument. May throw InvalidDocumentVersion. May throw InvalidInstanceId. May throw InvalidNotificationConfig. May throw InvalidOutputFolder. May throw InvalidParameters. May throw InvalidRole. May throw MaxDocumentSizeExceeded. May throw UnsupportedPlatformType.

Parameter documentName : The name of the Amazon Web Services Systems Manager document (SSM document) to run. This can be a public document or a custom document. To run a shared document belonging to another account, specify the document Amazon Resource Name (ARN). For more information about how to use shared documents, see Sharing SSM documents in the Amazon Web Services Systems Manager User Guide.

Parameter alarmConfiguration : The CloudWatch alarm you want to apply to your command.

Parameter cloudWatchOutputConfig : Enables Amazon Web Services Systems Manager to send Run Command output to Amazon CloudWatch Logs. Run Command is a tool in Amazon Web Services Systems Manager.

Parameter comment : User-specified information about the command, such as a brief description of what the command should do.

Parameter documentHash : The Sha256 or Sha1 hash created by the system when the document was created.

Parameter documentHashType : Sha256 or Sha1.

Parameter documentVersion : The SSM document version to use in the request. You can specify $DEFAULT, $LATEST, or a specific version number. If you run commands by using the Command Line Interface (Amazon Web Services CLI), then you must escape the first two options by using a backslash. If you specify a version number, then you don't need to use the backslash. For example:

--document-version "$DEFAULT"

--document-version "$LATEST"

--document-version "3"

Parameter instanceIds : The IDs of the managed nodes where the command should run. Specifying managed node IDs is most useful when you are targeting a limited number of managed nodes, though you can specify up to 50 IDs.

To target a larger number of managed nodes, or if you prefer not to list individual node IDs, we recommend using the Targets option instead. Using Targets, which accepts tag key-value pairs to identify the managed nodes to send commands to, you can a send command to tens, hundreds, or thousands of nodes at once.

For more information about how to use targets, see Run commands at scale in the Amazon Web Services Systems Manager User Guide.

Parameter maxConcurrency : (Optional) The maximum number of managed nodes that are allowed to run the command at the same time. You can specify a number such as 10 or a percentage such as 10%. The default value is 50. For more information about how to use MaxConcurrency, see Using concurrency controls in the Amazon Web Services Systems Manager User Guide.

Parameter maxErrors : The maximum number of errors allowed without the command failing. When the command fails one more time beyond the value of MaxErrors, the systems stops sending the command to additional targets. You can specify a number like 10 or a percentage like 10%. The default value is 0. For more information about how to use MaxErrors, see Using error controls in the Amazon Web Services Systems Manager User Guide.

Parameter notificationConfig : Configurations for sending notifications.

Parameter outputS3BucketName : The name of the S3 bucket where command execution responses should be stored.

Parameter outputS3KeyPrefix : The directory structure within the S3 bucket where the responses should be stored.

Parameter outputS3Region : (Deprecated) You can no longer specify this parameter. The system ignores it. Instead, Systems Manager automatically determines the Amazon Web Services Region of the S3 bucket.

Parameter parameters : The required and optional parameters specified in the document being run.

Parameter serviceRoleArn : The ARN of the Identity and Access Management (IAM) service role to use to publish Amazon Simple Notification Service (Amazon SNS) notifications for Run Command commands.

This role must provide the sns:Publish permission for your notification topic. For information about creating and using this service role, see Monitoring Systems Manager status changes using Amazon SNS notifications in the Amazon Web Services Systems Manager User Guide.

Parameter targets : An array of search criteria that targets managed nodes using a Key,Value combination that you specify. Specifying targets is most useful when you want to send a command to a large number of managed nodes at once. Using Targets, which accepts tag key-value pairs to identify managed nodes, you can send a command to tens, hundreds, or thousands of nodes at once.

To send a command to a smaller number of managed nodes, you can use the InstanceIds option instead.

For more information about how to use targets, see Run commands at scale in the Amazon Web Services Systems Manager User Guide.

Parameter timeoutSeconds : If this time is reached and the command hasn't already started running, it won't run.

Implementation

Future<SendCommandResult> sendCommand({
  required String documentName,
  AlarmConfiguration? alarmConfiguration,
  CloudWatchOutputConfig? cloudWatchOutputConfig,
  String? comment,
  String? documentHash,
  DocumentHashType? documentHashType,
  String? documentVersion,
  List<String>? instanceIds,
  String? maxConcurrency,
  String? maxErrors,
  NotificationConfig? notificationConfig,
  String? outputS3BucketName,
  String? outputS3KeyPrefix,
  String? outputS3Region,
  Map<String, List<String>>? parameters,
  String? serviceRoleArn,
  List<Target>? targets,
  int? timeoutSeconds,
}) async {
  _s.validateNumRange(
    'timeoutSeconds',
    timeoutSeconds,
    30,
    2592000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.SendCommand'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DocumentName': documentName,
      if (alarmConfiguration != null)
        'AlarmConfiguration': alarmConfiguration,
      if (cloudWatchOutputConfig != null)
        'CloudWatchOutputConfig': cloudWatchOutputConfig,
      if (comment != null) 'Comment': comment,
      if (documentHash != null) 'DocumentHash': documentHash,
      if (documentHashType != null)
        'DocumentHashType': documentHashType.value,
      if (documentVersion != null) 'DocumentVersion': documentVersion,
      if (instanceIds != null) 'InstanceIds': instanceIds,
      if (maxConcurrency != null) 'MaxConcurrency': maxConcurrency,
      if (maxErrors != null) 'MaxErrors': maxErrors,
      if (notificationConfig != null)
        'NotificationConfig': notificationConfig,
      if (outputS3BucketName != null)
        'OutputS3BucketName': outputS3BucketName,
      if (outputS3KeyPrefix != null) 'OutputS3KeyPrefix': outputS3KeyPrefix,
      if (outputS3Region != null) 'OutputS3Region': outputS3Region,
      if (parameters != null) 'Parameters': parameters,
      if (serviceRoleArn != null) 'ServiceRoleArn': serviceRoleArn,
      if (targets != null) 'Targets': targets,
      if (timeoutSeconds != null) 'TimeoutSeconds': timeoutSeconds,
    },
  );

  return SendCommandResult.fromJson(jsonResponse.body);
}