updateAssociation method

Future<UpdateAssociationResult> updateAssociation({
  1. required String associationId,
  2. AlarmConfiguration? alarmConfiguration,
  3. bool? applyOnlyAtCronInterval,
  4. String? associationDispatchAssumeRole,
  5. String? associationName,
  6. String? associationVersion,
  7. String? automationTargetParameterName,
  8. List<String>? calendarNames,
  9. AssociationComplianceSeverity? complianceSeverity,
  10. String? documentVersion,
  11. int? duration,
  12. String? maxConcurrency,
  13. String? maxErrors,
  14. String? name,
  15. InstanceAssociationOutputLocation? outputLocation,
  16. Map<String, List<String>>? parameters,
  17. String? scheduleExpression,
  18. int? scheduleOffset,
  19. AssociationSyncCompliance? syncCompliance,
  20. List<TargetLocation>? targetLocations,
  21. List<Map<String, List<String>>>? targetMaps,
  22. List<Target>? targets,
})

Updates an association. You can update the association name and version, the document version, schedule, parameters, and Amazon Simple Storage Service (Amazon S3) output. When you call UpdateAssociation, the system removes all optional parameters from the request and overwrites the association with null values for those parameters. This is by design. You must specify all optional parameters in the call, even if you are not changing the parameters. This includes the Name parameter. Before calling this API action, we recommend that you call the DescribeAssociation API operation and make a note of all optional parameters required for your UpdateAssociation call.

In order to call this API operation, a user, group, or role must be granted permission to call the DescribeAssociation API operation. If you don't have permission to call DescribeAssociation, then you receive the following error: An error occurred (AccessDeniedException) when calling the UpdateAssociation operation: User: <user_arn> isn't authorized to perform: ssm:DescribeAssociation on resource: <resource_arn>

May throw AssociationDoesNotExist. May throw AssociationVersionLimitExceeded. May throw InternalServerError. May throw InvalidAssociationVersion. May throw InvalidDocument. May throw InvalidDocumentVersion. May throw InvalidOutputLocation. May throw InvalidParameters. May throw InvalidSchedule. May throw InvalidTarget. May throw InvalidTargetMaps. May throw InvalidUpdate. May throw TooManyUpdates.

Parameter associationId : The ID of the association you want to update.

Parameter applyOnlyAtCronInterval : By default, when you update an association, the system runs it immediately after it is updated and then according to the schedule you specified. Specify true for ApplyOnlyAtCronInterval if you want the association to run only according to the schedule you specified.

If you chose this option when you created an association and later you edit that association or you make changes to the Automation runbook or SSM document on which that association is based, State Manager applies the association at the next specified cron interval. For example, if you chose the Latest version of an SSM document when you created an association and you edit the association by choosing a different document version on the Documents page, State Manager applies the association at the next specified cron interval if you previously set ApplyOnlyAtCronInterval to true. If this option wasn't selected, State Manager immediately runs the association.

For more information, see Understanding when associations are applied to resources and About target updates with Automation runbooks in the Amazon Web Services Systems Manager User Guide.

This parameter isn't supported for rate expressions.

You can reset this parameter. To do so, specify the no-apply-only-at-cron-interval parameter when you update the association from the command line. This parameter forces the association to run immediately after updating it and according to the interval specified.

Parameter associationDispatchAssumeRole : A role used by association to take actions on your behalf. State Manager will assume this role and call required APIs when dispatching configurations to nodes. If not specified, service-linked role for Systems Manager will be used by default.

Service-linked role support in State Manager is being phased out. Associations relying on service-linked role may require updates in the future to continue functioning properly.

Parameter associationName : The name of the association that you want to update.

Parameter associationVersion : This parameter is provided for concurrency control purposes. You must specify the latest association version in the service. If you want to ensure that this request succeeds, either specify $LATEST, or omit this parameter.

Parameter automationTargetParameterName : Choose the parameter that will define how your automation will branch out. This target is required for associations that use an Automation runbook and target resources by using rate controls. Automation is a tool in Amazon Web Services Systems Manager.

Parameter calendarNames : The names or Amazon Resource Names (ARNs) of the Change Calendar type documents you want to gate your associations under. The associations only run when that change calendar is open. For more information, see Amazon Web Services Systems Manager Change Calendar in the Amazon Web Services Systems Manager User Guide.

Parameter complianceSeverity : The severity level to assign to the association.

Parameter documentVersion : The document version you want update for the association.

Parameter duration : The number of hours the association can run before it is canceled. Duration applies to associations that are currently running, and any pending and in progress commands on all targets. If a target was taken offline for the association to run, it is made available again immediately, without a reboot.

The Duration parameter applies only when both these conditions are true:

  • The association for which you specify a duration is cancelable according to the parameters of the SSM command document or Automation runbook associated with this execution.
  • The command specifies the ApplyOnlyAtCronInterval parameter, which means that the association doesn't run immediately after it is updated, but only according to the specified schedule.

Parameter maxConcurrency : The maximum number of targets allowed to run the association at the same time. You can specify a number, for example 10, or a percentage of the target set, for example 10%. The default value is 100%, which means all targets run the association at the same time.

If a new managed node starts and attempts to run an association while Systems Manager is running MaxConcurrency associations, the association is allowed to run. During the next association interval, the new managed node will process its association within the limit specified for MaxConcurrency.

Parameter maxErrors : The number of errors that are allowed before the system stops sending requests to run the association on additional targets. You can specify either an absolute number of errors, for example 10, or a percentage of the target set, for example 10%. If you specify 3, for example, the system stops sending requests when the fourth error is received. If you specify 0, then the system stops sending requests after the first error is returned. If you run an association on 50 managed nodes and set MaxError to 10%, then the system stops sending the request when the sixth error is received.

Executions that are already running an association when MaxErrors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set MaxConcurrency to 1 so that executions proceed one at a time.

Parameter name : The name of the SSM Command document or Automation runbook that contains the configuration information for the managed node.

You can specify Amazon Web Services-predefined documents, documents you created, or a document that is shared with you from another account.

For Systems Manager document (SSM document) that are shared with you from other Amazon Web Services accounts, you must specify the complete SSM document ARN, in the following format:

arn:aws:ssm:region:account-id:document/document-name

For example:

arn:aws:ssm:us-east-2:12345678912:document/My-Shared-Document

For Amazon Web Services-predefined documents and SSM documents you created in your account, you only need to specify the document name. For example, AWS-ApplyPatchBaseline or My-Document.

Parameter outputLocation : An S3 bucket where you want to store the results of this request.

Parameter parameters : The parameters you want to update for the association. If you create a parameter using Parameter Store, a tool in Amazon Web Services Systems Manager, you can reference the parameter using {{ssm:parameter-name}}.

Parameter scheduleExpression : The cron expression used to schedule the association that you want to update.

Parameter scheduleOffset : Number of days to wait after the scheduled day to run an association. For example, if you specified a cron schedule of cron(0 0 ? * THU#2 *), you could specify an offset of 3 to run the association each Sunday after the second Thursday of the month. For more information about cron schedules for associations, see Reference: Cron and rate expressions for Systems Manager in the Amazon Web Services Systems Manager User Guide.

Parameter syncCompliance : The mode for generating association compliance. You can specify AUTO or MANUAL. In AUTO mode, the system uses the status of the association execution to determine the compliance status. If the association execution runs successfully, then the association is COMPLIANT. If the association execution doesn't run successfully, the association is NON-COMPLIANT.

In MANUAL mode, you must specify the AssociationId as a parameter for the PutComplianceItems API operation. In this case, compliance data isn't managed by State Manager, a tool in Amazon Web Services Systems Manager. It is managed by your direct call to the PutComplianceItems API operation.

By default, all associations use AUTO mode.

Parameter targetLocations : A location is a combination of Amazon Web Services Regions and Amazon Web Services accounts where you want to run the association. Use this action to update an association in multiple Regions and multiple accounts.

Parameter targetMaps : A key-value mapping of document parameters to target resources. Both Targets and TargetMaps can't be specified together.

Parameter targets : The targets of the association.

Implementation

Future<UpdateAssociationResult> updateAssociation({
  required String associationId,
  AlarmConfiguration? alarmConfiguration,
  bool? applyOnlyAtCronInterval,
  String? associationDispatchAssumeRole,
  String? associationName,
  String? associationVersion,
  String? automationTargetParameterName,
  List<String>? calendarNames,
  AssociationComplianceSeverity? complianceSeverity,
  String? documentVersion,
  int? duration,
  String? maxConcurrency,
  String? maxErrors,
  String? name,
  InstanceAssociationOutputLocation? outputLocation,
  Map<String, List<String>>? parameters,
  String? scheduleExpression,
  int? scheduleOffset,
  AssociationSyncCompliance? syncCompliance,
  List<TargetLocation>? targetLocations,
  List<Map<String, List<String>>>? targetMaps,
  List<Target>? targets,
}) async {
  _s.validateNumRange(
    'duration',
    duration,
    1,
    24,
  );
  _s.validateNumRange(
    'scheduleOffset',
    scheduleOffset,
    1,
    6,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.UpdateAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AssociationId': associationId,
      if (alarmConfiguration != null)
        'AlarmConfiguration': alarmConfiguration,
      if (applyOnlyAtCronInterval != null)
        'ApplyOnlyAtCronInterval': applyOnlyAtCronInterval,
      if (associationDispatchAssumeRole != null)
        'AssociationDispatchAssumeRole': associationDispatchAssumeRole,
      if (associationName != null) 'AssociationName': associationName,
      if (associationVersion != null)
        'AssociationVersion': associationVersion,
      if (automationTargetParameterName != null)
        'AutomationTargetParameterName': automationTargetParameterName,
      if (calendarNames != null) 'CalendarNames': calendarNames,
      if (complianceSeverity != null)
        'ComplianceSeverity': complianceSeverity.value,
      if (documentVersion != null) 'DocumentVersion': documentVersion,
      if (duration != null) 'Duration': duration,
      if (maxConcurrency != null) 'MaxConcurrency': maxConcurrency,
      if (maxErrors != null) 'MaxErrors': maxErrors,
      if (name != null) 'Name': name,
      if (outputLocation != null) 'OutputLocation': outputLocation,
      if (parameters != null) 'Parameters': parameters,
      if (scheduleExpression != null)
        'ScheduleExpression': scheduleExpression,
      if (scheduleOffset != null) 'ScheduleOffset': scheduleOffset,
      if (syncCompliance != null) 'SyncCompliance': syncCompliance.value,
      if (targetLocations != null) 'TargetLocations': targetLocations,
      if (targetMaps != null) 'TargetMaps': targetMaps,
      if (targets != null) 'Targets': targets,
    },
  );

  return UpdateAssociationResult.fromJson(jsonResponse.body);
}