validateCloudConnector method

Future<ValidateCloudConnectorResult> validateCloudConnector({
  1. required String cloudConnectorId,
  2. int? maxResults,
  3. String? nextToken,
})

Validates the configuration and connectivity of a cloud connector.

May throw InternalServerError. May throw ResourceNotFoundException.

Parameter cloudConnectorId : The ID of the cloud connector to validate.

Parameter maxResults : The maximum number of validation findings to return.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<ValidateCloudConnectorResult> validateCloudConnector({
  required String cloudConnectorId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    75,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonSSM.ValidateCloudConnector'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CloudConnectorId': cloudConnectorId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ValidateCloudConnectorResult.fromJson(jsonResponse.body);
}