SsmContacts class

Systems Manager Incident Manager is an incident management console designed to help users mitigate and recover from incidents affecting their Amazon Web Services-hosted applications. An incident is any unplanned interruption or reduction in quality of services.

Incident Manager increases incident resolution by notifying responders of impact, highlighting relevant troubleshooting data, and providing collaboration tools to get services back up and running. To achieve the primary goal of reducing the time-to-resolution of critical incidents, Incident Manager automates response plans and enables responder team escalation.

Constructors

SsmContacts({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptPage({required String acceptCode, required AcceptType acceptType, required String pageId, AcceptCodeValidation? acceptCodeValidation, String? contactChannelId, String? note}) Future<void>
Used to acknowledge an engagement to a contact channel during an incident.
activateContactChannel({required String activationCode, required String contactChannelId}) Future<void>
Activates a contact's contact channel. Incident Manager can't engage a contact until the contact channel has been activated.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createContact({required String alias, required Plan plan, required ContactType type, String? displayName, String? idempotencyToken, List<Tag>? tags}) Future<CreateContactResult>
Contacts are either the contacts that Incident Manager engages during an incident or the escalation plans that Incident Manager uses to engage contacts in phases during an incident.
createContactChannel({required String contactId, required ContactChannelAddress deliveryAddress, required String name, required ChannelType type, bool? deferActivation, String? idempotencyToken}) Future<CreateContactChannelResult>
A contact channel is the method that Incident Manager uses to engage your contact.
createRotation({required List<String> contactIds, required String name, required RecurrenceSettings recurrence, required String timeZoneId, String? idempotencyToken, DateTime? startTime, List<Tag>? tags}) Future<CreateRotationResult>
Creates a rotation in an on-call schedule.
createRotationOverride({required DateTime endTime, required List<String> newContactIds, required String rotationId, required DateTime startTime, String? idempotencyToken}) Future<CreateRotationOverrideResult>
Creates an override for a rotation in an on-call schedule.
deactivateContactChannel({required String contactChannelId}) Future<void>
To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel.
deleteContact({required String contactId}) Future<void>
To remove a contact from Incident Manager, you can delete the contact. However, deleting a contact does not remove it from escalation plans and related response plans. Deleting an escalation plan also does not remove it from all related response plans. To modify an escalation plan, we recommend using the UpdateContact action to specify a different existing contact.
deleteContactChannel({required String contactChannelId}) Future<void>
To stop receiving engagements on a contact channel, you can delete the channel from a contact. Deleting the contact channel does not remove it from the contact's engagement plan, but the stage that includes the channel will be ignored. If you delete the only contact channel for a contact, you'll no longer be able to engage that contact during an incident.
deleteRotation({required String rotationId}) Future<void>
Deletes a rotation from the system. If a rotation belongs to more than one on-call schedule, this operation deletes it from all of them.
deleteRotationOverride({required String rotationId, required String rotationOverrideId}) Future<void>
Deletes an existing override for an on-call rotation.
describeEngagement({required String engagementId}) Future<DescribeEngagementResult>
Incident Manager uses engagements to engage contacts and escalation plans during an incident. Use this command to describe the engagement that occurred during an incident.
describePage({required String pageId}) Future<DescribePageResult>
Lists details of the engagement to a contact channel.
getContact({required String contactId}) Future<GetContactResult>
Retrieves information about the specified contact or escalation plan.
getContactChannel({required String contactChannelId}) Future<GetContactChannelResult>
List details about a specific contact channel.
getContactPolicy({required String contactArn}) Future<GetContactPolicyResult>
Retrieves the resource policies attached to the specified contact or escalation plan.
getRotation({required String rotationId}) Future<GetRotationResult>
Retrieves information about an on-call rotation.
getRotationOverride({required String rotationId, required String rotationOverrideId}) Future<GetRotationOverrideResult>
Retrieves information about an override to an on-call rotation.
listContactChannels({required String contactId, int? maxResults, String? nextToken}) Future<ListContactChannelsResult>
Lists all contact channels for the specified contact.
listContacts({String? aliasPrefix, int? maxResults, String? nextToken, ContactType? type}) Future<ListContactsResult>
Lists all contacts and escalation plans in Incident Manager.
listEngagements({String? incidentId, int? maxResults, String? nextToken, TimeRange? timeRangeValue}) Future<ListEngagementsResult>
Lists all engagements that have happened in an incident.
listPageReceipts({required String pageId, int? maxResults, String? nextToken}) Future<ListPageReceiptsResult>
Lists all of the engagements to contact channels that have been acknowledged.
listPageResolutions({required String pageId, String? nextToken}) Future<ListPageResolutionsResult>
Returns the resolution path of an engagement. For example, the escalation plan engaged in an incident might target an on-call schedule that includes several contacts in a rotation, but just one contact on-call when the incident starts. The resolution path indicates the hierarchy of escalation plan > on-call schedule > contact.
listPagesByContact({required String contactId, int? maxResults, String? nextToken}) Future<ListPagesByContactResult>
Lists the engagements to a contact's contact channels.
listPagesByEngagement({required String engagementId, int? maxResults, String? nextToken}) Future<ListPagesByEngagementResult>
Lists the engagements to contact channels that occurred by engaging a contact.
listPreviewRotationShifts({required DateTime endTime, required List<String> members, required RecurrenceSettings recurrence, required String timeZoneId, int? maxResults, String? nextToken, List<PreviewOverride>? overrides, DateTime? rotationStartTime, DateTime? startTime}) Future<ListPreviewRotationShiftsResult>
Returns a list of shifts based on rotation configuration parameters.
listRotationOverrides({required DateTime endTime, required String rotationId, required DateTime startTime, int? maxResults, String? nextToken}) Future<ListRotationOverridesResult>
Retrieves a list of overrides currently specified for an on-call rotation.
listRotations({int? maxResults, String? nextToken, String? rotationNamePrefix}) Future<ListRotationsResult>
Retrieves a list of on-call rotations.
listRotationShifts({required DateTime endTime, required String rotationId, int? maxResults, String? nextToken, DateTime? startTime}) Future<ListRotationShiftsResult>
Returns a list of shifts generated by an existing rotation in the system.
listTagsForResource({required String resourceARN}) Future<ListTagsForResourceResult>
Lists the tags of a contact, escalation plan, rotation, or on-call schedule.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putContactPolicy({required String contactArn, required String policy}) Future<void>
Adds a resource policy to the specified contact or escalation plan. The resource policy is used to share the contact or escalation plan using Resource Access Manager (RAM). For more information about cross-account sharing, see Setting up cross-account functionality.
sendActivationCode({required String contactChannelId}) Future<void>
Sends an activation code to a contact channel. The contact can use this code to activate the contact channel in the console or with the ActivateChannel operation. Incident Manager can't engage a contact channel until it has been activated.
startEngagement({required String contactId, required String content, required String sender, required String subject, String? idempotencyToken, String? incidentId, String? publicContent, String? publicSubject}) Future<StartEngagementResult>
Starts an engagement to a contact or escalation plan. The engagement engages each contact specified in the incident.
stopEngagement({required String engagementId, String? reason}) Future<void>
Stops an engagement before it finishes the final stage of the escalation plan or engagement plan. Further contacts aren't engaged.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Tags a contact or escalation plan. You can tag only contacts and escalation plans in the first region of your replication set.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes tags from the specified resource.
updateContact({required String contactId, String? displayName, Plan? plan}) Future<void>
Updates the contact or escalation plan specified.
updateContactChannel({required String contactChannelId, ContactChannelAddress? deliveryAddress, String? name}) Future<void>
Updates a contact's contact channel.
updateRotation({required RecurrenceSettings recurrence, required String rotationId, List<String>? contactIds, DateTime? startTime, String? timeZoneId}) Future<void>
Updates the information specified for an on-call rotation.

Operators

operator ==(Object other) bool
The equality operator.
inherited