deleteRotation method
Deletes a rotation from the system. If a rotation belongs to more than one on-call schedule, this operation deletes it from all of them.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter rotationId :
The Amazon Resource Name (ARN) of the on-call rotation to delete.
Implementation
Future<void> deleteRotation({
required String rotationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SSMContacts.DeleteRotation'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RotationId': rotationId,
},
);
}