listPageReceipts method

Future<ListPageReceiptsResult> listPageReceipts({
  1. required String pageId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all of the engagements to contact channels that have been acknowledged.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter pageId : The Amazon Resource Name (ARN) of the engagement to a specific contact channel.

Parameter maxResults : The maximum number of acknowledgements per page of results.

Parameter nextToken : The pagination token to continue to the next page of results.

Implementation

Future<ListPageReceiptsResult> listPageReceipts({
  required String pageId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    0,
    1024,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SSMContacts.ListPageReceipts'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'PageId': pageId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListPageReceiptsResult.fromJson(jsonResponse.body);
}