listPageResolutions method

Future<ListPageResolutionsResult> listPageResolutions({
  1. required String pageId,
  2. String? nextToken,
})

Returns the resolution path of an engagement. For example, the escalation plan engaged in an incident might target an on-call schedule that includes several contacts in a rotation, but just one contact on-call when the incident starts. The resolution path indicates the hierarchy of escalation plan > on-call schedule > contact.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter pageId : The Amazon Resource Name (ARN) of the contact engaged for the incident.

Parameter nextToken : A token to start the list. Use this token to get the next set of results.

Implementation

Future<ListPageResolutionsResult> listPageResolutions({
  required String pageId,
  String? nextToken,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SSMContacts.ListPageResolutions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'PageId': pageId,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListPageResolutionsResult.fromJson(jsonResponse.body);
}