sendActivationCode method

Future<void> sendActivationCode({
  1. required String contactChannelId,
})

Sends an activation code to a contact channel. The contact can use this code to activate the contact channel in the console or with the ActivateChannel operation. Incident Manager can't engage a contact channel until it has been activated.

May throw AccessDeniedException. May throw DataEncryptionException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter contactChannelId : The Amazon Resource Name (ARN) of the contact channel.

Implementation

Future<void> sendActivationCode({
  required String contactChannelId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SSMContacts.SendActivationCode'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ContactChannelId': contactChannelId,
    },
  );
}