SsmGuiConnect class

Systems Manager GUI Connect, a component of Fleet Manager, lets you connect to your Window Server-type Amazon Elastic Compute Cloud (Amazon EC2) instances using the Remote Desktop Protocol (RDP). GUI Connect, which is powered by Amazon DCV, provides you with secure connectivity to your Windows Server instances directly from the Systems Manager console. You can have up to four simultaneous connections in a single browser window. In the console, GUI Connect is also referred to as Fleet Manager Remote Desktop.

Constructors

SsmGuiConnect({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteConnectionRecordingPreferences({String? clientToken}) Future<DeleteConnectionRecordingPreferencesResponse>
Deletes the preferences for recording RDP connections.
getConnectionRecordingPreferences() Future<GetConnectionRecordingPreferencesResponse>
Returns the preferences specified for recording RDP connections in the requesting Amazon Web Services account and Amazon Web Services Region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateConnectionRecordingPreferences({required ConnectionRecordingPreferences connectionRecordingPreferences, String? clientToken}) Future<UpdateConnectionRecordingPreferencesResponse>
Updates the preferences for recording RDP connections.

Operators

operator ==(Object other) bool
The equality operator.
inherited