createConfigurationManager method

Future<CreateConfigurationManagerOutput> createConfigurationManager({
  1. required List<ConfigurationDefinitionInput> configurationDefinitions,
  2. String? description,
  3. String? name,
  4. Map<String, String>? tags,
})

Creates a Quick Setup configuration manager resource. This object is a collection of desired state configurations for multiple configuration definitions and summaries describing the deployments of those definitions.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter configurationDefinitions : The definition of the Quick Setup configuration that the configuration manager deploys.

Parameter description : A description of the configuration manager.

Parameter name : A name for the configuration manager.

Parameter tags : Key-value pairs of metadata to assign to the configuration manager.

Implementation

Future<CreateConfigurationManagerOutput> createConfigurationManager({
  required List<ConfigurationDefinitionInput> configurationDefinitions,
  String? description,
  String? name,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'ConfigurationDefinitions': configurationDefinitions,
    if (description != null) 'Description': description,
    if (name != null) 'Name': name,
    if (tags != null) 'Tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/configurationManager',
    exceptionFnMap: _exceptionFns,
  );
  return CreateConfigurationManagerOutput.fromJson(response);
}