getServiceSettings method

Future<GetServiceSettingsOutput> getServiceSettings()

Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException.

Implementation

Future<GetServiceSettingsOutput> getServiceSettings() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/serviceSettings',
    exceptionFnMap: _exceptionFns,
  );
  return GetServiceSettingsOutput.fromJson(response);
}