listConfigurationManagers method

Future<ListConfigurationManagersOutput> listConfigurationManagers({
  1. List<Filter>? filters,
  2. int? maxItems,
  3. String? startingToken,
})

Returns Quick Setup configuration managers.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter filters : Filters the results returned by the request.

Parameter maxItems : Specifies the maximum number of configuration managers that are returned by the request.

Parameter startingToken : The token to use when requesting a specific set of items from a list.

Implementation

Future<ListConfigurationManagersOutput> listConfigurationManagers({
  List<Filter>? filters,
  int? maxItems,
  String? startingToken,
}) async {
  final $payload = <String, dynamic>{
    if (filters != null) 'Filters': filters,
    if (maxItems != null) 'MaxItems': maxItems,
    if (startingToken != null) 'StartingToken': startingToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/listConfigurationManagers',
    exceptionFnMap: _exceptionFns,
  );
  return ListConfigurationManagersOutput.fromJson(response);
}