updateConfigurationDefinition method

Future<void> updateConfigurationDefinition({
  1. required String id,
  2. required String managerArn,
  3. String? localDeploymentAdministrationRoleArn,
  4. String? localDeploymentExecutionRoleName,
  5. Map<String, String>? parameters,
  6. String? typeVersion,
})

Updates a Quick Setup configuration definition.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter id : The ID of the configuration definition you want to update.

Parameter managerArn : The ARN of the configuration manager associated with the definition to update.

Parameter localDeploymentAdministrationRoleArn : The ARN of the IAM role used to administrate local configuration deployments.

Parameter localDeploymentExecutionRoleName : The name of the IAM role used to deploy local configurations.

Parameter parameters : The parameters for the configuration definition type.

Parameter typeVersion : The version of the Quick Setup type to use.

Implementation

Future<void> updateConfigurationDefinition({
  required String id,
  required String managerArn,
  String? localDeploymentAdministrationRoleArn,
  String? localDeploymentExecutionRoleName,
  Map<String, String>? parameters,
  String? typeVersion,
}) async {
  final $payload = <String, dynamic>{
    if (localDeploymentAdministrationRoleArn != null)
      'LocalDeploymentAdministrationRoleArn':
          localDeploymentAdministrationRoleArn,
    if (localDeploymentExecutionRoleName != null)
      'LocalDeploymentExecutionRoleName': localDeploymentExecutionRoleName,
    if (parameters != null) 'Parameters': parameters,
    if (typeVersion != null) 'TypeVersion': typeVersion,
  };
  await _protocol.send(
    payload: $payload,
    method: 'PUT',
    requestUri:
        '/configurationDefinition/${Uri.encodeComponent(managerArn)}/${Uri.encodeComponent(id)}',
    exceptionFnMap: _exceptionFns,
  );
}