SsmSap class
This API reference provides descriptions, syntax, and other details about each of the actions and data types for AWS Systems Manager for SAP. The topic for each action shows the API request parameters and responses.
Constructors
- SsmSap({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deleteResourcePermission(
{required String resourceArn, PermissionActionType? actionType, String? sourceResourceArn}) → Future< DeleteResourcePermissionOutput> - Removes permissions associated with the target database.
-
deregisterApplication(
{required String applicationId}) → Future< void> - Deregister an SAP application with AWS Systems Manager for SAP. This action does not affect the existing setup of your SAP workloads on Amazon EC2.
-
getApplication(
{String? appRegistryArn, String? applicationArn, String? applicationId}) → Future< GetApplicationOutput> - Gets an application registered with AWS Systems Manager for SAP. It also returns the components of the application.
-
getComponent(
{required String applicationId, required String componentId}) → Future< GetComponentOutput> - Gets the component of an application registered with AWS Systems Manager for SAP.
-
getConfigurationCheckOperation(
{required String operationId}) → Future< GetConfigurationCheckOperationOutput> - Gets the details of a configuration check operation by specifying the operation ID.
-
getDatabase(
{String? applicationId, String? componentId, String? databaseArn, String? databaseId}) → Future< GetDatabaseOutput> - Gets the SAP HANA database of an application registered with AWS Systems Manager for SAP.
-
getOperation(
{required String operationId}) → Future< GetOperationOutput> - Gets the details of an operation by specifying the operation ID.
-
getResourcePermission(
{required String resourceArn, PermissionActionType? actionType}) → Future< GetResourcePermissionOutput> - Gets permissions associated with the target database.
-
listApplications(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListApplicationsOutput> - Lists all the applications registered with AWS Systems Manager for SAP.
-
listComponents(
{String? applicationId, int? maxResults, String? nextToken}) → Future< ListComponentsOutput> - Lists all the components registered with AWS Systems Manager for SAP.
-
listConfigurationCheckDefinitions(
{int? maxResults, String? nextToken}) → Future< ListConfigurationCheckDefinitionsOutput> - Lists all configuration check types supported by AWS Systems Manager for SAP.
-
listConfigurationCheckOperations(
{required String applicationId, List< Filter> ? filters, ConfigurationCheckOperationListingMode? listMode, int? maxResults, String? nextToken}) → Future<ListConfigurationCheckOperationsOutput> - Lists the configuration check operations performed by AWS Systems Manager for SAP.
-
listDatabases(
{String? applicationId, String? componentId, int? maxResults, String? nextToken}) → Future< ListDatabasesOutput> - Lists the SAP HANA databases of an application registered with AWS Systems Manager for SAP.
-
listOperationEvents(
{required String operationId, List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListOperationEventsOutput> - Returns a list of operations events.
-
listOperations(
{required String applicationId, List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListOperationsOutput> - Lists the operations performed by AWS Systems Manager for SAP.
-
listSubCheckResults(
{required String operationId, int? maxResults, String? nextToken}) → Future< ListSubCheckResultsOutput> - Lists the sub-check results of a specified configuration check operation.
-
listSubCheckRuleResults(
{required String subCheckResultId, int? maxResults, String? nextToken}) → Future< ListSubCheckRuleResultsOutput> - Lists the rules of a specified sub-check belonging to a configuration check operation.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists all tags on an SAP HANA application and/or database registered with AWS Systems Manager for SAP.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putResourcePermission(
{required PermissionActionType actionType, required String resourceArn, required String sourceResourceArn}) → Future< PutResourcePermissionOutput> - Adds permissions to the target database.
-
registerApplication(
{required String applicationId, required ApplicationType applicationType, required List< String> instances, List<ComponentInfo> ? componentsInfo, List<ApplicationCredential> ? credentials, String? databaseArn, String? sapInstanceNumber, String? sid, Map<String, String> ? tags}) → Future<RegisterApplicationOutput> - Register an SAP application with AWS Systems Manager for SAP. You must meet the following requirements before registering.
-
startApplication(
{required String applicationId}) → Future< StartApplicationOutput> - Request is an operation which starts an application.
-
startApplicationRefresh(
{required String applicationId}) → Future< StartApplicationRefreshOutput> - Refreshes a registered application.
-
startConfigurationChecks(
{required String applicationId, List< ConfigurationCheckType> ? configurationCheckIds}) → Future<StartConfigurationChecksOutput> - Initiates configuration check operations against a specified application.
-
stopApplication(
{required String applicationId, bool? includeEc2InstanceShutdown, ConnectedEntityType? stopConnectedEntity}) → Future< StopApplicationOutput> - Request is an operation to stop an application.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Creates tag for a resource by specifying the ARN.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Delete the tags for a resource.
-
updateApplicationSettings(
{required String applicationId, BackintConfig? backint, List< ApplicationCredential> ? credentialsToAddOrUpdate, List<ApplicationCredential> ? credentialsToRemove, String? databaseArn}) → Future<UpdateApplicationSettingsOutput> - Updates the settings of an application registered with AWS Systems Manager for SAP.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited