listApplications method
Lists all the applications registered with AWS Systems Manager for SAP.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter filters :
The filter of name, value, and operator.
Parameter maxResults :
The maximum number of results to return with a single call. To retrieve
the remaining results, make another call with the returned nextToken
value.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListApplicationsOutput> listApplications({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-applications',
exceptionFnMap: _exceptionFns,
);
return ListApplicationsOutput.fromJson(response);
}