listConfigurationCheckDefinitions method

Future<ListConfigurationCheckDefinitionsOutput> listConfigurationCheckDefinitions({
  1. int? maxResults,
  2. String? nextToken,
})

Lists all configuration check types supported by AWS Systems Manager for SAP.

May throw InternalServerException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListConfigurationCheckDefinitionsOutput>
    listConfigurationCheckDefinitions({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-configuration-check-definitions',
    exceptionFnMap: _exceptionFns,
  );
  return ListConfigurationCheckDefinitionsOutput.fromJson(response);
}