listConfigurationCheckOperations method

Future<ListConfigurationCheckOperationsOutput> listConfigurationCheckOperations({
  1. required String applicationId,
  2. List<Filter>? filters,
  3. ConfigurationCheckOperationListingMode? listMode,
  4. int? maxResults,
  5. String? nextToken,
})

Lists the configuration check operations performed by AWS Systems Manager for SAP.

May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application.

Parameter filters : The filters of an operation.

Parameter listMode : The mode for listing configuration check operations. Defaults to "LATEST_PER_CHECK".

  • LATEST_PER_CHECK - Will list the latest configuration check operation per check type.
  • ALL_OPERATIONS - Will list all configuration check operations performed on the application.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListConfigurationCheckOperationsOutput>
    listConfigurationCheckOperations({
  required String applicationId,
  List<Filter>? filters,
  ConfigurationCheckOperationListingMode? listMode,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $payload = <String, dynamic>{
    'ApplicationId': applicationId,
    if (filters != null) 'Filters': filters,
    if (listMode != null) 'ListMode': listMode.value,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-configuration-check-operations',
    exceptionFnMap: _exceptionFns,
  );
  return ListConfigurationCheckOperationsOutput.fromJson(response);
}