listDatabases method
Lists the SAP HANA databases of an application registered with AWS Systems Manager for SAP.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter applicationId :
The ID of the application.
Parameter componentId :
The ID of the component.
Parameter maxResults :
The maximum number of results to return with a single call. To retrieve
the remaining results, make another call with the returned nextToken
value. If you do not specify a value for MaxResults, the request returns
50 items per page by default.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListDatabasesOutput> listDatabases({
String? applicationId,
String? componentId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
if (applicationId != null) 'ApplicationId': applicationId,
if (componentId != null) 'ComponentId': componentId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-databases',
exceptionFnMap: _exceptionFns,
);
return ListDatabasesOutput.fromJson(response);
}