listOperations method

Future<ListOperationsOutput> listOperations({
  1. required String applicationId,
  2. List<Filter>? filters,
  3. int? maxResults,
  4. String? nextToken,
})

Lists the operations performed by AWS Systems Manager for SAP.

May throw InternalServerException. May throw ValidationException.

Parameter applicationId : The ID of the application.

Parameter filters : The filters of an operation.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If you do not specify a value for MaxResults, the request returns 50 items per page by default.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListOperationsOutput> listOperations({
  required String applicationId,
  List<Filter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $payload = <String, dynamic>{
    'ApplicationId': applicationId,
    if (filters != null) 'Filters': filters,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-operations',
    exceptionFnMap: _exceptionFns,
  );
  return ListOperationsOutput.fromJson(response);
}