listSubCheckResults method

Future<ListSubCheckResultsOutput> listSubCheckResults({
  1. required String operationId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the sub-check results of a specified configuration check operation.

May throw InternalServerException. May throw ValidationException.

Parameter operationId : The ID of the configuration check operation.

Parameter maxResults : The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListSubCheckResultsOutput> listSubCheckResults({
  required String operationId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    50,
  );
  final $payload = <String, dynamic>{
    'OperationId': operationId,
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/list-sub-check-results',
    exceptionFnMap: _exceptionFns,
  );
  return ListSubCheckResultsOutput.fromJson(response);
}