stopApplication method

Future<StopApplicationOutput> stopApplication({
  1. required String applicationId,
  2. bool? includeEc2InstanceShutdown,
  3. ConnectedEntityType? stopConnectedEntity,
})

Request is an operation to stop an application.

Parameter ApplicationId is required. Parameters StopConnectedEntity and IncludeEc2InstanceShutdown are optional.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter applicationId : The ID of the application.

Parameter includeEc2InstanceShutdown : Boolean. If included and if set to True, the StopApplication operation will shut down the associated Amazon EC2 instance in addition to the application.

Parameter stopConnectedEntity : Specify the ConnectedEntityType. Accepted type is DBMS.

If this parameter is included, the connected DBMS (Database Management System) will be stopped.

Implementation

Future<StopApplicationOutput> stopApplication({
  required String applicationId,
  bool? includeEc2InstanceShutdown,
  ConnectedEntityType? stopConnectedEntity,
}) async {
  final $payload = <String, dynamic>{
    'ApplicationId': applicationId,
    if (includeEc2InstanceShutdown != null)
      'IncludeEc2InstanceShutdown': includeEc2InstanceShutdown,
    if (stopConnectedEntity != null)
      'StopConnectedEntity': stopConnectedEntity.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/stop-application',
    exceptionFnMap: _exceptionFns,
  );
  return StopApplicationOutput.fromJson(response);
}