ssm_sap_2018_05_10 library

Classes

AwsClientCredentials
AWS credentials.
SsmSap
This API reference provides descriptions, syntax, and other details about each of the actions and data types for AWS Systems Manager for SAP. The topic for each action shows the API request parameters and responses.