sso library

Classes

AwsClientCredentials
AWS credentials.
Sso
AWS IAM Identity Center (successor to AWS Single Sign-On) Portal is a web service that makes it easy for you to assign user access to IAM Identity Center resources such as the AWS access portal. Users can get AWS account applications and roles assigned to them and get federated into the application. This reference guide describes the IAM Identity Center Portal operations that you can call programatically and includes detailed information on data types and errors.