deleteApplicationAccessScope method

Future<void> deleteApplicationAccessScope({
  1. required String applicationArn,
  2. required String scope,
})

Deletes an IAM Identity Center access scope from an application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : Specifies the ARN of the application with the access scope to delete.

Parameter scope : Specifies the name of the access scope to remove from the application.

Implementation

Future<void> deleteApplicationAccessScope({
  required String applicationArn,
  required String scope,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.DeleteApplicationAccessScope'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
      'Scope': scope,
    },
  );
}