deleteApplicationGrant method
Future<void>
deleteApplicationGrant({
- required String applicationArn,
- required GrantType grantType,
Deletes a grant from an application.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationArn :
Specifies the ARN of the application with the grant to delete.
Parameter grantType :
Specifies the type of grant to delete from the application.
Implementation
Future<void> deleteApplicationGrant({
required String applicationArn,
required GrantType grantType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.DeleteApplicationGrant'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationArn': applicationArn,
'GrantType': grantType.value,
},
);
}