deleteTrustedTokenIssuer method

Future<void> deleteTrustedTokenIssuer({
  1. required String trustedTokenIssuerArn,
})

Deletes a trusted token issuer configuration from an instance of IAM Identity Center.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter trustedTokenIssuerArn : Specifies the ARN of the trusted token issuer configuration to delete.

Implementation

Future<void> deleteTrustedTokenIssuer({
  required String trustedTokenIssuerArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.DeleteTrustedTokenIssuer'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TrustedTokenIssuerArn': trustedTokenIssuerArn,
    },
  );
}