describeAccountAssignmentCreationStatus method

Future<DescribeAccountAssignmentCreationStatusResponse> describeAccountAssignmentCreationStatus({
  1. required String accountAssignmentCreationRequestId,
  2. required String instanceArn,
})

Describes the status of the assignment creation request.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accountAssignmentCreationRequestId : The identifier that is used to track the request operation progress.

Parameter instanceArn : The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Implementation

Future<DescribeAccountAssignmentCreationStatusResponse>
    describeAccountAssignmentCreationStatus({
  required String accountAssignmentCreationRequestId,
  required String instanceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'SWBExternalService.DescribeAccountAssignmentCreationStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AccountAssignmentCreationRequestId':
          accountAssignmentCreationRequestId,
      'InstanceArn': instanceArn,
    },
  );

  return DescribeAccountAssignmentCreationStatusResponse.fromJson(
      jsonResponse.body);
}