describeApplication method

Future<DescribeApplicationResponse> describeApplication({
  1. required String applicationArn,
})

Retrieves the details of an application associated with an instance of IAM Identity Center.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : Specifies the ARN of the application. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Implementation

Future<DescribeApplicationResponse> describeApplication({
  required String applicationArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.DescribeApplication'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
    },
  );

  return DescribeApplicationResponse.fromJson(jsonResponse.body);
}