describeApplicationProvider method
Future<DescribeApplicationProviderResponse>
describeApplicationProvider({
- required String applicationProviderArn,
Retrieves details about a provider that can be used to connect an Amazon Web Services managed application or customer managed application to IAM Identity Center.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationProviderArn :
Specifies the ARN of the application provider for which you want details.
Implementation
Future<DescribeApplicationProviderResponse> describeApplicationProvider({
required String applicationProviderArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.DescribeApplicationProvider'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationProviderArn': applicationProviderArn,
},
);
return DescribeApplicationProviderResponse.fromJson(jsonResponse.body);
}