describeInstanceAccessControlAttributeConfiguration method
Future<DescribeInstanceAccessControlAttributeConfigurationResponse>
describeInstanceAccessControlAttributeConfiguration({
- required String instanceArn,
Returns the list of IAM Identity Center identity store attributes that have been configured to work with attributes-based access control (ABAC) for the specified IAM Identity Center instance. This will not return attributes configured and sent by an external identity provider. For more information about ABAC, see Attribute-Based Access Control in the IAM Identity Center User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed.
Implementation
Future<DescribeInstanceAccessControlAttributeConfigurationResponse>
describeInstanceAccessControlAttributeConfiguration({
required String instanceArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'SWBExternalService.DescribeInstanceAccessControlAttributeConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
},
);
return DescribeInstanceAccessControlAttributeConfigurationResponse.fromJson(
jsonResponse.body);
}