describePermissionSetProvisioningStatus method

Future<DescribePermissionSetProvisioningStatusResponse> describePermissionSetProvisioningStatus({
  1. required String instanceArn,
  2. required String provisionPermissionSetRequestId,
})

Describes the status for the given permission set provisioning request.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceArn : The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Parameter provisionPermissionSetRequestId : The identifier that is provided by the ProvisionPermissionSet call to retrieve the current status of the provisioning workflow.

Implementation

Future<DescribePermissionSetProvisioningStatusResponse>
    describePermissionSetProvisioningStatus({
  required String instanceArn,
  required String provisionPermissionSetRequestId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target':
        'SWBExternalService.DescribePermissionSetProvisioningStatus'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InstanceArn': instanceArn,
      'ProvisionPermissionSetRequestId': provisionPermissionSetRequestId,
    },
  );

  return DescribePermissionSetProvisioningStatusResponse.fromJson(
      jsonResponse.body);
}