describeTrustedTokenIssuer method
Future<DescribeTrustedTokenIssuerResponse>
describeTrustedTokenIssuer({
- required String trustedTokenIssuerArn,
Retrieves details about a trusted token issuer configuration stored in an instance of IAM Identity Center. Details include the name of the trusted token issuer, the issuer URL, and the path of the source attribute and the destination attribute for a trusted token issuer configuration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter trustedTokenIssuerArn :
Specifies the ARN of the trusted token issuer configuration that you want
details about.
Implementation
Future<DescribeTrustedTokenIssuerResponse> describeTrustedTokenIssuer({
required String trustedTokenIssuerArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.DescribeTrustedTokenIssuer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TrustedTokenIssuerArn': trustedTokenIssuerArn,
},
);
return DescribeTrustedTokenIssuerResponse.fromJson(jsonResponse.body);
}