detachManagedPolicyFromPermissionSet method
Detaches the attached Amazon Web Services managed policy ARN from the specified permission set.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter managedPolicyArn :
The Amazon Web Services managed policy ARN to be detached from a
permission set.
Parameter permissionSetArn :
The ARN of the PermissionSet from which the policy should be
detached.
Implementation
Future<void> detachManagedPolicyFromPermissionSet({
required String instanceArn,
required String managedPolicyArn,
required String permissionSetArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.DetachManagedPolicyFromPermissionSet'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
'ManagedPolicyArn': managedPolicyArn,
'PermissionSetArn': permissionSetArn,
},
);
}