getApplicationAccessScope method

Future<GetApplicationAccessScopeResponse> getApplicationAccessScope({
  1. required String applicationArn,
  2. required String scope,
})

Retrieves the authorized targets for an IAM Identity Center access scope for an application.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : Specifies the ARN of the application with the access scope that you want to retrieve.

Parameter scope : Specifies the name of the access scope for which you want the authorized targets.

Implementation

Future<GetApplicationAccessScopeResponse> getApplicationAccessScope({
  required String applicationArn,
  required String scope,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.GetApplicationAccessScope'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
      'Scope': scope,
    },
  );

  return GetApplicationAccessScopeResponse.fromJson(jsonResponse.body);
}