getApplicationSessionConfiguration method

Future<GetApplicationSessionConfigurationResponse> getApplicationSessionConfiguration({
  1. required String applicationArn,
})

Retrieves the session configuration for an application in IAM Identity Center.

The session configuration determines how users can access an application. This includes whether user background sessions are enabled. User background sessions allow users to start a job on a supported Amazon Web Services managed application without having to remain signed in to an active session while the job runs.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : The Amazon Resource Name (ARN) of the application for which to retrieve the session configuration.

Implementation

Future<GetApplicationSessionConfigurationResponse>
    getApplicationSessionConfiguration({
  required String applicationArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.GetApplicationSessionConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
    },
  );

  return GetApplicationSessionConfigurationResponse.fromJson(
      jsonResponse.body);
}