getInlinePolicyForPermissionSet method

Future<GetInlinePolicyForPermissionSetResponse> getInlinePolicyForPermissionSet({
  1. required String instanceArn,
  2. required String permissionSetArn,
})

Obtains the inline policy assigned to the permission set.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceArn : The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Parameter permissionSetArn : The ARN of the permission set.

Implementation

Future<GetInlinePolicyForPermissionSetResponse>
    getInlinePolicyForPermissionSet({
  required String instanceArn,
  required String permissionSetArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.GetInlinePolicyForPermissionSet'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InstanceArn': instanceArn,
      'PermissionSetArn': permissionSetArn,
    },
  );

  return GetInlinePolicyForPermissionSetResponse.fromJson(jsonResponse.body);
}