listAccountAssignments method

Future<ListAccountAssignmentsResponse> listAccountAssignments({
  1. required String accountId,
  2. required String instanceArn,
  3. required String permissionSetArn,
  4. int? maxResults,
  5. String? nextToken,
})

Lists the assignee of the specified Amazon Web Services account with the specified permission set.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter accountId : The identifier of the Amazon Web Services account from which to list the assignments.

Parameter instanceArn : The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Parameter permissionSetArn : The ARN of the permission set from which to list assignments.

Parameter maxResults : The maximum number of results to display for the assignment.

Parameter nextToken : The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.

Implementation

Future<ListAccountAssignmentsResponse> listAccountAssignments({
  required String accountId,
  required String instanceArn,
  required String permissionSetArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.ListAccountAssignments'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AccountId': accountId,
      'InstanceArn': instanceArn,
      'PermissionSetArn': permissionSetArn,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListAccountAssignmentsResponse.fromJson(jsonResponse.body);
}