listApplicationAuthenticationMethods method
Lists all of the authentication methods supported by the specified application.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationArn :
Specifies the ARN of the application with the authentication methods you
want to list.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Implementation
Future<ListApplicationAuthenticationMethodsResponse>
listApplicationAuthenticationMethods({
required String applicationArn,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.ListApplicationAuthenticationMethods'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationArn': applicationArn,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListApplicationAuthenticationMethodsResponse.fromJson(
jsonResponse.body);
}