listPermissionSetsProvisionedToAccount method
Lists all the permission sets that are provisioned to a specified Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountId :
The identifier of the Amazon Web Services account from which to list the
assignments.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter maxResults :
The maximum number of results to display for the assignment.
Parameter nextToken :
The pagination token for the list API. Initially the value is null. Use
the output of previous API calls to make subsequent calls.
Parameter provisioningStatus :
The status object for the permission set provisioning operation.
Implementation
Future<ListPermissionSetsProvisionedToAccountResponse>
listPermissionSetsProvisionedToAccount({
required String accountId,
required String instanceArn,
int? maxResults,
String? nextToken,
ProvisioningStatus? provisioningStatus,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'SWBExternalService.ListPermissionSetsProvisionedToAccount'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccountId': accountId,
'InstanceArn': instanceArn,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (provisioningStatus != null)
'ProvisioningStatus': provisioningStatus.value,
},
);
return ListPermissionSetsProvisionedToAccountResponse.fromJson(
jsonResponse.body);
}