listTrustedTokenIssuers method

Future<ListTrustedTokenIssuersResponse> listTrustedTokenIssuers({
  1. required String instanceArn,
  2. int? maxResults,
  3. String? nextToken,
})

Lists all the trusted token issuers configured in an instance of IAM Identity Center.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceArn : Specifies the ARN of the instance of IAM Identity Center with the trusted token issuer configurations that you want to list.

Parameter maxResults : Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next set of results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Parameter nextToken : Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's NextToken response to request the next page of results.

Implementation

Future<ListTrustedTokenIssuersResponse> listTrustedTokenIssuers({
  required String instanceArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.ListTrustedTokenIssuers'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'InstanceArn': instanceArn,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListTrustedTokenIssuersResponse.fromJson(jsonResponse.body);
}