provisionPermissionSet method
The process by which a specified permission set is provisioned to the specified target.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter permissionSetArn :
The ARN of the permission set.
Parameter targetType :
The entity type for which the assignment will be created.
Parameter targetId :
TargetID is an Amazon Web Services account identifier, (For example,
123456789012).
Implementation
Future<ProvisionPermissionSetResponse> provisionPermissionSet({
required String instanceArn,
required String permissionSetArn,
required ProvisionTargetType targetType,
String? targetId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.ProvisionPermissionSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
'PermissionSetArn': permissionSetArn,
'TargetType': targetType.value,
if (targetId != null) 'TargetId': targetId,
},
);
return ProvisionPermissionSetResponse.fromJson(jsonResponse.body);
}