putApplicationAuthenticationMethod method

Future<void> putApplicationAuthenticationMethod({
  1. required String applicationArn,
  2. required AuthenticationMethod authenticationMethod,
  3. required AuthenticationMethodType authenticationMethodType,
})

Adds or updates an authentication method for an application.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : Specifies the ARN of the application with the authentication method to add or update.

Parameter authenticationMethod : Specifies a structure that describes the authentication method to add or update. The structure type you provide is determined by the AuthenticationMethodType parameter.

Parameter authenticationMethodType : Specifies the type of the authentication method that you want to add or update.

Implementation

Future<void> putApplicationAuthenticationMethod({
  required String applicationArn,
  required AuthenticationMethod authenticationMethod,
  required AuthenticationMethodType authenticationMethodType,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.PutApplicationAuthenticationMethod'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
      'AuthenticationMethod': authenticationMethod,
      'AuthenticationMethodType': authenticationMethodType.value,
    },
  );
}