updateApplication method

Future<void> updateApplication({
  1. required String applicationArn,
  2. String? description,
  3. String? name,
  4. UpdateApplicationPortalOptions? portalOptions,
  5. ApplicationStatus? status,
})

Updates application properties.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter applicationArn : Specifies the ARN of the application. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Parameter description : The description of the .

Parameter name : Specifies the updated name for the application.

Parameter portalOptions : A structure that describes the options for the portal associated with an application.

Parameter status : Specifies whether the application is enabled or disabled.

Implementation

Future<void> updateApplication({
  required String applicationArn,
  String? description,
  String? name,
  UpdateApplicationPortalOptions? portalOptions,
  ApplicationStatus? status,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'SWBExternalService.UpdateApplication'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ApplicationArn': applicationArn,
      if (description != null) 'Description': description,
      if (name != null) 'Name': name,
      if (portalOptions != null) 'PortalOptions': portalOptions,
      if (status != null) 'Status': status.value,
    },
  );
}