SsoOidc class
IAM Identity Center OpenID Connect (OIDC) is a web service that enables a client (such as CLI or a native application) to register with IAM Identity Center. The service also enables the client to fetch the user’s access token upon successful authentication and authorization with IAM Identity Center.
API namespaces
IAM Identity Center uses the sso and identitystore
API namespaces. IAM Identity Center OpenID Connect uses the
sso-oauth namespace.
Considerations for using this guide
Before you begin using this guide, we recommend that you first review the following important information about how the IAM Identity Center OIDC service works.
- The IAM Identity Center OIDC service currently implements only the portions of the OAuth 2.0 Device Authorization Grant standard (https://tools.ietf.org/html/rfc8628) that are necessary to enable single sign-on authentication with the CLI.
- With older versions of the CLI, the service only emits OIDC access tokens, so to obtain a new token, users must explicitly re-authenticate. To access the OIDC flow that supports token refresh and doesn’t require re-authentication, update to the latest CLI version (1.27.10 for CLI V1 and 2.9.0 for CLI V2) with support for OIDC token refresh and configurable IAM Identity Center session durations. For more information, see Configure Amazon Web Services access portal session duration .
- The access tokens provided by this service grant access to all Amazon Web Services account entitlements assigned to an IAM Identity Center user, not just a particular application.
- The documentation in this guide does not describe the mechanism to convert the access token into Amazon Web Services Auth (“sigv4”) credentials for use with IAM-protected Amazon Web Services service endpoints. For more information, see GetRoleCredentials in the IAM Identity Center Portal API Reference Guide.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createToken(
{required String clientId, required String clientSecret, required String grantType, String? code, String? codeVerifier, String? deviceCode, String? redirectUri, String? refreshToken, List< String> ? scope}) → Future<CreateTokenResponse> -
Creates and returns access and refresh tokens for clients that are
authenticated using client secrets. The access token can be used to fetch
short-lived credentials for the assigned AWS accounts or to access
application APIs using
bearerauthentication. -
createTokenWithIAM(
{required String clientId, required String grantType, String? assertion, String? code, String? codeVerifier, String? redirectUri, String? refreshToken, String? requestedTokenType, List< String> ? scope, String? subjectToken, String? subjectTokenType}) → Future<CreateTokenWithIAMResponse> -
Creates and returns access and refresh tokens for authorized client
applications that are authenticated using any IAM entity, such as a
service role or user. These tokens might contain defined scopes that
specify permissions such as
read:profileorwrite:data. Through downscoping, you can use the scopes parameter to request tokens with reduced permissions compared to the original client application's permissions or, if applicable, the refresh token's scopes. The access token can be used to fetch short-lived credentials for the assigned Amazon Web Services accounts or to access application APIs usingbearerauthentication. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerClient(
{required String clientName, required String clientType, String? entitledApplicationArn, List< String> ? grantTypes, String? issuerUrl, List<String> ? redirectUris, List<String> ? scopes}) → Future<RegisterClientResponse> - Registers a public client with IAM Identity Center. This allows clients to perform authorization using the authorization code grant with Proof Key for Code Exchange (PKCE) or the device code grant.
-
startDeviceAuthorization(
{required String clientId, required String clientSecret, required String startUrl}) → Future< StartDeviceAuthorizationResponse> - Initiates device authorization by requesting a pair of verification codes from the authorization service.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited