cancelCacheReport method
Cancels generation of a specified cache report. You can use this operation to manually cancel an IN-PROGRESS report for any reason. This action changes the report status from IN-PROGRESS to CANCELLED. You can only cancel in-progress reports. If the the report you attempt to cancel is in FAILED, ERROR, or COMPLETED state, the cancel operation returns an error.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Parameter cacheReportARN :
The Amazon Resource Name (ARN) of the cache report you want to cancel.
Implementation
Future<CancelCacheReportOutput> cancelCacheReport({
required String cacheReportARN,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.CancelCacheReport'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CacheReportARN': cacheReportARN,
},
);
return CancelCacheReportOutput.fromJson(jsonResponse.body);
}