createNFSFileShare method

Future<CreateNFSFileShareOutput> createNFSFileShare({
  1. required String clientToken,
  2. required String gatewayARN,
  3. required String locationARN,
  4. required String role,
  5. String? auditDestinationARN,
  6. String? bucketRegion,
  7. CacheAttributes? cacheAttributes,
  8. List<String>? clientList,
  9. String? defaultStorageClass,
  10. EncryptionType? encryptionType,
  11. String? fileShareName,
  12. bool? guessMIMETypeEnabled,
  13. bool? kMSEncrypted,
  14. String? kMSKey,
  15. NFSFileShareDefaults? nFSFileShareDefaults,
  16. String? notificationPolicy,
  17. ObjectACL? objectACL,
  18. bool? readOnly,
  19. bool? requesterPays,
  20. String? squash,
  21. List<Tag>? tags,
  22. String? vPCEndpointDNSName,
})

Creates a Network File System (NFS) file share on an existing S3 File Gateway. In Storage Gateway, a file share is a file system mount point backed by Amazon S3 cloud storage. Storage Gateway exposes file shares using an NFS interface. This operation is only supported for S3 File Gateways.

S3 File Gateways do not support creating hard or symbolic links on a file share.

May throw InternalServerError. May throw InvalidGatewayRequestException.

Parameter clientToken : A unique string value that you supply that is used by S3 File Gateway to ensure idempotent file share creation.

Parameter gatewayARN : The Amazon Resource Name (ARN) of the S3 File Gateway on which you want to create a file share.

Parameter locationARN : A custom ARN for the backend storage used for storing data for file shares. It includes a resource ARN with an optional prefix concatenation. The prefix must end with a forward slash (/).

Bucket ARN:

arn:aws:s3:::amzn-s3-demo-bucket/prefix/

Access point ARN:

arn:aws:s3:region:account-id:accesspoint/access-point-name/prefix/

If you specify an access point, the bucket policy must be configured to delegate access control to the access point. For information, see Delegating access control to access points in the Amazon S3 User Guide.

Access point alias:

test-ap-ab123cdef4gehijklmn5opqrstuvuse1a-s3alias

Parameter role : The ARN of the Identity and Access Management (IAM) role that an S3 File Gateway assumes when it accesses the underlying storage.

Parameter auditDestinationARN : The Amazon Resource Name (ARN) of the storage used for audit logs.

Parameter bucketRegion : Specifies the Region of the S3 bucket where the NFS file share stores files.

Parameter cacheAttributes : Specifies refresh cache information for the file share.

Parameter clientList : The list of clients that are allowed to access the S3 File Gateway. The list must contain either valid IPv4/IPv6 addresses or valid CIDR blocks.

Parameter defaultStorageClass : The default storage class for objects put into an Amazon S3 bucket by the S3 File Gateway. The default value is S3_STANDARD. Optional.

Valid Values: S3_STANDARD | S3_INTELLIGENT_TIERING | S3_STANDARD_IA | S3_ONEZONE_IA

Parameter encryptionType : A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3.

If values for both parameters exist in the same request, then the specified encryption methods must not conflict. For example, if EncryptionType is SseS3, then KMSEncrypted must be false. If EncryptionType is SseKms or DsseKms, then KMSEncrypted must be true.

Parameter fileShareName : The name of the file share. Optional.

A valid NFS file share name can only contain the following characters: a-z, A-Z, 0-9, -, ., and _.

Parameter guessMIMETypeEnabled : A value that enables guessing of the MIME type for uploaded objects based on file extensions. Set this value to true to enable MIME type guessing, otherwise set to false. The default value is true.

Valid Values: true | false

Parameter kMSEncrypted : Optional. Set to true to use Amazon S3 server-side encryption with your own KMS key (SSE-KMS), or false to use a key managed by Amazon S3 (SSE-S3). To use dual-layer encryption (DSSE-KMS), set the EncryptionType parameter instead.

If values for both parameters exist in the same request, then the specified encryption methods must not conflict. For example, if EncryptionType is SseS3, then KMSEncrypted must be false. If EncryptionType is SseKms or DsseKms, then KMSEncrypted must be true. Valid Values: true | false

Parameter kMSKey : Optional. The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value must be set if KMSEncrypted is true, or if EncryptionType is SseKms or DsseKms.

Parameter nFSFileShareDefaults : File share default values. Optional.

Parameter notificationPolicy : The notification policy of the file share. SettlingTimeInSeconds controls the number of seconds to wait after the last point in time a client wrote to a file before generating an ObjectUploaded notification. Because clients can make many small writes to files, it's best to set this parameter for as long as possible to avoid generating multiple notifications for the same file in a small time period.

This setting is not meant to specify an exact time at which the notification will be sent. In some cases, the gateway might require more than the specified delay time to generate and send notifications. The following example sets NotificationPolicy on with SettlingTimeInSeconds set to 60.

{"Upload": {"SettlingTimeInSeconds": 60}}

The following example sets NotificationPolicy off.

{}

Parameter objectACL : A value that sets the access control list (ACL) permission for objects in the S3 bucket that a S3 File Gateway puts objects into. The default value is private.

Parameter readOnly : A value that sets the write status of a file share. Set this value to true to set the write status to read-only, otherwise set to false.

Valid Values: true | false

Parameter requesterPays : A value that sets who pays the cost of the request and the cost associated with data download from the S3 bucket. If this value is set to true, the requester pays the costs; otherwise, the S3 bucket owner pays. However, the S3 bucket owner always pays the cost of storing data. Valid Values: true | false

Parameter squash : A value that maps a user to anonymous user.

Valid values are the following:

  • RootSquash: Only root is mapped to anonymous user.
  • NoSquash: No one is mapped to anonymous user.
  • AllSquash: Everyone is mapped to anonymous user.

Parameter tags : A list of up to 50 tags that can be assigned to the NFS file share. Each tag is a key-value pair.

Parameter vPCEndpointDNSName : Specifies the DNS name for the VPC endpoint that the NFS file share uses to connect to Amazon S3.

Implementation

Future<CreateNFSFileShareOutput> createNFSFileShare({
  required String clientToken,
  required String gatewayARN,
  required String locationARN,
  required String role,
  String? auditDestinationARN,
  String? bucketRegion,
  CacheAttributes? cacheAttributes,
  List<String>? clientList,
  String? defaultStorageClass,
  EncryptionType? encryptionType,
  String? fileShareName,
  bool? guessMIMETypeEnabled,
  bool? kMSEncrypted,
  String? kMSKey,
  NFSFileShareDefaults? nFSFileShareDefaults,
  String? notificationPolicy,
  ObjectACL? objectACL,
  bool? readOnly,
  bool? requesterPays,
  String? squash,
  List<Tag>? tags,
  String? vPCEndpointDNSName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.CreateNFSFileShare'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ClientToken': clientToken,
      'GatewayARN': gatewayARN,
      'LocationARN': locationARN,
      'Role': role,
      if (auditDestinationARN != null)
        'AuditDestinationARN': auditDestinationARN,
      if (bucketRegion != null) 'BucketRegion': bucketRegion,
      if (cacheAttributes != null) 'CacheAttributes': cacheAttributes,
      if (clientList != null) 'ClientList': clientList,
      if (defaultStorageClass != null)
        'DefaultStorageClass': defaultStorageClass,
      if (encryptionType != null) 'EncryptionType': encryptionType.value,
      if (fileShareName != null) 'FileShareName': fileShareName,
      if (guessMIMETypeEnabled != null)
        'GuessMIMETypeEnabled': guessMIMETypeEnabled,
      if (kMSEncrypted != null) 'KMSEncrypted': kMSEncrypted,
      if (kMSKey != null) 'KMSKey': kMSKey,
      if (nFSFileShareDefaults != null)
        'NFSFileShareDefaults': nFSFileShareDefaults,
      if (notificationPolicy != null)
        'NotificationPolicy': notificationPolicy,
      if (objectACL != null) 'ObjectACL': objectACL.value,
      if (readOnly != null) 'ReadOnly': readOnly,
      if (requesterPays != null) 'RequesterPays': requesterPays,
      if (squash != null) 'Squash': squash,
      if (tags != null) 'Tags': tags,
      if (vPCEndpointDNSName != null)
        'VPCEndpointDNSName': vPCEndpointDNSName,
    },
  );

  return CreateNFSFileShareOutput.fromJson(jsonResponse.body);
}