deleteCacheReport method

Future<DeleteCacheReportOutput> deleteCacheReport({
  1. required String cacheReportARN,
})

Deletes the specified cache report and any associated tags from the Storage Gateway database. You can only delete completed reports. If the status of the report you attempt to delete still IN-PROGRESS, the delete operation returns an error. You can use CancelCacheReport to cancel an IN-PROGRESS report.

May throw InternalServerError. May throw InvalidGatewayRequestException.

Parameter cacheReportARN : The Amazon Resource Name (ARN) of the cache report you want to delete.

Implementation

Future<DeleteCacheReportOutput> deleteCacheReport({
  required String cacheReportARN,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.DeleteCacheReport'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CacheReportARN': cacheReportARN,
    },
  );

  return DeleteCacheReportOutput.fromJson(jsonResponse.body);
}