deleteSnapshotSchedule method
Deletes a snapshot of a volume.
You can take snapshots of your gateway volumes on a scheduled or ad hoc
basis. This API action enables you to delete a snapshot schedule for a
volume. For more information, see Backing
up your volumes. In the DeleteSnapshotSchedule request,
you identify the volume by providing its Amazon Resource Name (ARN). This
operation is only supported for cached volume gateway types.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Parameter volumeARN :
The volume which snapshot schedule to delete.
Implementation
Future<DeleteSnapshotScheduleOutput> deleteSnapshotSchedule({
required String volumeARN,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.DeleteSnapshotSchedule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'VolumeARN': volumeARN,
},
);
return DeleteSnapshotScheduleOutput.fromJson(jsonResponse.body);
}