describeAvailabilityMonitorTest method

Future<DescribeAvailabilityMonitorTestOutput> describeAvailabilityMonitorTest({
  1. required String gatewayARN,
})

Returns information about the most recent high availability monitoring test that was performed on the host in a cluster. If a test isn't performed, the status and start time in the response would be null.

May throw InternalServerError. May throw InvalidGatewayRequestException.

Implementation

Future<DescribeAvailabilityMonitorTestOutput>
    describeAvailabilityMonitorTest({
  required String gatewayARN,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.DescribeAvailabilityMonitorTest'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GatewayARN': gatewayARN,
    },
  );

  return DescribeAvailabilityMonitorTestOutput.fromJson(jsonResponse.body);
}