describeMaintenanceStartTime method
Future<DescribeMaintenanceStartTimeOutput>
describeMaintenanceStartTime({
- required String gatewayARN,
Returns your gateway's maintenance window schedule information, with values for monthly or weekly cadence, specific day and time to begin maintenance, and which types of updates to apply. Time values returned are for the gateway's time zone.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Implementation
Future<DescribeMaintenanceStartTimeOutput> describeMaintenanceStartTime({
required String gatewayARN,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.DescribeMaintenanceStartTime'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GatewayARN': gatewayARN,
},
);
return DescribeMaintenanceStartTimeOutput.fromJson(jsonResponse.body);
}