listCacheReports method

Future<ListCacheReportsOutput> listCacheReports({
  1. String? marker,
})

Returns a list of existing cache reports for all file shares associated with your Amazon Web Services account. This list includes all information provided by the DescribeCacheReport action, such as report name, status, completion progress, start time, end time, filters, and tags.

May throw InternalServerError. May throw InvalidGatewayRequestException.

Parameter marker : Opaque pagination token returned from a previous ListCacheReports operation. If present, Marker specifies where to continue the list from after a previous call to ListCacheReports. Optional.

Implementation

Future<ListCacheReportsOutput> listCacheReports({
  String? marker,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.ListCacheReports'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (marker != null) 'Marker': marker,
    },
  );

  return ListCacheReportsOutput.fromJson(jsonResponse.body);
}