refreshCache method
Refreshes the cached inventory of objects for the specified file share. This operation finds objects in the Amazon S3 bucket that were added, removed, or replaced since the gateway last listed the bucket's contents and cached the results. This operation does not import files into the S3 File Gateway cache storage. It only updates the cached inventory to reflect changes in the inventory of the objects in the S3 bucket. This operation is only supported in the S3 File Gateway types.
You can subscribe to be notified through an Amazon CloudWatch event when
your RefreshCache operation completes. For more information,
see Getting
notified about file operations in the Amazon S3 File Gateway User
Guide. This operation is Only supported for S3 File Gateways.
When this API is called, it only initiates the refresh operation. When the
API call completes and returns a success code, it doesn't necessarily mean
that the file refresh has completed. You should use the refresh-complete
notification to determine that the operation has completed before you
check for new files on the gateway file share. You can subscribe to be
notified through a CloudWatch event when your RefreshCache
operation completes.
Throttle limit: This API is asynchronous, so the gateway will accept no more than two refreshes at any time. We recommend using the refresh-complete CloudWatch event notification before issuing additional requests. For more information, see Getting notified about file operations in the Amazon S3 File Gateway User Guide.
- Wait at least 60 seconds between consecutive RefreshCache API requests.
-
If you invoke the RefreshCache API when two requests are already being
processed, any new request will cause an
InvalidGatewayRequestExceptionerror because too many requests were sent to the server.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Parameter fileShareARN :
The Amazon Resource Name (ARN) of the file share you want to refresh.
Parameter folderList :
A comma-separated list of the paths of folders to refresh in the cache.
The default is ["/"]. The default refreshes objects and
folders at the root of the Amazon S3 bucket. If Recursive is
set to true, the entire S3 bucket that the file share has
access to is refreshed.
Do not include / when specifying folder names. For example,
you would specify samplefolder rather than
samplefolder/.
Parameter recursive :
A value that specifies whether to recursively refresh folders in the
cache. The refresh includes folders that were in the cache the last time
the gateway listed the folder's contents. If this value set to
true, each folder that is listed in FolderList
is recursively updated. Otherwise, subfolders listed in
FolderList are not refreshed. Only objects that are in
folders listed directly under FolderList are found and used
for the update. The default is true.
Valid Values: true | false
Implementation
Future<RefreshCacheOutput> refreshCache({
required String fileShareARN,
List<String>? folderList,
bool? recursive,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.RefreshCache'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileShareARN': fileShareARN,
if (folderList != null) 'FolderList': folderList,
if (recursive != null) 'Recursive': recursive,
},
);
return RefreshCacheOutput.fromJson(jsonResponse.body);
}