setSMBGuestPassword method

Future<SetSMBGuestPasswordOutput> setSMBGuestPassword({
  1. required String gatewayARN,
  2. required String password,
})

Sets the password for the guest user smbguest. The smbguest user is the user when the authentication method for the file share is set to GuestAccess. This operation only supported for S3 File Gateways

May throw InternalServerError. May throw InvalidGatewayRequestException.

Parameter gatewayARN : The Amazon Resource Name (ARN) of the S3 File Gateway the SMB file share is associated with.

Parameter password : The password that you want to set for your SMB server.

Implementation

Future<SetSMBGuestPasswordOutput> setSMBGuestPassword({
  required String gatewayARN,
  required String password,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.SetSMBGuestPassword'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GatewayARN': gatewayARN,
      'Password': password,
    },
  );

  return SetSMBGuestPasswordOutput.fromJson(jsonResponse.body);
}