updateFileSystemAssociation method

Future<UpdateFileSystemAssociationOutput> updateFileSystemAssociation({
  1. required String fileSystemAssociationARN,
  2. String? auditDestinationARN,
  3. CacheAttributes? cacheAttributes,
  4. String? password,
  5. String? userName,
})

Updates a file system association. This operation is only supported in the FSx File Gateways.

May throw InternalServerError. May throw InvalidGatewayRequestException.

Parameter fileSystemAssociationARN : The Amazon Resource Name (ARN) of the file system association that you want to update.

Parameter auditDestinationARN : The Amazon Resource Name (ARN) of the storage used for the audit logs.

Parameter password : The password of the user credential.

Parameter userName : The user name of the user credential that has permission to access the root share D$ of the Amazon FSx file system. The user account must belong to the Amazon FSx delegated admin user group.

Implementation

Future<UpdateFileSystemAssociationOutput> updateFileSystemAssociation({
  required String fileSystemAssociationARN,
  String? auditDestinationARN,
  CacheAttributes? cacheAttributes,
  String? password,
  String? userName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'StorageGateway_20130630.UpdateFileSystemAssociation'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'FileSystemAssociationARN': fileSystemAssociationARN,
      if (auditDestinationARN != null)
        'AuditDestinationARN': auditDestinationARN,
      if (cacheAttributes != null) 'CacheAttributes': cacheAttributes,
      if (password != null) 'Password': password,
      if (userName != null) 'UserName': userName,
    },
  );

  return UpdateFileSystemAssociationOutput.fromJson(jsonResponse.body);
}