updateSMBSecurityStrategy method
- required String gatewayARN,
- required SMBSecurityStrategy sMBSecurityStrategy,
Updates the SMB security strategy level for an Amazon S3 file gateway. This action is only supported for Amazon S3 file gateways.
A higher security strategy level can affect performance of the gateway.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Parameter sMBSecurityStrategy :
Specifies the type of security strategy.
ClientSpecified: If you choose this option, requests are
established based on what is negotiated by the client. This option is
recommended when you want to maximize compatibility across different
clients in your environment. Supported only for S3 File Gateway.
MandatorySigning: If you choose this option, File Gateway
only allows connections from SMBv2 or SMBv3 clients that have signing
enabled. This option works with SMB clients on Microsoft Windows Vista,
Windows Server 2008 or newer.
MandatoryEncryption: If you choose this option, File Gateway
only allows connections from SMBv3 clients that have encryption enabled.
This option is recommended for environments that handle sensitive data.
This option works with SMB clients on Microsoft Windows 8, Windows Server
2012 or newer.
MandatoryEncryptionNoAes128: If you choose this option, File
Gateway only allows connections from SMBv3 clients that use 256-bit AES
encryption algorithms. 128-bit algorithms are not allowed. This option is
recommended for environments that handle sensitive data. It works with SMB
clients on Microsoft Windows 8, Windows Server 2012, or later.
Implementation
Future<UpdateSMBSecurityStrategyOutput> updateSMBSecurityStrategy({
required String gatewayARN,
required SMBSecurityStrategy sMBSecurityStrategy,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.UpdateSMBSecurityStrategy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GatewayARN': gatewayARN,
'SMBSecurityStrategy': sMBSecurityStrategy.value,
},
);
return UpdateSMBSecurityStrategyOutput.fromJson(jsonResponse.body);
}