assumeRoleWithWebIdentity method
Returns a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider. Example providers include the OAuth 2.0 providers Login with Amazon and Facebook, or any OpenID Connect-compatible identity provider such as Google or Amazon Cognito federated identities.
To learn more about Amazon Cognito, see Amazon
Cognito identity pools in Amazon Cognito Developer Guide.
Calling AssumeRoleWithWebIdentity does not require the use of
Amazon Web Services security credentials. Therefore, you can distribute an
application (for example, on mobile devices) that requests temporary
security credentials without including long-term Amazon Web Services
credentials in the application. You also don't need to deploy server-based
proxy services that use long-term Amazon Web Services credentials.
Instead, the identity of the caller is validated by using a token from the
web identity provider. For a comparison of
AssumeRoleWithWebIdentity with the other API operations that
produce temporary credentials, see Requesting
Temporary Security Credentials and Compare
STS credentials in the IAM User Guide.
The temporary security credentials returned by this API consist of an access key ID, a secret access key, and a security token. Applications can use these temporary security credentials to sign calls to Amazon Web Services service API operations.
Session Duration
By default, the temporary security credentials created by
AssumeRoleWithWebIdentity last for one hour. However, you can
use the optional DurationSeconds parameter to specify the
duration of your session. You can provide a value from 900 seconds (15
minutes) up to the maximum session duration setting for the role. This
setting can have a value from 1 hour to 12 hours. To learn how to view the
maximum value for your role, see Update
the maximum session duration for a role in the IAM User Guide.
The maximum session duration limit applies when you use the
AssumeRole* API operations or the assume-role*
CLI commands. However the limit does not apply when you use those
operations to create a console URL. For more information, see Using
IAM Roles in the IAM User Guide.
Permissions
The temporary security credentials created by
AssumeRoleWithWebIdentity can be used to make API calls to
any Amazon Web Services service with the following exception: you cannot
call the STS GetFederationToken or
GetSessionToken API operations.
(Optional) You can pass inline or managed session policies to this operation. You can pass a single JSON policy document to use as an inline session policy. You can also specify up to 10 managed policy Amazon Resource Names (ARNs) to use as managed session policies. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide.
Tags
(Optional) You can configure your IdP to pass attributes into your web identity token as session tags. Each session tag consists of a key name and an associated value. For more information about session tags, see Passing session tags using AssumeRoleWithWebIdentity in the IAM User Guide.
You can pass up to 50 session tags. The plaintext session tag keys can’t exceed 128 characters and the values can’t exceed 256 characters. For these and additional limits, see IAM and STS Character Limits in the IAM User Guide. You can pass a session tag with the same key as a tag that is attached to the role. When you do, the session tag overrides the role tag with the same key.
An administrator must grant you the permissions necessary to pass session tags. The administrator can also create granular permissions to allow you to pass only specific session tags. For more information, see Tutorial: Using Tags for Attribute-Based Access Control in the IAM User Guide.
You can set the session tags as transitive. Transitive tags persist during role chaining. For more information, see Chaining Roles with Session Tags in the IAM User Guide.
Identities
Before your application can call AssumeRoleWithWebIdentity,
you must have an identity token from a supported identity provider and
create a role that the application can assume. The role that your
application assumes must trust the identity provider that is associated
with the identity token. In other words, the identity provider must be
specified in the role's trust policy.
For more information about how to use OIDC federation and the
AssumeRoleWithWebIdentity API, see the following resources:
- Using Web Identity Federation API Operations for Mobile Apps and Federation Through a Web-based Identity Provider.
- Amazon Web Services SDK for iOS Developer Guide and Amazon Web Services SDK for Android Developer Guide. These toolkits contain sample apps that show how to invoke the identity providers. The toolkits then show how to use the information from these providers to get and use temporary security credentials.
May throw ExpiredTokenException.
May throw IDPCommunicationErrorException.
May throw IDPRejectedClaimException.
May throw InvalidIdentityTokenException.
May throw MalformedPolicyDocumentException.
May throw PackedPolicyTooLargeException.
May throw RegionDisabledException.
Parameter roleArn :
The Amazon Resource Name (ARN) of the role that the caller is assuming.
Parameter roleSessionName :
An identifier for the assumed role session. Typically, you pass the name
or identifier that is associated with the user who is using your
application. That way, the temporary security credentials that your
application will use are associated with that user. This session name is
included as part of the ARN and assumed role ID in the
AssumedRoleUser response element.
For security purposes, administrators can view this field in CloudTrail
logs to help identify who performed an action in Amazon Web Services.
Your administrator might require that you specify your user name as the
session name when you assume the role. For more information, see
sts:RoleSessionName .
The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@-
Parameter webIdentityToken :
The OAuth 2.0 access token or OpenID Connect ID token that is provided by
the identity provider. Your application must get this token by
authenticating the user who is using your application with a web identity
provider before the application makes an
AssumeRoleWithWebIdentity call. Timestamps in the token must
be formatted as either an integer or a long integer. Tokens must be signed
using either RSA keys (RS256, RS384, or RS512) or ECDSA keys (ES256,
ES384, or ES512).
Parameter durationSeconds :
The duration, in seconds, of the role session. The value can range from
900 seconds (15 minutes) up to the maximum session duration setting for
the role. This setting can have a value from 1 hour to 12 hours. If you
specify a value higher than this setting, the operation fails. For
example, if you specify a session duration of 12 hours, but your
administrator set the maximum session duration to 6 hours, your operation
fails. To learn how to view the maximum value for your role, see View
the Maximum Session Duration Setting for a Role in the IAM User
Guide.
By default, the value is set to 3600 seconds.
Parameter policy :
An IAM policy in JSON format that you want to use as an inline session
policy.
This parameter is optional. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide.
The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. The JSON policy characters can be any ASCII character from the space character to the end of the valid character list (\u0020 through \u00FF). It can also include the tab (\u0009), linefeed (\u000A), and carriage return (\u000D) characters.
For more information about role session permissions, see Session policies.
Parameter policyArns :
The Amazon Resource Names (ARNs) of the IAM managed policies that you want
to use as managed session policies. The policies must exist in the same
account as the role.
This parameter is optional. You can provide up to 10 managed policy ARNs. However, the plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide.
Parameter providerId :
The fully qualified host component of the domain name of the OAuth 2.0
identity provider. Do not specify this value for an OpenID Connect
identity provider.
Currently www.amazon.com and graph.facebook.com
are the only supported identity providers for OAuth 2.0 access tokens. Do
not include URL schemes and port numbers.
Do not specify this value for OpenID Connect ID tokens.
Implementation
Future<AssumeRoleWithWebIdentityResponse> assumeRoleWithWebIdentity({
required String roleArn,
required String roleSessionName,
required String webIdentityToken,
int? durationSeconds,
String? policy,
List<PolicyDescriptorType>? policyArns,
String? providerId,
}) async {
_s.validateNumRange(
'durationSeconds',
durationSeconds,
900,
43200,
);
final $request = <String, String>{
'RoleArn': roleArn,
'RoleSessionName': roleSessionName,
'WebIdentityToken': webIdentityToken,
if (durationSeconds != null)
'DurationSeconds': durationSeconds.toString(),
if (policy != null) 'Policy': policy,
if (policyArns != null)
if (policyArns.isEmpty)
'PolicyArns': ''
else
for (var i1 = 0; i1 < policyArns.length; i1++)
for (var e3 in policyArns[i1].toQueryMap().entries)
'PolicyArns.member.${i1 + 1}.${e3.key}': e3.value,
if (providerId != null) 'ProviderId': providerId,
};
final $result = await _protocol.send(
$request,
action: 'AssumeRoleWithWebIdentity',
version: '2011-06-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
signed: false,
resultWrapper: 'AssumeRoleWithWebIdentityResult',
);
return AssumeRoleWithWebIdentityResponse.fromXml($result);
}