getSessionToken method
Returns a set of temporary credentials for an Amazon Web Services account
or IAM user. The credentials consist of an access key ID, a secret access
key, and a security token. Typically, you use GetSessionToken
if you want to use MFA to protect programmatic calls to specific Amazon
Web Services API operations like Amazon EC2 StopInstances.
MFA-enabled IAM users must call GetSessionToken and submit an
MFA code that is associated with their MFA device. Using the temporary
security credentials that the call returns, IAM users can then make
programmatic calls to API operations that require MFA authentication. An
incorrect MFA code causes the API to return an access denied error. For a
comparison of GetSessionToken with the other API operations
that produce temporary credentials, see Requesting
Temporary Security Credentials and Compare
STS credentials in the IAM User Guide.
Session Duration
The GetSessionToken operation must be called by using the
long-term Amazon Web Services security credentials of an IAM user.
Credentials that are created by IAM users are valid for the duration that
you specify. This duration can range from 900 seconds (15 minutes) up to a
maximum of 129,600 seconds (36 hours), with a default of 43,200 seconds
(12 hours). Credentials based on account credentials can range from 900
seconds (15 minutes) up to 3,600 seconds (1 hour), with a default of 1
hour.
Permissions
The temporary security credentials created by GetSessionToken
can be used to make API calls to any Amazon Web Services service with the
following exceptions:
- You cannot call any IAM API operations unless MFA authentication information is included in the request.
-
You cannot call any STS API except
AssumeRoleorGetCallerIdentity.
GetSessionToken returns are based on
permissions associated with the IAM user whose credentials were used to
call the operation. The temporary credentials have the same permissions as
the IAM user.
For more information about using GetSessionToken to create
temporary credentials, see Temporary
Credentials for Users in Untrusted Environments in the IAM User
Guide.
May throw RegionDisabledException.
Parameter durationSeconds :
The duration, in seconds, that the credentials should remain valid.
Acceptable durations for IAM user sessions range from 900 seconds (15
minutes) to 129,600 seconds (36 hours), with 43,200 seconds (12 hours) as
the default. Sessions for Amazon Web Services account owners are
restricted to a maximum of 3,600 seconds (one hour). If the duration is
longer than one hour, the session for Amazon Web Services account owners
defaults to one hour.
Parameter serialNumber :
The identification number of the MFA device that is associated with the
IAM user who is making the GetSessionToken call. Specify this
value if the IAM user has a policy that requires MFA authentication. The
value is either the serial number for a hardware device (such as
GAHT12345678) or an Amazon Resource Name (ARN) for a virtual
device (such as arn:aws:iam::123456789012:mfa/user). You can
find the device for an IAM user by going to the Amazon Web Services
Management Console and viewing the user's security credentials.
The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@:/-
Parameter tokenCode :
The value provided by the MFA device, if MFA is required. If any policy
requires the IAM user to submit an MFA code, specify this value. If MFA
authentication is required, the user must provide a code when requesting a
set of temporary security credentials. A user who fails to provide the
code receives an "access denied" response when requesting resources that
require MFA authentication.
The format for this parameter, as described by its regex pattern, is a sequence of six numeric digits.
Implementation
Future<GetSessionTokenResponse> getSessionToken({
int? durationSeconds,
String? serialNumber,
String? tokenCode,
}) async {
_s.validateNumRange(
'durationSeconds',
durationSeconds,
900,
129600,
);
final $request = <String, String>{
if (durationSeconds != null)
'DurationSeconds': durationSeconds.toString(),
if (serialNumber != null) 'SerialNumber': serialNumber,
if (tokenCode != null) 'TokenCode': tokenCode,
};
final $result = await _protocol.send(
$request,
action: 'GetSessionToken',
version: '2011-06-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetSessionTokenResult',
);
return GetSessionTokenResponse.fromXml($result);
}