SupplyChain class
AWS Supply Chain is a cloud-based application that works with your enterprise resource planning (ERP) and supply chain management systems. Using AWS Supply Chain, you can connect and extract your inventory, supply, and demand related data from existing ERP or supply chain systems into a single data model.
The AWS Supply Chain API supports configuration data import for Supply Planning.
All AWS Supply chain API operations are Amazon-authenticated and certificate-signed. They not only require the use of the AWS SDK, but also allow for the exclusive use of AWS Identity and Access Management users and roles to help facilitate access, trust, and permission policies.
Constructors
- SupplyChain({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBillOfMaterialsImportJob(
{required String instanceId, required String s3uri, String? clientToken}) → Future< CreateBillOfMaterialsImportJobResponse> - CreateBillOfMaterialsImportJob creates an import job for the Product Bill Of Materials (BOM) entity. For information on the product_bom entity, see the AWS Supply Chain User Guide.
-
createDataIntegrationFlow(
{required String instanceId, required String name, required List< DataIntegrationFlowSource> sources, required DataIntegrationFlowTarget target, required DataIntegrationFlowTransformation transformation, Map<String, String> ? tags}) → Future<CreateDataIntegrationFlowResponse> - Enables you to programmatically create a data pipeline to ingest data from source systems such as Amazon S3 buckets, to a predefined Amazon Web Services Supply Chain dataset (product, inbound_order) or a temporary dataset along with the data transformation query provided with the API.
-
createDataLakeDataset(
{required String instanceId, required String name, required String namespace, String? description, DataLakeDatasetPartitionSpec? partitionSpec, DataLakeDatasetSchema? schema, Map< String, String> ? tags}) → Future<CreateDataLakeDatasetResponse> - Enables you to programmatically create an Amazon Web Services Supply Chain data lake dataset. Developers can create the datasets using their pre-defined or custom schema for a given instance ID, namespace, and dataset name.
-
createDataLakeNamespace(
{required String instanceId, required String name, String? description, Map< String, String> ? tags}) → Future<CreateDataLakeNamespaceResponse> - Enables you to programmatically create an Amazon Web Services Supply Chain data lake namespace. Developers can create the namespaces for a given instance ID.
-
createInstance(
{String? clientToken, String? instanceDescription, String? instanceName, String? kmsKeyArn, Map< String, String> ? tags, String? webAppDnsDomain}) → Future<CreateInstanceResponse> - Enables you to programmatically create an Amazon Web Services Supply Chain instance by applying KMS keys and relevant information associated with the API without using the Amazon Web Services console.
-
deleteDataIntegrationFlow(
{required String instanceId, required String name}) → Future< DeleteDataIntegrationFlowResponse> - Enable you to programmatically delete an existing data pipeline for the provided Amazon Web Services Supply Chain instance and DataIntegrationFlow name.
-
deleteDataLakeDataset(
{required String instanceId, required String name, required String namespace}) → Future< DeleteDataLakeDatasetResponse> - Enables you to programmatically delete an Amazon Web Services Supply Chain data lake dataset. Developers can delete the existing datasets for a given instance ID, namespace, and instance name.
-
deleteDataLakeNamespace(
{required String instanceId, required String name}) → Future< DeleteDataLakeNamespaceResponse> - Enables you to programmatically delete an Amazon Web Services Supply Chain data lake namespace and its underling datasets. Developers can delete the existing namespaces for a given instance ID and namespace name.
-
deleteInstance(
{required String instanceId}) → Future< DeleteInstanceResponse> - Enables you to programmatically delete an Amazon Web Services Supply Chain instance by deleting the KMS keys and relevant information associated with the API without using the Amazon Web Services console.
-
getBillOfMaterialsImportJob(
{required String instanceId, required String jobId}) → Future< GetBillOfMaterialsImportJobResponse> - Get status and details of a BillOfMaterialsImportJob.
-
getDataIntegrationEvent(
{required String eventId, required String instanceId}) → Future< GetDataIntegrationEventResponse> - Enables you to programmatically view an Amazon Web Services Supply Chain Data Integration Event. Developers can view the eventType, eventGroupId, eventTimestamp, datasetTarget, datasetLoadExecution.
-
getDataIntegrationFlow(
{required String instanceId, required String name}) → Future< GetDataIntegrationFlowResponse> - Enables you to programmatically view a specific data pipeline for the provided Amazon Web Services Supply Chain instance and DataIntegrationFlow name.
-
getDataIntegrationFlowExecution(
{required String executionId, required String flowName, required String instanceId}) → Future< GetDataIntegrationFlowExecutionResponse> - Get the flow execution.
-
getDataLakeDataset(
{required String instanceId, required String name, required String namespace}) → Future< GetDataLakeDatasetResponse> - Enables you to programmatically view an Amazon Web Services Supply Chain data lake dataset. Developers can view the data lake dataset information such as namespace, schema, and so on for a given instance ID, namespace, and dataset name.
-
getDataLakeNamespace(
{required String instanceId, required String name}) → Future< GetDataLakeNamespaceResponse> - Enables you to programmatically view an Amazon Web Services Supply Chain data lake namespace. Developers can view the data lake namespace information such as description for a given instance ID and namespace name.
-
getInstance(
{required String instanceId}) → Future< GetInstanceResponse> - Enables you to programmatically retrieve the information related to an Amazon Web Services Supply Chain instance ID.
-
listDataIntegrationEvents(
{required String instanceId, DataIntegrationEventType? eventType, int? maxResults, String? nextToken}) → Future< ListDataIntegrationEventsResponse> - Enables you to programmatically list all data integration events for the provided Amazon Web Services Supply Chain instance.
-
listDataIntegrationFlowExecutions(
{required String flowName, required String instanceId, int? maxResults, String? nextToken}) → Future< ListDataIntegrationFlowExecutionsResponse> - List flow executions.
-
listDataIntegrationFlows(
{required String instanceId, int? maxResults, String? nextToken}) → Future< ListDataIntegrationFlowsResponse> - Enables you to programmatically list all data pipelines for the provided Amazon Web Services Supply Chain instance.
-
listDataLakeDatasets(
{required String instanceId, required String namespace, int? maxResults, String? nextToken}) → Future< ListDataLakeDatasetsResponse> - Enables you to programmatically view the list of Amazon Web Services Supply Chain data lake datasets. Developers can view the datasets and the corresponding information such as namespace, schema, and so on for a given instance ID and namespace.
-
listDataLakeNamespaces(
{required String instanceId, int? maxResults, String? nextToken}) → Future< ListDataLakeNamespacesResponse> - Enables you to programmatically view the list of Amazon Web Services Supply Chain data lake namespaces. Developers can view the namespaces and the corresponding information such as description for a given instance ID. Note that this API only return custom namespaces, instance pre-defined namespaces are not included.
-
listInstances(
{List< String> ? instanceNameFilter, List<InstanceState> ? instanceStateFilter, int? maxResults, String? nextToken}) → Future<ListInstancesResponse> - List all Amazon Web Services Supply Chain instances for a specific account. Enables you to programmatically list all Amazon Web Services Supply Chain instances based on their account ID, instance name, and state of the instance (active or delete).
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - List all the tags for an Amazon Web ServicesSupply Chain resource. You can list all the tags added to a resource. By listing the tags, developers can view the tag level information on a resource and perform actions such as, deleting a resource associated with a particular tag.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendDataIntegrationEvent(
{required String data, required String eventGroupId, required DataIntegrationEventType eventType, required String instanceId, String? clientToken, DataIntegrationEventDatasetTargetConfiguration? datasetTarget, DateTime? eventTimestamp}) → Future< SendDataIntegrationEventResponse> - Send the data payload for the event with real-time data for analysis or monitoring. The real-time data events are stored in an Amazon Web Services service before being processed and stored in data lake.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - You can create tags during or after creating a resource such as instance, data flow, or dataset in AWS Supply chain. During the data ingestion process, you can add tags such as dev, test, or prod to data flows created during the data ingestion process in the AWS Supply Chain datasets. You can use these tags to identify a group of resources or a single resource used by the developer.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - You can delete tags for an Amazon Web Services Supply chain resource such as instance, data flow, or dataset in AWS Supply Chain. During the data ingestion process, you can delete tags such as dev, test, or prod to data flows created during the data ingestion process in the AWS Supply Chain datasets.
-
updateDataIntegrationFlow(
{required String instanceId, required String name, List< DataIntegrationFlowSource> ? sources, DataIntegrationFlowTarget? target, DataIntegrationFlowTransformation? transformation}) → Future<UpdateDataIntegrationFlowResponse> - Enables you to programmatically update an existing data pipeline to ingest data from the source systems such as, Amazon S3 buckets, to a predefined Amazon Web Services Supply Chain dataset (product, inbound_order) or a temporary dataset along with the data transformation query provided with the API.
-
updateDataLakeDataset(
{required String instanceId, required String name, required String namespace, String? description}) → Future< UpdateDataLakeDatasetResponse> - Enables you to programmatically update an Amazon Web Services Supply Chain data lake dataset. Developers can update the description of a data lake dataset for a given instance ID, namespace, and dataset name.
-
updateDataLakeNamespace(
{required String instanceId, required String name, String? description}) → Future< UpdateDataLakeNamespaceResponse> - Enables you to programmatically update an Amazon Web Services Supply Chain data lake namespace. Developers can update the description of a data lake namespace for a given instance ID and namespace name.
-
updateInstance(
{required String instanceId, String? instanceDescription, String? instanceName}) → Future< UpdateInstanceResponse> - Enables you to programmatically update an Amazon Web Services Supply Chain instance description by providing all the relevant information such as account ID, instance ID and so on without using the AWS console.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited