deleteDataIntegrationFlow method

Future<DeleteDataIntegrationFlowResponse> deleteDataIntegrationFlow({
  1. required String instanceId,
  2. required String name,
})

Enable you to programmatically delete an existing data pipeline for the provided Amazon Web Services Supply Chain instance and DataIntegrationFlow name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter instanceId : The Amazon Web Services Supply Chain instance identifier.

Parameter name : The name of the DataIntegrationFlow to be deleted.

Implementation

Future<DeleteDataIntegrationFlowResponse> deleteDataIntegrationFlow({
  required String instanceId,
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/api/data-integration/instance/${Uri.encodeComponent(instanceId)}/data-integration-flows/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDataIntegrationFlowResponse.fromJson(response);
}