getDataIntegrationFlow method

Future<GetDataIntegrationFlowResponse> getDataIntegrationFlow({
  1. required String instanceId,
  2. required String name,
})

Enables you to programmatically view a specific data pipeline for the provided Amazon Web Services Supply Chain instance and DataIntegrationFlow name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceId : The Amazon Web Services Supply Chain instance identifier.

Parameter name : The name of the DataIntegrationFlow created.

Implementation

Future<GetDataIntegrationFlowResponse> getDataIntegrationFlow({
  required String instanceId,
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/api/data-integration/instance/${Uri.encodeComponent(instanceId)}/data-integration-flows/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDataIntegrationFlowResponse.fromJson(response);
}