getDataLakeDataset method

Future<GetDataLakeDatasetResponse> getDataLakeDataset({
  1. required String instanceId,
  2. required String name,
  3. required String namespace,
})

Enables you to programmatically view an Amazon Web Services Supply Chain data lake dataset. Developers can view the data lake dataset information such as namespace, schema, and so on for a given instance ID, namespace, and dataset name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceId : The Amazon Web Services Supply Chain instance identifier.

Parameter name : The name of the dataset. For asc namespace, the name must be one of the supported data entities under https://docs.aws.amazon.com/aws-supply-chain/latest/userguide/data-model-asc.html.

Parameter namespace : The namespace of the dataset, besides the custom defined namespace, every instance comes with below pre-defined namespaces:

Implementation

Future<GetDataLakeDatasetResponse> getDataLakeDataset({
  required String instanceId,
  required String name,
  required String namespace,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/api/datalake/instance/${Uri.encodeComponent(instanceId)}/namespaces/${Uri.encodeComponent(namespace)}/datasets/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetDataLakeDatasetResponse.fromJson(response);
}