listDataIntegrationEvents method
Enables you to programmatically list all data integration events for the provided Amazon Web Services Supply Chain instance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceId :
The Amazon Web Services Supply Chain instance identifier.
Parameter eventType :
List data integration events for the specified eventType.
Parameter maxResults :
Specify the maximum number of data integration events to fetch in one
paginated request.
Parameter nextToken :
The pagination token to fetch the next page of the data integration
events.
Implementation
Future<ListDataIntegrationEventsResponse> listDataIntegrationEvents({
required String instanceId,
DataIntegrationEventType? eventType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final $query = <String, List<String>>{
if (eventType != null) 'eventType': [eventType.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/api-data/data-integration/instance/${Uri.encodeComponent(instanceId)}/data-integration-events',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataIntegrationEventsResponse.fromJson(response);
}