updateDataLakeDataset method

Future<UpdateDataLakeDatasetResponse> updateDataLakeDataset({
  1. required String instanceId,
  2. required String name,
  3. required String namespace,
  4. String? description,
})

Enables you to programmatically update an Amazon Web Services Supply Chain data lake dataset. Developers can update the description of a data lake dataset for a given instance ID, namespace, and dataset name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceId : The Amazon Web Services Chain instance identifier.

Parameter name : The name of the dataset. For asc namespace, the name must be one of the supported data entities under https://docs.aws.amazon.com/aws-supply-chain/latest/userguide/data-model-asc.html.

Parameter namespace : The namespace of the dataset, besides the custom defined namespace, every instance comes with below pre-defined namespaces:

Parameter description : The updated description of the data lake dataset.

Implementation

Future<UpdateDataLakeDatasetResponse> updateDataLakeDataset({
  required String instanceId,
  required String name,
  required String namespace,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/api/datalake/instance/${Uri.encodeComponent(instanceId)}/namespaces/${Uri.encodeComponent(namespace)}/datasets/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateDataLakeDatasetResponse.fromJson(response);
}