updateDataLakeNamespace method

Future<UpdateDataLakeNamespaceResponse> updateDataLakeNamespace({
  1. required String instanceId,
  2. required String name,
  3. String? description,
})

Enables you to programmatically update an Amazon Web Services Supply Chain data lake namespace. Developers can update the description of a data lake namespace for a given instance ID and namespace name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter instanceId : The Amazon Web Services Chain instance identifier.

Parameter name : The name of the namespace. Noted you cannot update namespace with name starting with asc, default, scn, aws, amazon, amzn

Parameter description : The updated description of the data lake namespace.

Implementation

Future<UpdateDataLakeNamespaceResponse> updateDataLakeNamespace({
  required String instanceId,
  required String name,
  String? description,
}) async {
  final $payload = <String, dynamic>{
    if (description != null) 'description': description,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/api/datalake/instance/${Uri.encodeComponent(instanceId)}/namespaces/${Uri.encodeComponent(name)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateDataLakeNamespaceResponse.fromJson(response);
}