supply_chain_2024_01_01 library

Classes

AwsClientCredentials
AWS credentials.
SupplyChain
AWS Supply Chain is a cloud-based application that works with your enterprise resource planning (ERP) and supply chain management systems. Using AWS Supply Chain, you can connect and extract your inventory, supply, and demand related data from existing ERP or supply chain systems into a single data model.