describeCreateCaseOptions method

Future<DescribeCreateCaseOptionsResponse> describeCreateCaseOptions({
  1. required String categoryCode,
  2. required String issueType,
  3. required String language,
  4. required String serviceCode,
})

Returns a list of CreateCaseOption types along with the corresponding supported hours and language availability. You can specify the language categoryCode, issueType and serviceCode used to retrieve the CreateCaseOptions.

  • You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
  • If you call the Amazon Web Services Support API from an account that doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see Amazon Web Services Support.

May throw InternalServerError. May throw ThrottlingException.

Parameter categoryCode : The category of problem for the support case. You also use the DescribeServices operation to get the category code for a service. Each Amazon Web Services service defines its own set of category codes.

Parameter issueType : The type of issue for the case. You can specify customer-service or technical. If you don't specify a value, the default is technical.

Parameter language : The language in which Amazon Web Services Support handles the case. Amazon Web Services Support currently supports Chinese (“zh”), English ("en"), Japanese ("ja") and Korean (“ko”). You must specify the ISO 639-1 code for the language parameter if you want support in that language.

Parameter serviceCode : The code for the Amazon Web Services service. You can use the DescribeServices operation to get the possible serviceCode values.

Implementation

Future<DescribeCreateCaseOptionsResponse> describeCreateCaseOptions({
  required String categoryCode,
  required String issueType,
  required String language,
  required String serviceCode,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSSupport_20130415.DescribeCreateCaseOptions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'categoryCode': categoryCode,
      'issueType': issueType,
      'language': language,
      'serviceCode': serviceCode,
    },
  );

  return DescribeCreateCaseOptionsResponse.fromJson(jsonResponse.body);
}