describeSeverityLevels method
Returns the list of severity levels that you can assign to a support case. The severity level for a case is also a field in the CaseDetails data type that you include for a CreateCase request.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
May throw InternalServerError.
Parameter language :
The language in which Amazon Web Services Support handles the case. Amazon
Web Services Support currently supports Chinese (“zh”), English ("en"),
Japanese ("ja") and Korean (“ko”). You must specify the ISO 639-1 code for
the language parameter if you want support in that language.
Implementation
Future<DescribeSeverityLevelsResponse> describeSeverityLevels({
String? language,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.DescribeSeverityLevels'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (language != null) 'language': language,
},
);
return DescribeSeverityLevelsResponse.fromJson(jsonResponse.body);
}