describeSupportedLanguages method

Future<DescribeSupportedLanguagesResponse> describeSupportedLanguages({
  1. required String categoryCode,
  2. required String issueType,
  3. required String serviceCode,
})

Returns a list of supported languages for a specified categoryCode, issueType and serviceCode. The returned supported languages will include a ISO 639-1 code for the language, and the language display name.

  • You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
  • If you call the Amazon Web Services Support API from an account that doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see Amazon Web Services Support.

May throw InternalServerError. May throw ThrottlingException.

Parameter categoryCode : The category of problem for the support case. You also use the DescribeServices operation to get the category code for a service. Each Amazon Web Services service defines its own set of category codes.

Parameter issueType : The type of issue for the case. You can specify customer-service or technical.

Parameter serviceCode : The code for the Amazon Web Services service. You can use the DescribeServices operation to get the possible serviceCode values.

Implementation

Future<DescribeSupportedLanguagesResponse> describeSupportedLanguages({
  required String categoryCode,
  required String issueType,
  required String serviceCode,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSSupport_20130415.DescribeSupportedLanguages'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'categoryCode': categoryCode,
      'issueType': issueType,
      'serviceCode': serviceCode,
    },
  );

  return DescribeSupportedLanguagesResponse.fromJson(jsonResponse.body);
}