describeTrustedAdvisorCheckRefreshStatuses method
Future<DescribeTrustedAdvisorCheckRefreshStatusesResponse>
describeTrustedAdvisorCheckRefreshStatuses({})
Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
Some checks are refreshed automatically, and you can't return their
refresh statuses by using the
DescribeTrustedAdvisorCheckRefreshStatuses operation. If you
call this operation for these checks, you might see an
InvalidParameterValue error.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
May throw InternalServerError.
May throw ThrottlingException.
Parameter checkIds :
The IDs of the Trusted Advisor checks to get the status.
Implementation
Future<DescribeTrustedAdvisorCheckRefreshStatusesResponse>
describeTrustedAdvisorCheckRefreshStatuses({
required List<String> checkIds,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSSupport_20130415.DescribeTrustedAdvisorCheckRefreshStatuses'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'checkIds': checkIds,
},
);
return DescribeTrustedAdvisorCheckRefreshStatusesResponse.fromJson(
jsonResponse.body);
}