describeTrustedAdvisorCheckSummaries method
Returns the results for the Trusted Advisor check summaries for the check IDs that you specified. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
The response contains an array of TrustedAdvisorCheckSummary objects.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
May throw InternalServerError.
May throw ThrottlingException.
Parameter checkIds :
The IDs of the Trusted Advisor checks.
Implementation
Future<DescribeTrustedAdvisorCheckSummariesResponse>
describeTrustedAdvisorCheckSummaries({
required List<String> checkIds,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.DescribeTrustedAdvisorCheckSummaries'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'checkIds': checkIds,
},
);
return DescribeTrustedAdvisorCheckSummariesResponse.fromJson(
jsonResponse.body);
}