describeTrustedAdvisorChecks method
Future<DescribeTrustedAdvisorChecksResponse>
describeTrustedAdvisorChecks({
- required String language,
Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata. You must specify a language code.
The response contains a TrustedAdvisorCheckDescription object for each check. You must set the Amazon Web Services Region to us-east-1.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support. - The names and descriptions for Trusted Advisor checks are subject to change. We recommend that you specify the check ID in your code to uniquely identify a check.
May throw InternalServerError.
May throw ThrottlingException.
Parameter language :
The ISO 639-1 code for the language that you want your checks to appear
in.
The Amazon Web Services Support API currently supports the following languages for Trusted Advisor:
-
Chinese, Simplified -
zh -
Chinese, Traditional -
zh_TW -
English -
en -
French -
fr -
German -
de -
Indonesian -
id -
Italian -
it -
Japanese -
ja -
Korean -
ko -
Portuguese, Brazilian -
pt_BR -
Spanish -
es
Implementation
Future<DescribeTrustedAdvisorChecksResponse> describeTrustedAdvisorChecks({
required String language,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.DescribeTrustedAdvisorChecks'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'language': language,
},
);
return DescribeTrustedAdvisorChecksResponse.fromJson(jsonResponse.body);
}