refreshTrustedAdvisorCheck method
Refreshes the Trusted Advisor check that you specify using the check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
Some checks are refreshed automatically. If you call the
RefreshTrustedAdvisorCheck operation to refresh them, you
might see the InvalidParameterValue error.
The response contains a TrustedAdvisorCheckRefreshStatus object.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
May throw InternalServerError.
Parameter checkId :
The unique identifier for the Trusted Advisor check to refresh.
Implementation
Future<RefreshTrustedAdvisorCheckResponse> refreshTrustedAdvisorCheck({
required String checkId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.RefreshTrustedAdvisorCheck'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'checkId': checkId,
},
);
return RefreshTrustedAdvisorCheckResponse.fromJson(jsonResponse.body);
}