resolveCase method

Future<ResolveCaseResponse> resolveCase({
  1. String? caseId,
})

Resolves a support case. This operation takes a caseId and returns the initial and final state of the case.

  • You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
  • If you call the Amazon Web Services Support API from an account that doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see Amazon Web Services Support.

May throw CaseIdNotFound. May throw InternalServerError.

Parameter caseId : The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

Implementation

Future<ResolveCaseResponse> resolveCase({
  String? caseId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSSupport_20130415.ResolveCase'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (caseId != null) 'caseId': caseId,
    },
  );

  return ResolveCaseResponse.fromJson(jsonResponse.body);
}