deleteAccountAlias method

Future<void> deleteAccountAlias()

Deletes an alias for an Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException.

Implementation

Future<void> deleteAccountAlias() async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/control/delete-account-alias',
    exceptionFnMap: _exceptionFns,
  );
}