deleteSlackWorkspaceConfiguration method

Future<void> deleteSlackWorkspaceConfiguration({
  1. required String teamId,
})

Deletes a Slack workspace configuration from your Amazon Web Services account. This operation doesn't delete your Slack workspace.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter teamId : The team ID in Slack. This ID uniquely identifies a Slack workspace, such as T012ABCDEFG.

Implementation

Future<void> deleteSlackWorkspaceConfiguration({
  required String teamId,
}) async {
  final $payload = <String, dynamic>{
    'teamId': teamId,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/control/delete-slack-workspace-configuration',
    exceptionFnMap: _exceptionFns,
  );
}