listSlackWorkspaceConfigurations method

Future<ListSlackWorkspaceConfigurationsResult> listSlackWorkspaceConfigurations({
  1. String? nextToken,
})

Lists the Slack workspace configurations for an Amazon Web Services account.

May throw AccessDeniedException. May throw InternalServerException.

Parameter nextToken : If the results of a search are large, the API only returns a portion of the results and includes a nextToken pagination token in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When the API returns the last set of results, the response doesn't include a pagination token value.

Implementation

Future<ListSlackWorkspaceConfigurationsResult>
    listSlackWorkspaceConfigurations({
  String? nextToken,
}) async {
  final $payload = <String, dynamic>{
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/control/list-slack-workspace-configurations',
    exceptionFnMap: _exceptionFns,
  );
  return ListSlackWorkspaceConfigurationsResult.fromJson(response);
}