putAccountAlias method

Future<void> putAccountAlias({
  1. required String accountAlias,
})

Creates or updates an individual alias for each Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.

May throw AccessDeniedException. May throw InternalServerException. May throw ValidationException.

Parameter accountAlias : An alias or short name for an Amazon Web Services account.

Implementation

Future<void> putAccountAlias({
  required String accountAlias,
}) async {
  final $payload = <String, dynamic>{
    'accountAlias': accountAlias,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/control/put-account-alias',
    exceptionFnMap: _exceptionFns,
  );
}