registerSlackWorkspaceForOrganization method
Future<RegisterSlackWorkspaceForOrganizationResult>
registerSlackWorkspaceForOrganization({
- required String teamId,
Registers a Slack workspace for your Amazon Web Services account. To call this API, your account must be part of an organization in Organizations.
If you're the management account and you want to register Slack workspaces for your organization, you must complete the following tasks:
- Sign in to the Amazon Web Services Support Center and authorize the Slack workspaces where you want your organization to have access to. See Authorize a Slack workspace in the Amazon Web Services Support User Guide.
-
Call the
RegisterSlackWorkspaceForOrganizationAPI to authorize each Slack workspace for the organization.
To use the Amazon Web Services Support App, each account must then complete the following tasks:
- Create an Identity and Access Management (IAM) role with the required permission. For more information, see Managing access to the Amazon Web Services Support App.
- Configure a Slack channel to use the Amazon Web Services Support App for support cases for that account. For more information, see Configuring a Slack channel.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter teamId :
The team ID in Slack. This ID uniquely identifies a Slack workspace, such
as T012ABCDEFG. Specify the Slack workspace that you want to
use for your organization.
Implementation
Future<RegisterSlackWorkspaceForOrganizationResult>
registerSlackWorkspaceForOrganization({
required String teamId,
}) async {
final $payload = <String, dynamic>{
'teamId': teamId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/control/register-slack-workspace-for-organization',
exceptionFnMap: _exceptionFns,
);
return RegisterSlackWorkspaceForOrganizationResult.fromJson(response);
}