SupportAuthz class

AWS SupportAuthZ enables you to control and authorize the actions that AWS support operators can perform on your resources. You create cryptographically signed support permits specifying which actions operators can perform, on which resources, and under what time-window conditions. Permits are signed using a customer-managed AWS KMS key (ECC_NIST_P384, SIGN_VERIFY) to ensure non-repudiation.

Constructors

SupportAuthz({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createSupportPermit({required String name, required Permit permit, required SigningKeyInfo signingKeyInfo, String? clientToken, String? description, String? supportCaseDisplayId, Map<String, String>? tags}) Future<CreateSupportPermitOutput>
Creates a support permit that authorizes an AWS support operator to perform specified actions on specified resources. The permit is cryptographically signed using a customer-managed AWS KMS key (ECC_NIST_P384, SIGN_VERIFY) to ensure non-repudiation.
deleteSupportPermit({required String supportPermitIdentifier}) Future<DeleteSupportPermitOutput>
Deletes a support permit, revoking the authorization previously granted to the AWS support operator.
getAction({required String action}) Future<GetActionOutput>
Retrieves the description of a specific support action.
getSupportPermit({required String supportPermitIdentifier}) Future<GetSupportPermitOutput>
Retrieves the details of a support permit by its ARN or name.
listActions({required String service, int? maxResults, String? nextToken}) Future<ListActionsOutput>
Lists available support actions for a specified AWS service. Use pagination to ensure that the operation returns quickly and successfully.
listSupportPermitRequests({int? maxResults, String? nextToken, String? supportCaseDisplayId}) Future<ListSupportPermitRequestsOutput>
Lists permit requests from AWS support operators. Use pagination to ensure that the operation returns quickly and successfully.
listSupportPermits({int? maxResults, String? nextToken, List<SupportPermitStatus>? supportPermitStatuses}) Future<ListSupportPermitsOutput>
Lists all support permits in the caller's account. Use pagination to ensure that the operation returns quickly and successfully.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceOutput>
Lists the tags associated with a support permit resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectSupportPermitRequest({required String requestArn}) Future<RejectSupportPermitRequestOutput>
Rejects a permit request from an AWS support operator. The operator cannot proceed with the requested action.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds or overwrites one or more tags for a support permit resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from a support permit resource.

Operators

operator ==(Object other) bool
The equality operator.
inherited