getSupportPermit method

Future<GetSupportPermitOutput> getSupportPermit({
  1. required String supportPermitIdentifier,
})

Retrieves the details of a support permit by its ARN or name.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter supportPermitIdentifier : The ARN or name of the support permit to retrieve.

Implementation

Future<GetSupportPermitOutput> getSupportPermit({
  required String supportPermitIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/support-permits/${Uri.encodeComponent(supportPermitIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSupportPermitOutput.fromJson(response);
}