listSupportPermitRequests method

Future<ListSupportPermitRequestsOutput> listSupportPermitRequests({
  1. int? maxResults,
  2. String? nextToken,
  3. String? supportCaseDisplayId,
})

Lists permit requests from AWS support operators. Use pagination to ensure that the operation returns quickly and successfully.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to return in a single call. Valid range is 1 to 100.

Parameter nextToken : The token for the next page of results.

Parameter supportCaseDisplayId : Filters the results by support case display identifier.

Implementation

Future<ListSupportPermitRequestsOutput> listSupportPermitRequests({
  int? maxResults,
  String? nextToken,
  String? supportCaseDisplayId,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (supportCaseDisplayId != null)
      'supportCaseDisplayId': [supportCaseDisplayId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/support-permit-requests',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSupportPermitRequestsOutput.fromJson(response);
}