Sustainability class
The AWS Sustainability service provides programmatic access to estimated carbon emissions data for your Amazon Web Services usage. Use the AWS Sustainability service to retrieve, analyze, and track the carbon footprint of your cloud infrastructure over time.
With the AWS Sustainability service, you can:
- Retrieve estimated carbon emissions for your Amazon Web Services usage across different time periods
- Group emissions data by dimensions such as account, region, and service
- Filter emissions data to focus on specific accounts, regions, or services
- Access multiple emissions calculation methodologies including Location-based Method (LBM) and Market-based Method (MBM)
- Aggregate emissions data at various time granularities including monthly, quarterly, and yearly periods
All emissions values are calculated using methodologies aligned with the Greenhouse Gas (GHG) Protocol and are provided in metric tons of carbon dioxide-equivalent (MTCO2e).
Constructors
- Sustainability({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getEstimatedCarbonEmissions(
{required TimePeriod timePeriod, List< EmissionsType> ? emissionsTypes, FilterExpression? filterBy, TimeGranularity? granularity, GranularityConfiguration? granularityConfiguration, List<Dimension> ? groupBy, int? maxResults, String? nextToken}) → Future<GetEstimatedCarbonEmissionsResponse> - Returns estimated carbon emission values based on customer grouping and filtering parameters. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
getEstimatedCarbonEmissionsDimensionValues(
{required List< Dimension> dimensions, required TimePeriod timePeriod, int? maxResults, String? nextToken}) → Future<GetEstimatedCarbonEmissionsDimensionValuesResponse> - Returns the possible dimension values available for a customer's account. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited