deleteWorkflowType method
Deletes the specified workflow type.
Note: Prior to deletion, workflow types must first be deprecated.
After a workflow type has been deleted, you cannot create new executions of that type. Executions that started before the type was deleted will continue to run.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys.-
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
-
cause parameter is
set to OPERATION_NOT_PERMITTED. For details and example IAM
policies, see Using
IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF
Developer Guide.
May throw OperationNotPermittedFault.
May throw TypeNotDeprecatedFault.
May throw UnknownResourceFault.
Parameter domain :
The name of the domain in which the workflow type is registered.
Parameter workflowType :
The workflow type to delete.
Implementation
Future<void> deleteWorkflowType({
required String domain,
required WorkflowType workflowType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'SimpleWorkflowService.DeleteWorkflowType'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'domain': domain,
'workflowType': workflowType,
},
);
}