deprecateWorkflowType method
Deprecates the specified workflow type. After a workflow type has been deprecated, you cannot create new executions of that type. Executions that were started before the type was deprecated continues to run. A deprecated workflow type may still be used when calling visibility actions. Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys.-
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
-
cause parameter is
set to OPERATION_NOT_PERMITTED. For details and example IAM
policies, see Using
IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF
Developer Guide.
May throw OperationNotPermittedFault.
May throw TypeDeprecatedFault.
May throw UnknownResourceFault.
Parameter domain :
The name of the domain in which the workflow type is registered.
Parameter workflowType :
The workflow type to deprecate.
Implementation
Future<void> deprecateWorkflowType({
required String domain,
required WorkflowType workflowType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'SimpleWorkflowService.DeprecateWorkflowType'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'domain': domain,
'workflowType': workflowType,
},
);
}