respondDecisionTaskCompleted method

Future<void> respondDecisionTaskCompleted({
  1. required String taskToken,
  2. List<Decision>? decisions,
  3. String? executionContext,
  4. TaskList? taskList,
  5. String? taskListScheduleToStartTimeout,
})

Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task.

A DecisionTaskCompleted event is added to the workflow history. The executionContext specified is attached to the event in the workflow execution history.

Access Control

If an IAM policy grants permission to use RespondDecisionTaskCompleted, it can express permissions for the list of decisions in the decisions parameter. Each of the decisions has one or more parameters, much like a regular API call. To allow for policies to be as readable as possible, you can express permissions on decisions as if they were actual API calls, including applying conditions to some parameters. For more information, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

May throw OperationNotPermittedFault. May throw UnknownResourceFault.

Parameter taskToken : The taskToken from the DecisionTask.

Parameter decisions : The list of decisions (possibly empty) made by the decider while processing this decision task. See the docs for the Decision structure for details.

Parameter executionContext : User defined context to add to workflow execution.

Parameter taskList : The task list to use for the future decision tasks of this workflow execution. This list overrides the original task list you specified while starting the workflow execution.

Parameter taskListScheduleToStartTimeout : Specifies a timeout (in seconds) for the task list override. When this parameter is missing, the task list override is permanent. This parameter makes it possible to temporarily override the task list. If a decision task scheduled on the override task list is not started within the timeout, the decision task will time out. Amazon SWF will revert the override and schedule a new decision task to the original task list.

If a decision task scheduled on the override task list is started within the timeout, but not completed within the start-to-close timeout, Amazon SWF will also revert the override and schedule a new decision task to the original task list.

Implementation

Future<void> respondDecisionTaskCompleted({
  required String taskToken,
  List<Decision>? decisions,
  String? executionContext,
  TaskList? taskList,
  String? taskListScheduleToStartTimeout,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'SimpleWorkflowService.RespondDecisionTaskCompleted'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'taskToken': taskToken,
      if (decisions != null) 'decisions': decisions,
      if (executionContext != null) 'executionContext': executionContext,
      if (taskList != null) 'taskList': taskList,
      if (taskListScheduleToStartTimeout != null)
        'taskListScheduleToStartTimeout': taskListScheduleToStartTimeout,
    },
  );
}