associateResource method

Future<void> associateResource({
  1. required String groupIdentifier,
  2. required String resourceArn,
})

Associates a canary with a group. Using groups can help you with managing and automating your canaries, and you can also view aggregated run results and statistics for all canaries in a group.

You must run this operation in the Region where the canary exists.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ValidationException.

Parameter groupIdentifier : Specifies the group. You can specify the group name, the ARN, or the group ID as the GroupIdentifier.

Parameter resourceArn : The ARN of the canary that you want to associate with the specified group.

Implementation

Future<void> associateResource({
  required String groupIdentifier,
  required String resourceArn,
}) async {
  final $payload = <String, dynamic>{
    'ResourceArn': resourceArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/group/${Uri.encodeComponent(groupIdentifier)}/associate',
    exceptionFnMap: _exceptionFns,
  );
}