createCanary method

Future<CreateCanaryResponse> createCanary({
  1. required String artifactS3Location,
  2. required CanaryCodeInput code,
  3. required String executionRoleArn,
  4. required String name,
  5. required String runtimeVersion,
  6. required CanaryScheduleInput schedule,
  7. ArtifactConfigInput? artifactConfig,
  8. List<BrowserConfig>? browserConfigs,
  9. int? failureRetentionPeriodInDays,
  10. ProvisionedResourceCleanupSetting? provisionedResourceCleanup,
  11. List<ResourceToTag>? resourcesToReplicateTags,
  12. CanaryRunConfigInput? runConfig,
  13. int? successRetentionPeriodInDays,
  14. Map<String, String>? tags,
  15. VpcConfigInput? vpcConfig,
})

Creates a canary. Canaries are scripts that monitor your endpoints and APIs from the outside-in. Canaries help you check the availability and latency of your web services and troubleshoot anomalies by investigating load time data, screenshots of the UI, logs, and metrics. You can set up a canary to run continuously or just once.

Do not use CreateCanary to modify an existing canary. Use UpdateCanary instead.

To create canaries, you must have the CloudWatchSyntheticsFullAccess policy. If you are creating a new IAM role for the canary, you also need the iam:CreateRole, iam:CreatePolicy and iam:AttachRolePolicy permissions. For more information, see Necessary Roles and Permissions.

Do not include secrets or proprietary information in your canary names. The canary name makes up part of the Amazon Resource Name (ARN) for the canary, and the ARN is included in outbound calls over the internet. For more information, see Security Considerations for Synthetics Canaries.

May throw InternalServerException. May throw RequestEntityTooLargeException. May throw ValidationException.

Parameter artifactS3Location : The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary. Artifacts include the log file, screenshots, and HAR files. The name of the Amazon S3 bucket can't include a period (.).

Parameter code : A structure that includes the entry point from which the canary should start running your script. If the script is stored in an Amazon S3 bucket, the bucket name, key, and version are also included.

Parameter executionRoleArn : The ARN of the IAM role to be used to run the canary. This role must already exist, and must include lambda.amazonaws.com as a principal in the trust policy. The role must also have the following permissions:

  • s3:PutObject
  • s3:GetBucketLocation
  • s3:ListAllMyBuckets
  • cloudwatch:PutMetricData
  • logs:CreateLogGroup
  • logs:CreateLogStream
  • logs:PutLogEvents

Parameter name : The name for this canary. Be sure to give it a descriptive name that distinguishes it from other canaries in your account.

Do not include secrets or proprietary information in your canary names. The canary name makes up part of the canary ARN, and the ARN is included in outbound calls over the internet. For more information, see Security Considerations for Synthetics Canaries.

Parameter runtimeVersion : Specifies the runtime version to use for the canary. For a list of valid runtime versions and more information about runtime versions, see Canary Runtime Versions.

Parameter schedule : A structure that contains information about how often the canary is to run and when these test runs are to stop.

Parameter artifactConfig : A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.

Parameter browserConfigs : CloudWatch Synthetics now supports multibrowser canaries for syn-nodejs-puppeteer-11.0 and syn-nodejs-playwright-3.0 runtimes. This feature allows you to run your canaries on both Firefox and Chrome browsers. To create a multibrowser canary, you need to specify the BrowserConfigs with a list of browsers you want to use.

Parameter failureRetentionPeriodInDays : The number of days to retain data about failed runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Parameter provisionedResourceCleanup : Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted. If you omit this parameter, the default of AUTOMATIC is used, which means that the Lambda functions and layers will be deleted when the canary is deleted.

If the value of this parameter is OFF, then the value of the DeleteLambda parameter of the DeleteCanary operation determines whether the Lambda functions and layers will be deleted.

Parameter resourcesToReplicateTags : To have the tags that you apply to this canary also be applied to the Lambda function that the canary uses, specify this parameter with the value lambda-function.

If you specify this parameter and don't specify any tags in the Tags parameter, the canary creation fails.

Parameter runConfig : A structure that contains the configuration for individual canary runs, such as timeout value and environment variables.

Parameter successRetentionPeriodInDays : The number of days to retain data about successful runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Parameter tags : A list of key-value pairs to associate with the canary. You can associate as many as 50 tags with a canary.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only the resources that have certain tag values.

To have the tags that you apply to this canary also be applied to the Lambda function that the canary uses, specify this parameter with the value lambda-function.

Parameter vpcConfig : If this canary is to test an endpoint in a VPC, this structure contains information about the subnet and security groups of the VPC endpoint. For more information, see Running a Canary in a VPC.

Implementation

Future<CreateCanaryResponse> createCanary({
  required String artifactS3Location,
  required CanaryCodeInput code,
  required String executionRoleArn,
  required String name,
  required String runtimeVersion,
  required CanaryScheduleInput schedule,
  ArtifactConfigInput? artifactConfig,
  List<BrowserConfig>? browserConfigs,
  int? failureRetentionPeriodInDays,
  ProvisionedResourceCleanupSetting? provisionedResourceCleanup,
  List<ResourceToTag>? resourcesToReplicateTags,
  CanaryRunConfigInput? runConfig,
  int? successRetentionPeriodInDays,
  Map<String, String>? tags,
  VpcConfigInput? vpcConfig,
}) async {
  _s.validateNumRange(
    'failureRetentionPeriodInDays',
    failureRetentionPeriodInDays,
    1,
    1024,
  );
  _s.validateNumRange(
    'successRetentionPeriodInDays',
    successRetentionPeriodInDays,
    1,
    1024,
  );
  final $payload = <String, dynamic>{
    'ArtifactS3Location': artifactS3Location,
    'Code': code,
    'ExecutionRoleArn': executionRoleArn,
    'Name': name,
    'RuntimeVersion': runtimeVersion,
    'Schedule': schedule,
    if (artifactConfig != null) 'ArtifactConfig': artifactConfig,
    if (browserConfigs != null) 'BrowserConfigs': browserConfigs,
    if (failureRetentionPeriodInDays != null)
      'FailureRetentionPeriodInDays': failureRetentionPeriodInDays,
    if (provisionedResourceCleanup != null)
      'ProvisionedResourceCleanup': provisionedResourceCleanup.value,
    if (resourcesToReplicateTags != null)
      'ResourcesToReplicateTags':
          resourcesToReplicateTags.map((e) => e.value).toList(),
    if (runConfig != null) 'RunConfig': runConfig,
    if (successRetentionPeriodInDays != null)
      'SuccessRetentionPeriodInDays': successRetentionPeriodInDays,
    if (tags != null) 'Tags': tags,
    if (vpcConfig != null) 'VpcConfig': vpcConfig,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/canary',
    exceptionFnMap: _exceptionFns,
  );
  return CreateCanaryResponse.fromJson(response);
}