deleteGroup method

Future<void> deleteGroup({
  1. required String groupIdentifier,
})

Deletes a group. The group doesn't need to be empty to be deleted. If there are canaries in the group, they are not deleted when you delete the group.

Groups are a global resource that appear in all Regions, but the request to delete a group must be made from its home Region. You can find the home Region of a group within its ARN.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter groupIdentifier : Specifies which group to delete. You can specify the group name, the ARN, or the group ID as the GroupIdentifier.

Implementation

Future<void> deleteGroup({
  required String groupIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/group/${Uri.encodeComponent(groupIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
}