disassociateResource method

Future<void> disassociateResource({
  1. required String groupIdentifier,
  2. required String resourceArn,
})

Removes a canary from a group. You must run this operation in the Region where the canary exists.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter groupIdentifier : Specifies the group. You can specify the group name, the ARN, or the group ID as the GroupIdentifier.

Parameter resourceArn : The ARN of the canary that you want to remove from the specified group.

Implementation

Future<void> disassociateResource({
  required String groupIdentifier,
  required String resourceArn,
}) async {
  final $payload = <String, dynamic>{
    'ResourceArn': resourceArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri: '/group/${Uri.encodeComponent(groupIdentifier)}/disassociate',
    exceptionFnMap: _exceptionFns,
  );
}