listGroupResources method

Future<ListGroupResourcesResponse> listGroupResources({
  1. required String groupIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

This operation returns a list of the ARNs of the canaries that are associated with the specified group.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter groupIdentifier : Specifies the group to return information for. You can specify the group name, the ARN, or the group ID as the GroupIdentifier.

Parameter maxResults : Specify this parameter to limit how many canary ARNs are returned each time you use the ListGroupResources operation. If you omit this parameter, the default of 20 is used.

Parameter nextToken : A token that indicates that there is more data available. You can use this token in a subsequent operation to retrieve the next set of results.

Implementation

Future<ListGroupResourcesResponse> listGroupResources({
  required String groupIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    20,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'MaxResults': maxResults,
    if (nextToken != null) 'NextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/group/${Uri.encodeComponent(groupIdentifier)}/resources',
    exceptionFnMap: _exceptionFns,
  );
  return ListGroupResourcesResponse.fromJson(response);
}