startCanary method

Future<void> startCanary({
  1. required String name,
})

Use this operation to run a canary that has already been created. The frequency of the canary runs is determined by the value of the canary's Schedule. To see a canary's schedule, use GetCanary.

May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter name : The name of the canary that you want to run. To find canary names, use DescribeCanaries.

Implementation

Future<void> startCanary({
  required String name,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri: '/canary/${Uri.encodeComponent(name)}/start',
    exceptionFnMap: _exceptionFns,
  );
}