TaxSettings class

You can use the tax setting API to programmatically set, modify, and delete the tax registration number (TRN), associated business legal name, and address (Collectively referred to as "TRN information"). You can also programmatically view TRN information and tax addresses ("Tax profiles").

You can use this API to automate your TRN information settings instead of manually using the console.

Service Endpoint

  • https://tax.us-east-1.amazonaws.com

Constructors

TaxSettings({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchDeleteTaxRegistration({required List<String> accountIds}) Future<BatchDeleteTaxRegistrationResponse>
Deletes tax registration for multiple accounts in batch. This can be used to delete tax registrations for up to five accounts in one batch.
batchGetTaxExemptions({required List<String> accountIds}) Future<BatchGetTaxExemptionsResponse>
Get the active tax exemptions for a given list of accounts. The IAM action is tax:GetExemptions.
batchPutTaxRegistration({required List<String> accountIds, required TaxRegistrationEntry taxRegistrationEntry}) Future<BatchPutTaxRegistrationResponse>
Adds or updates tax registration for multiple accounts in batch. This can be used to add or update tax registrations for up to five accounts in one batch. You can't set a TRN if there's a pending TRN. You'll need to delete the pending TRN first.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
deleteSupplementalTaxRegistration({required String authorityId}) Future<void>
Deletes a supplemental tax registration for a single account.
deleteTaxRegistration({String? accountId}) Future<void>
Deletes tax registration for a single account.
getTaxExemptionTypes() Future<GetTaxExemptionTypesResponse>
Get supported tax exemption types. The IAM action is tax:GetExemptions.
getTaxInheritance() Future<GetTaxInheritanceResponse>
The get account tax inheritance status.
getTaxRegistration({String? accountId}) Future<GetTaxRegistrationResponse>
Retrieves tax registration for a single account.
getTaxRegistrationDocument({required TaxDocumentMetadata taxDocumentMetadata, DestinationS3Location? destinationS3Location}) Future<GetTaxRegistrationDocumentResponse>
Downloads your tax documents to the Amazon S3 bucket that you specify in your request.
listSupplementalTaxRegistrations({int? maxResults, String? nextToken}) Future<ListSupplementalTaxRegistrationsResponse>
Retrieves supplemental tax registrations for a single account.
listTaxExemptions({int? maxResults, String? nextToken}) Future<ListTaxExemptionsResponse>
Retrieves the tax exemption of accounts listed in a consolidated billing family. The IAM action is tax:GetExemptions.
listTaxRegistrations({int? maxResults, String? nextToken}) Future<ListTaxRegistrationsResponse>
Retrieves the tax registration of accounts listed in a consolidated billing family. This can be used to retrieve up to 100 accounts' tax registrations in one call (default 50).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putSupplementalTaxRegistration({required SupplementalTaxRegistrationEntry taxRegistrationEntry}) Future<PutSupplementalTaxRegistrationResponse>
Stores supplemental tax registration for a single account.
putTaxExemption({required List<String> accountIds, required Authority authority, required ExemptionCertificate exemptionCertificate, required String exemptionType}) Future<PutTaxExemptionResponse>
Adds the tax exemption for a single account or all accounts listed in a consolidated billing family. The IAM action is tax:UpdateExemptions.
putTaxInheritance({HeritageStatus? heritageStatus}) Future<void>
The updated tax inheritance status.
putTaxRegistration({required TaxRegistrationEntry taxRegistrationEntry, String? accountId}) Future<PutTaxRegistrationResponse>
Adds or updates tax registration for a single account. You can't set a TRN if there's a pending TRN. You'll need to delete the pending TRN first.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited