batchPutTaxRegistration method
Adds or updates tax registration for multiple accounts in batch. This can be used to add or update tax registrations for up to five accounts in one batch. You can't set a TRN if there's a pending TRN. You'll need to delete the pending TRN first.
To call this API operation for specific countries, see the following country-specific requirements.
Bangladesh
-
You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject.
- You must complete the tax registration process in the Payment preferences page in the Billing and Cost Management console. After your TRN and billing address are verified, you can call this API operation.
- For Amazon Web Services accounts created through Organizations, you can call this API operation when you don't have a billing address.
-
The valid
personTypevalues arePhysical PersonandBusiness.
-
PutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022. -
BatchPutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022, through our third-party partner PT Achilles Advanced Management (OnlinePajak). -
You must specify the
taxRegistrationNumberTypein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. -
If you specify
decisionNumber, you must specify theppnExceptionDesignationCodein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. If thetaxRegistrationNumberTypeis set to NPWP or NITKU, valid values forppnExceptionDesignationCodeare either01,02,03,07, or08.For other
taxRegistrationNumberTypevalues,ppnExceptionDesignationCodemust be either01,07, or08. -
If
ppnExceptionDesignationCodeis07, you must specify thedecisionNumberin theindonesiaAdditionalInfofield of theadditionalTaxInformationobject.
-
You must specify the
personTypein thekenyaAdditionalInfofield of theadditionalTaxInformationobject. -
If the
personTypeisPhysical Person, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
-
The sector valid values are
BusinessandIndividual. -
RegistrationTypevalid values areNRICfor individual, and TIN and sales and service tax (SST) for Business. -
For individual, you can specify the
taxInformationNumberinMalaysiaAdditionalInfowith NRIC type, and a validMyKador NRIC number. -
For business, you must specify a
businessRegistrationNumberinMalaysiaAdditionalInfowith a TIN type and tax identification number. -
For business resellers, you must specify a
businessRegistrationNumberandtaxInformationNumberinMalaysiaAdditionalInfowith a sales and service tax (SST) type and a valid SST number. -
For business resellers with service codes, you must specify
businessRegistrationNumber,taxInformationNumber, and distinctserviceTaxCodesinMalaysiaAdditionalInfowith a SST type and valid sales and service tax (SST) number. By using this API operation, Amazon Web Services registers your self-declaration that you’re an authorized business reseller registered with the Royal Malaysia Customs Department (RMCD), and have a valid SST number. - Amazon Web Services reserves the right to seek additional information and/or take other actions to support your self-declaration as appropriate.
-
Amazon Web Services is currently registered under the following service
tax codes. You must include at least one of the service tax codes in the
service tax code strings to declare yourself as an authorized registered
business reseller.
Taxable service and service tax codes:
Consultancy - 9907061674
Training or coaching service - 9907071685
IT service - 9907101676
Digital services and electronic medium - 9907121690
-
The sector valid values are
BusinessandIndividual.
-
For
address, you must specifyaddressLine3.
-
You must specify the
certifiedEmailIdandlegalNamein theTaxRegistrationEntryobject. Use Korean characters forlegalName. -
You must specify the
businessRepresentativeName,itemOfBusiness, andlineOfBusinessin thesouthKoreaAdditionalInfofield of theadditionalTaxInformationobject. Use Korean characters for these fields. -
You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject. -
For the
addressobject, use Korean characters foraddressLine1,addressLine2city,postalCode, andstateOrRegion.
-
You must specify the
registrationTypein thespainAdditionalInfofield of theadditionalTaxInformationobject. -
If the
registrationTypeisLocal, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
-
You must specify the
sectorin thetaxRegistrationEntryobject. -
If your
sectorisBusiness,Individual, orGovernment:-
Specify the
taxOffice. If yoursectorisIndividual, don't enter this value. -
(Optional) Specify the
kepEmailId. If yoursectorisIndividual, don't enter this value. -
Note: In the Tax Settings page of the Billing console,
Governmentappears as Public institutions
-
Specify the
-
If your
sectorisBusinessand you're subject to KDV tax, you must specify your industry in theindustriesfield. -
For
address, you must specifydistrictOrCounty.
-
The sector valid values are
BusinessandIndividual.
May throw ConflictException.
May throw InternalServerException.
May throw ValidationException.
Parameter accountIds :
List of unique account identifiers.
Parameter taxRegistrationEntry :
Your TRN information that will be stored to the accounts mentioned in
putEntries.
Implementation
Future<BatchPutTaxRegistrationResponse> batchPutTaxRegistration({
required List<String> accountIds,
required TaxRegistrationEntry taxRegistrationEntry,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
'taxRegistrationEntry': taxRegistrationEntry,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchPutTaxRegistration',
exceptionFnMap: _exceptionFns,
);
return BatchPutTaxRegistrationResponse.fromJson(response);
}