putTaxExemption method

Future<PutTaxExemptionResponse> putTaxExemption({
  1. required List<String> accountIds,
  2. required Authority authority,
  3. required ExemptionCertificate exemptionCertificate,
  4. required String exemptionType,
})

Adds the tax exemption for a single account or all accounts listed in a consolidated billing family. The IAM action is tax:UpdateExemptions.

May throw AccessDeniedException. May throw AttachmentUploadException. May throw CaseCreationLimitExceededException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter accountIds : The list of unique account identifiers.

Parameter exemptionType : The exemption type. Use the supported tax exemption type description.

Implementation

Future<PutTaxExemptionResponse> putTaxExemption({
  required List<String> accountIds,
  required Authority authority,
  required ExemptionCertificate exemptionCertificate,
  required String exemptionType,
}) async {
  final $payload = <String, dynamic>{
    'accountIds': accountIds,
    'authority': authority,
    'exemptionCertificate': exemptionCertificate,
    'exemptionType': exemptionType,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/PutTaxExemption',
    exceptionFnMap: _exceptionFns,
  );
  return PutTaxExemptionResponse.fromJson(response);
}