Textract class
Amazon Textract detects and analyzes text in documents and converts it into machine-readable text. This is the API reference documentation for Amazon Textract.
Constructors
- Textract({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeDocument(
{required Document document, required List< FeatureType> featureTypes, AdaptersConfig? adaptersConfig, HumanLoopConfig? humanLoopConfig, QueriesConfig? queriesConfig}) → Future<AnalyzeDocumentResponse> - Analyzes an input document for relationships between detected items.
-
analyzeExpense(
{required Document document}) → Future< AnalyzeExpenseResponse> -
AnalyzeExpensesynchronously analyzes an input document for financially related relationships between text. -
analyzeID(
{required List< Document> documentPages}) → Future<AnalyzeIDResponse> -
Analyzes identity documents for relevant information. This information is
extracted and returned as
IdentityDocumentFields, which records both the normalized field and value of the extracted text. Unlike other Amazon Textract operations,AnalyzeIDdoesn't return any Geometry data. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAdapter(
{required String adapterName, required List< FeatureType> featureTypes, AutoUpdate? autoUpdate, String? clientRequestToken, String? description, Map<String, String> ? tags}) → Future<CreateAdapterResponse> -
Creates an adapter, which can be fine-tuned for enhanced performance on
user provided documents. Takes an AdapterName and FeatureType. Currently
the only supported feature type is
QUERIES. You can also provide a Description, Tags, and a ClientRequestToken. You can choose whether or not the adapter should be AutoUpdated with the AutoUpdate argument. By default, AutoUpdate is set to DISABLED. -
createAdapterVersion(
{required String adapterId, required AdapterVersionDatasetConfig datasetConfig, required OutputConfig outputConfig, String? clientRequestToken, String? kMSKeyId, Map< String, String> ? tags}) → Future<CreateAdapterVersionResponse> - Creates a new version of an adapter. Operates on a provided AdapterId and a specified dataset provided via the DatasetConfig argument. Requires that you specify an Amazon S3 bucket with the OutputConfig argument. You can provide an optional KMSKeyId, an optional ClientRequestToken, and optional tags.
-
deleteAdapter(
{required String adapterId}) → Future< void> - Deletes an Amazon Textract adapter. Takes an AdapterId and deletes the adapter specified by the ID.
-
deleteAdapterVersion(
{required String adapterId, required String adapterVersion}) → Future< void> - Deletes an Amazon Textract adapter version. Requires that you specify both an AdapterId and a AdapterVersion. Deletes the adapter version specified by the AdapterId and the AdapterVersion.
-
detectDocumentText(
{required Document document}) → Future< DetectDocumentTextResponse> -
Detects text in the input document. Amazon Textract can detect lines of
text and the words that make up a line of text. The input document must be
in one of the following image formats: JPEG, PNG, PDF, or TIFF.
DetectDocumentTextreturns the detected text in an array of Block objects. -
getAdapter(
{required String adapterId}) → Future< GetAdapterResponse> - Gets configuration information for an adapter specified by an AdapterId, returning information on AdapterName, Description, CreationTime, AutoUpdate status, and FeatureTypes.
-
getAdapterVersion(
{required String adapterId, required String adapterVersion}) → Future< GetAdapterVersionResponse> - Gets configuration information for the specified adapter version, including: AdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig, KMSKeyId, OutputConfig, Tags and EvaluationMetrics.
-
getDocumentAnalysis(
{required String jobId, int? maxResults, String? nextToken}) → Future< GetDocumentAnalysisResponse> - Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document.
-
getDocumentTextDetection(
{required String jobId, int? maxResults, String? nextToken}) → Future< GetDocumentTextDetectionResponse> - Gets the results for an Amazon Textract asynchronous operation that detects text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
-
getExpenseAnalysis(
{required String jobId, int? maxResults, String? nextToken}) → Future< GetExpenseAnalysisResponse> - Gets the results for an Amazon Textract asynchronous operation that analyzes invoices and receipts. Amazon Textract finds contact information, items purchased, and vendor name, from input invoices and receipts.
-
getLendingAnalysis(
{required String jobId, int? maxResults, String? nextToken}) → Future< GetLendingAnalysisResponse> - Gets the results for an Amazon Textract asynchronous operation that analyzes text in a lending document.
-
getLendingAnalysisSummary(
{required String jobId}) → Future< GetLendingAnalysisSummaryResponse> -
Gets summarized results for the
StartLendingAnalysisoperation, which analyzes text in a lending document. The returned summary consists of information about documents grouped together by a common document type. Information like detected signatures, page numbers, and split documents is returned with respect to the type of grouped document. -
listAdapters(
{DateTime? afterCreationTime, DateTime? beforeCreationTime, int? maxResults, String? nextToken}) → Future< ListAdaptersResponse> - Lists all adapters that match the specified filtration criteria.
-
listAdapterVersions(
{String? adapterId, DateTime? afterCreationTime, DateTime? beforeCreationTime, int? maxResults, String? nextToken}) → Future< ListAdapterVersionsResponse> - List all version of an adapter that meet the specified filtration criteria.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Lists all tags for an Amazon Textract resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startDocumentAnalysis(
{required DocumentLocation documentLocation, required List< FeatureType> featureTypes, AdaptersConfig? adaptersConfig, String? clientRequestToken, String? jobTag, String? kMSKeyId, NotificationChannel? notificationChannel, OutputConfig? outputConfig, QueriesConfig? queriesConfig}) → Future<StartDocumentAnalysisResponse> - Starts the asynchronous analysis of an input document for relationships between detected items such as key-value pairs, tables, and selection elements.
-
startDocumentTextDetection(
{required DocumentLocation documentLocation, String? clientRequestToken, String? jobTag, String? kMSKeyId, NotificationChannel? notificationChannel, OutputConfig? outputConfig}) → Future< StartDocumentTextDetectionResponse> - Starts the asynchronous detection of text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.
-
startExpenseAnalysis(
{required DocumentLocation documentLocation, String? clientRequestToken, String? jobTag, String? kMSKeyId, NotificationChannel? notificationChannel, OutputConfig? outputConfig}) → Future< StartExpenseAnalysisResponse> - Starts the asynchronous analysis of invoices or receipts for data like contact information, items purchased, and vendor names.
-
startLendingAnalysis(
{required DocumentLocation documentLocation, String? clientRequestToken, String? jobTag, String? kMSKeyId, NotificationChannel? notificationChannel, OutputConfig? outputConfig}) → Future< StartLendingAnalysisResponse> -
Starts the classification and analysis of an input document.
StartLendingAnalysisinitiates the classification and analysis of a packet of lending documents.StartLendingAnalysisoperates on a document file located in an Amazon S3 bucket. -
tagResource(
{required String resourceARN, required Map< String, String> tags}) → Future<void> - Adds one or more tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes any tags with the specified keys from the specified resource.
-
updateAdapter(
{required String adapterId, String? adapterName, AutoUpdate? autoUpdate, String? description}) → Future< UpdateAdapterResponse> - Update the configuration for an adapter. FeatureTypes configurations cannot be updated. At least one new parameter must be specified as an argument.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited