getExpenseAnalysis method
Gets the results for an Amazon Textract asynchronous operation that analyzes invoices and receipts. Amazon Textract finds contact information, items purchased, and vendor name, from input invoices and receipts.
You start asynchronous invoice/receipt analysis by calling
StartExpenseAnalysis, which returns a job identifier
(JobId). Upon completion of the invoice/receipt analysis,
Amazon Textract publishes the completion status to the Amazon Simple
Notification Service (Amazon SNS) topic. This topic must be registered in
the initial call to StartExpenseAnalysis. To get the results
of the invoice/receipt analysis operation, first ensure that the status
value published to the Amazon SNS topic is SUCCEEDED. If so,
call GetExpenseAnalysis, and pass the job identifier
(JobId) from the initial call to
StartExpenseAnalysis.
Use the MaxResults parameter to limit the number of blocks that are
returned. If there are more results than specified in
MaxResults, the value of NextToken in the
operation response contains a pagination token for getting the next set of
results. To get the next page of results, call
GetExpenseAnalysis, and populate the NextToken
request parameter with the token value that's returned from the previous
call to GetExpenseAnalysis.
For more information, see Analyzing Invoices and Receipts.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidJobIdException.
May throw InvalidKMSKeyException.
May throw InvalidParameterException.
May throw InvalidS3ObjectException.
May throw ProvisionedThroughputExceededException.
May throw ThrottlingException.
Parameter jobId :
A unique identifier for the text detection job. The JobId is
returned from StartExpenseAnalysis. A JobId
value is only valid for 7 days.
Parameter maxResults :
The maximum number of results to return per paginated call. The largest
value you can specify is 20. If you specify a value greater than 20, a
maximum of 20 results is returned. The default value is 20.
Parameter nextToken :
If the previous response was incomplete (because there are more blocks to
retrieve), Amazon Textract returns a pagination token in the response. You
can use this pagination token to retrieve the next set of blocks.
Implementation
Future<GetExpenseAnalysisResponse> getExpenseAnalysis({
required String jobId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Textract.GetExpenseAnalysis'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetExpenseAnalysisResponse.fromJson(jsonResponse.body);
}