getLendingAnalysisSummary method

Future<GetLendingAnalysisSummaryResponse> getLendingAnalysisSummary({
  1. required String jobId,
})

Gets summarized results for the StartLendingAnalysis operation, which analyzes text in a lending document. The returned summary consists of information about documents grouped together by a common document type. Information like detected signatures, page numbers, and split documents is returned with respect to the type of grouped document.

You start asynchronous text analysis by calling StartLendingAnalysis, which returns a job identifier (JobId). When the text analysis operation finishes, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that's registered in the initial call to StartLendingAnalysis.

To get the results of the text analysis operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetLendingAnalysisSummary, and pass the job identifier (JobId) from the initial call to StartLendingAnalysis.

May throw AccessDeniedException. May throw InternalServerError. May throw InvalidJobIdException. May throw InvalidKMSKeyException. May throw InvalidParameterException. May throw InvalidS3ObjectException. May throw ProvisionedThroughputExceededException. May throw ThrottlingException.

Parameter jobId : A unique identifier for the lending or text-detection job. The JobId is returned from StartLendingAnalysis. A JobId value is only valid for 7 days.

Implementation

Future<GetLendingAnalysisSummaryResponse> getLendingAnalysisSummary({
  required String jobId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Textract.GetLendingAnalysisSummary'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'JobId': jobId,
    },
  );

  return GetLendingAnalysisSummaryResponse.fromJson(jsonResponse.body);
}