startLendingAnalysis method

Future<StartLendingAnalysisResponse> startLendingAnalysis({
  1. required DocumentLocation documentLocation,
  2. String? clientRequestToken,
  3. String? jobTag,
  4. String? kMSKeyId,
  5. NotificationChannel? notificationChannel,
  6. OutputConfig? outputConfig,
})

Starts the classification and analysis of an input document. StartLendingAnalysis initiates the classification and analysis of a packet of lending documents. StartLendingAnalysis operates on a document file located in an Amazon S3 bucket.

StartLendingAnalysis can analyze text in documents that are in one of the following formats: JPEG, PNG, TIFF, PDF. Use DocumentLocation to specify the bucket name and the file name of the document.

StartLendingAnalysis returns a job identifier (JobId) that you use to get the results of the operation. When the text analysis is finished, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that you specify in NotificationChannel. To get the results of the text analysis operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If the status is SUCCEEDED you can call either GetLendingAnalysis or GetLendingAnalysisSummary and provide the JobId to obtain the results of the analysis.

If using OutputConfig to specify an Amazon S3 bucket, the output will be contained within the specified prefix in a directory labeled with the job-id. In the directory there are 3 sub-directories:

  • detailedResponse (contains the GetLendingAnalysis response)
  • summaryResponse (for the GetLendingAnalysisSummary response)
  • splitDocuments (documents split across logical boundaries)

May throw AccessDeniedException. May throw BadDocumentException. May throw DocumentTooLargeException. May throw IdempotentParameterMismatchException. May throw InternalServerError. May throw InvalidKMSKeyException. May throw InvalidParameterException. May throw InvalidS3ObjectException. May throw LimitExceededException. May throw ProvisionedThroughputExceededException. May throw ThrottlingException. May throw UnsupportedDocumentException.

Parameter clientRequestToken : The idempotent token that you use to identify the start request. If you use the same token with multiple StartLendingAnalysis requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentally started more than once. For more information, see Calling Amazon Textract Asynchronous Operations.

Parameter jobTag : An identifier that you specify to be included in the completion notification published to the Amazon SNS topic. For example, you can use JobTag to identify the type of document that the completion notification corresponds to (such as a tax form or a receipt).

Parameter kMSKeyId : The KMS key used to encrypt the inference results. This can be in either Key ID or Key Alias format. When a KMS key is provided, the KMS key will be used for server-side encryption of the objects in the customer bucket. When this parameter is not enabled, the result will be encrypted server side, using SSE-S3.

Implementation

Future<StartLendingAnalysisResponse> startLendingAnalysis({
  required DocumentLocation documentLocation,
  String? clientRequestToken,
  String? jobTag,
  String? kMSKeyId,
  NotificationChannel? notificationChannel,
  OutputConfig? outputConfig,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Textract.StartLendingAnalysis'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DocumentLocation': documentLocation,
      if (clientRequestToken != null)
        'ClientRequestToken': clientRequestToken,
      if (jobTag != null) 'JobTag': jobTag,
      if (kMSKeyId != null) 'KMSKeyId': kMSKeyId,
      if (notificationChannel != null)
        'NotificationChannel': notificationChannel,
      if (outputConfig != null) 'OutputConfig': outputConfig,
    },
  );

  return StartLendingAnalysisResponse.fromJson(jsonResponse.body);
}