listDbInstances method
Returns a list of Timestream for InfluxDB DB instances.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of items to return in the output. If the total number
of items available is more than the value specified, a NextToken is
provided in the output. To resume pagination, provide the NextToken value
as argument of a subsequent API invocation.
Parameter nextToken :
The pagination token. To resume pagination, provide the NextToken value as
argument of a subsequent API invocation.
Implementation
Future<ListDbInstancesOutput> listDbInstances({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonTimestreamInfluxDB.ListDbInstances'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListDbInstancesOutput.fromJson(jsonResponse.body);
}