TimestreamQuery class

Constructors

TimestreamQuery({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelQuery({required String queryId}) Future<CancelQueryResponse>
Cancels a query that has been issued. Cancellation is provided only if the query has not completed running before the cancellation request was issued. Because cancellation is an idempotent operation, subsequent cancellation requests will return a CancellationMessage, indicating that the query has already been canceled. See code sample for details.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createScheduledQuery({required ErrorReportConfiguration errorReportConfiguration, required String name, required NotificationConfiguration notificationConfiguration, required String queryString, required ScheduleConfiguration scheduleConfiguration, required String scheduledQueryExecutionRoleArn, String? clientToken, String? kmsKeyId, List<Tag>? tags, TargetConfiguration? targetConfiguration}) Future<CreateScheduledQueryResponse>
Create a scheduled query that will be run on your behalf at the configured schedule. Timestream assumes the execution role provided as part of the ScheduledQueryExecutionRoleArn parameter to run the query. You can use the NotificationConfiguration parameter to configure notification for your scheduled query operations.
deleteScheduledQuery({required String scheduledQueryArn}) Future<void>
Deletes a given scheduled query. This is an irreversible operation.
describeAccountSettings() Future<DescribeAccountSettingsResponse>
Describes the settings for your account that include the query pricing model and the configured maximum TCUs the service can use for your query workload.
describeEndpoints() Future<DescribeEndpointsResponse>
DescribeEndpoints returns a list of available endpoints to make Timestream API calls against. This API is available through both Write and Query.
describeScheduledQuery({required String scheduledQueryArn}) Future<DescribeScheduledQueryResponse>
Provides detailed information about a scheduled query.
executeScheduledQuery({required DateTime invocationTime, required String scheduledQueryArn, String? clientToken, ScheduledQueryInsights? queryInsights}) Future<void>
You can use this API to run a scheduled query manually.
listScheduledQueries({int? maxResults, String? nextToken}) Future<ListScheduledQueriesResponse>
Gets a list of all scheduled queries in the caller's Amazon account and Region. ListScheduledQueries is eventually consistent.
listTagsForResource({required String resourceARN, int? maxResults, String? nextToken}) Future<ListTagsForResourceResponse>
List all tags on a Timestream query resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareQuery({required String queryString, bool? validateOnly}) Future<PrepareQueryResponse>
A synchronous operation that allows you to submit a query with parameters to be stored by Timestream for later running. Timestream only supports using this operation with ValidateOnly set to true.
query({required String queryString, String? clientToken, int? maxRows, String? nextToken, QueryInsights? queryInsights}) Future<QueryResponse>
Query is a synchronous operation that enables you to run a query against your Amazon Timestream data.
tagResource({required String resourceARN, required List<Tag> tags}) Future<void>
Associate a set of tags with a Timestream resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceARN, required List<String> tagKeys}) Future<void>
Removes the association of tags from a Timestream query resource.
updateAccountSettings({int? maxQueryTCU, QueryComputeRequest? queryCompute, QueryPricingModel? queryPricingModel}) Future<UpdateAccountSettingsResponse>
Transitions your account to use TCUs for query pricing and modifies the maximum query compute units that you've configured. If you reduce the value of MaxQueryTCU to a desired configuration, the new value can take up to 24 hours to be effective.
updateScheduledQuery({required String scheduledQueryArn, required ScheduledQueryState state}) Future<void>
Update a scheduled query.

Operators

operator ==(Object other) bool
The equality operator.
inherited