query method
Query is a synchronous operation that enables you to run a
query against your Amazon Timestream data.
If you enabled QueryInsights, this API also returns insights
and metrics related to the query that you executed.
QueryInsights helps with performance tuning of your query.
For more information about QueryInsights, see Using
query insights to optimize queries in Amazon Timestream.
Query will time out after 60 seconds. You must update the
default timeout in the SDK to support a timeout of 60 seconds. See the code
sample for details.
Your query request will fail in the following cases:
-
If you submit a
Queryrequest with the same client token outside of the 5-minute idempotency window. -
If you submit a
Queryrequest with the same client token, but change other parameters, within the 5-minute idempotency window. -
If the size of the row (including the query metadata) exceeds 1 MB, then
the query will fail with the following error message:
Query aborted as max page response size has been exceeded by the output result row -
If the IAM principal of the query initiator and the result reader are not
the same and/or the query initiator and the result reader do not have the
same query string in the query requests, the query will fail with an
Invalid pagination tokenerror.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw InvalidEndpointException.
May throw QueryExecutionException.
May throw ThrottlingException.
May throw ValidationException.
Parameter queryString :
The query to be run by Timestream.
Parameter clientToken :
Unique, case-sensitive string of up to 64 ASCII characters specified when
a Query request is made. Providing a ClientToken
makes the call to Query idempotent. This means that
running the same query repeatedly will produce the same result. In other
words, making multiple identical Query requests has the same
effect as making a single request. When using ClientToken in
a query, note the following:
-
If the Query API is instantiated without a
ClientToken, the Query SDK generates aClientTokenon your behalf. -
If the
Queryinvocation only contains theClientTokenbut does not include aNextToken, that invocation ofQueryis assumed to be a new query run. -
If the invocation contains
NextToken, that particular invocation is assumed to be a subsequent invocation of a prior call to the Query API, and a result set is returned. -
After 4 hours, any request with the same
ClientTokenis treated as a new request.
Parameter maxRows :
The total number of rows to be returned in the Query output.
The initial run of Query with a MaxRows value
specified will return the result set of the query in two cases:
-
The size of the result is less than
1MB. -
The number of rows in the result set is less than the value of
maxRows.
Query only returns a
NextToken, which can then be used in subsequent calls to
fetch the result set. To resume pagination, provide the
NextToken value in the subsequent command.
If the row size is large (e.g. a row has many columns), Timestream may
return fewer rows to keep the response size from exceeding the 1 MB limit.
If MaxRows is not provided, Timestream will send the
necessary number of rows to meet the 1 MB limit.
Parameter nextToken :
A pagination token used to return a set of results. When the
Query API is invoked using NextToken, that
particular invocation is assumed to be a subsequent invocation of a prior
call to Query, and a result set is returned. However, if the
Query invocation only contains the ClientToken,
that invocation of Query is assumed to be a new query run.
Note the following when using NextToken in a query:
-
A pagination token can be used for up to five
Queryinvocations, OR for a duration of up to 1 hour – whichever comes first. -
Using the same
NextTokenwill return the same set of records. To keep paginating through the result set, you must to use the most recentnextToken. -
Suppose a
Queryinvocation returns twoNextTokenvalues,TokenAandTokenB. IfTokenBis used in a subsequentQueryinvocation, thenTokenAis invalidated and cannot be reused. - To request a previous result set from a query after pagination has begun, you must re-invoke the Query API.
-
The latest
NextTokenshould be used to paginate untilnullis returned, at which point a newNextTokenshould be used. -
If the IAM principal of the query initiator and the result reader are not
the same and/or the query initiator and the result reader do not have the
same query string in the query requests, the query will fail with an
Invalid pagination tokenerror.
Parameter queryInsights :
Encapsulates settings for enabling QueryInsights.
Enabling QueryInsights returns insights and metrics in
addition to query results for the query that you executed. You can use
QueryInsights to tune your query performance.
Implementation
Future<QueryResponse> query({
required String queryString,
String? clientToken,
int? maxRows,
String? nextToken,
QueryInsights? queryInsights,
}) async {
_s.validateNumRange(
'maxRows',
maxRows,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.Query'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'QueryString': queryString,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (maxRows != null) 'MaxRows': maxRows,
if (nextToken != null) 'NextToken': nextToken,
if (queryInsights != null) 'QueryInsights': queryInsights,
},
);
return QueryResponse.fromJson(jsonResponse.body);
}