updateAccountSettings method
- int? maxQueryTCU,
- QueryComputeRequest? queryCompute,
- QueryPricingModel? queryPricingModel,
Transitions your account to use TCUs for query pricing and modifies the
maximum query compute units that you've configured. If you reduce the
value of MaxQueryTCU to a desired configuration, the new
value can take up to 24 hours to be effective.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidEndpointException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxQueryTCU :
The maximum number of compute units the service will use at any point in
time to serve your queries. To run queries, you must set a minimum
capacity of 4 TCU. You can set the maximum number of TCU in multiples of
4, for example, 4, 8, 16, 32, and so on. The maximum value supported for
MaxQueryTCU is 1000. To request an increase to this soft
limit, contact Amazon Web Services Support. For information about the
default quota for maxQueryTCU, see Default quotas. This configuration is
applicable only for on-demand usage of Timestream Compute Units (TCUs).
The maximum value supported for MaxQueryTCU is 1000. To
request an increase to this soft limit, contact Amazon Web Services
Support. For information about the default quota for
maxQueryTCU, see Default
quotas.
Parameter queryCompute :
Modifies the query compute settings configured in your account, including
the query pricing model and provisioned Timestream Compute Units (TCUs) in
your account.
Parameter queryPricingModel :
The pricing model for queries in an account.
Implementation
Future<UpdateAccountSettingsResponse> updateAccountSettings({
int? maxQueryTCU,
QueryComputeRequest? queryCompute,
QueryPricingModel? queryPricingModel,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.UpdateAccountSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxQueryTCU != null) 'MaxQueryTCU': maxQueryTCU,
if (queryCompute != null) 'QueryCompute': queryCompute,
if (queryPricingModel != null)
'QueryPricingModel': queryPricingModel.value,
},
);
return UpdateAccountSettingsResponse.fromJson(jsonResponse.body);
}