TimestreamWrite class
Amazon Timestream is a fast, scalable, fully managed time-series database service that makes it easy to store and analyze trillions of time-series data points per day. With Timestream, you can easily store and analyze IoT sensor data to derive insights from your IoT applications. You can analyze industrial telemetry to streamline equipment management and maintenance. You can also store and analyze log data and metrics to improve the performance and availability of your applications.
Constructors
- TimestreamWrite({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBatchLoadTask(
{required DataSourceConfiguration dataSourceConfiguration, required ReportConfiguration reportConfiguration, required String targetDatabaseName, required String targetTableName, String? clientToken, DataModelConfiguration? dataModelConfiguration, int? recordVersion}) → Future< CreateBatchLoadTaskResponse> -
Creates a new Timestream batch load task. A batch load task processes data
from a CSV source in an S3 location and writes to a Timestream table. A
mapping from source to target is defined in a batch load task. Errors and
events are written to a report at an S3 location. For the report, if the
KMS key is not specified, the report will be encrypted with an S3 managed
key when
SSE_S3is the option. Otherwise an error is thrown. For more information, see Amazon Web Services managed keys. Service quotas apply. For details, see code sample. -
createDatabase(
{required String databaseName, String? kmsKeyId, List< Tag> ? tags}) → Future<CreateDatabaseResponse> - Creates a new Timestream database. If the KMS key is not specified, the database will be encrypted with a Timestream managed KMS key located in your account. For more information, see Amazon Web Services managed keys. Service quotas apply. For details, see code sample.
-
createTable(
{required String databaseName, required String tableName, MagneticStoreWriteProperties? magneticStoreWriteProperties, RetentionProperties? retentionProperties, Schema? schema, List< Tag> ? tags}) → Future<CreateTableResponse> - Adds a new table to an existing database in your account. In an Amazon Web Services account, table names must be at least unique within each Region if they are in the same database. You might have identical table names in the same Region if the tables are in separate databases. While creating the table, you must specify the table name, database name, and the retention properties. Service quotas apply. See code sample for details.
-
deleteDatabase(
{required String databaseName}) → Future< void> - Deletes a given Timestream database. This is an irreversible operation. After a database is deleted, the time-series data from its tables cannot be recovered.
-
deleteTable(
{required String databaseName, required String tableName}) → Future< void> - Deletes a given Timestream table. This is an irreversible operation. After a Timestream database table is deleted, the time-series data stored in the table cannot be recovered. See code sample for details.
-
describeBatchLoadTask(
{required String taskId}) → Future< DescribeBatchLoadTaskResponse> - Returns information about the batch load task, including configurations, mappings, progress, and other details. Service quotas apply. See code sample for details.
-
describeDatabase(
{required String databaseName}) → Future< DescribeDatabaseResponse> - Returns information about the database, including the database name, time that the database was created, and the total number of tables found within the database. Service quotas apply. See code sample for details.
-
describeEndpoints(
) → Future< DescribeEndpointsResponse> - Returns a list of available endpoints to make Timestream API calls against. This API operation is available through both the Write and Query APIs.
-
describeTable(
{required String databaseName, required String tableName}) → Future< DescribeTableResponse> - Returns information about the table, including the table name, database name, retention duration of the memory store and the magnetic store. Service quotas apply. See code sample for details.
-
listBatchLoadTasks(
{int? maxResults, String? nextToken, BatchLoadStatus? taskStatus}) → Future< ListBatchLoadTasksResponse> - Provides a list of batch load tasks, along with the name, status, when the task is resumable until, and other details. See code sample for details.
-
listDatabases(
{int? maxResults, String? nextToken}) → Future< ListDatabasesResponse> - Returns a list of your Timestream databases. Service quotas apply. See code sample for details.
-
listTables(
{String? databaseName, int? maxResults, String? nextToken}) → Future< ListTablesResponse> - Provides a list of tables, along with the name, status, and retention properties of each table. See code sample for details.
-
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Lists all tags on a Timestream resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resumeBatchLoadTask(
{required String taskId}) → Future< void> -
May throw
AccessDeniedException. May throwInternalServerException. May throwInvalidEndpointException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Associates a set of tags with a Timestream resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes the association of tags from a Timestream resource.
-
updateDatabase(
{required String databaseName, required String kmsKeyId}) → Future< UpdateDatabaseResponse> -
Modifies the KMS key for an existing database. While updating the
database, you must specify the database name and the identifier of the new
KMS key to be used (
KmsKeyId). If there are any concurrentUpdateDatabaserequests, first writer wins. -
updateTable(
{required String databaseName, required String tableName, MagneticStoreWriteProperties? magneticStoreWriteProperties, RetentionProperties? retentionProperties, Schema? schema}) → Future< UpdateTableResponse> - Modifies the retention duration of the memory store and magnetic store for your Timestream table. Note that the change in retention duration takes effect immediately. For example, if the retention period of the memory store was initially set to 2 hours and then changed to 24 hours, the memory store will be capable of holding 24 hours of data, but will be populated with 24 hours of data 22 hours after this change was made. Timestream does not retrieve data from the magnetic store to populate the memory store.
-
writeRecords(
{required String databaseName, required List< Record> records, required String tableName, Record? commonAttributes}) → Future<WriteRecordsResponse> - Enables you to write your time-series data into Timestream. You can specify a single data point or a batch of data points to be inserted into the system. Timestream offers you a flexible schema that auto detects the column names and data types for your Timestream tables based on the dimension names and data types of the data points you specify when invoking writes into the database.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited