describeDatabase method
Returns information about the database, including the database name, time that the database was created, and the total number of tables found within the database. Service quotas apply. See code sample for details.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidEndpointException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter databaseName :
The name of the Timestream database.
Implementation
Future<DescribeDatabaseResponse> describeDatabase({
required String databaseName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.DescribeDatabase'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseName': databaseName,
},
);
return DescribeDatabaseResponse.fromJson(jsonResponse.body);
}