describeTable method

Future<DescribeTableResponse> describeTable({
  1. required String databaseName,
  2. required String tableName,
})

Returns information about the table, including the table name, database name, retention duration of the memory store and the magnetic store. Service quotas apply. See code sample for details.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidEndpointException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter databaseName : The name of the Timestream database.

Parameter tableName : The name of the Timestream table.

Implementation

Future<DescribeTableResponse> describeTable({
  required String databaseName,
  required String tableName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Timestream_20181101.DescribeTable'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DatabaseName': databaseName,
      'TableName': tableName,
    },
  );

  return DescribeTableResponse.fromJson(jsonResponse.body);
}