listDatabases method

Future<ListDatabasesResponse> listDatabases({
  1. int? maxResults,
  2. String? nextToken,
})

Returns a list of your Timestream databases. Service quotas apply. See code sample for details.

May throw AccessDeniedException. May throw InternalServerException. May throw InvalidEndpointException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The total number of items to return in the output. If the total number of items available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.

Parameter nextToken : The pagination token. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.

Implementation

Future<ListDatabasesResponse> listDatabases({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    20,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'Timestream_20181101.ListDatabases'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListDatabasesResponse.fromJson(jsonResponse.body);
}