cancelSolNetworkOperation method

Future<void> cancelSolNetworkOperation({
  1. required String nsLcmOpOccId,
})

Cancels a network operation.

A network operation is any operation that is done to your network, such as network instance instantiation or termination.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nsLcmOpOccId : The identifier of the network operation.

Implementation

Future<void> cancelSolNetworkOperation({
  required String nsLcmOpOccId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'POST',
    requestUri:
        '/sol/nslcm/v1/ns_lcm_op_occs/${Uri.encodeComponent(nsLcmOpOccId)}/cancel',
    exceptionFnMap: _exceptionFns,
  );
}