deleteSolNetworkInstance method
Deletes a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
To delete a network instance, the instance must be in a stopped or terminated state. To terminate a network instance, see TerminateSolNetworkInstance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsInstanceId :
Network instance ID.
Implementation
Future<void> deleteSolNetworkInstance({
required String nsInstanceId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/sol/nslcm/v1/ns_instances/${Uri.encodeComponent(nsInstanceId)}',
exceptionFnMap: _exceptionFns,
);
}