getSolFunctionPackage method

Future<GetSolFunctionPackageOutput> getSolFunctionPackage({
  1. required String vnfPkgId,
})

Gets the details of an individual function package, such as the operational state and whether the package is in use.

A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network..

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter vnfPkgId : ID of the function package.

Implementation

Future<GetSolFunctionPackageOutput> getSolFunctionPackage({
  required String vnfPkgId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/sol/vnfpkgm/v1/vnf_packages/${Uri.encodeComponent(vnfPkgId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSolFunctionPackageOutput.fromJson(response);
}