getSolNetworkOperation method

Future<GetSolNetworkOperationOutput> getSolNetworkOperation({
  1. required String nsLcmOpOccId,
})

Gets the details of a network operation, including the tasks involved in the network operation and the status of the tasks.

A network operation is any operation that is done to your network, such as network instance instantiation or termination.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nsLcmOpOccId : The identifier of the network operation.

Implementation

Future<GetSolNetworkOperationOutput> getSolNetworkOperation({
  required String nsLcmOpOccId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/sol/nslcm/v1/ns_lcm_op_occs/${Uri.encodeComponent(nsLcmOpOccId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSolNetworkOperationOutput.fromJson(response);
}