getSolNetworkPackage method
Gets the details of a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsdInfoId :
ID of the network service descriptor in the network package.
Implementation
Future<GetSolNetworkPackageOutput> getSolNetworkPackage({
required String nsdInfoId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/sol/nsd/v1/ns_descriptors/${Uri.encodeComponent(nsdInfoId)}',
exceptionFnMap: _exceptionFns,
);
return GetSolNetworkPackageOutput.fromJson(response);
}