getSolNetworkPackageDescriptor method

Future<GetSolNetworkPackageDescriptorOutput> getSolNetworkPackageDescriptor({
  1. required String nsdInfoId,
})

Gets the content of the network service descriptor.

A network service descriptor is a .yaml file in a network package that uses the TOSCA standard to describe the network functions you want to deploy and the Amazon Web Services infrastructure you want to deploy the network functions on.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nsdInfoId : ID of the network service descriptor in the network package.

Implementation

Future<GetSolNetworkPackageDescriptorOutput> getSolNetworkPackageDescriptor({
  required String nsdInfoId,
}) async {
  final response = await _protocol.sendRaw(
    payload: null,
    method: 'GET',
    requestUri:
        '/sol/nsd/v1/ns_descriptors/${Uri.encodeComponent(nsdInfoId)}/nsd',
    exceptionFnMap: _exceptionFns,
  );
  return GetSolNetworkPackageDescriptorOutput(
    nsd: await response.stream.toBytes(),
    contentType: _s
        .extractHeaderStringValue(response.headers, 'Content-Type')
        ?.let(DescriptorContentType.fromString),
  );
}