instantiateSolNetworkInstance method
Instantiates a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
Before you can instantiate a network instance, you have to create a network instance. For more information, see CreateSolNetworkInstance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsInstanceId :
ID of the network instance.
Parameter additionalParamsForNs :
Provides values for the configurable properties.
Parameter dryRun :
A check for whether you have the required permissions for the action
without actually making the request and provides an error response. If you
have the required permissions, the error response is
DryRunOperation. Otherwise, it is
UnauthorizedOperation.
Parameter tags :
A tag is a label that you assign to an Amazon Web Services resource. Each
tag consists of a key and an optional value. When you use this API, the
tags are only applied to the network operation that is created. These tags
are not applied to the network instance. Use tags to search and filter
your resources or track your Amazon Web Services costs.
Implementation
Future<InstantiateSolNetworkInstanceOutput> instantiateSolNetworkInstance({
required String nsInstanceId,
Document? additionalParamsForNs,
bool? dryRun,
Map<String, String>? tags,
}) async {
final $query = <String, List<String>>{
if (dryRun != null) 'dry_run': [dryRun.toString()],
};
final $payload = <String, dynamic>{
if (additionalParamsForNs != null)
'additionalParamsForNs': additionalParamsForNs,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sol/nslcm/v1/ns_instances/${Uri.encodeComponent(nsInstanceId)}/instantiate',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return InstantiateSolNetworkInstanceOutput.fromJson(response);
}