listSolFunctionInstances method

Future<ListSolFunctionInstancesOutput> listSolFunctionInstances({
  1. int? maxResults,
  2. String? nextToken,
})

Lists network function instances.

A network function instance is a function in a function package .

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to include in the response.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListSolFunctionInstancesOutput> listSolFunctionInstances({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'nextpage_opaque_marker': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/sol/vnflcm/v1/vnf_instances',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSolFunctionInstancesOutput.fromJson(response);
}