listSolFunctionPackages method

Future<ListSolFunctionPackagesOutput> listSolFunctionPackages({
  1. int? maxResults,
  2. String? nextToken,
})

Lists information about function packages.

A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to include in the response.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListSolFunctionPackagesOutput> listSolFunctionPackages({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'nextpage_opaque_marker': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/sol/vnfpkgm/v1/vnf_packages',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSolFunctionPackagesOutput.fromJson(response);
}