listSolNetworkInstances method

Future<ListSolNetworkInstancesOutput> listSolNetworkInstances({
  1. int? maxResults,
  2. String? nextToken,
})

Lists your network instances.

A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to include in the response.

Parameter nextToken : The token for the next page of results.

Implementation

Future<ListSolNetworkInstancesOutput> listSolNetworkInstances({
  int? maxResults,
  String? nextToken,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'nextpage_opaque_marker': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/sol/nslcm/v1/ns_instances',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSolNetworkInstancesOutput.fromJson(response);
}