listSolNetworkOperations method

Future<ListSolNetworkOperationsOutput> listSolNetworkOperations({
  1. int? maxResults,
  2. String? nextToken,
  3. String? nsInstanceId,
})

Lists details for a network operation, including when the operation started and the status of the operation.

A network operation is any operation that is done to your network, such as network instance instantiation or termination.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter maxResults : The maximum number of results to include in the response.

Parameter nextToken : The token for the next page of results.

Parameter nsInstanceId : Network instance id filter, to retrieve network operations associated to a network instance.

Implementation

Future<ListSolNetworkOperationsOutput> listSolNetworkOperations({
  int? maxResults,
  String? nextToken,
  String? nsInstanceId,
}) async {
  final $query = <String, List<String>>{
    if (maxResults != null) 'max_results': [maxResults.toString()],
    if (nextToken != null) 'nextpage_opaque_marker': [nextToken],
    if (nsInstanceId != null) 'nsInstanceId': [nsInstanceId],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/sol/nslcm/v1/ns_lcm_op_occs',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListSolNetworkOperationsOutput.fromJson(response);
}