listSolNetworkPackages method
Lists network packages.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to include in the response.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListSolNetworkPackagesOutput> listSolNetworkPackages({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'max_results': [maxResults.toString()],
if (nextToken != null) 'nextpage_opaque_marker': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/sol/nsd/v1/ns_descriptors',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSolNetworkPackagesOutput.fromJson(response);
}