updateSolNetworkInstance method
Update a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
Choose the updateType parameter to target the necessary update of the network instance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsInstanceId :
ID of the network instance.
Parameter updateType :
The type of update.
-
Use the
MODIFY_VNF_INFORMATIONupdate type, to update a specific network function configuration, in the network instance. -
Use the
UPDATE_NSupdate type, to update the network instance to a new network service descriptor.
Parameter modifyVnfInfoData :
Identifies the network function information parameters and/or the
configurable properties of the network function to be modified.
Include this property only if the update type is
MODIFY_VNF_INFORMATION.
Parameter tags :
A tag is a label that you assign to an Amazon Web Services resource. Each
tag consists of a key and an optional value. When you use this API, the
tags are only applied to the network operation that is created. These tags
are not applied to the network instance. Use tags to search and filter
your resources or track your Amazon Web Services costs.
Parameter updateNs :
Identifies the network service descriptor and the configurable properties
of the descriptor, to be used for the update.
Include this property only if the update type is UPDATE_NS.
Implementation
Future<UpdateSolNetworkInstanceOutput> updateSolNetworkInstance({
required String nsInstanceId,
required UpdateSolNetworkType updateType,
UpdateSolNetworkModify? modifyVnfInfoData,
Map<String, String>? tags,
UpdateSolNetworkServiceData? updateNs,
}) async {
final $payload = <String, dynamic>{
'updateType': updateType.value,
if (modifyVnfInfoData != null) 'modifyVnfInfoData': modifyVnfInfoData,
if (tags != null) 'tags': tags,
if (updateNs != null) 'updateNs': updateNs,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sol/nslcm/v1/ns_instances/${Uri.encodeComponent(nsInstanceId)}/update',
exceptionFnMap: _exceptionFns,
);
return UpdateSolNetworkInstanceOutput.fromJson(response);
}