updateSolNetworkPackage method

Future<UpdateSolNetworkPackageOutput> updateSolNetworkPackage({
  1. required String nsdInfoId,
  2. required NsdOperationalState nsdOperationalState,
})

Updates the operational state of a network package.

A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.

A network service descriptor is a .yaml file in a network package that uses the TOSCA standard to describe the network functions you want to deploy and the Amazon Web Services infrastructure you want to deploy the network functions on.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nsdInfoId : ID of the network service descriptor in the network package.

Parameter nsdOperationalState : Operational state of the network service descriptor in the network package.

Implementation

Future<UpdateSolNetworkPackageOutput> updateSolNetworkPackage({
  required String nsdInfoId,
  required NsdOperationalState nsdOperationalState,
}) async {
  final $payload = <String, dynamic>{
    'nsdOperationalState': nsdOperationalState.value,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/sol/nsd/v1/ns_descriptors/${Uri.encodeComponent(nsdInfoId)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateSolNetworkPackageOutput.fromJson(response);
}