Transcribe class
Amazon Transcribe offers three main types of batch transcription: Standard, Medical, and Call Analytics.
- Standard transcriptions are the most common option. Refer to for details.
- Medical transcriptions are tailored to medical professionals and incorporate medical terms. A common use case for this service is transcribing doctor-patient dialogue into after-visit notes. Refer to for details.
- Call Analytics transcriptions are designed for use with call center audio on two different channels; if you're looking for insight into customer service calls, use this option. Refer to for details.
Constructors
- Transcribe({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCallAnalyticsCategory(
{required String categoryName, required List< Rule> rules, InputType? inputType, List<Tag> ? tags}) → Future<CreateCallAnalyticsCategoryResponse> - Creates a new Call Analytics category.
-
createLanguageModel(
{required BaseModelName baseModelName, required InputDataConfig inputDataConfig, required CLMLanguageCode languageCode, required String modelName, List< Tag> ? tags}) → Future<CreateLanguageModelResponse> - Creates a new custom language model.
-
createMedicalVocabulary(
{required LanguageCode languageCode, required String vocabularyFileUri, required String vocabularyName, List< Tag> ? tags}) → Future<CreateMedicalVocabularyResponse> - Creates a new custom medical vocabulary.
-
createVocabulary(
{required LanguageCode languageCode, required String vocabularyName, String? dataAccessRoleArn, List< String> ? phrases, List<Tag> ? tags, String? vocabularyFileUri}) → Future<CreateVocabularyResponse> - Creates a new custom vocabulary.
-
createVocabularyFilter(
{required LanguageCode languageCode, required String vocabularyFilterName, String? dataAccessRoleArn, List< Tag> ? tags, String? vocabularyFilterFileUri, List<String> ? words}) → Future<CreateVocabularyFilterResponse> - Creates a new custom vocabulary filter.
-
deleteCallAnalyticsCategory(
{required String categoryName}) → Future< void> -
Deletes a Call Analytics category. To use this operation, specify the name
of the category you want to delete using
CategoryName. Category names are case sensitive. -
deleteCallAnalyticsJob(
{required String callAnalyticsJobName}) → Future< void> -
Deletes a Call Analytics job. To use this operation, specify the name of
the job you want to delete using
CallAnalyticsJobName. Job names are case sensitive. -
deleteLanguageModel(
{required String modelName}) → Future< void> -
Deletes a custom language model. To use this operation, specify the name
of the language model you want to delete using
ModelName. custom language model names are case sensitive. -
deleteMedicalScribeJob(
{required String medicalScribeJobName}) → Future< void> -
Deletes a Medical Scribe job. To use this operation, specify the name of
the job you want to delete using
MedicalScribeJobName. Job names are case sensitive. -
deleteMedicalTranscriptionJob(
{required String medicalTranscriptionJobName}) → Future< void> -
Deletes a medical transcription job. To use this operation, specify the
name of the job you want to delete using
MedicalTranscriptionJobName. Job names are case sensitive. -
deleteMedicalVocabulary(
{required String vocabularyName}) → Future< void> -
Deletes a custom medical vocabulary. To use this operation, specify the
name of the custom vocabulary you want to delete using
VocabularyName. Custom vocabulary names are case sensitive. -
deleteTranscriptionJob(
{required String transcriptionJobName}) → Future< void> -
Deletes a transcription job. To use this operation, specify the name of
the job you want to delete using
TranscriptionJobName. Job names are case sensitive. -
deleteVocabulary(
{required String vocabularyName}) → Future< void> -
Deletes a custom vocabulary. To use this operation, specify the name of
the custom vocabulary you want to delete using
VocabularyName. Custom vocabulary names are case sensitive. -
deleteVocabularyFilter(
{required String vocabularyFilterName}) → Future< void> -
Deletes a custom vocabulary filter. To use this operation, specify the
name of the custom vocabulary filter you want to delete using
VocabularyFilterName. Custom vocabulary filter names are case sensitive. -
describeLanguageModel(
{required String modelName}) → Future< DescribeLanguageModelResponse> - Provides information about the specified custom language model.
-
getCallAnalyticsCategory(
{required String categoryName}) → Future< GetCallAnalyticsCategoryResponse> - Provides information about the specified Call Analytics category.
-
getCallAnalyticsJob(
{required String callAnalyticsJobName}) → Future< GetCallAnalyticsJobResponse> - Provides information about the specified Call Analytics job.
-
getMedicalScribeJob(
{required String medicalScribeJobName}) → Future< GetMedicalScribeJobResponse> - Provides information about the specified Medical Scribe job.
-
getMedicalTranscriptionJob(
{required String medicalTranscriptionJobName}) → Future< GetMedicalTranscriptionJobResponse> - Provides information about the specified medical transcription job.
-
getMedicalVocabulary(
{required String vocabularyName}) → Future< GetMedicalVocabularyResponse> - Provides information about the specified custom medical vocabulary.
-
getTranscriptionJob(
{required String transcriptionJobName}) → Future< GetTranscriptionJobResponse> - Provides information about the specified transcription job.
-
getVocabulary(
{required String vocabularyName}) → Future< GetVocabularyResponse> - Provides information about the specified custom vocabulary.
-
getVocabularyFilter(
{required String vocabularyFilterName}) → Future< GetVocabularyFilterResponse> - Provides information about the specified custom vocabulary filter.
-
listCallAnalyticsCategories(
{int? maxResults, String? nextToken}) → Future< ListCallAnalyticsCategoriesResponse> - Provides a list of Call Analytics categories, including all rules that make up each category.
-
listCallAnalyticsJobs(
{String? jobNameContains, int? maxResults, String? nextToken, CallAnalyticsJobStatus? status}) → Future< ListCallAnalyticsJobsResponse> - Provides a list of Call Analytics jobs that match the specified criteria. If no criteria are specified, all Call Analytics jobs are returned.
-
listLanguageModels(
{int? maxResults, String? nameContains, String? nextToken, ModelStatus? statusEquals}) → Future< ListLanguageModelsResponse> - Provides a list of custom language models that match the specified criteria. If no criteria are specified, all custom language models are returned.
-
listMedicalScribeJobs(
{String? jobNameContains, int? maxResults, String? nextToken, MedicalScribeJobStatus? status}) → Future< ListMedicalScribeJobsResponse> - Provides a list of Medical Scribe jobs that match the specified criteria. If no criteria are specified, all Medical Scribe jobs are returned.
-
listMedicalTranscriptionJobs(
{String? jobNameContains, int? maxResults, String? nextToken, TranscriptionJobStatus? status}) → Future< ListMedicalTranscriptionJobsResponse> - Provides a list of medical transcription jobs that match the specified criteria. If no criteria are specified, all medical transcription jobs are returned.
-
listMedicalVocabularies(
{int? maxResults, String? nameContains, String? nextToken, VocabularyState? stateEquals}) → Future< ListMedicalVocabulariesResponse> - Provides a list of custom medical vocabularies that match the specified criteria. If no criteria are specified, all custom medical vocabularies are returned.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists all tags associated with the specified transcription job, vocabulary, model, or resource.
-
listTranscriptionJobs(
{String? jobNameContains, int? maxResults, String? nextToken, TranscriptionJobStatus? status}) → Future< ListTranscriptionJobsResponse> - Provides a list of transcription jobs that match the specified criteria. If no criteria are specified, all transcription jobs are returned.
-
listVocabularies(
{int? maxResults, String? nameContains, String? nextToken, VocabularyState? stateEquals}) → Future< ListVocabulariesResponse> - Provides a list of custom vocabularies that match the specified criteria. If no criteria are specified, all custom vocabularies are returned.
-
listVocabularyFilters(
{int? maxResults, String? nameContains, String? nextToken}) → Future< ListVocabularyFiltersResponse> - Provides a list of custom vocabulary filters that match the specified criteria. If no criteria are specified, all custom vocabularies are returned.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCallAnalyticsJob(
{required String callAnalyticsJobName, required Media media, List< ChannelDefinition> ? channelDefinitions, String? dataAccessRoleArn, String? outputEncryptionKMSKeyId, String? outputLocation, CallAnalyticsJobSettings? settings, List<Tag> ? tags}) → Future<StartCallAnalyticsJobResponse> - Transcribes the audio from a customer service call and applies any additional Request Parameters you choose to include in your request.
-
startMedicalScribeJob(
{required String dataAccessRoleArn, required Media media, required String medicalScribeJobName, required String outputBucketName, required MedicalScribeSettings settings, List< MedicalScribeChannelDefinition> ? channelDefinitions, Map<String, String> ? kMSEncryptionContext, MedicalScribeContext? medicalScribeContext, String? outputEncryptionKMSKeyId, List<Tag> ? tags}) → Future<StartMedicalScribeJobResponse> - Transcribes patient-clinician conversations and generates clinical notes.
-
startMedicalTranscriptionJob(
{required LanguageCode languageCode, required Media media, required String medicalTranscriptionJobName, required String outputBucketName, required Specialty specialty, required Type type, MedicalContentIdentificationType? contentIdentificationType, Map< String, String> ? kMSEncryptionContext, MediaFormat? mediaFormat, int? mediaSampleRateHertz, String? outputEncryptionKMSKeyId, String? outputKey, MedicalTranscriptionSetting? settings, List<Tag> ? tags}) → Future<StartMedicalTranscriptionJobResponse> - Transcribes the audio from a medical dictation or conversation and applies any additional Request Parameters you choose to include in your request.
-
startTranscriptionJob(
{required Media media, required String transcriptionJobName, ContentRedaction? contentRedaction, bool? identifyLanguage, bool? identifyMultipleLanguages, JobExecutionSettings? jobExecutionSettings, Map< String, String> ? kMSEncryptionContext, LanguageCode? languageCode, Map<LanguageCode, LanguageIdSettings> ? languageIdSettings, List<LanguageCode> ? languageOptions, MediaFormat? mediaFormat, int? mediaSampleRateHertz, ModelSettings? modelSettings, String? outputBucketName, String? outputEncryptionKMSKeyId, String? outputKey, Settings? settings, Subtitles? subtitles, List<Tag> ? tags, List<ToxicityDetectionSettings> ? toxicityDetection}) → Future<StartTranscriptionJobResponse> - Transcribes the audio from a media file and applies any additional Request Parameters you choose to include in your request.
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Adds one or more custom tags, each in the form of a key:value pair, to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the specified Amazon Transcribe resource.
-
updateCallAnalyticsCategory(
{required String categoryName, required List< Rule> rules, InputType? inputType}) → Future<UpdateCallAnalyticsCategoryResponse> -
Updates the specified Call Analytics category with new rules. Note that
the
UpdateCallAnalyticsCategoryoperation overwrites all existing rules contained in the specified category. You cannot append additional rules onto an existing category. -
updateMedicalVocabulary(
{required LanguageCode languageCode, required String vocabularyFileUri, required String vocabularyName}) → Future< UpdateMedicalVocabularyResponse> - Updates an existing custom medical vocabulary with new values. This operation overwrites all existing information with your new values; you cannot append new terms onto an existing custom vocabulary.
-
updateVocabulary(
{required LanguageCode languageCode, required String vocabularyName, String? dataAccessRoleArn, List< String> ? phrases, String? vocabularyFileUri}) → Future<UpdateVocabularyResponse> - Updates an existing custom vocabulary with new values. This operation overwrites all existing information with your new values; you cannot append new terms onto an existing custom vocabulary.
-
updateVocabularyFilter(
{required String vocabularyFilterName, String? dataAccessRoleArn, String? vocabularyFilterFileUri, List< String> ? words}) → Future<UpdateVocabularyFilterResponse> - Updates an existing custom vocabulary filter with a new list of words. The new list you provide overwrites all previous entries; you cannot append new terms onto an existing custom vocabulary filter.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited