createVocabulary method
Creates a new custom vocabulary.
When creating a new custom vocabulary, you can either upload a text file
that contains your new entries, phrases, and terms into an Amazon S3
bucket and include the URI in your request. Or you can include a list of
terms directly in your request using the Phrases flag.
Each language has a character set that contains all allowed characters for that specific language. If you use unsupported characters, your custom vocabulary request fails. Refer to Character Sets for Custom Vocabularies to get the character set for your language.
For more information, see Custom vocabularies.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
Parameter languageCode :
The language code that represents the language of the entries in your
custom vocabulary. Each custom vocabulary must contain terms in only one
language.
A custom vocabulary can only be used to transcribe files in the same
language as the custom vocabulary. For example, if you create a custom
vocabulary using US English (en-US), you can only apply this
custom vocabulary to files that contain English audio.
For a list of supported languages and their associated language codes, refer to the Supported languages table.
Parameter vocabularyName :
A unique name, chosen by you, for your new custom vocabulary.
This name is case sensitive, cannot contain spaces, and must be unique
within an Amazon Web Services account. If you try to create a new custom
vocabulary with the same name as an existing custom vocabulary, you get a
ConflictException error.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of an IAM role that has permissions to
access the Amazon S3 bucket that contains your input files (in this case,
your custom vocabulary). If the role that you specify doesn’t have the
appropriate permissions to access the specified Amazon S3 location, your
request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For
example: arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
Parameter phrases :
Use this parameter if you want to create your custom vocabulary by
including all desired terms, as comma-separated values, within your
request. The other option for creating your custom vocabulary is to save
your entries in a text file and upload them to an Amazon S3 bucket, then
specify the location of your file using the VocabularyFileUri
parameter.
Note that if you include Phrases in your request, you cannot
use VocabularyFileUri; you must choose one or the other.
Each language has a character set that contains all allowed characters for that specific language. If you use unsupported characters, your custom vocabulary filter request fails. Refer to Character Sets for Custom Vocabularies to get the character set for your language.
Parameter tags :
Adds one or more custom tags, each in the form of a key:value pair, to a
new custom vocabulary at the time you create this new custom vocabulary.
To learn more about using tags with Amazon Transcribe, refer to Tagging resources.
Parameter vocabularyFileUri :
The Amazon S3 location of the text file that contains your custom
vocabulary. The URI must be located in the same Amazon Web Services Region
as the resource you're calling.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-vocab-file.txt
Note that if you include VocabularyFileUri in your request,
you cannot use the Phrases flag; you must choose one or the
other.
Implementation
Future<CreateVocabularyResponse> createVocabulary({
required LanguageCode languageCode,
required String vocabularyName,
String? dataAccessRoleArn,
List<String>? phrases,
List<Tag>? tags,
String? vocabularyFileUri,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.CreateVocabulary'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'LanguageCode': languageCode.value,
'VocabularyName': vocabularyName,
if (dataAccessRoleArn != null) 'DataAccessRoleArn': dataAccessRoleArn,
if (phrases != null) 'Phrases': phrases,
if (tags != null) 'Tags': tags,
if (vocabularyFileUri != null) 'VocabularyFileUri': vocabularyFileUri,
},
);
return CreateVocabularyResponse.fromJson(jsonResponse.body);
}