deleteCallAnalyticsJob method

Future<void> deleteCallAnalyticsJob({
  1. required String callAnalyticsJobName,
})

Deletes a Call Analytics job. To use this operation, specify the name of the job you want to delete using CallAnalyticsJobName. Job names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter callAnalyticsJobName : The name of the Call Analytics job you want to delete. Job names are case sensitive.

Implementation

Future<void> deleteCallAnalyticsJob({
  required String callAnalyticsJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteCallAnalyticsJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CallAnalyticsJobName': callAnalyticsJobName,
    },
  );
}