deleteLanguageModel method

Future<void> deleteLanguageModel({
  1. required String modelName,
})

Deletes a custom language model. To use this operation, specify the name of the language model you want to delete using ModelName. custom language model names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter modelName : The name of the custom language model you want to delete. Model names are case sensitive.

Implementation

Future<void> deleteLanguageModel({
  required String modelName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteLanguageModel'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ModelName': modelName,
    },
  );
}