deleteMedicalScribeJob method

Future<void> deleteMedicalScribeJob({
  1. required String medicalScribeJobName,
})

Deletes a Medical Scribe job. To use this operation, specify the name of the job you want to delete using MedicalScribeJobName. Job names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter medicalScribeJobName : The name of the Medical Scribe job you want to delete. Job names are case sensitive.

Implementation

Future<void> deleteMedicalScribeJob({
  required String medicalScribeJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteMedicalScribeJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MedicalScribeJobName': medicalScribeJobName,
    },
  );
}