deleteMedicalTranscriptionJob method

Future<void> deleteMedicalTranscriptionJob({
  1. required String medicalTranscriptionJobName,
})

Deletes a medical transcription job. To use this operation, specify the name of the job you want to delete using MedicalTranscriptionJobName. Job names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter medicalTranscriptionJobName : The name of the medical transcription job you want to delete. Job names are case sensitive.

Implementation

Future<void> deleteMedicalTranscriptionJob({
  required String medicalTranscriptionJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteMedicalTranscriptionJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MedicalTranscriptionJobName': medicalTranscriptionJobName,
    },
  );
}