deleteTranscriptionJob method

Future<void> deleteTranscriptionJob({
  1. required String transcriptionJobName,
})

Deletes a transcription job. To use this operation, specify the name of the job you want to delete using TranscriptionJobName. Job names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter transcriptionJobName : The name of the transcription job you want to delete. Job names are case sensitive.

Implementation

Future<void> deleteTranscriptionJob({
  required String transcriptionJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteTranscriptionJob'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TranscriptionJobName': transcriptionJobName,
    },
  );
}