deleteVocabularyFilter method

Future<void> deleteVocabularyFilter({
  1. required String vocabularyFilterName,
})

Deletes a custom vocabulary filter. To use this operation, specify the name of the custom vocabulary filter you want to delete using VocabularyFilterName. Custom vocabulary filter names are case sensitive.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter vocabularyFilterName : The name of the custom vocabulary filter you want to delete. Custom vocabulary filter names are case sensitive.

Implementation

Future<void> deleteVocabularyFilter({
  required String vocabularyFilterName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.DeleteVocabularyFilter'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'VocabularyFilterName': vocabularyFilterName,
    },
  );
}