getCallAnalyticsCategory method

Future<GetCallAnalyticsCategoryResponse> getCallAnalyticsCategory({
  1. required String categoryName,
})

Provides information about the specified Call Analytics category.

To get a list of your Call Analytics categories, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter categoryName : The name of the Call Analytics category you want information about. Category names are case sensitive.

Implementation

Future<GetCallAnalyticsCategoryResponse> getCallAnalyticsCategory({
  required String categoryName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.GetCallAnalyticsCategory'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CategoryName': categoryName,
    },
  );

  return GetCallAnalyticsCategoryResponse.fromJson(jsonResponse.body);
}