getMedicalScribeJob method

Future<GetMedicalScribeJobResponse> getMedicalScribeJob({
  1. required String medicalScribeJobName,
})

Provides information about the specified Medical Scribe job.

To view the status of the specified medical transcription job, check the MedicalScribeJobStatus field. If the status is COMPLETED, the job is finished. You can find the results at the location specified in MedicalScribeOutput. If the status is FAILED, FailureReason provides details on why your Medical Scribe job failed.

To get a list of your Medical Scribe jobs, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter medicalScribeJobName : The name of the Medical Scribe job you want information about. Job names are case sensitive.

Implementation

Future<GetMedicalScribeJobResponse> getMedicalScribeJob({
  required String medicalScribeJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.GetMedicalScribeJob'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MedicalScribeJobName': medicalScribeJobName,
    },
  );

  return GetMedicalScribeJobResponse.fromJson(jsonResponse.body);
}