getMedicalVocabulary method

Future<GetMedicalVocabularyResponse> getMedicalVocabulary({
  1. required String vocabularyName,
})

Provides information about the specified custom medical vocabulary.

To view the status of the specified custom medical vocabulary, check the VocabularyState field. If the status is READY, your custom vocabulary is available to use. If the status is FAILED, FailureReason provides details on why your vocabulary failed.

To get a list of your custom medical vocabularies, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter vocabularyName : The name of the custom medical vocabulary you want information about. Custom medical vocabulary names are case sensitive.

Implementation

Future<GetMedicalVocabularyResponse> getMedicalVocabulary({
  required String vocabularyName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.GetMedicalVocabulary'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'VocabularyName': vocabularyName,
    },
  );

  return GetMedicalVocabularyResponse.fromJson(jsonResponse.body);
}