getTranscriptionJob method

Future<GetTranscriptionJobResponse> getTranscriptionJob({
  1. required String transcriptionJobName,
})

Provides information about the specified transcription job.

To view the status of the specified transcription job, check the TranscriptionJobStatus field. If the status is COMPLETED, the job is finished. You can find the results at the location specified in TranscriptFileUri. If the status is FAILED, FailureReason provides details on why your transcription job failed.

If you enabled content redaction, the redacted transcript can be found at the location specified in RedactedTranscriptFileUri.

To get a list of your transcription jobs, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter transcriptionJobName : The name of the transcription job you want information about. Job names are case sensitive.

Implementation

Future<GetTranscriptionJobResponse> getTranscriptionJob({
  required String transcriptionJobName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.GetTranscriptionJob'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'TranscriptionJobName': transcriptionJobName,
    },
  );

  return GetTranscriptionJobResponse.fromJson(jsonResponse.body);
}