getVocabularyFilter method

Future<GetVocabularyFilterResponse> getVocabularyFilter({
  1. required String vocabularyFilterName,
})

Provides information about the specified custom vocabulary filter.

To get a list of your custom vocabulary filters, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw NotFoundException.

Parameter vocabularyFilterName : The name of the custom vocabulary filter you want information about. Custom vocabulary filter names are case sensitive.

Implementation

Future<GetVocabularyFilterResponse> getVocabularyFilter({
  required String vocabularyFilterName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.GetVocabularyFilter'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'VocabularyFilterName': vocabularyFilterName,
    },
  );

  return GetVocabularyFilterResponse.fromJson(jsonResponse.body);
}