listCallAnalyticsCategories method

Future<ListCallAnalyticsCategoriesResponse> listCallAnalyticsCategories({
  1. int? maxResults,
  2. String? nextToken,
})

Provides a list of Call Analytics categories, including all rules that make up each category.

To get detailed information about a specific Call Analytics category, use the operation.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException.

Parameter maxResults : The maximum number of Call Analytics categories to return in each page of results. If there are fewer results than the value that you specify, only the actual results are returned. If you do not specify a value, a default of 5 is used.

Parameter nextToken : If your ListCallAnalyticsCategories request returns more results than can be displayed, NextToken is displayed in the response with an associated string. To get the next page of results, copy this string and repeat your request, including NextToken with the value of the copied string. Repeat as needed to view all your results.

Implementation

Future<ListCallAnalyticsCategoriesResponse> listCallAnalyticsCategories({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'Transcribe.ListCallAnalyticsCategories'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListCallAnalyticsCategoriesResponse.fromJson(jsonResponse.body);
}