startCallAnalyticsJob method
Transcribes the audio from a customer service call and applies any additional Request Parameters you choose to include in your request.
In addition to many standard transcription features, Call Analytics provides you with call characteristics, call summarization, speaker sentiment, and optional redaction of your text transcript and your audio file. You can also apply custom categories to flag specified conditions. To learn more about these features and insights, refer to Analyzing call center audio with Call Analytics.
If you want to apply categories to your Call Analytics job, you must create them before submitting your job request. Categories cannot be retroactively applied to a job. To create a new category, use the operation. To learn more about Call Analytics categories, see Creating categories for post-call transcriptions and Creating categories for real-time transcriptions.
To make a StartCallAnalyticsJob request, you must first
upload your media file into an Amazon S3 bucket; you can then specify the
Amazon S3 location of the file using the Media parameter.
Job queuing is available for Call Analytics jobs. If you pass a
DataAccessRoleArn in your request and you exceed your
Concurrent Job Limit, your job will automatically be added to a queue to
be processed once your concurrent job count is below the limit.
You must include the following parameters in your
StartCallAnalyticsJob request:
-
region: The Amazon Web Services Region where you are making your request. For a list of Amazon Web Services Regions supported with Amazon Transcribe, refer to Amazon Transcribe endpoints and quotas. -
CallAnalyticsJobName: A custom name that you create for your transcription job that's unique within your Amazon Web Services account. -
Media(MediaFileUriorRedactedMediaFileUri): The Amazon S3 location of your media file.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
Parameter callAnalyticsJobName :
A unique name, chosen by you, for your Call Analytics job.
This name is case sensitive, cannot contain spaces, and must be unique
within an Amazon Web Services account. If you try to create a new job with
the same name as an existing job, you get a ConflictException
error.
Parameter media :
Describes the Amazon S3 location of the media file you want to use in your
Call Analytics request.
Parameter channelDefinitions :
Makes it possible to specify which speaker is on which channel. For
example, if your agent is the first participant to speak, you would set
ChannelId to 0 (to indicate the first channel)
and ParticipantRole to AGENT (to indicate that
it's the agent speaking).
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of an IAM role that has permissions to
access the Amazon S3 bucket that contains your input files. If the role
that you specify doesn’t have the appropriate permissions to access the
specified Amazon S3 location, your request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For
example: arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
Parameter outputEncryptionKMSKeyId :
The Amazon Resource Name (ARN) of a KMS key that you want to use to
encrypt your Call Analytics output.
KMS key ARNs have the format
arn:partition:kms:region:account:key/key-id. For example:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.
For more information, see
KMS key ARNs.
If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3).
Note that the role making the request and the role specified in the
DataAccessRoleArn request parameter (if present) must have
permission to use the specified KMS key.
Parameter outputLocation :
The Amazon S3 location where you want your Call Analytics transcription
output stored. You can use any of the following formats to specify the
output location:
- s3://DOC-EXAMPLE-BUCKET
- s3://DOC-EXAMPLE-BUCKET/my-output-folder/
- s3://DOC-EXAMPLE-BUCKET/my-output-folder/my-call-analytics-job.json
CallAnalyticsJobName parameter.
You can specify a KMS key to encrypt your output using the
OutputEncryptionKMSKeyId parameter. If you do not specify a
KMS key, Amazon Transcribe uses the default Amazon S3 key for server-side
encryption.
If you do not specify OutputLocation, your transcript is
placed in a service-managed Amazon S3 bucket and you are provided with a
URI to access your transcript.
Parameter settings :
Specify additional optional settings in your request, including content
redaction; allows you to apply custom language models, vocabulary filters,
and custom vocabularies to your Call Analytics job.
Parameter tags :
Adds one or more custom tags, each in the form of a key:value pair, to a
new call analytics job at the time you start this new job.
To learn more about using tags with Amazon Transcribe, refer to Tagging resources.
Implementation
Future<StartCallAnalyticsJobResponse> startCallAnalyticsJob({
required String callAnalyticsJobName,
required Media media,
List<ChannelDefinition>? channelDefinitions,
String? dataAccessRoleArn,
String? outputEncryptionKMSKeyId,
String? outputLocation,
CallAnalyticsJobSettings? settings,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.StartCallAnalyticsJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CallAnalyticsJobName': callAnalyticsJobName,
'Media': media,
if (channelDefinitions != null)
'ChannelDefinitions': channelDefinitions,
if (dataAccessRoleArn != null) 'DataAccessRoleArn': dataAccessRoleArn,
if (outputEncryptionKMSKeyId != null)
'OutputEncryptionKMSKeyId': outputEncryptionKMSKeyId,
if (outputLocation != null) 'OutputLocation': outputLocation,
if (settings != null) 'Settings': settings,
if (tags != null) 'Tags': tags,
},
);
return StartCallAnalyticsJobResponse.fromJson(jsonResponse.body);
}