startTranscriptionJob method
- required Media media,
- required String transcriptionJobName,
- ContentRedaction? contentRedaction,
- bool? identifyLanguage,
- bool? identifyMultipleLanguages,
- JobExecutionSettings? jobExecutionSettings,
- Map<
String, String> ? kMSEncryptionContext, - LanguageCode? languageCode,
- Map<
LanguageCode, LanguageIdSettings> ? languageIdSettings, - List<
LanguageCode> ? languageOptions, - MediaFormat? mediaFormat,
- int? mediaSampleRateHertz,
- ModelSettings? modelSettings,
- String? outputBucketName,
- String? outputEncryptionKMSKeyId,
- String? outputKey,
- Settings? settings,
- Subtitles? subtitles,
- List<
Tag> ? tags, - List<
ToxicityDetectionSettings> ? toxicityDetection,
Transcribes the audio from a media file and applies any additional Request Parameters you choose to include in your request.
To make a StartTranscriptionJob request, you must first
upload your media file into an Amazon S3 bucket; you can then specify the
Amazon S3 location of the file using the Media parameter.
You must include the following parameters in your
StartTranscriptionJob request:
-
region: The Amazon Web Services Region where you are making your request. For a list of Amazon Web Services Regions supported with Amazon Transcribe, refer to Amazon Transcribe endpoints and quotas. -
TranscriptionJobName: A custom name you create for your transcription job that is unique within your Amazon Web Services account. -
Media(MediaFileUri): The Amazon S3 location of your media file. -
One of
LanguageCode,IdentifyLanguage, orIdentifyMultipleLanguages: If you know the language of your media file, specify it using theLanguageCodeparameter; you can find all valid language codes in the Supported languages table. If you do not know the languages spoken in your media, use eitherIdentifyLanguageorIdentifyMultipleLanguagesand let Amazon Transcribe identify the languages for you.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
Parameter media :
Describes the Amazon S3 location of the media file you want to use in your
request.
Parameter transcriptionJobName :
A unique name, chosen by you, for your transcription job. The name that
you specify is also used as the default name of your transcription output
file. If you want to specify a different name for your transcription
output, use the OutputKey parameter.
This name is case sensitive, cannot contain spaces, and must be unique
within an Amazon Web Services account. If you try to create a new job with
the same name as an existing job, you get a ConflictException
error.
Parameter contentRedaction :
Makes it possible to redact or flag specified personally identifiable
information (PII) in your transcript. If you use
ContentRedaction, you must also include the sub-parameters:
RedactionOutput and RedactionType. You can
optionally include PiiEntityTypes to choose which types of
PII you want to redact. If you do not include PiiEntityTypes
in your request, all PII is redacted.
Parameter identifyLanguage :
Enables automatic language identification in your transcription job
request. Use this parameter if your media file contains only one language.
If your media contains multiple languages, use
IdentifyMultipleLanguages instead.
If you include IdentifyLanguage, you can optionally include a
list of language codes, using LanguageOptions, that you think
may be present in your media file. Including LanguageOptions
restricts IdentifyLanguage to only the language options that
you specify, which can improve transcription accuracy.
If you want to apply a custom language model, a custom vocabulary, or a
custom vocabulary filter to your automatic language identification
request, include LanguageIdSettings with the relevant
sub-parameters (VocabularyName,
LanguageModelName, and VocabularyFilterName). If
you include LanguageIdSettings, also include
LanguageOptions.
Note that you must include one of LanguageCode,
IdentifyLanguage, or IdentifyMultipleLanguages
in your request. If you include more than one of these parameters, your
transcription job fails.
Parameter identifyMultipleLanguages :
Enables automatic multi-language identification in your transcription job
request. Use this parameter if your media file contains more than one
language. If your media contains only one language, use
IdentifyLanguage instead.
If you include IdentifyMultipleLanguages, you can optionally
include a list of language codes, using LanguageOptions, that
you think may be present in your media file. Including
LanguageOptions restricts IdentifyLanguage to
only the language options that you specify, which can improve
transcription accuracy.
If you want to apply a custom vocabulary or a custom vocabulary filter to
your automatic language identification request, include
LanguageIdSettings with the relevant sub-parameters
(VocabularyName and VocabularyFilterName). If
you include LanguageIdSettings, also include
LanguageOptions.
Note that you must include one of LanguageCode,
IdentifyLanguage, or IdentifyMultipleLanguages
in your request. If you include more than one of these parameters, your
transcription job fails.
Parameter jobExecutionSettings :
Makes it possible to control how your transcription job is processed.
Currently, the only JobExecutionSettings modification you can
choose is enabling job queueing using the
AllowDeferredExecution sub-parameter.
If you include JobExecutionSettings in your request, you must
also include the sub-parameters: AllowDeferredExecution and
DataAccessRoleArn.
Parameter kMSEncryptionContext :
A map of plain text, non-secret key:value pairs, known as encryption
context pairs, that provide an added layer of security for your data. For
more information, see KMS
encryption context and Asymmetric
keys in KMS.
Parameter languageCode :
The language code that represents the language spoken in the input media
file.
If you're unsure of the language spoken in your media file, consider using
IdentifyLanguage or IdentifyMultipleLanguages to
enable automatic language identification.
Note that you must include one of LanguageCode,
IdentifyLanguage, or IdentifyMultipleLanguages
in your request. If you include more than one of these parameters, your
transcription job fails.
For a list of supported languages and their associated language codes, refer to the Supported languages table.
Parameter languageIdSettings :
If using automatic language identification in your request and you want to
apply a custom language model, a custom vocabulary, or a custom vocabulary
filter, include LanguageIdSettings with the relevant
sub-parameters (VocabularyName,
LanguageModelName, and VocabularyFilterName).
Note that multi-language identification
(IdentifyMultipleLanguages) doesn't support custom language
models.
LanguageIdSettings supports two to five language codes. Each
language code you include can have an associated custom language model,
custom vocabulary, and custom vocabulary filter. The language codes that
you specify must match the languages of the associated custom language
models, custom vocabularies, and custom vocabulary filters.
It's recommended that you include LanguageOptions when using
LanguageIdSettings to ensure that the correct language
dialect is identified. For example, if you specify a custom vocabulary
that is in en-US but Amazon Transcribe determines that the
language spoken in your media is en-AU, your custom
vocabulary is not applied to your transcription. If you include
LanguageOptions and include en-US as the only
English language dialect, your custom vocabulary is applied to your
transcription.
If you want to include a custom language model with your request but do
not want to use automatic language identification, use instead the
parameter with the LanguageModelName
sub-parameter. If you want to include a custom vocabulary or a custom
vocabulary filter (or both) with your request but do not want to
use automatic language identification, use instead the
parameter with the VocabularyName or
VocabularyFilterName (or both) sub-parameter.
Parameter languageOptions :
You can specify two or more language codes that represent the languages
you think may be present in your media. Including more than five is not
recommended. If you're unsure what languages are present, do not include
this parameter.
If you include LanguageOptions in your request, you must also
include IdentifyLanguage.
For more information, refer to Supported languages.
To transcribe speech in Modern Standard Arabic (ar-SA)in
Amazon Web Services GovCloud (US) (US-West, us-gov-west-1), Amazon Web
Services GovCloud (US) (US-East, us-gov-east-1), in Canada (Calgary)
ca-west-1 and Africa (Cape Town) af-south-1, your media file must be
encoded at a sample rate of 16,000 Hz or higher.
Parameter mediaFormat :
Specify the format of your input media file.
Parameter mediaSampleRateHertz :
The sample rate, in hertz, of the audio track in your input media file.
If you do not specify the media sample rate, Amazon Transcribe determines
it for you. If you specify the sample rate, it must match the rate
detected by Amazon Transcribe. If there's a mismatch between the value
that you specify and the value detected, your job fails. In most cases,
you can omit MediaSampleRateHertz and let Amazon Transcribe
determine the sample rate.
Parameter modelSettings :
Specify the custom language model you want to include with your
transcription job. If you include ModelSettings in your
request, you must include the LanguageModelName
sub-parameter.
For more information, see Custom language models.
Parameter outputBucketName :
The name of the Amazon S3 bucket where you want your transcription output
stored. Do not include the S3:// prefix of the specified
bucket.
If you want your output to go to a sub-folder of this bucket, specify it
using the OutputKey parameter; OutputBucketName
only accepts the name of a bucket.
For example, if you want your output stored in
S3://DOC-EXAMPLE-BUCKET, set OutputBucketName to
DOC-EXAMPLE-BUCKET. However, if you want your output stored
in S3://DOC-EXAMPLE-BUCKET/test-files/, set
OutputBucketName to DOC-EXAMPLE-BUCKET and
OutputKey to test-files/.
Note that Amazon Transcribe must have permission to use the specified location. You can change Amazon S3 permissions using the Amazon Web Services Management Console. See also Permissions Required for IAM User Roles.
If you do not specify OutputBucketName, your transcript is
placed in a service-managed Amazon S3 bucket and you are provided with a
URI to access your transcript.
Parameter outputEncryptionKMSKeyId :
The Amazon Resource Name (ARN) of a KMS key that you want to use to
encrypt your transcription output.
KMS key ARNs have the format
arn:partition:kms:region:account:key/key-id. For example:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.
For more information, see
KMS key ARNs.
If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3).
Note that the role making the request and the role specified in the
DataAccessRoleArn request parameter (if present) must have
permission to use the specified KMS key.
Parameter outputKey :
Use in combination with OutputBucketName to specify the
output location of your transcript and, optionally, a unique name for your
output file. The default name for your transcription output is the same as
the name you specified for your transcription job
(TranscriptionJobName).
Here are some examples of how you can use OutputKey:
-
If you specify 'DOC-EXAMPLE-BUCKET' as the
OutputBucketNameand 'my-transcript.json' as theOutputKey, your transcription output path iss3://DOC-EXAMPLE-BUCKET/my-transcript.json. -
If you specify 'my-first-transcription' as the
TranscriptionJobName, 'DOC-EXAMPLE-BUCKET' as theOutputBucketName, and 'my-transcript' as theOutputKey, your transcription output path iss3://DOC-EXAMPLE-BUCKET/my-transcript/my-first-transcription.json. -
If you specify 'DOC-EXAMPLE-BUCKET' as the
OutputBucketNameand 'test-files/my-transcript.json' as theOutputKey, your transcription output path iss3://DOC-EXAMPLE-BUCKET/test-files/my-transcript.json. -
If you specify 'my-first-transcription' as the
TranscriptionJobName, 'DOC-EXAMPLE-BUCKET' as theOutputBucketName, and 'test-files/my-transcript' as theOutputKey, your transcription output path iss3://DOC-EXAMPLE-BUCKET/test-files/my-transcript/my-first-transcription.json.
Parameter settings :
Specify additional optional settings in your request, including channel
identification, alternative transcriptions, speaker partitioning. You can
use that to apply custom vocabularies and vocabulary filters.
If you want to include a custom vocabulary or a custom vocabulary filter
(or both) with your request but do not want to use automatic
language identification, use Settings with the
VocabularyName or VocabularyFilterName (or both)
sub-parameter.
If you're using automatic language identification with your request and
want to include a custom language model, a custom vocabulary, or a custom
vocabulary filter, use instead the parameter with the
LanguageModelName, VocabularyName or
VocabularyFilterName sub-parameters.
Parameter subtitles :
Produces subtitle files for your input media. You can specify WebVTT
(.vtt) and SubRip (.srt) formats.
Parameter tags :
Adds one or more custom tags, each in the form of a key:value pair, to a
new transcription job at the time you start this new job.
To learn more about using tags with Amazon Transcribe, refer to Tagging resources.
Parameter toxicityDetection :
Enables toxic speech detection in your transcript. If you include
ToxicityDetection in your request, you must also include
ToxicityCategories.
For information on the types of toxic speech Amazon Transcribe can detect, see Detecting toxic speech.
Implementation
Future<StartTranscriptionJobResponse> startTranscriptionJob({
required Media media,
required String transcriptionJobName,
ContentRedaction? contentRedaction,
bool? identifyLanguage,
bool? identifyMultipleLanguages,
JobExecutionSettings? jobExecutionSettings,
Map<String, String>? kMSEncryptionContext,
LanguageCode? languageCode,
Map<LanguageCode, LanguageIdSettings>? languageIdSettings,
List<LanguageCode>? languageOptions,
MediaFormat? mediaFormat,
int? mediaSampleRateHertz,
ModelSettings? modelSettings,
String? outputBucketName,
String? outputEncryptionKMSKeyId,
String? outputKey,
Settings? settings,
Subtitles? subtitles,
List<Tag>? tags,
List<ToxicityDetectionSettings>? toxicityDetection,
}) async {
_s.validateNumRange(
'mediaSampleRateHertz',
mediaSampleRateHertz,
8000,
48000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.StartTranscriptionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Media': media,
'TranscriptionJobName': transcriptionJobName,
if (contentRedaction != null) 'ContentRedaction': contentRedaction,
if (identifyLanguage != null) 'IdentifyLanguage': identifyLanguage,
if (identifyMultipleLanguages != null)
'IdentifyMultipleLanguages': identifyMultipleLanguages,
if (jobExecutionSettings != null)
'JobExecutionSettings': jobExecutionSettings,
if (kMSEncryptionContext != null)
'KMSEncryptionContext': kMSEncryptionContext,
if (languageCode != null) 'LanguageCode': languageCode.value,
if (languageIdSettings != null)
'LanguageIdSettings':
languageIdSettings.map((k, e) => MapEntry(k.value, e)),
if (languageOptions != null)
'LanguageOptions': languageOptions.map((e) => e.value).toList(),
if (mediaFormat != null) 'MediaFormat': mediaFormat.value,
if (mediaSampleRateHertz != null)
'MediaSampleRateHertz': mediaSampleRateHertz,
if (modelSettings != null) 'ModelSettings': modelSettings,
if (outputBucketName != null) 'OutputBucketName': outputBucketName,
if (outputEncryptionKMSKeyId != null)
'OutputEncryptionKMSKeyId': outputEncryptionKMSKeyId,
if (outputKey != null) 'OutputKey': outputKey,
if (settings != null) 'Settings': settings,
if (subtitles != null) 'Subtitles': subtitles,
if (tags != null) 'Tags': tags,
if (toxicityDetection != null) 'ToxicityDetection': toxicityDetection,
},
);
return StartTranscriptionJobResponse.fromJson(jsonResponse.body);
}