updateVocabulary method
Updates an existing custom vocabulary with new values. This operation overwrites all existing information with your new values; you cannot append new terms onto an existing custom vocabulary.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter languageCode :
The language code that represents the language of the entries in the
custom vocabulary you want to update. Each custom vocabulary must contain
terms in only one language.
A custom vocabulary can only be used to transcribe files in the same
language as the custom vocabulary. For example, if you create a custom
vocabulary using US English (en-US), you can only apply this
custom vocabulary to files that contain English audio.
For a list of supported languages and their associated language codes, refer to the Supported languages table.
Parameter vocabularyName :
The name of the custom vocabulary you want to update. Custom vocabulary
names are case sensitive.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of an IAM role that has permissions to
access the Amazon S3 bucket that contains your input files (in this case,
your custom vocabulary). If the role that you specify doesn’t have the
appropriate permissions to access the specified Amazon S3 location, your
request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For
example: arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
Parameter phrases :
Use this parameter if you want to update your custom vocabulary by
including all desired terms, as comma-separated values, within your
request. The other option for updating your custom vocabulary is to save
your entries in a text file and upload them to an Amazon S3 bucket, then
specify the location of your file using the VocabularyFileUri
parameter.
Note that if you include Phrases in your request, you cannot
use VocabularyFileUri; you must choose one or the other.
Each language has a character set that contains all allowed characters for that specific language. If you use unsupported characters, your custom vocabulary filter request fails. Refer to Character Sets for Custom Vocabularies to get the character set for your language.
Parameter vocabularyFileUri :
The Amazon S3 location of the text file that contains your custom
vocabulary. The URI must be located in the same Amazon Web Services Region
as the resource you're calling.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-vocab-file.txt
Note that if you include VocabularyFileUri in your request,
you cannot use the Phrases flag; you must choose one or the
other.
Implementation
Future<UpdateVocabularyResponse> updateVocabulary({
required LanguageCode languageCode,
required String vocabularyName,
String? dataAccessRoleArn,
List<String>? phrases,
String? vocabularyFileUri,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.UpdateVocabulary'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'LanguageCode': languageCode.value,
'VocabularyName': vocabularyName,
if (dataAccessRoleArn != null) 'DataAccessRoleArn': dataAccessRoleArn,
if (phrases != null) 'Phrases': phrases,
if (vocabularyFileUri != null) 'VocabularyFileUri': vocabularyFileUri,
},
);
return UpdateVocabularyResponse.fromJson(jsonResponse.body);
}