updateVocabularyFilter method
Updates an existing custom vocabulary filter with a new list of words. The new list you provide overwrites all previous entries; you cannot append new terms onto an existing custom vocabulary filter.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter vocabularyFilterName :
The name of the custom vocabulary filter you want to update. Custom
vocabulary filter names are case sensitive.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of an IAM role that has permissions to
access the Amazon S3 bucket that contains your input files (in this case,
your custom vocabulary filter). If the role that you specify doesn’t have
the appropriate permissions to access the specified Amazon S3 location,
your request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For
example: arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
Parameter vocabularyFilterFileUri :
The Amazon S3 location of the text file that contains your custom
vocabulary filter terms. The URI must be located in the same Amazon Web
Services Region as the resource you're calling.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-vocab-filter-file.txt
Note that if you include VocabularyFilterFileUri in your
request, you cannot use Words; you must choose one or the
other.
Parameter words :
Use this parameter if you want to update your custom vocabulary filter by
including all desired terms, as comma-separated values, within your
request. The other option for updating your vocabulary filter is to save
your entries in a text file and upload them to an Amazon S3 bucket, then
specify the location of your file using the
VocabularyFilterFileUri parameter.
Note that if you include Words in your request, you cannot
use VocabularyFilterFileUri; you must choose one or the
other.
Each language has a character set that contains all allowed characters for that specific language. If you use unsupported characters, your custom vocabulary filter request fails. Refer to Character Sets for Custom Vocabularies to get the character set for your language.
Implementation
Future<UpdateVocabularyFilterResponse> updateVocabularyFilter({
required String vocabularyFilterName,
String? dataAccessRoleArn,
String? vocabularyFilterFileUri,
List<String>? words,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.UpdateVocabularyFilter'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'VocabularyFilterName': vocabularyFilterName,
if (dataAccessRoleArn != null) 'DataAccessRoleArn': dataAccessRoleArn,
if (vocabularyFilterFileUri != null)
'VocabularyFilterFileUri': vocabularyFilterFileUri,
if (words != null) 'Words': words,
},
);
return UpdateVocabularyFilterResponse.fromJson(jsonResponse.body);
}