TranscribeStreaming class

Amazon Transcribe streaming offers four main types of real-time transcription: Standard, Medical, Call Analytics, and Health Scribe.

  • Standard transcriptions are the most common option. Refer to for details.
  • Medical transcriptions are tailored to medical professionals and incorporate medical terms. A common use case for this service is transcribing doctor-patient dialogue in real time, so doctors can focus on their patient instead of taking notes. Refer to for details.
  • Call Analytics transcriptions are designed for use with call center audio on two different channels; if you're looking for insight into customer service calls, use this option. Refer to for details.
  • HealthScribe transcriptions are designed to automatically create clinical notes from patient-clinician conversations using generative AI. Refer to \[here\] for details.

Constructors

TranscribeStreaming({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getMedicalScribeStream({required String sessionId}) Future<GetMedicalScribeStreamResponse>
Provides details about the specified Amazon Web Services HealthScribe streaming session. To view the status of the streaming session, check the StreamStatus field in the response. To get the details of post-stream analytics, including its status, check the PostStreamAnalyticsResult field in the response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCallAnalyticsStreamTranscription({required AudioStream audioStream, required MediaEncoding mediaEncoding, required int mediaSampleRateHertz, ContentIdentificationType? contentIdentificationType, ContentRedactionType? contentRedactionType, bool? enablePartialResultsStabilization, bool? identifyLanguage, CallAnalyticsLanguageCode? languageCode, String? languageModelName, String? languageOptions, PartialResultsStability? partialResultsStability, String? piiEntityTypes, CallAnalyticsLanguageCode? preferredLanguage, String? sessionId, VocabularyFilterMethod? vocabularyFilterMethod, String? vocabularyFilterName, String? vocabularyFilterNames, String? vocabularyName, String? vocabularyNames}) Future<StartCallAnalyticsStreamTranscriptionResponse>
Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to Amazon Transcribe and the transcription results are streamed to your application. Use this operation for Call Analytics transcriptions.
startMedicalScribeStream({required MedicalScribeInputStream inputStream, required MedicalScribeLanguageCode languageCode, required MedicalScribeMediaEncoding mediaEncoding, required int mediaSampleRateHertz, String? sessionId}) Future<StartMedicalScribeStreamResponse>
Starts a bidirectional HTTP/2 stream, where audio is streamed to Amazon Web Services HealthScribe and the transcription results are streamed to your application.
startMedicalStreamTranscription({required AudioStream audioStream, required LanguageCode languageCode, required MediaEncoding mediaEncoding, required int mediaSampleRateHertz, required Specialty specialty, required Type type, MedicalContentIdentificationType? contentIdentificationType, bool? enableChannelIdentification, int? numberOfChannels, String? sessionId, bool? showSpeakerLabel, String? vocabularyName}) Future<StartMedicalStreamTranscriptionResponse>
Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to Amazon Transcribe Medical and the transcription results are streamed to your application.
startStreamTranscription({required AudioStream audioStream, required MediaEncoding mediaEncoding, required int mediaSampleRateHertz, ContentIdentificationType? contentIdentificationType, ContentRedactionType? contentRedactionType, bool? enableChannelIdentification, bool? enablePartialResultsStabilization, bool? identifyLanguage, bool? identifyMultipleLanguages, LanguageCode? languageCode, String? languageModelName, String? languageOptions, int? numberOfChannels, PartialResultsStability? partialResultsStability, String? piiEntityTypes, LanguageCode? preferredLanguage, String? sessionId, int? sessionResumeWindow, bool? showSpeakerLabel, VocabularyFilterMethod? vocabularyFilterMethod, String? vocabularyFilterName, String? vocabularyFilterNames, String? vocabularyName, String? vocabularyNames}) Future<StartStreamTranscriptionResponse>
Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to Amazon Transcribe and the transcription results are streamed to your application.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited