getMedicalScribeStream method

Future<GetMedicalScribeStreamResponse> getMedicalScribeStream({
  1. required String sessionId,
})

Provides details about the specified Amazon Web Services HealthScribe streaming session. To view the status of the streaming session, check the StreamStatus field in the response. To get the details of post-stream analytics, including its status, check the PostStreamAnalyticsResult field in the response.

May throw BadRequestException. May throw InternalFailureException. May throw LimitExceededException. May throw ResourceNotFoundException.

Parameter sessionId : The identifier of the HealthScribe streaming session you want information about.

Implementation

Future<GetMedicalScribeStreamResponse> getMedicalScribeStream({
  required String sessionId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/medical-scribe-stream/${Uri.encodeComponent(sessionId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetMedicalScribeStreamResponse.fromJson(response);
}