Transfer class
Transfer Family is a fully managed service that enables the transfer of files over the File Transfer Protocol (FTP), File Transfer Protocol over SSL (FTPS), or Secure Shell (SSH) File Transfer Protocol (SFTP) directly into and out of Amazon Simple Storage Service (Amazon S3) or Amazon EFS. Additionally, you can use Applicability Statement 2 (AS2) to transfer files into and out of Amazon S3. Amazon Web Services helps you seamlessly migrate your file transfer workflows to Transfer Family by integrating with existing authentication systems, and providing DNS routing with Amazon Route 53 so nothing changes for your customers and partners, or their applications. With your data in Amazon S3, you can use it with Amazon Web Services services for processing, analytics, machine learning, and archiving. Getting started with Transfer Family is easy since there is no infrastructure to buy and set up.
Constructors
- Transfer({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccess(
{required String externalId, required String role, required String serverId, String? homeDirectory, List< HomeDirectoryMapEntry> ? homeDirectoryMappings, HomeDirectoryType? homeDirectoryType, String? policy, PosixProfile? posixProfile}) → Future<CreateAccessResponse> -
Used by administrators to choose which groups in the directory should have
access to upload and download files over the enabled protocols using
Transfer Family. For example, a Microsoft Active Directory might contain
50,000 users, but only a small fraction might need the ability to transfer
files to the server. An administrator can use
CreateAccessto limit the access to the correct set of users who need this ability. -
createAgreement(
{required String accessRole, required String localProfileId, required String partnerProfileId, required String serverId, String? baseDirectory, CustomDirectoriesType? customDirectories, String? description, EnforceMessageSigningType? enforceMessageSigning, PreserveFilenameType? preserveFilename, AgreementStatusType? status, List< Tag> ? tags}) → Future<CreateAgreementResponse> - Creates an agreement. An agreement is a bilateral trading partner agreement, or partnership, between an Transfer Family server and an AS2 process. The agreement defines the file and message transfer relationship between the server and the AS2 process. To define an agreement, Transfer Family combines a server, local profile, partner profile, certificate, and other attributes.
-
createConnector(
{required String accessRole, As2ConnectorConfig? as2Config, ConnectorEgressConfig? egressConfig, ConnectorsIpAddressType? ipAddressType, String? loggingRole, String? securityPolicyName, SftpConnectorConfig? sftpConfig, List< Tag> ? tags, String? url}) → Future<CreateConnectorResponse> - Creates the connector, which captures the parameters for a connection for the AS2 or SFTP protocol. For AS2, the connector is required for sending files to an externally hosted AS2 server. For SFTP, the connector is required when sending files to an SFTP server or receiving files from an SFTP server. For more details about connectors, see Configure AS2 connectors and Create SFTP connectors.
-
createProfile(
{required String as2Id, required ProfileType profileType, List< String> ? certificateIds, List<Tag> ? tags}) → Future<CreateProfileResponse> - Creates the local or partner profile to use for AS2 transfers.
-
createServer(
{String? certificate, Domain? domain, EndpointDetails? endpointDetails, EndpointType? endpointType, String? hostKey, IdentityProviderDetails? identityProviderDetails, IdentityProviderType? identityProviderType, IpAddressType? ipAddressType, String? loggingRole, String? postAuthenticationLoginBanner, String? preAuthenticationLoginBanner, ProtocolDetails? protocolDetails, List< Protocol> ? protocols, S3StorageOptions? s3StorageOptions, String? securityPolicyName, List<String> ? structuredLogDestinations, List<Tag> ? tags, WorkflowDetails? workflowDetails}) → Future<CreateServerResponse> -
Instantiates an auto-scaling virtual server based on the selected file
transfer protocol in Amazon Web Services. When you make updates to your
file transfer protocol-enabled server or when you work with users, use the
service-generated
ServerIdproperty that is assigned to the newly created server. -
createUser(
{required String role, required String serverId, required String userName, String? homeDirectory, List< HomeDirectoryMapEntry> ? homeDirectoryMappings, HomeDirectoryType? homeDirectoryType, String? policy, PosixProfile? posixProfile, String? sshPublicKeyBody, List<Tag> ? tags}) → Future<CreateUserResponse> -
Creates a user and associates them with an existing file transfer
protocol-enabled server. You can only create and associate users with
servers that have the
IdentityProviderTypeset toSERVICE_MANAGED. Using parameters forCreateUser, you can specify the user name, set the home directory, store the user's public key, and assign the user's Identity and Access Management (IAM) role. You can also optionally add a session policy, and assign metadata with tags that can be used to group and search for users. -
createWebApp(
{required WebAppIdentityProviderDetails identityProviderDetails, String? accessEndpoint, WebAppEndpointDetails? endpointDetails, List< Tag> ? tags, WebAppEndpointPolicy? webAppEndpointPolicy, WebAppUnits? webAppUnits}) → Future<CreateWebAppResponse> - Creates a web app based on specified parameters, and returns the ID for the new web app. You can configure the web app to be publicly accessible or hosted within a VPC.
-
createWorkflow(
{required List< WorkflowStep> steps, String? description, List<WorkflowStep> ? onExceptionSteps, List<Tag> ? tags}) → Future<CreateWorkflowResponse> -
Allows you to create a workflow with specified steps and step details the
workflow invokes after file transfer completes. After creating a workflow,
you can associate the workflow created with any transfer servers by
specifying the
workflow-detailsfield inCreateServerandUpdateServeroperations. -
deleteAccess(
{required String externalId, required String serverId}) → Future< void> -
Allows you to delete the access specified in the
ServerIDandExternalIDparameters. -
deleteAgreement(
{required String agreementId, required String serverId}) → Future< void> -
Delete the agreement that's specified in the provided
AgreementId. -
deleteCertificate(
{required String certificateId}) → Future< void> -
Deletes the certificate that's specified in the
CertificateIdparameter. -
deleteConnector(
{required String connectorId}) → Future< void> -
Deletes the connector that's specified in the provided
ConnectorId. -
deleteHostKey(
{required String hostKeyId, required String serverId}) → Future< void> -
Deletes the host key that's specified in the
HostKeyIdparameter. -
deleteProfile(
{required String profileId}) → Future< void> -
Deletes the profile that's specified in the
ProfileIdparameter. -
deleteServer(
{required String serverId}) → Future< void> - Deletes the file transfer protocol-enabled server that you specify.
-
deleteSshPublicKey(
{required String serverId, required String sshPublicKeyId, required String userName}) → Future< void> - Deletes a user's Secure Shell (SSH) public key.
-
deleteUser(
{required String serverId, required String userName}) → Future< void> - Deletes the user belonging to a file transfer protocol-enabled server you specify.
-
deleteWebApp(
{required String webAppId}) → Future< void> - Deletes the specified web app.
-
deleteWebAppCustomization(
{required String webAppId}) → Future< void> -
Deletes the
WebAppCustomizationobject that corresponds to the web app ID specified. -
deleteWorkflow(
{required String workflowId}) → Future< void> - Deletes the specified workflow.
-
describeAccess(
{required String externalId, required String serverId}) → Future< DescribeAccessResponse> -
Describes the access that is assigned to the specific file transfer
protocol-enabled server, as identified by its
ServerIdproperty and itsExternalId. -
describeAgreement(
{required String agreementId, required String serverId}) → Future< DescribeAgreementResponse> -
Describes the agreement that's identified by the
AgreementId. -
describeCertificate(
{required String certificateId}) → Future< DescribeCertificateResponse> -
Describes the certificate that's identified by the
CertificateId. -
describeConnector(
{required String connectorId}) → Future< DescribeConnectorResponse> -
Describes the connector that's identified by the
ConnectorId. -
describeExecution(
{required String executionId, required String workflowId}) → Future< DescribeExecutionResponse> -
You can use
DescribeExecutionto check the details of the execution of the specified workflow. -
describeHostKey(
{required String hostKeyId, required String serverId}) → Future< DescribeHostKeyResponse> -
Returns the details of the host key that's specified by the
HostKeyIdandServerId. -
describeProfile(
{required String profileId}) → Future< DescribeProfileResponse> -
Returns the details of the profile that's specified by the
ProfileId. -
describeSecurityPolicy(
{required String securityPolicyName}) → Future< DescribeSecurityPolicyResponse> - Describes the security policy that is attached to your server or SFTP connector. The response contains a description of the security policy's properties. For more information about security policies, see Working with security policies for servers or Working with security policies for SFTP connectors.
-
describeServer(
{required String serverId}) → Future< DescribeServerResponse> -
Describes a file transfer protocol-enabled server that you specify by
passing the
ServerIdparameter. -
describeUser(
{required String serverId, required String userName}) → Future< DescribeUserResponse> -
Describes the user assigned to the specific file transfer protocol-enabled
server, as identified by its
ServerIdproperty. -
describeWebApp(
{required String webAppId}) → Future< DescribeWebAppResponse> -
Describes the web app that's identified by
WebAppId. The response includes endpoint configuration details such as whether the web app is publicly accessible or VPC hosted. -
describeWebAppCustomization(
{required String webAppId}) → Future< DescribeWebAppCustomizationResponse> -
Describes the web app customization object that's identified by
WebAppId. -
describeWorkflow(
{required String workflowId}) → Future< DescribeWorkflowResponse> - Describes the specified workflow.
-
importCertificate(
{required String certificate, required CertificateUsageType usage, DateTime? activeDate, String? certificateChain, String? description, DateTime? inactiveDate, String? privateKey, List< Tag> ? tags}) → Future<ImportCertificateResponse> - Imports the signing and encryption certificates that you need to create local (AS2) profiles and partner profiles.
-
importHostKey(
{required String hostKeyBody, required String serverId, String? description, List< Tag> ? tags}) → Future<ImportHostKeyResponse> -
Adds a host key to the server that's specified by the
ServerIdparameter. -
importSshPublicKey(
{required String serverId, required String sshPublicKeyBody, required String userName}) → Future< ImportSshPublicKeyResponse> -
Adds a Secure Shell (SSH) public key to a Transfer Family user identified
by a
UserNamevalue assigned to the specific file transfer protocol-enabled server, identified byServerId. -
listAccesses(
{required String serverId, int? maxResults, String? nextToken}) → Future< ListAccessesResponse> - Lists the details for all the accesses you have on your server.
-
listAgreements(
{required String serverId, int? maxResults, String? nextToken}) → Future< ListAgreementsResponse> -
Returns a list of the agreements for the server that's identified by the
ServerIdthat you supply. If you want to limit the results to a certain number, supply a value for theMaxResultsparameter. If you ran the command previously and received a value forNextToken, you can supply that value to continue listing agreements from where you left off. -
listCertificates(
{int? maxResults, String? nextToken}) → Future< ListCertificatesResponse> -
Returns a list of the current certificates that have been imported into
Transfer Family. If you want to limit the results to a certain number,
supply a value for the
MaxResultsparameter. If you ran the command previously and received a value for theNextTokenparameter, you can supply that value to continue listing certificates from where you left off. -
listConnectors(
{int? maxResults, String? nextToken}) → Future< ListConnectorsResponse> - Lists the connectors for the specified Region.
-
listExecutions(
{required String workflowId, int? maxResults, String? nextToken}) → Future< ListExecutionsResponse> - Lists all in-progress executions for the specified workflow.
-
listFileTransferResults(
{required String connectorId, required String transferId, int? maxResults, String? nextToken}) → Future< ListFileTransferResultsResponse> -
Returns real-time updates and detailed information on the status of each
individual file being transferred in a specific file transfer operation.
You specify the file transfer by providing its
ConnectorIdand itsTransferId. -
listHostKeys(
{required String serverId, int? maxResults, String? nextToken}) → Future< ListHostKeysResponse> -
Returns a list of host keys for the server that's specified by the
ServerIdparameter. -
listProfiles(
{int? maxResults, String? nextToken, ProfileType? profileType}) → Future< ListProfilesResponse> -
Returns a list of the profiles for your system. If you want to limit the
results to a certain number, supply a value for the
MaxResultsparameter. If you ran the command previously and received a value forNextToken, you can supply that value to continue listing profiles from where you left off. -
listSecurityPolicies(
{int? maxResults, String? nextToken}) → Future< ListSecurityPoliciesResponse> - Lists the security policies that are attached to your servers and SFTP connectors. For more information about security policies, see Working with security policies for servers or Working with security policies for SFTP connectors.
-
listServers(
{int? maxResults, String? nextToken}) → Future< ListServersResponse> - Lists the file transfer protocol-enabled servers that are associated with your Amazon Web Services account.
-
listTagsForResource(
{required String arn, int? maxResults, String? nextToken}) → Future< ListTagsForResourceResponse> - Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
-
listUsers(
{required String serverId, int? maxResults, String? nextToken}) → Future< ListUsersResponse> -
Lists the users for a file transfer protocol-enabled server that you
specify by passing the
ServerIdparameter. -
listWebApps(
{int? maxResults, String? nextToken}) → Future< ListWebAppsResponse> - Lists all web apps associated with your Amazon Web Services account for your current region. The response includes the endpoint type for each web app, showing whether it is publicly accessible or VPC hosted.
-
listWorkflows(
{int? maxResults, String? nextToken}) → Future< ListWorkflowsResponse> - Lists all workflows associated with your Amazon Web Services account for your current region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendWorkflowStepState(
{required String executionId, required CustomStepStatus status, required String token, required String workflowId}) → Future< void> - Sends a callback for asynchronous custom steps.
-
startDirectoryListing(
{required String connectorId, required String outputDirectoryPath, required String remoteDirectoryPath, int? maxItems}) → Future< StartDirectoryListingResponse> -
Retrieves a list of the contents of a directory from a remote SFTP server.
You specify the connector ID, the output path, and the remote directory
path. You can also specify the optional
MaxItemsvalue to control the maximum number of items that are listed from the remote directory. This API returns a list of all files and directories in the remote directory (up to the maximum value), but does not return files or folders in sub-directories. That is, it only returns a list of files and directories one-level deep. -
startFileTransfer(
{required String connectorId, List< CustomHttpHeader> ? customHttpHeaders, String? localDirectoryPath, String? remoteDirectoryPath, List<String> ? retrieveFilePaths, List<String> ? sendFilePaths}) → Future<StartFileTransferResponse> - Begins a file transfer between local Amazon Web Services storage and a remote AS2 or SFTP server.
-
startRemoteDelete(
{required String connectorId, required String deletePath}) → Future< StartRemoteDeleteResponse> - Deletes a file or directory on the remote SFTP server.
-
startRemoteMove(
{required String connectorId, required String sourcePath, required String targetPath}) → Future< StartRemoteMoveResponse> - Moves or renames a file or directory on the remote SFTP server.
-
startServer(
{required String serverId}) → Future< void> -
Changes the state of a file transfer protocol-enabled server from
OFFLINEtoONLINE. It has no impact on a server that is alreadyONLINE. AnONLINEserver can accept and process file transfer jobs. -
stopServer(
{required String serverId}) → Future< void> -
Changes the state of a file transfer protocol-enabled server from
ONLINEtoOFFLINE. AnOFFLINEserver cannot accept and process file transfer jobs. Information tied to your server, such as server and user properties, are not affected by stopping your server. The state ofSTOPPINGindicates that the server is in an intermediate state, either not fully able to respond, or not fully offline. The values ofSTOP_FAILEDcan indicate an error condition. -
tagResource(
{required String arn, required List< Tag> tags}) → Future<void> - Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
-
testConnection(
{required String connectorId}) → Future< TestConnectionResponse> - Tests whether your SFTP connector is set up successfully. We highly recommend that you call this operation to test your ability to transfer files between local Amazon Web Services storage and a trading partner's SFTP server.
-
testIdentityProvider(
{required String serverId, required String userName, Protocol? serverProtocol, String? sourceIp, String? userPassword}) → Future< TestIdentityProviderResponse> -
If the
IdentityProviderTypeof a file transfer protocol-enabled server isAWS_DIRECTORY_SERVICEorAPI_Gateway, tests whether your identity provider is set up successfully. We highly recommend that you call this operation to test your authentication method as soon as you create your server. By doing so, you can troubleshoot issues with the identity provider integration to ensure that your users can successfully use the service. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String arn, required List< String> tagKeys}) → Future<void> - Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
-
updateAccess(
{required String externalId, required String serverId, String? homeDirectory, List< HomeDirectoryMapEntry> ? homeDirectoryMappings, HomeDirectoryType? homeDirectoryType, String? policy, PosixProfile? posixProfile, String? role}) → Future<UpdateAccessResponse> -
Allows you to update parameters for the access specified in the
ServerIDandExternalIDparameters. -
updateAgreement(
{required String agreementId, required String serverId, String? accessRole, String? baseDirectory, CustomDirectoriesType? customDirectories, String? description, EnforceMessageSigningType? enforceMessageSigning, String? localProfileId, String? partnerProfileId, PreserveFilenameType? preserveFilename, AgreementStatusType? status}) → Future< UpdateAgreementResponse> -
Updates some of the parameters for an existing agreement. Provide the
AgreementIdand theServerIdfor the agreement that you want to update, along with the new values for the parameters to update. -
updateCertificate(
{required String certificateId, DateTime? activeDate, String? description, DateTime? inactiveDate}) → Future< UpdateCertificateResponse> - Updates the active and inactive dates for a certificate.
-
updateConnector(
{required String connectorId, String? accessRole, As2ConnectorConfig? as2Config, UpdateConnectorEgressConfig? egressConfig, ConnectorsIpAddressType? ipAddressType, String? loggingRole, String? securityPolicyName, SftpConnectorConfig? sftpConfig, String? url}) → Future< UpdateConnectorResponse> -
Updates some of the parameters for an existing connector. Provide the
ConnectorIdfor the connector that you want to update, along with the new values for the parameters to update. -
updateHostKey(
{required String description, required String hostKeyId, required String serverId}) → Future< UpdateHostKeyResponse> -
Updates the description for the host key that's specified by the
ServerIdandHostKeyIdparameters. -
updateProfile(
{required String profileId, List< String> ? certificateIds}) → Future<UpdateProfileResponse> -
Updates some of the parameters for an existing profile. Provide the
ProfileIdfor the profile that you want to update, along with the new values for the parameters to update. -
updateServer(
{required String serverId, String? certificate, EndpointDetails? endpointDetails, EndpointType? endpointType, String? hostKey, IdentityProviderDetails? identityProviderDetails, IdentityProviderType? identityProviderType, IpAddressType? ipAddressType, String? loggingRole, String? postAuthenticationLoginBanner, String? preAuthenticationLoginBanner, ProtocolDetails? protocolDetails, List< Protocol> ? protocols, S3StorageOptions? s3StorageOptions, String? securityPolicyName, List<String> ? structuredLogDestinations, WorkflowDetails? workflowDetails}) → Future<UpdateServerResponse> - Updates the file transfer protocol-enabled server's properties after that server has been created.
-
updateUser(
{required String serverId, required String userName, String? homeDirectory, List< HomeDirectoryMapEntry> ? homeDirectoryMappings, HomeDirectoryType? homeDirectoryType, String? policy, PosixProfile? posixProfile, String? role}) → Future<UpdateUserResponse> -
Assigns new properties to a user. Parameters you pass modify any or all of
the following: the home directory, role, and policy for the
UserNameandServerIdyou specify. -
updateWebApp(
{required String webAppId, String? accessEndpoint, UpdateWebAppEndpointDetails? endpointDetails, UpdateWebAppIdentityProviderDetails? identityProviderDetails, WebAppUnits? webAppUnits}) → Future< UpdateWebAppResponse> - Assigns new properties to a web app. You can modify the access point, identity provider details, endpoint configuration, and the web app units.
-
updateWebAppCustomization(
{required String webAppId, Uint8List? faviconFile, Uint8List? logoFile, String? title}) → Future< UpdateWebAppCustomizationResponse> - Assigns new customization properties to a web app. You can modify the icon file, logo file, and title.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited