createAgreement method
- required String accessRole,
- required String localProfileId,
- required String partnerProfileId,
- required String serverId,
- String? baseDirectory,
- CustomDirectoriesType? customDirectories,
- String? description,
- EnforceMessageSigningType? enforceMessageSigning,
- PreserveFilenameType? preserveFilename,
- AgreementStatusType? status,
- List<
Tag> ? tags,
Creates an agreement. An agreement is a bilateral trading partner agreement, or partnership, between an Transfer Family server and an AS2 process. The agreement defines the file and message transfer relationship between the server and the AS2 process. To define an agreement, Transfer Family combines a server, local profile, partner profile, certificate, and other attributes.
The partner is identified with the PartnerProfileId, and the
AS2 process is identified with the LocalProfileId.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter accessRole :
Connectors are used to send files using either the AS2 or SFTP protocol.
For the access role, provide the Amazon Resource Name (ARN) of the
Identity and Access Management role to use.
For AS2 connectors
With AS2, you can send files by calling StartFileTransfer and
specifying the file paths in the request parameter,
SendFilePaths. We use the file’s parent directory (for
example, for --send-file-paths /bucket/dir/file.txt, parent
directory is /bucket/dir/) to temporarily store a processed
AS2 message file, store the MDN when we receive them from the partner, and
write a final JSON file containing relevant metadata of the transmission.
So, the AccessRole needs to provide read and write access to
the parent directory of the file location used in the
StartFileTransfer request. Additionally, you need to provide
read and write access to the parent directory of the files that you intend
to send with StartFileTransfer.
If you are using Basic authentication for your AS2 connector, the access
role requires the secretsmanager:GetSecretValue permission
for the secret. If the secret is encrypted using a customer-managed key
instead of the Amazon Web Services managed key in Secrets Manager, then
the role also needs the kms:Decrypt permission for that key.
For SFTP connectors
Make sure that the access role provides read and write access to the
parent directory of the file location that's used in the
StartFileTransfer request. Additionally, make sure that the
role provides secretsmanager:GetSecretValue permission to
Secrets Manager.
Parameter localProfileId :
A unique identifier for the AS2 local profile.
Parameter partnerProfileId :
A unique identifier for the partner profile used in the agreement.
Parameter serverId :
A system-assigned unique identifier for a server instance. This is the
specific server that the agreement uses.
Parameter baseDirectory :
The landing directory (folder) for files transferred by using the AS2
protocol.
A BaseDirectory example is
/amzn-s3-demo-bucket/home/mydirectory.
Parameter customDirectories :
A CustomDirectoriesType structure. This structure specifies
custom directories for storing various AS2 message files. You can specify
directories for the following types of files.
- Failed files
- MDN files
- Payload files
- Status files
- Temporary files
Parameter description :
A name or short description to identify the agreement.
Parameter enforceMessageSigning :
Determines whether or not unsigned messages from your trading partners
will be accepted.
-
ENABLED: Transfer Family rejects unsigned messages from your trading partner. -
DISABLED(default value): Transfer Family accepts unsigned messages from your trading partner.
Parameter preserveFilename :
Determines whether or not Transfer Family appends a unique string of
characters to the end of the AS2 message payload filename when saving it.
-
ENABLED: the filename provided by your trading parter is preserved when the file is saved. -
DISABLED(default value): when Transfer Family saves the file, the filename is adjusted, as described in File names and locations.
Parameter status :
The status of the agreement. The agreement can be either
ACTIVE or INACTIVE.
Parameter tags :
Key-value pairs that can be used to group and search for agreements.
Implementation
Future<CreateAgreementResponse> createAgreement({
required String accessRole,
required String localProfileId,
required String partnerProfileId,
required String serverId,
String? baseDirectory,
CustomDirectoriesType? customDirectories,
String? description,
EnforceMessageSigningType? enforceMessageSigning,
PreserveFilenameType? preserveFilename,
AgreementStatusType? status,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.CreateAgreement'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccessRole': accessRole,
'LocalProfileId': localProfileId,
'PartnerProfileId': partnerProfileId,
'ServerId': serverId,
if (baseDirectory != null) 'BaseDirectory': baseDirectory,
if (customDirectories != null) 'CustomDirectories': customDirectories,
if (description != null) 'Description': description,
if (enforceMessageSigning != null)
'EnforceMessageSigning': enforceMessageSigning.value,
if (preserveFilename != null)
'PreserveFilename': preserveFilename.value,
if (status != null) 'Status': status.value,
if (tags != null) 'Tags': tags,
},
);
return CreateAgreementResponse.fromJson(jsonResponse.body);
}