deleteAgreement method

Future<void> deleteAgreement({
  1. required String agreementId,
  2. required String serverId,
})

Delete the agreement that's specified in the provided AgreementId.

May throw InternalServiceError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter agreementId : A unique identifier for the agreement. This identifier is returned when you create an agreement.

Parameter serverId : The server identifier associated with the agreement that you are deleting.

Implementation

Future<void> deleteAgreement({
  required String agreementId,
  required String serverId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TransferService.DeleteAgreement'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'AgreementId': agreementId,
      'ServerId': serverId,
    },
  );
}