deleteUser method
Deletes the user belonging to a file transfer protocol-enabled server you specify.
No response returns from this operation.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter serverId :
A system-assigned unique identifier for a server instance that has the
user assigned to it.
Parameter userName :
A unique string that identifies a user that is being deleted from a
server.
Implementation
Future<void> deleteUser({
required String serverId,
required String userName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.DeleteUser'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServerId': serverId,
'UserName': userName,
},
);
}