deleteWebAppCustomization method

Future<void> deleteWebAppCustomization({
  1. required String webAppId,
})

Deletes the WebAppCustomization object that corresponds to the web app ID specified.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServiceError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter webAppId : Provide the unique identifier for the web app that contains the customizations that you are deleting.

Implementation

Future<void> deleteWebAppCustomization({
  required String webAppId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TransferService.DeleteWebAppCustomization'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'WebAppId': webAppId,
    },
  );
}