describeWebApp method

Future<DescribeWebAppResponse> describeWebApp({
  1. required String webAppId,
})

Describes the web app that's identified by WebAppId. The response includes endpoint configuration details such as whether the web app is publicly accessible or VPC hosted.

For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.

May throw AccessDeniedException. May throw InternalServiceError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter webAppId : Provide the unique identifier for the web app.

Implementation

Future<DescribeWebAppResponse> describeWebApp({
  required String webAppId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TransferService.DescribeWebApp'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'WebAppId': webAppId,
    },
  );

  return DescribeWebAppResponse.fromJson(jsonResponse.body);
}