listConnectors method

Future<ListConnectorsResponse> listConnectors({
  1. int? maxResults,
  2. String? nextToken,
})

Lists the connectors for the specified Region.

May throw InternalServiceError. May throw InvalidNextTokenException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceUnavailableException.

Parameter maxResults : The maximum number of items to return.

Parameter nextToken : When you can get additional results from the ListConnectors call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional connectors.

Implementation

Future<ListConnectorsResponse> listConnectors({
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    1000,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TransferService.ListConnectors'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListConnectorsResponse.fromJson(jsonResponse.body);
}