listWebApps method
Lists all web apps associated with your Amazon Web Services account for your current region. The response includes the endpoint type for each web app, showing whether it is publicly accessible or VPC hosted.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
May throw InternalServiceError.
May throw InvalidNextTokenException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of items to return.
Parameter nextToken :
Returns the NextToken parameter in the output. You can then
pass the NextToken parameter in a subsequent command to
continue listing additional web apps.
Implementation
Future<ListWebAppsResponse> listWebApps({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.ListWebApps'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListWebAppsResponse.fromJson(jsonResponse.body);
}