updateConnector method

Future<UpdateConnectorResponse> updateConnector({
  1. required String connectorId,
  2. String? accessRole,
  3. As2ConnectorConfig? as2Config,
  4. UpdateConnectorEgressConfig? egressConfig,
  5. ConnectorsIpAddressType? ipAddressType,
  6. String? loggingRole,
  7. String? securityPolicyName,
  8. SftpConnectorConfig? sftpConfig,
  9. String? url,
})

Updates some of the parameters for an existing connector. Provide the ConnectorId for the connector that you want to update, along with the new values for the parameters to update.

May throw InternalServiceError. May throw InvalidRequestException. May throw ResourceExistsException. May throw ResourceNotFoundException. May throw ServiceUnavailableException. May throw ThrottlingException.

Parameter connectorId : The unique identifier for the connector.

Parameter accessRole : Connectors are used to send files using either the AS2 or SFTP protocol. For the access role, provide the Amazon Resource Name (ARN) of the Identity and Access Management role to use.

For AS2 connectors

With AS2, you can send files by calling StartFileTransfer and specifying the file paths in the request parameter, SendFilePaths. We use the file’s parent directory (for example, for --send-file-paths /bucket/dir/file.txt, parent directory is /bucket/dir/) to temporarily store a processed AS2 message file, store the MDN when we receive them from the partner, and write a final JSON file containing relevant metadata of the transmission. So, the AccessRole needs to provide read and write access to the parent directory of the file location used in the StartFileTransfer request. Additionally, you need to provide read and write access to the parent directory of the files that you intend to send with StartFileTransfer.

If you are using Basic authentication for your AS2 connector, the access role requires the secretsmanager:GetSecretValue permission for the secret. If the secret is encrypted using a customer-managed key instead of the Amazon Web Services managed key in Secrets Manager, then the role also needs the kms:Decrypt permission for that key.

For SFTP connectors

Make sure that the access role provides read and write access to the parent directory of the file location that's used in the StartFileTransfer request. Additionally, make sure that the role provides secretsmanager:GetSecretValue permission to Secrets Manager.

Parameter as2Config : A structure that contains the parameters for an AS2 connector object.

Parameter egressConfig : Updates the egress configuration for the connector, allowing you to modify how traffic is routed from the connector to the SFTP server. Changes to VPC configuration may require connector restart.

Parameter ipAddressType : Specifies the IP address type for the connector's network connections. When set to IPV4, the connector uses IPv4 addresses only. When set to DUALSTACK, the connector supports both IPv4 and IPv6 addresses, with IPv6 preferred when available.

Parameter loggingRole : The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that allows a connector to turn on CloudWatch logging for Amazon S3 events. When set, you can view connector activity in your CloudWatch logs.

Parameter securityPolicyName : Specifies the name of the security policy for the connector.

Parameter sftpConfig : A structure that contains the parameters for an SFTP connector object.

Parameter url : The URL of the partner's AS2 or SFTP endpoint.

When creating AS2 connectors or service-managed SFTP connectors (connectors without egress configuration), you must provide a URL to specify the remote server endpoint. For VPC Lattice type connectors, the URL must be null.

Implementation

Future<UpdateConnectorResponse> updateConnector({
  required String connectorId,
  String? accessRole,
  As2ConnectorConfig? as2Config,
  UpdateConnectorEgressConfig? egressConfig,
  ConnectorsIpAddressType? ipAddressType,
  String? loggingRole,
  String? securityPolicyName,
  SftpConnectorConfig? sftpConfig,
  String? url,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'TransferService.UpdateConnector'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ConnectorId': connectorId,
      if (accessRole != null) 'AccessRole': accessRole,
      if (as2Config != null) 'As2Config': as2Config,
      if (egressConfig != null) 'EgressConfig': egressConfig,
      if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
      if (loggingRole != null) 'LoggingRole': loggingRole,
      if (securityPolicyName != null)
        'SecurityPolicyName': securityPolicyName,
      if (sftpConfig != null) 'SftpConfig': sftpConfig,
      if (url != null) 'Url': url,
    },
  );

  return UpdateConnectorResponse.fromJson(jsonResponse.body);
}