updateUser method
Assigns new properties to a user. Parameters you pass modify any or all of
the following: the home directory, role, and policy for the
UserName and ServerId you specify.
The response returns the ServerId and the
UserName for the updated user.
In the console, you can select Restricted when you create or update
a user. This ensures that the user can't access anything outside of their
home directory. The programmatic way to configure this behavior is to
update the user. Set their HomeDirectoryType to
LOGICAL, and specify HomeDirectoryMappings with
Entry as root (/) and Target as
their home directory.
For example, if the user's home directory is
/test/admin-user, the following command updates the user so
that their configuration in the console shows the Restricted flag
as selected.
aws transfer update-user --server-id <server-id> --user-name
admin-user --home-directory-type LOGICAL --home-directory-mappings
"[{"Entry":"/", "Target":"/test/admin-user"}]"
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter serverId :
A system-assigned unique identifier for a Transfer Family server instance
that the user is assigned to.
Parameter userName :
A unique string that identifies a user and is associated with a server as
specified by the ServerId. This user name must be a minimum
of 3 and a maximum of 100 characters long. The following are valid
characters: a-z, A-Z, 0-9, underscore '_', hyphen '-', period '.', and at
sign '@'. The user name can't start with a hyphen, period, or at sign.
Parameter homeDirectory :
The landing directory (folder) for a user when they log in to the server
using the client.
A HomeDirectory example is
/bucket_name/home/mydirectory.
Parameter homeDirectoryMappings :
Logical directory mappings that specify what Amazon S3 or Amazon EFS paths
and keys should be visible to your user and how you want to make them
visible. You must specify the Entry and Target
pair, where Entry shows how the path is made visible and
Target is the actual Amazon S3 or Amazon EFS path. If you
only specify a target, it is displayed as is. You also must ensure that
your Identity and Access Management (IAM) role provides access to paths in
Target. This value can be set only when
HomeDirectoryType is set to LOGICAL.
The following is an Entry and Target pair
example.
[ { "Entry": "/directory1", "Target":
"/bucket_name/home/mydirectory" } ]
In most cases, you can use this value instead of the session policy to
lock down your user to the designated home directory
("chroot"). To do this, you can set Entry to '/'
and set Target to the HomeDirectory parameter value.
The following is an Entry and Target pair
example for chroot.
[ { "Entry": "/", "Target": "/bucket_name/home/mydirectory" }
]
Parameter homeDirectoryType :
The type of landing directory (folder) that you want your users' home
directory to be when they log in to the server. If you set it to
PATH, the user will see the absolute Amazon S3 bucket or
Amazon EFS path as is in their file transfer protocol clients. If you set
it to LOGICAL, you need to provide mappings in the
HomeDirectoryMappings for how you want to make Amazon S3 or
Amazon EFS paths visible to your users.
Parameter policy :
A session policy for your user so that you can use the same Identity and
Access Management (IAM) role across multiple users. This policy scopes
down a user's access to portions of their Amazon S3 bucket. Variables that
you can use inside this policy include ${Transfer:UserName},
${Transfer:HomeDirectory}, and
${Transfer:HomeBucket}.
For session policies, Transfer Family stores the policy as a JSON blob,
instead of the Amazon Resource Name (ARN) of the policy. You save the
policy as a JSON blob and pass it in the Policy argument.
For an example of a session policy, see Creating a session policy.
For more information, see AssumeRole in the Amazon Web Services Security Token Service API Reference.
Parameter posixProfile :
Specifies the full POSIX identity, including user ID (Uid),
group ID (Gid), and any secondary groups IDs
(SecondaryGids), that controls your users' access to your
Amazon Elastic File Systems (Amazon EFS). The POSIX permissions that are
set on files and directories in your file system determines the level of
access your users get when transferring files into and out of your Amazon
EFS file systems.
Parameter role :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role that controls your users' access to your Amazon S3 bucket or Amazon
EFS file system. The policies attached to this role determine the level of
access that you want to provide your users when transferring files into
and out of your Amazon S3 bucket or Amazon EFS file system. The IAM role
should also contain a trust relationship that allows the server to access
your resources when servicing your users' transfer requests.
Implementation
Future<UpdateUserResponse> updateUser({
required String serverId,
required String userName,
String? homeDirectory,
List<HomeDirectoryMapEntry>? homeDirectoryMappings,
HomeDirectoryType? homeDirectoryType,
String? policy,
PosixProfile? posixProfile,
String? role,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.UpdateUser'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServerId': serverId,
'UserName': userName,
if (homeDirectory != null) 'HomeDirectory': homeDirectory,
if (homeDirectoryMappings != null)
'HomeDirectoryMappings': homeDirectoryMappings,
if (homeDirectoryType != null)
'HomeDirectoryType': homeDirectoryType.value,
if (policy != null) 'Policy': policy,
if (posixProfile != null) 'PosixProfile': posixProfile,
if (role != null) 'Role': role,
},
);
return UpdateUserResponse.fromJson(jsonResponse.body);
}