Translate class

Provides translation of the input content from the source language to the target language.

Constructors

Translate({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createParallelData({required String name, required ParallelDataConfig parallelDataConfig, String? clientToken, String? description, EncryptionKey? encryptionKey, List<Tag>? tags}) Future<CreateParallelDataResponse>
Creates a parallel data resource in Amazon Translate by importing an input file from Amazon S3. Parallel data files contain examples that show how you want segments of text to be translated. By adding parallel data, you can influence the style, tone, and word choice in your translation output.
deleteParallelData({required String name}) Future<DeleteParallelDataResponse>
Deletes a parallel data resource in Amazon Translate.
deleteTerminology({required String name}) Future<void>
A synchronous action that deletes a custom terminology.
describeTextTranslationJob({required String jobId}) Future<DescribeTextTranslationJobResponse>
Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.
getParallelData({required String name}) Future<GetParallelDataResponse>
Provides information about a parallel data resource.
getTerminology({required String name, TerminologyDataFormat? terminologyDataFormat}) Future<GetTerminologyResponse>
Retrieves a custom terminology.
importTerminology({required MergeStrategy mergeStrategy, required String name, required TerminologyData terminologyData, String? description, EncryptionKey? encryptionKey, List<Tag>? tags}) Future<ImportTerminologyResponse>
Creates or updates a custom terminology, depending on whether one already exists for the given terminology name. Importing a terminology with the same name as an existing one will merge the terminologies based on the chosen merge strategy. The only supported merge strategy is OVERWRITE, where the imported terminology overwrites the existing terminology of the same name.
listLanguages({DisplayLanguageCode? displayLanguageCode, int? maxResults, String? nextToken}) Future<ListLanguagesResponse>
Provides a list of languages (RFC-5646 codes and names) that Amazon Translate supports.
listParallelData({int? maxResults, String? nextToken}) Future<ListParallelDataResponse>
Provides a list of your parallel data resources in Amazon Translate.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists all tags associated with a given Amazon Translate resource. For more information, see Tagging your resources.
listTerminologies({int? maxResults, String? nextToken}) Future<ListTerminologiesResponse>
Provides a list of custom terminologies associated with your account.
listTextTranslationJobs({TextTranslationJobFilter? filter, int? maxResults, String? nextToken}) Future<ListTextTranslationJobsResponse>
Gets a list of the batch translation jobs that you have submitted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTextTranslationJob({required String dataAccessRoleArn, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, required String sourceLanguageCode, required List<String> targetLanguageCodes, String? clientToken, String? jobName, List<String>? parallelDataNames, TranslationSettings? settings, List<String>? terminologyNames}) Future<StartTextTranslationJobResponse>
Starts an asynchronous batch translation job. Use batch translation jobs to translate large volumes of text across multiple documents at once. For batch translation, you can input documents with different source languages (specify auto as the source language). You can specify one or more target languages. Batch translation translates each input document into each of the target languages. For more information, see Asynchronous batch processing.
stopTextTranslationJob({required String jobId}) Future<StopTextTranslationJobResponse>
Stops an asynchronous batch translation job that is in progress.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Associates a specific tag with a resource. A tag is a key-value pair that adds as a metadata to a resource. For more information, see Tagging your resources.
toString() String
A string representation of this object.
inherited
translateDocument({required Document document, required String sourceLanguageCode, required String targetLanguageCode, TranslationSettings? settings, List<String>? terminologyNames}) Future<TranslateDocumentResponse>
Translates the input document from the source language to the target language. This synchronous operation supports text, HTML, or Word documents as the input document. TranslateDocument supports translations from English to any supported language, and from any supported language to English. Therefore, specify either the source language code or the target language code as “en” (English).
translateText({required String sourceLanguageCode, required String targetLanguageCode, required String text, TranslationSettings? settings, List<String>? terminologyNames}) Future<TranslateTextResponse>
Translates input text from the source language to the target language. For a list of available languages and language codes, see Supported languages.
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes a specific tag associated with an Amazon Translate resource. For more information, see Tagging your resources.
updateParallelData({required String name, required ParallelDataConfig parallelDataConfig, String? clientToken, String? description}) Future<UpdateParallelDataResponse>
Updates a previously created parallel data resource by importing a new input file from Amazon S3.

Operators

operator ==(Object other) bool
The equality operator.
inherited