describeTextTranslationJob method
Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier that Amazon Translate generated for the job. The
StartTextTranslationJob operation returns this identifier in its
response.
Implementation
Future<DescribeTextTranslationJobResponse> describeTextTranslationJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSShineFrontendService_20170701.DescribeTextTranslationJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribeTextTranslationJobResponse.fromJson(jsonResponse.body);
}