translateText method
Translates input text from the source language to the target language. For a list of available languages and language codes, see Supported languages.
May throw DetectedLanguageLowConfidenceException.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw TextSizeLimitExceededException.
May throw TooManyRequestsException.
May throw UnsupportedLanguagePairException.
Parameter sourceLanguageCode :
The language code for the language of the source text. For a list of
language codes, see Supported
languages.
To have Amazon Translate determine the source language of your text, you
can specify auto in the SourceLanguageCode
field. If you specify auto, Amazon Translate will call Amazon
Comprehend to determine the source language.
Parameter targetLanguageCode :
The language code requested for the language of the target text. For a
list of language codes, see Supported
languages.
Parameter text :
The text to translate. The text string can be a maximum of 10,000 bytes
long. Depending on your character set, this may be fewer than 10,000
characters.
Parameter settings :
Settings to configure your translation output. You can configure the
following options:
- Brevity: reduces the length of the translated output for most translations.
- Formality: sets the formality level of the output text.
- Profanity: masks profane words and phrases in your translation output.
Parameter terminologyNames :
The name of a terminology list file to add to the translation job. This
file provides source terms and the desired translation for each term. A
terminology list can contain a maximum of 256 terms. You can use one
custom terminology resource in your translation request.
Use the ListTerminologies operation to get the available terminology lists.
For more information about custom terminology lists, see Custom terminology.
Implementation
Future<TranslateTextResponse> translateText({
required String sourceLanguageCode,
required String targetLanguageCode,
required String text,
TranslationSettings? settings,
List<String>? terminologyNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSShineFrontendService_20170701.TranslateText'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SourceLanguageCode': sourceLanguageCode,
'TargetLanguageCode': targetLanguageCode,
'Text': text,
if (settings != null) 'Settings': settings,
if (terminologyNames != null) 'TerminologyNames': terminologyNames,
},
);
return TranslateTextResponse.fromJson(jsonResponse.body);
}