untagResource method

Future<void> untagResource({
  1. required String resourceArn,
  2. required List<String> tagKeys,
})

Removes a specific tag associated with an Amazon Translate resource. For more information, see Tagging your resources.

May throw ConcurrentModificationException. May throw InternalServerException. May throw InvalidParameterValueException. May throw ResourceNotFoundException.

Parameter resourceArn : The Amazon Resource Name (ARN) of the given Amazon Translate resource from which you want to remove the tags.

Parameter tagKeys : The initial part of a key-value pair that forms a tag being removed from a given resource. Keys must be unique and cannot be duplicated for a particular resource.

Implementation

Future<void> untagResource({
  required String resourceArn,
  required List<String> tagKeys,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSShineFrontendService_20170701.UntagResource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceArn': resourceArn,
      'TagKeys': tagKeys,
    },
  );
}