TrustedAdvisor class

TrustedAdvisor Public API

Constructors

TrustedAdvisor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchUpdateRecommendationResourceExclusion({required List<RecommendationResourceExclusion> recommendationResourceExclusions}) Future<BatchUpdateRecommendationResourceExclusionResponse>
Update one or more exclusion statuses for a list of recommendation resources. This API supports up to 25 unique recommendation resource ARNs per request. This API currently doesn't support prioritized recommendation resources. This API updates global recommendations, eliminating the need to call the API in each AWS Region. After submitting an exclusion update, note that it might take a few minutes for the changes to be reflected in the system.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
getOrganizationRecommendation({required String organizationRecommendationIdentifier}) Future<GetOrganizationRecommendationResponse>
Get a specific recommendation within an AWS Organizations organization. This API supports only prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.
getRecommendation({required String recommendationIdentifier, RecommendationLanguage? language}) Future<GetRecommendationResponse>
Get a specific Recommendation. This API provides global recommendations, eliminating the need to call the API in each AWS Region.
listChecks({String? awsService, RecommendationLanguage? language, int? maxResults, String? nextToken, RecommendationPillar? pillar, RecommendationSource? source}) Future<ListChecksResponse>
List a filterable set of Checks. This API provides global recommendations, eliminating the need to call the API in each AWS Region.
listOrganizationRecommendationAccounts({required String organizationRecommendationIdentifier, String? affectedAccountId, int? maxResults, String? nextToken}) Future<ListOrganizationRecommendationAccountsResponse>
Lists the accounts that own the resources for an organization aggregate recommendation. This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.
listOrganizationRecommendationResources({required String organizationRecommendationIdentifier, String? affectedAccountId, ExclusionStatus? exclusionStatus, int? maxResults, String? nextToken, String? regionCode, ResourceStatus? status}) Future<ListOrganizationRecommendationResourcesResponse>
List Resources of a Recommendation within an Organization. This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.
listOrganizationRecommendations({DateTime? afterLastUpdatedAt, String? awsService, DateTime? beforeLastUpdatedAt, String? checkIdentifier, int? maxResults, String? nextToken, RecommendationPillar? pillar, RecommendationSource? source, RecommendationStatus? status, RecommendationType? type}) Future<ListOrganizationRecommendationsResponse>
List a filterable set of Recommendations within an Organization. This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.
listRecommendationResources({required String recommendationIdentifier, ExclusionStatus? exclusionStatus, RecommendationLanguage? language, int? maxResults, String? nextToken, String? regionCode, ResourceStatus? status}) Future<ListRecommendationResourcesResponse>
List Resources of a Recommendation. This API provides global recommendations, eliminating the need to call the API in each AWS Region.
listRecommendations({DateTime? afterLastUpdatedAt, String? awsService, DateTime? beforeLastUpdatedAt, String? checkIdentifier, RecommendationLanguage? language, int? maxResults, String? nextToken, RecommendationPillar? pillar, RecommendationSource? source, RecommendationStatus? status, RecommendationType? type}) Future<ListRecommendationsResponse>
List a filterable set of Recommendations. This API provides global recommendations, eliminating the need to call the API in each AWS Region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateOrganizationRecommendationLifecycle({required UpdateRecommendationLifecycleStage lifecycleStage, required String organizationRecommendationIdentifier, String? updateReason, UpdateRecommendationLifecycleStageReasonCode? updateReasonCode}) Future<void>
Update the lifecycle of a Recommendation within an Organization. This API only supports prioritized recommendations and updates global priority recommendations, eliminating the need to call the API in each AWS Region.
updateRecommendationLifecycle({required UpdateRecommendationLifecycleStage lifecycleStage, required String recommendationIdentifier, String? updateReason, UpdateRecommendationLifecycleStageReasonCode? updateReasonCode}) Future<void>
Update the lifecyle of a Recommendation. This API only supports prioritized recommendations and updates global priority recommendations, eliminating the need to call the API in each AWS Region.

Operators

operator ==(Object other) bool
The equality operator.
inherited