getOrganizationRecommendation method
Future<GetOrganizationRecommendationResponse>
getOrganizationRecommendation({
- required String organizationRecommendationIdentifier,
Get a specific recommendation within an AWS Organizations organization. This API supports only prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter organizationRecommendationIdentifier :
The Recommendation identifier
Implementation
Future<GetOrganizationRecommendationResponse> getOrganizationRecommendation({
required String organizationRecommendationIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/organization-recommendations/${Uri.encodeComponent(organizationRecommendationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return GetOrganizationRecommendationResponse.fromJson(response);
}