getAccountCustomizations method

Future<GetAccountCustomizationsOutput> getAccountCustomizations()

Returns the current account customization settings, including account color, visible services, and visible Regions. Settings that you have not configured return their default values: visible Regions and visible services return null, and account color returns none.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Implementation

Future<GetAccountCustomizationsOutput> getAccountCustomizations() async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/account-customizations',
    exceptionFnMap: _exceptionFns,
  );
  return GetAccountCustomizationsOutput.fromJson(response);
}