deleteIdentitySource method

Future<void> deleteIdentitySource({
  1. required String identitySourceId,
  2. required String policyStoreId,
})

Deletes an identity source that references an identity provider (IdP) such as Amazon Cognito. After you delete the identity source, you can no longer use tokens for identities from that identity source to represent principals in authorization queries made using IsAuthorizedWithToken. operations.

May throw ConflictException. May throw ResourceNotFoundException.

Parameter identitySourceId : Specifies the ID of the identity source that you want to delete.

Parameter policyStoreId : Specifies the ID of the policy store that contains the identity source that you want to delete.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with policy-store-alias/. For example:

  • ID: PSEXAMPLEabcdefg111111
  • Alias name: policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.

Implementation

Future<void> deleteIdentitySource({
  required String identitySourceId,
  required String policyStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VerifiedPermissions.DeleteIdentitySource'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'identitySourceId': identitySourceId,
      'policyStoreId': policyStoreId,
    },
  );
}