deletePolicyStore method

Future<void> deletePolicyStore({
  1. required String policyStoreId,
})

Deletes the specified policy store.

This operation is idempotent. If you specify a policy store that does not exist, the request response will still return a successful HTTP 200 status code.

May throw InvalidStateException.

Parameter policyStoreId : Specifies the ID of the policy store that you want to delete.

Implementation

Future<void> deletePolicyStore({
  required String policyStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VerifiedPermissions.DeletePolicyStore'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'policyStoreId': policyStoreId,
    },
  );
}