deletePolicyTemplate method
Deletes the specified policy template from the policy store.
May throw ConflictException.
May throw ResourceNotFoundException.
Parameter policyStoreId :
Specifies the ID of the policy store that contains the policy template
that you want to delete.
To specify a policy store, use its ID or alias name. When using an alias
name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
Parameter policyTemplateId :
Specifies the ID of the policy template that you want to delete.
You can use the policy template name in place of the policy template ID.
When using a name, prefix it with name/. For example:
-
ID:
PTEXAMPLEabcdefg111111 -
Name:
name/example-policy-template
Implementation
Future<void> deletePolicyTemplate({
required String policyStoreId,
required String policyTemplateId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VerifiedPermissions.DeletePolicyTemplate'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'policyStoreId': policyStoreId,
'policyTemplateId': policyTemplateId,
},
);
}