getIdentitySource method

Future<GetIdentitySourceOutput> getIdentitySource({
  1. required String identitySourceId,
  2. required String policyStoreId,
})

Retrieves the details about the specified identity source.

May throw ResourceNotFoundException.

Parameter identitySourceId : Specifies the ID of the identity source you want information about.

Parameter policyStoreId : Specifies the ID of the policy store that contains the identity source you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with policy-store-alias/. For example:

  • ID: PSEXAMPLEabcdefg111111
  • Alias name: policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.

Implementation

Future<GetIdentitySourceOutput> getIdentitySource({
  required String identitySourceId,
  required String policyStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VerifiedPermissions.GetIdentitySource'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'identitySourceId': identitySourceId,
      'policyStoreId': policyStoreId,
    },
  );

  return GetIdentitySourceOutput.fromJson(jsonResponse.body);
}