getPolicy method

Future<GetPolicyOutput> getPolicy({
  1. required String policyId,
  2. required String policyStoreId,
})

Retrieves information about the specified policy.

May throw ResourceNotFoundException.

Parameter policyId : Specifies the ID of the policy you want information about.

You can use the policy name in place of the policy ID. When using a name, prefix it with name/. For example:

  • ID: SPEXAMPLEabcdefg111111
  • Name: name/example-policy

Parameter policyStoreId : Specifies the ID of the policy store that contains the policy that you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with policy-store-alias/. For example:

  • ID: PSEXAMPLEabcdefg111111
  • Alias name: policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.

Implementation

Future<GetPolicyOutput> getPolicy({
  required String policyId,
  required String policyStoreId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VerifiedPermissions.GetPolicy'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'policyId': policyId,
      'policyStoreId': policyStoreId,
    },
  );

  return GetPolicyOutput.fromJson(jsonResponse.body);
}