getSchema method
Retrieve the details for the specified schema in the specified policy store.
May throw ResourceNotFoundException.
Parameter policyStoreId :
Specifies the ID of the policy store that contains the schema.
To specify a policy store, use its ID or alias name. When using an alias
name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
Implementation
Future<GetSchemaOutput> getSchema({
required String policyStoreId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VerifiedPermissions.GetSchema'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'policyStoreId': policyStoreId,
},
);
return GetSchemaOutput.fromJson(jsonResponse.body);
}