VoiceID class

Amazon Connect Voice ID provides real-time caller authentication and fraud risk detection, which make voice interactions in contact centers more secure and efficient.

Constructors

VoiceID({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateFraudster({required String domainId, required String fraudsterId, required String watchlistId}) Future<AssociateFraudsterResponse>
Associates the fraudsters with the watchlist specified in the same domain.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createDomain({required String name, required ServerSideEncryptionConfiguration serverSideEncryptionConfiguration, String? clientToken, String? description, List<Tag>? tags}) Future<CreateDomainResponse>
Creates a domain that contains all Amazon Connect Voice ID data, such as speakers, fraudsters, customer audio, and voiceprints. Every domain is created with a default watchlist that fraudsters can be a part of.
createWatchlist({required String domainId, required String name, String? clientToken, String? description}) Future<CreateWatchlistResponse>
Creates a watchlist that fraudsters can be a part of.
deleteDomain({required String domainId}) Future<void>
Deletes the specified domain from Voice ID.
deleteFraudster({required String domainId, required String fraudsterId}) Future<void>
Deletes the specified fraudster from Voice ID. This action disassociates the fraudster from any watchlists it is a part of.
deleteSpeaker({required String domainId, required String speakerId}) Future<void>
Deletes the specified speaker from Voice ID.
deleteWatchlist({required String domainId, required String watchlistId}) Future<void>
Deletes the specified watchlist from Voice ID. This API throws an exception when there are fraudsters in the watchlist that you are trying to delete. You must delete the fraudsters, and then delete the watchlist. Every domain has a default watchlist which cannot be deleted.
describeDomain({required String domainId}) Future<DescribeDomainResponse>
Describes the specified domain.
describeFraudster({required String domainId, required String fraudsterId}) Future<DescribeFraudsterResponse>
Describes the specified fraudster.
describeFraudsterRegistrationJob({required String domainId, required String jobId}) Future<DescribeFraudsterRegistrationJobResponse>
Describes the specified fraudster registration job.
describeSpeaker({required String domainId, required String speakerId}) Future<DescribeSpeakerResponse>
Describes the specified speaker.
describeSpeakerEnrollmentJob({required String domainId, required String jobId}) Future<DescribeSpeakerEnrollmentJobResponse>
Describes the specified speaker enrollment job.
describeWatchlist({required String domainId, required String watchlistId}) Future<DescribeWatchlistResponse>
Describes the specified watchlist.
disassociateFraudster({required String domainId, required String fraudsterId, required String watchlistId}) Future<DisassociateFraudsterResponse>
Disassociates the fraudsters from the watchlist specified. Voice ID always expects a fraudster to be a part of at least one watchlist. If you try to disassociate a fraudster from its only watchlist, a ValidationException is thrown.
evaluateSession({required String domainId, required String sessionNameOrId}) Future<EvaluateSessionResponse>
Evaluates a specified session based on audio data accumulated during a streaming Amazon Connect Voice ID call.
listDomains({int? maxResults, String? nextToken}) Future<ListDomainsResponse>
Lists all the domains in the Amazon Web Services account.
listFraudsterRegistrationJobs({required String domainId, FraudsterRegistrationJobStatus? jobStatus, int? maxResults, String? nextToken}) Future<ListFraudsterRegistrationJobsResponse>
Lists all the fraudster registration jobs in the domain with the given JobStatus. If JobStatus is not provided, this lists all fraudster registration jobs in the given domain.
listFraudsters({required String domainId, int? maxResults, String? nextToken, String? watchlistId}) Future<ListFraudstersResponse>
Lists all fraudsters in a specified watchlist or domain.
listSpeakerEnrollmentJobs({required String domainId, SpeakerEnrollmentJobStatus? jobStatus, int? maxResults, String? nextToken}) Future<ListSpeakerEnrollmentJobsResponse>
Lists all the speaker enrollment jobs in the domain with the specified JobStatus. If JobStatus is not provided, this lists all jobs with all possible speaker enrollment job statuses.
listSpeakers({required String domainId, int? maxResults, String? nextToken}) Future<ListSpeakersResponse>
Lists all speakers in a specified domain.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists all tags associated with a specified Voice ID resource.
listWatchlists({required String domainId, int? maxResults, String? nextToken}) Future<ListWatchlistsResponse>
Lists all watchlists in a specified domain.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optOutSpeaker({required String domainId, required String speakerId}) Future<OptOutSpeakerResponse>
Opts out a speaker from Voice ID. A speaker can be opted out regardless of whether or not they already exist in Voice ID. If they don't yet exist, a new speaker is created in an opted out state. If they already exist, their existing status is overridden and they are opted out. Enrollment and evaluation authentication requests are rejected for opted out speakers, and opted out speakers have no voice embeddings stored in Voice ID.
startFraudsterRegistrationJob({required String dataAccessRoleArn, required String domainId, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, String? clientToken, String? jobName, RegistrationConfig? registrationConfig}) Future<StartFraudsterRegistrationJobResponse>
Starts a new batch fraudster registration job using provided details.
startSpeakerEnrollmentJob({required String dataAccessRoleArn, required String domainId, required InputDataConfig inputDataConfig, required OutputDataConfig outputDataConfig, String? clientToken, EnrollmentConfig? enrollmentConfig, String? jobName}) Future<StartSpeakerEnrollmentJobResponse>
Starts a new batch speaker enrollment job using specified details.
tagResource({required String resourceArn, required List<Tag> tags}) Future<void>
Tags a Voice ID resource with the provided list of tags.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes specified tags from a specified Amazon Connect Voice ID resource.
updateDomain({required String domainId, required String name, required ServerSideEncryptionConfiguration serverSideEncryptionConfiguration, String? description}) Future<UpdateDomainResponse>
Updates the specified domain. This API has clobber behavior, and clears and replaces all attributes. If an optional field, such as 'Description' is not provided, it is removed from the domain.
updateWatchlist({required String domainId, required String watchlistId, String? description, String? name}) Future<UpdateWatchlistResponse>
Updates the specified watchlist. Every domain has a default watchlist which cannot be updated.

Operators

operator ==(Object other) bool
The equality operator.
inherited