associateFraudster method
Associates the fraudsters with the watchlist specified in the same domain.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainId :
The identifier of the domain that contains the fraudster.
Parameter fraudsterId :
The identifier of the fraudster to be associated with the watchlist.
Parameter watchlistId :
The identifier of the watchlist you want to associate with the fraudster.
Implementation
Future<AssociateFraudsterResponse> associateFraudster({
required String domainId,
required String fraudsterId,
required String watchlistId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VoiceID.AssociateFraudster'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainId': domainId,
'FraudsterId': fraudsterId,
'WatchlistId': watchlistId,
},
);
return AssociateFraudsterResponse.fromJson(jsonResponse.body);
}