deleteFraudster method

Future<void> deleteFraudster({
  1. required String domainId,
  2. required String fraudsterId,
})

Deletes the specified fraudster from Voice ID. This action disassociates the fraudster from any watchlists it is a part of.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The identifier of the domain that contains the fraudster.

Parameter fraudsterId : The identifier of the fraudster you want to delete.

Implementation

Future<void> deleteFraudster({
  required String domainId,
  required String fraudsterId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VoiceID.DeleteFraudster'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DomainId': domainId,
      'FraudsterId': fraudsterId,
    },
  );
}