deleteSpeaker method

Future<void> deleteSpeaker({
  1. required String domainId,
  2. required String speakerId,
})

Deletes the specified speaker from Voice ID.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The identifier of the domain that contains the speaker.

Parameter speakerId : The identifier of the speaker you want to delete.

Implementation

Future<void> deleteSpeaker({
  required String domainId,
  required String speakerId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VoiceID.DeleteSpeaker'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DomainId': domainId,
      'SpeakerId': speakerId,
    },
  );
}