describeWatchlist method

Future<DescribeWatchlistResponse> describeWatchlist({
  1. required String domainId,
  2. required String watchlistId,
})

Describes the specified watchlist.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domainId : The identifier of the domain that contains the watchlist.

Parameter watchlistId : The identifier of the watchlist that you are describing.

Implementation

Future<DescribeWatchlistResponse> describeWatchlist({
  required String domainId,
  required String watchlistId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'VoiceID.DescribeWatchlist'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DomainId': domainId,
      'WatchlistId': watchlistId,
    },
  );

  return DescribeWatchlistResponse.fromJson(jsonResponse.body);
}