VpcLattice class
Amazon VPC Lattice is a fully managed application networking service that you use to connect, secure, and monitor all of your services across multiple accounts and virtual private clouds (VPCs). Amazon VPC Lattice interconnects your microservices and legacy services within a logical boundary, so that you can discover and manage them more efficiently. For more information, see the Amazon VPC Lattice User Guide
Constructors
- VpcLattice({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchUpdateRule(
{required String listenerIdentifier, required List< RuleUpdate> rules, required String serviceIdentifier}) → Future<BatchUpdateRuleResponse> - Updates the listener rules in a batch. You can use this operation to change the priority of listener rules. This can be useful when bulk updating or swapping rule priority.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessLogSubscription(
{required String destinationArn, required String resourceIdentifier, String? clientToken, ServiceNetworkLogType? serviceNetworkLogType, Map< String, String> ? tags}) → Future<CreateAccessLogSubscriptionResponse> - Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon Kinesis Data Firehose. The service network owner can use the access logs to audit the services in the network. The service network owner can only see access logs from clients and services that are associated with their service network. Access log entries represent traffic originated from VPCs associated with that network. For more information, see Access logs in the Amazon VPC Lattice User Guide.
-
createListener(
{required RuleAction defaultAction, required String name, required ListenerProtocol protocol, required String serviceIdentifier, String? clientToken, int? port, Map< String, String> ? tags}) → Future<CreateListenerResponse> - Creates a listener for a service. Before you start using your Amazon VPC Lattice service, you must add one or more listeners. A listener is a process that checks for connection requests to your services. For more information, see Listeners in the Amazon VPC Lattice User Guide.
-
createResourceConfiguration(
{required String name, required ResourceConfigurationType type, String? clientToken, String? customDomainName, String? domainVerificationIdentifier, String? groupDomain, List< String> ? portRanges, ProtocolType? protocol, ResourceConfigurationDefinition? resourceConfigurationDefinition, String? resourceConfigurationGroupIdentifier, String? resourceGatewayIdentifier, Map<String, String> ? tags}) → Future<CreateResourceConfigurationResponse> - Creates a resource configuration. A resource configuration defines a specific resource. You can associate a resource configuration with a service network or a VPC endpoint.
-
createResourceGateway(
{required String name, String? clientToken, ResourceGatewayIpAddressType? ipAddressType, int? ipv4AddressesPerEni, ResourceConfigDnsResolution? resourceConfigDnsResolution, List< String> ? securityGroupIds, List<String> ? subnetIds, Map<String, String> ? tags, String? vpcIdentifier}) → Future<CreateResourceGatewayResponse> - A resource gateway is a point of ingress into the VPC where a resource resides. It spans multiple Availability Zones. For your resource to be accessible from all Availability Zones, you should create your resource gateways to span as many Availability Zones as possible. A VPC can have multiple resource gateways.
-
createRule(
{required RuleAction action, required String listenerIdentifier, required RuleMatch match, required String name, required int priority, required String serviceIdentifier, String? clientToken, Map< String, String> ? tags}) → Future<CreateRuleResponse> - Creates a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions. For more information, see Listener rules in the Amazon VPC Lattice User Guide.
-
createService(
{required String name, AuthType? authType, String? certificateArn, String? clientToken, String? customDomainName, Map< String, String> ? tags}) → Future<CreateServiceResponse> - Creates a service. A service is any software application that can run on instances containers, or serverless functions within an account or virtual private cloud (VPC).
-
createServiceNetwork(
{required String name, AuthType? authType, String? clientToken, SharingConfig? sharingConfig, Map< String, String> ? tags}) → Future<CreateServiceNetworkResponse> - Creates a service network. A service network is a logical boundary for a collection of services. You can associate services and VPCs with a service network.
-
createServiceNetworkResourceAssociation(
{required String resourceConfigurationIdentifier, required String serviceNetworkIdentifier, String? clientToken, bool? privateDnsEnabled, Map< String, String> ? tags}) → Future<CreateServiceNetworkResourceAssociationResponse> - Associates the specified service network with the specified resource configuration. This allows the resource configuration to receive connections through the service network, including through a service network VPC endpoint.
-
createServiceNetworkServiceAssociation(
{required String serviceIdentifier, required String serviceNetworkIdentifier, String? clientToken, Map< String, String> ? tags}) → Future<CreateServiceNetworkServiceAssociationResponse> - Associates the specified service with the specified service network. For more information, see Manage service associations in the Amazon VPC Lattice User Guide.
-
createServiceNetworkVpcAssociation(
{required String serviceNetworkIdentifier, required String vpcIdentifier, String? clientToken, DnsOptions? dnsOptions, bool? privateDnsEnabled, List< String> ? securityGroupIds, Map<String, String> ? tags}) → Future<CreateServiceNetworkVpcAssociationResponse> - Associates a VPC with a service network. When you associate a VPC with the service network, it enables all the resources within that VPC to be clients and communicate with other services in the service network. For more information, see Manage VPC associations in the Amazon VPC Lattice User Guide.
-
createTargetGroup(
{required String name, required TargetGroupType type, String? clientToken, TargetGroupConfig? config, Map< String, String> ? tags}) → Future<CreateTargetGroupResponse> - Creates a target group. A target group is a collection of targets, or compute resources, that run your application or service. A target group can only be used by a single service.
-
deleteAccessLogSubscription(
{required String accessLogSubscriptionIdentifier}) → Future< void> - Deletes the specified access log subscription.
-
deleteAuthPolicy(
{required String resourceIdentifier}) → Future< void> -
Deletes the specified auth policy. If an auth is set to
AWS_IAMand the auth policy is deleted, all requests are denied. If you are trying to remove the auth policy completely, you must set the auth type toNONE. If auth is enabled on the resource, but no auth policy is set, all requests are denied. -
deleteDomainVerification(
{required String domainVerificationIdentifier}) → Future< void> - Deletes the specified domain verification.
-
deleteListener(
{required String listenerIdentifier, required String serviceIdentifier}) → Future< void> - Deletes the specified listener.
-
deleteResourceConfiguration(
{required String resourceConfigurationIdentifier}) → Future< void> - Deletes the specified resource configuration.
-
deleteResourceEndpointAssociation(
{required String resourceEndpointAssociationIdentifier}) → Future< DeleteResourceEndpointAssociationResponse> - Disassociates the resource configuration from the resource VPC endpoint.
-
deleteResourceGateway(
{required String resourceGatewayIdentifier}) → Future< DeleteResourceGatewayResponse> - Deletes the specified resource gateway.
-
deleteResourcePolicy(
{required String resourceArn}) → Future< void> - Deletes the specified resource policy.
-
deleteRule(
{required String listenerIdentifier, required String ruleIdentifier, required String serviceIdentifier}) → Future< void> - Deletes a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions. You can delete additional listener rules, but you cannot delete the default rule.
-
deleteService(
{required String serviceIdentifier}) → Future< DeleteServiceResponse> - Deletes a service. A service can't be deleted if it's associated with a service network. If you delete a service, all resources related to the service, such as the resource policy, auth policy, listeners, listener rules, and access log subscriptions, are also deleted. For more information, see Delete a service in the Amazon VPC Lattice User Guide.
-
deleteServiceNetwork(
{required String serviceNetworkIdentifier}) → Future< void> - Deletes a service network. You can only delete the service network if there is no service or VPC associated with it. If you delete a service network, all resources related to the service network, such as the resource policy, auth policy, and access log subscriptions, are also deleted. For more information, see Delete a service network in the Amazon VPC Lattice User Guide.
-
deleteServiceNetworkResourceAssociation(
{required String serviceNetworkResourceAssociationIdentifier}) → Future< DeleteServiceNetworkResourceAssociationResponse> - Deletes the association between a service network and a resource configuration.
-
deleteServiceNetworkServiceAssociation(
{required String serviceNetworkServiceAssociationIdentifier}) → Future< DeleteServiceNetworkServiceAssociationResponse> - Deletes the association between a service and a service network. This operation fails if an association is still in progress.
-
deleteServiceNetworkVpcAssociation(
{required String serviceNetworkVpcAssociationIdentifier}) → Future< DeleteServiceNetworkVpcAssociationResponse> - Disassociates the VPC from the service network. You can't disassociate the VPC if there is a create or update association in progress.
-
deleteTargetGroup(
{required String targetGroupIdentifier}) → Future< DeleteTargetGroupResponse> - Deletes a target group. You can't delete a target group if it is used in a listener rule or if the target group creation is in progress.
-
deregisterTargets(
{required String targetGroupIdentifier, required List< Target> targets}) → Future<DeregisterTargetsResponse> - Deregisters the specified targets from the specified target group.
-
getAccessLogSubscription(
{required String accessLogSubscriptionIdentifier}) → Future< GetAccessLogSubscriptionResponse> - Retrieves information about the specified access log subscription.
-
getAuthPolicy(
{required String resourceIdentifier}) → Future< GetAuthPolicyResponse> - Retrieves information about the auth policy for the specified service or service network.
-
getDomainVerification(
{required String domainVerificationIdentifier}) → Future< GetDomainVerificationResponse> - Retrieves information about a domain verification.ß
-
getListener(
{required String listenerIdentifier, required String serviceIdentifier}) → Future< GetListenerResponse> - Retrieves information about the specified listener for the specified service.
-
getResourceConfiguration(
{required String resourceConfigurationIdentifier}) → Future< GetResourceConfigurationResponse> - Retrieves information about the specified resource configuration.
-
getResourceGateway(
{required String resourceGatewayIdentifier}) → Future< GetResourceGatewayResponse> - Retrieves information about the specified resource gateway.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> - Retrieves information about the specified resource policy. The resource policy is an IAM policy created on behalf of the resource owner when they share a resource.
-
getRule(
{required String listenerIdentifier, required String ruleIdentifier, required String serviceIdentifier}) → Future< GetRuleResponse> - Retrieves information about the specified listener rules. You can also retrieve information about the default listener rule. For more information, see Listener rules in the Amazon VPC Lattice User Guide.
-
getService(
{required String serviceIdentifier}) → Future< GetServiceResponse> - Retrieves information about the specified service.
-
getServiceNetwork(
{required String serviceNetworkIdentifier}) → Future< GetServiceNetworkResponse> - Retrieves information about the specified service network.
-
getServiceNetworkResourceAssociation(
{required String serviceNetworkResourceAssociationIdentifier}) → Future< GetServiceNetworkResourceAssociationResponse> - Retrieves information about the specified association between a service network and a resource configuration.
-
getServiceNetworkServiceAssociation(
{required String serviceNetworkServiceAssociationIdentifier}) → Future< GetServiceNetworkServiceAssociationResponse> - Retrieves information about the specified association between a service network and a service.
-
getServiceNetworkVpcAssociation(
{required String serviceNetworkVpcAssociationIdentifier}) → Future< GetServiceNetworkVpcAssociationResponse> - Retrieves information about the specified association between a service network and a VPC.
-
getTargetGroup(
{required String targetGroupIdentifier}) → Future< GetTargetGroupResponse> - Retrieves information about the specified target group.
-
listAccessLogSubscriptions(
{required String resourceIdentifier, int? maxResults, String? nextToken}) → Future< ListAccessLogSubscriptionsResponse> - Lists the access log subscriptions for the specified service network or service.
-
listDomainVerifications(
{int? maxResults, String? nextToken}) → Future< ListDomainVerificationsResponse> - Lists the domain verifications.
-
listListeners(
{required String serviceIdentifier, int? maxResults, String? nextToken}) → Future< ListListenersResponse> - Lists the listeners for the specified service.
-
listResourceConfigurations(
{String? domainVerificationIdentifier, int? maxResults, String? nextToken, String? resourceConfigurationGroupIdentifier, String? resourceGatewayIdentifier}) → Future< ListResourceConfigurationsResponse> - Lists the resource configurations owned by or shared with this account.
-
listResourceEndpointAssociations(
{required String resourceConfigurationIdentifier, int? maxResults, String? nextToken, String? resourceEndpointAssociationIdentifier, String? vpcEndpointId, String? vpcEndpointOwner}) → Future< ListResourceEndpointAssociationsResponse> - Lists the associations for the specified VPC endpoint.
-
listResourceGateways(
{int? maxResults, String? nextToken}) → Future< ListResourceGatewaysResponse> - Lists the resource gateways that you own or that were shared with you.
-
listRules(
{required String listenerIdentifier, required String serviceIdentifier, int? maxResults, String? nextToken}) → Future< ListRulesResponse> - Lists the rules for the specified listener.
-
listServiceNetworkResourceAssociations(
{bool? includeChildren, int? maxResults, String? nextToken, String? resourceConfigurationIdentifier, String? serviceNetworkIdentifier}) → Future< ListServiceNetworkResourceAssociationsResponse> - Lists the associations between a service network and a resource configuration.
-
listServiceNetworks(
{int? maxResults, String? nextToken}) → Future< ListServiceNetworksResponse> - Lists the service networks owned by or shared with this account. The account ID in the ARN shows which account owns the service network.
-
listServiceNetworkServiceAssociations(
{int? maxResults, String? nextToken, String? serviceIdentifier, String? serviceNetworkIdentifier}) → Future< ListServiceNetworkServiceAssociationsResponse> - Lists the associations between a service network and a service. You can filter the list either by service or service network. You must provide either the service network identifier or the service identifier.
-
listServiceNetworkVpcAssociations(
{int? maxResults, String? nextToken, String? serviceNetworkIdentifier, String? vpcIdentifier}) → Future< ListServiceNetworkVpcAssociationsResponse> - Lists the associations between a service network and a VPC. You can filter the list either by VPC or service network. You must provide either the ID of the service network identifier or the ID of the VPC.
-
listServiceNetworkVpcEndpointAssociations(
{required String serviceNetworkIdentifier, int? maxResults, String? nextToken}) → Future< ListServiceNetworkVpcEndpointAssociationsResponse> - Lists the associations between a service network and a VPC endpoint.
-
listServices(
{int? maxResults, String? nextToken}) → Future< ListServicesResponse> - Lists the services owned by the caller account or shared with the caller account.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for the specified resource.
-
listTargetGroups(
{int? maxResults, String? nextToken, TargetGroupType? targetGroupType, String? vpcIdentifier}) → Future< ListTargetGroupsResponse> - Lists your target groups. You can narrow your search by using the filters below in your request.
-
listTargets(
{required String targetGroupIdentifier, int? maxResults, String? nextToken, List< Target> ? targets}) → Future<ListTargetsResponse> - Lists the targets for the target group. By default, all targets are included. You can use this API to check the health status of targets. You can also filter the results by target.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAuthPolicy(
{required String policy, required String resourceIdentifier}) → Future< PutAuthPolicyResponse> - Creates or updates the auth policy. The policy string in JSON must not contain newlines or blank lines.
-
putResourcePolicy(
{required String policy, required String resourceArn}) → Future< void> - Attaches a resource-based permission policy to a service or service network. The policy must contain the same actions and condition statements as the Amazon Web Services Resource Access Manager permission for sharing services and service networks.
-
registerTargets(
{required String targetGroupIdentifier, required List< Target> targets}) → Future<RegisterTargetsResponse> - Registers the targets with the target group. If it's a Lambda target, you can only have one target in a target group.
-
startDomainVerification(
{required String domainName, String? clientToken, Map< String, String> ? tags}) → Future<StartDomainVerificationResponse> - Starts the domain verification process for a custom domain name.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds the specified tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the specified resource.
-
updateAccessLogSubscription(
{required String accessLogSubscriptionIdentifier, required String destinationArn}) → Future< UpdateAccessLogSubscriptionResponse> - Updates the specified access log subscription.
-
updateListener(
{required RuleAction defaultAction, required String listenerIdentifier, required String serviceIdentifier}) → Future< UpdateListenerResponse> - Updates the specified listener for the specified service.
-
updateResourceConfiguration(
{required String resourceConfigurationIdentifier, List< String> ? portRanges, ResourceConfigurationDefinition? resourceConfigurationDefinition}) → Future<UpdateResourceConfigurationResponse> - Updates the specified resource configuration.
-
updateResourceGateway(
{required String resourceGatewayIdentifier, List< String> ? securityGroupIds}) → Future<UpdateResourceGatewayResponse> - Updates the specified resource gateway.
-
updateRule(
{required String listenerIdentifier, required String ruleIdentifier, required String serviceIdentifier, RuleAction? action, RuleMatch? match, int? priority}) → Future< UpdateRuleResponse> -
Updates a specified rule for the listener. You can't modify a default
listener rule. To modify a default listener rule, use
UpdateListener. -
updateService(
{required String serviceIdentifier, AuthType? authType, String? certificateArn}) → Future< UpdateServiceResponse> - Updates the specified service.
-
updateServiceNetwork(
{required AuthType authType, required String serviceNetworkIdentifier}) → Future< UpdateServiceNetworkResponse> - Updates the specified service network.
-
updateServiceNetworkVpcAssociation(
{required List< String> securityGroupIds, required String serviceNetworkVpcAssociationIdentifier}) → Future<UpdateServiceNetworkVpcAssociationResponse> - Updates the service network and VPC association. If you add a security group to the service network and VPC association, the association must continue to have at least one security group. You can add or edit security groups at any time. However, to remove all security groups, you must first delete the association and then recreate it without security groups.
-
updateTargetGroup(
{required HealthCheckConfig healthCheck, required String targetGroupIdentifier}) → Future< UpdateTargetGroupResponse> - Updates the specified target group.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited