deleteAuthPolicy method

Future<void> deleteAuthPolicy({
  1. required String resourceIdentifier,
})

Deletes the specified auth policy. If an auth is set to AWS_IAM and the auth policy is deleted, all requests are denied. If you are trying to remove the auth policy completely, you must set the auth type to NONE. If auth is enabled on the resource, but no auth policy is set, all requests are denied.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter resourceIdentifier : The ID or ARN of the resource.

Implementation

Future<void> deleteAuthPolicy({
  required String resourceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/authpolicy/${Uri.encodeComponent(resourceIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
}