deleteRule method

Future<void> deleteRule({
  1. required String listenerIdentifier,
  2. required String ruleIdentifier,
  3. required String serviceIdentifier,
})

Deletes a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions. You can delete additional listener rules, but you cannot delete the default rule.

For more information, see Listener rules in the Amazon VPC Lattice User Guide.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter listenerIdentifier : The ID or ARN of the listener.

Parameter ruleIdentifier : The ID or ARN of the rule.

Parameter serviceIdentifier : The ID or ARN of the service.

Implementation

Future<void> deleteRule({
  required String listenerIdentifier,
  required String ruleIdentifier,
  required String serviceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/services/${Uri.encodeComponent(serviceIdentifier)}/listeners/${Uri.encodeComponent(listenerIdentifier)}/rules/${Uri.encodeComponent(ruleIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
}