deleteServiceNetworkServiceAssociation method
Future<DeleteServiceNetworkServiceAssociationResponse>
deleteServiceNetworkServiceAssociation({
- required String serviceNetworkServiceAssociationIdentifier,
Deletes the association between a service and a service network. This operation fails if an association is still in progress.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter serviceNetworkServiceAssociationIdentifier :
The ID or ARN of the association.
Implementation
Future<DeleteServiceNetworkServiceAssociationResponse>
deleteServiceNetworkServiceAssociation({
required String serviceNetworkServiceAssociationIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/servicenetworkserviceassociations/${Uri.encodeComponent(serviceNetworkServiceAssociationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return DeleteServiceNetworkServiceAssociationResponse.fromJson(response);
}