getRule method

Future<GetRuleResponse> getRule({
  1. required String listenerIdentifier,
  2. required String ruleIdentifier,
  3. required String serviceIdentifier,
})

Retrieves information about the specified listener rules. You can also retrieve information about the default listener rule. For more information, see Listener rules in the Amazon VPC Lattice User Guide.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter listenerIdentifier : The ID or ARN of the listener.

Parameter ruleIdentifier : The ID or ARN of the listener rule.

Parameter serviceIdentifier : The ID or ARN of the service.

Implementation

Future<GetRuleResponse> getRule({
  required String listenerIdentifier,
  required String ruleIdentifier,
  required String serviceIdentifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/services/${Uri.encodeComponent(serviceIdentifier)}/listeners/${Uri.encodeComponent(listenerIdentifier)}/rules/${Uri.encodeComponent(ruleIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetRuleResponse.fromJson(response);
}