listAccessLogSubscriptions method
Lists the access log subscriptions for the specified service network or service.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceIdentifier :
The ID or ARN of the service network or service.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
A pagination token for the next page of results.
Implementation
Future<ListAccessLogSubscriptionsResponse> listAccessLogSubscriptions({
required String resourceIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
'resourceIdentifier': [resourceIdentifier],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accesslogsubscriptions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAccessLogSubscriptionsResponse.fromJson(response);
}