listResourceGateways method
Lists the resource gateways that you own or that were shared with you.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum page size.
Parameter nextToken :
If there are additional results, a pagination token for the next page of
results.
Implementation
Future<ListResourceGatewaysResponse> listResourceGateways({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/resourcegateways',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListResourceGatewaysResponse.fromJson(response);
}