listServiceNetworkResourceAssociations method

Future<ListServiceNetworkResourceAssociationsResponse> listServiceNetworkResourceAssociations({
  1. bool? includeChildren,
  2. int? maxResults,
  3. String? nextToken,
  4. String? resourceConfigurationIdentifier,
  5. String? serviceNetworkIdentifier,
})

Lists the associations between a service network and a resource configuration.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter includeChildren : Include service network resource associations of the child resource configuration with the grouped resource configuration.

The type is boolean and the default value is false.

Parameter maxResults : The maximum page size.

Parameter nextToken : If there are additional results, a pagination token for the next page of results.

Parameter resourceConfigurationIdentifier : The ID of the resource configuration.

Parameter serviceNetworkIdentifier : The ID of the service network.

Implementation

Future<ListServiceNetworkResourceAssociationsResponse>
    listServiceNetworkResourceAssociations({
  bool? includeChildren,
  int? maxResults,
  String? nextToken,
  String? resourceConfigurationIdentifier,
  String? serviceNetworkIdentifier,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (includeChildren != null)
      'includeChildren': [includeChildren.toString()],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
    if (resourceConfigurationIdentifier != null)
      'resourceConfigurationIdentifier': [resourceConfigurationIdentifier],
    if (serviceNetworkIdentifier != null)
      'serviceNetworkIdentifier': [serviceNetworkIdentifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/servicenetworkresourceassociations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListServiceNetworkResourceAssociationsResponse.fromJson(response);
}