listServiceNetworkVpcEndpointAssociations method

Future<ListServiceNetworkVpcEndpointAssociationsResponse> listServiceNetworkVpcEndpointAssociations({
  1. required String serviceNetworkIdentifier,
  2. int? maxResults,
  3. String? nextToken,
})

Lists the associations between a service network and a VPC endpoint.

May throw AccessDeniedException. May throw InternalServerException. May throw ThrottlingException. May throw ValidationException.

Parameter serviceNetworkIdentifier : The ID of the service network associated with the VPC endpoint.

Parameter maxResults : The maximum page size.

Parameter nextToken : If there are additional results, a pagination token for the next page of results.

Implementation

Future<ListServiceNetworkVpcEndpointAssociationsResponse>
    listServiceNetworkVpcEndpointAssociations({
  required String serviceNetworkIdentifier,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    'serviceNetworkIdentifier': [serviceNetworkIdentifier],
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/servicenetworkvpcendpointassociations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListServiceNetworkVpcEndpointAssociationsResponse.fromJson(response);
}