listServices method
Lists the services owned by the caller account or shared with the caller account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
A pagination token for the next page of results.
Implementation
Future<ListServicesResponse> listServices({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/services',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListServicesResponse.fromJson(response);
}