startDomainVerification method

Future<StartDomainVerificationResponse> startDomainVerification({
  1. required String domainName,
  2. String? clientToken,
  3. Map<String, String>? tags,
})

Starts the domain verification process for a custom domain name.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domainName : The domain name to verify ownership for.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren't identical, the retry fails.

Parameter tags : The tags for the domain verification.

Implementation

Future<StartDomainVerificationResponse> startDomainVerification({
  required String domainName,
  String? clientToken,
  Map<String, String>? tags,
}) async {
  final $payload = <String, dynamic>{
    'domainName': domainName,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (tags != null) 'tags': tags,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/domainverifications',
    exceptionFnMap: _exceptionFns,
  );
  return StartDomainVerificationResponse.fromJson(response);
}