updateServiceNetworkVpcAssociation method

Future<UpdateServiceNetworkVpcAssociationResponse> updateServiceNetworkVpcAssociation({
  1. required List<String> securityGroupIds,
  2. required String serviceNetworkVpcAssociationIdentifier,
})

Updates the service network and VPC association. If you add a security group to the service network and VPC association, the association must continue to have at least one security group. You can add or edit security groups at any time. However, to remove all security groups, you must first delete the association and then recreate it without security groups.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter securityGroupIds : The IDs of the security groups.

Parameter serviceNetworkVpcAssociationIdentifier : The ID or ARN of the association.

Implementation

Future<UpdateServiceNetworkVpcAssociationResponse>
    updateServiceNetworkVpcAssociation({
  required List<String> securityGroupIds,
  required String serviceNetworkVpcAssociationIdentifier,
}) async {
  final $payload = <String, dynamic>{
    'securityGroupIds': securityGroupIds,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/servicenetworkvpcassociations/${Uri.encodeComponent(serviceNetworkVpcAssociationIdentifier)}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateServiceNetworkVpcAssociationResponse.fromJson(response);
}