associateWebACL method
Associates a web ACL with a resource, to protect the resource.
Use this for all resource types except for Amazon CloudFront
distributions. For Amazon CloudFront, call UpdateDistribution
for the distribution and provide the Amazon Resource Name (ARN) of the web
ACL in the web ACL ID. For information, see UpdateDistribution
in the Amazon CloudFront Developer Guide.
Required permissions for customer-managed IAM policies
This call requires permissions that are specific to the protected resource type. For details, see Permissions for AssociateWebACL in the WAF Developer Guide.
Temporary inconsistencies during updates
When you create or change a web ACL or other WAF resources, the changes take a small amount of time to propagate to all areas where the resources are stored. The propagation time can be from a few seconds to a number of minutes.
The following are examples of the temporary inconsistencies that you might notice during change propagation:
- After you create a web ACL, if you try to associate it with a resource, you might get an exception indicating that the web ACL is unavailable.
- After you add a rule group to a web ACL, the new rule group rules might be in effect in one area where the web ACL is used and not in another.
- After you change a rule action setting, you might see the old action in some places and the new action in others.
- After you add an IP address to an IP set that is in use in a blocking rule, the new address might be blocked in one area while still allowed in another.
May throw WAFFeatureNotIncludedInPricingPlanException.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFLimitsExceededException.
May throw WAFNonexistentItemException.
May throw WAFUnavailableEntityException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to associate with the web
ACL.
The ARN must be in one of the following formats:
-
For an Application Load Balancer:
arn:partition:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id -
For an Amazon API Gateway REST API:
arn:partition:apigateway:region::/restapis/api-id/stages/stage-name -
For an AppSync GraphQL API:
arn:partition:appsync:region:account-id:apis/GraphQLApiId -
For an Amazon Cognito user pool:
arn:partition:cognito-idp:region:account-id:userpool/user-pool-id -
For an App Runner service:
arn:partition:apprunner:region:account-id:service/apprunner-service-name/apprunner-service-id -
For an Amazon Web Services Verified Access instance:
arn:partition:ec2:region:account-id:verified-access-instance/instance-id -
For an Amplify application:
arn:partition:amplify:region:account-id:apps/app-id
Parameter webACLArn :
The Amazon Resource Name (ARN) of the web ACL that you want to associate
with the resource.
Implementation
Future<void> associateWebACL({
required String resourceArn,
required String webACLArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.AssociateWebACL'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'WebACLArn': webACLArn,
},
);
}