createIPSet method
Creates an IPSet, which you use to identify web requests that originate from specific IP addresses or ranges of IP addresses. For example, if you're receiving a lot of requests from a ranges of IP addresses, you can configure WAF to block them using an IPSet that lists those IP addresses.
May throw WAFDuplicateItemException.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFLimitsExceededException.
May throw WAFOptimisticLockException.
May throw WAFTagOperationException.
May throw WAFTagOperationInternalErrorException.
Parameter addresses :
Contains an array of strings that specifies zero or more IP addresses or
blocks of IP addresses that you want WAF to inspect for in incoming
requests. All addresses must be specified using Classless Inter-Domain
Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except
for /0.
Example address strings:
-
For requests that originated from the IP address 192.0.2.44, specify
192.0.2.44/32. -
For requests that originated from IP addresses from 192.0.2.0 to
192.0.2.255, specify
192.0.2.0/24. -
For requests that originated from the IP address
1111:0000:0000:0000:0000:0000:0000:0111, specify
1111:0000:0000:0000:0000:0000:0000:0111/128. -
For requests that originated from IP addresses
1111:0000:0000:0000:0000:0000:0000:0000 to
1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify
1111:0000:0000:0000:0000:0000:0000:0000/64.
Example JSON Addresses specifications:
-
Empty array:
"Addresses": \[\] -
Array with one address:
"Addresses": \["192.0.2.44/32"\] -
Array with three addresses:
"Addresses": \["192.0.2.44/32", "192.0.2.0/24", "192.0.0.0/16"\] -
INVALID specification:
"Addresses": \[""\]INVALID
Parameter iPAddressVersion :
The version of the IP addresses, either IPV4 or
IPV6.
Parameter name :
The name of the IP set. You cannot change the name of an
IPSet after you create it.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter description :
A description of the IP set that helps with identification.
Parameter tags :
An array of key:value pairs to associate with the resource.
Implementation
Future<CreateIPSetResponse> createIPSet({
required List<String> addresses,
required IPAddressVersion iPAddressVersion,
required String name,
required Scope scope,
String? description,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.CreateIPSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Addresses': addresses,
'IPAddressVersion': iPAddressVersion.value,
'Name': name,
'Scope': scope.value,
if (description != null) 'Description': description,
if (tags != null) 'Tags': tags,
},
);
return CreateIPSetResponse.fromJson(jsonResponse.body);
}