deleteFirewallManagerRuleGroups method
Deletes all rule groups that are managed by Firewall Manager from the specified WebACL.
You can only use this if ManagedByFirewallManager and
RetrofittedByFirewallManager are both false in the web ACL.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
Parameter webACLArn :
The Amazon Resource Name (ARN) of the web ACL.
Parameter webACLLockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Implementation
Future<DeleteFirewallManagerRuleGroupsResponse>
deleteFirewallManagerRuleGroups({
required String webACLArn,
required String webACLLockToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.DeleteFirewallManagerRuleGroups'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WebACLArn': webACLArn,
'WebACLLockToken': webACLLockToken,
},
);
return DeleteFirewallManagerRuleGroupsResponse.fromJson(jsonResponse.body);
}