getIPSet method

Future<GetIPSetResponse> getIPSet({
  1. required String id,
  2. required String name,
  3. required Scope scope,
})

Retrieves the specified IPSet.

May throw WAFInternalErrorException. May throw WAFInvalidOperationException. May throw WAFInvalidParameterException. May throw WAFNonexistentItemException.

Parameter id : A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Parameter name : The name of the IP set. You cannot change the name of an IPSet after you create it.

Parameter scope : Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.
  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Implementation

Future<GetIPSetResponse> getIPSet({
  required String id,
  required String name,
  required Scope scope,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSWAF_20190729.GetIPSet'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'Name': name,
      'Scope': scope.value,
    },
  );

  return GetIPSetResponse.fromJson(jsonResponse.body);
}