getRegexPatternSet method
Retrieves the specified RegexPatternSet.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
Parameter id :
A unique identifier for the set. This ID is returned in the responses to
create and list commands. You provide it to operations like update and
delete.
Parameter name :
The name of the set. You cannot change the name after you create the set.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Implementation
Future<GetRegexPatternSetResponse> getRegexPatternSet({
required String id,
required String name,
required Scope scope,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.GetRegexPatternSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'Name': name,
'Scope': scope.value,
},
);
return GetRegexPatternSetResponse.fromJson(jsonResponse.body);
}