getSampledRequests method

Future<GetSampledRequestsResponse> getSampledRequests({
  1. required int maxItems,
  2. required String ruleMetricName,
  3. required Scope scope,
  4. required TimeWindow timeWindow,
  5. required String webAclArn,
})

Gets detailed information about a specified number of requests--a sample--that WAF randomly selects from among the first 5,000 requests that your Amazon Web Services resource received during a time range that you choose. You can specify a sample size of up to 500 requests, and you can specify any time range in the previous three hours.

GetSampledRequests returns a time range, which is usually the time range that you specified. However, if your resource (such as a CloudFront distribution) received 5,000 requests before the specified time range elapsed, GetSampledRequests returns an updated time range. This new time range indicates the actual period during which WAF selected the requests in the sample.

May throw WAFInternalErrorException. May throw WAFInvalidParameterException. May throw WAFNonexistentItemException.

Parameter maxItems : The number of requests that you want WAF to return from among the first 5,000 requests that your Amazon Web Services resource received during the time range. If your resource received fewer requests than the value of MaxItems, GetSampledRequests returns information about all of them.

Parameter ruleMetricName : The metric name assigned to the Rule or RuleGroup dimension for which you want a sample of requests.

Parameter scope : Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.
  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Parameter timeWindow : The start date and time and the end date and time of the range for which you want GetSampledRequests to return a sample of requests. You must specify the times in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, "2016-09-27T14:50Z". You can specify any time range in the previous three hours. If you specify a start time that's earlier than three hours ago, WAF sets it to three hours ago.

Parameter webAclArn : The Amazon resource name (ARN) of the WebACL for which you want a sample of requests.

Implementation

Future<GetSampledRequestsResponse> getSampledRequests({
  required int maxItems,
  required String ruleMetricName,
  required Scope scope,
  required TimeWindow timeWindow,
  required String webAclArn,
}) async {
  _s.validateNumRange(
    'maxItems',
    maxItems,
    1,
    500,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSWAF_20190729.GetSampledRequests'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MaxItems': maxItems,
      'RuleMetricName': ruleMetricName,
      'Scope': scope.value,
      'TimeWindow': timeWindow,
      'WebAclArn': webAclArn,
    },
  );

  return GetSampledRequestsResponse.fromJson(jsonResponse.body);
}