getWebACL method
Retrieves the specified WebACL.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
Parameter arn :
The Amazon Resource Name (ARN) of the web ACL that you want to retrieve.
Parameter id :
The unique identifier for the web ACL. This ID is returned in the
responses to create and list commands. You provide it to operations like
update and delete.
Parameter name :
The name of the web ACL. You cannot change the name of a web ACL after you
create it.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Implementation
Future<GetWebACLResponse> getWebACL({
String? arn,
String? id,
String? name,
Scope? scope,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.GetWebACL'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (arn != null) 'ARN': arn,
if (id != null) 'Id': id,
if (name != null) 'Name': name,
if (scope != null) 'Scope': scope.value,
},
);
return GetWebACLResponse.fromJson(jsonResponse.body);
}