listAPIKeys method
Retrieves a list of the API keys that you've defined for the specified scope.
API keys are required for the integration of the CAPTCHA API in your JavaScript client applications. The API lets you customize the placement and characteristics of the CAPTCHA puzzle for your end users. For more information about the CAPTCHA JavaScript integration, see WAF client application integration in the WAF Developer Guide.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFInvalidResourceException.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter limit :
The maximum number of objects that you want WAF to return for this
request. If more objects are available, in the response, WAF provides a
NextMarker value that you can use in a subsequent call to get
the next batch of objects.
Parameter nextMarker :
When you request a list of objects with a Limit setting, if
the number of objects that are still available for retrieval exceeds the
limit, WAF returns a NextMarker value in the response. To
retrieve the next batch of objects, provide the marker from the prior call
in your next request.
Implementation
Future<ListAPIKeysResponse> listAPIKeys({
required Scope scope,
int? limit,
String? nextMarker,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.ListAPIKeys'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Scope': scope.value,
if (limit != null) 'Limit': limit,
if (nextMarker != null) 'NextMarker': nextMarker,
},
);
return ListAPIKeysResponse.fromJson(jsonResponse.body);
}