listLoggingConfigurations method
Retrieves an array of your LoggingConfiguration objects.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter limit :
The maximum number of objects that you want WAF to return for this
request. If more objects are available, in the response, WAF provides a
NextMarker value that you can use in a subsequent call to get
the next batch of objects.
Parameter logScope :
The owner of the logging configuration, which must be set to
CUSTOMER for the configurations that you manage.
The log scope SECURITY_LAKE indicates a configuration that is
managed through Amazon Security Lake. You can use Security Lake to collect
log and event data from various sources for normalization, analysis, and
management. For information, see Collecting
data from Amazon Web Services services in the Amazon Security Lake
user guide.
The log scope CLOUDWATCH_TELEMETRY_RULE_MANAGED indicates a
configuration that is managed through Amazon CloudWatch Logs for telemetry
data collection and analysis. For information, see What
is Amazon CloudWatch Logs ? in the Amazon CloudWatch Logs user
guide.
Default: CUSTOMER
Parameter nextMarker :
When you request a list of objects with a Limit setting, if
the number of objects that are still available for retrieval exceeds the
limit, WAF returns a NextMarker value in the response. To
retrieve the next batch of objects, provide the marker from the prior call
in your next request.
Implementation
Future<ListLoggingConfigurationsResponse> listLoggingConfigurations({
required Scope scope,
int? limit,
LogScope? logScope,
String? nextMarker,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.ListLoggingConfigurations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Scope': scope.value,
if (limit != null) 'Limit': limit,
if (logScope != null) 'LogScope': logScope.value,
if (nextMarker != null) 'NextMarker': nextMarker,
},
);
return ListLoggingConfigurationsResponse.fromJson(jsonResponse.body);
}