listResourcesForWebACL method
- required String webACLArn,
- ResourceType? resourceType,
Retrieves an array of the Amazon Resource Names (ARNs) for the resources that are associated with the specified web ACL.
For Amazon CloudFront, don't use this call. Instead, use the CloudFront
call ListDistributionsByWebACLId. For information, see ListDistributionsByWebACLId
in the Amazon CloudFront API Reference.
Required permissions for customer-managed IAM policies
This call requires permissions that are specific to the protected resource type. For details, see Permissions for ListResourcesForWebACL in the WAF Developer Guide.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
Parameter webACLArn :
The Amazon Resource Name (ARN) of the web ACL.
Parameter resourceType :
Retrieves the web ACLs that are used by the specified resource type.
For Amazon CloudFront, don't use this call. Instead, use the CloudFront
call ListDistributionsByWebACLId. For information, see ListDistributionsByWebACLId
in the Amazon CloudFront API Reference.
Default: APPLICATION_LOAD_BALANCER
Implementation
Future<ListResourcesForWebACLResponse> listResourcesForWebACL({
required String webACLArn,
ResourceType? resourceType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.ListResourcesForWebACL'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WebACLArn': webACLArn,
if (resourceType != null) 'ResourceType': resourceType.value,
},
);
return ListResourcesForWebACLResponse.fromJson(jsonResponse.body);
}