updateIPSet method
Updates the specified IPSet.
To modify an IP set, do the following:
- Retrieve it by calling GetIPSet
- Update its settings as needed
- Provide the complete IP set specification to this call
When you create or change a web ACL or other WAF resources, the changes take a small amount of time to propagate to all areas where the resources are stored. The propagation time can be from a few seconds to a number of minutes.
The following are examples of the temporary inconsistencies that you might notice during change propagation:
- After you create a web ACL, if you try to associate it with a resource, you might get an exception indicating that the web ACL is unavailable.
- After you add a rule group to a web ACL, the new rule group rules might be in effect in one area where the web ACL is used and not in another.
- After you change a rule action setting, you might see the old action in some places and the new action in others.
- After you add an IP address to an IP set that is in use in a blocking rule, the new address might be blocked in one area while still allowed in another.
May throw WAFDuplicateItemException.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFLimitsExceededException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
Parameter addresses :
Contains an array of strings that specifies zero or more IP addresses or
blocks of IP addresses that you want WAF to inspect for in incoming
requests. All addresses must be specified using Classless Inter-Domain
Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except
for /0.
Example address strings:
-
For requests that originated from the IP address 192.0.2.44, specify
192.0.2.44/32. -
For requests that originated from IP addresses from 192.0.2.0 to
192.0.2.255, specify
192.0.2.0/24. -
For requests that originated from the IP address
1111:0000:0000:0000:0000:0000:0000:0111, specify
1111:0000:0000:0000:0000:0000:0000:0111/128. -
For requests that originated from IP addresses
1111:0000:0000:0000:0000:0000:0000:0000 to
1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify
1111:0000:0000:0000:0000:0000:0000:0000/64.
Example JSON Addresses specifications:
-
Empty array:
"Addresses": \[\] -
Array with one address:
"Addresses": \["192.0.2.44/32"\] -
Array with three addresses:
"Addresses": \["192.0.2.44/32", "192.0.2.0/24", "192.0.0.0/16"\] -
INVALID specification:
"Addresses": \[""\]INVALID
Parameter id :
A unique identifier for the set. This ID is returned in the responses to
create and list commands. You provide it to operations like update and
delete.
Parameter lockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Parameter name :
The name of the IP set. You cannot change the name of an
IPSet after you create it.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter description :
A description of the IP set that helps with identification.
Implementation
Future<UpdateIPSetResponse> updateIPSet({
required List<String> addresses,
required String id,
required String lockToken,
required String name,
required Scope scope,
String? description,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.UpdateIPSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Addresses': addresses,
'Id': id,
'LockToken': lockToken,
'Name': name,
'Scope': scope.value,
if (description != null) 'Description': description,
},
);
return UpdateIPSetResponse.fromJson(jsonResponse.body);
}