updateManagedRuleSetVersionExpiryDate method
Updates the expiration information for your managed rule set. Use this to initiate the expiration of a managed rule group version. After you initiate expiration for a version, WAF excludes it from the response to ListAvailableManagedRuleGroupVersions for the managed rule group.
Vendors, you can use the managed rule set APIs to provide controlled
rollout of your versioned managed rule group offerings for your customers.
The APIs are ListManagedRuleSets,
GetManagedRuleSet, PutManagedRuleSetVersions,
and UpdateManagedRuleSetVersionExpiryDate.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
Parameter expiryTimestamp :
The time that you want the version to expire.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, "2016-09-27T14:50Z".
Parameter id :
A unique identifier for the managed rule set. The ID is returned in the
responses to commands like list. You provide it to operations
like get and update.
Parameter lockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Parameter name :
The name of the managed rule set. You use this, along with the rule set
ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter versionToExpire :
The version that you want to remove from your list of offerings for the
named managed rule group.
Implementation
Future<UpdateManagedRuleSetVersionExpiryDateResponse>
updateManagedRuleSetVersionExpiryDate({
required DateTime expiryTimestamp,
required String id,
required String lockToken,
required String name,
required Scope scope,
required String versionToExpire,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.UpdateManagedRuleSetVersionExpiryDate'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ExpiryTimestamp': unixTimestampToJson(expiryTimestamp),
'Id': id,
'LockToken': lockToken,
'Name': name,
'Scope': scope.value,
'VersionToExpire': versionToExpire,
},
);
return UpdateManagedRuleSetVersionExpiryDateResponse.fromJson(
jsonResponse.body);
}