updateRegexPatternSet method

Future<UpdateRegexPatternSetResponse> updateRegexPatternSet({
  1. required String id,
  2. required String lockToken,
  3. required String name,
  4. required List<Regex> regularExpressionList,
  5. required Scope scope,
  6. String? description,
})

Updates the specified RegexPatternSet.

To modify a regex pattern set, do the following:

  1. Retrieve it by calling GetRegexPatternSet
  2. Update its settings as needed
  3. Provide the complete regex pattern set specification to this call
Temporary inconsistencies during updates

When you create or change a web ACL or other WAF resources, the changes take a small amount of time to propagate to all areas where the resources are stored. The propagation time can be from a few seconds to a number of minutes.

The following are examples of the temporary inconsistencies that you might notice during change propagation:

  • After you create a web ACL, if you try to associate it with a resource, you might get an exception indicating that the web ACL is unavailable.
  • After you add a rule group to a web ACL, the new rule group rules might be in effect in one area where the web ACL is used and not in another.
  • After you change a rule action setting, you might see the old action in some places and the new action in others.
  • After you add an IP address to an IP set that is in use in a blocking rule, the new address might be blocked in one area while still allowed in another.

May throw WAFDuplicateItemException. May throw WAFInternalErrorException. May throw WAFInvalidOperationException. May throw WAFInvalidParameterException. May throw WAFLimitsExceededException. May throw WAFNonexistentItemException. May throw WAFOptimisticLockException.

Parameter id : A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Parameter lockToken : A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.

Parameter name : The name of the set. You cannot change the name after you create the set.

Parameter regularExpressionList :

Parameter scope : Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.
  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Parameter description : A description of the set that helps with identification.

Implementation

Future<UpdateRegexPatternSetResponse> updateRegexPatternSet({
  required String id,
  required String lockToken,
  required String name,
  required List<Regex> regularExpressionList,
  required Scope scope,
  String? description,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSWAF_20190729.UpdateRegexPatternSet'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Id': id,
      'LockToken': lockToken,
      'Name': name,
      'RegularExpressionList': regularExpressionList,
      'Scope': scope.value,
      if (description != null) 'Description': description,
    },
  );

  return UpdateRegexPatternSetResponse.fromJson(jsonResponse.body);
}