updateRuleGroup method
Updates the specified RuleGroup.
To modify a rule group, do the following:
- Retrieve it by calling GetRuleGroup
- Update its settings as needed
- Provide the complete rule group specification to this call
Temporary inconsistencies during updates
When you create or change a web ACL or other WAF resources, the changes take a small amount of time to propagate to all areas where the resources are stored. The propagation time can be from a few seconds to a number of minutes.
The following are examples of the temporary inconsistencies that you might notice during change propagation:
- After you create a web ACL, if you try to associate it with a resource, you might get an exception indicating that the web ACL is unavailable.
- After you add a rule group to a web ACL, the new rule group rules might be in effect in one area where the web ACL is used and not in another.
- After you change a rule action setting, you might see the old action in some places and the new action in others.
- After you add an IP address to an IP set that is in use in a blocking rule, the new address might be blocked in one area while still allowed in another.
May throw WAFConfigurationWarningException.
May throw WAFDuplicateItemException.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFLimitsExceededException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
May throw WAFSubscriptionNotFoundException.
May throw WAFUnavailableEntityException.
Parameter id :
A unique identifier for the rule group. This ID is returned in the
responses to create and list commands. You provide it to operations like
update and delete.
Parameter lockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Parameter name :
The name of the rule group. You cannot change the name of a rule group
after you create it.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter visibilityConfig :
Defines and enables Amazon CloudWatch metrics and web request sample
collection.
Parameter customResponseBodies :
A map of custom response keys and content bodies. When you create a rule
with a block action, you can send a custom response to the web request.
You define these for the rule group, and then use them in the rules that
you define in the rule group.
For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.
For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide.
Parameter description :
A description of the rule group that helps with identification.
Parameter rules :
The Rule statements used to identify the web requests that you want
to manage. Each rule includes one top-level statement that WAF uses to
identify matching web requests, and parameters that govern how WAF handles
them.
Implementation
Future<UpdateRuleGroupResponse> updateRuleGroup({
required String id,
required String lockToken,
required String name,
required Scope scope,
required VisibilityConfig visibilityConfig,
Map<String, CustomResponseBody>? customResponseBodies,
String? description,
List<Rule>? rules,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.UpdateRuleGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'LockToken': lockToken,
'Name': name,
'Scope': scope.value,
'VisibilityConfig': visibilityConfig,
if (customResponseBodies != null)
'CustomResponseBodies': customResponseBodies,
if (description != null) 'Description': description,
if (rules != null) 'Rules': rules,
},
);
return UpdateRuleGroupResponse.fromJson(jsonResponse.body);
}