WellArchitected class

This is the Well-Architected Tool API Reference. The WA Tool API provides programmatic access to the Well-Architected Tool in the Amazon Web Services Management Console. For information about the Well-Architected Tool, see the Well-Architected Tool User Guide.

Constructors

WellArchitected({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateLenses({required List<String> lensAliases, required String workloadId}) Future<void>
Associate a lens to a workload.
associateProfiles({required List<String> profileArns, required String workloadId}) Future<void>
Associate a profile with a workload.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createLensShare({required String lensAlias, required String sharedWith, String? clientRequestToken}) Future<CreateLensShareOutput>
Create a lens share.
createLensVersion({required String lensAlias, required String lensVersion, String? clientRequestToken, bool? isMajorVersion}) Future<CreateLensVersionOutput>
Create a new lens version.
createMilestone({required String milestoneName, required String workloadId, String? clientRequestToken}) Future<CreateMilestoneOutput>
Create a milestone for an existing workload.
createProfile({required String profileDescription, required String profileName, required List<ProfileQuestionUpdate> profileQuestions, String? clientRequestToken, Map<String, String>? tags}) Future<CreateProfileOutput>
Create a profile.
createProfileShare({required String profileArn, required String sharedWith, String? clientRequestToken}) Future<CreateProfileShareOutput>
Create a profile share.
createReviewTemplate({required String description, required List<String> lenses, required String templateName, String? clientRequestToken, String? notes, Map<String, String>? tags}) Future<CreateReviewTemplateOutput>
Create a review template.
createTemplateShare({required String sharedWith, required String templateArn, String? clientRequestToken}) Future<CreateTemplateShareOutput>
Create a review template share.
createWorkload({required String description, required WorkloadEnvironment environment, required List<String> lenses, required String workloadName, List<String>? accountIds, List<String>? applications, String? architecturalDesign, List<String>? awsRegions, String? clientRequestToken, WorkloadDiscoveryConfig? discoveryConfig, String? industry, String? industryType, WorkloadJiraConfigurationInput? jiraConfiguration, List<String>? nonAwsRegions, String? notes, List<String>? pillarPriorities, List<String>? profileArns, String? reviewOwner, List<String>? reviewTemplateArns, Map<String, String>? tags}) Future<CreateWorkloadOutput>
Create a new workload.
createWorkloadShare({required PermissionType permissionType, required String sharedWith, required String workloadId, String? clientRequestToken}) Future<CreateWorkloadShareOutput>
Create a workload share.
deleteLens({required String lensAlias, required LensStatusType lensStatus, String? clientRequestToken}) Future<void>
Delete an existing lens.
deleteLensShare({required String lensAlias, required String shareId, String? clientRequestToken}) Future<void>
Delete a lens share.
deleteProfile({required String profileArn, String? clientRequestToken}) Future<void>
Delete a profile.
deleteProfileShare({required String profileArn, required String shareId, String? clientRequestToken}) Future<void>
Delete a profile share.
deleteReviewTemplate({required String templateArn, String? clientRequestToken}) Future<void>
Delete a review template.
deleteTemplateShare({required String shareId, required String templateArn, String? clientRequestToken}) Future<void>
Delete a review template share.
deleteWorkload({required String workloadId, String? clientRequestToken}) Future<void>
Delete an existing workload.
deleteWorkloadShare({required String shareId, required String workloadId, String? clientRequestToken}) Future<void>
Delete a workload share.
disassociateLenses({required List<String> lensAliases, required String workloadId}) Future<void>
Disassociate a lens from a workload.
disassociateProfiles({required List<String> profileArns, required String workloadId}) Future<void>
Disassociate a profile from a workload.
exportLens({required String lensAlias, String? lensVersion}) Future<ExportLensOutput>
Export an existing lens.
getAnswer({required String lensAlias, required String questionId, required String workloadId, int? milestoneNumber}) Future<GetAnswerOutput>
Get the answer to a specific question in a workload review.
getConsolidatedReport({required ReportFormat format, bool? includeSharedResources, int? maxResults, String? nextToken}) Future<GetConsolidatedReportOutput>
Get a consolidated report of your workloads.
getGlobalSettings() Future<GetGlobalSettingsOutput>
Global settings for all workloads.
getLens({required String lensAlias, String? lensVersion}) Future<GetLensOutput>
Get an existing lens.
getLensReview({required String lensAlias, required String workloadId, int? milestoneNumber}) Future<GetLensReviewOutput>
Get lens review.
getLensReviewReport({required String lensAlias, required String workloadId, int? milestoneNumber}) Future<GetLensReviewReportOutput>
Get lens review report.
getLensVersionDifference({required String lensAlias, String? baseLensVersion, String? targetLensVersion}) Future<GetLensVersionDifferenceOutput>
Get lens version differences.
getMilestone({required int milestoneNumber, required String workloadId}) Future<GetMilestoneOutput>
Get a milestone for an existing workload.
getProfile({required String profileArn, String? profileVersion}) Future<GetProfileOutput>
Get profile information.
getProfileTemplate() Future<GetProfileTemplateOutput>
Get profile template.
getReviewTemplate({required String templateArn}) Future<GetReviewTemplateOutput>
Get review template.
getReviewTemplateAnswer({required String lensAlias, required String questionId, required String templateArn}) Future<GetReviewTemplateAnswerOutput>
Get review template answer.
getReviewTemplateLensReview({required String lensAlias, required String templateArn}) Future<GetReviewTemplateLensReviewOutput>
Get a lens review associated with a review template.
getWorkload({required String workloadId}) Future<GetWorkloadOutput>
Get an existing workload.
importLens({required String jSONString, String? clientRequestToken, String? lensAlias, Map<String, String>? tags}) Future<ImportLensOutput>
Import a new custom lens or update an existing custom lens.
listAnswers({required String lensAlias, required String workloadId, int? maxResults, int? milestoneNumber, String? nextToken, String? pillarId, QuestionPriority? questionPriority}) Future<ListAnswersOutput>
List of answers for a particular workload and lens.
listCheckDetails({required String choiceId, required String lensArn, required String pillarId, required String questionId, required String workloadId, int? maxResults, String? nextToken}) Future<ListCheckDetailsOutput>
List of Trusted Advisor check details by account related to the workload.
listCheckSummaries({required String choiceId, required String lensArn, required String pillarId, required String questionId, required String workloadId, int? maxResults, String? nextToken}) Future<ListCheckSummariesOutput>
List of Trusted Advisor checks summarized for all accounts related to the workload.
listLenses({String? lensName, LensStatusType? lensStatus, LensType? lensType, int? maxResults, String? nextToken}) Future<ListLensesOutput>
List the available lenses.
listLensReviewImprovements({required String lensAlias, required String workloadId, int? maxResults, int? milestoneNumber, String? nextToken, String? pillarId, QuestionPriority? questionPriority}) Future<ListLensReviewImprovementsOutput>
List the improvements of a particular lens review.
listLensReviews({required String workloadId, int? maxResults, int? milestoneNumber, String? nextToken}) Future<ListLensReviewsOutput>
List lens reviews for a particular workload.
listLensShares({required String lensAlias, int? maxResults, String? nextToken, String? sharedWithPrefix, ShareStatus? status}) Future<ListLensSharesOutput>
List the lens shares associated with the lens.
listMilestones({required String workloadId, int? maxResults, String? nextToken}) Future<ListMilestonesOutput>
List all milestones for an existing workload.
listNotifications({int? maxResults, String? nextToken, String? resourceArn, String? workloadId}) Future<ListNotificationsOutput>
List lens notifications.
listProfileNotifications({int? maxResults, String? nextToken, String? workloadId}) Future<ListProfileNotificationsOutput>
List profile notifications.
listProfiles({int? maxResults, String? nextToken, String? profileNamePrefix, ProfileOwnerType? profileOwnerType}) Future<ListProfilesOutput>
List profiles.
listProfileShares({required String profileArn, int? maxResults, String? nextToken, String? sharedWithPrefix, ShareStatus? status}) Future<ListProfileSharesOutput>
List profile shares.
listReviewTemplateAnswers({required String lensAlias, required String templateArn, int? maxResults, String? nextToken, String? pillarId}) Future<ListReviewTemplateAnswersOutput>
List the answers of a review template.
listReviewTemplates({int? maxResults, String? nextToken}) Future<ListReviewTemplatesOutput>
List review templates.
listShareInvitations({String? lensNamePrefix, int? maxResults, String? nextToken, String? profileNamePrefix, ShareResourceType? shareResourceType, String? templateNamePrefix, String? workloadNamePrefix}) Future<ListShareInvitationsOutput>
List the share invitations.
listTagsForResource({required String workloadArn}) Future<ListTagsForResourceOutput>
List the tags for a resource.
listTemplateShares({required String templateArn, int? maxResults, String? nextToken, String? sharedWithPrefix, ShareStatus? status}) Future<ListTemplateSharesOutput>
List review template shares.
listWorkloads({int? maxResults, String? nextToken, String? workloadNamePrefix}) Future<ListWorkloadsOutput>
Paginated list of workloads.
listWorkloadShares({required String workloadId, int? maxResults, String? nextToken, String? sharedWithPrefix, ShareStatus? status}) Future<ListWorkloadSharesOutput>
List the workload shares associated with the workload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required Map<String, String> tags, required String workloadArn}) Future<void>
Adds one or more tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required List<String> tagKeys, required String workloadArn}) Future<void>
Deletes specified tags from a resource. To specify multiple tags, use separate tagKeys parameters, for example:
updateAnswer({required String lensAlias, required String questionId, required String workloadId, Map<String, ChoiceUpdate>? choiceUpdates, bool? isApplicable, String? notes, AnswerReason? reason, List<String>? selectedChoices}) Future<UpdateAnswerOutput>
Update the answer to a specific question in a workload review.
updateGlobalSettings({DiscoveryIntegrationStatus? discoveryIntegrationStatus, AccountJiraConfigurationInput? jiraConfiguration, OrganizationSharingStatus? organizationSharingStatus}) Future<void>
Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features.
updateIntegration({required IntegratingService integratingService, required String workloadId, String? clientRequestToken}) Future<void>
Update integration features.
updateLensReview({required String lensAlias, required String workloadId, JiraSelectedQuestionConfiguration? jiraConfiguration, String? lensNotes, Map<String, String>? pillarNotes}) Future<UpdateLensReviewOutput>
Update lens review for a particular workload.
updateProfile({required String profileArn, String? profileDescription, List<ProfileQuestionUpdate>? profileQuestions}) Future<UpdateProfileOutput>
Update a profile.
updateReviewTemplate({required String templateArn, String? description, List<String>? lensesToAssociate, List<String>? lensesToDisassociate, String? notes, String? templateName}) Future<UpdateReviewTemplateOutput>
Update a review template.
updateReviewTemplateAnswer({required String lensAlias, required String questionId, required String templateArn, Map<String, ChoiceUpdate>? choiceUpdates, bool? isApplicable, String? notes, AnswerReason? reason, List<String>? selectedChoices}) Future<UpdateReviewTemplateAnswerOutput>
Update a review template answer.
updateReviewTemplateLensReview({required String lensAlias, required String templateArn, String? lensNotes, Map<String, String>? pillarNotes}) Future<UpdateReviewTemplateLensReviewOutput>
Update a lens review associated with a review template.
updateShareInvitation({required ShareInvitationAction shareInvitationAction, required String shareInvitationId}) Future<UpdateShareInvitationOutput>
Update a workload or custom lens share invitation.
updateWorkload({required String workloadId, List<String>? accountIds, List<String>? applications, String? architecturalDesign, List<String>? awsRegions, String? description, WorkloadDiscoveryConfig? discoveryConfig, WorkloadEnvironment? environment, WorkloadImprovementStatus? improvementStatus, String? industry, String? industryType, bool? isReviewOwnerUpdateAcknowledged, WorkloadJiraConfigurationInput? jiraConfiguration, List<String>? nonAwsRegions, String? notes, List<String>? pillarPriorities, String? reviewOwner, String? workloadName}) Future<UpdateWorkloadOutput>
Update an existing workload.
updateWorkloadShare({required PermissionType permissionType, required String shareId, required String workloadId}) Future<UpdateWorkloadShareOutput>
Update a workload share.
upgradeLensReview({required String lensAlias, required String milestoneName, required String workloadId, String? clientRequestToken}) Future<void>
Upgrade lens review for a particular workload.
upgradeProfileVersion({required String profileArn, required String workloadId, String? clientRequestToken, String? milestoneName}) Future<void>
Upgrade a profile.
upgradeReviewTemplateLensReview({required String lensAlias, required String templateArn, String? clientRequestToken}) Future<void>
Upgrade the lens review of a review template.

Operators

operator ==(Object other) bool
The equality operator.
inherited