associateLenses method
Associate a lens to a workload.
Up to 10 lenses can be associated with a workload in a single API operation. A maximum of 20 lenses can be associated with a workload.
By accessing and/or applying custom lenses created by another Amazon Web Services user or account, you acknowledge that custom lenses created by other users and shared with you are Third Party Content as defined in the Amazon Web Services Customer Agreement.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Implementation
Future<void> associateLenses({
required List<String> lensAliases,
required String workloadId,
}) async {
final $payload = <String, dynamic>{
'LensAliases': lensAliases,
};
await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/workloads/${Uri.encodeComponent(workloadId)}/associateLenses',
exceptionFnMap: _exceptionFns,
);
}