deleteTemplateShare method

Future<void> deleteTemplateShare({
  1. required String shareId,
  2. required String templateArn,
  3. String? clientRequestToken,
})

Delete a review template share.

After the review template share is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter templateArn : The review template ARN.

Implementation

Future<void> deleteTemplateShare({
  required String shareId,
  required String templateArn,
  String? clientRequestToken,
}) async {
  final $query = <String, List<String>>{
    if (clientRequestToken != null)
      'ClientRequestToken': [clientRequestToken],
  };
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/templates/shares/${Uri.encodeComponent(templateArn)}/${Uri.encodeComponent(shareId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}