untagResource method

Future<void> untagResource({
  1. required List<String> tagKeys,
  2. required String workloadArn,
})

Deletes specified tags from a resource. To specify multiple tags, use separate tagKeys parameters, for example:

DELETE /tags/WorkloadArn?tagKeys=key1&tagKeys=key2

May throw InternalServerException. May throw ResourceNotFoundException.

Parameter tagKeys : A list of tag keys. Existing tags of the resource whose keys are members of this list are removed from the resource.

Implementation

Future<void> untagResource({
  required List<String> tagKeys,
  required String workloadArn,
}) async {
  final $query = <String, List<String>>{
    'tagKeys': tagKeys,
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/tags/${Uri.encodeComponent(workloadArn)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
}