createDataRetentionBot method
Creates a data retention bot in a Wickr network. Data retention bots are specialized bots that handle message archiving and compliance by capturing and storing messages for regulatory or organizational requirements.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter networkId :
The ID of the Wickr network where the data retention bot will be created.
Implementation
Future<CreateDataRetentionBotResponse> createDataRetentionBot({
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/networks/${Uri.encodeComponent(networkId)}/data-retention-bots',
exceptionFnMap: _exceptionFns,
);
return CreateDataRetentionBotResponse.fromJson(response);
}