createDataRetentionBotChallenge method
Future<CreateDataRetentionBotChallengeResponse>
createDataRetentionBotChallenge({
- required String networkId,
Creates a new challenge password for the data retention bot. This password is used for authentication when the bot connects to the network.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter networkId :
The ID of the Wickr network containing the data retention bot.
Implementation
Future<CreateDataRetentionBotChallengeResponse>
createDataRetentionBotChallenge({
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/networks/${Uri.encodeComponent(networkId)}/data-retention-bots/challenge',
exceptionFnMap: _exceptionFns,
);
return CreateDataRetentionBotChallengeResponse.fromJson(response);
}