deleteBot method

Future<DeleteBotResponse> deleteBot({
  1. required String botId,
  2. required String networkId,
})

Deletes a bot from a specified Wickr network. This operation permanently removes the bot account and its associated data from the network.

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter botId : The unique identifier of the bot to be deleted.

Parameter networkId : The ID of the Wickr network from which the bot will be deleted.

Implementation

Future<DeleteBotResponse> deleteBot({
  required String botId,
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/bots/${Uri.encodeComponent(botId)}',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteBotResponse.fromJson(response);
}