deleteDataRetentionBot method

Future<DeleteDataRetentionBotResponse> deleteDataRetentionBot({
  1. required String networkId,
})

Deletes the data retention bot from a Wickr network. This operation permanently removes the bot and all its associated data from the database.

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter networkId : The ID of the Wickr network from which the data retention bot will be deleted.

Implementation

Future<DeleteDataRetentionBotResponse> deleteDataRetentionBot({
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/data-retention-bots',
    exceptionFnMap: _exceptionFns,
  );
  return DeleteDataRetentionBotResponse.fromJson(response);
}