deleteSecurityGroup method
Deletes a security group from a Wickr network. This operation cannot be performed on the default security group.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter groupId :
The unique identifier of the security group to delete.
Parameter networkId :
The ID of the Wickr network from which the security group will be deleted.
Implementation
Future<DeleteSecurityGroupResponse> deleteSecurityGroup({
required String groupId,
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/networks/${Uri.encodeComponent(networkId)}/security-groups/${Uri.encodeComponent(groupId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteSecurityGroupResponse.fromJson(response);
}