getBot method

Future<GetBotResponse> getBot({
  1. required String botId,
  2. required String networkId,
})

Retrieves detailed information about a specific bot in a Wickr network, including its status, group membership, and authentication details.

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter botId : The unique identifier of the bot to retrieve.

Parameter networkId : The ID of the Wickr network containing the bot.

Implementation

Future<GetBotResponse> getBot({
  required String botId,
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/bots/${Uri.encodeComponent(botId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetBotResponse.fromJson(response);
}