getBotsCount method

Future<GetBotsCountResponse> getBotsCount({
  1. required String networkId,
})

Retrieves the count of bots in a Wickr network, categorized by their status (pending, active, and total).

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter networkId : The ID of the Wickr network for which to retrieve bot counts.

Implementation

Future<GetBotsCountResponse> getBotsCount({
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/networks/${Uri.encodeComponent(networkId)}/bots/count',
    exceptionFnMap: _exceptionFns,
  );
  return GetBotsCountResponse.fromJson(response);
}