getDataRetentionBot method
Retrieves information about the data retention bot in a Wickr network, including its status and whether the data retention service is enabled.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter networkId :
The ID of the Wickr network containing the data retention bot.
Implementation
Future<GetDataRetentionBotResponse> getDataRetentionBot({
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/networks/${Uri.encodeComponent(networkId)}/data-retention-bots',
exceptionFnMap: _exceptionFns,
);
return GetDataRetentionBotResponse.fromJson(response);
}