getGuestUserHistoryCount method

Future<GetGuestUserHistoryCountResponse> getGuestUserHistoryCount({
  1. required String networkId,
})

Retrieves historical guest user count data for a Wickr network, showing the number of guest users per billing period over the past 90 days.

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter networkId : The ID of the Wickr network for which to retrieve guest user history.

Implementation

Future<GetGuestUserHistoryCountResponse> getGuestUserHistoryCount({
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/guest-users/count',
    exceptionFnMap: _exceptionFns,
  );
  return GetGuestUserHistoryCountResponse.fromJson(response);
}