getSecurityGroup method

Future<GetSecurityGroupResponse> getSecurityGroup({
  1. required String groupId,
  2. required String networkId,
})

Retrieves detailed information about a specific security group in a Wickr network, including its settings, member counts, and configuration.

May throw BadRequestError. May throw ForbiddenError. May throw InternalServerError. May throw RateLimitError. May throw ResourceNotFoundError. May throw UnauthorizedError. May throw ValidationError.

Parameter groupId : The unique identifier of the security group to retrieve.

Parameter networkId : The ID of the Wickr network containing the security group.

Implementation

Future<GetSecurityGroupResponse> getSecurityGroup({
  required String groupId,
  required String networkId,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/networks/${Uri.encodeComponent(networkId)}/security-groups/${Uri.encodeComponent(groupId)}',
    exceptionFnMap: _exceptionFns,
  );
  return GetSecurityGroupResponse.fromJson(response);
}