registerOidcConfigTest method
Tests an OpenID Connect (OIDC) configuration for a Wickr network by validating the connection to the identity provider and retrieving its supported capabilities.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter issuer :
The issuer URL of the OIDC provider to test.
Parameter networkId :
The ID of the Wickr network for which the OIDC configuration will be
tested.
Parameter scopes :
The OAuth scopes to test with the OIDC provider.
Parameter certificate :
The CA certificate for secure communication with the OIDC provider
(optional).
Parameter extraAuthParams :
Additional authentication parameters to include in the test (optional).
Implementation
Future<RegisterOidcConfigTestResponse> registerOidcConfigTest({
required String issuer,
required String networkId,
required String scopes,
String? certificate,
String? extraAuthParams,
}) async {
final $payload = <String, dynamic>{
'issuer': issuer,
'scopes': scopes,
if (certificate != null) 'certificate': certificate,
if (extraAuthParams != null) 'extraAuthParams': extraAuthParams,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/networks/${Uri.encodeComponent(networkId)}/oidc/test',
exceptionFnMap: _exceptionFns,
);
return RegisterOidcConfigTestResponse.fromJson(response);
}