Wisdom class

Amazon Connect Wisdom delivers agents the information they need to solve customer issues as they're actively speaking with customers. Agents can search across connected repositories from within their agent desktop to find answers quickly. Use Amazon Connect Wisdom to create an assistant and a knowledge base, for example, or manage content by uploading custom files.

Constructors

Wisdom({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAssistant({required String name, required AssistantType type, String? clientToken, String? description, ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration, Map<String, String>? tags}) Future<CreateAssistantResponse>
Creates an Amazon Connect Wisdom assistant.
createAssistantAssociation({required String assistantId, required AssistantAssociationInputData association, required AssociationType associationType, String? clientToken, Map<String, String>? tags}) Future<CreateAssistantAssociationResponse>
Creates an association between an Amazon Connect Wisdom assistant and another resource. Currently, the only supported association is with a knowledge base. An assistant can have only a single association.
createContent({required String knowledgeBaseId, required String name, required String uploadId, String? clientToken, Map<String, String>? metadata, String? overrideLinkOutUri, Map<String, String>? tags, String? title}) Future<CreateContentResponse>
Creates Wisdom content. Before to calling this API, use StartContentUpload to upload an asset.
createKnowledgeBase({required KnowledgeBaseType knowledgeBaseType, required String name, String? clientToken, String? description, RenderingConfiguration? renderingConfiguration, ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration, SourceConfiguration? sourceConfiguration, Map<String, String>? tags}) Future<CreateKnowledgeBaseResponse>
Creates a knowledge base.
createQuickResponse({required QuickResponseDataProvider content, required String knowledgeBaseId, required String name, List<String>? channels, String? clientToken, String? contentType, String? description, GroupingConfiguration? groupingConfiguration, bool? isActive, String? language, String? shortcutKey, Map<String, String>? tags}) Future<CreateQuickResponseResponse>
Creates a Wisdom quick response.
createSession({required String assistantId, required String name, String? clientToken, String? description, Map<String, String>? tags}) Future<CreateSessionResponse>
Creates a session. A session is a contextual container used for generating recommendations. Amazon Connect creates a new Wisdom session for each contact on which Wisdom is enabled.
deleteAssistant({required String assistantId}) Future<void>
Deletes an assistant.
deleteAssistantAssociation({required String assistantAssociationId, required String assistantId}) Future<void>
Deletes an assistant association.
deleteContent({required String contentId, required String knowledgeBaseId}) Future<void>
Deletes the content.
deleteImportJob({required String importJobId, required String knowledgeBaseId}) Future<void>
Deletes the quick response import job.
deleteKnowledgeBase({required String knowledgeBaseId}) Future<void>
Deletes the knowledge base.
deleteQuickResponse({required String knowledgeBaseId, required String quickResponseId}) Future<void>
Deletes a quick response.
getAssistant({required String assistantId}) Future<GetAssistantResponse>
Retrieves information about an assistant.
getAssistantAssociation({required String assistantAssociationId, required String assistantId}) Future<GetAssistantAssociationResponse>
Retrieves information about an assistant association.
getContent({required String contentId, required String knowledgeBaseId}) Future<GetContentResponse>
Retrieves content, including a pre-signed URL to download the content.
getContentSummary({required String contentId, required String knowledgeBaseId}) Future<GetContentSummaryResponse>
Retrieves summary information about the content.
getImportJob({required String importJobId, required String knowledgeBaseId}) Future<GetImportJobResponse>
Retrieves the started import job.
getKnowledgeBase({required String knowledgeBaseId}) Future<GetKnowledgeBaseResponse>
Retrieves information about the knowledge base.
getQuickResponse({required String knowledgeBaseId, required String quickResponseId}) Future<GetQuickResponseResponse>
Retrieves the quick response.
getRecommendations({required String assistantId, required String sessionId, int? maxResults, int? waitTimeSeconds}) Future<GetRecommendationsResponse>
Retrieves recommendations for the specified session. To avoid retrieving the same recommendations in subsequent calls, use NotifyRecommendationsReceived. This API supports long-polling behavior with the waitTimeSeconds parameter. Short poll is the default behavior and only returns recommendations already available. To perform a manual query against an assistant, use QueryAssistant.
getSession({required String assistantId, required String sessionId}) Future<GetSessionResponse>
Retrieves information for a specified session.
listAssistantAssociations({required String assistantId, int? maxResults, String? nextToken}) Future<ListAssistantAssociationsResponse>
Lists information about assistant associations.
listAssistants({int? maxResults, String? nextToken}) Future<ListAssistantsResponse>
Lists information about assistants.
listContents({required String knowledgeBaseId, int? maxResults, String? nextToken}) Future<ListContentsResponse>
Lists the content.
listImportJobs({required String knowledgeBaseId, int? maxResults, String? nextToken}) Future<ListImportJobsResponse>
Lists information about import jobs.
listKnowledgeBases({int? maxResults, String? nextToken}) Future<ListKnowledgeBasesResponse>
Lists the knowledge bases.
listQuickResponses({required String knowledgeBaseId, int? maxResults, String? nextToken}) Future<ListQuickResponsesResponse>
Lists information about quick response.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Lists the tags for the specified resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyRecommendationsReceived({required String assistantId, required List<String> recommendationIds, required String sessionId}) Future<NotifyRecommendationsReceivedResponse>
Removes the specified recommendations from the specified assistant's queue of newly available recommendations. You can use this API in conjunction with GetRecommendations and a waitTimeSeconds input for long-polling behavior and avoiding duplicate recommendations.
queryAssistant({required String assistantId, required String queryText, int? maxResults, String? nextToken}) Future<QueryAssistantResponse>
Performs a manual search against the specified assistant. To retrieve recommendations for an assistant, use GetRecommendations.
removeKnowledgeBaseTemplateUri({required String knowledgeBaseId}) Future<void>
Removes a URI template from a knowledge base.
searchContent({required String knowledgeBaseId, required SearchExpression searchExpression, int? maxResults, String? nextToken}) Future<SearchContentResponse>
Searches for content in a specified knowledge base. Can be used to get a specific content resource by its name.
searchQuickResponses({required String knowledgeBaseId, required QuickResponseSearchExpression searchExpression, Map<String, String>? attributes, int? maxResults, String? nextToken}) Future<SearchQuickResponsesResponse>
Searches existing Wisdom quick responses in a Wisdom knowledge base.
searchSessions({required String assistantId, required SearchExpression searchExpression, int? maxResults, String? nextToken}) Future<SearchSessionsResponse>
Searches for sessions.
startContentUpload({required String contentType, required String knowledgeBaseId, int? presignedUrlTimeToLive}) Future<StartContentUploadResponse>
Get a URL to upload content to a knowledge base. To upload content, first make a PUT request to the returned URL with your file, making sure to include the required headers. Then use CreateContent to finalize the content creation process or UpdateContent to modify an existing resource. You can only upload content to a knowledge base of type CUSTOM.
startImportJob({required ImportJobType importJobType, required String knowledgeBaseId, required String uploadId, String? clientToken, ExternalSourceConfiguration? externalSourceConfiguration, Map<String, String>? metadata}) Future<StartImportJobResponse>
Start an asynchronous job to import Wisdom resources from an uploaded source file. Before calling this API, use StartContentUpload to upload an asset that contains the resource data.
tagResource({required String resourceArn, required Map<String, String> tags}) Future<void>
Adds the specified tags to the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes the specified tags from the specified resource.
updateContent({required String contentId, required String knowledgeBaseId, Map<String, String>? metadata, String? overrideLinkOutUri, bool? removeOverrideLinkOutUri, String? revisionId, String? title, String? uploadId}) Future<UpdateContentResponse>
Updates information about the content.
updateKnowledgeBaseTemplateUri({required String knowledgeBaseId, required String templateUri}) Future<UpdateKnowledgeBaseTemplateUriResponse>
Updates the template URI of a knowledge base. This is only supported for knowledge bases of type EXTERNAL. Include a single variable in ${variable} format; this interpolated by Wisdom using ingested content. For example, if you ingest a Salesforce article, it has an Id value, and you can set the template URI to https://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view.
updateQuickResponse({required String knowledgeBaseId, required String quickResponseId, List<String>? channels, QuickResponseDataProvider? content, String? contentType, String? description, GroupingConfiguration? groupingConfiguration, bool? isActive, String? language, String? name, bool? removeDescription, bool? removeGroupingConfiguration, bool? removeShortcutKey, String? shortcutKey}) Future<UpdateQuickResponseResponse>
Updates an existing Wisdom quick response.

Operators

operator ==(Object other) bool
The equality operator.
inherited