listAssistantAssociations method

Future<ListAssistantAssociationsResponse> listAssistantAssociations({
  1. required String assistantId,
  2. int? maxResults,
  3. String? nextToken,
})

Lists information about assistant associations.

May throw AccessDeniedException. May throw ResourceNotFoundException. May throw ValidationException.

Parameter assistantId : The identifier of the Wisdom assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.

Parameter maxResults : The maximum number of results to return per page.

Parameter nextToken : The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Implementation

Future<ListAssistantAssociationsResponse> listAssistantAssociations({
  required String assistantId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $query = <String, List<String>>{
    if (maxResults != null) 'maxResults': [maxResults.toString()],
    if (nextToken != null) 'nextToken': [nextToken],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri:
        '/assistants/${Uri.encodeComponent(assistantId)}/associations',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return ListAssistantAssociationsResponse.fromJson(response);
}