listAssistants method
Lists information about assistants.
May throw AccessDeniedException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListAssistantsResponse> listAssistants({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/assistants',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAssistantsResponse.fromJson(response);
}