listContents method
Lists the content.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter knowledgeBaseId :
The identifier of the knowledge base. This should not be a QUICK_RESPONSES
type knowledge base if you're storing Wisdom Content resource to it. Can
be either the ID or the ARN. URLs cannot contain the ARN.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListContentsResponse> listContents({
required String knowledgeBaseId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/knowledgeBases/${Uri.encodeComponent(knowledgeBaseId)}/contents',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListContentsResponse.fromJson(response);
}