searchSessions method
Searches for sessions.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter assistantId :
The identifier of the Wisdom assistant. Can be either the ID or the ARN.
URLs cannot contain the ARN.
Parameter searchExpression :
The search expression to filter results.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<SearchSessionsResponse> searchSessions({
required String assistantId,
required SearchExpression searchExpression,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
'searchExpression': searchExpression,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/assistants/${Uri.encodeComponent(assistantId)}/searchSessions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return SearchSessionsResponse.fromJson(response);
}