deleteEmailMonitoringConfiguration method

Future<void> deleteEmailMonitoringConfiguration({
  1. required String organizationId,
})

Deletes the email monitoring configuration for a specified organization.

May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException.

Parameter organizationId : The ID of the organization from which the email monitoring configuration is deleted.

Implementation

Future<void> deleteEmailMonitoringConfiguration({
  required String organizationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.DeleteEmailMonitoringConfiguration'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'OrganizationId': organizationId,
    },
  );
}