deleteMailboxPermissions method

Future<void> deleteMailboxPermissions({
  1. required String entityId,
  2. required String granteeId,
  3. required String organizationId,
})

Deletes permissions granted to a member (user or group).

May throw EntityNotFoundException. May throw EntityStateException. May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException.

Parameter entityId : The identifier of the entity that owns the mailbox.

The identifier can be UserId or Group Id, Username or Groupname, or email.

  • Entity ID: 12345678-1234-1234-1234-123456789012, r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: entity@domain.tld
  • Entity name: entity

Parameter granteeId : The identifier of the entity for which to delete granted permissions.

The identifier can be UserId, ResourceID, or Group Id, Username or Groupname, or email.

  • Grantee ID: 12345678-1234-1234-1234-123456789012,r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: grantee@domain.tld
  • Grantee name: grantee

Parameter organizationId : The identifier of the organization under which the member (user or group) exists.

Implementation

Future<void> deleteMailboxPermissions({
  required String entityId,
  required String granteeId,
  required String organizationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.DeleteMailboxPermissions'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EntityId': entityId,
      'GranteeId': granteeId,
      'OrganizationId': organizationId,
    },
  );
}