deleteMobileDeviceAccessRule method

Future<void> deleteMobileDeviceAccessRule({
  1. required String mobileDeviceAccessRuleId,
  2. required String organizationId,
})

Deletes a mobile device access rule for the specified WorkMail organization.

May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException.

Parameter mobileDeviceAccessRuleId : The identifier of the rule to be deleted.

Parameter organizationId : The WorkMail organization under which the rule will be deleted.

Implementation

Future<void> deleteMobileDeviceAccessRule({
  required String mobileDeviceAccessRuleId,
  required String organizationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.DeleteMobileDeviceAccessRule'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MobileDeviceAccessRuleId': mobileDeviceAccessRuleId,
      'OrganizationId': organizationId,
    },
  );
}