deregisterFromWorkMail method

Future<void> deregisterFromWorkMail({
  1. required String entityId,
  2. required String organizationId,
})

Mark a user, group, or resource as no longer used in WorkMail. This action disassociates the mailbox and schedules it for clean-up. WorkMail keeps mailboxes for 30 days before they are permanently removed. The functionality in the console is Disable.

May throw EntityNotFoundException. May throw EntityStateException. May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException.

Parameter entityId : The identifier for the member to be updated.

The identifier can be UserId, ResourceId, or Group Id, Username, Resourcename, or Groupname, or email.

  • Entity ID: 12345678-1234-1234-1234-123456789012, r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: entity@domain.tld
  • Entity name: entity

Parameter organizationId : The identifier for the organization under which the WorkMail entity exists.

Implementation

Future<void> deregisterFromWorkMail({
  required String entityId,
  required String organizationId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.DeregisterFromWorkMail'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EntityId': entityId,
      'OrganizationId': organizationId,
    },
  );
}