getMobileDeviceAccessOverride method

Future<GetMobileDeviceAccessOverrideResponse> getMobileDeviceAccessOverride({
  1. required String deviceId,
  2. required String organizationId,
  3. required String userId,
})

Gets the mobile device access override for the given WorkMail organization, user, and device.

May throw EntityNotFoundException. May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException. May throw ResourceNotFoundException.

Parameter deviceId : The mobile device to which the override applies. DeviceId is case insensitive.

Parameter organizationId : The WorkMail organization to which you want to apply the override.

Parameter userId : Identifies the WorkMail user for the override. Accepts the following types of user identities:

  • User ID: 12345678-1234-1234-1234-123456789012 or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: user@domain.tld
  • User name: user

Implementation

Future<GetMobileDeviceAccessOverrideResponse> getMobileDeviceAccessOverride({
  required String deviceId,
  required String organizationId,
  required String userId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.GetMobileDeviceAccessOverride'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DeviceId': deviceId,
      'OrganizationId': organizationId,
      'UserId': userId,
    },
  );

  return GetMobileDeviceAccessOverrideResponse.fromJson(jsonResponse.body);
}