listGroupMembers method
Returns an overview of the members of a group. Users and groups can be members of a group.
May throw EntityNotFoundException.
May throw EntityStateException.
May throw InvalidParameterException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter groupId :
The identifier for the group to which the members (users or groups) are
associated.
The identifier can accept GroupId, Groupname, or email. The following identity formats are available:
- Group ID: 12345678-1234-1234-1234-123456789012 or S-1-1-12-1234567890-123456789-123456789-1234
- Email address: group@domain.tld
- Group name: group
Parameter organizationId :
The identifier for the organization under which the group exists.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
The token to use to retrieve the next page of results. The first call does
not contain any tokens.
Implementation
Future<ListGroupMembersResponse> listGroupMembers({
required String groupId,
required String organizationId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.ListGroupMembers'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GroupId': groupId,
'OrganizationId': organizationId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListGroupMembersResponse.fromJson(jsonResponse.body);
}