updateDefaultMailDomain method
Updates the default mail domain for an organization. The default mail domain is used by the WorkMail AWS Console to suggest an email address when enabling a mail user. You can only have one default domain.
May throw InvalidParameterException.
May throw MailDomainNotFoundException.
May throw MailDomainStateException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter domainName :
The domain name that will become the default domain.
Parameter organizationId :
The WorkMail organization for which to list domains.
Implementation
Future<void> updateDefaultMailDomain({
required String domainName,
required String organizationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.UpdateDefaultMailDomain'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainName': domainName,
'OrganizationId': organizationId,
},
);
}