updateGroup method

Future<void> updateGroup({
  1. required String groupId,
  2. required String organizationId,
  3. bool? hiddenFromGlobalAddressList,
})

Updates attributes in a group.

May throw EntityNotFoundException. May throw EntityStateException. May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException. May throw UnsupportedOperationException.

Parameter groupId : The identifier for the group to be updated.

The identifier can accept GroupId, Groupname, or email. The following identity formats are available:

  • Group ID: 12345678-1234-1234-1234-123456789012 or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: group@domain.tld
  • Group name: group

Parameter organizationId : The identifier for the organization under which the group exists.

Parameter hiddenFromGlobalAddressList : If enabled, the group is hidden from the global address list.

Implementation

Future<void> updateGroup({
  required String groupId,
  required String organizationId,
  bool? hiddenFromGlobalAddressList,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.UpdateGroup'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'GroupId': groupId,
      'OrganizationId': organizationId,
      if (hiddenFromGlobalAddressList != null)
        'HiddenFromGlobalAddressList': hiddenFromGlobalAddressList,
    },
  );
}