updateMailboxQuota method

Future<void> updateMailboxQuota({
  1. required int mailboxQuota,
  2. required String organizationId,
  3. required String userId,
})

Updates a user's current mailbox quota for a specified organization and user.

May throw EntityNotFoundException. May throw EntityStateException. May throw InvalidParameterException. May throw OrganizationNotFoundException. May throw OrganizationStateException.

Parameter mailboxQuota : The updated mailbox quota, in MB, for the specified user.

Parameter organizationId : The identifier for the organization that contains the user for whom to update the mailbox quota.

Parameter userId : The identifer for the user for whom to update the mailbox quota.

The identifier can be the UserId, Username, or email. The following identity formats are available:

  • User ID: 12345678-1234-1234-1234-123456789012 or S-1-1-12-1234567890-123456789-123456789-1234
  • Email address: user@domain.tld
  • User name: user

Implementation

Future<void> updateMailboxQuota({
  required int mailboxQuota,
  required String organizationId,
  required String userId,
}) async {
  _s.validateNumRange(
    'mailboxQuota',
    mailboxQuota,
    1,
    1152921504606846976,
    isRequired: true,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkMailService.UpdateMailboxQuota'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'MailboxQuota': mailboxQuota,
      'OrganizationId': organizationId,
      'UserId': userId,
    },
  );
}