WorkSpaces class

Amazon WorkSpaces enables you to provision virtual, cloud-based Microsoft Windows or Amazon Linux desktops for your users, known as WorkSpaces. WorkSpaces eliminates the need to procure and deploy hardware or install complex software. You can quickly add or remove users as your needs change. Users can access their virtual desktops from multiple devices or web browsers.

Constructors

WorkSpaces({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptAccountLinkInvitation({required String linkId, String? clientToken}) Future<AcceptAccountLinkInvitationResult>
Accepts the account link invitation.
associateConnectionAlias({required String aliasId, required String resourceId}) Future<AssociateConnectionAliasResult>
Associates the specified connection alias with the specified directory to enable cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
associateIpGroups({required String directoryId, required List<String> groupIds}) Future<void>
Associates the specified IP access control group with the specified directory.
associateWorkspaceApplication({required String applicationId, required String workspaceId}) Future<AssociateWorkspaceApplicationResult>
Associates the specified application to the specified WorkSpace.
authorizeIpRules({required String groupId, required List<IpRuleItem> userRules}) Future<void>
Adds one or more rules to the specified IP access control group.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
copyWorkspaceImage({required String name, required String sourceImageId, required String sourceRegion, String? description, List<Tag>? tags}) Future<CopyWorkspaceImageResult>
Copies the specified image from the specified Region to the current Region. For more information about copying images, see Copy a Custom WorkSpaces Image.
createAccountLinkInvitation({required String targetAccountId, String? clientToken}) Future<CreateAccountLinkInvitationResult>
Creates the account link invitation.
createConnectClientAddIn({required String name, required String resourceId, required String url}) Future<CreateConnectClientAddInResult>
Creates a client-add-in for Connect Customer within a directory. You can create only one Connect Customer client add-in within a directory.
createConnectionAlias({required String connectionString, List<Tag>? tags}) Future<CreateConnectionAliasResult>
Creates the specified connection alias for use with cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
createIpGroup({required String groupName, String? groupDesc, List<Tag>? tags, List<IpRuleItem>? userRules}) Future<CreateIpGroupResult>
Creates an IP access control group.
createStandbyWorkspaces({required String primaryRegion, required List<StandbyWorkspace> standbyWorkspaces}) Future<CreateStandbyWorkspacesResult>
Creates a standby WorkSpace in a secondary Region.
createTags({required String resourceId, required List<Tag> tags}) Future<void>
Creates the specified tags for the specified WorkSpaces resource.
createUpdatedWorkspaceImage({required String description, required String name, required String sourceImageId, List<Tag>? tags}) Future<CreateUpdatedWorkspaceImageResult>
Creates a new updated WorkSpace image based on the specified source image. The new updated WorkSpace image has the latest drivers and other updates required by the Amazon WorkSpaces components.
createWorkspaceBundle({required String bundleDescription, required String bundleName, required ComputeType computeType, required String imageId, required UserStorage userStorage, RootStorage? rootStorage, List<Tag>? tags}) Future<CreateWorkspaceBundleResult>
Creates the specified WorkSpace bundle. For more information about creating WorkSpace bundles, see Create a Custom WorkSpaces Image and Bundle.
createWorkspaceImage({required String description, required String name, required String workspaceId, List<Tag>? tags}) Future<CreateWorkspaceImageResult>
Creates a new WorkSpace image from an existing WorkSpace.
createWorkspaces({required List<WorkspaceRequest> workspaces}) Future<CreateWorkspacesResult>
Creates one or more WorkSpaces.
createWorkspacesPool({required String bundleId, required Capacity capacity, required String description, required String directoryId, required String poolName, ApplicationSettingsRequest? applicationSettings, PoolsRunningMode? runningMode, List<Tag>? tags, TimeoutSettings? timeoutSettings}) Future<CreateWorkspacesPoolResult>
Creates a pool of WorkSpaces.
deleteAccountLinkInvitation({required String linkId, String? clientToken}) Future<DeleteAccountLinkInvitationResult>
Deletes the account link invitation.
deleteClientBranding({required List<ClientDeviceType> platforms, required String resourceId}) Future<void>
Deletes customized client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
deleteConnectClientAddIn({required String addInId, required String resourceId}) Future<void>
Deletes a client-add-in for Connect Customer that is configured within a directory.
deleteConnectionAlias({required String aliasId}) Future<void>
Deletes the specified connection alias. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
deleteIpGroup({required String groupId}) Future<void>
Deletes the specified IP access control group.
deleteTags({required String resourceId, required List<String> tagKeys}) Future<void>
Deletes the specified tags from the specified WorkSpaces resource.
deleteWorkspaceBundle({String? bundleId}) Future<void>
Deletes the specified WorkSpace bundle. For more information about deleting WorkSpace bundles, see Delete a Custom WorkSpaces Bundle or Image.
deleteWorkspaceImage({required String imageId}) Future<void>
Deletes the specified image from your account. To delete an image, you must first delete any bundles that are associated with the image and unshare the image if it is shared with other accounts.
deployWorkspaceApplications({required String workspaceId, bool? force}) Future<DeployWorkspaceApplicationsResult>
Deploys associated applications to the specified WorkSpace
deregisterWorkspaceDirectory({required String directoryId}) Future<void>
Deregisters the specified directory. This operation is asynchronous and returns before the WorkSpace directory is deregistered. If any WorkSpaces are registered to this directory, you must remove them before you can deregister the directory.
describeAccount() Future<DescribeAccountResult>
Retrieves a list that describes the configuration of Bring Your Own License (BYOL) for the specified account.
describeAccountModifications({String? nextToken}) Future<DescribeAccountModificationsResult>
Retrieves a list that describes modifications to the configuration of Bring Your Own License (BYOL) for the specified account.
describeApplicationAssociations({required String applicationId, required List<ApplicationAssociatedResourceType> associatedResourceTypes, int? maxResults, String? nextToken}) Future<DescribeApplicationAssociationsResult>
Describes the associations between the application and the specified associated resources.
describeApplications({List<String>? applicationIds, List<Compute>? computeTypeNames, WorkSpaceApplicationLicenseType? licenseType, int? maxResults, String? nextToken, List<OperatingSystemName>? operatingSystemNames, String? owner}) Future<DescribeApplicationsResult>
Describes the specified applications by filtering based on their compute types, license availability, operating systems, and owners.
describeBundleAssociations({required List<BundleAssociatedResourceType> associatedResourceTypes, required String bundleId}) Future<DescribeBundleAssociationsResult>
Describes the associations between the applications and the specified bundle.
describeClientBranding({required String resourceId}) Future<DescribeClientBrandingResult>
Describes the specified client branding. Client branding allows you to customize the log in page of various device types for your users. You can add your company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
describeClientProperties({required List<String> resourceIds}) Future<DescribeClientPropertiesResult>
Retrieves a list that describes one or more specified Amazon WorkSpaces clients.
describeConnectClientAddIns({required String resourceId, int? maxResults, String? nextToken}) Future<DescribeConnectClientAddInsResult>
Retrieves a list of Connect Customer client add-ins that have been created.
describeConnectionAliases({List<String>? aliasIds, int? limit, String? nextToken, String? resourceId}) Future<DescribeConnectionAliasesResult>
Retrieves a list that describes the connection aliases used for cross-Region redirection. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
describeConnectionAliasPermissions({required String aliasId, int? maxResults, String? nextToken}) Future<DescribeConnectionAliasPermissionsResult>
Describes the permissions that the owner of a connection alias has granted to another Amazon Web Services account for the specified connection alias. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
describeCustomWorkspaceImageImport({required String imageId}) Future<DescribeCustomWorkspaceImageImportResult>
Retrieves information about a WorkSpace BYOL image being imported via ImportCustomWorkspaceImage.
describeImageAssociations({required List<ImageAssociatedResourceType> associatedResourceTypes, required String imageId}) Future<DescribeImageAssociationsResult>
Describes the associations between the applications and the specified image.
describeIpGroups({List<String>? groupIds, int? maxResults, String? nextToken}) Future<DescribeIpGroupsResult>
Describes one or more of your IP access control groups.
describeTags({required String resourceId}) Future<DescribeTagsResult>
Describes the specified tags for the specified WorkSpaces resource.
describeWorkspaceAssociations({required List<WorkSpaceAssociatedResourceType> associatedResourceTypes, required String workspaceId}) Future<DescribeWorkspaceAssociationsResult>
Describes the associations betweens applications and the specified WorkSpace.
describeWorkspaceBundles({List<String>? bundleIds, String? nextToken, String? owner}) Future<DescribeWorkspaceBundlesResult>
Retrieves a list that describes the available WorkSpace bundles.
describeWorkspaceDirectories({List<String>? directoryIds, List<DescribeWorkspaceDirectoriesFilter>? filters, int? limit, String? nextToken, List<String>? workspaceDirectoryNames}) Future<DescribeWorkspaceDirectoriesResult>
Describes the available directories that are registered with Amazon WorkSpaces.
describeWorkspaceImagePermissions({required String imageId, int? maxResults, String? nextToken}) Future<DescribeWorkspaceImagePermissionsResult>
Describes the permissions that the owner of an image has granted to other Amazon Web Services accounts for an image.
describeWorkspaceImages({List<String>? imageIds, ImageType? imageType, int? maxResults, String? nextToken}) Future<DescribeWorkspaceImagesResult>
Retrieves a list that describes one or more specified images, if the image identifiers are provided. Otherwise, all images in the account are described.
describeWorkspaces({String? bundleId, String? directoryId, int? limit, String? nextToken, String? userName, List<String>? workspaceIds, String? workspaceName}) Future<DescribeWorkspacesResult>
Describes the specified WorkSpaces.
describeWorkspacesConnectionStatus({String? nextToken, List<String>? workspaceIds}) Future<DescribeWorkspacesConnectionStatusResult>
Describes the connection status of the specified WorkSpaces.
describeWorkspaceSnapshots({required String workspaceId}) Future<DescribeWorkspaceSnapshotsResult>
Describes the snapshots for the specified WorkSpace.
describeWorkspacesPools({List<DescribeWorkspacesPoolsFilter>? filters, int? limit, String? nextToken, List<String>? poolIds}) Future<DescribeWorkspacesPoolsResult>
Describes the specified WorkSpaces Pools.
describeWorkspacesPoolSessions({required String poolId, int? limit, String? nextToken, String? userId}) Future<DescribeWorkspacesPoolSessionsResult>
Retrieves a list that describes the streaming sessions for a specified pool.
disassociateConnectionAlias({required String aliasId}) Future<void>
Disassociates a connection alias from a directory. Disassociating a connection alias disables cross-Region redirection between two directories in different Regions. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
disassociateIpGroups({required String directoryId, required List<String> groupIds}) Future<void>
Disassociates the specified IP access control group from the specified directory.
disassociateWorkspaceApplication({required String applicationId, required String workspaceId}) Future<DisassociateWorkspaceApplicationResult>
Disassociates the specified application from a WorkSpace.
Retrieves account link information.
importClientBranding({required String resourceId, DefaultImportClientBrandingAttributes? deviceTypeAndroid, IosImportClientBrandingAttributes? deviceTypeIos, DefaultImportClientBrandingAttributes? deviceTypeLinux, DefaultImportClientBrandingAttributes? deviceTypeOsx, DefaultImportClientBrandingAttributes? deviceTypeWeb, DefaultImportClientBrandingAttributes? deviceTypeWindows}) Future<ImportClientBrandingResult>
Imports client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
importCustomWorkspaceImage({required ImageComputeType computeType, required String imageDescription, required String imageName, required ImageSourceIdentifier imageSource, required String infrastructureConfigurationArn, required OSVersion osVersion, required Platform platform, required CustomImageProtocol protocol, List<Tag>? tags}) Future<ImportCustomWorkspaceImageResult>
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces using EC2 Image Builder. The image must be an already licensed image that is in your Amazon Web Services account, and you must own the image. For more information about creating BYOL images, see Bring Your Own Windows Desktop Licenses.
importWorkspaceImage({required String ec2ImageId, required String imageDescription, required String imageName, required WorkspaceImageIngestionProcess ingestionProcess, List<Application>? applications, List<Tag>? tags}) Future<ImportWorkspaceImageResult>
Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces. The image must be an already licensed Amazon EC2 image that is in your Amazon Web Services account, and you must own the image. For more information about creating BYOL images, see Bring Your Own Windows Desktop Licenses.
Lists all account links.
listAvailableManagementCidrRanges({required String managementCidrRangeConstraint, int? maxResults, String? nextToken}) Future<ListAvailableManagementCidrRangesResult>
Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you can use for the network management interface when you enable Bring Your Own License (BYOL).
migrateWorkspace({required String bundleId, required String sourceWorkspaceId}) Future<MigrateWorkspaceResult>
Migrates a WorkSpace from one operating system or bundle type to another, while retaining the data on the user volume.
modifyAccount({String? dedicatedTenancyManagementCidrRange, DedicatedTenancySupportEnum? dedicatedTenancySupport}) Future<ModifyAccountResult>
Modifies the configuration of Bring Your Own License (BYOL) for the specified account.
modifyCertificateBasedAuthProperties({required String resourceId, CertificateBasedAuthProperties? certificateBasedAuthProperties, List<DeletableCertificateBasedAuthProperty>? propertiesToDelete}) Future<void>
Modifies the properties of the certificate-based authentication you want to use with your WorkSpaces.
modifyClientProperties({required ClientProperties clientProperties, required String resourceId}) Future<void>
Modifies the properties of the specified Amazon WorkSpaces clients.
modifyEndpointEncryptionMode({required String directoryId, required EndpointEncryptionMode endpointEncryptionMode}) Future<void>
Modifies the endpoint encryption mode that allows you to configure the specified directory between Standard TLS and FIPS 140-2 validated mode.
modifySamlProperties({required String resourceId, List<DeletableSamlProperty>? propertiesToDelete, SamlProperties? samlProperties}) Future<void>
Modifies multiple properties related to SAML 2.0 authentication, including the enablement status, user access URL, and relay state parameter name that are used for configuring federation with an SAML 2.0 identity provider.
modifySelfservicePermissions({required String resourceId, required SelfservicePermissions selfservicePermissions}) Future<void>
Modifies the self-service WorkSpace management capabilities for your users. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users.
modifyStreamingProperties({required String resourceId, StreamingProperties? streamingProperties}) Future<void>
Modifies the specified streaming properties.
modifyWorkspaceAccessProperties({required String resourceId, required WorkspaceAccessProperties workspaceAccessProperties}) Future<void>
Specifies which devices and operating systems users can use to access their WorkSpaces. For more information, see Control Device Access.
modifyWorkspaceCreationProperties({required String resourceId, required WorkspaceCreationProperties workspaceCreationProperties}) Future<void>
Modify the default properties used to create WorkSpaces.
modifyWorkspaceProperties({required String workspaceId, DataReplication? dataReplication, WorkspaceProperties? workspaceProperties}) Future<void>
Modifies the specified WorkSpace properties. For important information about how to modify the size of the root and user volumes, see Modify a WorkSpace.
modifyWorkspaceState({required String workspaceId, required TargetWorkspaceState workspaceState}) Future<void>
Sets the state of the specified WorkSpace.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebootWorkspaces({required List<RebootRequest> rebootWorkspaceRequests}) Future<RebootWorkspacesResult>
Reboots the specified WorkSpaces.
rebuildWorkspaces({required List<RebuildRequest> rebuildWorkspaceRequests}) Future<RebuildWorkspacesResult>
Rebuilds the specified WorkSpace.
registerWorkspaceDirectory({ActiveDirectoryConfig? activeDirectoryConfig, String? directoryId, bool? enableSelfService, String? idcInstanceArn, MicrosoftEntraConfig? microsoftEntraConfig, List<String>? subnetIds, List<Tag>? tags, Tenancy? tenancy, UserIdentityType? userIdentityType, String? workspaceDirectoryDescription, String? workspaceDirectoryName, WorkspaceType? workspaceType}) Future<RegisterWorkspaceDirectoryResult>
Registers the specified directory. This operation is asynchronous and returns before the WorkSpace directory is registered. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.
rejectAccountLinkInvitation({required String linkId, String? clientToken}) Future<RejectAccountLinkInvitationResult>
Rejects the account link invitation.
restoreWorkspace({required String workspaceId}) Future<void>
Restores the specified WorkSpace to its last known healthy state.
revokeIpRules({required String groupId, required List<String> userRules}) Future<void>
Removes one or more rules from the specified IP access control group.
startWorkspaces({required List<StartRequest> startWorkspaceRequests}) Future<StartWorkspacesResult>
Starts the specified WorkSpaces.
startWorkspacesPool({required String poolId}) Future<void>
Starts the specified pool.
stopWorkspaces({required List<StopRequest> stopWorkspaceRequests}) Future<StopWorkspacesResult>
Stops the specified WorkSpaces.
stopWorkspacesPool({required String poolId}) Future<void>
Stops the specified pool.
terminateWorkspaces({required List<TerminateRequest> terminateWorkspaceRequests}) Future<TerminateWorkspacesResult>
Terminates the specified WorkSpaces. You can terminate a WorkSpace that is in any state except SUSPENDED.
terminateWorkspacesPool({required String poolId}) Future<void>
Terminates the specified pool.
terminateWorkspacesPoolSession({required String sessionId}) Future<void>
Terminates the pool session.
toString() String
A string representation of this object.
inherited
updateConnectClientAddIn({required String addInId, required String resourceId, String? name, String? url}) Future<void>
Updates a Connect Customer client add-in. Use this action to update the name and endpoint URL of a Connect Customer client add-in.
updateConnectionAliasPermission({required String aliasId, required ConnectionAliasPermission connectionAliasPermission}) Future<void>
Shares or unshares a connection alias with one account by specifying whether that account has permission to associate the connection alias with a directory. If the association permission is granted, the connection alias is shared with that account. If the association permission is revoked, the connection alias is unshared with the account. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
updateRulesOfIpGroup({required String groupId, required List<IpRuleItem> userRules}) Future<void>
Replaces the current rules of the specified IP access control group with the specified rules.
updateWorkspaceBundle({String? bundleId, String? imageId}) Future<void>
Updates a WorkSpace bundle with a new image. For more information about updating WorkSpace bundles, see Update a Custom WorkSpaces Bundle.
updateWorkspaceImagePermission({required bool allowCopyImage, required String imageId, required String sharedAccountId}) Future<void>
Shares or unshares an image with one account in the same Amazon Web Services Region by specifying whether that account has permission to copy the image. If the copy image permission is granted, the image is shared with that account. If the copy image permission is revoked, the image is unshared with the account.
updateWorkspacesPool({required String poolId, ApplicationSettingsRequest? applicationSettings, String? bundleId, Capacity? capacity, String? description, String? directoryId, PoolsRunningMode? runningMode, TimeoutSettings? timeoutSettings}) Future<UpdateWorkspacesPoolResult>
Updates the specified pool.

Operators

operator ==(Object other) bool
The equality operator.
inherited