deleteClientBranding method

Future<void> deleteClientBranding({
  1. required List<ClientDeviceType> platforms,
  2. required String resourceId,
})

Deletes customized client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.

After you delete your customized client branding, your login portal reverts to the default client branding.

May throw AccessDeniedException. May throw InvalidParameterValuesException. May throw ResourceNotFoundException.

Parameter platforms : The device type for which you want to delete client branding.

Parameter resourceId : The directory identifier of the WorkSpace for which you want to delete client branding.

Implementation

Future<void> deleteClientBranding({
  required List<ClientDeviceType> platforms,
  required String resourceId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.DeleteClientBranding'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Platforms': platforms.map((e) => e.value).toList(),
      'ResourceId': resourceId,
    },
  );
}