describeClientBranding method

Future<DescribeClientBrandingResult> describeClientBranding({
  1. required String resourceId,
})

Describes the specified client branding. Client branding allows you to customize the log in page of various device types for your users. You can add your company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.

May throw AccessDeniedException. May throw InvalidParameterValuesException. May throw ResourceNotFoundException.

Parameter resourceId : The directory identifier of the WorkSpace for which you want to view client branding information.

Implementation

Future<DescribeClientBrandingResult> describeClientBranding({
  required String resourceId,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.DescribeClientBranding'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceId': resourceId,
    },
  );

  return DescribeClientBrandingResult.fromJson(jsonResponse.body);
}