describeConnectClientAddIns method

Future<DescribeConnectClientAddInsResult> describeConnectClientAddIns({
  1. required String resourceId,
  2. int? maxResults,
  3. String? nextToken,
})

Retrieves a list of Connect Customer client add-ins that have been created.

May throw AccessDeniedException. May throw InvalidParameterValuesException. May throw ResourceNotFoundException.

Parameter resourceId : The directory identifier for which the client add-in is configured.

Parameter maxResults : The maximum number of items to return.

Parameter nextToken : If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.

Implementation

Future<DescribeConnectClientAddInsResult> describeConnectClientAddIns({
  required String resourceId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.DescribeConnectClientAddIns'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceId': resourceId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeConnectClientAddInsResult.fromJson(jsonResponse.body);
}