describeConnectionAliasPermissions method
Describes the permissions that the owner of a connection alias has granted to another Amazon Web Services account for the specified connection alias. For more information, see Cross-Region Redirection for Amazon WorkSpaces.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
Parameter aliasId :
The identifier of the connection alias.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
If you received a NextToken from a previous call that was
paginated, provide this token to receive the next set of results.
Implementation
Future<DescribeConnectionAliasPermissionsResult>
describeConnectionAliasPermissions({
required String aliasId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.DescribeConnectionAliasPermissions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AliasId': aliasId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeConnectionAliasPermissionsResult.fromJson(jsonResponse.body);
}