describeWorkspaceImagePermissions method

Future<DescribeWorkspaceImagePermissionsResult> describeWorkspaceImagePermissions({
  1. required String imageId,
  2. int? maxResults,
  3. String? nextToken,
})

Describes the permissions that the owner of an image has granted to other Amazon Web Services accounts for an image.

May throw AccessDeniedException. May throw InvalidParameterValuesException. May throw ResourceNotFoundException.

Parameter imageId : The identifier of the image.

Parameter maxResults : The maximum number of items to return.

Parameter nextToken : If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.

Implementation

Future<DescribeWorkspaceImagePermissionsResult>
    describeWorkspaceImagePermissions({
  required String imageId,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.DescribeWorkspaceImagePermissions'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ImageId': imageId,
      if (maxResults != null) 'MaxResults': maxResults,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return DescribeWorkspaceImagePermissionsResult.fromJson(jsonResponse.body);
}