describeWorkspacesPools method

Future<DescribeWorkspacesPoolsResult> describeWorkspacesPools({
  1. List<DescribeWorkspacesPoolsFilter>? filters,
  2. int? limit,
  3. String? nextToken,
  4. List<String>? poolIds,
})

Describes the specified WorkSpaces Pools.

May throw AccessDeniedException. May throw InvalidParameterValuesException. May throw ResourceNotFoundException.

Parameter filters : The filter conditions for the WorkSpaces Pool to return.

Parameter limit : The maximum number of items to return.

Parameter nextToken : If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.

Parameter poolIds : The identifier of the WorkSpaces Pools.

Implementation

Future<DescribeWorkspacesPoolsResult> describeWorkspacesPools({
  List<DescribeWorkspacesPoolsFilter>? filters,
  int? limit,
  String? nextToken,
  List<String>? poolIds,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    25,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.DescribeWorkspacesPools'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      if (filters != null) 'Filters': filters,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
      if (poolIds != null) 'PoolIds': poolIds,
    },
  );

  return DescribeWorkspacesPoolsResult.fromJson(jsonResponse.body);
}