importClientBranding method
- required String resourceId,
- DefaultImportClientBrandingAttributes? deviceTypeAndroid,
- IosImportClientBrandingAttributes? deviceTypeIos,
- DefaultImportClientBrandingAttributes? deviceTypeLinux,
- DefaultImportClientBrandingAttributes? deviceTypeOsx,
- DefaultImportClientBrandingAttributes? deviceTypeWeb,
- DefaultImportClientBrandingAttributes? deviceTypeWindows,
Imports client branding. Client branding allows you to customize your WorkSpace's client login portal. You can tailor your login portal company logo, the support email address, support link, link to reset password, and a custom message for users trying to sign in.
After you import client branding, the default branding experience for the specified platform type is replaced with the imported experience
- You must specify at least one platform type when importing client branding.
- You can import up to 6 MB of data with each request. If your request exceeds this limit, you can import client branding for different platform types using separate requests.
-
In each platform type, the
SupportEmailandSupportLinkparameters are mutually exclusive. You can specify only one parameter for each platform type, but not both. - Imported data can take up to a minute to appear in the WorkSpaces client.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw ResourceLimitExceededException.
May throw ResourceNotFoundException.
Parameter resourceId :
The directory identifier of the WorkSpace for which you want to import
client branding.
Parameter deviceTypeAndroid :
The branding information to import for Android devices.
Parameter deviceTypeIos :
The branding information to import for iOS devices.
Parameter deviceTypeLinux :
The branding information to import for Linux devices.
Parameter deviceTypeOsx :
The branding information to import for macOS devices.
Parameter deviceTypeWeb :
The branding information to import for web access.
Parameter deviceTypeWindows :
The branding information to import for Windows devices.
Implementation
Future<ImportClientBrandingResult> importClientBranding({
required String resourceId,
DefaultImportClientBrandingAttributes? deviceTypeAndroid,
IosImportClientBrandingAttributes? deviceTypeIos,
DefaultImportClientBrandingAttributes? deviceTypeLinux,
DefaultImportClientBrandingAttributes? deviceTypeOsx,
DefaultImportClientBrandingAttributes? deviceTypeWeb,
DefaultImportClientBrandingAttributes? deviceTypeWindows,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.ImportClientBranding'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceId': resourceId,
if (deviceTypeAndroid != null) 'DeviceTypeAndroid': deviceTypeAndroid,
if (deviceTypeIos != null) 'DeviceTypeIos': deviceTypeIos,
if (deviceTypeLinux != null) 'DeviceTypeLinux': deviceTypeLinux,
if (deviceTypeOsx != null) 'DeviceTypeOsx': deviceTypeOsx,
if (deviceTypeWeb != null) 'DeviceTypeWeb': deviceTypeWeb,
if (deviceTypeWindows != null) 'DeviceTypeWindows': deviceTypeWindows,
},
);
return ImportClientBrandingResult.fromJson(jsonResponse.body);
}