modifyCertificateBasedAuthProperties method
Modifies the properties of the certificate-based authentication you want to use with your WorkSpaces.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
Parameter resourceId :
The resource identifiers, in the form of directory IDs.
Parameter certificateBasedAuthProperties :
The properties of the certificate-based authentication.
Parameter propertiesToDelete :
The properties of the certificate-based authentication you want to delete.
Implementation
Future<void> modifyCertificateBasedAuthProperties({
required String resourceId,
CertificateBasedAuthProperties? certificateBasedAuthProperties,
List<DeletableCertificateBasedAuthProperty>? propertiesToDelete,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.ModifyCertificateBasedAuthProperties'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceId': resourceId,
if (certificateBasedAuthProperties != null)
'CertificateBasedAuthProperties': certificateBasedAuthProperties,
if (propertiesToDelete != null)
'PropertiesToDelete': propertiesToDelete.map((e) => e.value).toList(),
},
);
}