modifyWorkspaceAccessProperties method

Future<void> modifyWorkspaceAccessProperties({
  1. required String resourceId,
  2. required WorkspaceAccessProperties workspaceAccessProperties,
})

Specifies which devices and operating systems users can use to access their WorkSpaces. For more information, see Control Device Access.

May throw AccessDeniedException. May throw InvalidParameterCombinationException. May throw InvalidParameterValuesException. May throw OperationNotSupportedException. May throw ResourceNotFoundException.

Parameter resourceId : The identifier of the directory.

Parameter workspaceAccessProperties : The device types and operating systems to enable or disable for access.

Implementation

Future<void> modifyWorkspaceAccessProperties({
  required String resourceId,
  required WorkspaceAccessProperties workspaceAccessProperties,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'WorkspacesService.ModifyWorkspaceAccessProperties'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'ResourceId': resourceId,
      'WorkspaceAccessProperties': workspaceAccessProperties,
    },
  );
}