updateWorkspaceImagePermission method
Shares or unshares an image with one account in the same Amazon Web Services Region by specifying whether that account has permission to copy the image. If the copy image permission is granted, the image is shared with that account. If the copy image permission is revoked, the image is unshared with the account.
After an image has been shared, the recipient account can copy the image to other Regions as needed.
In the China (Ningxia) Region, you can copy images only within the same Region.
In Amazon Web Services GovCloud (US), to copy images to and from other Regions, contact Amazon Web Services Support.
For more information about sharing images, see Share or Unshare a Custom WorkSpaces Image.
- To delete an image that has been shared, you must unshare the image before you delete it.
- Sharing Bring Your Own License (BYOL) images across Amazon Web Services accounts isn't supported at this time in Amazon Web Services GovCloud (US). To share BYOL images across accounts in Amazon Web Services GovCloud (US), contact Amazon Web Services Support.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
Parameter allowCopyImage :
The permission to copy the image. This permission can be revoked only
after an image has been shared.
Parameter imageId :
The identifier of the image.
Parameter sharedAccountId :
The identifier of the Amazon Web Services account to share or unshare the
image with.
Implementation
Future<void> updateWorkspaceImagePermission({
required bool allowCopyImage,
required String imageId,
required String sharedAccountId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.UpdateWorkspaceImagePermission'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AllowCopyImage': allowCopyImage,
'ImageId': imageId,
'SharedAccountId': sharedAccountId,
},
);
}