WorkSpacesThinClient class
Amazon WorkSpaces Thin Client is an affordable device built to work with Amazon Web Services End User Computing (EUC) virtual desktops to provide users with a complete cloud desktop solution. WorkSpaces Thin Client is a compact device designed to connect up to two monitors and USB devices like a keyboard, mouse, headset, and webcam. To maximize endpoint security, WorkSpaces Thin Client devices do not allow local data storage or installation of unapproved applications. The WorkSpaces Thin Client device ships preloaded with device management software.
You can use these APIs to complete WorkSpaces Thin Client tasks, such as creating environments or viewing devices. For more information about WorkSpaces Thin Client, including the required permissions to use the service, see the Amazon WorkSpaces Thin Client Administrator Guide. For more information about using the Command Line Interface (CLI) to manage your WorkSpaces Thin Client resources, see the WorkSpaces Thin Client section of the CLI Reference.
Constructors
- WorkSpacesThinClient({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createEnvironment(
{required String desktopArn, String? clientToken, String? desiredSoftwareSetId, String? desktopEndpoint, Map< String, String> ? deviceCreationTags, String? kmsKeyArn, MaintenanceWindow? maintenanceWindow, String? name, SoftwareSetUpdateMode? softwareSetUpdateMode, SoftwareSetUpdateSchedule? softwareSetUpdateSchedule, Map<String, String> ? tags}) → Future<CreateEnvironmentResponse> - Creates an environment for your thin client devices.
-
deleteDevice(
{required String id, String? clientToken}) → Future< void> - Deletes a thin client device.
-
deleteEnvironment(
{required String id, String? clientToken}) → Future< void> - Deletes an environment.
-
deregisterDevice(
{required String id, String? clientToken, TargetDeviceStatus? targetDeviceStatus}) → Future< void> - Deregisters a thin client device.
-
getDevice(
{required String id}) → Future< GetDeviceResponse> - Returns information for a thin client device.
-
getEnvironment(
{required String id}) → Future< GetEnvironmentResponse> - Returns information for an environment.
-
getSoftwareSet(
{required String id}) → Future< GetSoftwareSetResponse> - Returns information for a software set.
-
listDevices(
{int? maxResults, String? nextToken}) → Future< ListDevicesResponse> - Returns a list of thin client devices.
-
listEnvironments(
{int? maxResults, String? nextToken}) → Future< ListEnvironmentsResponse> - Returns a list of environments.
-
listSoftwareSets(
{int? maxResults, String? nextToken}) → Future< ListSoftwareSetsResponse> - Returns a list of software sets.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag or tags from a resource.
-
updateDevice(
{required String id, String? desiredSoftwareSetId, String? name, SoftwareSetUpdateSchedule? softwareSetUpdateSchedule}) → Future< UpdateDeviceResponse> - Updates a thin client device.
-
updateEnvironment(
{required String id, String? desiredSoftwareSetId, String? desktopArn, String? desktopEndpoint, Map< String, String> ? deviceCreationTags, MaintenanceWindow? maintenanceWindow, String? name, SoftwareSetUpdateMode? softwareSetUpdateMode, SoftwareSetUpdateSchedule? softwareSetUpdateSchedule}) → Future<UpdateEnvironmentResponse> - Updates an environment.
-
updateSoftwareSet(
{required String id, required SoftwareSetValidationStatus validationStatus}) → Future< void> - Updates a software set.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited