deregisterDevice method
Deregisters a thin client device.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The ID of the device to deregister.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value.
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter targetDeviceStatus :
The desired new status for the device.
Implementation
Future<void> deregisterDevice({
required String id,
String? clientToken,
TargetDeviceStatus? targetDeviceStatus,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (targetDeviceStatus != null)
'targetDeviceStatus': targetDeviceStatus.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/deregister-device/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}