WorkSpacesWeb class

Amazon WorkSpaces Secure Browser is a low cost, fully managed WorkSpace built specifically to facilitate secure, web-based workloads. WorkSpaces Secure Browser makes it easy for customers to safely provide their employees with access to internal websites and SaaS web applications without the administrative burden of appliances or specialized client software. WorkSpaces Secure Browser provides simple policy tools tailored for user interactions, while offloading common tasks like capacity management, scaling, and maintaining browser images.

Constructors

WorkSpacesWeb({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

associateBrowserSettings({required String browserSettingsArn, required String portalArn}) Future<AssociateBrowserSettingsResponse>
Associates a browser settings resource with a web portal.
associateDataProtectionSettings({required String dataProtectionSettingsArn, required String portalArn}) Future<AssociateDataProtectionSettingsResponse>
Associates a data protection settings resource with a web portal.
associateIpAccessSettings({required String ipAccessSettingsArn, required String portalArn}) Future<AssociateIpAccessSettingsResponse>
Associates an IP access settings resource with a web portal.
associateNetworkSettings({required String networkSettingsArn, required String portalArn}) Future<AssociateNetworkSettingsResponse>
Associates a network settings resource with a web portal.
associateSessionLogger({required String portalArn, required String sessionLoggerArn}) Future<AssociateSessionLoggerResponse>
Associates a session logger with a portal.
associateTrustStore({required String portalArn, required String trustStoreArn}) Future<AssociateTrustStoreResponse>
Associates a trust store with a web portal.
associateUserAccessLoggingSettings({required String portalArn, required String userAccessLoggingSettingsArn}) Future<AssociateUserAccessLoggingSettingsResponse>
Associates a user access logging settings resource with a web portal.
associateUserSettings({required String portalArn, required String userSettingsArn}) Future<AssociateUserSettingsResponse>
Associates a user settings resource with a web portal.
close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createBrowserSettings({Map<String, String>? additionalEncryptionContext, String? browserPolicy, String? clientToken, String? customerManagedKey, List<Tag>? tags, WebContentFilteringPolicy? webContentFilteringPolicy}) Future<CreateBrowserSettingsResponse>
Creates a browser settings resource that can be associated with a web portal. Once associated with a web portal, browser settings control how the browser will behave once a user starts a streaming session for the web portal.
createDataProtectionSettings({Map<String, String>? additionalEncryptionContext, String? clientToken, String? customerManagedKey, String? description, String? displayName, InlineRedactionConfiguration? inlineRedactionConfiguration, List<Tag>? tags}) Future<CreateDataProtectionSettingsResponse>
Creates a data protection settings resource that can be associated with a web portal.
createIdentityProvider({required Map<String, String> identityProviderDetails, required String identityProviderName, required IdentityProviderType identityProviderType, required String portalArn, String? clientToken, List<Tag>? tags}) Future<CreateIdentityProviderResponse>
Creates an identity provider resource that is then associated with a web portal.
createIpAccessSettings({required List<IpRule> ipRules, Map<String, String>? additionalEncryptionContext, String? clientToken, String? customerManagedKey, String? description, String? displayName, List<Tag>? tags}) Future<CreateIpAccessSettingsResponse>
Creates an IP access settings resource that can be associated with a web portal.
createNetworkSettings({required List<String> securityGroupIds, required List<String> subnetIds, required String vpcId, String? clientToken, List<Tag>? tags}) Future<CreateNetworkSettingsResponse>
Creates a network settings resource that can be associated with a web portal. Once associated with a web portal, network settings define how streaming instances will connect with your specified VPC.
createPortal({Map<String, String>? additionalEncryptionContext, AuthenticationType? authenticationType, String? clientToken, String? customerManagedKey, String? displayName, InstanceType? instanceType, int? maxConcurrentSessions, String? portalCustomDomain, List<Tag>? tags}) Future<CreatePortalResponse>
Creates a web portal.
createSessionLogger({required EventFilter eventFilter, required LogConfiguration logConfiguration, Map<String, String>? additionalEncryptionContext, String? clientToken, String? customerManagedKey, String? displayName, List<Tag>? tags}) Future<CreateSessionLoggerResponse>
Creates a session logger.
createTrustStore({required List<Uint8List> certificateList, String? clientToken, List<Tag>? tags}) Future<CreateTrustStoreResponse>
Creates a trust store that can be associated with a web portal. A trust store contains certificate authority (CA) certificates. Once associated with a web portal, the browser in a streaming session will recognize certificates that have been issued using any of the CAs in the trust store. If your organization has internal websites that use certificates issued by private CAs, you should add the private CA certificate to the trust store.
createUserAccessLoggingSettings({required String kinesisStreamArn, String? clientToken, List<Tag>? tags}) Future<CreateUserAccessLoggingSettingsResponse>
Creates a user access logging settings resource that can be associated with a web portal.
createUserSettings({required EnabledType copyAllowed, required EnabledType downloadAllowed, required EnabledType pasteAllowed, required EnabledType printAllowed, required EnabledType uploadAllowed, Map<String, String>? additionalEncryptionContext, BrandingConfigurationCreateInput? brandingConfigurationInput, String? clientToken, CookieSynchronizationConfiguration? cookieSynchronizationConfiguration, String? customerManagedKey, EnabledType? deepLinkAllowed, int? disconnectTimeoutInMinutes, int? idleDisconnectTimeoutInMinutes, List<Tag>? tags, ToolbarConfiguration? toolbarConfiguration, EnabledType? webAuthnAllowed}) Future<CreateUserSettingsResponse>
Creates a user settings resource that can be associated with a web portal. Once associated with a web portal, user settings control how users can transfer data between a streaming session and the their local devices.
deleteBrowserSettings({required String browserSettingsArn}) Future<void>
Deletes browser settings.
deleteDataProtectionSettings({required String dataProtectionSettingsArn}) Future<void>
Deletes data protection settings.
deleteIdentityProvider({required String identityProviderArn}) Future<void>
Deletes the identity provider.
deleteIpAccessSettings({required String ipAccessSettingsArn}) Future<void>
Deletes IP access settings.
deleteNetworkSettings({required String networkSettingsArn}) Future<void>
Deletes network settings.
deletePortal({required String portalArn}) Future<void>
Deletes a web portal.
deleteSessionLogger({required String sessionLoggerArn}) Future<void>
Deletes a session logger resource.
deleteTrustStore({required String trustStoreArn}) Future<void>
Deletes the trust store.
deleteUserAccessLoggingSettings({required String userAccessLoggingSettingsArn}) Future<void>
Deletes user access logging settings.
deleteUserSettings({required String userSettingsArn}) Future<void>
Deletes user settings.
disassociateBrowserSettings({required String portalArn}) Future<void>
Disassociates browser settings from a web portal.
disassociateDataProtectionSettings({required String portalArn}) Future<void>
Disassociates data protection settings from a web portal.
disassociateIpAccessSettings({required String portalArn}) Future<void>
Disassociates IP access settings from a web portal.
disassociateNetworkSettings({required String portalArn}) Future<void>
Disassociates network settings from a web portal.
disassociateSessionLogger({required String portalArn}) Future<void>
Disassociates a session logger from a portal.
disassociateTrustStore({required String portalArn}) Future<void>
Disassociates a trust store from a web portal.
disassociateUserAccessLoggingSettings({required String portalArn}) Future<void>
Disassociates user access logging settings from a web portal.
disassociateUserSettings({required String portalArn}) Future<void>
Disassociates user settings from a web portal.
expireSession({required String portalId, required String sessionId}) Future<void>
Expires an active secure browser session.
getBrowserSettings({required String browserSettingsArn}) Future<GetBrowserSettingsResponse>
Gets browser settings.
getDataProtectionSettings({required String dataProtectionSettingsArn}) Future<GetDataProtectionSettingsResponse>
Gets the data protection settings.
getIdentityProvider({required String identityProviderArn}) Future<GetIdentityProviderResponse>
Gets the identity provider.
getIpAccessSettings({required String ipAccessSettingsArn}) Future<GetIpAccessSettingsResponse>
Gets the IP access settings.
getNetworkSettings({required String networkSettingsArn}) Future<GetNetworkSettingsResponse>
Gets the network settings.
getPortal({required String portalArn}) Future<GetPortalResponse>
Gets the web portal.
getPortalServiceProviderMetadata({required String portalArn}) Future<GetPortalServiceProviderMetadataResponse>
Gets the service provider metadata.
getSession({required String portalId, required String sessionId}) Future<GetSessionResponse>
Gets information for a secure browser session.
getSessionLogger({required String sessionLoggerArn}) Future<GetSessionLoggerResponse>
Gets details about a specific session logger resource.
getTrustStore({required String trustStoreArn}) Future<GetTrustStoreResponse>
Gets the trust store.
getTrustStoreCertificate({required String thumbprint, required String trustStoreArn}) Future<GetTrustStoreCertificateResponse>
Gets the trust store certificate.
getUserAccessLoggingSettings({required String userAccessLoggingSettingsArn}) Future<GetUserAccessLoggingSettingsResponse>
Gets user access logging settings.
getUserSettings({required String userSettingsArn}) Future<GetUserSettingsResponse>
Gets user settings.
listBrowserSettings({int? maxResults, String? nextToken}) Future<ListBrowserSettingsResponse>
Retrieves a list of browser settings.
listDataProtectionSettings({int? maxResults, String? nextToken}) Future<ListDataProtectionSettingsResponse>
Retrieves a list of data protection settings.
listIdentityProviders({required String portalArn, int? maxResults, String? nextToken}) Future<ListIdentityProvidersResponse>
Retrieves a list of identity providers for a specific web portal.
listIpAccessSettings({int? maxResults, String? nextToken}) Future<ListIpAccessSettingsResponse>
Retrieves a list of IP access settings.
listNetworkSettings({int? maxResults, String? nextToken}) Future<ListNetworkSettingsResponse>
Retrieves a list of network settings.
listPortals({int? maxResults, String? nextToken}) Future<ListPortalsResponse>
Retrieves a list or web portals.
listSessionLoggers({int? maxResults, String? nextToken}) Future<ListSessionLoggersResponse>
Lists all available session logger resources.
listSessions({required String portalId, int? maxResults, String? nextToken, String? sessionId, SessionSortBy? sortBy, SessionStatus? status, String? username}) Future<ListSessionsResponse>
Lists information for multiple secure browser sessions from a specific portal.
listTagsForResource({required String resourceArn}) Future<ListTagsForResourceResponse>
Retrieves a list of tags for a resource.
listTrustStoreCertificates({required String trustStoreArn, int? maxResults, String? nextToken}) Future<ListTrustStoreCertificatesResponse>
Retrieves a list of trust store certificates.
listTrustStores({int? maxResults, String? nextToken}) Future<ListTrustStoresResponse>
Retrieves a list of trust stores.
listUserAccessLoggingSettings({int? maxResults, String? nextToken}) Future<ListUserAccessLoggingSettingsResponse>
Retrieves a list of user access logging settings.
listUserSettings({int? maxResults, String? nextToken}) Future<ListUserSettingsResponse>
Retrieves a list of user settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource({required String resourceArn, required List<Tag> tags, String? clientToken}) Future<void>
Adds or overwrites one or more tags for the specified resource.
toString() String
A string representation of this object.
inherited
untagResource({required String resourceArn, required List<String> tagKeys}) Future<void>
Removes one or more tags from the specified resource.
updateBrowserSettings({required String browserSettingsArn, String? browserPolicy, String? clientToken, WebContentFilteringPolicy? webContentFilteringPolicy}) Future<UpdateBrowserSettingsResponse>
Updates browser settings.
updateDataProtectionSettings({required String dataProtectionSettingsArn, String? clientToken, String? description, String? displayName, InlineRedactionConfiguration? inlineRedactionConfiguration}) Future<UpdateDataProtectionSettingsResponse>
Updates data protection settings.
updateIdentityProvider({required String identityProviderArn, String? clientToken, Map<String, String>? identityProviderDetails, String? identityProviderName, IdentityProviderType? identityProviderType}) Future<UpdateIdentityProviderResponse>
Updates the identity provider.
updateIpAccessSettings({required String ipAccessSettingsArn, String? clientToken, String? description, String? displayName, List<IpRule>? ipRules}) Future<UpdateIpAccessSettingsResponse>
Updates IP access settings.
updateNetworkSettings({required String networkSettingsArn, String? clientToken, List<String>? securityGroupIds, List<String>? subnetIds, String? vpcId}) Future<UpdateNetworkSettingsResponse>
Updates network settings.
updatePortal({required String portalArn, AuthenticationType? authenticationType, String? displayName, InstanceType? instanceType, int? maxConcurrentSessions, String? portalCustomDomain}) Future<UpdatePortalResponse>
Updates a web portal.
updateSessionLogger({required String sessionLoggerArn, String? displayName, EventFilter? eventFilter, LogConfiguration? logConfiguration}) Future<UpdateSessionLoggerResponse>
Updates the details of a session logger.
updateTrustStore({required String trustStoreArn, List<Uint8List>? certificatesToAdd, List<String>? certificatesToDelete, String? clientToken}) Future<UpdateTrustStoreResponse>
Updates the trust store.
updateUserAccessLoggingSettings({required String userAccessLoggingSettingsArn, String? clientToken, String? kinesisStreamArn}) Future<UpdateUserAccessLoggingSettingsResponse>
Updates the user access logging settings.
updateUserSettings({required String userSettingsArn, BrandingConfigurationUpdateInput? brandingConfigurationInput, String? clientToken, CookieSynchronizationConfiguration? cookieSynchronizationConfiguration, EnabledType? copyAllowed, EnabledType? deepLinkAllowed, int? disconnectTimeoutInMinutes, EnabledType? downloadAllowed, int? idleDisconnectTimeoutInMinutes, EnabledType? pasteAllowed, EnabledType? printAllowed, ToolbarConfiguration? toolbarConfiguration, EnabledType? uploadAllowed, EnabledType? webAuthnAllowed}) Future<UpdateUserSettingsResponse>
Updates the user settings.

Operators

operator ==(Object other) bool
The equality operator.
inherited