associateSessionLogger method

Future<AssociateSessionLoggerResponse> associateSessionLogger({
  1. required String portalArn,
  2. required String sessionLoggerArn,
})

Associates a session logger with a portal.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter portalArn : The ARN of the portal to associate to the session logger ARN.

Parameter sessionLoggerArn : The ARN of the session logger to associate to the portal ARN.

Implementation

Future<AssociateSessionLoggerResponse> associateSessionLogger({
  required String portalArn,
  required String sessionLoggerArn,
}) async {
  final $query = <String, List<String>>{
    'sessionLoggerArn': [sessionLoggerArn],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'PUT',
    requestUri:
        '/portals/${portalArn.split('/').map(Uri.encodeComponent).join('/')}/sessionLogger',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return AssociateSessionLoggerResponse.fromJson(response);
}