createBrowserSettings method

Future<CreateBrowserSettingsResponse> createBrowserSettings({
  1. Map<String, String>? additionalEncryptionContext,
  2. String? browserPolicy,
  3. String? clientToken,
  4. String? customerManagedKey,
  5. List<Tag>? tags,
  6. WebContentFilteringPolicy? webContentFilteringPolicy,
})

Creates a browser settings resource that can be associated with a web portal. Once associated with a web portal, browser settings control how the browser will behave once a user starts a streaming session for the web portal.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter additionalEncryptionContext : Additional encryption context of the browser settings.

Parameter browserPolicy : A JSON string containing Chrome Enterprise policies that will be applied to all streaming sessions.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.

If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.

Parameter customerManagedKey : The custom managed key of the browser settings.

Parameter tags : The tags to add to the browser settings resource. A tag is a key-value pair.

Parameter webContentFilteringPolicy : The policy that specifies which URLs end users are allowed to access or which URLs or domain categories they are restricted from accessing for enhanced security.

Implementation

Future<CreateBrowserSettingsResponse> createBrowserSettings({
  Map<String, String>? additionalEncryptionContext,
  String? browserPolicy,
  String? clientToken,
  String? customerManagedKey,
  List<Tag>? tags,
  WebContentFilteringPolicy? webContentFilteringPolicy,
}) async {
  final $payload = <String, dynamic>{
    if (additionalEncryptionContext != null)
      'additionalEncryptionContext': additionalEncryptionContext,
    if (browserPolicy != null) 'browserPolicy': browserPolicy,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (customerManagedKey != null) 'customerManagedKey': customerManagedKey,
    if (tags != null) 'tags': tags,
    if (webContentFilteringPolicy != null)
      'webContentFilteringPolicy': webContentFilteringPolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/browserSettings',
    exceptionFnMap: _exceptionFns,
  );
  return CreateBrowserSettingsResponse.fromJson(response);
}