createTrustStore method
Creates a trust store that can be associated with a web portal. A trust store contains certificate authority (CA) certificates. Once associated with a web portal, the browser in a streaming session will recognize certificates that have been issued using any of the CAs in the trust store. If your organization has internal websites that use certificates issued by private CAs, you should add the private CA certificate to the trust store.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter certificateList :
A list of CA certificates to be added to the trust store.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Idempotency ensures that an API request
completes only once. With an idempotent request, if the original request
completes successfully, subsequent retries with the same client token
returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.
Parameter tags :
The tags to add to the trust store. A tag is a key-value pair.
Implementation
Future<CreateTrustStoreResponse> createTrustStore({
required List<Uint8List> certificateList,
String? clientToken,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'certificateList': certificateList.map(base64Encode).toList(),
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/trustStores',
exceptionFnMap: _exceptionFns,
);
return CreateTrustStoreResponse.fromJson(response);
}