listSessionLoggers method
Lists all available session logger resources.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to be included in the next page.
Parameter nextToken :
The pagination token used to retrieve the next page of results for this
operation.
Implementation
Future<ListSessionLoggersResponse> listSessionLoggers({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/sessionLoggers',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSessionLoggersResponse.fromJson(response);
}