listTrustStoreCertificates method
Retrieves a list of trust store certificates.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter trustStoreArn :
The ARN of the trust store
Parameter maxResults :
The maximum number of results to be included in the next page.
Parameter nextToken :
The pagination token used to retrieve the next page of results for this
operation.
Implementation
Future<ListTrustStoreCertificatesResponse> listTrustStoreCertificates({
required String trustStoreArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/trustStores/${trustStoreArn.split('/').map(Uri.encodeComponent).join('/')}/certificates',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListTrustStoreCertificatesResponse.fromJson(response);
}