updateBrowserSettings method

Future<UpdateBrowserSettingsResponse> updateBrowserSettings({
  1. required String browserSettingsArn,
  2. String? browserPolicy,
  3. String? clientToken,
  4. WebContentFilteringPolicy? webContentFilteringPolicy,
})

Updates browser settings.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter browserSettingsArn : The ARN of the browser settings.

Parameter browserPolicy : A JSON string containing Chrome Enterprise policies that will be applied to all streaming sessions.

Parameter clientToken : A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.

If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.

Parameter webContentFilteringPolicy : The policy that specifies which URLs end users are allowed to access or which URLs or domain categories they are restricted from accessing for enhanced security.

Implementation

Future<UpdateBrowserSettingsResponse> updateBrowserSettings({
  required String browserSettingsArn,
  String? browserPolicy,
  String? clientToken,
  WebContentFilteringPolicy? webContentFilteringPolicy,
}) async {
  final $payload = <String, dynamic>{
    if (browserPolicy != null) 'browserPolicy': browserPolicy,
    'clientToken': clientToken ?? _s.generateIdempotencyToken(),
    if (webContentFilteringPolicy != null)
      'webContentFilteringPolicy': webContentFilteringPolicy,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'PATCH',
    requestUri:
        '/browserSettings/${browserSettingsArn.split('/').map(Uri.encodeComponent).join('/')}',
    exceptionFnMap: _exceptionFns,
  );
  return UpdateBrowserSettingsResponse.fromJson(response);
}