updateDataProtectionSettings method
Updates data protection settings.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter dataProtectionSettingsArn :
The ARN of the data protection settings.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Idempotency ensures that an API request
completes only once. With an idempotent request, if the original request
completes successfully, subsequent retries with the same client token
return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.
Parameter description :
The description of the data protection settings.
Parameter displayName :
The display name of the data protection settings.
Parameter inlineRedactionConfiguration :
The inline redaction configuration of the data protection settings that
will be applied to all sessions.
Implementation
Future<UpdateDataProtectionSettingsResponse> updateDataProtectionSettings({
required String dataProtectionSettingsArn,
String? clientToken,
String? description,
String? displayName,
InlineRedactionConfiguration? inlineRedactionConfiguration,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'description': description,
if (displayName != null) 'displayName': displayName,
if (inlineRedactionConfiguration != null)
'inlineRedactionConfiguration': inlineRedactionConfiguration,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/dataProtectionSettings/${dataProtectionSettingsArn.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
return UpdateDataProtectionSettingsResponse.fromJson(response);
}