XRay class
Amazon Web Services X-Ray provides APIs for managing debug traces and retrieving service maps and other data created by processing those traces.
Constructors
- XRay({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetTraces(
{required List< String> traceIds, String? nextToken}) → Future<BatchGetTracesResult> - GetTraceSummaries
-
cancelTraceRetrieval(
{required String retrievalToken}) → Future< void> -
Cancels an ongoing trace retrieval job initiated by
StartTraceRetrievalusing the providedRetrievalToken. A successful cancellation will return an HTTP 200 response. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createGroup(
{required String groupName, String? filterExpression, InsightsConfiguration? insightsConfiguration, List< Tag> ? tags}) → Future<CreateGroupResult> - Creates a group resource with a name and a filter expression.
-
createSamplingRule(
{required SamplingRule samplingRule, List< Tag> ? tags}) → Future<CreateSamplingRuleResult> - Creates a rule to control sampling behavior for instrumented applications. Services retrieve rules with GetSamplingRules, and evaluate each rule in ascending order of priority for each request. If a rule matches, the service records a trace, borrowing it from the reservoir size. After 10 seconds, the service reports back to X-Ray with GetSamplingTargets to get updated versions of each in-use rule. The updated rule contains a trace quota that the service can use instead of borrowing from the reservoir.
-
deleteGroup(
{String? groupARN, String? groupName}) → Future< void> - Deletes a group resource.
-
deleteResourcePolicy(
{required String policyName, String? policyRevisionId}) → Future< void> - Deletes a resource policy from the target Amazon Web Services account.
-
deleteSamplingRule(
{String? ruleARN, String? ruleName}) → Future< DeleteSamplingRuleResult> - Deletes a sampling rule.
-
getEncryptionConfig(
) → Future< GetEncryptionConfigResult> - Retrieves the current encryption configuration for X-Ray data.
-
getGroup(
{String? groupARN, String? groupName}) → Future< GetGroupResult> - Retrieves group resource details.
-
getGroups(
{String? nextToken}) → Future< GetGroupsResult> - Retrieves all active group details.
-
getIndexingRules(
{String? nextToken}) → Future< GetIndexingRulesResult> - Retrieves all indexing rules.
-
getInsight(
{required String insightId}) → Future< GetInsightResult> - Retrieves the summary information of an insight. This includes impact to clients and root cause services, the top anomalous services, the category, the state of the insight, and the start and end time of the insight.
-
getInsightEvents(
{required String insightId, int? maxResults, String? nextToken}) → Future< GetInsightEventsResult> - X-Ray reevaluates insights periodically until they're resolved, and records each intermediate state as an event. You can review an insight's events in the Impact Timeline on the Inspect page in the X-Ray console.
-
getInsightImpactGraph(
{required DateTime endTime, required String insightId, required DateTime startTime, String? nextToken}) → Future< GetInsightImpactGraphResult> - Retrieves a service graph structure filtered by the specified insight. The service graph is limited to only structural information. For a complete service graph, use this API with the GetServiceGraph API.
-
getInsightSummaries(
{required DateTime endTime, required DateTime startTime, String? groupARN, String? groupName, int? maxResults, String? nextToken, List< InsightState> ? states}) → Future<GetInsightSummariesResult> - Retrieves the summaries of all insights in the specified group matching the provided filter values.
-
getRetrievedTracesGraph(
{required String retrievalToken, String? nextToken}) → Future< GetRetrievedTracesGraphResult> -
Retrieves a service graph for traces based on the specified
RetrievalTokenfrom the CloudWatch log group generated by Transaction Search. This API does not initiate a retrieval job. You must first executeStartTraceRetrievalto obtain the requiredRetrievalToken. -
getSamplingRules(
{String? nextToken}) → Future< GetSamplingRulesResult> - Retrieves all sampling rules.
-
getSamplingStatisticSummaries(
{String? nextToken}) → Future< GetSamplingStatisticSummariesResult> - Retrieves information about recent sampling results for all sampling rules.
-
getSamplingTargets(
{required List< SamplingStatisticsDocument> samplingStatisticsDocuments, List<SamplingBoostStatisticsDocument> ? samplingBoostStatisticsDocuments}) → Future<GetSamplingTargetsResult> - Requests a sampling quota for rules that the service is using to sample requests.
-
getServiceGraph(
{required DateTime endTime, required DateTime startTime, String? groupARN, String? groupName, String? nextToken}) → Future< GetServiceGraphResult> - Retrieves a document that describes services that process incoming requests, and downstream services that they call as a result. Root services process incoming requests and make calls to downstream services. Root services are applications that use the Amazon Web Services X-Ray SDK. Downstream services can be other applications, Amazon Web Services resources, HTTP web APIs, or SQL databases.
-
getTimeSeriesServiceStatistics(
{required DateTime endTime, required DateTime startTime, String? entitySelectorExpression, bool? forecastStatistics, String? groupARN, String? groupName, String? nextToken, int? period}) → Future< GetTimeSeriesServiceStatisticsResult> - Get an aggregation of service statistics defined by a specific time range.
-
getTraceGraph(
{required List< String> traceIds, String? nextToken}) → Future<GetTraceGraphResult> - Retrieves a service graph for one or more specific trace IDs.
-
getTraceSegmentDestination(
) → Future< GetTraceSegmentDestinationResult> -
Retrieves the current destination of data sent to
PutTraceSegmentsand OpenTelemetry protocol (OTLP) endpoint. The Transaction Search feature requires a CloudWatchLogs destination. For more information, see Transaction Search and OpenTelemetry. -
getTraceSummaries(
{required DateTime endTime, required DateTime startTime, String? filterExpression, String? nextToken, bool? sampling, SamplingStrategy? samplingStrategy, TimeRangeType? timeRangeType}) → Future< GetTraceSummariesResult> -
Retrieves IDs and annotations for traces available for a specified time
frame using an optional filter. To get the full traces, pass the trace IDs
to
BatchGetTraces. -
listResourcePolicies(
{String? nextToken}) → Future< ListResourcePoliciesResult> - Returns the list of resource policies in the target Amazon Web Services account.
-
listRetrievedTraces(
{required String retrievalToken, String? nextToken, TraceFormatType? traceFormat}) → Future< ListRetrievedTracesResult> -
Retrieves a list of traces for a given
RetrievalTokenfrom the CloudWatch log group generated by Transaction Search. For information on what each trace returns, see BatchGetTraces. -
listTagsForResource(
{required String resourceARN, String? nextToken}) → Future< ListTagsForResourceResponse> - Returns a list of tags that are applied to the specified Amazon Web Services X-Ray group or sampling rule.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putEncryptionConfig(
{required EncryptionType type, String? keyId}) → Future< PutEncryptionConfigResult> - Updates the encryption configuration for X-Ray data.
-
putResourcePolicy(
{required String policyDocument, required String policyName, bool? bypassPolicyLockoutCheck, String? policyRevisionId}) → Future< PutResourcePolicyResult> - Sets the resource policy to grant one or more Amazon Web Services services and accounts permissions to access X-Ray. Each resource policy will be associated with a specific Amazon Web Services account. Each Amazon Web Services account can have a maximum of 5 resource policies, and each policy name must be unique within that account. The maximum size of each resource policy is 5KB.
-
putTelemetryRecords(
{required List< TelemetryRecord> telemetryRecords, String? eC2InstanceId, String? hostname, String? resourceARN}) → Future<void> - Used by the Amazon Web Services X-Ray daemon to upload telemetry.
-
putTraceSegments(
{required List< String> traceSegmentDocuments}) → Future<PutTraceSegmentsResult> - Uploads segment documents to Amazon Web Services X-Ray. A segment document can be a completed segment, an in-progress segment, or an array of subsegments.
-
startTraceRetrieval(
{required DateTime endTime, required DateTime startTime, required List< String> traceIds}) → Future<StartTraceRetrievalResult> - Initiates a trace retrieval process using the specified time range and for the given trace IDs in the Transaction Search generated CloudWatch log group. For more information, see Transaction Search.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Applies tags to an existing Amazon Web Services X-Ray group or sampling rule.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> -
Removes tags from an Amazon Web Services X-Ray group or sampling rule. You
cannot edit or delete system tags (those with an
aws:prefix). -
updateGroup(
{String? filterExpression, String? groupARN, String? groupName, InsightsConfiguration? insightsConfiguration}) → Future< UpdateGroupResult> - Updates a group resource.
-
updateIndexingRule(
{required String name, required IndexingRuleValueUpdate rule}) → Future< UpdateIndexingRuleResult> - Modifies an indexing rule’s configuration.
-
updateSamplingRule(
{required SamplingRuleUpdate samplingRuleUpdate}) → Future< UpdateSamplingRuleResult> - Modifies a sampling rule's configuration.
-
updateTraceSegmentDestination(
{TraceSegmentDestination? destination}) → Future< UpdateTraceSegmentDestinationResult> -
Modifies the destination of data sent to
PutTraceSegments. The Transaction Search feature requires the CloudWatchLogs destination. For more information, see Transaction Search.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited