getRetrievedTracesGraph method
Retrieves a service graph for traces based on the specified
RetrievalToken from the CloudWatch log group generated by
Transaction Search. This API does not initiate a retrieval job. You must
first execute StartTraceRetrieval to obtain the required
RetrievalToken.
The trace graph describes services that process incoming requests and any downstream services they call, which may include Amazon Web Services resources, external APIs, or databases.
The response is empty until the RetrievalStatus is
COMPLETE. Retry the request after the status changes from
RUNNING or SCHEDULED to COMPLETE to access the full
service graph.
When CloudWatch log is the destination, this API can support cross-account observability and service graph retrieval across linked accounts.
For retrieving graphs from X-Ray directly as opposed to the Transaction-Search Log group, see GetTraceGraph.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottledException.
Parameter retrievalToken :
Retrieval token.
Parameter nextToken :
Specify the pagination token returned by a previous request to retrieve
the next page of indexes.
Implementation
Future<GetRetrievedTracesGraphResult> getRetrievedTracesGraph({
required String retrievalToken,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'RetrievalToken': retrievalToken,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetRetrievedTracesGraph',
exceptionFnMap: _exceptionFns,
);
return GetRetrievedTracesGraphResult.fromJson(response);
}