getServiceGraph method
Retrieves a document that describes services that process incoming requests, and downstream services that they call as a result. Root services process incoming requests and make calls to downstream services. Root services are applications that use the Amazon Web Services X-Ray SDK. Downstream services can be other applications, Amazon Web Services resources, HTTP web APIs, or SQL databases.
May throw InvalidRequestException.
May throw ThrottledException.
Parameter endTime :
The end of the timeframe for which to generate a graph.
Parameter startTime :
The start of the time frame for which to generate a graph.
Parameter groupARN :
The Amazon Resource Name (ARN) of a group based on which you want to
generate a graph.
Parameter groupName :
The name of a group based on which you want to generate a graph.
Parameter nextToken :
Pagination token.
Implementation
Future<GetServiceGraphResult> getServiceGraph({
required DateTime endTime,
required DateTime startTime,
String? groupARN,
String? groupName,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'EndTime': unixTimestampToJson(endTime),
'StartTime': unixTimestampToJson(startTime),
if (groupARN != null) 'GroupARN': groupARN,
if (groupName != null) 'GroupName': groupName,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ServiceGraph',
exceptionFnMap: _exceptionFns,
);
return GetServiceGraphResult.fromJson(response);
}