getPrimaryEmail method
Retrieves the primary email address for the specified account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter accountId :
Specifies the 12-digit account ID number of the Amazon Web Services
account that you want to access or modify with this operation. To use this
parameter, the caller must be an identity in the organization's
management account or a delegated administrator account. The specified
account ID must be a member account in the same organization. The
organization must have all
features enabled, and the organization must have trusted
access enabled for the Account Management service, and optionally a delegated
admin account assigned.
This operation can only be called from the management account or the delegated administrator account of an organization for a member account.
Implementation
Future<GetPrimaryEmailResponse> getPrimaryEmail({
required String accountId,
}) async {
final $payload = <String, dynamic>{
'AccountId': accountId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/getPrimaryEmail',
exceptionFnMap: _exceptionFns,
);
return GetPrimaryEmailResponse.fromJson(response);
}