tagResource method
Adds one or more tags to an ACM resource. Tags are labels that you can use
to identify and organize your Amazon Web Services resources. Each tag
consists of a key and an optional value.
To remove one or more tags, use the UntagResource action. To view
all of the tags that have been applied to a resource, use the
ListTagsForResource action.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the ACM resource to which the tag is to be applied.
Parameter tags :
The key-value pair that defines the tag to apply.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CertificateManager.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'Tags': tags,
},
endpoint: _resolveEndpoint(
serviceType: 'ACM',
),
);
}