untagResource method
Removes one or more tags from an ACM resource. To add one or more tags, use the TagResource action. To view all of the tags that have been applied to a resource, use the ListTagsForResource action.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the ACM resource from which the tag is to be removed.
Parameter tagKeys :
The key of each tag to remove.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CertificateManager.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
endpoint: _resolveEndpoint(
serviceType: 'ACM',
),
);
}