updateCertificateOptions method
- required String certificateArn,
- required CertificateOptions options,
Updates a certificate. You can use this function to specify whether to export your certificate. Certificate transparency logging opt-out is no longer available. For more information, see Certificate Transparency Logging and Certificate Manager Exportable Managed Certificates.
May throw InvalidArnException.
May throw InvalidStateException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter certificateArn :
ARN of the requested certificate to update. This must be of the form:
arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012
Parameter options :
Use to update the options for your certificate. Currently, you can specify
whether to export your certificate. Certificate transparency logging
opt-out is no longer available. All public certificates are recorded in a
certificate transparency log. For more information, see Certificate
Transparency Logging.
Implementation
Future<void> updateCertificateOptions({
required String certificateArn,
required CertificateOptions options,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CertificateManager.UpdateCertificateOptions'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CertificateArn': certificateArn,
'Options': options,
},
endpoint: _resolveEndpoint(
serviceType: 'ACM',
),
);
}