searchDiscoverableRegistryRecords method
Searches the discoverable registry records in a registry using a natural language query. Returns metadata for the matching records ordered by relevance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter registryIds :
The registry identifiers to search within. Currently, you must specify
exactly one registry identifier. You can provide either the full Amazon
Web Services Resource Name (ARN) or the registry ID.
Parameter searchQuery :
The natural language query to search for matching registry records.
Parameter filters :
An optional structured JSON metadata filter that narrows the search
results. Supports the field-level operators $eq,
$ne, and $in, and the logical operators
$and and $or on filterable fields.
Parameter maxResults :
The maximum number of results to return. Valid values are 1 through 20.
The default value is 10.
Implementation
Future<SearchDiscoverableRegistryRecordsResponse>
searchDiscoverableRegistryRecords({
required List<String> registryIds,
required String searchQuery,
Object? filters,
int? maxResults,
}) async {
final $payload = <String, dynamic>{
'registryIds': registryIds,
'searchQuery': searchQuery,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/discoverable-records-search',
exceptionFnMap: _exceptionFns,
);
return SearchDiscoverableRegistryRecordsResponse.fromJson(response);
}