listRegistryRecords method
Lists the registry records within a registry, with optional filtering by name, status, and record type
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter registryId :
The identifier of the registry to list records from (ARN or ID)
Parameter filters :
Filters to apply to the registry record list
Parameter maxResults :
Maximum number of records to return
Parameter nextToken :
Token for pagination
Implementation
Future<ListRegistryRecordsResponse> listRegistryRecords({
required String registryId,
List<RegistryRecordFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/registries/${Uri.encodeComponent(registryId)}/records-list',
exceptionFnMap: _exceptionFns,
);
return ListRegistryRecordsResponse.fromJson(response);
}