getInvestigationGroup method
Returns the configuration information for the specified investigation group.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter identifier :
Specify either the name or the ARN of the investigation group that you
want to view. This is used to set the name of the investigation group.
Implementation
Future<GetInvestigationGroupResponse> getInvestigationGroup({
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/investigationGroups/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return GetInvestigationGroupResponse.fromJson(response);
}