listInvestigationGroups method
Returns the ARN and name of each investigation group in the account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of results to return in one operation. If you omit this
parameter, the default of 50 is used.
Parameter nextToken :
Include this value, if it was returned by the previous operation, to get
the next set of service operations.
Implementation
Future<ListInvestigationGroupsOutput> listInvestigationGroups({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/investigationGroups',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListInvestigationGroupsOutput.fromJson(response);
}