deleteAlertManagerDefinition method
Deletes the alert manager definition from a workspace.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace to delete the alert manager definition from.
Parameter clientToken :
A unique identifier that you can provide to ensure the idempotency of the
request. Case-sensitive.
Implementation
Future<void> deleteAlertManagerDefinition({
required String workspaceId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/alertmanager/definition',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}