describeAlertManagerDefinition method
Future<DescribeAlertManagerDefinitionResponse>
describeAlertManagerDefinition({
- required String workspaceId,
Retrieves the full information about the alert manager definition for a workspace.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace to retrieve the alert manager definition from.
Implementation
Future<DescribeAlertManagerDefinitionResponse>
describeAlertManagerDefinition({
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/alertmanager/definition',
exceptionFnMap: _exceptionFns,
);
return DescribeAlertManagerDefinitionResponse.fromJson(response);
}