describeQueryLoggingConfiguration method
Future<DescribeQueryLoggingConfigurationResponse>
describeQueryLoggingConfiguration({
- required String workspaceId,
Retrieves the details of the query logging configuration for the specified workspace.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter workspaceId :
The ID of the workspace for which to retrieve the query logging
configuration.
Implementation
Future<DescribeQueryLoggingConfigurationResponse>
describeQueryLoggingConfiguration({
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/logging/query',
exceptionFnMap: _exceptionFns,
);
return DescribeQueryLoggingConfigurationResponse.fromJson(response);
}