describeRuleGroupsNamespace method
Returns complete information about one rule groups namespace. To retrieve
a list of rule groups namespaces, use
ListRuleGroupsNamespaces.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the rule groups namespace that you want information for.
Parameter workspaceId :
The ID of the workspace containing the rule groups namespace.
Implementation
Future<DescribeRuleGroupsNamespaceResponse> describeRuleGroupsNamespace({
required String name,
required String workspaceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workspaces/${Uri.encodeComponent(workspaceId)}/rulegroupsnamespaces/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return DescribeRuleGroupsNamespaceResponse.fromJson(response);
}