tagResource method
The TagResource operation associates tags with an Amazon
Managed Service for Prometheus resource. The only resources that can be
tagged are rule groups namespaces, scrapers, and workspaces.
If you specify a new tag key for the resource, this tag is appended to the
list of tags associated with the resource. If you specify a tag key that
is already associated with the resource, the new tag value that you
specify replaces the previous value for that tag. To remove a tag, use
UntagResource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the resource to apply tags to.
Parameter tags :
The list of tag keys and values to associate with the resource.
Keys must not begin with aws:.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}