deleteTheme method
Deletes a theme from an Amplify app.
May throw InternalServerException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
Parameter appId :
The unique ID of the Amplify app associated with the theme to delete.
Parameter environmentName :
The name of the backend environment that is a part of the Amplify app.
Parameter id :
The unique ID of the theme to delete.
Implementation
Future<void> deleteTheme({
required String appId,
required String environmentName,
required String id,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/app/${Uri.encodeComponent(appId)}/environment/${Uri.encodeComponent(environmentName)}/themes/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}