exportComponents method
Exports component configurations to code that is ready to integrate into an Amplify app.
May throw InternalServerException.
May throw InvalidParameterException.
Parameter appId :
The unique ID of the Amplify app to export components to.
Parameter environmentName :
The name of the backend environment that is a part of the Amplify app.
Parameter nextToken :
The token to request the next page of results.
Implementation
Future<ExportComponentsResponse> exportComponents({
required String appId,
required String environmentName,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/export/app/${Uri.encodeComponent(appId)}/environment/${Uri.encodeComponent(environmentName)}/components',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ExportComponentsResponse.fromJson(response);
}