updateDeployment method
Changes information about a Deployment resource.
May throw BadRequestException.
May throw ConflictException.
May throw LimitExceededException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter deploymentId :
The replacement identifier for the Deployment resource to change
information about.
Parameter restApiId :
The string identifier of the associated RestApi.
Parameter patchOperations :
For more information about supported patch operations, see Patch
Operations.
Implementation
Future<Deployment> updateDeployment({
required String deploymentId,
required String restApiId,
List<PatchOperation>? patchOperations,
}) async {
final $payload = <String, dynamic>{
if (patchOperations != null) 'patchOperations': patchOperations,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/restapis/${Uri.encodeComponent(restApiId)}/deployments/${Uri.encodeComponent(deploymentId)}',
exceptionFnMap: _exceptionFns,
);
return Deployment.fromJson(response);
}