tagResource method
Assigns metadata to an AppConfig resource. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. You can specify a maximum of 50 tags for a resource.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The ARN of the resource for which to retrieve tags.
Parameter tags :
The key-value string map. The valid character set is [a-zA-Z+-=._:/].
The tag key can be up to 128 characters and must not start with
aws:. The tag value can be up to 256 characters.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}