AppConfigData class
AppConfig Data provides the data plane APIs your application uses to retrieve configuration data. Here's how it works:
Your application retrieves configuration data by first establishing a configuration session using the AppConfig Data StartConfigurationSession API action. Your session's client then makes periodic calls to GetLatestConfiguration to check for and retrieve the latest data available.
When calling StartConfigurationSession, your code sends the
following information:
- Identifiers (ID or name) of an AppConfig application, environment, and configuration profile that the session tracks.
-
(Optional) The minimum amount of time the session's client must wait between
calls to
GetLatestConfiguration.
InitialConfigurationToken to
be given to the session's client and used the first time it calls
GetLatestConfiguration for that session.
When calling GetLatestConfiguration, your client code sends the
most recent ConfigurationToken value it has and receives in
response:
-
NextPollConfigurationToken: theConfigurationTokenvalue to use on the next call toGetLatestConfiguration. -
NextPollIntervalInSeconds: the duration the client should wait before making its next call toGetLatestConfiguration. This duration may vary over the course of the session, so it should be used instead of the value sent on theStartConfigurationSessioncall. - The configuration: the latest data intended for the session. This may be empty if the client already has the latest version of the configuration.
StartConfigurationSession and
GetLatestConfiguration API actions, see Retrieving
the configuration in the AppConfig User Guide.
Constructors
- AppConfigData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getLatestConfiguration(
{required String configurationToken}) → Future< GetLatestConfigurationResponse> - Retrieves the latest deployed configuration. This API may return empty configuration data if the client already has the latest version. For more information about this API action and to view example CLI commands that show how to use it with the StartConfigurationSession API action, see Retrieving the configuration in the AppConfig User Guide.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConfigurationSession(
{required String applicationIdentifier, required String configurationProfileIdentifier, required String environmentIdentifier, int? requiredMinimumPollIntervalInSeconds}) → Future< StartConfigurationSessionResponse> - Starts a configuration session used to retrieve a deployed configuration. For more information about this API action and to view example CLI commands that show how to use it with the GetLatestConfiguration API action, see Retrieving the configuration in the AppConfig User Guide.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited