createAppBundle method
Creates an app bundle to collect data from an application using AppFabric.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value.
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter customerManagedKeyIdentifier :
The Amazon Resource Name (ARN) of the Key Management Service (KMS) key to
use to encrypt the application data. If this is not specified, an Amazon
Web Services owned key is used for encryption.
Parameter tags :
A map of the key-value pairs of the tag or tags to assign to the resource.
Implementation
Future<CreateAppBundleResponse> createAppBundle({
String? clientToken,
String? customerManagedKeyIdentifier,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (customerManagedKeyIdentifier != null)
'customerManagedKeyIdentifier': customerManagedKeyIdentifier,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/appbundles',
exceptionFnMap: _exceptionFns,
);
return CreateAppBundleResponse.fromJson(response);
}