deleteGatewayRoute method
Deletes an existing gateway route.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ResourceInUseException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter gatewayRouteName :
The name of the gateway route to delete.
Parameter meshName :
The name of the service mesh to delete the gateway route from.
Parameter virtualGatewayName :
The name of the virtual gateway to delete the route from.
Parameter meshOwner :
The Amazon Web Services IAM account ID of the service mesh owner. If the
account ID is not your own, then it's the ID of the account that shared
the mesh with your account. For more information about mesh sharing, see
Working
with shared meshes.
Implementation
Future<DeleteGatewayRouteOutput> deleteGatewayRoute({
required String gatewayRouteName,
required String meshName,
required String virtualGatewayName,
String? meshOwner,
}) async {
final $query = <String, List<String>>{
if (meshOwner != null) 'meshOwner': [meshOwner],
};
final response = await _protocol.sendRaw(
payload: null,
method: 'DELETE',
requestUri:
'/v20190125/meshes/${Uri.encodeComponent(meshName)}/virtualGateway/${Uri.encodeComponent(virtualGatewayName)}/gatewayRoutes/${Uri.encodeComponent(gatewayRouteName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return DeleteGatewayRouteOutput(
gatewayRoute: GatewayRouteData.fromJson($json),
);
}