deleteObservabilityConfiguration method
Future<DeleteObservabilityConfigurationResponse>
deleteObservabilityConfiguration({
- required String observabilityConfigurationArn,
Delete an App Runner observability configuration resource. You can delete a specific revision or the latest active revision. You can't delete a configuration that's used by one or more App Runner services.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter observabilityConfigurationArn :
The Amazon Resource Name (ARN) of the App Runner observability
configuration that you want to delete.
The ARN can be a full observability configuration ARN, or a partial ARN
ending with either .../name or
.../name/revision . If a revision isn't
specified, the latest active revision is deleted.
Implementation
Future<DeleteObservabilityConfigurationResponse>
deleteObservabilityConfiguration({
required String observabilityConfigurationArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AppRunner.DeleteObservabilityConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ObservabilityConfigurationArn': observabilityConfigurationArn,
},
);
return DeleteObservabilityConfigurationResponse.fromJson(jsonResponse.body);
}