disassociateCustomDomain method

Future<DisassociateCustomDomainResponse> disassociateCustomDomain({
  1. required String domainName,
  2. required String serviceArn,
})

Disassociate a custom domain name from an App Runner service.

Certificates tracking domain validity are associated with a custom domain and are stored in AWS Certificate Manager (ACM). These certificates aren't deleted as part of this action. App Runner delays certificate deletion for 30 days after a domain is disassociated from your service.

May throw InternalServiceErrorException. May throw InvalidRequestException. May throw InvalidStateException. May throw ResourceNotFoundException.

Parameter domainName : The domain name that you want to disassociate from the App Runner service.

Parameter serviceArn : The Amazon Resource Name (ARN) of the App Runner service that you want to disassociate a custom domain name from.

Implementation

Future<DisassociateCustomDomainResponse> disassociateCustomDomain({
  required String domainName,
  required String serviceArn,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'AppRunner.DisassociateCustomDomain'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'DomainName': domainName,
      'ServiceArn': serviceArn,
    },
  );

  return DisassociateCustomDomainResponse.fromJson(jsonResponse.body);
}