describeAppBlockBuilderAppBlockAssociations method
Future<DescribeAppBlockBuilderAppBlockAssociationsResult>
describeAppBlockBuilderAppBlockAssociations({})
Retrieves a list that describes one or more app block builder associations.
May throw InvalidParameterCombinationException.
May throw OperationNotPermittedException.
Parameter appBlockArn :
The ARN of the app block.
Parameter appBlockBuilderName :
The name of the app block builder.
Parameter maxResults :
The maximum size of each page of results.
Parameter nextToken :
The pagination token used to retrieve the next page of results for this
operation.
Implementation
Future<DescribeAppBlockBuilderAppBlockAssociationsResult>
describeAppBlockBuilderAppBlockAssociations({
String? appBlockArn,
String? appBlockBuilderName,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'PhotonAdminProxyService.DescribeAppBlockBuilderAppBlockAssociations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (appBlockArn != null) 'AppBlockArn': appBlockArn,
if (appBlockBuilderName != null)
'AppBlockBuilderName': appBlockBuilderName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeAppBlockBuilderAppBlockAssociationsResult.fromJson(
jsonResponse.body);
}