describeApplicationFleetAssociations method
Retrieves a list that describes one or more application fleet associations. Either ApplicationArn or FleetName must be specified.
May throw InvalidParameterCombinationException.
May throw OperationNotPermittedException.
Parameter applicationArn :
The ARN of the application.
Parameter fleetName :
The name of the fleet.
Parameter maxResults :
The maximum size of each page of results.
Parameter nextToken :
The pagination token used to retrieve the next page of results for this
operation.
Implementation
Future<DescribeApplicationFleetAssociationsResult>
describeApplicationFleetAssociations({
String? applicationArn,
String? fleetName,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'PhotonAdminProxyService.DescribeApplicationFleetAssociations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (applicationArn != null) 'ApplicationArn': applicationArn,
if (fleetName != null) 'FleetName': fleetName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeApplicationFleetAssociationsResult.fromJson(
jsonResponse.body);
}