describeSoftwareAssociations method
Retrieves license included application associations for a specified resource.
May throw OperationNotPermittedException.
May throw ResourceNotFoundException.
Parameter associatedResource :
The ARN of the resource to describe software associations. Possible
resources are Image and ImageBuilder.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The pagination token to use to retrieve the next page of results for this
operation.
Implementation
Future<DescribeSoftwareAssociationsResult> describeSoftwareAssociations({
required String associatedResource,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PhotonAdminProxyService.DescribeSoftwareAssociations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AssociatedResource': associatedResource,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeSoftwareAssociationsResult.fromJson(jsonResponse.body);
}