updateFleet method
- List<
FleetAttribute> ? attributesToDelete, - ComputeCapacity? computeCapacity,
- bool? deleteVpcConfig,
- String? description,
- bool? disableIMDSV1,
- int? disconnectTimeoutInSeconds,
- String? displayName,
- DomainJoinInfo? domainJoinInfo,
- bool? enableDefaultInternetAccess,
- String? iamRoleArn,
- int? idleDisconnectTimeoutInSeconds,
- String? imageArn,
- String? imageName,
- String? instanceType,
- int? maxConcurrentSessions,
- int? maxSessionsPerInstance,
- int? maxUserDurationInSeconds,
- String? name,
- PlatformType? platform,
- VolumeConfig? rootVolumeConfig,
- S3Location? sessionScriptS3Location,
- StreamView? streamView,
- List<
String> ? usbDeviceFilterStrings, - VpcConfig? vpcConfig,
Updates the specified fleet.
If the fleet is in the STOPPED state, you can update any
attribute except the fleet name.
If the fleet is in the RUNNING state, you can update the
following based on the fleet type:
-
Always-On and On-Demand fleet types
You can update the
DisplayName,ComputeCapacity,ImageARN,ImageName,IdleDisconnectTimeoutInSeconds, andDisconnectTimeoutInSecondsattributes. -
Elastic fleet type
You can update the
DisplayName,IdleDisconnectTimeoutInSeconds,DisconnectTimeoutInSeconds,MaxConcurrentSessions,SessionScriptS3LocationandUsbDeviceFilterStringsattributes.
STARTING or STOPPED
state, you can't update it.
May throw ConcurrentModificationException.
May throw IncompatibleImageException.
May throw InvalidAccountStatusException.
May throw InvalidParameterCombinationException.
May throw InvalidRoleException.
May throw LimitExceededException.
May throw OperationNotPermittedException.
May throw RequestLimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotAvailableException.
May throw ResourceNotFoundException.
Parameter attributesToDelete :
The fleet attributes to delete.
Parameter computeCapacity :
The desired capacity for the fleet. This is not allowed for Elastic
fleets.
Parameter deleteVpcConfig :
Deletes the VPC association for the specified fleet.
Parameter description :
The description to display.
Parameter disableIMDSV1 :
Set to true to disable Instance Metadata Service Version 1 (IMDSv1) and
enforce IMDSv2. Set to false to enable both IMDSv1 and IMDSv2.
Parameter disconnectTimeoutInSeconds :
The amount of time that a streaming session remains active after users
disconnect. If users try to reconnect to the streaming session after a
disconnection or network interruption within this time interval, they are
connected to their previous session. Otherwise, they are connected to a
new session with a new streaming instance.
Specify a value between 60 and 36000.
Parameter displayName :
The fleet name to display.
Parameter domainJoinInfo :
The name of the directory and organizational unit (OU) to use to join the
fleet to a Microsoft Active Directory domain.
Parameter enableDefaultInternetAccess :
Enables or disables default internet access for the fleet.
Parameter iamRoleArn :
The Amazon Resource Name (ARN) of the IAM role to apply to the fleet. To
assume a role, a fleet instance calls the AWS Security Token Service (STS)
AssumeRole API operation and passes the ARN of the role to
use. The operation creates a new session with temporary credentials.
WorkSpaces Applications retrieves the temporary credentials and creates
the appstream_machine_role credential profile on the instance.
For more information, see Using an IAM Role to Grant Permissions to Applications and Scripts Running on WorkSpaces Applications Streaming Instances in the Amazon WorkSpaces Applications Administration Guide.
Parameter idleDisconnectTimeoutInSeconds :
The amount of time that users can be idle (inactive) before they are
disconnected from their streaming session and the
DisconnectTimeoutInSeconds time interval begins. Users are
notified before they are disconnected due to inactivity. If users try to
reconnect to the streaming session before the time interval specified in
DisconnectTimeoutInSeconds elapses, they are connected to
their previous session. Users are considered idle when they stop providing
keyboard or mouse input during their streaming session. File uploads and
downloads, audio in, audio out, and pixels changing do not qualify as user
activity. If users continue to be idle after the time interval in
IdleDisconnectTimeoutInSeconds elapses, they are
disconnected.
To prevent users from being disconnected due to inactivity, specify a value of 0. Otherwise, specify a value between 60 and 36000. The default value is 0.
Parameter imageArn :
The ARN of the public, private, or shared image to use.
Parameter imageName :
The name of the image used to create the fleet.
Parameter instanceType :
The instance type to use when launching fleet instances. The following
instance types are available:
- stream.standard.small
- stream.standard.medium
- stream.standard.large
- stream.standard.xlarge
- stream.standard.2xlarge
- stream.compute.large
- stream.compute.xlarge
- stream.compute.2xlarge
- stream.compute.4xlarge
- stream.compute.8xlarge
- stream.memory.large
- stream.memory.xlarge
- stream.memory.2xlarge
- stream.memory.4xlarge
- stream.memory.8xlarge
- stream.memory.z1d.large
- stream.memory.z1d.xlarge
- stream.memory.z1d.2xlarge
- stream.memory.z1d.3xlarge
- stream.memory.z1d.6xlarge
- stream.memory.z1d.12xlarge
- stream.graphics.g4dn.xlarge
- stream.graphics.g4dn.2xlarge
- stream.graphics.g4dn.4xlarge
- stream.graphics.g4dn.8xlarge
- stream.graphics.g4dn.12xlarge
- stream.graphics.g4dn.16xlarge
- stream.graphics.g5.xlarge
- stream.graphics.g5.2xlarge
- stream.graphics.g5.4xlarge
- stream.graphics.g5.8xlarge
- stream.graphics.g5.16xlarge
- stream.graphics.g5.12xlarge
- stream.graphics.g5.24xlarge
- stream.graphics.g6.xlarge
- stream.graphics.g6.2xlarge
- stream.graphics.g6.4xlarge
- stream.graphics.g6.8xlarge
- stream.graphics.g6.16xlarge
- stream.graphics.g6.12xlarge
- stream.graphics.g6.24xlarge
- stream.graphics.gr6.4xlarge
- stream.graphics.gr6.8xlarge
- stream.graphics.g6f.large
- stream.graphics.g6f.xlarge
- stream.graphics.g6f.2xlarge
- stream.graphics.g6f.4xlarge
- stream.graphics.gr6f.4xlarge
- stream.standard.small
- stream.standard.medium
- stream.standard.large
- stream.standard.xlarge
- stream.standard.2xlarge
Parameter maxConcurrentSessions :
The maximum number of concurrent sessions for a fleet.
Parameter maxSessionsPerInstance :
The maximum number of user sessions on an instance. This only applies to
multi-session fleets.
Parameter maxUserDurationInSeconds :
The maximum amount of time that a streaming session can remain active, in
seconds. If users are still connected to a streaming instance five minutes
before this limit is reached, they are prompted to save any open documents
before being disconnected. After this time elapses, the instance is
terminated and replaced by a new instance.
Specify a value between 600 and 432000.
Parameter name :
A unique name for the fleet.
Parameter platform :
The platform of the fleet. WINDOWS_SERVER_2019, AMAZON_LINUX2 and
UBUNTU_PRO_2404 are supported for Elastic fleets.
Parameter rootVolumeConfig :
The updated configuration for the root volume of fleet instances. Note
that volume size cannot be decreased below the image volume size.
Parameter sessionScriptS3Location :
The S3 location of the session scripts configuration zip file. This only
applies to Elastic fleets.
Parameter streamView :
The WorkSpaces Applications view that is displayed to your users when they
stream from the fleet. When APP is specified, only the
windows of applications opened by users display. When DESKTOP
is specified, the standard desktop that is provided by the operating
system displays.
The default value is APP.
Parameter usbDeviceFilterStrings :
The USB device filter strings that specify which USB devices a user can
redirect to the fleet streaming session, when using the Windows native
client. This is allowed but not required for Elastic fleets.
Parameter vpcConfig :
The VPC configuration for the fleet. This is required for Elastic fleets,
but not required for other fleet types. Elastic fleets require that you
specify at least two subnets in different availability zones.
Implementation
Future<UpdateFleetResult> updateFleet({
List<FleetAttribute>? attributesToDelete,
ComputeCapacity? computeCapacity,
bool? deleteVpcConfig,
String? description,
bool? disableIMDSV1,
int? disconnectTimeoutInSeconds,
String? displayName,
DomainJoinInfo? domainJoinInfo,
bool? enableDefaultInternetAccess,
String? iamRoleArn,
int? idleDisconnectTimeoutInSeconds,
String? imageArn,
String? imageName,
String? instanceType,
int? maxConcurrentSessions,
int? maxSessionsPerInstance,
int? maxUserDurationInSeconds,
String? name,
PlatformType? platform,
VolumeConfig? rootVolumeConfig,
S3Location? sessionScriptS3Location,
StreamView? streamView,
List<String>? usbDeviceFilterStrings,
VpcConfig? vpcConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'PhotonAdminProxyService.UpdateFleet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (attributesToDelete != null)
'AttributesToDelete': attributesToDelete.map((e) => e.value).toList(),
if (computeCapacity != null) 'ComputeCapacity': computeCapacity,
if (deleteVpcConfig != null) 'DeleteVpcConfig': deleteVpcConfig,
if (description != null) 'Description': description,
if (disableIMDSV1 != null) 'DisableIMDSV1': disableIMDSV1,
if (disconnectTimeoutInSeconds != null)
'DisconnectTimeoutInSeconds': disconnectTimeoutInSeconds,
if (displayName != null) 'DisplayName': displayName,
if (domainJoinInfo != null) 'DomainJoinInfo': domainJoinInfo,
if (enableDefaultInternetAccess != null)
'EnableDefaultInternetAccess': enableDefaultInternetAccess,
if (iamRoleArn != null) 'IamRoleArn': iamRoleArn,
if (idleDisconnectTimeoutInSeconds != null)
'IdleDisconnectTimeoutInSeconds': idleDisconnectTimeoutInSeconds,
if (imageArn != null) 'ImageArn': imageArn,
if (imageName != null) 'ImageName': imageName,
if (instanceType != null) 'InstanceType': instanceType,
if (maxConcurrentSessions != null)
'MaxConcurrentSessions': maxConcurrentSessions,
if (maxSessionsPerInstance != null)
'MaxSessionsPerInstance': maxSessionsPerInstance,
if (maxUserDurationInSeconds != null)
'MaxUserDurationInSeconds': maxUserDurationInSeconds,
if (name != null) 'Name': name,
if (platform != null) 'Platform': platform.value,
if (rootVolumeConfig != null) 'RootVolumeConfig': rootVolumeConfig,
if (sessionScriptS3Location != null)
'SessionScriptS3Location': sessionScriptS3Location,
if (streamView != null) 'StreamView': streamView.value,
if (usbDeviceFilterStrings != null)
'UsbDeviceFilterStrings': usbDeviceFilterStrings,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return UpdateFleetResult.fromJson(jsonResponse.body);
}