listSourceApiAssociations method
Lists the SourceApiAssociationSummary data.
May throw BadRequestException.
May throw InternalFailureException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter apiId :
The API ID.
Parameter maxResults :
The maximum number of results that you want the request to return.
Parameter nextToken :
An identifier that was returned from the previous call to this operation,
which you can use to return the next set of items in the list.
Implementation
Future<ListSourceApiAssociationsResponse> listSourceApiAssociations({
required String apiId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
25,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/apis/${Uri.encodeComponent(apiId)}/sourceApiAssociations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSourceApiAssociationsResponse.fromJson(response);
}