describeConnectorEntity method
Provides details regarding the entity used with the connector, with a description of the data model for each field in that entity.
May throw ConnectorAuthenticationException.
May throw ConnectorServerException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter connectorEntityName :
The entity name for that connector.
Parameter apiVersion :
The version of the API that's used by the connector.
Parameter connectorProfileName :
The name of the connector profile. The name is unique for each
ConnectorProfile in the Amazon Web Services account.
Parameter connectorType :
The type of connector application, such as Salesforce, Amplitude, and so
on.
Implementation
Future<DescribeConnectorEntityResponse> describeConnectorEntity({
required String connectorEntityName,
String? apiVersion,
String? connectorProfileName,
ConnectorType? connectorType,
}) async {
final $payload = <String, dynamic>{
'connectorEntityName': connectorEntityName,
if (apiVersion != null) 'apiVersion': apiVersion,
if (connectorProfileName != null)
'connectorProfileName': connectorProfileName,
if (connectorType != null) 'connectorType': connectorType.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/describe-connector-entity',
exceptionFnMap: _exceptionFns,
);
return DescribeConnectorEntityResponse.fromJson(response);
}