describeFlowExecutionRecords method
Fetches the execution history of the flow.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter flowName :
The specified name of the flow. Spaces are not allowed. Use underscores
(_) or hyphens (-) only.
Parameter maxResults :
Specifies the maximum number of items that should be returned in the
result set. The default for maxResults is 20 (for all
paginated API operations).
Parameter nextToken :
The pagination token for the next page of data.
Implementation
Future<DescribeFlowExecutionRecordsResponse> describeFlowExecutionRecords({
required String flowName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'flowName': flowName,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/describe-flow-execution-records',
exceptionFnMap: _exceptionFns,
);
return DescribeFlowExecutionRecordsResponse.fromJson(response);
}