listConnectorEntities method
Returns the list of available connector entities supported by Amazon AppFlow. For example, you can query Salesforce for Account and Opportunity entities, or query ServiceNow for the Incident entity.
May throw ConnectorAuthenticationException.
May throw ConnectorServerException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter apiVersion :
The version of the API that's used by the connector.
Parameter connectorProfileName :
The name of the connector profile. The name is unique for each
ConnectorProfile in the Amazon Web Services account, and is
used to query the downstream connector.
Parameter connectorType :
The type of connector, such as Salesforce, Amplitude, and so on.
Parameter entitiesPath :
This optional parameter is specific to connector implementation. Some
connectors support multiple levels or categories of entities. You can find
out the list of roots for such providers by sending a request without the
entitiesPath parameter. If the connector supports entities at
different roots, this initial request returns the list of roots.
Otherwise, this request returns all entities supported by the provider.
Parameter maxResults :
The maximum number of items that the operation returns in the response.
Parameter nextToken :
A token that was provided by your prior ListConnectorEntities
operation if the response was too big for the page size. You specify this
token to get the next page of results in paginated response.
Implementation
Future<ListConnectorEntitiesResponse> listConnectorEntities({
String? apiVersion,
String? connectorProfileName,
ConnectorType? connectorType,
String? entitiesPath,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
10000,
);
final $payload = <String, dynamic>{
if (apiVersion != null) 'apiVersion': apiVersion,
if (connectorProfileName != null)
'connectorProfileName': connectorProfileName,
if (connectorType != null) 'connectorType': connectorType.value,
if (entitiesPath != null) 'entitiesPath': entitiesPath,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-connector-entities',
exceptionFnMap: _exceptionFns,
);
return ListConnectorEntitiesResponse.fromJson(response);
}