listConnectors method
Returns the list of all registered custom connectors in your Amazon Web Services account. This API lists only custom connectors registered in this account, not the Amazon Web Services authored connectors.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
Specifies the maximum number of items that should be returned in the
result set. The default for maxResults is 20 (for all
paginated API operations).
Parameter nextToken :
The pagination token for the next page of data.
Implementation
Future<ListConnectorsResponse> listConnectors({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-connectors',
exceptionFnMap: _exceptionFns,
);
return ListConnectorsResponse.fromJson(response);
}