listFlows method
Lists all of the flows associated with your account.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
Specifies the maximum number of items that should be returned in the
result set.
Parameter nextToken :
The pagination token for next page of data.
Implementation
Future<ListFlowsResponse> listFlows({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-flows',
exceptionFnMap: _exceptionFns,
);
return ListFlowsResponse.fromJson(response);
}