ApplicationCostProfiler class
This reference provides descriptions of the AWS Application Cost Profiler API.
The AWS Application Cost Profiler API provides programmatic access to view, create, update, and delete application cost report definitions, as well as to import your usage data into the Application Cost Profiler service.
For more information about using this service, see the AWS Application Cost Profiler User Guide.
Constructors
- ApplicationCostProfiler({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deleteReportDefinition(
{required String reportId}) → Future< DeleteReportDefinitionResult> - Deletes the specified report definition in AWS Application Cost Profiler. This stops the report from being generated.
-
getReportDefinition(
{required String reportId}) → Future< GetReportDefinitionResult> - Retrieves the definition of a report already configured in AWS Application Cost Profiler.
-
importApplicationUsage(
{required SourceS3Location sourceS3Location}) → Future< ImportApplicationUsageResult> - Ingests application usage data from Amazon Simple Storage Service (Amazon S3).
-
listReportDefinitions(
{int? maxResults, String? nextToken}) → Future< ListReportDefinitionsResult> - Retrieves a list of all reports and their configurations for your AWS account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putReportDefinition(
{required S3Location destinationS3Location, required Format format, required String reportDescription, required ReportFrequency reportFrequency, required String reportId}) → Future< PutReportDefinitionResult> - Creates the report definition for a report in Application Cost Profiler.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateReportDefinition(
{required S3Location destinationS3Location, required Format format, required String reportDescription, required ReportFrequency reportFrequency, required String reportId}) → Future< UpdateReportDefinitionResult> - Updates existing report in AWS Application Cost Profiler.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited