ApplicationDiscovery class
Amazon Web Services Application Discovery Service (Application Discovery Service) helps you plan application migration projects. It automatically identifies servers, virtual machines (VMs), and network dependencies in your on-premises data centers. For more information, see the Amazon Web Services Application Discovery Service FAQ.
Constructors
- ApplicationDiscovery({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateConfigurationItemsToApplication(
{required String applicationConfigurationId, required List< String> configurationIds}) → Future<void> - Associates one or more configuration items with an application.
-
batchDeleteAgents(
{required List< DeleteAgent> deleteAgents}) → Future<BatchDeleteAgentsResponse> -
Deletes one or more agents or collectors as specified by ID. Deleting an
agent or collector does not delete the previously discovered data. To
delete the data collected, use
StartBatchDeleteConfigurationTask. -
batchDeleteImportData(
{required List< String> importTaskIds, bool? deleteHistory}) → Future<BatchDeleteImportDataResponse> - Deletes one or more import tasks, each identified by their import ID. Each import task has a number of records that can identify servers or applications.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createApplication(
{required String name, String? description, String? wave}) → Future< CreateApplicationResponse> - Creates an application with the given name and description.
-
createTags(
{required List< String> configurationIds, required List<Tag> tags}) → Future<void> - Creates one or more tags for configuration items. Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items.
-
deleteApplications(
{required List< String> configurationIds}) → Future<void> - Deletes a list of applications and their associations with configuration items.
-
deleteTags(
{required List< String> configurationIds, List<Tag> ? tags}) → Future<void> - Deletes the association between configuration items and one or more tags. This API accepts a list of multiple configuration items.
-
describeAgents(
{List< String> ? agentIds, List<Filter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeAgentsResponse> -
Lists agents or collectors as specified by ID or other filters. All
agents/collectors associated with your user can be listed if you call
DescribeAgentsas is without passing any parameters. -
describeBatchDeleteConfigurationTask(
{required String taskId}) → Future< DescribeBatchDeleteConfigurationTaskResponse> - Takes a unique deletion task identifier as input and returns metadata about a configuration deletion task.
-
describeConfigurations(
{required List< String> configurationIds}) → Future<DescribeConfigurationsResponse> - Retrieves attributes for a list of configuration item IDs.
-
describeContinuousExports(
{List< String> ? exportIds, int? maxResults, String? nextToken}) → Future<DescribeContinuousExportsResponse> -
Lists exports as specified by ID. All continuous exports associated with
your user can be listed if you call
DescribeContinuousExportsas is without passing any parameters. -
describeExportConfigurations(
{List< String> ? exportIds, int? maxResults, String? nextToken}) → Future<DescribeExportConfigurationsResponse> -
DescribeExportConfigurationsis deprecated. Use DescribeExportTasks, instead. -
describeExportTasks(
{List< String> ? exportIds, List<ExportFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeExportTasksResponse> - Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.
-
describeImportTasks(
{List< ImportTaskFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeImportTasksResponse> - Returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more.
-
describeTags(
{List< TagFilter> ? filters, int? maxResults, String? nextToken}) → Future<DescribeTagsResponse> -
Retrieves a list of configuration items that have tags as specified by the
key-value pairs, name and value, passed to the optional parameter
filters. -
disassociateConfigurationItemsFromApplication(
{required String applicationConfigurationId, required List< String> configurationIds}) → Future<void> - Disassociates one or more configuration items from an application.
-
exportConfigurations(
) → Future< ExportConfigurationsResponse> -
Deprecated. Use
StartExportTaskinstead. -
getDiscoverySummary(
) → Future< GetDiscoverySummaryResponse> - Retrieves a short summary of discovered assets.
-
listConfigurations(
{required ConfigurationItemType configurationType, List< Filter> ? filters, int? maxResults, String? nextToken, List<OrderByElement> ? orderBy}) → Future<ListConfigurationsResponse> -
Retrieves a list of configuration items as specified by the value passed
to the required parameter
configurationType. Optional filtering may be applied to refine search results. -
listServerNeighbors(
{required String configurationId, int? maxResults, List< String> ? neighborConfigurationIds, String? nextToken, bool? portInformationNeeded}) → Future<ListServerNeighborsResponse> - Retrieves a list of servers that are one network hop away from a specified server.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startBatchDeleteConfigurationTask(
{required List< String> configurationIds, required DeletionConfigurationItemType configurationType}) → Future<StartBatchDeleteConfigurationTaskResponse> - Takes a list of configurationId as input and starts an asynchronous deletion task to remove the configurationItems. Returns a unique deletion task identifier.
-
startContinuousExport(
) → Future< StartContinuousExportResponse> - Start the continuous flow of agent's discovered data into Amazon Athena.
-
startDataCollectionByAgentIds(
{required List< String> agentIds}) → Future<StartDataCollectionByAgentIdsResponse> - Instructs the specified agents to start collecting data.
-
startExportTask(
{DateTime? endTime, List< ExportDataFormat> ? exportDataFormat, List<ExportFilter> ? filters, ExportPreferences? preferences, DateTime? startTime}) → Future<StartExportTaskResponse> -
Begins the export of a discovered data report to an Amazon S3 bucket
managed by Amazon Web Services.
If you do not specify
preferencesoragentIdsin the filter, a summary of all servers, applications, tags, and performance is generated. This data is an aggregation of all server data collected through on-premises tooling, file import, application grouping and applying tags. -
startImportTask(
{required String importUrl, required String name, String? clientRequestToken}) → Future< StartImportTaskResponse> - Starts an import task, which allows you to import details of your on-premises environment directly into Amazon Web Services Migration Hub without having to use the Amazon Web Services Application Discovery Service (Application Discovery Service) tools such as the Amazon Web Services Application Discovery Service Agentless Collector or Application Discovery Agent. This gives you the option to perform migration assessment and planning directly from your imported data, including the ability to group your devices as applications and track their migration status.
-
stopContinuousExport(
{required String exportId}) → Future< StopContinuousExportResponse> - Stop the continuous flow of agent's discovered data into Amazon Athena.
-
stopDataCollectionByAgentIds(
{required List< String> agentIds}) → Future<StopDataCollectionByAgentIdsResponse> - Instructs the specified agents to stop collecting data.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateApplication(
{required String configurationId, String? description, String? name, String? wave}) → Future< void> - Updates metadata about an application.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited