listGroupingAttributeDefinitions method
Returns the current grouping configuration for this account, including all custom grouping attribute definitions that have been configured. These definitions determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter awsAccountId :
The Amazon Web Services account ID to retrieve grouping attribute
definitions for. Use this when accessing grouping configurations from a
different account in cross-account monitoring scenarios.
Parameter includeLinkedAccounts :
If you are using this operation in a monitoring account, specify
true to include grouping attributes from source accounts in
the returned data.
Parameter nextToken :
Include this value, if it was returned by the previous operation, to get
the next set of grouping attribute definitions.
Implementation
Future<ListGroupingAttributeDefinitionsOutput>
listGroupingAttributeDefinitions({
String? awsAccountId,
bool? includeLinkedAccounts,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (awsAccountId != null) 'AwsAccountId': [awsAccountId],
if (includeLinkedAccounts != null)
'IncludeLinkedAccounts': [includeLinkedAccounts.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/grouping-attribute-definitions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListGroupingAttributeDefinitionsOutput.fromJson(response);
}