listServiceLevelObjectiveExclusionWindows method
Future<ListServiceLevelObjectiveExclusionWindowsOutput>
listServiceLevelObjectiveExclusionWindows({})
Retrieves all exclusion windows configured for a specific SLO.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The ID of the SLO to list exclusion windows for.
Parameter maxResults :
The maximum number of results to return in one operation. If you omit this
parameter, the default of 50 is used.
Parameter nextToken :
Include this value, if it was returned by the previous operation, to get
the next set of service level objectives.
Implementation
Future<ListServiceLevelObjectiveExclusionWindowsOutput>
listServiceLevelObjectiveExclusionWindows({
required String id,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
10,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/slo/${Uri.encodeComponent(id)}/exclusion-windows',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListServiceLevelObjectiveExclusionWindowsOutput.fromJson(response);
}