untagResource method
Removes one or more tags from the specified resource.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the CloudWatch resource that you want to
delete tags from.
The ARN format of an Application Signals SLO is
arn:aws:cloudwatch:Region:account-id:slo:slo-name
For more information about ARN format, see Resource Types Defined by Amazon CloudWatch in the Amazon Web Services General Reference.
Parameter tagKeys :
The list of tag keys to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $payload = <String, dynamic>{
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/untag-resource',
exceptionFnMap: _exceptionFns,
);
}