listRoute53HealthChecksInRegion method
List the Amazon Route 53 health checks in a specific Amazon Web Services Region.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw InternalServerException.
May throw ResourceNotFoundException.
Parameter arn :
The Amazon Resource Name (ARN) of the Arc Region Switch Plan.
Parameter hostedZoneId :
The hosted zone ID for the health checks.
Parameter maxResults :
The maximum number of results to return in the response.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a nextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's nextToken response
to request the next page of results.
Parameter recordName :
The record name for the health checks.
Implementation
Future<ListRoute53HealthChecksInRegionResponse>
listRoute53HealthChecksInRegion({
required String arn,
String? hostedZoneId,
int? maxResults,
String? nextToken,
String? recordName,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'ArcRegionSwitch.ListRoute53HealthChecksInRegion'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'arn': arn,
if (hostedZoneId != null) 'hostedZoneId': hostedZoneId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (recordName != null) 'recordName': recordName,
},
);
return ListRoute53HealthChecksInRegionResponse.fromJson(jsonResponse.body);
}