cancelPracticeRun method
Cancel an in-progress practice run zonal shift in Amazon Application Recovery Controller.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter zonalShiftId :
The identifier of a practice run zonal shift in Amazon Application
Recovery Controller that you want to cancel.
Implementation
Future<CancelPracticeRunResponse> cancelPracticeRun({
required String zonalShiftId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/practiceruns/${Uri.encodeComponent(zonalShiftId)}',
exceptionFnMap: _exceptionFns,
);
return CancelPracticeRunResponse.fromJson(response);
}