cancelZonalShift method
Cancel a zonal shift in Amazon Application Recovery Controller. To cancel the zonal shift, specify the zonal shift ID.
A zonal shift can be one that you've started for a resource in your Amazon Web Services account in an Amazon Web Services Region, or it can be a zonal shift started by a practice run with zonal autoshift.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter zonalShiftId :
The internally-generated identifier of a zonal shift.
Implementation
Future<ZonalShift> cancelZonalShift({
required String zonalShiftId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/zonalshifts/${Uri.encodeComponent(zonalShiftId)}',
exceptionFnMap: _exceptionFns,
);
return ZonalShift.fromJson(response);
}