createPracticeRunConfiguration method
A practice run configuration for zonal autoshift is required when you enable zonal autoshift. A practice run configuration includes specifications for blocked dates and blocked time windows, and for Amazon CloudWatch alarms that you create to use with practice runs. The alarms that you specify are an outcome alarm, to monitor application health during practice runs and, optionally, a blocking alarm, to block practice runs from starting.
When a resource has a practice run configuration, ARC starts zonal shifts for the resource weekly, to shift traffic for practice runs. Practice runs help you to ensure that shifting away traffic from an Availability Zone during an autoshift is safe for your application.
For more information, see Considerations when you configure zonal autoshift in the Amazon Application Recovery Controller Developer Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter outcomeAlarms :
Outcome alarms for practice runs are alarms that you specify that
end a practice run when one or more of the alarms is in an
ALARM state.
Configure one or more of these alarms to monitor the health of your
application when traffic is shifted away from an Availability Zone during
each practice run. You should configure these alarms to go into an
ALARM state if you want to stop a zonal shift, to let traffic
for the resource return to the original Availability Zone.
Parameter resourceIdentifier :
The identifier of the resource that Amazon Web Services shifts traffic for
with a practice run zonal shift. The identifier is the Amazon Resource
Name (ARN) for the resource.
Amazon Application Recovery Controller currently supports enabling the following resources for zonal shift and zonal autoshift:
- Amazon EC2 Auto Scaling groups
- Amazon Elastic Kubernetes Service
- Application Load Balancer
- Network Load Balancer
Parameter allowedWindows :
Optionally, you can allow ARC to start practice runs for specific windows
of days and times.
The format for allowed windows is: DAY:HH:SS-DAY:HH:SS. Keep in mind, when you specify dates, that dates and times for practice runs are in UTC. Also, be aware of potential time adjustments that might be required for daylight saving time differences. Separate multiple allowed windows with spaces.
For example, say you want to allow practice runs only on Wednesdays and
Fridays from noon to 5 p.m. For this scenario, you could set the following
recurring days and times as allowed windows, for example:
Wed-12:00-Wed:17:00 Fri-12:00-Fri:17:00.
Parameter blockedDates :
Optionally, you can block ARC from starting practice runs for a resource
on specific calendar dates.
The format for blocked dates is: YYYY-MM-DD. Keep in mind, when you specify dates, that dates and times for practice runs are in UTC. Separate multiple blocked dates with spaces.
For example, if you have an application update scheduled to launch on May
1, 2024, and you don't want practice runs to shift traffic away at that
time, you could set a blocked date for 2024-05-01.
Parameter blockedWindows :
Optionally, you can block ARC from starting practice runs for specific
windows of days and times.
The format for blocked windows is: DAY:HH:SS-DAY:HH:SS. Keep in mind, when you specify dates, that dates and times for practice runs are in UTC. Also, be aware of potential time adjustments that might be required for daylight saving time differences. Separate multiple blocked windows with spaces.
For example, say you run business report summaries three days a week. For
this scenario, you could set the following recurring days and times as
blocked windows, for example: Mon:00:00-Mon:10:00
Wed-20:30-Wed:21:30 Fri-20:30-Fri:21:30.
Parameter blockingAlarms :
Blocking alarms for practice runs are optional alarms that you can
specify that block practice runs when one or more of the alarms is in an
ALARM state.
Implementation
Future<CreatePracticeRunConfigurationResponse>
createPracticeRunConfiguration({
required List<ControlCondition> outcomeAlarms,
required String resourceIdentifier,
List<String>? allowedWindows,
List<String>? blockedDates,
List<String>? blockedWindows,
List<ControlCondition>? blockingAlarms,
}) async {
final $payload = <String, dynamic>{
'outcomeAlarms': outcomeAlarms,
'resourceIdentifier': resourceIdentifier,
if (allowedWindows != null) 'allowedWindows': allowedWindows,
if (blockedDates != null) 'blockedDates': blockedDates,
if (blockedWindows != null) 'blockedWindows': blockedWindows,
if (blockingAlarms != null) 'blockingAlarms': blockingAlarms,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/configuration',
exceptionFnMap: _exceptionFns,
);
return CreatePracticeRunConfigurationResponse.fromJson(response);
}