getCapacityAssignmentConfiguration method

Future<GetCapacityAssignmentConfigurationOutput> getCapacityAssignmentConfiguration({
  1. required String capacityReservationName,
})

Gets the capacity assignment configuration for a capacity reservation, if one exists.

May throw InternalServerException. May throw InvalidRequestException.

Parameter capacityReservationName : The name of the capacity reservation to retrieve the capacity assignment configuration for.

Implementation

Future<GetCapacityAssignmentConfigurationOutput>
    getCapacityAssignmentConfiguration({
  required String capacityReservationName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AmazonAthena.GetCapacityAssignmentConfiguration'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'CapacityReservationName': capacityReservationName,
    },
  );

  return GetCapacityAssignmentConfigurationOutput.fromJson(jsonResponse.body);
}