getQueryRuntimeStatistics method
- required String queryExecutionId,
Returns query execution runtime statistics related to a single execution
of a query if you have access to the workgroup in which the query ran.
Statistics from the Timeline section of the response object
are available as soon as QueryExecutionStatus$State is in a
SUCCEEDED or FAILED state. The remaining non-timeline statistics in the
response (like stage-level input and output row count and data size) are
updated asynchronously and may not be available immediately after a query
completes or, in some cases, may not be returned. The non-timeline
statistics are also not included when a query has row-level filters
defined in Lake Formation.
May throw InternalServerException.
May throw InvalidRequestException.
Parameter queryExecutionId :
The unique ID of the query execution.
Implementation
Future<GetQueryRuntimeStatisticsOutput> getQueryRuntimeStatistics({
required String queryExecutionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonAthena.GetQueryRuntimeStatistics'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'QueryExecutionId': queryExecutionId,
},
);
return GetQueryRuntimeStatisticsOutput.fromJson(jsonResponse.body);
}