listNotebookMetadata method
Displays the notebook files for the specified workgroup in paginated format.
May throw InternalServerException.
May throw InvalidRequestException.
May throw TooManyRequestsException.
Parameter workGroup :
The name of the Spark enabled workgroup to retrieve notebook metadata for.
Parameter filters :
Search filter string.
Parameter maxResults :
Specifies the maximum number of results to return.
Parameter nextToken :
A token generated by the Athena service that specifies where to continue
pagination if a previous request was truncated.
Implementation
Future<ListNotebookMetadataOutput> listNotebookMetadata({
required String workGroup,
FilterDefinition? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonAthena.ListNotebookMetadata'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WorkGroup': workGroup,
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListNotebookMetadataOutput.fromJson(jsonResponse.body);
}