updateNotebookMetadata method
Updates the metadata for a notebook.
May throw InternalServerException.
May throw InvalidRequestException.
May throw TooManyRequestsException.
Parameter name :
The name to update the notebook to.
Parameter notebookId :
The ID of the notebook to update the metadata for.
Parameter clientRequestToken :
A unique case-sensitive string used to ensure the request to create the
notebook is idempotent (executes only once).
Implementation
Future<void> updateNotebookMetadata({
required String name,
required String notebookId,
String? clientRequestToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonAthena.UpdateNotebookMetadata'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'NotebookId': notebookId,
if (clientRequestToken != null)
'ClientRequestToken': clientRequestToken,
},
);
}