batchDisassociateAssessmentReportEvidence method
Future<BatchDisassociateAssessmentReportEvidenceResponse>
batchDisassociateAssessmentReportEvidence({})
Disassociates a list of evidence from an assessment report in Audit Manager.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter assessmentId :
The identifier for the assessment.
Parameter evidenceFolderId :
The identifier for the folder that the evidence is stored in.
Parameter evidenceIds :
The list of evidence identifiers.
Implementation
Future<BatchDisassociateAssessmentReportEvidenceResponse>
batchDisassociateAssessmentReportEvidence({
required String assessmentId,
required String evidenceFolderId,
required List<String> evidenceIds,
}) async {
final $payload = <String, dynamic>{
'evidenceFolderId': evidenceFolderId,
'evidenceIds': evidenceIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/assessments/${Uri.encodeComponent(assessmentId)}/batchDisassociateFromAssessmentReport',
exceptionFnMap: _exceptionFns,
);
return BatchDisassociateAssessmentReportEvidenceResponse.fromJson(response);
}