getEvidenceFolder method
Gets an evidence folder from a specified assessment in Audit Manager.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter assessmentId :
The unique identifier for the assessment.
Parameter controlSetId :
The unique identifier for the control set.
Parameter evidenceFolderId :
The unique identifier for the folder that the evidence is stored in.
Implementation
Future<GetEvidenceFolderResponse> getEvidenceFolder({
required String assessmentId,
required String controlSetId,
required String evidenceFolderId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/assessments/${Uri.encodeComponent(assessmentId)}/controlSets/${Uri.encodeComponent(controlSetId)}/evidenceFolders/${Uri.encodeComponent(evidenceFolderId)}',
exceptionFnMap: _exceptionFns,
);
return GetEvidenceFolderResponse.fromJson(response);
}