listControlDomainInsights method
Lists the latest analytics data for control domains across all of your active assessments.
Audit Manager supports the control domains that are provided by Amazon Web
Services Control Catalog. For information about how to find a list of
available control domains, see
ListDomains in the Amazon Web Services Control Catalog
API Reference.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter maxResults :
Represents the maximum number of results on a page or for an API request
call.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListControlDomainInsightsResponse> listControlDomainInsights({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/insights/control-domains',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListControlDomainInsightsResponse.fromJson(response);
}