updateAssessmentFramework method
Updates a custom framework in Audit Manager.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter controlSets :
The control sets that are associated with the framework.
Parameter frameworkId :
The unique identifier for the framework.
Parameter name :
The name of the framework to be updated.
Parameter complianceType :
The compliance type that the new custom framework supports, such as CIS or
HIPAA.
Parameter description :
The description of the updated framework.
Implementation
Future<UpdateAssessmentFrameworkResponse> updateAssessmentFramework({
required List<UpdateAssessmentFrameworkControlSet> controlSets,
required String frameworkId,
required String name,
String? complianceType,
String? description,
}) async {
final $payload = <String, dynamic>{
'controlSets': controlSets,
'name': name,
if (complianceType != null) 'complianceType': complianceType,
if (description != null) 'description': description,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/assessmentFrameworks/${Uri.encodeComponent(frameworkId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateAssessmentFrameworkResponse.fromJson(response);
}