updateAssessmentFrameworkShare method
Updates a share request for a custom framework in Audit Manager.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter action :
Specifies the update action for the share request.
Parameter requestId :
The unique identifier for the share request.
Parameter requestType :
Specifies whether the share request is a sent request or a received
request.
Implementation
Future<UpdateAssessmentFrameworkShareResponse>
updateAssessmentFrameworkShare({
required ShareRequestAction action,
required String requestId,
required ShareRequestType requestType,
}) async {
final $payload = <String, dynamic>{
'action': action.value,
'requestType': requestType.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/assessmentFrameworkShareRequests/${Uri.encodeComponent(requestId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateAssessmentFrameworkShareResponse.fromJson(response);
}