describeLoadBalancers method
This operation describes only Classic Load Balancers. If you have Application Load Balancers, Network Load Balancers, or Gateway Load Balancers, use the DescribeLoadBalancerTargetGroups API instead.
To determine the attachment status of the load balancer, use the
State element in the response. When you attach a load
balancer to an Auto Scaling group, the initial State value is
Adding. The state transitions to Added after all
Auto Scaling instances are registered with the load balancer. If Elastic
Load Balancing health checks are enabled for the Auto Scaling group, the
state transitions to InService after at least one Auto
Scaling instance passes the health check. When the load balancer is in the
InService state, Amazon EC2 Auto Scaling can terminate and
replace any instances that are reported as unhealthy. If no registered
instances pass the health checks, the load balancer doesn't enter the
InService state.
Load balancers also have an InService state if you attach
them in the CreateAutoScalingGroup
API call. If your load balancer state is InService, but it is
not working properly, check the scaling activities by calling DescribeScalingActivities
and take any corrective actions necessary.
For help with failed health checks, see Troubleshooting Amazon EC2 Auto Scaling: Health checks in the Amazon EC2 Auto Scaling User Guide. For more information, see Use Elastic Load Balancing to distribute traffic across the instances in your Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.
May throw InvalidNextToken.
May throw ResourceContentionFault.
Parameter autoScalingGroupName :
The name of the Auto Scaling group.
Parameter maxRecords :
The maximum number of items to return with this call. The default value is
100 and the maximum value is 100.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<DescribeLoadBalancersResponse> describeLoadBalancers({
required String autoScalingGroupName,
int? maxRecords,
String? nextToken,
}) async {
final $request = <String, String>{
'AutoScalingGroupName': autoScalingGroupName,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'DescribeLoadBalancers',
version: '2011-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeLoadBalancersResult',
);
return DescribeLoadBalancersResponse.fromXml($result);
}