listProfiles method
Lists the profiles associated with your Amazon Web Services account for your current or specified region. A profile is the mechanism used to create the concept of a private network.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
Specifies the maximum number of profiles to return.
Parameter nextToken :
When additional results are obtained from the command, a
NextToken parameter is returned in the output. You can then
pass the NextToken parameter in a subsequent command to
continue listing additional resources.
Implementation
Future<ListProfilesResponse> listProfiles({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'B2BI.ListProfiles'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListProfilesResponse.fromJson(jsonResponse.body);
}