associateBackupVaultMpaApprovalTeam method
Associates an MPA approval team with a backup vault.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of the backup vault to associate with the MPA approval team.
Parameter mpaApprovalTeamArn :
The Amazon Resource Name (ARN) of the MPA approval team to associate with
the backup vault.
Parameter requesterComment :
A comment provided by the requester explaining the association request.
Implementation
Future<void> associateBackupVaultMpaApprovalTeam({
required String backupVaultName,
required String mpaApprovalTeamArn,
String? requesterComment,
}) async {
final $payload = <String, dynamic>{
'MpaApprovalTeamArn': mpaApprovalTeamArn,
if (requesterComment != null) 'RequesterComment': requesterComment,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/mpaApprovalTeam',
exceptionFnMap: _exceptionFns,
);
}