deleteBackupVault method
Deletes the backup vault identified by its name. A vault can be deleted only if it is empty.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created.
Implementation
Future<void> deleteBackupVault({
required String backupVaultName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/backup-vaults/${Uri.encodeComponent(backupVaultName)}',
exceptionFnMap: _exceptionFns,
);
}