deleteBackupVaultNotifications method
Deletes event notifications for the specified backup vault.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Region where they are created.
Implementation
Future<void> deleteBackupVaultNotifications({
required String backupVaultName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/notification-configuration',
exceptionFnMap: _exceptionFns,
);
}