deleteRecoveryPoint method
Deletes the recovery point specified by a recovery point ID.
If the recovery point ID belongs to a continuous backup, calling this endpoint deletes the existing continuous backup and stops future continuous backup.
When an IAM role's permissions are insufficient to call this API, the
service sends back an HTTP 200 response with an empty HTTP body, but the
recovery point is not deleted. Instead, it enters an EXPIRED
state.
EXPIRED recovery points can be deleted with this API once the
IAM role has the iam:CreateServiceLinkedRole action. To learn
more about adding this role, see
Troubleshooting manual deletions.
If the user or role is deleted or the permission within the role is
removed, the deletion will not be successful and will enter an
EXPIRED state.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw InvalidResourceStateException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web Services Region where they are created.
Parameter recoveryPointArn :
An Amazon Resource Name (ARN) that uniquely identifies a recovery point;
for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Implementation
Future<void> deleteRecoveryPoint({
required String backupVaultName,
required String recoveryPointArn,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/backup-vaults/${Uri.encodeComponent(backupVaultName)}/recovery-points/${Uri.encodeComponent(recoveryPointArn)}',
exceptionFnMap: _exceptionFns,
);
}