deleteRestoreTestingSelection method
Input the Restore Testing Plan name and Restore Testing Selection name.
All testing selections associated with a restore testing plan must be deleted before the restore testing plan can be deleted.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter restoreTestingPlanName :
Required unique name of the restore testing plan that contains the restore
testing selection you wish to delete.
Parameter restoreTestingSelectionName :
Required unique name of the restore testing selection you wish to delete.
Implementation
Future<void> deleteRestoreTestingSelection({
required String restoreTestingPlanName,
required String restoreTestingSelectionName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/restore-testing/plans/${Uri.encodeComponent(restoreTestingPlanName)}/selections/${Uri.encodeComponent(restoreTestingSelectionName)}',
exceptionFnMap: _exceptionFns,
);
}