describeGlobalSettings method
Describes whether the Amazon Web Services account has enabled different
cross-account management options, including cross-account backup,
multi-party approval, and delegated administrator. Returns an error if the
account is not a member of an Organizations organization. Example:
describe-global-settings --region us-west-2
May throw InvalidRequestException.
May throw ServiceUnavailableException.
Implementation
Future<DescribeGlobalSettingsOutput> describeGlobalSettings() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/global-settings',
exceptionFnMap: _exceptionFns,
);
return DescribeGlobalSettingsOutput.fromJson(response);
}