describeRegionSettings method
Returns the current service opt-in settings for the Region. If service opt-in is enabled for a service, Backup tries to protect that service's resources in this Region, when the resource is included in an on-demand backup or scheduled backup plan. Otherwise, Backup does not try to protect that service's resources in this Region.
May throw ServiceUnavailableException.
Implementation
Future<DescribeRegionSettingsOutput> describeRegionSettings() async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/account-settings',
exceptionFnMap: _exceptionFns,
);
return DescribeRegionSettingsOutput.fromJson(response);
}