getLegalHold method
This action returns details for a specified legal hold. The details are the body of a legal hold in JSON format, in addition to metadata.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter legalHoldId :
The ID of the legal hold.
Implementation
Future<GetLegalHoldOutput> getLegalHold({
required String legalHoldId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/legal-holds/${Uri.encodeComponent(legalHoldId)}',
exceptionFnMap: _exceptionFns,
);
return GetLegalHoldOutput.fromJson(response);
}