getRestoreJobMetadata method
This request returns the metadata for the specified restore job.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter restoreJobId :
This is a unique identifier of a restore job within Backup.
Implementation
Future<GetRestoreJobMetadataOutput> getRestoreJobMetadata({
required String restoreJobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/restore-jobs/${Uri.encodeComponent(restoreJobId)}/metadata',
exceptionFnMap: _exceptionFns,
);
return GetRestoreJobMetadataOutput.fromJson(response);
}