getRestoreTestingInferredMetadata method
This request returns the minimal required set of metadata needed to start
a restore job with secure default settings. BackupVaultName
and RecoveryPointArn are required parameters.
BackupVaultAccountId is an optional parameter.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of a logical container where backups are stored. Backup vaults
are identified by names that are unique to the account used to create them
and the Amazon Web ServicesRegion where they are created. They consist of
letters, numbers, and hyphens.
Parameter recoveryPointArn :
An Amazon Resource Name (ARN) that uniquely identifies a recovery point;
for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Parameter backupVaultAccountId :
The account ID of the specified backup vault.
Implementation
Future<GetRestoreTestingInferredMetadataOutput>
getRestoreTestingInferredMetadata({
required String backupVaultName,
required String recoveryPointArn,
String? backupVaultAccountId,
}) async {
final $query = <String, List<String>>{
'BackupVaultName': [backupVaultName],
'RecoveryPointArn': [recoveryPointArn],
if (backupVaultAccountId != null)
'BackupVaultAccountId': [backupVaultAccountId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/restore-testing/inferred-metadata',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetRestoreTestingInferredMetadataOutput.fromJson(response);
}