listRestoreJobs method
Returns a list of jobs that Backup initiated to restore a saved resource, including details about the recovery process.
May throw InvalidParameterValueException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter byAccountId :
The account ID to list the jobs from. Returns only restore jobs associated
with the specified account ID.
Parameter byCompleteAfter :
Returns only copy jobs completed after a date expressed in Unix format and
Coordinated Universal Time (UTC).
Parameter byCompleteBefore :
Returns only copy jobs completed before a date expressed in Unix format
and Coordinated Universal Time (UTC).
Parameter byCreatedAfter :
Returns only restore jobs that were created after the specified date.
Parameter byCreatedBefore :
Returns only restore jobs that were created before the specified date.
Parameter byParentJobId :
This is a filter to list child (nested) restore jobs based on parent
restore job ID.
Parameter byResourceType :
Include this parameter to return only restore jobs for the specified
resources:
-
Aurorafor Amazon Aurora -
CloudFormationfor CloudFormation -
DocumentDBfor Amazon DocumentDB (with MongoDB compatibility) -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
EKSfor Amazon Elastic Kubernetes Service -
FSxfor Amazon FSx -
Neptunefor Amazon Neptune -
RDSfor Amazon Relational Database Service -
Redshiftfor Amazon Redshift -
S3for Amazon Simple Storage Service (Amazon S3) -
SAP HANA on Amazon EC2for SAP HANA databases on Amazon Elastic Compute Cloud instances -
Storage Gatewayfor Storage Gateway -
Timestreamfor Amazon Timestream -
VirtualMachinefor VMware virtual machines
Parameter byRestoreTestingPlanArn :
This returns only restore testing jobs that match the specified resource
Amazon Resource Name (ARN).
Parameter byStatus :
Returns only restore jobs associated with the specified job status.
Parameter maxResults :
The maximum number of items to be returned.
Parameter nextToken :
The next item following a partial list of returned items. For example, if
a request is made to return MaxResults number of items,
NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
Implementation
Future<ListRestoreJobsOutput> listRestoreJobs({
String? byAccountId,
DateTime? byCompleteAfter,
DateTime? byCompleteBefore,
DateTime? byCreatedAfter,
DateTime? byCreatedBefore,
String? byParentJobId,
String? byResourceType,
String? byRestoreTestingPlanArn,
RestoreJobStatus? byStatus,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (byAccountId != null) 'accountId': [byAccountId],
if (byCompleteAfter != null)
'completeAfter': [_s.iso8601ToJson(byCompleteAfter).toString()],
if (byCompleteBefore != null)
'completeBefore': [_s.iso8601ToJson(byCompleteBefore).toString()],
if (byCreatedAfter != null)
'createdAfter': [_s.iso8601ToJson(byCreatedAfter).toString()],
if (byCreatedBefore != null)
'createdBefore': [_s.iso8601ToJson(byCreatedBefore).toString()],
if (byParentJobId != null) 'parentJobId': [byParentJobId],
if (byResourceType != null) 'resourceType': [byResourceType],
if (byRestoreTestingPlanArn != null)
'restoreTestingPlanArn': [byRestoreTestingPlanArn],
if (byStatus != null) 'status': [byStatus.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/restore-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRestoreJobsOutput.fromJson(response);
}