revokeRestoreAccessBackupVault method
Revokes access to a restore access backup vault, removing the ability to restore from its recovery points and permanently deleting the vault.
May throw InvalidParameterValueException.
May throw InvalidRequestException.
May throw MissingParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter backupVaultName :
The name of the source backup vault associated with the restore access
backup vault to be revoked.
Parameter restoreAccessBackupVaultArn :
The ARN of the restore access backup vault to revoke.
Parameter requesterComment :
A comment explaining the reason for revoking access to the restore access
backup vault.
Implementation
Future<void> revokeRestoreAccessBackupVault({
required String backupVaultName,
required String restoreAccessBackupVaultArn,
String? requesterComment,
}) async {
final $query = <String, List<String>>{
if (requesterComment != null) 'requesterComment': [requesterComment],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/logically-air-gapped-backup-vaults/${Uri.encodeComponent(backupVaultName)}/restore-access-backup-vaults/${Uri.encodeComponent(restoreAccessBackupVaultArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}