BackupGateway class
Backup gateway connects Backup to your hypervisor, so you can create, store, and restore backups of your virtual machines (VMs) anywhere, whether on-premises or in the VMware Cloud (VMC) on Amazon Web Services.
Constructors
- BackupGateway({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateGatewayToServer(
{required String gatewayArn, required String serverArn}) → Future< AssociateGatewayToServerOutput> - Associates a backup gateway with your server. After you complete the association process, you can back up and restore your VMs through the gateway.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createGateway(
{required String activationKey, required String gatewayDisplayName, required GatewayType gatewayType, List< Tag> ? tags}) → Future<CreateGatewayOutput> -
Creates a backup gateway. After you create a gateway, you can associate it
with a server using the
AssociateGatewayToServeroperation. -
deleteGateway(
{required String gatewayArn}) → Future< DeleteGatewayOutput> - Deletes a backup gateway.
-
deleteHypervisor(
{required String hypervisorArn}) → Future< DeleteHypervisorOutput> - Deletes a hypervisor.
-
disassociateGatewayFromServer(
{required String gatewayArn}) → Future< DisassociateGatewayFromServerOutput> - Disassociates a backup gateway from the specified server. After the disassociation process finishes, the gateway can no longer access the virtual machines on the server.
-
getBandwidthRateLimitSchedule(
{required String gatewayArn}) → Future< GetBandwidthRateLimitScheduleOutput> - Retrieves the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. Use this to get a gateway's bandwidth rate limit schedule.
-
getGateway(
{required String gatewayArn}) → Future< GetGatewayOutput> - By providing the ARN (Amazon Resource Name), this API returns the gateway.
-
getHypervisor(
{required String hypervisorArn}) → Future< GetHypervisorOutput> - This action requests information about the specified hypervisor to which the gateway will connect. A hypervisor is hardware, software, or firmware that creates and manages virtual machines, and allocates resources to them.
-
getHypervisorPropertyMappings(
{required String hypervisorArn}) → Future< GetHypervisorPropertyMappingsOutput> - This action retrieves the property mappings for the specified hypervisor. A hypervisor property mapping displays the relationship of entity properties available from the hypervisor to the properties available in Amazon Web Services.
-
getVirtualMachine(
{required String resourceArn}) → Future< GetVirtualMachineOutput> - By providing the ARN (Amazon Resource Name), this API returns the virtual machine.
-
importHypervisorConfiguration(
{required String host, required String name, String? kmsKeyArn, String? password, List< Tag> ? tags, String? username}) → Future<ImportHypervisorConfigurationOutput> - Connect to a hypervisor by importing its configuration.
-
listGateways(
{int? maxResults, String? nextToken}) → Future< ListGatewaysOutput> - Lists backup gateways owned by an Amazon Web Services account in an Amazon Web Services Region. The returned list is ordered by gateway Amazon Resource Name (ARN).
-
listHypervisors(
{int? maxResults, String? nextToken}) → Future< ListHypervisorsOutput> - Lists your hypervisors.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists the tags applied to the resource identified by its Amazon Resource Name (ARN).
-
listVirtualMachines(
{String? hypervisorArn, int? maxResults, String? nextToken}) → Future< ListVirtualMachinesOutput> - Lists your virtual machines.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putBandwidthRateLimitSchedule(
{required List< BandwidthRateLimitInterval> bandwidthRateLimitIntervals, required String gatewayArn}) → Future<PutBandwidthRateLimitScheduleOutput> - This action sets the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have a bandwidth rate limit schedule, which means no bandwidth rate limiting is in effect. Use this to initiate a gateway's bandwidth rate limit schedule.
-
putHypervisorPropertyMappings(
{required String hypervisorArn, required String iamRoleArn, required List< VmwareToAwsTagMapping> vmwareToAwsTagMappings}) → Future<PutHypervisorPropertyMappingsOutput> - This action sets the property mappings for the specified hypervisor. A hypervisor property mapping displays the relationship of entity properties available from the hypervisor to the properties available in Amazon Web Services.
-
putMaintenanceStartTime(
{required String gatewayArn, required int hourOfDay, required int minuteOfHour, int? dayOfMonth, int? dayOfWeek}) → Future< PutMaintenanceStartTimeOutput> - Set the maintenance start time for a gateway.
-
startVirtualMachinesMetadataSync(
{required String hypervisorArn}) → Future< StartVirtualMachinesMetadataSyncOutput> - This action sends a request to sync metadata across the specified virtual machines.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<TagResourceOutput> - Tag the resource.
-
testHypervisorConfiguration(
{required String gatewayArn, required String host, String? password, String? username}) → Future< void> - Tests your hypervisor configuration to validate that backup gateway can connect with the hypervisor and its resources.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<UntagResourceOutput> - Removes tags from the resource.
-
updateGatewayInformation(
{required String gatewayArn, String? gatewayDisplayName}) → Future< UpdateGatewayInformationOutput> - Updates a gateway's name. Specify which gateway to update using the Amazon Resource Name (ARN) of the gateway in your request.
-
updateGatewaySoftwareNow(
{required String gatewayArn}) → Future< UpdateGatewaySoftwareNowOutput> - Updates the gateway virtual machine (VM) software. The request immediately triggers the software update.
-
updateHypervisor(
{required String hypervisorArn, String? host, String? logGroupArn, String? name, String? password, String? username}) → Future< UpdateHypervisorOutput> - Updates a hypervisor metadata, including its host, username, and password. Specify which hypervisor to update using the Amazon Resource Name (ARN) of the hypervisor in your request.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited