getBandwidthRateLimitSchedule method
Future<GetBandwidthRateLimitScheduleOutput>
getBandwidthRateLimitSchedule({
- required String gatewayArn,
Retrieves the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. Use this to get a gateway's bandwidth rate limit schedule.
May throw ResourceNotFoundException.
Parameter gatewayArn :
The Amazon Resource Name (ARN) of the gateway. Use the
ListGateways operation to return a list of gateways for
your account and Amazon Web Services Region.
Implementation
Future<GetBandwidthRateLimitScheduleOutput> getBandwidthRateLimitSchedule({
required String gatewayArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'BackupOnPremises_v20210101.GetBandwidthRateLimitSchedule'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GatewayArn': gatewayArn,
},
);
return GetBandwidthRateLimitScheduleOutput.fromJson(jsonResponse.body);
}