getHypervisor method
This action requests information about the specified hypervisor to which the gateway will connect. A hypervisor is hardware, software, or firmware that creates and manages virtual machines, and allocates resources to them.
May throw ResourceNotFoundException.
Parameter hypervisorArn :
The Amazon Resource Name (ARN) of the hypervisor.
Implementation
Future<GetHypervisorOutput> getHypervisor({
required String hypervisorArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'BackupOnPremises_v20210101.GetHypervisor'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'HypervisorArn': hypervisorArn,
},
);
return GetHypervisorOutput.fromJson(jsonResponse.body);
}