getHypervisorPropertyMappings method
Future<GetHypervisorPropertyMappingsOutput>
getHypervisorPropertyMappings({
- required String hypervisorArn,
This action retrieves the property mappings for the specified hypervisor. A hypervisor property mapping displays the relationship of entity properties available from the hypervisor to the properties available in Amazon Web Services.
May throw ResourceNotFoundException.
Parameter hypervisorArn :
The Amazon Resource Name (ARN) of the hypervisor.
Implementation
Future<GetHypervisorPropertyMappingsOutput> getHypervisorPropertyMappings({
required String hypervisorArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'BackupOnPremises_v20210101.GetHypervisorPropertyMappings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'HypervisorArn': hypervisorArn,
},
);
return GetHypervisorPropertyMappingsOutput.fromJson(jsonResponse.body);
}