testHypervisorConfiguration method
Tests your hypervisor configuration to validate that backup gateway can connect with the hypervisor and its resources.
May throw ConflictException.
May throw ResourceNotFoundException.
Parameter gatewayArn :
The Amazon Resource Name (ARN) of the gateway to the hypervisor to test.
Parameter host :
The server host of the hypervisor. This can be either an IP address or a
fully-qualified domain name (FQDN).
Parameter password :
The password for the hypervisor.
Parameter username :
The username for the hypervisor.
Implementation
Future<void> testHypervisorConfiguration({
required String gatewayArn,
required String host,
String? password,
String? username,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'BackupOnPremises_v20210101.TestHypervisorConfiguration'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GatewayArn': gatewayArn,
'Host': host,
if (password != null) 'Password': password,
if (username != null) 'Username': username,
},
);
}