BackupSearch class
Backup Search is the recovery point and item level search for Backup.
Constructors
- BackupSearch({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getSearchJob(
{required String searchJobIdentifier}) → Future< GetSearchJobOutput> - This operation retrieves metadata of a search job, including its progress.
-
getSearchResultExportJob(
{required String exportJobIdentifier}) → Future< GetSearchResultExportJobOutput> - This operation retrieves the metadata of an export job.
-
listSearchJobBackups(
{required String searchJobIdentifier, int? maxResults, String? nextToken}) → Future< ListSearchJobBackupsOutput> - This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
-
listSearchJobResults(
{required String searchJobIdentifier, int? maxResults, String? nextToken}) → Future< ListSearchJobResultsOutput> - This operation returns a list of a specified search job.
-
listSearchJobs(
{SearchJobState? byStatus, int? maxResults, String? nextToken}) → Future< ListSearchJobsOutput> - This operation returns a list of search jobs belonging to an account.
-
listSearchResultExportJobs(
{int? maxResults, String? nextToken, String? searchJobIdentifier, ExportJobStatus? status}) → Future< ListSearchResultExportJobsOutput> - This operation exports search results of a search job to a specified destination S3 bucket.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - This operation returns the tags for a resource type.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startSearchJob(
{required SearchScope searchScope, String? clientToken, String? encryptionKeyArn, ItemFilters? itemFilters, String? name, Map< String, String> ? tags}) → Future<StartSearchJobOutput> - This operation creates a search job which returns recovery points filtered by SearchScope and items filtered by ItemFilters.
-
startSearchResultExportJob(
{required ExportSpecification exportSpecification, required String searchJobIdentifier, String? clientToken, String? roleArn, Map< String, String> ? tags}) → Future<StartSearchResultExportJobOutput> - This operations starts a job to export the results of search job to a designated S3 bucket.
-
stopSearchJob(
{required String searchJobIdentifier}) → Future< void> - This operations ends a search job.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - This operation puts tags on the resource you indicate.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - This operation removes tags from the specified resource.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited