listSearchJobBackups method
This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
If a search does not display an expected backup in the results, you can
call this operation to display each backup included in the search. Any
backups that were not included because they have a FAILED
status from a permissions issue will be displayed, along with a status
message.
Only recovery points with a backup index that has a status of
ACTIVE will be included in search results. If the index has
any other status, its status will be displayed along with a status
message.
May throw ResourceNotFoundException.
Parameter searchJobIdentifier :
The unique string that specifies the search job.
Parameter maxResults :
The maximum number of resource list items to be returned.
Parameter nextToken :
The next item following a partial list of returned backups included in a
search job.
For example, if a request is made to return MaxResults number
of backups, NextToken allows you to return more items in your
list starting at the location pointed to by the next token.
Implementation
Future<ListSearchJobBackupsOutput> listSearchJobBackups({
required String searchJobIdentifier,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/search-jobs/${Uri.encodeComponent(searchJobIdentifier)}/backups',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSearchJobBackupsOutput.fromJson(response);
}