tagResource method
This operation puts tags on the resource you indicate.
May throw ResourceNotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) that uniquely identifies the resource.
This is the resource that will have the indicated tags.
Parameter tags :
Required tags to include. A tag is a key-value pair you can use to manage,
filter, and search for your resources. Allowed characters include UTF-8
letters, numbers, spaces, and the following characters: + - = . _ : /.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}