listConsumableResources method
Returns a list of Batch consumable resources.
May throw ClientException.
May throw ServerException.
Parameter filters :
The filters to apply to the consumable resource list query. If used, only
those consumable resources that match the filter are listed. Filter names
and values can be:
-
name:
CONSUMABLE_RESOURCE_NAMEvalues: case-insensitive matches for the consumable resource name. If a filter value ends with an asterisk (), it matches any consumable resource name that begins with the string before the ''.
Parameter maxResults :
The maximum number of results returned by
ListConsumableResources in paginated output. When this
parameter is used, ListConsumableResources only returns
maxResults results in a single page and a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListConsumableResources request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListConsumableResources returns up
to 100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a previous paginated
ListConsumableResources request where maxResults
was used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there
are no more results to return.
Implementation
Future<ListConsumableResourcesResponse> listConsumableResources({
List<KeyValuesPair>? filters,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/listconsumableresources',
exceptionFnMap: _exceptionFns,
);
return ListConsumableResourcesResponse.fromJson(response);
}