listQuotaShares method
Returns a list of Batch quota shares associated with a job queue.
May throw ClientException.
May throw ServerException.
Parameter jobQueue :
The name or full Amazon Resource Name (ARN) of the job queue used to list
quota shares.
Parameter maxResults :
The maximum number of results returned by ListQuotaShares in
paginated output. When this parameter is used,
ListQuotaShares only returns maxResults results
in a single page and a nextToken response element. You can
see the remaining results of the initial request by sending another
ListQuotaShares request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, ListQuotaShares returns up to 100
results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value that's returned from a previous paginated
ListQuotaShares request where maxResults was
used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there
are no more results to return.
Implementation
Future<ListQuotaSharesResponse> listQuotaShares({
required String jobQueue,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'jobQueue': jobQueue,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/listquotashares',
exceptionFnMap: _exceptionFns,
);
return ListQuotaSharesResponse.fromJson(response);
}