listServiceJobs method
Returns a list of service jobs for a specified job queue.
May throw ClientException.
May throw ServerException.
Parameter filters :
The filter to apply to the query. Only one filter can be used at a time.
When the filter is used, jobStatus is ignored with the
exception that SHARE_IDENTIFIER or
QUOTA_SHARE_NAME and jobStatus can be used
together. The results are sorted by the createdAt field, with
the most recent jobs being first.
- JOB_NAME
-
The value of the filter is a case-insensitive match for the job name. If
the value ends with an asterisk (), the filter matches any job name that
begins with the string before the ''. This corresponds to the
jobNamevalue. For example,test1matches bothTest1andtest1, andtest1*matches bothtest1andTest10. When theJOB_NAMEfilter is used, the results are grouped by the job name and version. - BEFORE_CREATED_AT
-
The value for the filter is the time that's before the job was created.
This corresponds to the
createdAtvalue. The value is a string representation of the number of milliseconds since 00:00:00 UTC (midnight) on January 1, 1970. - AFTER_CREATED_AT
-
The value for the filter is the time that's after the job was created.
This corresponds to the
createdAtvalue. The value is a string representation of the number of milliseconds since 00:00:00 UTC (midnight) on January 1, 1970. - SHARE_IDENTIFIER
- The value for the filter is the fairshare scheduling share identifier.
- QUOTA_SHARE_NAME
- The value for the filter is the quota management share name.
Parameter jobQueue :
The name or ARN of the job queue with which to list service jobs.
Parameter jobStatus :
The job status used to filter service jobs in the specified queue. If the
filters parameter is specified, the jobStatus
parameter is ignored and jobs with any status are returned. The exceptions
are the SHARE_IDENTIFIER filter and
QUOTA_SHARE_NAME filter, which can be used with
jobStatus. If you don't specify a status, only
RUNNING jobs are returned.
Parameter maxResults :
The maximum number of results returned by ListServiceJobs in
paginated output. When this parameter is used,
ListServiceJobs only returns maxResults results
in a single page and a nextToken response element. The
remaining results of the initial request can be seen by sending another
ListServiceJobs request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListServiceJobs returns up to 100
results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a previous paginated
ListServiceJobs request where maxResults was
used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there
are no more results to return.
Implementation
Future<ListServiceJobsResponse> listServiceJobs({
List<KeyValuesPair>? filters,
String? jobQueue,
ServiceJobStatus? jobStatus,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (jobQueue != null) 'jobQueue': jobQueue,
if (jobStatus != null) 'jobStatus': jobStatus.value,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/listservicejobs',
exceptionFnMap: _exceptionFns,
);
return ListServiceJobsResponse.fromJson(response);
}