updateSchedulingPolicy method
Updates a scheduling policy.
May throw ClientException.
May throw ServerException.
Parameter arn :
The Amazon Resource Name (ARN) of the scheduling policy to update.
Parameter fairsharePolicy :
The fair-share policy scheduling details. Once set during creation, a
fairsharePolicy cannot be removed or changed to a quotaSharePolicy.
Parameter quotaSharePolicy :
The quota share scheduling policy details. Once set during creation, a
quotaSharePolicy cannot be removed or changed to a fairsharePolicy.
Implementation
Future<void> updateSchedulingPolicy({
required String arn,
FairsharePolicy? fairsharePolicy,
QuotaSharePolicy? quotaSharePolicy,
}) async {
final $payload = <String, dynamic>{
'arn': arn,
if (fairsharePolicy != null) 'fairsharePolicy': fairsharePolicy,
if (quotaSharePolicy != null) 'quotaSharePolicy': quotaSharePolicy,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/updateschedulingpolicy',
exceptionFnMap: _exceptionFns,
);
}