BcmRecommendedActions class
You can use the Billing and Cost Management Recommended Actions API to programmatically query your best practices and recommendations to optimize your costs.
The Billing and Cost Management Recommended Actions API provides the following endpoint:
- https://bcm-recommended-actions.us-east-1.api.aws
Constructors
- BcmRecommendedActions({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
listRecommendedActions(
{RequestFilter? filter, int? maxResults, String? nextToken}) → Future< ListRecommendedActionsResponse> - Returns a list of recommended actions that match the filter criteria.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited