cancelAutomatedReasoningPolicyBuildWorkflow method
Cancels a running Automated Reasoning policy build workflow. This stops the policy generation process and prevents further processing of the source documents.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter buildWorkflowId :
The unique identifier of the build workflow to cancel. You can get this ID
from the StartAutomatedReasoningPolicyBuildWorkflow response or by listing
build workflows.
Parameter policyArn :
The Amazon Resource Name (ARN) of the Automated Reasoning policy whose
build workflow you want to cancel.
Implementation
Future<void> cancelAutomatedReasoningPolicyBuildWorkflow({
required String buildWorkflowId,
required String policyArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/automated-reasoning-policies/${Uri.encodeComponent(policyArn)}/build-workflows/${Uri.encodeComponent(buildWorkflowId)}/cancel',
exceptionFnMap: _exceptionFns,
);
}