getModelImportJob method
Retrieves the properties associated with import model job, including the status of the job. For more information, see Import a customized model in the Amazon Bedrock User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter jobIdentifier :
The identifier of the import job.
Implementation
Future<GetModelImportJobResponse> getModelImportJob({
required String jobIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/model-import-jobs/${Uri.encodeComponent(jobIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return GetModelImportJobResponse.fromJson(response);
}