listProvisionedModelThroughputs method
Lists the Provisioned Throughputs in the account. For more information, see Provisioned Throughput in the Amazon Bedrock User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter creationTimeAfter :
A filter that returns Provisioned Throughputs created after the specified
time.
Parameter creationTimeBefore :
A filter that returns Provisioned Throughputs created before the specified
time.
Parameter maxResults :
THe maximum number of results to return in the response. If there are more
results than the number you specified, the response returns a
nextToken value. To see the next batch of results, send the
nextToken value in another list request.
Parameter modelArnEquals :
A filter that returns Provisioned Throughputs whose model Amazon Resource
Name (ARN) is equal to the value that you specify.
Parameter nameContains :
A filter that returns Provisioned Throughputs if their name contains the
expression that you specify.
Parameter nextToken :
If there are more results than the number you specified in the
maxResults field, the response returns a
nextToken value. To see the next batch of results, specify
the nextToken value in this field.
Parameter sortBy :
The field by which to sort the returned list of Provisioned Throughputs.
Parameter sortOrder :
The sort order of the results.
Parameter statusEquals :
A filter that returns Provisioned Throughputs if their statuses matches
the value that you specify.
Implementation
Future<ListProvisionedModelThroughputsResponse>
listProvisionedModelThroughputs({
DateTime? creationTimeAfter,
DateTime? creationTimeBefore,
int? maxResults,
String? modelArnEquals,
String? nameContains,
String? nextToken,
SortByProvisionedModels? sortBy,
SortOrder? sortOrder,
ProvisionedModelStatus? statusEquals,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (creationTimeAfter != null)
'creationTimeAfter': [_s.iso8601ToJson(creationTimeAfter).toString()],
if (creationTimeBefore != null)
'creationTimeBefore': [_s.iso8601ToJson(creationTimeBefore).toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (modelArnEquals != null) 'modelArnEquals': [modelArnEquals],
if (nameContains != null) 'nameContains': [nameContains],
if (nextToken != null) 'nextToken': [nextToken],
if (sortBy != null) 'sortBy': [sortBy.value],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
if (statusEquals != null) 'statusEquals': [statusEquals.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/provisioned-model-throughputs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListProvisionedModelThroughputsResponse.fromJson(response);
}