stopAdvancedPromptOptimizationJob method
Stops an advanced prompt optimization job that is in progress.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter jobIdentifier :
The ARN or ID of the advanced prompt optimization job to stop.
Implementation
Future<void> stopAdvancedPromptOptimizationJob({
required String jobIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/advanced-prompt-optimization-jobs/${Uri.encodeComponent(jobIdentifier)}/stop',
exceptionFnMap: _exceptionFns,
);
}