stopModelInvocationJob method
Stops a batch inference job. You're only charged for tokens that were already processed. For more information, see Stop a batch inference job.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter jobIdentifier :
The Amazon Resource Name (ARN) of the batch inference job to stop.
Implementation
Future<void> stopModelInvocationJob({
required String jobIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/model-invocation-job/${Uri.encodeComponent(jobIdentifier)}/stop',
exceptionFnMap: _exceptionFns,
);
}