getAgentAlias method
Gets information about an alias of an agent.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter agentAliasId :
The unique identifier of the alias for which to get information.
Parameter agentId :
The unique identifier of the agent to which the alias to get information
belongs.
Implementation
Future<GetAgentAliasResponse> getAgentAlias({
required String agentAliasId,
required String agentId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/agents/${Uri.encodeComponent(agentId)}/agentaliases/${Uri.encodeComponent(agentAliasId)}/',
exceptionFnMap: _exceptionFns,
);
return GetAgentAliasResponse.fromJson(response);
}