getFlowVersion method
Retrieves information about a version of a flow. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter flowIdentifier :
The unique identifier of the flow for which to get information.
Parameter flowVersion :
The version of the flow for which to get information.
Parameter includedData :
Controls the scope of data returned. Set to METADATA_ONLY to
return only resource metadata. Set to ALL_DATA or omit this
field to return the full response.
Implementation
Future<GetFlowVersionResponse> getFlowVersion({
required String flowIdentifier,
required String flowVersion,
IncludedData? includedData,
}) async {
final $query = <String, List<String>>{
if (includedData != null) 'includedData': [includedData.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/flows/${Uri.encodeComponent(flowIdentifier)}/versions/${Uri.encodeComponent(flowVersion)}/',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetFlowVersionResponse.fromJson(response);
}