getCodeInterpreterSession method
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, and metadata.
To get a code interpreter session, you must specify both the code interpreter identifier and the session ID. The response includes information about the session's timeout settings and current status.
The following operations are related to
GetCodeInterpreterSession:
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter codeInterpreterIdentifier :
The unique identifier of the code interpreter associated with the session.
Parameter sessionId :
The unique identifier of the code interpreter session to retrieve.
Implementation
Future<GetCodeInterpreterSessionResponse> getCodeInterpreterSession({
required String codeInterpreterIdentifier,
required String sessionId,
}) async {
final $query = <String, List<String>>{
'sessionId': [sessionId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/code-interpreters/${Uri.encodeComponent(codeInterpreterIdentifier)}/sessions/get',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetCodeInterpreterSessionResponse.fromJson(response);
}