stopBatchEvaluation method
Stops a running batch evaluation. Sessions that have already been evaluated retain their results.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter batchEvaluationId :
The unique identifier of the batch evaluation to stop.
Implementation
Future<StopBatchEvaluationResponse> stopBatchEvaluation({
required String batchEvaluationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/evaluations/batch-evaluate/${Uri.encodeComponent(batchEvaluationId)}/stop',
exceptionFnMap: _exceptionFns,
);
return StopBatchEvaluationResponse.fromJson(response);
}