BedrockAgentCoreControl class
Welcome to the Amazon Bedrock AgentCore Control plane API reference. Control plane actions configure, create, modify, and monitor Amazon Web Services resources.
Constructors
- BedrockAgentCoreControl({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDatasetExamples(
{required String datasetId, required DataSourceType source, String? clientToken}) → Future< AddDatasetExamplesResponse> - Adds examples to the dataset's DRAFT. All examples are validated against the dataset's schema type before any writes occur. If any example fails validation, the entire batch is rejected (all-or-nothing semantics).
-
batchPutGatewayRateLimits(
{required String gatewayIdentifier, required List< BatchPutLimitEntry> rateLimits, String? clientToken}) → Future<BatchPutGatewayRateLimitsResponse> - Atomically creates or updates multiple rate limits for a gateway. The operation updates existing limits with matching keys and creates new limits for new keys. If the operation fails, the service applies no changes. Retry the request after resolving the issue.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAgentRuntime(
{required AgentRuntimeArtifact agentRuntimeArtifact, required String agentRuntimeName, required String roleArn, AuthorizerConfiguration? authorizerConfiguration, CapacityProviderConfiguration? capacityProviderConfiguration, String? clientToken, String? description, Map< String, String> ? environmentVariables, List<FilesystemConfiguration> ? filesystemConfigurations, LifecycleConfiguration? lifecycleConfiguration, NetworkConfiguration? networkConfiguration, ProtocolConfiguration? protocolConfiguration, RequestHeaderConfiguration? requestHeaderConfiguration, Map<String, String> ? tags}) → Future<CreateAgentRuntimeResponse> - Creates an Amazon Bedrock AgentCore Runtime.
-
createAgentRuntimeEndpoint(
{required String agentRuntimeId, required String name, String? agentRuntimeVersion, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateAgentRuntimeEndpointResponse> - Creates an AgentCore Runtime endpoint.
-
createApiKeyCredentialProvider(
{required String name, String? apiKey, SecretReference? apiKeySecretConfig, SecretSourceType? apiKeySecretSource, Map< String, String> ? tags}) → Future<CreateApiKeyCredentialProviderResponse> - Creates a new API key credential provider.
-
createBrowser(
{required String name, required BrowserNetworkConfiguration networkConfiguration, BrowserSigningConfigInput? browserSigning, List< Certificate> ? certificates, String? clientToken, String? description, List<BrowserEnterprisePolicy> ? enterprisePolicies, String? executionRoleArn, List<ToolsFileSystemConfiguration> ? filesystemConfigurations, RecordingConfig? recording, Map<String, String> ? tags}) → Future<CreateBrowserResponse> - Creates a custom browser.
-
createBrowserProfile(
{required String name, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateBrowserProfileResponse> - Creates a browser profile in Amazon Bedrock AgentCore. A browser profile stores persistent browser data such as cookies, local storage, session storage, and browsing history that can be saved from browser sessions and reused in subsequent sessions.
-
createCapacityProvider(
{required ComputeConfiguration computeConfiguration, required String name, required PermissionsConfiguration permissionsConfiguration, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreateCapacityProviderOutput> - Creates a capacity provider. A capacity provider defines the Amazon EC2 infrastructure for AgentCore Runtime, including the operating system, allowed instance types, networking, and storage. It also specifies the IAM permissions that AgentCore uses to manage those instances.
-
createCodeInterpreter(
{required String name, required CodeInterpreterNetworkConfiguration networkConfiguration, List< Certificate> ? certificates, String? clientToken, String? description, String? executionRoleArn, List<ToolsFileSystemConfiguration> ? filesystemConfigurations, Map<String, String> ? tags}) → Future<CreateCodeInterpreterResponse> - Creates a custom code interpreter.
-
createConfigurationBundle(
{required String bundleName, required Map< String, ComponentConfiguration> components, String? branchName, String? clientToken, String? commitMessage, VersionCreatedBySource? createdBy, String? description, String? kmsKeyArn, Map<String, String> ? tags}) → Future<CreateConfigurationBundleResponse> - Creates a new configuration bundle resource. A configuration bundle stores versioned component configurations for agent evaluation workflows.
-
createDataset(
{required String datasetName, required DatasetSchemaType schemaType, required DataSourceType source, String? clientToken, String? description, String? kmsKeyArn, Map< String, String> ? tags}) → Future<CreateDatasetResponse> -
Creates a new dataset resource asynchronously. Returns immediately with
status CREATING. Poll
GetDatasetuntil status transitions to ACTIVE or CREATE_FAILED. -
createDatasetVersion(
{required String datasetId, String? clientToken}) → Future< CreateDatasetVersionResponse> -
Publishes the current DRAFT as a new numbered version. The DRAFT is
preserved and remains editable after publishing. Returns immediately with
status UPDATING. Poll
GetDatasetuntil status transitions to ACTIVE or UPDATE_FAILED. -
createEvaluator(
{required EvaluatorConfig evaluatorConfig, required String evaluatorName, required EvaluatorLevel level, String? clientToken, String? description, String? kmsKeyArn, Map< String, String> ? tags}) → Future<CreateEvaluatorResponse> - Creates a custom evaluator for agent quality assessment. Custom evaluators can use either LLM-as-a-Judge configurations with user-defined prompts, rating scales, and model settings, or code-based configurations with customer-managed Lambda functions to evaluate agent performance at tool call, trace, or session levels.
-
createGateway(
{required AuthorizerType authorizerType, required String name, required String roleArn, AuthorizerConfiguration? authorizerConfiguration, String? clientToken, String? description, ExceptionLevel? exceptionLevel, List< GatewayInterceptorConfiguration> ? interceptorConfigurations, String? kmsKeyArn, GatewayPolicyEngineConfiguration? policyEngineConfiguration, GatewayProtocolConfiguration? protocolConfiguration, GatewayProtocolType? protocolType, Map<String, String> ? tags}) → Future<CreateGatewayResponse> - Creates a gateway for Amazon Bedrock Agent. A gateway serves as an integration point between your agent and external services.
-
createGatewayRateLimit(
{required List< String> dimensionKeys, required List<LimitEntry> entries, required String gatewayIdentifier, String? clientToken, String? description, String? rateLimitId}) → Future<CreateGatewayRateLimitResponse> - Creates a rate limit for a gateway. Rate limits define throttling rules for each dimension that control request rates, token consumption rates, and concurrent connections through the gateway.
-
createGatewayRule(
{required List< Action> actions, required String gatewayIdentifier, required int priority, String? clientToken, List<Condition> ? conditions, String? description}) → Future<CreateGatewayRuleResponse> - Creates a rule for a gateway. Rules define conditions and actions that control how requests are routed and processed through the gateway, including principal-based access control and path-based routing.
-
createGatewayTarget(
{required String gatewayIdentifier, required TargetConfiguration targetConfiguration, String? clientToken, List< CredentialProviderConfiguration> ? credentialProviderConfigurations, String? description, MetadataConfiguration? metadataConfiguration, String? name, PrivateEndpoint? privateEndpoint}) → Future<CreateGatewayTargetResponse> - Creates a target for a gateway. A target defines an endpoint that the gateway can connect to.
-
createHarness(
{required String executionRoleArn, required String harnessName, List< String> ? allowedTools, AuthorizerConfiguration? authorizerConfiguration, String? clientToken, HarnessEnvironmentProviderRequest? environment, HarnessEnvironmentArtifact? environmentArtifact, Map<String, String> ? environmentVariables, int? maxIterations, int? maxTokens, HarnessMemoryConfiguration? memory, HarnessModelConfiguration? model, List<HarnessSkill> ? skills, List<HarnessSystemContentBlock> ? systemPrompt, Map<String, String> ? tags, int? timeoutSeconds, List<HarnessTool> ? tools, HarnessTruncationConfiguration? truncation}) → Future<CreateHarnessResponse> - Operation to create a harness.
-
createHarnessEndpoint(
{required String endpointName, required String harnessId, String? clientToken, String? description, Map< String, String> ? tags, String? targetVersion}) → Future<CreateHarnessEndpointResponse> - Operation to create a harness endpoint.
-
createMemory(
{required int eventExpiryDuration, required String name, String? clientToken, String? description, String? encryptionKeyArn, List< IndexedKey> ? indexedKeys, String? memoryExecutionRoleArn, List<MemoryStrategyInput> ? memoryStrategies, StreamDeliveryResources? streamDeliveryResources, Map<String, String> ? tags}) → Future<CreateMemoryOutput> - Creates a new Amazon Bedrock AgentCore Memory resource.
-
createOauth2CredentialProvider(
{required CredentialProviderVendorType credentialProviderVendor, required String name, required Oauth2ProviderConfigInput oauth2ProviderConfigInput, Map< String, String> ? tags}) → Future<CreateOauth2CredentialProviderResponse> - Creates a new OAuth2 credential provider.
-
createOnlineEvaluationConfig(
{required DataSourceConfig dataSourceConfig, required bool enableOnCreate, required String evaluationExecutionRoleArn, required String onlineEvaluationConfigName, required Rule rule, String? clientToken, ClusteringConfig? clusteringConfig, String? description, List< EvaluatorReference> ? evaluators, List<Insight> ? insights, Map<String, String> ? tags}) → Future<CreateOnlineEvaluationConfigResponse> - Creates an online evaluation configuration for continuous monitoring of agent performance. Online evaluation automatically samples live traffic from CloudWatch logs at specified rates and applies evaluators to assess agent quality in production.
-
createPaymentConnector(
{required List< CredentialsProviderConfiguration> credentialProviderConfigurations, required String name, required String paymentManagerId, required PaymentConnectorType type, String? clientToken, String? description}) → Future<CreatePaymentConnectorResponse> - Creates a new payment connector for a payment manager. A payment connector integrates with a supported payment provider to enable payment processing capabilities.
-
createPaymentCredentialProvider(
{required PaymentCredentialProviderVendorType credentialProviderVendor, required String name, required PaymentProviderConfigurationInput providerConfigurationInput, Map< String, String> ? tags}) → Future<CreatePaymentCredentialProviderResponse> - Creates a new payment credential provider for storing authentication credentials used by payment connectors to communicate with external payment providers.
-
createPaymentManager(
{required PaymentsAuthorizerType authorizerType, required String name, required String roleArn, AuthorizerConfiguration? authorizerConfiguration, String? clientToken, String? description, Map< String, String> ? tags}) → Future<CreatePaymentManagerResponse> - Creates a new payment manager in your Amazon Web Services account. A payment manager serves as the top-level resource for managing payment processing capabilities, including payment connectors that integrate with supported payment providers.
-
createPolicy(
{required PolicyDefinition definition, required String name, required String policyEngineId, String? clientToken, String? description, EnforcementMode? enforcementMode, PolicyValidationMode? validationMode}) → Future< CreatePolicyResponse> -
Creates a policy within the AgentCore Policy system. Policies provide
real-time, deterministic control over agentic interactions with AgentCore
Gateway. Using the Cedar policy language, you can define fine-grained
policies that specify which interactions with Gateway tools are permitted
based on input parameters and OAuth claims, ensuring agents operate within
defined boundaries and business rules. The policy is validated during
creation against the Cedar schema generated from the Gateway's tools'
input schemas, which defines the available tools, their parameters, and
expected data types. This is an asynchronous operation. Use the GetPolicy
operation to poll the
statusfield to track completion. -
createPolicyEngine(
{required String name, String? clientToken, String? description, String? encryptionKeyArn, Map< String, String> ? tags}) → Future<CreatePolicyEngineResponse> -
Creates a new policy engine within the AgentCore Policy system. A policy
engine is a collection of policies that evaluates and authorizes agent
tool calls. When associated with Gateways (each Gateway can be associated
with at most one policy engine, but multiple Gateways can be associated
with the same engine), the policy engine intercepts all agent requests and
determines whether to allow or deny each action based on the defined
policies. This is an asynchronous operation. Use the GetPolicyEngine
operation to poll the
statusfield to track completion. -
createRegistry(
{required String name, ApprovalConfiguration? approvalConfiguration, AuthorizerConfiguration? authorizerConfiguration, RegistryAuthorizerType? authorizerType, String? clientToken, String? description}) → Future< CreateRegistryResponse> - Creates a new registry in your Amazon Web Services account. A registry serves as a centralized catalog for organizing and managing registry records, including MCP servers, A2A agents, agent skills, and custom resource types.
-
createRegistryRecord(
{required DescriptorType descriptorType, required String name, required String registryId, String? clientToken, String? description, Descriptors? descriptors, String? recordVersion, SynchronizationConfiguration? synchronizationConfiguration, SynchronizationType? synchronizationType}) → Future< CreateRegistryRecordResponse> - Creates a new registry record within the specified registry. A registry record represents an individual AI resource's metadata in the registry. This could be an MCP server (and associated tools), A2A agent, agent skill, or a custom resource with a custom schema.
-
createWorkloadIdentity(
{required String name, List< String> ? allowedResourceOauth2ReturnUrls, Map<String, String> ? tags}) → Future<CreateWorkloadIdentityResponse> - Creates a new workload identity.
-
deleteAgentRuntime(
{required String agentRuntimeId, String? agentRuntimeVersion, String? clientToken}) → Future< DeleteAgentRuntimeResponse> - Deletes an Amazon Bedrock AgentCore Runtime, or a single version of an AgentCore Runtime when you provide the version qualifier.
-
deleteAgentRuntimeEndpoint(
{required String agentRuntimeId, required String endpointName, String? clientToken}) → Future< DeleteAgentRuntimeEndpointResponse> - Deletes an AgentCore Runtime endpoint.
-
deleteApiKeyCredentialProvider(
{required String name}) → Future< void> - Deletes an API key credential provider.
-
deleteBrowser(
{required String browserId, String? clientToken}) → Future< DeleteBrowserResponse> - Deletes a custom browser.
-
deleteBrowserProfile(
{required String profileId, String? clientToken}) → Future< DeleteBrowserProfileResponse> - Deletes a browser profile.
-
deleteCapacityProvider(
{required String capacityProviderId, String? clientToken}) → Future< DeleteCapacityProviderOutput> - Deletes a capacity provider. Before you delete a capacity provider, disassociate all agent runtimes and runtime versions that reference it. If any references remain, the operation fails.
-
deleteCodeInterpreter(
{required String codeInterpreterId, String? clientToken}) → Future< DeleteCodeInterpreterResponse> - Deletes a custom code interpreter.
-
deleteConfigurationBundle(
{required String bundleId}) → Future< DeleteConfigurationBundleResponse> - Deletes a configuration bundle and all of its versions.
-
deleteDataset(
{required String datasetId, String? datasetVersion}) → Future< DeleteDatasetResponse> -
Deletes a dataset version or an entire dataset asynchronously. If
datasetVersionis absent, deletes all versions and the dataset record itself. If provided, deletes only that specific version. -
deleteDatasetExamples(
{required String datasetId, required List< String> exampleIds, String? clientToken}) → Future<DeleteDatasetExamplesResponse> - Deletes specific examples by ID from DRAFT. All example IDs are validated before any deletes occur. If any ID does not exist in DRAFT, the entire batch is rejected (all-or-nothing semantics).
-
deleteEvaluator(
{required String evaluatorId}) → Future< DeleteEvaluatorResponse> - Deletes a custom evaluator. Builtin evaluators cannot be deleted. The evaluator must not be referenced by any active online evaluation configurations.
-
deleteGateway(
{required String gatewayIdentifier}) → Future< DeleteGatewayResponse> - Deletes a gateway.
-
deleteGatewayRateLimit(
{required String gatewayIdentifier, required String rateLimitId}) → Future< DeleteGatewayRateLimitResponse> - Deletes a gateway rate limit.
-
deleteGatewayRule(
{required String gatewayIdentifier, required String ruleId}) → Future< DeleteGatewayRuleResponse> - Deletes a gateway rule.
-
deleteGatewayTarget(
{required String gatewayIdentifier, required String targetId}) → Future< DeleteGatewayTargetResponse> - Deletes a gateway target.
-
deleteHarness(
{required String harnessId, String? clientToken, bool? deleteManagedMemory}) → Future< DeleteHarnessResponse> - Operation to delete a Harness.
-
deleteHarnessEndpoint(
{required String endpointName, required String harnessId, String? clientToken}) → Future< DeleteHarnessEndpointResponse> - Operation to delete a harness endpoint.
-
deleteMemory(
{required String memoryId, String? clientToken}) → Future< DeleteMemoryOutput> - Deletes an Amazon Bedrock AgentCore Memory resource.
-
deleteOauth2CredentialProvider(
{required String name}) → Future< void> - Deletes an OAuth2 credential provider.
-
deleteOnlineEvaluationConfig(
{required String onlineEvaluationConfigId}) → Future< DeleteOnlineEvaluationConfigResponse> - Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it.
-
deletePaymentConnector(
{required String paymentConnectorId, required String paymentManagerId, String? clientToken}) → Future< DeletePaymentConnectorResponse> - Deletes a payment connector.
-
deletePaymentCredentialProvider(
{required String name}) → Future< void> - Deletes a payment credential provider and its associated stored credentials.
-
deletePaymentManager(
{required String paymentManagerId, String? clientToken}) → Future< DeletePaymentManagerResponse> - Deletes a payment manager. All payment connectors associated with the payment manager must be deleted before the payment manager can be deleted. This operation initiates the deletion process asynchronously.
-
deletePolicy(
{required String policyEngineId, required String policyId}) → Future< DeletePolicyResponse> -
Deletes an existing policy from the AgentCore Policy system. Once deleted,
the policy can no longer be used for agent behavior control and all
references to it become invalid. This is an asynchronous operation. Use
the
GetPolicyoperation to poll thestatusfield to track completion. -
deletePolicyEngine(
{required String policyEngineId}) → Future< DeletePolicyEngineResponse> -
Deletes an existing policy engine from the AgentCore Policy system. The
policy engine must not have any associated policies before deletion. Once
deleted, the policy engine and all its configurations become unavailable
for policy management and evaluation. This is an asynchronous operation.
Use the
GetPolicyEngineoperation to poll thestatusfield to track completion. -
deleteRegistry(
{required String registryId}) → Future< DeleteRegistryResponse> - Deletes a registry. The registry must contain zero records before it can be deleted. This operation initiates the deletion process asynchronously.
-
deleteRegistryRecord(
{required String recordId, required String registryId}) → Future< void> -
Deletes a registry record. The record's status transitions to
DELETINGand the record is removed asynchronously. -
deleteResourcePolicy(
{required String resourceArn}) → Future< void> - Deletes the resource-based policy for a specified resource.
-
deleteWorkloadIdentity(
{required String name}) → Future< void> - Deletes a workload identity.
-
getAgentRuntime(
{required String agentRuntimeId, String? agentRuntimeVersion}) → Future< GetAgentRuntimeResponse> - Gets an Amazon Bedrock AgentCore Runtime.
-
getAgentRuntimeEndpoint(
{required String agentRuntimeId, required String endpointName}) → Future< GetAgentRuntimeEndpointResponse> - Gets information about an Amazon Secure AgentEndpoint.
-
getApiKeyCredentialProvider(
{required String name}) → Future< GetApiKeyCredentialProviderResponse> - Retrieves information about an API key credential provider.
-
getBrowser(
{required String browserId}) → Future< GetBrowserResponse> - Gets information about a custom browser.
-
getBrowserProfile(
{required String profileId}) → Future< GetBrowserProfileResponse> - Gets information about a browser profile.
-
getCapacityProvider(
{required String capacityProviderId}) → Future< GetCapacityProviderOutput> - Retrieves information about a capacity provider, including its status, permissions configuration, and compute configuration.
-
getCodeInterpreter(
{required String codeInterpreterId}) → Future< GetCodeInterpreterResponse> - Gets information about a custom code interpreter.
-
getConfigurationBundle(
{required String bundleId, String? branchName}) → Future< GetConfigurationBundleResponse> -
Gets the latest version of a configuration bundle. By default, returns the
latest version on the mainline branch. Use
GetConfigurationBundleVersionto retrieve a specific historical version. -
getConfigurationBundleVersion(
{required String bundleId, required String versionId}) → Future< GetConfigurationBundleVersionResponse> - Gets a specific version of a configuration bundle by its version identifier.
-
getDataset(
{required String datasetId, String? datasetVersion}) → Future< GetDatasetResponse> -
Retrieves dataset metadata. Use the
datasetVersionquery parameter to retrieve a specific version's metadata. If absent, defaults to DRAFT. For paginated example content, useListDatasetExamples. -
getEvaluator(
{required String evaluatorId, IncludedData? includedData}) → Future< GetEvaluatorResponse> - Retrieves detailed information about an evaluator, including its configuration, status, and metadata. Works with both built-in and custom evaluators.
-
getGateway(
{required String gatewayIdentifier}) → Future< GetGatewayResponse> - Retrieves information about a specific Gateway.
-
getGatewayRateLimit(
{required String gatewayIdentifier, required String rateLimitId}) → Future< GetGatewayRateLimitResponse> - Retrieves information about a gateway rate limit.
-
getGatewayRule(
{required String gatewayIdentifier, required String ruleId}) → Future< GetGatewayRuleResponse> - Retrieves detailed information about a specific gateway rule.
-
getGatewayTarget(
{required String gatewayIdentifier, required String targetId}) → Future< GetGatewayTargetResponse> - Retrieves information about a specific gateway target.
-
getHarness(
{required String harnessId, String? harnessVersion}) → Future< GetHarnessResponse> - Operation to get a single harness.
-
getHarnessEndpoint(
{required String endpointName, required String harnessId}) → Future< GetHarnessEndpointResponse> - Operation to get a single harness endpoint.
-
getMemory(
{required String memoryId, MemoryView? view}) → Future< GetMemoryOutput> - Retrieve an existing Amazon Bedrock AgentCore Memory resource.
-
getOauth2CredentialProvider(
{required String name}) → Future< GetOauth2CredentialProviderResponse> - Retrieves information about an OAuth2 credential provider.
-
getOnlineEvaluationConfig(
{required String onlineEvaluationConfigId}) → Future< GetOnlineEvaluationConfigResponse> - Retrieves detailed information about an online evaluation configuration, including its rules, data sources, evaluators, and execution status.
-
getPaymentConnector(
{required String paymentConnectorId, required String paymentManagerId}) → Future< GetPaymentConnectorResponse> - Retrieves information about a specific payment connector.
-
getPaymentCredentialProvider(
{required String name}) → Future< GetPaymentCredentialProviderResponse> - Retrieves information about a specific payment credential provider.
-
getPaymentManager(
{required String paymentManagerId}) → Future< GetPaymentManagerResponse> - Retrieves information about a specific payment manager.
-
getPolicy(
{required String policyEngineId, required String policyId}) → Future< GetPolicyResponse> - Retrieves detailed information about a specific policy within the AgentCore Policy system. This operation returns the complete policy definition, metadata, and current status, allowing administrators to review and manage policy configurations.
-
getPolicyEngine(
{required String policyEngineId}) → Future< GetPolicyEngineResponse> - Retrieves detailed information about a specific policy engine within the AgentCore Policy system. This operation returns the complete policy engine configuration, metadata, and current status, allowing administrators to review and manage policy engine settings.
-
getPolicyEngineSummary(
{required String policyEngineId}) → Future< GetPolicyEngineSummaryResponse> - Retrieves a metadata-only summary of a specific policy engine without decrypting customer content. This lightweight read operation returns resource identifiers, status, timestamps, and the encryption key ARN, but does not include the description or status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
getPolicyGeneration(
{required String policyEngineId, required String policyGenerationId}) → Future< GetPolicyGenerationResponse> - Retrieves information about a policy generation request within the AgentCore Policy system. Policy generation converts natural language descriptions into Cedar policy statements using AI-powered translation, enabling non-technical users to create policies.
-
getPolicyGenerationSummary(
{required String policyEngineId, required String policyGenerationId}) → Future< GetPolicyGenerationSummaryResponse> - Retrieves a metadata-only summary of a specific policy generation request without decrypting customer content. This lightweight read operation returns resource identifiers, status, timestamps, and findings, but does not include status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
getPolicySummary(
{required String policyEngineId, required String policyId}) → Future< GetPolicySummaryResponse> - Retrieves a metadata-only summary of a specific policy without decrypting customer content. This lightweight read operation returns resource identifiers, status, and timestamps, but does not include the policy definition, description, or status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
getRegistry(
{required String registryId}) → Future< GetRegistryResponse> - Retrieves information about a specific registry.
-
getRegistryRecord(
{required String recordId, required String registryId}) → Future< GetRegistryRecordResponse> - Retrieves information about a specific registry record.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> - Retrieves the resource-based policy for a specified resource.
-
getTokenVault(
{String? tokenVaultId}) → Future< GetTokenVaultResponse> - Retrieves information about a token vault.
-
getWorkloadIdentity(
{required String name}) → Future< GetWorkloadIdentityResponse> - Retrieves information about a workload identity.
-
listAgentRuntimeEndpoints(
{required String agentRuntimeId, int? maxResults, String? nextToken}) → Future< ListAgentRuntimeEndpointsResponse> - Lists all endpoints for a specific Amazon Secure Agent.
-
listAgentRuntimes(
{int? maxResults, String? nextToken}) → Future< ListAgentRuntimesResponse> - Lists all Amazon Secure Agents in your account.
-
listAgentRuntimeVersions(
{required String agentRuntimeId, int? maxResults, String? nextToken}) → Future< ListAgentRuntimeVersionsResponse> - Lists all versions of a specific Amazon Secure Agent.
-
listAgentRuntimeVersionsByCapacityProvider(
{required String capacityProviderId, int? maxResults, String? nextToken}) → Future< ListAgentRuntimeVersionsByCapacityProviderOutput> -
Lists the agent runtime versions that are associated with a capacity
provider. Use this operation to identify the runtimes you must
disassociate before you can delete the capacity provider. Results are
paginated; use the
nextTokenparameter to retrieve additional results. -
listApiKeyCredentialProviders(
{int? maxResults, String? nextToken}) → Future< ListApiKeyCredentialProvidersResponse> - Lists all API key credential providers in your account.
-
listBrowserProfiles(
{int? maxResults, String? name, String? nextToken}) → Future< ListBrowserProfilesResponse> - Lists all browser profiles in your account.
-
listBrowsers(
{int? maxResults, String? nextToken, ResourceType? type}) → Future< ListBrowsersResponse> - Lists all custom browsers in your account.
-
listCapacityProviders(
{int? maxResults, String? nextToken}) → Future< ListCapacityProvidersOutput> -
Lists the capacity providers in your account and returns summary
information for each one. To retrieve the full configuration for a
specific capacity provider, use
GetCapacityProvider. Results are paginated; use thenextTokenparameter to retrieve additional results. -
listCodeInterpreters(
{int? maxResults, String? nextToken, ResourceType? type}) → Future< ListCodeInterpretersResponse> - Lists all custom code interpreters in your account.
-
listConfigurationBundles(
{int? maxResults, String? nextToken}) → Future< ListConfigurationBundlesResponse> - Lists all configuration bundles in the account.
-
listConfigurationBundleVersions(
{required String bundleId, VersionFilter? filter, int? maxResults, String? nextToken}) → Future< ListConfigurationBundleVersionsResponse> - Lists all versions of a configuration bundle, with optional filtering by branch name or creation source.
-
listDatasetExamples(
{required String datasetId, String? datasetVersion, int? maxResults, String? nextToken}) → Future< ListDatasetExamplesResponse> - Returns paginated examples from the dataset. The server embeds the resolved version in the pagination token. Once pagination begins, all subsequent pages are pinned to that version regardless of concurrent mutations.
-
listDatasets(
{int? maxResults, String? nextToken}) → Future< ListDatasetsResponse> - Lists all datasets in the caller's account, paginated.
-
listDatasetVersions(
{required String datasetId, int? maxResults, String? nextToken}) → Future< ListDatasetVersionsResponse> - Lists all published versions of a dataset, sorted by version number descending (newest first). Does not include the DRAFT working copy.
-
listEvaluators(
{int? maxResults, String? nextToken}) → Future< ListEvaluatorsResponse> - Lists all available evaluators, including both builtin evaluators provided by the service and custom evaluators created by the user.
-
listGatewayRateLimits(
{required String gatewayIdentifier, int? maxResults, String? nextToken}) → Future< ListGatewayRateLimitsResponse> -
Lists all rate limits for a gateway. Results are paginated. Use the
nextTokenparameter to retrieve additional results. -
listGatewayRules(
{required String gatewayIdentifier, int? maxResults, String? nextToken}) → Future< ListGatewayRulesResponse> - Lists all rules for a gateway.
-
listGateways(
{int? maxResults, String? nextToken}) → Future< ListGatewaysResponse> - Lists all gateways in the account.
-
listGatewayTargets(
{required String gatewayIdentifier, int? maxResults, String? nextToken}) → Future< ListGatewayTargetsResponse> - Lists all targets for a specific gateway.
-
listHarnessEndpoints(
{required String harnessId, int? maxResults, String? nextToken}) → Future< ListHarnessEndpointsResponse> - Operation to list the endpoints of a harness.
-
listHarnesses(
{int? maxResults, String? nextToken}) → Future< ListHarnessesResponse> - Operation to list harnesses.
-
listHarnessVersions(
{required String harnessId, int? maxResults, String? nextToken}) → Future< ListHarnessVersionsResponse> - Operation to list the versions of a Harness.
-
listMemories(
{int? maxResults, String? nextToken}) → Future< ListMemoriesOutput> - Lists the available Amazon Bedrock AgentCore Memory resources in the current Amazon Web Services Region.
-
listOauth2CredentialProviders(
{int? maxResults, String? nextToken}) → Future< ListOauth2CredentialProvidersResponse> - Lists all OAuth2 credential providers in your account.
-
listOnlineEvaluationConfigs(
{int? maxResults, String? nextToken}) → Future< ListOnlineEvaluationConfigsResponse> - Lists all online evaluation configurations in the account, providing summary information about each configuration's status and settings.
-
listPaymentConnectors(
{required String paymentManagerId, int? maxResults, String? nextToken}) → Future< ListPaymentConnectorsResponse> - Lists all payment connectors for a specified payment manager.
-
listPaymentCredentialProviders(
{int? maxResults, String? nextToken}) → Future< ListPaymentCredentialProvidersResponse> - Lists all payment credential providers in the account.
-
listPaymentManagers(
{int? maxResults, String? nextToken}) → Future< ListPaymentManagersResponse> - Lists all payment managers in the account.
-
listPolicies(
{required String policyEngineId, int? maxResults, String? nextToken, String? targetResourceScope}) → Future< ListPoliciesResponse> - Retrieves a list of policies within the AgentCore Policy engine. This operation supports pagination and filtering to help administrators manage and discover policies across policy engines. Results can be filtered by policy engine or resource associations.
-
listPolicyEngines(
{int? maxResults, String? nextToken}) → Future< ListPolicyEnginesResponse> - Retrieves a list of policy engines within the AgentCore Policy system. This operation supports pagination to help administrators discover and manage policy engines across their account. Each policy engine serves as a container for related policies.
-
listPolicyEngineSummaries(
{int? maxResults, String? nextToken}) → Future< ListPolicyEngineSummariesResponse> - Retrieves a paginated list of metadata-only policy engine summaries without decrypting customer content. This lightweight read operation returns resource identifiers, status, and timestamps for each policy engine, but does not include descriptions or status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
listPolicyGenerationAssets(
{required String policyEngineId, required String policyGenerationId, int? maxResults, String? nextToken}) → Future< ListPolicyGenerationAssetsResponse> - Retrieves a list of generated policy assets from a policy generation request within the AgentCore Policy system. This operation returns the actual Cedar policies and related artifacts produced by the AI-powered policy generation process, allowing users to review and select from multiple generated policy options.
-
listPolicyGenerations(
{required String policyEngineId, int? maxResults, String? nextToken}) → Future< ListPolicyGenerationsResponse> - Retrieves a list of policy generation requests within the AgentCore Policy system. This operation supports pagination and filtering to help track and manage AI-powered policy generation operations.
-
listPolicyGenerationSummaries(
{required String policyEngineId, int? maxResults, String? nextToken}) → Future< ListPolicyGenerationSummariesResponse> - Retrieves a paginated list of metadata-only policy generation summaries within a policy engine without decrypting customer content. This lightweight read operation returns resource identifiers, status, timestamps, and findings for each policy generation, but does not include status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
listPolicySummaries(
{required String policyEngineId, int? maxResults, String? nextToken, String? targetResourceScope}) → Future< ListPolicySummariesResponse> - Retrieves a paginated list of metadata-only policy summaries within a policy engine without decrypting customer content. This lightweight read operation returns resource identifiers, status, and timestamps for each policy, but does not include policy definitions, descriptions, or status reasons. Because this operation does not require access to the customer's KMS key, it is suitable for resource discovery, inventory, and integration scenarios where only metadata is needed.
-
listRegistries(
{RegistryAuthorizerType? authorizerType, int? maxResults, String? nextToken, RegistryStatus? status}) → Future< ListRegistriesResponse> -
Lists all registries in the account. You can optionally filter results by
status using the
statusparameter, or by authorizer type using theauthorizerTypeparameter. -
listRegistryRecords(
{required String registryId, DescriptorType? descriptorType, int? maxResults, String? name, String? nextToken, RegistryRecordStatus? status}) → Future< ListRegistryRecordsResponse> -
Lists registry records within a registry. You can optionally filter
results using the
name,status, anddescriptorTypeparameters. When multiple filters are specified, they are combined using AND logic. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags associated with the specified resource.
-
listWorkloadIdentities(
{int? maxResults, String? nextToken}) → Future< ListWorkloadIdentitiesResponse> - Lists all workload identities in your account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putResourcePolicy(
{required String policy, required String resourceArn}) → Future< PutResourcePolicyResponse> - Creates or updates a resource-based policy for a resource with the specified resourceArn.
-
setTokenVaultCMK(
{required KmsConfiguration kmsConfiguration, String? tokenVaultId}) → Future< SetTokenVaultCMKResponse> - Sets the customer master key (CMK) for a token vault.
-
startPolicyGeneration(
{required Content content, required String name, required String policyEngineId, required Resource resource, String? clientToken}) → Future< StartPolicyGenerationResponse> - Initiates the AI-powered generation of Cedar policies from natural language descriptions within the AgentCore Policy system. This feature enables both technical and non-technical users to create policies by describing their authorization requirements in plain English, which is then automatically translated into formal Cedar policy statements. The generation process analyzes the natural language input along with the Gateway's tool context to produce validated policy options. Generated policy assets are automatically deleted after 7 days, so you should review and create policies from the generated assets within this timeframe. Once created, policies are permanent and not subject to this expiration. Generated policies should be reviewed and tested in log-only mode before deploying to production. Use this when you want to describe policy intent naturally rather than learning Cedar syntax, though generated policies may require refinement for complex scenarios.
-
submitRegistryRecordForApproval(
{required String recordId, required String registryId}) → Future< SubmitRegistryRecordForApprovalResponse> -
Submits a registry record for approval. This transitions the record from
DRAFTstatus toPENDING_APPROVALstatus. If the registry has auto-approval enabled, the record is automatically approved. -
synchronizeGatewayTargets(
{required String gatewayIdentifier, required List< String> targetIdList}) → Future<SynchronizeGatewayTargetsResponse> - Synchronizes the gateway targets by fetching the latest tool definitions from the target endpoints.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the specified tags from the specified resource.
-
updateAgentRuntime(
{required AgentRuntimeArtifact agentRuntimeArtifact, required String agentRuntimeId, required String roleArn, AuthorizerConfiguration? authorizerConfiguration, CapacityProviderConfiguration? capacityProviderConfiguration, String? clientToken, String? description, Map< String, String> ? environmentVariables, List<FilesystemConfiguration> ? filesystemConfigurations, LifecycleConfiguration? lifecycleConfiguration, RuntimeMetadataConfiguration? metadataConfiguration, NetworkConfiguration? networkConfiguration, ProtocolConfiguration? protocolConfiguration, RequestHeaderConfiguration? requestHeaderConfiguration}) → Future<UpdateAgentRuntimeResponse> - Updates an existing Amazon Secure Agent.
-
updateAgentRuntimeEndpoint(
{required String agentRuntimeId, required String endpointName, String? agentRuntimeVersion, String? clientToken, String? description}) → Future< UpdateAgentRuntimeEndpointResponse> - Updates an existing Amazon Bedrock AgentCore Runtime endpoint.
-
updateApiKeyCredentialProvider(
{required String name, String? apiKey, SecretReference? apiKeySecretConfig, SecretSourceType? apiKeySecretSource}) → Future< UpdateApiKeyCredentialProviderResponse> - Updates an existing API key credential provider.
-
updateCapacityProvider(
{required String capacityProviderId, String? clientToken, UpdatedDescription? description}) → Future< UpdateCapacityProviderOutput> - Updates a capacity provider. Only the description can be changed. To change other configuration, such as instance types, networking, or storage, create a new capacity provider.
-
updateConfigurationBundle(
{required String bundleId, String? branchName, String? bundleName, String? clientToken, String? commitMessage, Map< String, ComponentConfiguration> ? components, VersionCreatedBySource? createdBy, String? description, String? kmsKeyArn, List<String> ? parentVersionIds}) → Future<UpdateConfigurationBundleResponse> - Updates a configuration bundle by creating a new version with the specified changes. Each update creates a new version in the version history.
-
updateDataset(
{required String datasetId, String? clientToken, String? description}) → Future< UpdateDatasetResponse> -
Updates a dataset's metadata. Synchronous operation. Only provided fields
are updated; omitted fields remain unchanged. To modify dataset content,
use
AddDatasetExamples,UpdateDatasetExamples, orDeleteDatasetExamples. -
updateDatasetExamples(
{required String datasetId, required List< Object> examples, String? clientToken}) → Future<UpdateDatasetExamplesResponse> - Updates multiple existing examples in-place on DRAFT. All examples are validated against the dataset's schema type before any writes occur. If any example fails validation, the entire batch is rejected (all-or-nothing semantics).
-
updateEvaluator(
{required String evaluatorId, String? clientToken, String? description, EvaluatorConfig? evaluatorConfig, String? kmsKeyArn, EvaluatorLevel? level}) → Future< UpdateEvaluatorResponse> - Updates a custom evaluator's configuration, description, or evaluation level. Built-in evaluators cannot be updated. The evaluator must not be locked for modification.
-
updateGateway(
{required AuthorizerType authorizerType, required String gatewayIdentifier, required String name, required String roleArn, AuthorizerConfiguration? authorizerConfiguration, CustomTransformConfiguration? customTransformConfiguration, String? description, ExceptionLevel? exceptionLevel, List< GatewayInterceptorConfiguration> ? interceptorConfigurations, String? kmsKeyArn, GatewayPolicyEngineConfiguration? policyEngineConfiguration, GatewayProtocolConfiguration? protocolConfiguration, GatewayProtocolType? protocolType, WafConfiguration? wafConfiguration}) → Future<UpdateGatewayResponse> - Updates an existing gateway.
-
updateGatewayRateLimit(
{required List< LimitEntry> entries, required String gatewayIdentifier, required String rateLimitId, String? description}) → Future<UpdateGatewayRateLimitResponse> - Updates the entries of a gateway rate limit. The dimension keys are immutable after creation.
-
updateGatewayRule(
{required String gatewayIdentifier, required String ruleId, List< Action> ? actions, List<Condition> ? conditions, String? description, int? priority}) → Future<UpdateGatewayRuleResponse> - Updates a gateway rule's priority, conditions, actions, or description.
-
updateGatewayTarget(
{required String gatewayIdentifier, required TargetConfiguration targetConfiguration, required String targetId, List< CredentialProviderConfiguration> ? credentialProviderConfigurations, String? description, MetadataConfiguration? metadataConfiguration, String? name, PrivateEndpoint? privateEndpoint}) → Future<UpdateGatewayTargetResponse> - Updates an existing gateway target.
-
updateHarness(
{required String harnessId, List< String> ? allowedTools, UpdatedAuthorizerConfiguration? authorizerConfiguration, String? clientToken, HarnessEnvironmentProviderRequest? environment, UpdatedHarnessEnvironmentArtifact? environmentArtifact, Map<String, String> ? environmentVariables, String? executionRoleArn, int? maxIterations, int? maxTokens, UpdatedHarnessMemoryConfiguration? memory, HarnessModelConfiguration? model, List<HarnessSkill> ? skills, List<HarnessSystemContentBlock> ? systemPrompt, int? timeoutSeconds, List<HarnessTool> ? tools, HarnessTruncationConfiguration? truncation}) → Future<UpdateHarnessResponse> - Operation to update a harness.
-
updateHarnessEndpoint(
{required String endpointName, required String harnessId, String? clientToken, String? description, String? targetVersion}) → Future< UpdateHarnessEndpointResponse> - Operation to update a harness endpoint.
-
updateMemory(
{required String memoryId, List< IndexedKey> ? addIndexedKeys, String? clientToken, String? description, int? eventExpiryDuration, String? memoryExecutionRoleArn, ModifyMemoryStrategies? memoryStrategies, StreamDeliveryResources? streamDeliveryResources}) → Future<UpdateMemoryOutput> - Update an Amazon Bedrock AgentCore Memory resource memory.
-
updateOauth2CredentialProvider(
{required CredentialProviderVendorType credentialProviderVendor, required String name, required Oauth2ProviderConfigInput oauth2ProviderConfigInput}) → Future< UpdateOauth2CredentialProviderResponse> - Updates an existing OAuth2 credential provider.
-
updateOnlineEvaluationConfig(
{required String onlineEvaluationConfigId, String? clientToken, ClusteringConfig? clusteringConfig, DataSourceConfig? dataSourceConfig, String? description, String? evaluationExecutionRoleArn, List< EvaluatorReference> ? evaluators, OnlineEvaluationExecutionStatus? executionStatus, List<Insight> ? insights, Rule? rule}) → Future<UpdateOnlineEvaluationConfigResponse> - Updates an online evaluation configuration's settings, including rules, data sources, evaluators, and execution status. Changes take effect immediately for ongoing evaluations.
-
updatePaymentConnector(
{required String paymentConnectorId, required String paymentManagerId, String? clientToken, List< CredentialsProviderConfiguration> ? credentialProviderConfigurations, String? description, PaymentConnectorType? type}) → Future<UpdatePaymentConnectorResponse> - Updates an existing payment connector. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
-
updatePaymentCredentialProvider(
{required PaymentCredentialProviderVendorType credentialProviderVendor, required String name, required PaymentProviderConfigurationInput providerConfigurationInput}) → Future< UpdatePaymentCredentialProviderResponse> - Updates an existing payment credential provider with new authentication credentials.
-
updatePaymentManager(
{required String paymentManagerId, AuthorizerConfiguration? authorizerConfiguration, PaymentsAuthorizerType? authorizerType, String? clientToken, String? description, String? roleArn}) → Future< UpdatePaymentManagerResponse> - Updates an existing payment manager. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
-
updatePolicy(
{required String policyEngineId, required String policyId, PolicyDefinition? definition, UpdatedDescription? description, EnforcementMode? enforcementMode, PolicyValidationMode? validationMode}) → Future< UpdatePolicyResponse> -
Updates an existing policy within the AgentCore Policy system. This
operation allows modification of the policy description and definition
while maintaining the policy's identity. The updated policy is validated
against the Cedar schema before being applied. This is an asynchronous
operation. Use the
GetPolicyoperation to poll thestatusfield to track completion. -
updatePolicyEngine(
{required String policyEngineId, UpdatedDescription? description}) → Future< UpdatePolicyEngineResponse> -
Updates an existing policy engine within the AgentCore Policy system. This
operation allows modification of the policy engine description while
maintaining its identity. This is an asynchronous operation. Use the
GetPolicyEngineoperation to poll thestatusfield to track completion. -
updateRegistry(
{required String registryId, UpdatedApprovalConfiguration? approvalConfiguration, UpdatedAuthorizerConfiguration? authorizerConfiguration, UpdatedDescription? description, String? name}) → Future< UpdateRegistryResponse> - Updates an existing registry. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
-
updateRegistryRecord(
{required String recordId, required String registryId, UpdatedDescription? description, DescriptorType? descriptorType, UpdatedDescriptors? descriptors, String? name, String? recordVersion, UpdatedSynchronizationConfiguration? synchronizationConfiguration, UpdatedSynchronizationType? synchronizationType, bool? triggerSynchronization}) → Future< UpdateRegistryRecordResponse> - Updates an existing registry record. This operation uses PATCH semantics, so you only need to specify the fields you want to change. The update is processed asynchronously and returns HTTP 202 Accepted.
-
updateRegistryRecordStatus(
{required String recordId, required String registryId, required RegistryRecordStatus status, required String statusReason}) → Future< UpdateRegistryRecordStatusResponse> - Updates the status of a registry record. Use this operation to approve, reject, or deprecate a registry record.
-
updateWorkloadIdentity(
{required String name, List< String> ? allowedResourceOauth2ReturnUrls}) → Future<UpdateWorkloadIdentityResponse> - Updates an existing workload identity.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited