deleteConfigurationBundle method
Deletes a configuration bundle and all of its versions.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter bundleId :
The unique identifier of the configuration bundle to delete.
Implementation
Future<DeleteConfigurationBundleResponse> deleteConfigurationBundle({
required String bundleId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/configuration-bundles/${Uri.encodeComponent(bundleId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteConfigurationBundleResponse.fromJson(response);
}