deletePaymentManager method
Deletes a payment manager. All payment connectors associated with the payment manager must be deleted before the payment manager can be deleted. This operation initiates the deletion process asynchronously.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter paymentManagerId :
The unique identifier of the payment manager to delete.
Parameter clientToken :
A unique, case-sensitive identifier to ensure that the API request
completes no more than one time. If you don't specify this field, a value
is randomly generated for you. If this token matches a previous request,
the service ignores the request, but doesn't return an error. For more
information, see Ensuring
idempotency.
Implementation
Future<DeletePaymentManagerResponse> deletePaymentManager({
required String paymentManagerId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/payments/managers/${Uri.encodeComponent(paymentManagerId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeletePaymentManagerResponse.fromJson(response);
}