getConfigurationBundle method
Gets the latest version of a configuration bundle. By default, returns the
latest version on the mainline branch. Use
GetConfigurationBundleVersion to retrieve a specific
historical version.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter bundleId :
The unique identifier of the configuration bundle to retrieve.
Parameter branchName :
The branch name to get the latest version from. If not specified, returns
the latest version on the mainline branch.
Implementation
Future<GetConfigurationBundleResponse> getConfigurationBundle({
required String bundleId,
String? branchName,
}) async {
final $query = <String, List<String>>{
if (branchName != null) 'branchName': [branchName],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/configuration-bundles/${Uri.encodeComponent(bundleId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetConfigurationBundleResponse.fromJson(response);
}