getConfigurationBundleVersion method
Gets a specific version of a configuration bundle by its version identifier.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter bundleId :
The unique identifier of the configuration bundle.
Parameter versionId :
The version identifier of the configuration bundle version to retrieve.
Implementation
Future<GetConfigurationBundleVersionResponse> getConfigurationBundleVersion({
required String bundleId,
required String versionId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/configuration-bundles/${Uri.encodeComponent(bundleId)}/versions/${Uri.encodeComponent(versionId)}',
exceptionFnMap: _exceptionFns,
);
return GetConfigurationBundleVersionResponse.fromJson(response);
}