setTokenVaultCMK method
Future<SetTokenVaultCMKResponse>
setTokenVaultCMK({
- required KmsConfiguration kmsConfiguration,
- String? tokenVaultId,
Sets the customer master key (CMK) for a token vault.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter kmsConfiguration :
The KMS configuration for the token vault, including the key type and KMS
key ARN.
Parameter tokenVaultId :
The unique identifier of the token vault to update.
Implementation
Future<SetTokenVaultCMKResponse> setTokenVaultCMK({
required KmsConfiguration kmsConfiguration,
String? tokenVaultId,
}) async {
final $payload = <String, dynamic>{
'kmsConfiguration': kmsConfiguration,
if (tokenVaultId != null) 'tokenVaultId': tokenVaultId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/identities/set-token-vault-cmk',
exceptionFnMap: _exceptionFns,
);
return SetTokenVaultCMKResponse.fromJson(response);
}