getInvocationStep method
Retrieves the details of a specific invocation step within an invocation in a session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter invocationIdentifier :
The unique identifier for the invocation in UUID format.
Parameter invocationStepId :
The unique identifier (in UUID format) for the specific invocation step to
retrieve.
Parameter sessionIdentifier :
The unique identifier for the invocation step's associated session. You
can specify either the session's sessionId or its Amazon
Resource Name (ARN).
Implementation
Future<GetInvocationStepResponse> getInvocationStep({
required String invocationIdentifier,
required String invocationStepId,
required String sessionIdentifier,
}) async {
final $payload = <String, dynamic>{
'invocationIdentifier': invocationIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sessions/${Uri.encodeComponent(sessionIdentifier)}/invocationSteps/${Uri.encodeComponent(invocationStepId)}',
exceptionFnMap: _exceptionFns,
);
return GetInvocationStepResponse.fromJson(response);
}