getSession method
Retrieves details about a specific session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sessionIdentifier :
A unique identifier for the session to retrieve. You can specify either
the session's sessionId or its Amazon Resource Name (ARN).
Implementation
Future<GetSessionResponse> getSession({
required String sessionIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/sessions/${Uri.encodeComponent(sessionIdentifier)}/',
exceptionFnMap: _exceptionFns,
);
return GetSessionResponse.fromJson(response);
}