stopFlowExecution method
Stops an Amazon Bedrock flow's execution. This operation prevents further
processing of the flow and changes the execution status to
Aborted.
May throw AccessDeniedException.
May throw BadGatewayException.
May throw ConflictException.
May throw DependencyFailedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter executionIdentifier :
The unique identifier of the flow execution to stop.
Parameter flowAliasIdentifier :
The unique identifier of the flow alias used for the execution.
Parameter flowIdentifier :
The unique identifier of the flow.
Implementation
Future<StopFlowExecutionResponse> stopFlowExecution({
required String executionIdentifier,
required String flowAliasIdentifier,
required String flowIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/flows/${Uri.encodeComponent(flowIdentifier)}/aliases/${Uri.encodeComponent(flowAliasIdentifier)}/executions/${Uri.encodeComponent(executionIdentifier)}/stop',
exceptionFnMap: _exceptionFns,
);
return StopFlowExecutionResponse.fromJson(response);
}