getDataAutomationLibraryEntity method
Gets an existing entity based on entity type from the library
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter entityId :
Unique identifier for the entity
Parameter entityType :
The entity type for which the entity is requested
Parameter libraryArn :
ARN generated at the server side when a DataAutomationLibrary is created
Implementation
Future<GetDataAutomationLibraryEntityResponse>
getDataAutomationLibraryEntity({
required String entityId,
required EntityType entityType,
required String libraryArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/data-automation-libraries/${Uri.encodeComponent(libraryArn)}/entityType/${Uri.encodeComponent(entityType.value)}/entities/${Uri.encodeComponent(entityId)}',
exceptionFnMap: _exceptionFns,
);
return GetDataAutomationLibraryEntityResponse.fromJson(response);
}