listDataAutomationLibraryEntities method
Lists all stored entities in the library
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter entityType :
The entity type for which the entity list is requested
Parameter libraryArn :
ARN generated at the server side when a DataAutomationLibrary is created
Parameter nextToken :
Pagination token for retrieving the next set of results
Implementation
Future<ListDataAutomationLibraryEntitiesResponse>
listDataAutomationLibraryEntities({
required EntityType entityType,
required String libraryArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/data-automation-libraries/${Uri.encodeComponent(libraryArn)}/entityType/${Uri.encodeComponent(entityType.value)}/entities/',
exceptionFnMap: _exceptionFns,
);
return ListDataAutomationLibraryEntitiesResponse.fromJson(response);
}