invokeModel method
Invokes the specified Amazon Bedrock model to run inference using the prompt and inference parameters provided in the request body. You use model inference to generate text, images, and embeddings.
For example code, see Invoke model code examples in the Amazon Bedrock User Guide.
This operation requires permission for the
bedrock:InvokeModel action.
For troubleshooting some of the common errors you might encounter when
using the InvokeModel API, see Troubleshooting
Amazon Bedrock API Error Codes in the Amazon Bedrock User Guide
May throw AccessDeniedException.
May throw InternalServerException.
May throw ModelErrorException.
May throw ModelNotReadyException.
May throw ModelTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter modelId :
The unique identifier of the model to invoke to run inference.
The modelId to provide depends on the type of model or
throughput that you use:
- If you use a base model, specify the model ID or its ARN. For a list of model IDs for base models, see Amazon Bedrock base model IDs (on-demand throughput) in the Amazon Bedrock User Guide.
- If you use an inference profile, specify the inference profile ID or its ARN. For a list of inference profile IDs, see Supported Regions and models for cross-region inference in the Amazon Bedrock User Guide.
- If you use a provisioned model, specify the ARN of the Provisioned Throughput. For more information, see Run inference using a Provisioned Throughput in the Amazon Bedrock User Guide.
- If you use a custom model, specify the ARN of the custom model deployment (for on-demand inference) or the ARN of your provisioned model (for Provisioned Throughput). For more information, see Use a custom model in Amazon Bedrock in the Amazon Bedrock User Guide.
- If you use an imported model, specify the ARN of the imported model. You can get the model ARN from a successful call to CreateModelImportJob or from the Imported models page in the Amazon Bedrock console.
Parameter accept :
The desired MIME type of the inference body in the response. The default
value is application/json.
Parameter body :
The prompt and inference parameters in the format specified in the
contentType in the header. You must provide the body in JSON
format. To see the format and content of the request and response bodies
for different models, refer to Inference
parameters. For more information, see Run
inference in the Bedrock User Guide.
Parameter contentType :
The MIME type of the input data in the request. You must specify
application/json.
Parameter guardrailIdentifier :
The unique identifier of the guardrail that you want to use. If you don't
provide a value, no guardrail is applied to the invocation.
An error will be thrown in the following situations.
-
You don't provide a guardrail identifier but you specify the
amazon-bedrock-guardrailConfigfield in the request body. -
You enable the guardrail but the
contentTypeisn'tapplication/json. -
You provide a guardrail identifier, but
guardrailVersionisn't specified.
Parameter guardrailVersion :
The version number for the guardrail. The value can also be
DRAFT.
Parameter performanceConfigLatency :
Model performance settings for the request.
Parameter requestMetadata :
Key-value pairs that you can use to filter invocation logs.
Parameter serviceTier :
Specifies the processing tier type used for serving the request.
Parameter trace :
Specifies whether to enable or disable the Bedrock trace. If enabled, you
can see the full Bedrock trace.
Implementation
Future<InvokeModelResponse> invokeModel({
required String modelId,
String? accept,
Uint8List? body,
String? contentType,
String? guardrailIdentifier,
String? guardrailVersion,
PerformanceConfigLatency? performanceConfigLatency,
String? requestMetadata,
ServiceTierType? serviceTier,
Trace? trace,
}) async {
final headers = <String, String>{
if (accept != null) 'Accept': accept.toString(),
if (contentType != null) 'Content-Type': contentType.toString(),
if (guardrailIdentifier != null)
'X-Amzn-Bedrock-GuardrailIdentifier': guardrailIdentifier.toString(),
if (guardrailVersion != null)
'X-Amzn-Bedrock-GuardrailVersion': guardrailVersion.toString(),
if (performanceConfigLatency != null)
'X-Amzn-Bedrock-PerformanceConfig-Latency':
performanceConfigLatency.value,
if (requestMetadata != null)
'X-Amzn-Bedrock-Request-Metadata': requestMetadata.toString(),
if (serviceTier != null) 'X-Amzn-Bedrock-Service-Tier': serviceTier.value,
if (trace != null) 'X-Amzn-Bedrock-Trace': trace.value,
};
final response = await _protocol.sendRaw(
payload: body,
method: 'POST',
requestUri: '/model/${Uri.encodeComponent(modelId)}/invoke',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return InvokeModelResponse(
body: await response.stream.toBytes(),
contentType:
_s.extractHeaderStringValue(response.headers, 'Content-Type')!,
performanceConfigLatency: _s
.extractHeaderStringValue(
response.headers, 'X-Amzn-Bedrock-PerformanceConfig-Latency')
?.let(PerformanceConfigLatency.fromString),
serviceTier: _s
.extractHeaderStringValue(
response.headers, 'X-Amzn-Bedrock-Service-Tier')
?.let(ServiceTierType.fromString),
);
}