Billing class
You can use the Billing API to programatically list the billing views available to you for a given time period. A billing view represents a set of billing data.
The Billing API provides the following endpoint:
Constructors
- Billing({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateSourceViews(
{required String arn, required List< String> sourceViews}) → Future<AssociateSourceViewsResponse> - Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBillingView(
{required String name, required List< String> sourceViews, String? clientToken, Expression? dataFilterExpression, String? description, List<ResourceTag> ? resourceTags}) → Future<CreateBillingViewResponse> - Creates a billing view with the specified billing view attributes.
-
deleteBillingView(
{required String arn, bool? force}) → Future< DeleteBillingViewResponse> - Deletes the specified billing view.
-
disassociateSourceViews(
{required String arn, required List< String> sourceViews}) → Future<DisassociateSourceViewsResponse> - Removes the association between one or more source billing views and an existing billing view. This allows modifying the composition of aggregate billing views.
-
getBillingView(
{required String arn}) → Future< GetBillingViewResponse> - Returns the metadata associated to the specified billing view ARN.
-
getResourcePolicy(
{required String resourceArn}) → Future< GetResourcePolicyResponse> -
Returns the resource-based policy document attached to the resource in
JSONformat. -
listBillingViews(
{ActiveTimeRange? activeTimeRange, List< String> ? arns, List<BillingViewType> ? billingViewTypes, int? maxResults, List<StringSearch> ? names, String? nextToken, String? ownerAccountId, String? sourceAccountId}) → Future<ListBillingViewsResponse> - Lists the billing views available for a given time period.
-
listSourceViewsForBillingView(
{required String arn, int? maxResults, String? nextToken}) → Future< ListSourceViewsForBillingViewResponse> - Lists the source views (managed Amazon Web Services billing views) associated with the billing view.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists tags associated with the billing view resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required List< ResourceTag> resourceTags}) → Future<void> - An API operation for adding one or more tags (key-value pairs) to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> resourceTagKeys}) → Future<void> - Removes one or more tags from a resource. Specify only tag keys in your request. Don't specify the value.
-
updateBillingView(
{required String arn, Expression? dataFilterExpression, String? description, String? name}) → Future< UpdateBillingViewResponse> - An API to update the attributes of the billing view.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited