updateBillingGroup method
This updates an existing billing group.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon Resource Name (ARN) of the billing group being updated.
Parameter accountGrouping :
Specifies if the billing group has automatic account association
(AutoAssociate) enabled.
Parameter computationPreference :
The preferences and settings that will be used to compute the Amazon Web
Services charges for a billing group.
Parameter description :
A description of the billing group.
Parameter name :
The name of the billing group. The names must be unique to each billing
group.
Parameter status :
The status of the billing group. Only one of the valid values can be used.
Implementation
Future<UpdateBillingGroupOutput> updateBillingGroup({
required String arn,
UpdateBillingGroupAccountGrouping? accountGrouping,
ComputationPreference? computationPreference,
String? description,
String? name,
BillingGroupStatus? status,
}) async {
final $payload = <String, dynamic>{
'Arn': arn,
if (accountGrouping != null) 'AccountGrouping': accountGrouping,
if (computationPreference != null)
'ComputationPreference': computationPreference,
if (description != null) 'Description': description,
if (name != null) 'Name': name,
if (status != null) 'Status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/update-billing-group',
exceptionFnMap: _exceptionFns,
);
return UpdateBillingGroupOutput.fromJson(response);
}