tagResource method
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
May throw InternalServiceError.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw TooManyTagsException.
Parameter resourceARN :
The ARN of the configuration.
Parameter tags :
A list of tags to apply to the configuration.
Implementation
Future<void> tagResource({
required String resourceARN,
required List<Tag> tags,
}) async {
final $payload = <String, dynamic>{
'ResourceARN': resourceARN,
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tag-resource',
exceptionFnMap: _exceptionFns,
);
}