Adds up to 50 members to a chat room in an Amazon Chime Enterprise
account. Members can be users or bots. The member role designates whether
the member is a chat room administrator or a general chat room member.
Moves phone numbers into the Deletion queue. Phone numbers must be
disassociated from any users or Amazon Chime Voice Connectors before they
can be deleted.
Suspends up to 50 users from a Team or
EnterpriseLWA Amazon Chime account. For more information
about different account types, see Managing
Your Amazon Chime Accounts in the Amazon Chime Administration
Guide.
Removes the suspension from up to 50 previously suspended users for the
specified Amazon Chime EnterpriseLWA account. Only users on
EnterpriseLWA accounts can be unsuspended using this action.
For more information about different account types, see
Managing Your Amazon Chime Accounts in the account types, in the
Amazon Chime Administration Guide.
Updates phone number product types or calling names. You can update one
attribute at a time for each UpdatePhoneNumberRequestItem.
For example, you can update the product type or the calling name.
Updates user details within the UpdateUserRequestItem object for up
to 20 users for the specified Amazon Chime account. Currently, only
LicenseType updates are supported for this action.
Creates an Amazon Chime account under the administrator's AWS account.
Only Team account types are currently supported for this
action. For more information about different account types, see Managing
Your Amazon Chime Accounts in the Amazon Chime Administration
Guide.
Uses the join token and call metadata in a meeting request (From number,
To number, and so forth) to initiate an outbound call to a public switched
telephone network (PSTN) and join them into a Chime meeting. Also ensures
that the From number belongs to the customer.
Creates an order for phone numbers to be provisioned. For toll-free
numbers, you cannot use the Amazon Chime Business Calling product type.
For numbers outside the U.S., you must use the Amazon Chime SIP Media
Application Dial-In product type.
Adds a member to a chat room in an Amazon Chime Enterprise account. A
member can be either a user or a bot. The member role designates whether
the member is a chat room administrator or a general chat room member.
Moves the specified phone number into the Deletion queue. A phone
number must be disassociated from any users or Amazon Chime Voice
Connectors before it can be deleted.
Retrieves account settings for the specified Amazon Chime account ID, such
as remote control and dialout settings. For more information about these
settings, see Use the
Policies Page in the Amazon Chime Administration Guide.
Retrieves details for the specified phone number order, such as the order
creation timestamp, phone numbers in E.164 format, product type, and order
status.
Gets the retention settings for the specified Amazon Chime Enterprise
account. For more information about retention settings, see Managing
Chat Retention Policies in the Amazon Chime Administration
Guide.
Sends email to a maximum of 50 users, inviting them to the specified
Amazon Chime Team account. Only Team account
types are currently supported for this action.
Lists the Amazon Chime accounts under the administrator's AWS account. You
can filter accounts by account name prefix. To find out which Amazon Chime
account a user belongs to, you can filter by the user's email address,
which returns one account result.
Lists the room details for the specified Amazon Chime Enterprise account.
Optionally, filter the results by a member ID (user ID or bot ID) to see a
list of rooms that the member belongs to.
Lists the users that belong to the specified Amazon Chime account. You can
specify an email address to list only the user that the email address
belongs to.
Creates an events configuration that allows a bot to receive outgoing
events sent by Amazon Chime. Choose either an HTTPS endpoint or a Lambda
function ARN. For more information, see Bot.
Puts retention settings for the specified Amazon Chime Enterprise account.
We recommend using AWS CloudTrail to monitor usage of this API for your
account. For more information, see Logging
Amazon Chime API Calls with AWS CloudTrail in the Amazon Chime
Administration Guide.
Searches for phone numbers that can be ordered. For US numbers, provide at
least one of the following search filters: AreaCode,
City, State, or TollFreePrefix. If
you provide City, you must also provide State.
Numbers outside the US only support the PhoneNumberType
filter, which you must use.
Updates account details for the specified Amazon Chime account. Currently,
only account name and default license updates are supported for this
action.
Updates the settings for the specified Amazon Chime account. You can
update settings for remote control of shared screens, or for the dial-out
option. For more information about these settings, see Use the
Policies Page in the Amazon Chime Administration Guide.
Updates phone number details, such as product type or calling name, for
the specified phone number ID. You can update one phone number detail at a
time. For example, you can update either the product type or the calling
name in one action.
Updates the phone number settings for the administrator's AWS account,
such as the default outbound calling name. You can update the default
outbound calling name once every seven days. Outbound calling names can
take up to 72 hours to update.
Updates room membership details, such as the member role, for a room in an
Amazon Chime Enterprise account. The member role designates whether the
member is a chat room administrator or a general chat room member. The
member role can be updated only for user IDs.