describeChannelModeratedByAppInstanceUser method
Future<DescribeChannelModeratedByAppInstanceUserResponse>
describeChannelModeratedByAppInstanceUser({})
Returns the full details of a channel moderated by the specified
AppInstanceUser or AppInstanceBot.
May throw BadRequestException.
May throw ForbiddenException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter appInstanceUserArn :
The ARN of the user or bot in the moderated channel.
Parameter channelArn :
The ARN of the moderated channel.
Parameter chimeBearer :
The ARN of the AppInstanceUser or AppInstanceBot
that makes the API call.
Implementation
Future<DescribeChannelModeratedByAppInstanceUserResponse>
describeChannelModeratedByAppInstanceUser({
required String appInstanceUserArn,
required String channelArn,
required String chimeBearer,
}) async {
final headers = <String, String>{
'x-amz-chime-bearer': chimeBearer.toString(),
};
final $query = <String, List<String>>{
'app-instance-user-arn': [appInstanceUserArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/channels/${Uri.encodeComponent(channelArn)}?scope=app-instance-user-moderated-channel',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return DescribeChannelModeratedByAppInstanceUserResponse.fromJson(response);
}