listChannelFlows method
Returns a paginated lists of all the channel flows created under a single Chime. This is a developer API.
May throw BadRequestException.
May throw ForbiddenException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter appInstanceArn :
The ARN of the app instance.
Parameter maxResults :
The maximum number of channel flows that you want to return.
Parameter nextToken :
The token passed by previous API calls until all requested channel flows
are returned.
Implementation
Future<ListChannelFlowsResponse> listChannelFlows({
required String appInstanceArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
'app-instance-arn': [appInstanceArn],
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/channel-flows',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListChannelFlowsResponse.fromJson(response);
}