deleteVoiceConnectorExternalSystemsConfiguration method
Future<void>
deleteVoiceConnectorExternalSystemsConfiguration({
- required String voiceConnectorId,
Deletes the external systems configuration for a Voice Connector.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter voiceConnectorId :
The ID of the Voice Connector for which to delete the external system
configuration.
Implementation
Future<void> deleteVoiceConnectorExternalSystemsConfiguration({
required String voiceConnectorId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/voice-connectors/${Uri.encodeComponent(voiceConnectorId)}/external-systems-configuration',
exceptionFnMap: _exceptionFns,
);
}