getVoiceConnectorExternalSystemsConfiguration method
Future<GetVoiceConnectorExternalSystemsConfigurationResponse>
getVoiceConnectorExternalSystemsConfiguration({
- required String voiceConnectorId,
Gets information about an external systems configuration for a Voice Connector.
May throw BadRequestException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter voiceConnectorId :
The ID of the Voice Connector for which to return information about the
external system configuration.
Implementation
Future<GetVoiceConnectorExternalSystemsConfigurationResponse>
getVoiceConnectorExternalSystemsConfiguration({
required String voiceConnectorId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/voice-connectors/${Uri.encodeComponent(voiceConnectorId)}/external-systems-configuration',
exceptionFnMap: _exceptionFns,
);
return GetVoiceConnectorExternalSystemsConfigurationResponse.fromJson(
response);
}