putVoiceConnectorExternalSystemsConfiguration method
Future<PutVoiceConnectorExternalSystemsConfigurationResponse>
putVoiceConnectorExternalSystemsConfiguration({})
Adds an external systems configuration to a Voice Connector.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw NotFoundException.
May throw ServiceFailureException.
May throw ServiceUnavailableException.
May throw ThrottledClientException.
May throw UnauthorizedClientException.
Parameter voiceConnectorId :
The ID of the Voice Connector for which to add the external system
configuration.
Parameter contactCenterSystemTypes :
The contact center system to use.
Parameter sessionBorderControllerTypes :
The session border controllers to use.
Implementation
Future<PutVoiceConnectorExternalSystemsConfigurationResponse>
putVoiceConnectorExternalSystemsConfiguration({
required String voiceConnectorId,
List<ContactCenterSystemType>? contactCenterSystemTypes,
List<SessionBorderControllerType>? sessionBorderControllerTypes,
}) async {
final $payload = <String, dynamic>{
if (contactCenterSystemTypes != null)
'ContactCenterSystemTypes':
contactCenterSystemTypes.map((e) => e.value).toList(),
if (sessionBorderControllerTypes != null)
'SessionBorderControllerTypes':
sessionBorderControllerTypes.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/voice-connectors/${Uri.encodeComponent(voiceConnectorId)}/external-systems-configuration',
exceptionFnMap: _exceptionFns,
);
return PutVoiceConnectorExternalSystemsConfigurationResponse.fromJson(
response);
}