createCollaboration method
- required String creatorDisplayName,
- required List<
MemberAbility> creatorMemberAbilities, - required String description,
- required List<
MemberSpecification> members, - required String name,
- required CollaborationQueryLogStatus queryLogStatus,
- List<
SupportedS3Region> ? allowedResultRegions, - AnalyticsEngine? analyticsEngine,
- List<
AutoApprovedChangeType> ? autoApprovedChangeRequestTypes, - MLMemberAbilities? creatorMLMemberAbilities,
- PaymentConfiguration? creatorPaymentConfiguration,
- DataEncryptionMetadata? dataEncryptionMetadata,
- bool? isMetricsEnabled,
- CollaborationJobLogStatus? jobLogStatus,
- Map<
String, String> ? tags,
Creates a new collaboration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter creatorDisplayName :
The display name of the collaboration creator.
Parameter creatorMemberAbilities :
The abilities granted to the collaboration creator.
Parameter description :
A description of the collaboration provided by the collaboration owner.
Parameter members :
A list of initial members, not including the creator. This list is
immutable.
Parameter name :
The display name for a collaboration.
Parameter queryLogStatus :
An indicator as to whether query logging has been enabled or disabled for
the collaboration.
When ENABLED, Clean Rooms logs details about queries run
within this collaboration and those logs can be viewed in Amazon
CloudWatch Logs. The default value is DISABLED.
Parameter allowedResultRegions :
The Amazon Web Services Regions where collaboration query results can be
stored. When specified, results can only be written to these Regions. This
parameter enables you to meet your compliance and data governance
requirements, and implement regional data governance policies.
Parameter analyticsEngine :
The analytics engine.
Parameter autoApprovedChangeRequestTypes :
The types of change requests that are automatically approved for this
collaboration.
Parameter creatorMLMemberAbilities :
The ML abilities granted to the collaboration creator.
Parameter creatorPaymentConfiguration :
The collaboration creator's payment responsibilities set by the
collaboration creator.
If the collaboration creator hasn't specified anyone as the member paying for query compute costs, then the member who can query is the default payer.
Parameter dataEncryptionMetadata :
The settings for client-side encryption with Cryptographic Computing for
Clean Rooms.
Parameter isMetricsEnabled :
An indicator as to whether metrics have been enabled or disabled for the
collaboration.
When true, collaboration members can opt in to Amazon
CloudWatch metrics for their membership queries. The default value is
false.
Parameter jobLogStatus :
Specifies whether job logs are enabled for this collaboration.
When ENABLED, Clean Rooms logs details about jobs run within
this collaboration; those logs can be viewed in Amazon CloudWatch Logs.
The default value is DISABLED.
Parameter tags :
An optional label that you can assign to a resource when you create it.
Each tag consists of a key and an optional value, both of which you
define. When you use tagging, you can also use tag-based access control in
IAM policies to control access to this resource.
Implementation
Future<CreateCollaborationOutput> createCollaboration({
required String creatorDisplayName,
required List<MemberAbility> creatorMemberAbilities,
required String description,
required List<MemberSpecification> members,
required String name,
required CollaborationQueryLogStatus queryLogStatus,
List<SupportedS3Region>? allowedResultRegions,
AnalyticsEngine? analyticsEngine,
List<AutoApprovedChangeType>? autoApprovedChangeRequestTypes,
MLMemberAbilities? creatorMLMemberAbilities,
PaymentConfiguration? creatorPaymentConfiguration,
DataEncryptionMetadata? dataEncryptionMetadata,
bool? isMetricsEnabled,
CollaborationJobLogStatus? jobLogStatus,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'creatorDisplayName': creatorDisplayName,
'creatorMemberAbilities':
creatorMemberAbilities.map((e) => e.value).toList(),
'description': description,
'members': members,
'name': name,
'queryLogStatus': queryLogStatus.value,
if (allowedResultRegions != null)
'allowedResultRegions':
allowedResultRegions.map((e) => e.value).toList(),
if (analyticsEngine != null) 'analyticsEngine': analyticsEngine.value,
if (autoApprovedChangeRequestTypes != null)
'autoApprovedChangeRequestTypes':
autoApprovedChangeRequestTypes.map((e) => e.value).toList(),
if (creatorMLMemberAbilities != null)
'creatorMLMemberAbilities': creatorMLMemberAbilities,
if (creatorPaymentConfiguration != null)
'creatorPaymentConfiguration': creatorPaymentConfiguration,
if (dataEncryptionMetadata != null)
'dataEncryptionMetadata': dataEncryptionMetadata,
if (isMetricsEnabled != null) 'isMetricsEnabled': isMetricsEnabled,
if (jobLogStatus != null) 'jobLogStatus': jobLogStatus.value,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/collaborations',
exceptionFnMap: _exceptionFns,
);
return CreateCollaborationOutput.fromJson(response);
}