createCollaborationChangeRequest method
Creates a new change request to modify an existing collaboration. This enables post-creation modifications to collaborations through a structured API-driven approach.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter changes :
The list of changes to apply to the collaboration. Each change specifies
the type of modification and the details of what should be changed.
Parameter collaborationIdentifier :
The identifier of the collaboration that the change request is made
against.
Implementation
Future<CreateCollaborationChangeRequestOutput>
createCollaborationChangeRequest({
required List<ChangeInput> changes,
required String collaborationIdentifier,
}) async {
final $payload = <String, dynamic>{
'changes': changes,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/changeRequests',
exceptionFnMap: _exceptionFns,
);
return CreateCollaborationChangeRequestOutput.fromJson(response);
}