createIdNamespaceAssociation method
Creates an ID namespace association.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter inputReferenceConfig :
The input reference configuration needed to create the ID namespace
association.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the ID namespace
association.
Parameter name :
The name for the ID namespace association.
Parameter description :
The description of the ID namespace association.
Parameter idMappingConfig :
The configuration settings for the ID mapping table.
Parameter tags :
An optional label that you can assign to a resource when you create it.
Each tag consists of a key and an optional value, both of which you
define. When you use tagging, you can also use tag-based access control in
IAM policies to control access to this resource.
Implementation
Future<CreateIdNamespaceAssociationOutput> createIdNamespaceAssociation({
required IdNamespaceAssociationInputReferenceConfig inputReferenceConfig,
required String membershipIdentifier,
required String name,
String? description,
IdMappingConfig? idMappingConfig,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'inputReferenceConfig': inputReferenceConfig,
'name': name,
if (description != null) 'description': description,
if (idMappingConfig != null) 'idMappingConfig': idMappingConfig,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/idnamespaceassociations',
exceptionFnMap: _exceptionFns,
);
return CreateIdNamespaceAssociationOutput.fromJson(response);
}