deleteConfiguredTableAnalysisRule method
Future<void>
deleteConfiguredTableAnalysisRule({
- required ConfiguredTableAnalysisRuleType analysisRuleType,
- required String configuredTableIdentifier,
Deletes a configured table analysis rule.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analysisRuleType :
The analysis rule type to be deleted. Configured table analysis rules are
uniquely identified by their configured table identifier and analysis rule
type.
Parameter configuredTableIdentifier :
The unique identifier for the configured table that the analysis rule
applies to. Currently accepts the configured table ID.
Implementation
Future<void> deleteConfiguredTableAnalysisRule({
required ConfiguredTableAnalysisRuleType analysisRuleType,
required String configuredTableIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/configuredTables/${Uri.encodeComponent(configuredTableIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
exceptionFnMap: _exceptionFns,
);
}