getConfiguredTableAnalysisRule method
Future<GetConfiguredTableAnalysisRuleOutput>
getConfiguredTableAnalysisRule({
- required ConfiguredTableAnalysisRuleType analysisRuleType,
- required String configuredTableIdentifier,
Retrieves a configured table analysis rule.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analysisRuleType :
The analysis rule to be retrieved. Configured table analysis rules are
uniquely identified by their configured table identifier and analysis rule
type.
Parameter configuredTableIdentifier :
The unique identifier for the configured table to retrieve. Currently
accepts the configured table ID.
Implementation
Future<GetConfiguredTableAnalysisRuleOutput> getConfiguredTableAnalysisRule({
required ConfiguredTableAnalysisRuleType analysisRuleType,
required String configuredTableIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/configuredTables/${Uri.encodeComponent(configuredTableIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
exceptionFnMap: _exceptionFns,
);
return GetConfiguredTableAnalysisRuleOutput.fromJson(response);
}