getConfiguredTableAssociationAnalysisRule method
Future<GetConfiguredTableAssociationAnalysisRuleOutput>
getConfiguredTableAssociationAnalysisRule({})
Retrieves the analysis rule for a configured table association.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analysisRuleType :
The type of analysis rule that you want to retrieve.
Parameter configuredTableAssociationIdentifier :
The identifier for the configured table association that's related to the
analysis rule.
Parameter membershipIdentifier :
A unique identifier for the membership that the configured table
association belongs to. Currently accepts the membership ID.
Implementation
Future<GetConfiguredTableAssociationAnalysisRuleOutput>
getConfiguredTableAssociationAnalysisRule({
required ConfiguredTableAssociationAnalysisRuleType analysisRuleType,
required String configuredTableAssociationIdentifier,
required String membershipIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredTableAssociations/${Uri.encodeComponent(configuredTableAssociationIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
exceptionFnMap: _exceptionFns,
);
return GetConfiguredTableAssociationAnalysisRuleOutput.fromJson(response);
}