getIntermediateTableAnalysisRule method
Retrieves the analysis rule for an intermediate table.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter analysisRuleType :
The type of analysis rule to retrieve. Currently, only CUSTOM
is supported.
Parameter intermediateTableIdentifier :
The unique identifier of the intermediate table for which to retrieve the
analysis rule.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the intermediate
table.
Implementation
Future<GetIntermediateTableAnalysisRuleOutput>
getIntermediateTableAnalysisRule({
required IntermediateTableAnalysisRuleType analysisRuleType,
required String intermediateTableIdentifier,
required String membershipIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}/analysisRule/${Uri.encodeComponent(analysisRuleType.value)}',
exceptionFnMap: _exceptionFns,
);
return GetIntermediateTableAnalysisRuleOutput.fromJson(response);
}