getSchemaAnalysisRule method
Retrieves a schema analysis rule.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
A unique identifier for the collaboration that the schema belongs to.
Currently accepts a collaboration ID.
Parameter name :
The name of the schema to retrieve the analysis rule for.
Parameter type :
The type of the schema analysis rule to retrieve. Schema analysis rules
are uniquely identified by a combination of the collaboration, the schema
name, and their type.
Implementation
Future<GetSchemaAnalysisRuleOutput> getSchemaAnalysisRule({
required String collaborationIdentifier,
required String name,
required AnalysisRuleType type,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/schemas/${Uri.encodeComponent(name)}/analysisRule/${Uri.encodeComponent(type.value)}',
exceptionFnMap: _exceptionFns,
);
return GetSchemaAnalysisRuleOutput.fromJson(response);
}