listCollaborationChangeRequests method
Lists all change requests for a collaboration with pagination support. Returns change requests sorted by creation time.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
The identifier of the collaboration that the change request is made
against.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Parameter status :
A filter to only return change requests with the specified status.
Implementation
Future<ListCollaborationChangeRequestsOutput>
listCollaborationChangeRequests({
required String collaborationIdentifier,
int? maxResults,
String? nextToken,
ChangeRequestStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/changeRequests',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCollaborationChangeRequestsOutput.fromJson(response);
}