listCollaborations method
Lists collaborations the caller owns, is active in, or has been invited to.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
The service chooses a default number if you don't set one. The service
might return a nextToken even if the maxResults value has not been
met.
Parameter memberStatus :
The caller's status in a collaboration.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListCollaborationsOutput> listCollaborations({
int? maxResults,
FilterableMemberStatus? memberStatus,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (memberStatus != null) 'memberStatus': [memberStatus.value],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/collaborations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCollaborationsOutput.fromJson(response);
}