listConfiguredTables method
Lists configured tables.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
The service chooses a default number if you don't set one. The service
might return a nextToken even if the maxResults value has not been
met.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListConfiguredTablesOutput> listConfiguredTables({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/configuredTables',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListConfiguredTablesOutput.fromJson(response);
}