listIntermediateTableVersions method
Lists the version history of an intermediate table. Each call to
PopulateIntermediateTable creates a new version. We recommend
using pagination to ensure that the operation returns quickly and
successfully.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter intermediateTableIdentifier :
The unique identifier of the intermediate table for which to list
versions.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the intermediate
table.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
The service chooses a default number if you don't set one. The service
might return a nextToken even if the maxResults
value has not been met.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListIntermediateTableVersionsOutput> listIntermediateTableVersions({
required String intermediateTableIdentifier,
required String membershipIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}/versions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListIntermediateTableVersionsOutput.fromJson(response);
}