listProtectedJobs method
Lists protected jobs, sorted by most recent job.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The identifier for the membership in the collaboration.
Parameter maxResults :
The maximum number of results that are returned for an API request call.
The service chooses a default number if you don't set one. The service
might return a nextToken even if the maxResults value has not been
met.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Parameter status :
A filter on the status of the protected job.
Implementation
Future<ListProtectedJobsOutput> listProtectedJobs({
required String membershipIdentifier,
int? maxResults,
String? nextToken,
ProtectedJobStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/protectedJobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListProtectedJobsOutput.fromJson(response);
}