untagResource method
Removes a tag or list of tags from a resource.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) associated with the resource you want to
remove the tag from.
Parameter tagKeys :
A list of key names of tags to be removed.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}