updateConfiguredTableAssociation method
Updates a configured table association.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter configuredTableAssociationIdentifier :
The unique identifier for the configured table association to update.
Currently accepts the configured table association ID.
Parameter membershipIdentifier :
The unique ID for the membership that the configured table association
belongs to.
Parameter description :
A new description for the configured table association.
Parameter roleArn :
The service will assume this role to access catalog metadata and query the
table.
Implementation
Future<UpdateConfiguredTableAssociationOutput>
updateConfiguredTableAssociation({
required String configuredTableAssociationIdentifier,
required String membershipIdentifier,
String? description,
String? roleArn,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (roleArn != null) 'roleArn': roleArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configuredTableAssociations/${Uri.encodeComponent(configuredTableAssociationIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateConfiguredTableAssociationOutput.fromJson(response);
}