updateIdMappingTable method
Provides the details that are necessary to update an ID mapping table.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter idMappingTableIdentifier :
The unique identifier of the ID mapping table that you want to update.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the ID mapping table
that you want to update.
Parameter description :
A new description for the ID mapping table.
Parameter kmsKeyArn :
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key.
Implementation
Future<UpdateIdMappingTableOutput> updateIdMappingTable({
required String idMappingTableIdentifier,
required String membershipIdentifier,
String? description,
String? kmsKeyArn,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (kmsKeyArn != null) 'kmsKeyArn': kmsKeyArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/idmappingtables/${Uri.encodeComponent(idMappingTableIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateIdMappingTableOutput.fromJson(response);
}