updateIntermediateTable method
Updates an intermediate table. You can update the description, KMS key ARN, and column types of existing columns. Only the intermediate table owner can call this operation.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter intermediateTableIdentifier :
The unique identifier of the intermediate table to update.
Parameter membershipIdentifier :
The unique identifier of the membership that contains the intermediate
table.
Parameter columns :
The list of columns with updated type definitions. Only the type of
existing columns can be updated.
Parameter description :
A new description for the intermediate table.
Parameter kmsKeyArn :
The Amazon Resource Name (ARN) of the customer-managed KMS key to use for
encrypting future population data.
Implementation
Future<UpdateIntermediateTableOutput> updateIntermediateTable({
required String intermediateTableIdentifier,
required String membershipIdentifier,
List<IntermediateTableColumn>? columns,
String? description,
String? kmsKeyArn,
}) async {
final $payload = <String, dynamic>{
if (columns != null) 'columns': columns,
if (description != null) 'description': description,
if (kmsKeyArn != null) 'kmsKeyArn': kmsKeyArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/intermediateTables/${Uri.encodeComponent(intermediateTableIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateIntermediateTableOutput.fromJson(response);
}