cancelTrainedModelInferenceJob method
Submits a request to cancel a trained model inference job.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The membership ID of the trained model inference job that you want to
cancel.
Parameter trainedModelInferenceJobArn :
The Amazon Resource Name (ARN) of the trained model inference job that you
want to cancel.
Implementation
Future<void> cancelTrainedModelInferenceJob({
required String membershipIdentifier,
required String trainedModelInferenceJobArn,
}) async {
await _protocol.send(
payload: null,
method: 'PATCH',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-model-inference-jobs/${Uri.encodeComponent(trainedModelInferenceJobArn)}',
exceptionFnMap: _exceptionFns,
);
}