createConfiguredModelAlgorithm method
Creates a configured model algorithm using a container image stored in an ECR repository.
May throw AccessDeniedException.
May throw ConflictException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter name :
The name of the configured model algorithm.
Parameter roleArn :
The Amazon Resource Name (ARN) of the role that is used to access the
repository.
Parameter description :
The description of the configured model algorithm.
Parameter inferenceContainerConfig :
Configuration information for the inference container that is used when
you run an inference job on a configured model algorithm.
Parameter kmsKeyArn :
The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt
and decrypt customer-owned data in the configured ML model algorithm and
associated data.
Parameter tags :
The optional metadata that you apply to the resource to help you
categorize and organize them. Each tag consists of a key and an optional
value, both of which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50.
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8.
- Maximum value length - 256 Unicode characters in UTF-8.
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case sensitive.
- Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.
Parameter trainingContainerConfig :
Configuration information for the training container, including
entrypoints and arguments.
Implementation
Future<CreateConfiguredModelAlgorithmResponse>
createConfiguredModelAlgorithm({
required String name,
required String roleArn,
String? description,
InferenceContainerConfig? inferenceContainerConfig,
String? kmsKeyArn,
Map<String, String>? tags,
ContainerConfig? trainingContainerConfig,
}) async {
final $payload = <String, dynamic>{
'name': name,
'roleArn': roleArn,
if (description != null) 'description': description,
if (inferenceContainerConfig != null)
'inferenceContainerConfig': inferenceContainerConfig,
if (kmsKeyArn != null) 'kmsKeyArn': kmsKeyArn,
if (tags != null) 'tags': tags,
if (trainingContainerConfig != null)
'trainingContainerConfig': trainingContainerConfig,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/configured-model-algorithms',
exceptionFnMap: _exceptionFns,
);
return CreateConfiguredModelAlgorithmResponse.fromJson(response);
}