createConfiguredModelAlgorithmAssociation method
Associates a configured model algorithm to a collaboration for use by any member of the collaboration.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter configuredModelAlgorithmArn :
The Amazon Resource Name (ARN) of the configured model algorithm that you
want to associate.
Parameter membershipIdentifier :
The membership ID of the member who is associating this configured model
algorithm.
Parameter name :
The name of the configured model algorithm association.
Parameter description :
The description of the configured model algorithm association.
Parameter privacyConfiguration :
Specifies the privacy configuration information for the configured model
algorithm association. This information includes the maximum data size
that can be exported.
Parameter tags :
The optional metadata that you apply to the resource to help you
categorize and organize them. Each tag consists of a key and an optional
value, both of which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50.
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8.
- Maximum value length - 256 Unicode characters in UTF-8.
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case sensitive.
- Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.
Implementation
Future<CreateConfiguredModelAlgorithmAssociationResponse>
createConfiguredModelAlgorithmAssociation({
required String configuredModelAlgorithmArn,
required String membershipIdentifier,
required String name,
String? description,
PrivacyConfiguration? privacyConfiguration,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'configuredModelAlgorithmArn': configuredModelAlgorithmArn,
'name': name,
if (description != null) 'description': description,
if (privacyConfiguration != null)
'privacyConfiguration': privacyConfiguration,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configured-model-algorithm-associations',
exceptionFnMap: _exceptionFns,
);
return CreateConfiguredModelAlgorithmAssociationResponse.fromJson(response);
}