getCollaborationConfiguredModelAlgorithmAssociation method
Future<GetCollaborationConfiguredModelAlgorithmAssociationResponse>
getCollaborationConfiguredModelAlgorithmAssociation({})
Returns information about the configured model algorithm association in a collaboration.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
The collaboration ID for the collaboration that contains the configured
model algorithm association that you want to return information about.
Parameter configuredModelAlgorithmAssociationArn :
The Amazon Resource Name (ARN) of the configured model algorithm
association that you want to return information about.
Implementation
Future<GetCollaborationConfiguredModelAlgorithmAssociationResponse>
getCollaborationConfiguredModelAlgorithmAssociation({
required String collaborationIdentifier,
required String configuredModelAlgorithmAssociationArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/configured-model-algorithm-associations/${Uri.encodeComponent(configuredModelAlgorithmAssociationArn)}',
exceptionFnMap: _exceptionFns,
);
return GetCollaborationConfiguredModelAlgorithmAssociationResponse.fromJson(
response);
}