getTrainedModel method
Returns information about a trained model.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The membership ID of the member that created the trained model that you
are interested in.
Parameter trainedModelArn :
The Amazon Resource Name (ARN) of the trained model that you are
interested in.
Parameter versionIdentifier :
The version identifier of the trained model to retrieve. If not specified,
the operation returns information about the latest version of the trained
model.
Implementation
Future<GetTrainedModelResponse> getTrainedModel({
required String membershipIdentifier,
required String trainedModelArn,
String? versionIdentifier,
}) async {
final $query = <String, List<String>>{
if (versionIdentifier != null) 'versionIdentifier': [versionIdentifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-models/${Uri.encodeComponent(trainedModelArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetTrainedModelResponse.fromJson(response);
}