listCollaborationTrainedModelInferenceJobs method
Returns a list of trained model inference jobs in a specified collaboration.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter collaborationIdentifier :
The collaboration ID of the collaboration that contains the trained model
inference jobs that you are interested in.
Parameter maxResults :
The maximum size of the results that is returned per call.
Parameter nextToken :
The token value retrieved from a previous call to access the next page of
results.
Parameter trainedModelArn :
The Amazon Resource Name (ARN) of the trained model that was used to
create the trained model inference jobs that you are interested in.
Parameter trainedModelVersionIdentifier :
The version identifier of the trained model to filter inference jobs by.
When specified, only inference jobs that used this specific version of the
trained model are returned.
Implementation
Future<ListCollaborationTrainedModelInferenceJobsResponse>
listCollaborationTrainedModelInferenceJobs({
required String collaborationIdentifier,
int? maxResults,
String? nextToken,
String? trainedModelArn,
String? trainedModelVersionIdentifier,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (trainedModelArn != null) 'trainedModelArn': [trainedModelArn],
if (trainedModelVersionIdentifier != null)
'trainedModelVersionIdentifier': [trainedModelVersionIdentifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/collaborations/${Uri.encodeComponent(collaborationIdentifier)}/trained-model-inference-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCollaborationTrainedModelInferenceJobsResponse.fromJson(
response);
}