listConfiguredModelAlgorithmAssociations method
Future<ListConfiguredModelAlgorithmAssociationsResponse>
listConfiguredModelAlgorithmAssociations({})
Returns a list of configured model algorithm associations.
May throw AccessDeniedException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The membership ID of the member that created the configured model
algorithm associations you are interested in.
Parameter maxResults :
The maximum size of the results that is returned per call.
Parameter nextToken :
The token value retrieved from a previous call to access the next page of
results.
Implementation
Future<ListConfiguredModelAlgorithmAssociationsResponse>
listConfiguredModelAlgorithmAssociations({
required String membershipIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/configured-model-algorithm-associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListConfiguredModelAlgorithmAssociationsResponse.fromJson(response);
}