startTrainedModelExportJob method
Provides the information necessary to start a trained model export job.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter membershipIdentifier :
The membership ID of the member that is receiving the exported trained
model artifacts.
Parameter name :
The name of the trained model export job.
Parameter outputConfiguration :
The output configuration information for the trained model export job.
Parameter trainedModelArn :
The Amazon Resource Name (ARN) of the trained model that you want to
export.
Parameter description :
The description of the trained model export job.
Parameter trainedModelVersionIdentifier :
The version identifier of the trained model to export. This specifies
which version of the trained model should be exported to the specified
destination.
Implementation
Future<void> startTrainedModelExportJob({
required String membershipIdentifier,
required String name,
required TrainedModelExportOutputConfiguration outputConfiguration,
required String trainedModelArn,
String? description,
String? trainedModelVersionIdentifier,
}) async {
final $payload = <String, dynamic>{
'name': name,
'outputConfiguration': outputConfiguration,
if (description != null) 'description': description,
if (trainedModelVersionIdentifier != null)
'trainedModelVersionIdentifier': trainedModelVersionIdentifier,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/memberships/${Uri.encodeComponent(membershipIdentifier)}/trained-models/${Uri.encodeComponent(trainedModelArn)}/export-jobs',
exceptionFnMap: _exceptionFns,
);
}