CloudControl class
For more information about Amazon Web Services Cloud Control API, see the Amazon Web Services Cloud Control API User Guide.
Constructors
- CloudControl({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelResourceRequest(
{required String requestToken}) → Future< CancelResourceRequestOutput> - Cancels the specified resource operation request. For more information, see Canceling resource operation requests in the Amazon Web Services Cloud Control API User Guide.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createResource(
{required String desiredState, required String typeName, String? clientToken, String? roleArn, String? typeVersionId}) → Future< CreateResourceOutput> - Creates the specified resource. For more information, see Creating a resource in the Amazon Web Services Cloud Control API User Guide.
-
deleteResource(
{required String identifier, required String typeName, String? clientToken, String? roleArn, String? typeVersionId}) → Future< DeleteResourceOutput> - Deletes the specified resource. For details, see Deleting a resource in the Amazon Web Services Cloud Control API User Guide.
-
getResource(
{required String identifier, required String typeName, String? roleArn, String? typeVersionId}) → Future< GetResourceOutput> - Returns information about the current state of the specified resource. For details, see Reading a resource's current state.
-
getResourceRequestStatus(
{required String requestToken}) → Future< GetResourceRequestStatusOutput> - Returns the current status of a resource operation request. For more information, see Tracking the progress of resource operation requests in the Amazon Web Services Cloud Control API User Guide.
-
listResourceRequests(
{int? maxResults, String? nextToken, ResourceRequestStatusFilter? resourceRequestStatusFilter}) → Future< ListResourceRequestsOutput> - Returns existing resource operation requests. This includes requests of all status types. For more information, see Listing active resource operation requests in the Amazon Web Services Cloud Control API User Guide.
-
listResources(
{required String typeName, int? maxResults, String? nextToken, String? resourceModel, String? roleArn, String? typeVersionId}) → Future< ListResourcesOutput> - Returns information about the specified resources. For more information, see Discovering resources in the Amazon Web Services Cloud Control API User Guide.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateResource(
{required String identifier, required String patchDocument, required String typeName, String? clientToken, String? roleArn, String? typeVersionId}) → Future< UpdateResourceOutput> - Updates the specified property values in the resource.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited