continueUpdateRollback method
Continues rolling back a stack from UPDATE_ROLLBACK_FAILED to
UPDATE_ROLLBACK_COMPLETE state. Depending on the cause of the
failure, you can manually fix the error and continue the rollback. By
continuing the rollback, you can return your stack to a working state (the
UPDATE_ROLLBACK_COMPLETE state) and then try to update the
stack again.
A stack enters the UPDATE_ROLLBACK_FAILED state when
CloudFormation can't roll back all changes after a failed stack update.
For example, this might occur when a stack attempts to roll back to an old
database that was deleted outside of CloudFormation. Because
CloudFormation doesn't know the instance was deleted, it assumes the
instance still exists and attempts to roll back to it, causing the update
rollback to fail.
For more information, see Continue rolling back an update in the CloudFormation User Guide. For information for troubleshooting a failed update rollback, see Update rollback failed.
May throw TokenAlreadyExistsException.
Parameter stackName :
The name or the unique ID of the stack that you want to continue rolling
back.
Parameter clientRequestToken :
A unique identifier for this ContinueUpdateRollback request.
Specify this token if you plan to retry requests so that CloudFormation
knows that you're not attempting to continue the rollback to a stack with
the same name. You might retry ContinueUpdateRollback
requests to ensure that CloudFormation successfully received them.
Parameter resourcesToSkip :
A list of the logical IDs of the resources that CloudFormation skips
during the continue update rollback operation. You can specify only
resources that are in the UPDATE_FAILED state because a
rollback failed. You can't specify resources that are in the
UPDATE_FAILED state for other reasons, for example, because
an update was canceled. To check why a resource update failed, use the
DescribeStackResources action, and view the resource status reason.
Specify the minimum number of resources required to successfully roll back
your stack. For example, a failed resource update might cause dependent
resources to fail. In this case, it might not be necessary to skip the
dependent resources.
To skip resources that are part of nested stacks, use the following
format: NestedStackName.ResourceLogicalID. If you want to
specify the logical ID of a stack resource (Type:
AWS::CloudFormation::Stack) in the ResourcesToSkip
list, then its corresponding embedded stack must be in one of the
following states: DELETE_IN_PROGRESS,
DELETE_COMPLETE, or DELETE_FAILED.
Parameter roleARN :
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes
to roll back the stack. CloudFormation uses the role's credentials to make
calls on your behalf. CloudFormation always uses this role for all future
operations on the stack. Provided that users have permission to operate on
the stack, CloudFormation uses this role even if the users don't have
permission to pass it. Ensure that the role grants least permission.
If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that's generated from your user credentials.
Implementation
Future<void> continueUpdateRollback({
required String stackName,
String? clientRequestToken,
List<String>? resourcesToSkip,
String? roleARN,
}) async {
final $request = <String, String>{
'StackName': stackName,
if (clientRequestToken != null) 'ClientRequestToken': clientRequestToken,
if (resourcesToSkip != null)
if (resourcesToSkip.isEmpty)
'ResourcesToSkip': ''
else
for (var i1 = 0; i1 < resourcesToSkip.length; i1++)
'ResourcesToSkip.member.${i1 + 1}': resourcesToSkip[i1],
if (roleARN != null) 'RoleARN': roleARN,
};
await _protocol.send(
$request,
action: 'ContinueUpdateRollback',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ContinueUpdateRollbackResult',
);
}