describeAccountLimits method
Retrieves your account's CloudFormation limits, such as the maximum number of stacks that you can create in your account. For more information about account limits, see Understand CloudFormation quotas in the CloudFormation User Guide.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<DescribeAccountLimitsOutput> describeAccountLimits({
String? nextToken,
}) async {
final $request = <String, String>{
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'DescribeAccountLimits',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeAccountLimitsResult',
);
return DescribeAccountLimitsOutput.fromXml($result);
}