describeChangeSetHooks method
Returns Hook-related information for the change set and a list of changes that CloudFormation makes when you run the change set.
May throw ChangeSetNotFoundException.
Parameter changeSetName :
The name or Amazon Resource Name (ARN) of the change set that you want to
describe.
Parameter logicalResourceId :
If specified, lists only the Hooks related to the specified
LogicalResourceId.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Parameter stackName :
If you specified the name of a change set, specify the stack name or stack
ID (ARN) of the change set you want to describe.
Implementation
Future<DescribeChangeSetHooksOutput> describeChangeSetHooks({
required String changeSetName,
String? logicalResourceId,
String? nextToken,
String? stackName,
}) async {
final $request = <String, String>{
'ChangeSetName': changeSetName,
if (logicalResourceId != null) 'LogicalResourceId': logicalResourceId,
if (nextToken != null) 'NextToken': nextToken,
if (stackName != null) 'StackName': stackName,
};
final $result = await _protocol.send(
$request,
action: 'DescribeChangeSetHooks',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeChangeSetHooksResult',
);
return DescribeChangeSetHooksOutput.fromXml($result);
}