describeStackInstance method
Returns the stack instance that's associated with the specified StackSet, Amazon Web Services account, and Amazon Web Services Region.
For a list of stack instances that are associated with a specific StackSet, use ListStackInstances.
May throw StackInstanceNotFoundException.
May throw StackSetNotFoundException.
Parameter stackInstanceAccount :
The ID of an Amazon Web Services account that's associated with this stack
instance.
Parameter stackInstanceRegion :
The name of a Region that's associated with this stack instance.
Parameter stackSetName :
The name or the unique stack ID of the StackSet that you want to get stack
instance information for.
Parameter callAs :
[Service-managed permissions] Specifies whether you are acting as an
account administrator in the organization's management account or as a
delegated administrator in a member account.
By default, SELF is specified. Use SELF for
StackSets with self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
Implementation
Future<DescribeStackInstanceOutput> describeStackInstance({
required String stackInstanceAccount,
required String stackInstanceRegion,
required String stackSetName,
CallAs? callAs,
}) async {
final $request = <String, String>{
'StackInstanceAccount': stackInstanceAccount,
'StackInstanceRegion': stackInstanceRegion,
'StackSetName': stackSetName,
if (callAs != null) 'CallAs': callAs.value,
};
final $result = await _protocol.send(
$request,
action: 'DescribeStackInstance',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeStackInstanceResult',
);
return DescribeStackInstanceOutput.fromXml($result);
}