describeStackResource method
Returns a description of the specified resource in the specified stack.
For deleted stacks, DescribeStackResource returns resource information for up to 90 days after the stack has been deleted.
Parameter logicalResourceId :
The logical name of the resource as specified in the template.
Parameter stackName :
The name or the unique stack ID that's associated with the stack, which
aren't always interchangeable:
- Running stacks: You can specify either the stack's name or its unique stack ID.
- Deleted stacks: You must specify the unique stack ID.
Implementation
Future<DescribeStackResourceOutput> describeStackResource({
required String logicalResourceId,
required String stackName,
}) async {
final $request = <String, String>{
'LogicalResourceId': logicalResourceId,
'StackName': stackName,
};
final $result = await _protocol.send(
$request,
action: 'DescribeStackResource',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeStackResourceResult',
);
return DescribeStackResourceOutput.fromXml($result);
}