describeStackSetOperation method
Returns the description of the specified StackSet operation.
May throw OperationNotFoundException.
May throw StackSetNotFoundException.
Parameter operationId :
The unique ID of the StackSet operation.
Parameter stackSetName :
The name or the unique stack ID of the StackSet for the stack operation.
Parameter callAs :
[Service-managed permissions] Specifies whether you are acting as an
account administrator in the organization's management account or as a
delegated administrator in a member account.
By default, SELF is specified. Use SELF for
StackSets with self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
Implementation
Future<DescribeStackSetOperationOutput> describeStackSetOperation({
required String operationId,
required String stackSetName,
CallAs? callAs,
}) async {
final $request = <String, String>{
'OperationId': operationId,
'StackSetName': stackSetName,
if (callAs != null) 'CallAs': callAs.value,
};
final $result = await _protocol.send(
$request,
action: 'DescribeStackSetOperation',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeStackSetOperationResult',
);
return DescribeStackSetOperationOutput.fromXml($result);
}