listChangeSets method
Returns the ID and status of each active change set for a stack. For
example, CloudFormation lists change sets that are in the
CREATE_IN_PROGRESS or CREATE_PENDING state.
Parameter stackName :
The name or the Amazon Resource Name (ARN) of the stack for which you want
to list change sets.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<ListChangeSetsOutput> listChangeSets({
required String stackName,
String? nextToken,
}) async {
final $request = <String, String>{
'StackName': stackName,
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListChangeSets',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListChangeSetsResult',
);
return ListChangeSetsOutput.fromXml($result);
}