listGeneratedTemplates method
Lists your generated templates in this Region.
Parameter maxResults :
If the number of available results exceeds this maximum, the response
includes a NextToken value that you can use for the
NextToken parameter to get the next set of results. By
default the ListGeneratedTemplates API action will return at
most 50 results in each response. The maximum value is 100.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<ListGeneratedTemplatesOutput> listGeneratedTemplates({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $request = <String, String>{
if (maxResults != null) 'MaxResults': maxResults.toString(),
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListGeneratedTemplates',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListGeneratedTemplatesResult',
);
return ListGeneratedTemplatesOutput.fromXml($result);
}