listImports method
Lists all stacks that are importing an exported output value. To modify or remove an exported output value, first use this action to see which stacks are using it. To see the exported output values in your account, see ListExports.
For more information about importing an exported output value, see the Fn::ImportValue function.
Parameter exportName :
The name of the exported output value. CloudFormation returns the stack
names that are importing this value.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Implementation
Future<ListImportsOutput> listImports({
required String exportName,
String? nextToken,
}) async {
final $request = <String, String>{
'ExportName': exportName,
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListImports',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListImportsResult',
);
return ListImportsOutput.fromXml($result);
}