listResourceScans method
List the resource scans from newest to oldest. By default it will return up to 10 resource scans.
Parameter maxResults :
If the number of available results exceeds this maximum, the response
includes a NextToken value that you can use for the
NextToken parameter to get the next set of results. The
default value is 10. The maximum value is 100.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Parameter scanTypeFilter :
The scan type that you want to get summary information about. The default
is FULL.
Implementation
Future<ListResourceScansOutput> listResourceScans({
int? maxResults,
String? nextToken,
ScanType? scanTypeFilter,
}) async {
final $request = <String, String>{
if (maxResults != null) 'MaxResults': maxResults.toString(),
if (nextToken != null) 'NextToken': nextToken,
if (scanTypeFilter != null) 'ScanTypeFilter': scanTypeFilter.value,
};
final $result = await _protocol.send(
$request,
action: 'ListResourceScans',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListResourceScansResult',
);
return ListResourceScansOutput.fromXml($result);
}