listStackSetOperationResults method

Future<ListStackSetOperationResultsOutput> listStackSetOperationResults({
  1. required String operationId,
  2. required String stackSetName,
  3. CallAs? callAs,
  4. List<OperationResultFilter>? filters,
  5. int? maxResults,
  6. String? nextToken,
})

Returns summary information about the results of a StackSet operation.

May throw OperationNotFoundException. May throw StackSetNotFoundException.

Parameter operationId : The ID of the StackSet operation.

Parameter stackSetName : The name or unique ID of the StackSet that you want to get operation results for.

Parameter callAs : [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

  • If you are signed in to the management account, specify SELF.
  • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

    Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

Parameter filters : The filter to apply to operation results.

Parameter maxResults : The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.

Parameter nextToken : The token for the next set of items to return. (You received this token from a previous call.)

Implementation

Future<ListStackSetOperationResultsOutput> listStackSetOperationResults({
  required String operationId,
  required String stackSetName,
  CallAs? callAs,
  List<OperationResultFilter>? filters,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    100,
  );
  final $request = <String, String>{
    'OperationId': operationId,
    'StackSetName': stackSetName,
    if (callAs != null) 'CallAs': callAs.value,
    if (filters != null)
      if (filters.isEmpty)
        'Filters': ''
      else
        for (var i1 = 0; i1 < filters.length; i1++)
          for (var e3 in filters[i1].toQueryMap().entries)
            'Filters.member.${i1 + 1}.${e3.key}': e3.value,
    if (maxResults != null) 'MaxResults': maxResults.toString(),
    if (nextToken != null) 'NextToken': nextToken,
  };
  final $result = await _protocol.send(
    $request,
    action: 'ListStackSetOperationResults',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'ListStackSetOperationResultsResult',
  );
  return ListStackSetOperationResultsOutput.fromXml($result);
}