registerPublisher method
Registers your account as a publisher of public extensions in the CloudFormation registry. Public extensions are available for use by all CloudFormation users. This publisher ID applies to your account in all Amazon Web Services Regions.
For information about requirements for registering as a public extension publisher, see Prerequisite: Registering your account to publish CloudFormation extensions in the CloudFormation Command Line Interface (CLI) User Guide.
May throw CFNRegistryException.
Parameter acceptTermsAndConditions :
Whether you accept the Terms
and Conditions for publishing extensions in the CloudFormation
registry. You must accept the terms and conditions in order to register to
publish public extensions to the CloudFormation registry.
The default is false.
Parameter connectionArn :
If you are using a Bitbucket or GitHub account for identity verification,
the Amazon Resource Name (ARN) for your connection to that account.
For more information, see Prerequisite: Registering your account to publish CloudFormation extensions in the CloudFormation Command Line Interface (CLI) User Guide.
Implementation
Future<RegisterPublisherOutput> registerPublisher({
bool? acceptTermsAndConditions,
String? connectionArn,
}) async {
final $request = <String, String>{
if (acceptTermsAndConditions != null)
'AcceptTermsAndConditions': acceptTermsAndConditions.toString(),
if (connectionArn != null) 'ConnectionArn': connectionArn,
};
final $result = await _protocol.send(
$request,
action: 'RegisterPublisher',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RegisterPublisherResult',
);
return RegisterPublisherOutput.fromXml($result);
}