stopStackSetOperation method
Stops an in-progress operation on a StackSet and its associated stack instances. StackSets will cancel all the unstarted stack instance deployments and wait for those are in-progress to complete.
May throw InvalidOperationException.
May throw OperationNotFoundException.
May throw StackSetNotFoundException.
Parameter operationId :
The ID of the stack operation.
Parameter stackSetName :
The name or unique ID of the StackSet that you want to stop the operation
for.
Parameter callAs :
Specifies whether you are acting as an account administrator in the
organization's management account or as a delegated administrator in a
member account. Valid only if the StackSet uses service-managed
permissions.
By default, SELF is specified. Use SELF for
StackSets with self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
Implementation
Future<void> stopStackSetOperation({
required String operationId,
required String stackSetName,
CallAs? callAs,
}) async {
final $request = <String, String>{
'OperationId': operationId,
'StackSetName': stackSetName,
if (callAs != null) 'CallAs': callAs.value,
};
await _protocol.send(
$request,
action: 'StopStackSetOperation',
version: '2010-05-15',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'StopStackSetOperationResult',
);
}