updateStackInstances method

Future<UpdateStackInstancesOutput> updateStackInstances({
  1. required List<String> regions,
  2. required String stackSetName,
  3. List<String>? accounts,
  4. CallAs? callAs,
  5. DeploymentTargets? deploymentTargets,
  6. String? operationId,
  7. StackSetOperationPreferences? operationPreferences,
  8. List<Parameter>? parameterOverrides,
})

Updates the parameter values for stack instances for the specified accounts, within the specified Amazon Web Services Regions. A stack instance refers to a stack in a specific account and Region.

You can only update stack instances in Amazon Web Services Regions and accounts where they already exist; to create additional stack instances, use CreateStackInstances.

During StackSet updates, any parameters overridden for a stack instance aren't updated, but retain their overridden value.

You can only update the parameter values that are specified in the StackSet. To add or delete a parameter itself, use UpdateStackSet to update the StackSet template. If you add a parameter to a template, before you can override the parameter value specified in the StackSet you must first use UpdateStackSet to update all stack instances with the updated template and parameter value specified in the StackSet. Once a stack instance has been updated with the new parameter, you can then override the parameter value using UpdateStackInstances.

If you need more than 50, consider the following options:

  • Batch processing: If you don't want to expose your OU hierarchy, split up the operations into multiple calls with less than 50 OUs each.
  • Parent OU strategy: If you don't mind exposing the OU hierarchy, target a parent OU that contains all desired child OUs.

May throw InvalidOperationException. May throw OperationIdAlreadyExistsException. May throw OperationInProgressException. May throw StackInstanceNotFoundException. May throw StackSetNotFoundException. May throw StaleRequestException.

Parameter regions : The names of one or more Amazon Web Services Regions in which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions.

Parameter stackSetName : The name or unique ID of the StackSet associated with the stack instances.

Parameter accounts : [Self-managed permissions] The account IDs of one or more Amazon Web Services accounts in which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions.

You can specify Accounts or DeploymentTargets, but not both.

Parameter callAs : [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

  • If you are signed in to the management account, specify SELF.
  • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

    Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

Parameter deploymentTargets : [Service-managed permissions] The Organizations accounts in which you want to update parameter values for stack instances. If your update targets OUs, the overridden parameter values only apply to the accounts that are currently in the target OUs and their child OUs. Accounts added to the target OUs and their child OUs in the future won't use the overridden values.

You can specify Accounts or DeploymentTargets, but not both.

Parameter operationId : The unique identifier for this StackSet operation.

The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the StackSet operation only once, even if you retry the request multiple times. You might retry StackSet operation requests to ensure that CloudFormation successfully received them.

If you don't specify an operation ID, the SDK generates one automatically.

Parameter operationPreferences : Preferences for how CloudFormation performs this StackSet operation.

Parameter parameterOverrides : A list of input parameters whose values you want to update for the specified stack instances.

Any overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions. When specifying parameters and their values, be aware of how CloudFormation sets parameter values during stack instance update operations:

  • To override the current value for a parameter, include the parameter and specify its value.
  • To leave an overridden parameter set to its present value, include the parameter and specify UsePreviousValue as true. (You can't specify both a value and set UsePreviousValue to true.)
  • To set an overridden parameter back to the value specified in the StackSet, specify a parameter list but don't include the parameter in the list.
  • To leave all parameters set to their present values, don't specify this property at all.
During StackSet updates, any parameter values overridden for a stack instance aren't updated, but retain their overridden value.

You can only override the parameter values that are specified in the StackSet. To add or delete a parameter itself, use UpdateStackSet to update the StackSet template. If you add a parameter to a template, before you can override the parameter value specified in the StackSet you must first use UpdateStackSet to update all stack instances with the updated template and parameter value specified in the StackSet. Once a stack instance has been updated with the new parameter, you can then override the parameter value using UpdateStackInstances.

Implementation

Future<UpdateStackInstancesOutput> updateStackInstances({
  required List<String> regions,
  required String stackSetName,
  List<String>? accounts,
  CallAs? callAs,
  DeploymentTargets? deploymentTargets,
  String? operationId,
  StackSetOperationPreferences? operationPreferences,
  List<Parameter>? parameterOverrides,
}) async {
  final $request = <String, String>{
    if (regions.isEmpty)
      'Regions': ''
    else
      for (var i1 = 0; i1 < regions.length; i1++)
        'Regions.member.${i1 + 1}': regions[i1],
    'StackSetName': stackSetName,
    if (accounts != null)
      if (accounts.isEmpty)
        'Accounts': ''
      else
        for (var i1 = 0; i1 < accounts.length; i1++)
          'Accounts.member.${i1 + 1}': accounts[i1],
    if (callAs != null) 'CallAs': callAs.value,
    if (deploymentTargets != null)
      for (var e1 in deploymentTargets.toQueryMap().entries)
        'DeploymentTargets.${e1.key}': e1.value,
    'OperationId': operationId ?? _s.generateIdempotencyToken(),
    if (operationPreferences != null)
      for (var e1 in operationPreferences.toQueryMap().entries)
        'OperationPreferences.${e1.key}': e1.value,
    if (parameterOverrides != null)
      if (parameterOverrides.isEmpty)
        'ParameterOverrides': ''
      else
        for (var i1 = 0; i1 < parameterOverrides.length; i1++)
          for (var e3 in parameterOverrides[i1].toQueryMap().entries)
            'ParameterOverrides.member.${i1 + 1}.${e3.key}': e3.value,
  };
  final $result = await _protocol.send(
    $request,
    action: 'UpdateStackInstances',
    version: '2010-05-15',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'UpdateStackInstancesResult',
  );
  return UpdateStackInstancesOutput.fromXml($result);
}