getDistributionTenantByDomain method
Future<GetDistributionTenantByDomainResult>
getDistributionTenantByDomain({
- required String domain,
Gets information about a distribution tenant by the associated domain.
May throw AccessDenied.
May throw EntityNotFound.
Parameter domain :
A domain name associated with the target distribution tenant.
Implementation
Future<GetDistributionTenantByDomainResult> getDistributionTenantByDomain({
required String domain,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/2020-05-31/distribution-tenant',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return GetDistributionTenantByDomainResult(
distributionTenant: DistributionTenant.fromXml($elem),
eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
);
}