listConnectionGroups method
Lists the connection groups in your Amazon Web Services account.
May throw AccessDenied.
May throw EntityNotFound.
May throw InvalidArgument.
Parameter associationFilter :
Filter by associated Anycast IP list ID.
Parameter marker :
The marker for the next set of connection groups to retrieve.
Parameter maxItems :
The maximum number of connection groups to return.
Implementation
Future<ListConnectionGroupsResult> listConnectionGroups({
ConnectionGroupAssociationFilter? associationFilter,
String? marker,
int? maxItems,
}) async {
final $result = await _protocol.send(
method: 'POST',
requestUri: '/2020-05-31/connection-groups',
payload: ListConnectionGroupsRequest(
associationFilter: associationFilter,
marker: marker,
maxItems: maxItems)
.toXml('ListConnectionGroupsRequest'),
exceptionFnMap: _exceptionFns,
);
return ListConnectionGroupsResult.fromXml($result.body);
}