listContinuousDeploymentPolicies method
Gets a list of the continuous deployment policies in your Amazon Web Services account.
You can optionally specify the maximum number of items to receive in the
response. If the total number of items in the list exceeds the maximum
that you specify, or the default maximum, the response is paginated. To
get the next page of items, send a subsequent request that specifies the
NextMarker value from the current response as the
Marker value in the subsequent request.
May throw AccessDenied.
May throw InvalidArgument.
May throw NoSuchContinuousDeploymentPolicy.
Parameter marker :
Use this field when paginating results to indicate where to begin in your
list of continuous deployment policies. The response includes policies in
the list that occur after the marker. To get the next page of the list,
set this field's value to the value of NextMarker from the
current page's response.
Parameter maxItems :
The maximum number of continuous deployment policies that you want
returned in the response.
Implementation
Future<ListContinuousDeploymentPoliciesResult>
listContinuousDeploymentPolicies({
String? marker,
int? maxItems,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/2020-05-31/continuous-deployment-policy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListContinuousDeploymentPoliciesResult(
continuousDeploymentPolicyList:
ContinuousDeploymentPolicyList.fromXml($elem),
);
}