listDistributionTenantsByCustomization method
Lists distribution tenants by the customization that you specify.
You must specify either the CertificateArn parameter or
WebACLArn parameter, but not both in the same request.
May throw AccessDenied.
May throw EntityNotFound.
May throw InvalidArgument.
Parameter certificateArn :
Filter by the ARN of the associated ACM certificate.
Parameter marker :
The marker for the next set of results.
Parameter maxItems :
The maximum number of distribution tenants to return by the specified
customization.
Parameter webACLArn :
Filter by the ARN of the associated WAF web ACL.
Implementation
Future<ListDistributionTenantsByCustomizationResult>
listDistributionTenantsByCustomization({
String? certificateArn,
String? marker,
int? maxItems,
String? webACLArn,
}) async {
final $result = await _protocol.send(
method: 'POST',
requestUri: '/2020-05-31/distribution-tenants-by-customization',
payload: ListDistributionTenantsByCustomizationRequest(
certificateArn: certificateArn,
marker: marker,
maxItems: maxItems,
webACLArn: webACLArn)
.toXml('ListDistributionTenantsByCustomizationRequest'),
exceptionFnMap: _exceptionFns,
);
return ListDistributionTenantsByCustomizationResult.fromXml($result.body);
}