listDistributionsByConnectionMode method
Lists the distributions by the connection mode that you specify.
May throw AccessDenied.
May throw InvalidArgument.
Parameter connectionMode :
This field specifies whether the connection mode is through a standard
distribution (direct) or a multi-tenant distribution with distribution
tenants (tenant-only).
Parameter marker :
The marker for the next set of distributions to retrieve.
Parameter maxItems :
The maximum number of distributions to return.
Implementation
Future<ListDistributionsByConnectionModeResult>
listDistributionsByConnectionMode({
required ConnectionMode connectionMode,
String? marker,
int? maxItems,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri:
'/2020-05-31/distributionsByConnectionMode/${Uri.encodeComponent(connectionMode.value)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListDistributionsByConnectionModeResult(
distributionList: DistributionList.fromXml($elem),
);
}