listOriginAccessControls method
Gets the list of CloudFront origin access controls (OACs) in this Amazon Web Services account.
You can optionally specify the maximum number of items to receive in the
response. If the total number of items in the list exceeds the maximum
that you specify, or the default maximum, the response is paginated. To
get the next page of items, send another request that specifies the
NextMarker value from the current response as the
Marker value in the next request.
May throw InvalidArgument.
Parameter marker :
Use this field when paginating results to indicate where to begin in your
list of origin access controls. The response includes the items in the
list that occur after the marker. To get the next page of the list, set
this field's value to the value of NextMarker from the
current page's response.
Parameter maxItems :
The maximum number of origin access controls that you want in the
response.
Implementation
Future<ListOriginAccessControlsResult> listOriginAccessControls({
String? marker,
int? maxItems,
}) async {
final $query = <String, List<String>>{
if (marker != null) 'Marker': [marker],
if (maxItems != null) 'MaxItems': [maxItems.toString()],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/2020-05-31/origin-access-control',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListOriginAccessControlsResult(
originAccessControlList: OriginAccessControlList.fromXml($elem),
);
}