tagResource method
Add tags to a CloudFront resource. For more information, see Tagging a distribution in the Amazon CloudFront Developer Guide.
May throw AccessDenied.
May throw InvalidArgument.
May throw InvalidTagging.
May throw NoSuchResource.
Parameter resource :
An ARN of a CloudFront resource.
Parameter tags :
A complex type that contains zero or more Tag elements.
Implementation
Future<void> tagResource({
required String resource,
required Tags tags,
}) async {
final $query = <String, List<String>>{
'Resource': [resource],
};
await _protocol.send(
method: 'POST',
requestUri: '/2020-05-31/tagging?Operation=Tag',
queryParams: $query,
payload: tags.toXml('Tags'),
exceptionFnMap: _exceptionFns,
);
}