updateKeyValueStore method
Specifies the key value store to update.
May throw AccessDenied.
May throw EntityNotFound.
May throw InvalidArgument.
May throw InvalidIfMatchVersion.
May throw PreconditionFailed.
May throw UnsupportedOperation.
Parameter comment :
The comment of the key value store to update.
Parameter ifMatch :
The key value store to update, if a match occurs.
Parameter name :
The name of the key value store to update.
Implementation
Future<UpdateKeyValueStoreResult> updateKeyValueStore({
required String comment,
required String ifMatch,
required String name,
}) async {
final headers = <String, String>{
'If-Match': ifMatch.toString(),
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri: '/2020-05-31/key-value-store/${Uri.encodeComponent(name)}',
headers: headers,
payload: UpdateKeyValueStoreRequest(
comment: comment, ifMatch: ifMatch, name: name)
.toXml('UpdateKeyValueStoreRequest'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return UpdateKeyValueStoreResult(
keyValueStore: KeyValueStore.fromXml($elem),
eTag: _s.extractHeaderStringValue($result.headers, 'ETag'),
);
}