deleteDomain method
Permanently deletes a search domain and all of its data. Once a domain has been deleted, it cannot be recovered. For more information, see Deleting a Search Domain in the Amazon CloudSearch Developer Guide.
May throw BaseException.
May throw InternalException.
Parameter domainName :
The name of the domain you want to permanently delete.
Implementation
Future<DeleteDomainResponse> deleteDomain({
required String domainName,
}) async {
final $request = <String, String>{
'DomainName': domainName,
};
final $result = await _protocol.send(
$request,
action: 'DeleteDomain',
version: '2013-01-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DeleteDomainResult',
);
return DeleteDomainResponse.fromXml($result);
}