createEventDataStore method
Creates a new event data store.
May throw CloudTrailAccessNotEnabledException.
May throw ConflictException.
May throw EventDataStoreAlreadyExistsException.
May throw EventDataStoreMaxLimitExceededException.
May throw InsufficientDependencyServiceAccessPermissionException.
May throw InsufficientEncryptionPolicyException.
May throw InvalidEventSelectorsException.
May throw InvalidKmsKeyIdException.
May throw InvalidParameterException.
May throw InvalidTagParameterException.
May throw KmsException.
May throw KmsKeyNotFoundException.
May throw NoManagementAccountSLRExistsException.
May throw NotOrganizationMasterAccountException.
May throw OperationNotPermittedException.
May throw OrganizationNotInAllFeaturesModeException.
May throw OrganizationsNotInUseException.
May throw ThrottlingException.
May throw UnsupportedOperationException.
Parameter name :
The name of the event data store.
Parameter advancedEventSelectors :
The advanced event selectors to use to select the events for the data
store. You can configure up to five advanced event selectors for each
event data store.
For more information about how to use advanced event selectors to log CloudTrail events, see Log events by using advanced event selectors in the CloudTrail User Guide.
For more information about how to use advanced event selectors to include Config configuration items in your event data store, see Create an event data store for Config configuration items in the CloudTrail User Guide.
For more information about how to use advanced event selectors to include events outside of Amazon Web Services events in your event data store, see Create an integration to log events from outside Amazon Web Services in the CloudTrail User Guide.
Parameter billingMode :
The billing mode for the event data store determines the cost for
ingesting events and the default and maximum retention period for the
event data store.
The following are the possible values:
-
EXTENDABLE_RETENTION_PRICING- This billing mode is generally recommended if you want a flexible retention period of up to 3653 days (about 10 years). The default retention period for this billing mode is 366 days. -
FIXED_RETENTION_PRICING- This billing mode is recommended if you expect to ingest more than 25 TB of event data per month and need a retention period of up to 2557 days (about 7 years). The default retention period for this billing mode is 2557 days.
EXTENDABLE_RETENTION_PRICING.
For more information about CloudTrail pricing, see CloudTrail Pricing and Managing CloudTrail Lake costs.
Parameter kmsKeyId :
Specifies the KMS key ID to use to encrypt the events delivered by
CloudTrail. The value can be an alias name prefixed by
alias/, a fully specified ARN to an alias, a fully specified
ARN to a key, or a globally unique identifier.
CloudTrail also supports KMS multi-Region keys. For more information about
multi-Region keys, see Using
multi-Region keys in the Key Management Service Developer
Guide.
Examples:
-
alias/MyAliasName -
arn:aws:kms:us-east-2:123456789012:alias/MyAliasName -
arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012 -
12345678-1234-1234-1234-123456789012
Parameter multiRegionEnabled :
Specifies whether the event data store includes events from all Regions,
or only from the Region in which the event data store is created.
Parameter organizationEnabled :
Specifies whether an event data store collects events logged for an
organization in Organizations.
Parameter retentionPeriod :
The retention period of the event data store, in days. If
BillingMode is set to
EXTENDABLE_RETENTION_PRICING, you can set a retention period
of up to 3653 days, the equivalent of 10 years. If
BillingMode is set to FIXED_RETENTION_PRICING,
you can set a retention period of up to 2557 days, the equivalent of seven
years.
CloudTrail Lake determines whether to retain an event by checking if the
eventTime of the event is within the specified retention
period. For example, if you set a retention period of 90 days, CloudTrail
will remove events when the eventTime is older than 90 days.
Parameter startIngestion :
Specifies whether the event data store should start ingesting live events.
The default is true.
Parameter terminationProtectionEnabled :
Specifies whether termination protection is enabled for the event data
store. If termination protection is enabled, you cannot delete the event
data store until termination protection is disabled.
Implementation
Future<CreateEventDataStoreResponse> createEventDataStore({
required String name,
List<AdvancedEventSelector>? advancedEventSelectors,
BillingMode? billingMode,
String? kmsKeyId,
bool? multiRegionEnabled,
bool? organizationEnabled,
int? retentionPeriod,
bool? startIngestion,
List<Tag>? tagsList,
bool? terminationProtectionEnabled,
}) async {
_s.validateNumRange(
'retentionPeriod',
retentionPeriod,
7,
3653,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CloudTrail_20131101.CreateEventDataStore'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (advancedEventSelectors != null)
'AdvancedEventSelectors': advancedEventSelectors,
if (billingMode != null) 'BillingMode': billingMode.value,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (multiRegionEnabled != null)
'MultiRegionEnabled': multiRegionEnabled,
if (organizationEnabled != null)
'OrganizationEnabled': organizationEnabled,
if (retentionPeriod != null) 'RetentionPeriod': retentionPeriod,
if (startIngestion != null) 'StartIngestion': startIngestion,
if (tagsList != null) 'TagsList': tagsList,
if (terminationProtectionEnabled != null)
'TerminationProtectionEnabled': terminationProtectionEnabled,
},
);
return CreateEventDataStoreResponse.fromJson(jsonResponse.body);
}