getEventSelectors method
Describes the settings for the event selectors that you configured for your trail. The information returned for your event selectors includes the following:
- If your event selector includes read-only events, write-only events, or all events. This applies to management events, data events, and network activity events.
- If your event selector includes management events.
- If your event selector includes network activity events, the event sources for which you are logging network activity events.
- If your event selector includes data events, the resources on which you are logging data events.
May throw CloudTrailARNInvalidException.
May throw InvalidTrailNameException.
May throw NoManagementAccountSLRExistsException.
May throw OperationNotPermittedException.
May throw TrailNotFoundException.
May throw UnsupportedOperationException.
Parameter trailName :
Specifies the name of the trail or trail ARN. If you specify a trail name,
the string must meet the following requirements:
- Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
- Start with a letter or number, and end with a letter or number
- Be between 3 and 128 characters
-
Have no adjacent periods, underscores or dashes. Names like
my-_namespaceandmy--namespaceare not valid. - Not be in IP address format (for example, 192.168.5.4)
arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail
Implementation
Future<GetEventSelectorsResponse> getEventSelectors({
required String trailName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CloudTrail_20131101.GetEventSelectors'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TrailName': trailName,
},
);
return GetEventSelectorsResponse.fromJson(jsonResponse.body);
}