CloudTrailData class
The CloudTrail Data Service lets you ingest events into CloudTrail from any
source in your hybrid environments, such as in-house or SaaS applications
hosted on-premises or in the cloud, virtual machines, or containers. You can
store, access, analyze, troubleshoot and take action on this data without
maintaining multiple log aggregators and reporting tools. After you run
PutAuditEvents to ingest your application activity into
CloudTrail, you can use CloudTrail Lake to search, query, and analyze the
data that is logged from your applications.
Constructors
- CloudTrailData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAuditEvents(
{required List< AuditEvent> auditEvents, required String channelArn, String? externalId}) → Future<PutAuditEventsResponse> -
Ingests your application events into CloudTrail Lake. A required
parameter,
auditEvents, accepts the JSON records (also called payload) of events that you want CloudTrail to ingest. You can add up to 100 of these events (or up to 1 MB) perPutAuditEventsrequest. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited