deleteAlarms method
Deletes the specified alarms. You can delete up to 100 alarms in one operation. However, this total can include no more than one composite alarm. For example, you could delete 99 metric alarms and one composite alarms with one operation, but you can't delete two composite alarms with one operation.
If you specify any incorrect alarm names, the alarms you specify with
correct names are still deleted. Other syntax errors might result in no
alarms being deleted. To confirm that alarms were deleted successfully,
you can use the DescribeAlarms
operation after using DeleteAlarms.
To get out of such a situation, you must break the cycle by changing the
rule of one of the composite alarms in the cycle to remove a dependency
that creates the cycle. The simplest change to make to break a cycle is to
change the AlarmRule of one of the alarms to
false.
Additionally, the evaluation of composite alarms stops if CloudWatch detects a cycle in the evaluation path.
May throw ResourceNotFound.
Parameter alarmNames :
The alarms to be deleted. Do not enclose the alarm names in quote marks.
Implementation
Future<void> deleteAlarms({
required List<String> alarmNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.DeleteAlarms'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AlarmNames': alarmNames,
},
);
}