getMetricStream method
Returns information about the metric stream that you specify.
May throw InternalServiceFault.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw MissingRequiredParameterException.
May throw ResourceNotFoundException.
Parameter name :
The name of the metric stream to retrieve information about.
Implementation
Future<GetMetricStreamOutput> getMetricStream({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'GraniteServiceVersion20100801.GetMetricStream'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
return GetMetricStreamOutput.fromJson(jsonResponse.body);
}