deauthorizeConnection method
Removes all authorization parameters from the connection. This lets you remove the secret from the connection so you can reuse it without having to create a new connection.
May throw ConcurrentModificationException.
May throw InternalException.
May throw ResourceNotFoundException.
Parameter name :
The name of the connection to remove authorization from.
Implementation
Future<DeauthorizeConnectionResponse> deauthorizeConnection({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.DeauthorizeConnection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
return DeauthorizeConnectionResponse.fromJson(jsonResponse.body);
}