testEventPattern method
Tests whether the specified event pattern matches the provided event.
Most services in Amazon Web Services treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.
May throw InternalException.
May throw InvalidEventPatternException.
Parameter event :
The event, in JSON format, to test against the event pattern. The JSON
must follow the format specified in Amazon
Web Services Events, and the following fields are mandatory:
-
id -
account -
source -
time -
region -
resources -
detail-type
Parameter eventPattern :
The event pattern. For more information, see Events
and Event Patterns in the Amazon EventBridge User Guide.
Implementation
Future<TestEventPatternResponse> testEventPattern({
required String event,
required String eventPattern,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSEvents.TestEventPattern'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Event': event,
'EventPattern': eventPattern,
},
);
return TestEventPatternResponse.fromJson(jsonResponse.body);
}