deleteDataProtectionPolicy method
Deletes the data protection policy from the specified log group.
For more information about data protection policies, see PutDataProtectionPolicy.
May throw InvalidParameterException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter logGroupIdentifier :
The name or ARN of the log group that you want to delete the data
protection policy for.
Implementation
Future<void> deleteDataProtectionPolicy({
required String logGroupIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteDataProtectionPolicy'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupIdentifier': logGroupIdentifier,
},
);
}