deleteDeliveryDestination method
Deletes a delivery destination. A delivery is a connection between a logical delivery source and a logical delivery destination.
You can't delete a delivery destination if any current deliveries are
associated with it. To find whether any deliveries are associated with
this delivery destination, use the DescribeDeliveries
operation and check the deliveryDestinationArn field in the
results.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the delivery destination that you want to delete. You can find
a list of delivery destination names by using the DescribeDeliveryDestinations
operation.
Implementation
Future<void> deleteDeliveryDestination({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteDeliveryDestination'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'name': name,
},
);
}