deleteIntegration method
Deletes the integration between CloudWatch Logs and OpenSearch Service. If
your integration has active vended logs dashboards, you must specify
true for the force parameter, otherwise the
operation will fail. If you delete the integration by setting
force to true, all your vended logs dashboards
powered by OpenSearch Service will be deleted and the data that was on
them will no longer be accessible.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ValidationException.
Parameter integrationName :
The name of the integration to delete. To find the name of your
integration, use ListIntegrations.
Parameter force :
Specify true to force the deletion of the integration even if
vended logs dashboards currently exist.
The default is false.
Implementation
Future<void> deleteIntegration({
required String integrationName,
bool? force,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DeleteIntegration'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'integrationName': integrationName,
if (force != null) 'force': force,
},
);
}