disassociateSourceFromS3TableIntegration method
Future<DisassociateSourceFromS3TableIntegrationResponse>
disassociateSourceFromS3TableIntegration({
- required String identifier,
Disassociates a data source from an S3 Table Integration, removing query access and deleting all associated data from the integration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The unique identifier of the association to remove between the data source
and S3 Table Integration.
Implementation
Future<DisassociateSourceFromS3TableIntegrationResponse>
disassociateSourceFromS3TableIntegration({
required String identifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.DisassociateSourceFromS3TableIntegration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'identifier': identifier,
},
);
return DisassociateSourceFromS3TableIntegrationResponse.fromJson(
jsonResponse.body);
}