getDeliveryDestinationPolicy method
Future<GetDeliveryDestinationPolicyResponse>
getDeliveryDestinationPolicy({
- required String deliveryDestinationName,
Retrieves the delivery destination policy assigned to the delivery destination that you specify. For more information about delivery destinations and their policies, see PutDeliveryDestinationPolicy.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ValidationException.
Parameter deliveryDestinationName :
The name of the delivery destination that you want to retrieve the policy
of.
Implementation
Future<GetDeliveryDestinationPolicyResponse> getDeliveryDestinationPolicy({
required String deliveryDestinationName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.GetDeliveryDestinationPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'deliveryDestinationName': deliveryDestinationName,
},
);
return GetDeliveryDestinationPolicyResponse.fromJson(jsonResponse.body);
}