getLogAnomalyDetector method
Future<GetLogAnomalyDetectorResponse>
getLogAnomalyDetector({
- required String anomalyDetectorArn,
Retrieves information about the log anomaly detector that you specify. The KMS key ARN detected is valid.
May throw InvalidParameterException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter anomalyDetectorArn :
The ARN of the anomaly detector to retrieve information about. You can
find the ARNs of log anomaly detectors in your account by using the ListLogAnomalyDetectors
operation.
Implementation
Future<GetLogAnomalyDetectorResponse> getLogAnomalyDetector({
required String anomalyDetectorArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.GetLogAnomalyDetector'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'anomalyDetectorArn': anomalyDetectorArn,
},
);
return GetLogAnomalyDetectorResponse.fromJson(jsonResponse.body);
}