putDataProtectionPolicy method
Creates a data protection policy for the specified log group. A data
protection policy can help safeguard sensitive data that's ingested by the
log group by auditing and masking the sensitive log data.
By default, when a user views a log event that includes masked data, the
sensitive data is replaced by asterisks. A user who has the
logs:Unmask permission can use a GetLogEvents
or FilterLogEvents
operation with the unmask parameter set to true
to view the unmasked log events. Users with the logs:Unmask
can also view unmasked data in the CloudWatch Logs console by running a
CloudWatch Logs Insights query with the unmask query command.
For more information, including a list of types of data that can be audited and masked, see Protect sensitive log data with masking.
The PutDataProtectionPolicy operation applies to only the
specified log group. You can also use PutAccountPolicy
to create an account-level data protection policy that applies to all log
groups in the account, including both existing log groups and log groups
that are created level. If a log group has its own data protection policy
and the account also has an account-level data protection policy, then the
two policies are cumulative. Any sensitive term specified in either policy
is masked.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter logGroupIdentifier :
Specify either the log group name or log group ARN.
Parameter policyDocument :
Specify the data protection policy, in JSON.
This policy must include two JSON blocks:
-
The first block must include both a
DataIdentiferarray and anOperationproperty with anAuditaction. TheDataIdentiferarray lists the types of sensitive data that you want to mask. For more information about the available options, see Types of data that you can mask.The
Operationproperty with anAuditaction is required to find the sensitive data terms. ThisAuditaction must contain aFindingsDestinationobject. You can optionally use thatFindingsDestinationobject to list one or more destinations to send audit findings to. If you specify destinations such as log groups, Firehose streams, and S3 buckets, they must already exist. -
The second block must include both a
DataIdentiferarray and anOperationproperty with anDeidentifyaction. TheDataIdentiferarray must exactly match theDataIdentiferarray in the first block of the policy.The
Operationproperty with theDeidentifyaction is what actually masks the data, and it must contain the"MaskConfig": {}object. The"MaskConfig": {}object must be empty.
policyDocument can
also include Name, Description, and
Version fields. The Name is used as a dimension
when CloudWatch Logs reports audit findings metrics to CloudWatch.
The JSON specified in policyDocument can be up to 30,720
characters.
Implementation
Future<PutDataProtectionPolicyResponse> putDataProtectionPolicy({
required String logGroupIdentifier,
required String policyDocument,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.PutDataProtectionPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'logGroupIdentifier': logGroupIdentifier,
'policyDocument': policyDocument,
},
);
return PutDataProtectionPolicyResponse.fromJson(jsonResponse.body);
}