putResourcePolicy method
Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53. This API has the following restrictions:
-
Supported actions - Policy only supports
logs:PutLogEventsandlogs:CreateLogStreamactions - Supported principals - Policy only applies when operations are invoked by Amazon Web Services service principals (not IAM users, roles, or cross-account principals
- Policy limits - An account can have a maximum of 10 policies without resourceARN and one per LogGroup resourceARN
May throw InvalidParameterException.
May throw LimitExceededException.
May throw OperationAbortedException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter expectedRevisionId :
The expected revision ID of the resource policy. Required when
resourceArn is provided to prevent concurrent modifications.
Use null when creating a resource policy for the first time.
Parameter policyDocument :
Details of the new policy, including the identity of the principal that is
enabled to put logs to this account. This is formatted as a JSON string.
This parameter is required.
The following example creates a resource policy enabling the Route 53
service to put DNS query logs in to the specified log group. Replace
"logArn" with the ARN of your CloudWatch Logs resource, such
as a log group or log stream.
CloudWatch Logs also supports aws:SourceArn and aws:SourceAccount condition context keys.
In the example resource policy, you would replace the value of
SourceArn with the resource making the call from Route 53 to
CloudWatch Logs. You would also replace the value of
SourceAccount with the Amazon Web Services account ID making
that call.
{ "Version": "2012-10-17", "Statement": [ { "Sid":
"Route53LogsToCloudWatchLogs", "Effect": "Allow", "Principal": {
"Service": [ "route53.amazonaws.com" ] }, "Action": "logs:PutLogEvents",
"Resource": "logArn", "Condition": { "ArnLike": { "aws:SourceArn":
"myRoute53ResourceArn" }, "StringEquals": { "aws:SourceAccount":
"myAwsAccountId" } } } ] }
Parameter policyName :
Name of the new policy. This parameter is required.
Parameter resourceArn :
The ARN of the CloudWatch Logs resource to which the resource policy needs
to be added or attached. Currently only supports LogGroup ARN.
Implementation
Future<PutResourcePolicyResponse> putResourcePolicy({
String? expectedRevisionId,
String? policyDocument,
String? policyName,
String? resourceArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Logs_20140328.PutResourcePolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (expectedRevisionId != null)
'expectedRevisionId': expectedRevisionId,
if (policyDocument != null) 'policyDocument': policyDocument,
if (policyName != null) 'policyName': policyName,
if (resourceArn != null) 'resourceArn': resourceArn,
},
);
return PutResourcePolicyResponse.fromJson(jsonResponse.body);
}