listFleets method
Gets a list of compute fleet names with each compute fleet name representing a single compute fleet.
May throw InvalidInputException.
Parameter maxResults :
The maximum number of paginated compute fleets returned per response. Use
nextToken to iterate pages in the list of returned compute
fleets.
Parameter nextToken :
During a previous call, if there are more than 100 items in the list, only
the first 100 items are returned, along with a unique string called a
nextToken. To get the next batch of items in the list, call this
operation again, adding the next token to the call. To get all of the
items in the list, keep calling this operation with each subsequent next
token that is returned, until no more next tokens are returned.
Parameter sortBy :
The criterion to be used to list compute fleet names. Valid values
include:
-
CREATED_TIME: List based on when each compute fleet was created. -
LAST_MODIFIED_TIME: List based on when information about each compute fleet was last changed. -
NAME: List based on each compute fleet's name.
sortOrder to specify in what order to list the compute
fleet names based on the preceding criteria.
Parameter sortOrder :
The order in which to list compute fleets. Valid values include:
-
ASCENDING: List in ascending order. -
DESCENDING: List in descending order.
sortBy to specify the criterion to be used to list
compute fleet names.
Implementation
Future<ListFleetsOutput> listFleets({
int? maxResults,
String? nextToken,
FleetSortByType? sortBy,
SortOrderType? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodeBuild_20161006.ListFleets'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (sortBy != null) 'sortBy': sortBy.value,
if (sortOrder != null) 'sortOrder': sortOrder.value,
},
);
return ListFleetsOutput.fromJson(jsonResponse.body);
}