CodeCatalyst class
Welcome to the Amazon CodeCatalyst API reference. This reference provides descriptions of operations and data types for Amazon CodeCatalyst. You can use the Amazon CodeCatalyst API to work with the following objects.
Spaces, by calling the following:
- DeleteSpace, which deletes a space.
- GetSpace, which returns information about a space.
- GetSubscription, which returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space.
- ListSpaces, which retrieves a list of spaces.
- UpdateSpace, which changes one or more values for a space.
- CreateProject which creates a project in a specified space.
- GetProject, which returns information about a project.
- ListProjects, which retrieves a list of projects in a space.
- GetUserDetails, which returns information about a user in Amazon CodeCatalyst.
- CreateSourceRepository, which creates an empty Git-based source repository in a specified project.
- CreateSourceRepositoryBranch, which creates a branch in a specified repository where you can work on code.
- DeleteSourceRepository, which deletes a source repository.
- GetSourceRepository, which returns information about a source repository.
- GetSourceRepositoryCloneUrls, which returns information about the URLs that can be used with a Git client to clone a source repository.
- ListSourceRepositories, which retrieves a list of source repositories in a project.
- ListSourceRepositoryBranches, which retrieves a list of branches in a source repository.
- CreateDevEnvironment, which creates a Dev Environment, where you can quickly work on the code stored in the source repositories of your project.
- DeleteDevEnvironment, which deletes a Dev Environment.
- GetDevEnvironment, which returns information about a Dev Environment.
- ListDevEnvironments, which retrieves a list of Dev Environments in a project.
- ListDevEnvironmentSessions, which retrieves a list of active Dev Environment sessions in a project.
- StartDevEnvironment, which starts a specified Dev Environment and puts it into an active state.
- StartDevEnvironmentSession, which starts a session to a specified Dev Environment.
- StopDevEnvironment, which stops a specified Dev Environment and puts it into an stopped state.
- StopDevEnvironmentSession, which stops a session for a specified Dev Environment.
- UpdateDevEnvironment, which changes one or more values for a Dev Environment.
- GetWorkflow, which returns information about a workflow.
- GetWorkflowRun, which returns information about a specified run of a workflow.
- ListWorkflowRuns, which retrieves a list of runs of a specified workflow.
- ListWorkflows, which retrieves a list of workflows in a specified project.
- StartWorkflowRun, which starts a run of a specified workflow.
- CreateAccessToken, which creates a personal access token (PAT) for the current user.
- DeleteAccessToken, which deletes a specified personal access token (PAT).
- ListAccessTokens, which lists all personal access tokens (PATs) associated with a user.
- ListEventLogs, which retrieves a list of events that occurred during a specified time period in a space.
- VerifySession, which verifies whether the calling user has a valid Amazon CodeCatalyst login and session.
Constructors
- CodeCatalyst({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessToken(
{required String name, DateTime? expiresTime}) → Future< CreateAccessTokenResponse> - Creates a personal access token (PAT) for the current user. A personal access token (PAT) is similar to a password. It is associated with your user identity for use across all spaces and projects in Amazon CodeCatalyst. You use PATs to access CodeCatalyst from resources that include integrated development environments (IDEs) and Git-based source repositories. PATs represent you in Amazon CodeCatalyst and you can manage them in your user settings.For more information, see Managing personal access tokens in Amazon CodeCatalyst.
-
createDevEnvironment(
{required InstanceType instanceType, required PersistentStorageConfiguration persistentStorage, required String projectName, required String spaceName, String? alias, String? clientToken, List< IdeConfiguration> ? ides, int? inactivityTimeoutMinutes, List<RepositoryInput> ? repositories, String? vpcConnectionName}) → Future<CreateDevEnvironmentResponse> - Creates a Dev Environment in Amazon CodeCatalyst, a cloud-based development environment that you can use to quickly work on the code stored in the source repositories of your project.
-
createProject(
{required String displayName, required String spaceName, String? description}) → Future< CreateProjectResponse> - Creates a project in a specified space.
-
createSourceRepository(
{required String name, required String projectName, required String spaceName, String? description}) → Future< CreateSourceRepositoryResponse> -
Creates an empty Git-based source repository in a specified project. The
repository is created with an initial empty commit with a default branch
named
main. -
createSourceRepositoryBranch(
{required String name, required String projectName, required String sourceRepositoryName, required String spaceName, String? headCommitId}) → Future< CreateSourceRepositoryBranchResponse> - Creates a branch in a specified source repository in Amazon CodeCatalyst.
-
deleteAccessToken(
{required String id}) → Future< void> - Deletes a specified personal access token (PAT). A personal access token can only be deleted by the user who created it.
-
deleteDevEnvironment(
{required String id, required String projectName, required String spaceName}) → Future< DeleteDevEnvironmentResponse> - Deletes a Dev Environment.
-
deleteProject(
{required String name, required String spaceName}) → Future< DeleteProjectResponse> - Deletes a project in a space.
-
deleteSourceRepository(
{required String name, required String projectName, required String spaceName}) → Future< DeleteSourceRepositoryResponse> - Deletes a source repository in Amazon CodeCatalyst. You cannot use this API to delete a linked repository. It can only be used to delete a Amazon CodeCatalyst source repository.
-
deleteSpace(
{required String name}) → Future< DeleteSpaceResponse> - Deletes a space.
-
getDevEnvironment(
{required String id, required String projectName, required String spaceName}) → Future< GetDevEnvironmentResponse> - Returns information about a Dev Environment for a source repository in a project. Dev Environments are specific to the user who creates them.
-
getProject(
{required String name, required String spaceName}) → Future< GetProjectResponse> - Returns information about a project.
-
getSourceRepository(
{required String name, required String projectName, required String spaceName}) → Future< GetSourceRepositoryResponse> - Returns information about a source repository.
-
getSourceRepositoryCloneUrls(
{required String projectName, required String sourceRepositoryName, required String spaceName}) → Future< GetSourceRepositoryCloneUrlsResponse> - Returns information about the URLs that can be used with a Git client to clone a source repository.
-
getSpace(
{required String name}) → Future< GetSpaceResponse> - Returns information about an space.
-
getSubscription(
{required String spaceName}) → Future< GetSubscriptionResponse> - Returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space.
-
getUserDetails(
{String? id, String? userName}) → Future< GetUserDetailsResponse> - Returns information about a user.
-
getWorkflow(
{required String id, required String projectName, required String spaceName}) → Future< GetWorkflowResponse> - Returns information about a workflow.
-
getWorkflowRun(
{required String id, required String projectName, required String spaceName}) → Future< GetWorkflowRunResponse> - Returns information about a specified run of a workflow.
-
listAccessTokens(
{int? maxResults, String? nextToken}) → Future< ListAccessTokensResponse> - Lists all personal access tokens (PATs) associated with the user who calls the API. You can only list PATs associated with your Amazon Web Services Builder ID.
-
listDevEnvironments(
{required String spaceName, List< Filter> ? filters, int? maxResults, String? nextToken, String? projectName}) → Future<ListDevEnvironmentsResponse> - Retrieves a list of Dev Environments in a project.
-
listDevEnvironmentSessions(
{required String devEnvironmentId, required String projectName, required String spaceName, int? maxResults, String? nextToken}) → Future< ListDevEnvironmentSessionsResponse> - Retrieves a list of active sessions for a Dev Environment in a project.
-
listEventLogs(
{required DateTime endTime, required String spaceName, required DateTime startTime, String? eventName, int? maxResults, String? nextToken}) → Future< ListEventLogsResponse> - Retrieves a list of events that occurred during a specific time in a space. You can use these events to audit user and system activity in a space. For more information, see Monitoring in the Amazon CodeCatalyst User Guide.
-
listProjects(
{required String spaceName, List< ProjectListFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListProjectsResponse> - Retrieves a list of projects.
-
listSourceRepositories(
{required String projectName, required String spaceName, int? maxResults, String? nextToken}) → Future< ListSourceRepositoriesResponse> - Retrieves a list of source repositories in a project.
-
listSourceRepositoryBranches(
{required String projectName, required String sourceRepositoryName, required String spaceName, int? maxResults, String? nextToken}) → Future< ListSourceRepositoryBranchesResponse> - Retrieves a list of branches in a specified source repository.
-
listSpaces(
{String? nextToken}) → Future< ListSpacesResponse> - Retrieves a list of spaces.
-
listWorkflowRuns(
{required String projectName, required String spaceName, int? maxResults, String? nextToken, List< WorkflowRunSortCriteria> ? sortBy, String? workflowId}) → Future<ListWorkflowRunsResponse> - Retrieves a list of workflow runs of a specified workflow.
-
listWorkflows(
{required String projectName, required String spaceName, int? maxResults, String? nextToken, List< WorkflowSortCriteria> ? sortBy}) → Future<ListWorkflowsResponse> - Retrieves a list of workflows in a specified project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startDevEnvironment(
{required String id, required String projectName, required String spaceName, List< IdeConfiguration> ? ides, int? inactivityTimeoutMinutes, InstanceType? instanceType}) → Future<StartDevEnvironmentResponse> - Starts a specified Dev Environment and puts it into an active state.
-
startDevEnvironmentSession(
{required String id, required String projectName, required DevEnvironmentSessionConfiguration sessionConfiguration, required String spaceName}) → Future< StartDevEnvironmentSessionResponse> - Starts a session for a specified Dev Environment.
-
startWorkflowRun(
{required String projectName, required String spaceName, required String workflowId, String? clientToken}) → Future< StartWorkflowRunResponse> - Begins a run of a specified workflow.
-
stopDevEnvironment(
{required String id, required String projectName, required String spaceName}) → Future< StopDevEnvironmentResponse> - Pauses a specified Dev Environment and places it in a non-running state. Stopped Dev Environments do not consume compute minutes.
-
stopDevEnvironmentSession(
{required String id, required String projectName, required String sessionId, required String spaceName}) → Future< StopDevEnvironmentSessionResponse> - Stops a session for a specified Dev Environment.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDevEnvironment(
{required String id, required String projectName, required String spaceName, String? alias, String? clientToken, List< IdeConfiguration> ? ides, int? inactivityTimeoutMinutes, InstanceType? instanceType}) → Future<UpdateDevEnvironmentResponse> - Changes one or more values for a Dev Environment. Updating certain values of the Dev Environment will cause a restart.
-
updateProject(
{required String name, required String spaceName, String? description}) → Future< UpdateProjectResponse> - Changes one or more values for a project.
-
updateSpace(
{required String name, String? description}) → Future< UpdateSpaceResponse> - Changes one or more values for a space.
-
verifySession(
) → Future< VerifySessionResponse> - Verifies whether the calling user has a valid Amazon CodeCatalyst login and session. If successful, this returns the ID of the user in Amazon CodeCatalyst.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited