getDevEnvironment method
Returns information about a Dev Environment for a source repository in a project. Dev Environments are specific to the user who creates them.
Parameter id :
The system-generated unique ID of the Dev Environment for which you want
to view information. To retrieve a list of Dev Environment IDs, use
ListDevEnvironments.
Parameter projectName :
The name of the project in the space.
Parameter spaceName :
The name of the space.
Implementation
Future<GetDevEnvironmentResponse> getDevEnvironment({
required String id,
required String projectName,
required String spaceName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/spaces/${Uri.encodeComponent(spaceName)}/projects/${Uri.encodeComponent(projectName)}/devEnvironments/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return GetDevEnvironmentResponse.fromJson(response);
}