getSubscription method
Returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space.
Parameter spaceName :
The name of the space.
Implementation
Future<GetSubscriptionResponse> getSubscription({
required String spaceName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/spaces/${Uri.encodeComponent(spaceName)}/subscription',
exceptionFnMap: _exceptionFns,
);
return GetSubscriptionResponse.fromJson(response);
}