listDevEnvironments method
Retrieves a list of Dev Environments in a project.
Parameter spaceName :
The name of the space.
Parameter filters :
Information about filters to apply to narrow the results returned in the
list.
Parameter maxResults :
The maximum number of results to show in a single call to this API. If the
number of results is larger than the number you specified, the response
will include a NextToken element, which you can use to obtain
additional results.
Parameter nextToken :
A token returned from a call to this API to indicate the next batch of
results to return, if any.
Parameter projectName :
The name of the project in the space.
Implementation
Future<ListDevEnvironmentsResponse> listDevEnvironments({
required String spaceName,
List<Filter>? filters,
int? maxResults,
String? nextToken,
String? projectName,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (projectName != null) 'projectName': projectName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v1/spaces/${Uri.encodeComponent(spaceName)}/devEnvironments',
exceptionFnMap: _exceptionFns,
);
return ListDevEnvironmentsResponse.fromJson(response);
}