updateRepositoryDescription method
Sets or changes the comment or description for a repository.
May throw EncryptionIntegrityChecksFailedException.
May throw EncryptionKeyAccessDeniedException.
May throw EncryptionKeyDisabledException.
May throw EncryptionKeyNotFoundException.
May throw EncryptionKeyUnavailableException.
May throw InvalidRepositoryDescriptionException.
May throw InvalidRepositoryNameException.
May throw RepositoryDoesNotExistException.
May throw RepositoryNameRequiredException.
Parameter repositoryName :
The name of the repository to set or change the comment or description
for.
Parameter repositoryDescription :
The new comment or description for the specified repository. Repository
descriptions are limited to 1,000 characters.
Implementation
Future<void> updateRepositoryDescription({
required String repositoryName,
String? repositoryDescription,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodeCommit_20150413.UpdateRepositoryDescription'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'repositoryName': repositoryName,
if (repositoryDescription != null)
'repositoryDescription': repositoryDescription,
},
);
}