code_connections_2023_12_01 library
Classes
- AwsClientCredentials
- AWS credentials.
- CodeConnections
- This Amazon Web Services CodeConnections API Reference provides descriptions and usage examples of the operations and data types for the Amazon Web Services CodeConnections API. You can use the connections API to work with connections and installations.