skipWaitTimeForInstanceTermination method
In a blue/green deployment, overrides any specified wait time and starts terminating instances immediately after the traffic routing is complete.
May throw DeploymentAlreadyCompletedException.
May throw DeploymentDoesNotExistException.
May throw DeploymentIdRequiredException.
May throw DeploymentNotStartedException.
May throw InvalidDeploymentIdException.
May throw UnsupportedActionForDeploymentTypeException.
Parameter deploymentId :
The unique ID of a blue/green deployment for which you want to skip the
instance termination wait time.
Implementation
Future<void> skipWaitTimeForInstanceTermination({
String? deploymentId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodeDeploy_20141006.SkipWaitTimeForInstanceTermination'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (deploymentId != null) 'deploymentId': deploymentId,
},
);
}