getPipelineExecution method
Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.
May throw PipelineExecutionNotFoundException.
May throw PipelineNotFoundException.
May throw ValidationException.
Parameter pipelineExecutionId :
The ID of the pipeline execution about which you want to get execution
details.
Parameter pipelineName :
The name of the pipeline about which you want to get execution details.
Implementation
Future<GetPipelineExecutionOutput> getPipelineExecution({
required String pipelineExecutionId,
required String pipelineName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.GetPipelineExecution'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'pipelineExecutionId': pipelineExecutionId,
'pipelineName': pipelineName,
},
);
return GetPipelineExecutionOutput.fromJson(jsonResponse.body);
}