listRuleExecutions method
Lists the rule executions that have occurred in a pipeline configured for conditions with rules.
May throw InvalidNextTokenException.
May throw PipelineExecutionNotFoundException.
May throw PipelineNotFoundException.
May throw ValidationException.
Parameter pipelineName :
The name of the pipeline for which you want to get execution summary
information.
Parameter filter :
Input information used to filter rule execution history.
Parameter maxResults :
The maximum number of results to return in a single call. To retrieve the
remaining results, make another call with the returned nextToken value.
Pipeline history is limited to the most recent 12 months, based on
pipeline execution start times. Default value is 100.
Parameter nextToken :
The token that was returned from the previous
ListRuleExecutions call, which can be used to return the next
set of rule executions in the list.
Implementation
Future<ListRuleExecutionsOutput> listRuleExecutions({
required String pipelineName,
RuleExecutionFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.ListRuleExecutions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'pipelineName': pipelineName,
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListRuleExecutionsOutput.fromJson(jsonResponse.body);
}