updateActionType method
Updates an action type that was created with any supported integration
model, where the action type is to be used by customers of the action type
provider. Use a JSON file with the action definition and
UpdateActionType to provide the full structure.
May throw ActionTypeNotFoundException.
May throw RequestFailedException.
May throw ValidationException.
Parameter actionType :
The action type definition for the action type to be updated.
Implementation
Future<void> updateActionType({
required ActionTypeDeclaration actionType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'CodePipeline_20150709.UpdateActionType'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'actionType': actionType,
},
);
}