code_star_connections library
Classes
- AwsClientCredentials
- AWS credentials.
- CodeStarConnections
- This Amazon Web Services CodeStar Connections API Reference provides descriptions and usage examples of the operations and data types for the Amazon Web Services CodeStar Connections API. You can use the connections API to work with connections and installations.