listRepositoryLinks method
Lists the repository links created for connections in your account.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw InternalServerException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter maxResults :
A non-zero, non-negative integer used to limit the number of returned
results.
Parameter nextToken :
An enumeration token that, when provided in a request, returns the next
batch of the results.
Implementation
Future<ListRepositoryLinksOutput> listRepositoryLinks({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CodeStar_connections_20191201.ListRepositoryLinks'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListRepositoryLinksOutput.fromJson(jsonResponse.body);
}