listRepositorySyncDefinitions method
Future<ListRepositorySyncDefinitionsOutput>
listRepositorySyncDefinitions({
- required String repositoryLinkId,
- required SyncConfigurationType syncType,
Lists the repository sync definitions for repository links in your account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter repositoryLinkId :
The ID of the repository link for the sync definition for which you want
to retrieve information.
Parameter syncType :
The sync type of the repository link for the the sync definition for which
you want to retrieve information.
Implementation
Future<ListRepositorySyncDefinitionsOutput> listRepositorySyncDefinitions({
required String repositoryLinkId,
required SyncConfigurationType syncType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target':
'CodeStar_connections_20191201.ListRepositorySyncDefinitions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RepositoryLinkId': repositoryLinkId,
'SyncType': syncType.value,
},
);
return ListRepositorySyncDefinitionsOutput.fromJson(jsonResponse.body);
}