listSyncConfigurations method
Returns a list of sync configurations for a specified repository.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter repositoryLinkId :
The ID of the repository link for the requested list of sync
configurations.
Parameter syncType :
The sync type for the requested list of sync configurations.
Parameter maxResults :
A non-zero, non-negative integer used to limit the number of returned
results.
Parameter nextToken :
An enumeration token that allows the operation to batch the results of the
operation.
Implementation
Future<ListSyncConfigurationsOutput> listSyncConfigurations({
required String repositoryLinkId,
required SyncConfigurationType syncType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'CodeStar_connections_20191201.ListSyncConfigurations'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RepositoryLinkId': repositoryLinkId,
'SyncType': syncType.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListSyncConfigurationsOutput.fromJson(jsonResponse.body);
}