deleteRepository method
Deletes a repository.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that contains the repository to delete.
Parameter repository :
The name of the repository to delete.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DeleteRepositoryResult> deleteRepository({
required String domain,
required String repository,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'repository': [repository],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/repository',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeleteRepositoryResult.fromJson(response);
}