describePackage method

Future<DescribePackageResult> describePackage({
  1. required String domain,
  2. required PackageFormat format,
  3. required String package,
  4. required String repository,
  5. String? domainOwner,
  6. String? namespace,
})

Returns a PackageDescription object that contains information about the requested package.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter domain : The name of the domain that contains the repository that contains the package.

Parameter format : A format that specifies the type of the requested package.

Parameter package : The name of the requested package.

Parameter repository : The name of the repository that contains the requested package.

Parameter domainOwner : The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

Parameter namespace : The namespace of the requested package. The package component that specifies its namespace depends on its type. For example:

  • Maven
  • Swift
  • generic
  • The namespace of a Maven package version is its groupId.
  • The namespace of an npm or Swift package version is its scope.
  • The namespace of a generic package is its namespace.
  • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

Implementation

Future<DescribePackageResult> describePackage({
  required String domain,
  required PackageFormat format,
  required String package,
  required String repository,
  String? domainOwner,
  String? namespace,
}) async {
  final $query = <String, List<String>>{
    'domain': [domain],
    'format': [format.value],
    'package': [package],
    'repository': [repository],
    if (domainOwner != null) 'domain-owner': [domainOwner],
    if (namespace != null) 'namespace': [namespace],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/v1/package',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DescribePackageResult.fromJson(response);
}