describePackageGroup method
Returns a PackageGroupDescription object that contains information about the requested package group.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that contains the package group.
Parameter packageGroup :
The pattern of the requested package group.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DescribePackageGroupResult> describePackageGroup({
required String domain,
required String packageGroup,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'package-group': [packageGroup],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/package-group',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribePackageGroupResult.fromJson(response);
}