describeRepository method
Returns a RepositoryDescription object that contains detailed
information about the requested repository.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that contains the repository to describe.
Parameter repository :
A string that specifies the name of the requested repository.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DescribeRepositoryResult> describeRepository({
required String domain,
required String repository,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'repository': [repository],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/repository',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeRepositoryResult.fromJson(response);
}