disassociateExternalConnection method
Removes an existing external connection from a repository.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that contains the repository from which to remove
the external repository.
Parameter externalConnection :
The name of the external connection to be removed from the repository.
Parameter repository :
The name of the repository from which the external connection will be
removed.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Implementation
Future<DisassociateExternalConnectionResult> disassociateExternalConnection({
required String domain,
required String externalConnection,
required String repository,
String? domainOwner,
}) async {
final $query = <String, List<String>>{
'domain': [domain],
'external-connection': [externalConnection],
'repository': [repository],
if (domainOwner != null) 'domain-owner': [domainOwner],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/repository/external-connection',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DisassociateExternalConnectionResult.fromJson(response);
}