getAuthorizationToken method
Generates a temporary authorization token for accessing repositories in
the domain. This API requires the
codeartifact:GetAuthorizationToken and
sts:GetServiceBearerToken permissions. For more information
about authorization tokens, see CodeArtifact
authentication and tokens.
The authorization period begins after login or
GetAuthorizationToken is called. If login or
GetAuthorizationToken is called while assuming a role, the
token lifetime is independent of the maximum session duration of the role.
For example, if you call sts assume-role and specify a
session duration of 15 minutes, then generate a CodeArtifact authorization
token, the token will be valid for the full authorization period even
though this is longer than the 15-minute session duration.
See Using IAM Roles for more information on controlling session duration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The name of the domain that is in scope for the generated authorization
token.
Parameter domainOwner :
The 12-digit account number of the Amazon Web Services account that owns
the domain. It does not include dashes or spaces.
Parameter durationSeconds :
The time, in seconds, that the generated authorization token is valid.
Valid values are 0 and any number between 900
(15 minutes) and 43200 (12 hours). A value of 0
will set the expiration of the authorization token to the same expiration
of the user's role's temporary credentials.
Implementation
Future<GetAuthorizationTokenResult> getAuthorizationToken({
required String domain,
String? domainOwner,
int? durationSeconds,
}) async {
_s.validateNumRange(
'durationSeconds',
durationSeconds,
0,
43200,
);
final $query = <String, List<String>>{
'domain': [domain],
if (domainOwner != null) 'domain-owner': [domainOwner],
if (durationSeconds != null) 'duration': [durationSeconds.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/v1/authorization-token',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetAuthorizationTokenResult.fromJson(response);
}