listRepositories method
Returns a list of RepositorySummary
objects. Each RepositorySummary contains information about a
repository in the specified Amazon Web Services account and that matches
the input parameters.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Parameter repositoryPrefix :
A prefix used to filter returned repositories. Only repositories with
names that start with repositoryPrefix are returned.
Implementation
Future<ListRepositoriesResult> listRepositories({
int? maxResults,
String? nextToken,
String? repositoryPrefix,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
if (repositoryPrefix != null) 'repository-prefix': [repositoryPrefix],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/v1/repositories',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRepositoriesResult.fromJson(response);
}