listFlywheelIterationHistory method
Information about the history of a flywheel iteration. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
May throw InternalServerException.
May throw InvalidFilterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter flywheelArn :
The ARN of the flywheel.
Parameter filter :
Filter the flywheel iteration history based on creation time.
Parameter maxResults :
Maximum number of iteration history results to return
Parameter nextToken :
Next token
Implementation
Future<ListFlywheelIterationHistoryResponse> listFlywheelIterationHistory({
required String flywheelArn,
FlywheelIterationFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.ListFlywheelIterationHistory'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FlywheelArn': flywheelArn,
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListFlywheelIterationHistoryResponse.fromJson(jsonResponse.body);
}