startTopicsDetectionJob method
Starts an asynchronous topic detection job. Use the
DescribeTopicDetectionJob operation to track the status of a
job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw KmsKeyValidationException.
May throw ResourceInUseException.
May throw TooManyRequestsException.
May throw TooManyTagsException.
Parameter dataAccessRoleArn :
The Amazon Resource Name (ARN) of the IAM role that grants Amazon
Comprehend read access to your input data. For more information, see Role-based
permissions.
Parameter inputDataConfig :
Specifies the format and location of the input data for the job.
Parameter outputDataConfig :
Specifies where to send the output files. The output is a compressed
archive with two files, topic-terms.csv that lists the terms
associated with each topic, and doc-topics.csv that lists the
documents associated with each topic
Parameter clientRequestToken :
A unique identifier for the request. If you do not set the client request
token, Amazon Comprehend generates one.
Parameter jobName :
The identifier of the job.
Parameter numberOfTopics :
The number of topics to detect.
Parameter tags :
Tags to associate with the topics detection job. A tag is a key-value pair
that adds metadata to a resource used by Amazon Comprehend. For example, a
tag with "Sales" as the key might be added to a resource to indicate its
use by the sales department.
Parameter volumeKmsKeyId :
ID for the Amazon Web Services Key Management Service (KMS) key that
Amazon Comprehend uses to encrypt data on the storage volume attached to
the ML compute instance(s) that process the analysis job. The
VolumeKmsKeyId can be either of the following formats:
-
KMS Key ID:
"1234abcd-12ab-34cd-56ef-1234567890ab" -
Amazon Resource Name (ARN) of a KMS Key:
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
Parameter vpcConfig :
Configuration parameters for an optional private Virtual Private Cloud
(VPC) containing the resources you are using for your topic detection job.
For more information, see Amazon
VPC.
Implementation
Future<StartTopicsDetectionJobResponse> startTopicsDetectionJob({
required String dataAccessRoleArn,
required InputDataConfig inputDataConfig,
required OutputDataConfig outputDataConfig,
String? clientRequestToken,
String? jobName,
int? numberOfTopics,
List<Tag>? tags,
String? volumeKmsKeyId,
VpcConfig? vpcConfig,
}) async {
_s.validateNumRange(
'numberOfTopics',
numberOfTopics,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.StartTopicsDetectionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DataAccessRoleArn': dataAccessRoleArn,
'InputDataConfig': inputDataConfig,
'OutputDataConfig': outputDataConfig,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (jobName != null) 'JobName': jobName,
if (numberOfTopics != null) 'NumberOfTopics': numberOfTopics,
if (tags != null) 'Tags': tags,
if (volumeKmsKeyId != null) 'VolumeKmsKeyId': volumeKmsKeyId,
if (vpcConfig != null) 'VpcConfig': vpcConfig,
},
);
return StartTopicsDetectionJobResponse.fromJson(jsonResponse.body);
}