describePHIDetectionJob method
Gets the properties associated with a protected health information (PHI) detection job. Use this operation to get the status of a detection job.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter jobId :
The identifier that Amazon Comprehend Medical generated for the job. The
StartPHIDetectionJob operation returns this identifier in its
response.
Implementation
Future<DescribePHIDetectionJobResponse> describePHIDetectionJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ComprehendMedical_20181030.DescribePHIDetectionJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return DescribePHIDetectionJobResponse.fromJson(jsonResponse.body);
}