detectEntities method
The DetectEntities operation is deprecated. You should use
the DetectEntitiesV2 operation instead.
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information.
May throw InternalServerException.
May throw InvalidEncodingException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw TextSizeLimitExceededException.
May throw TooManyRequestsException.
Parameter text :
A UTF-8 text string containing the clinical content being examined for
entities.
Implementation
Future<DetectEntitiesResponse> detectEntities({
required String text,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ComprehendMedical_20181030.DetectEntities'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Text': text,
},
);
return DetectEntitiesResponse.fromJson(jsonResponse.body);
}