inferSNOMEDCT method
InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology
May throw InternalServerException.
May throw InvalidEncodingException.
May throw InvalidRequestException.
May throw ServiceUnavailableException.
May throw TextSizeLimitExceededException.
May throw TooManyRequestsException.
Parameter text :
The input text to be analyzed using InferSNOMEDCT.
Implementation
Future<InferSNOMEDCTResponse> inferSNOMEDCT({
required String text,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ComprehendMedical_20181030.InferSNOMEDCT'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Text': text,
},
);
return InferSNOMEDCTResponse.fromJson(jsonResponse.body);
}