deleteResourceConfig method
Records the configuration state for a custom resource that has been deleted. This API records a new ConfigurationItem with a ResourceDeleted status. You can retrieve the ConfigurationItems recorded for this resource in your Config History.
May throw NoRunningConfigurationRecorderException.
May throw ValidationException.
Parameter resourceId :
Unique identifier of the resource.
Parameter resourceType :
The type of the resource.
Implementation
Future<void> deleteResourceConfig({
required String resourceId,
required String resourceType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DeleteResourceConfig'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceId': resourceId,
'ResourceType': resourceType,
},
);
}