describeAggregateComplianceByConfigRules method
Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules. Does not display rules that do not have compliance results.
May throw InvalidLimitException.
May throw InvalidNextTokenException.
May throw NoSuchConfigurationAggregatorException.
May throw ValidationException.
Parameter configurationAggregatorName :
The name of the configuration aggregator.
Parameter filters :
Filters the results by ConfigRuleComplianceFilters object.
Parameter limit :
The maximum number of evaluation results returned on each page. The
default is maximum. If you specify 0, Config uses the default.
Parameter nextToken :
The nextToken string returned on a previous page that you use
to get the next page of results in a paginated response.
Implementation
Future<DescribeAggregateComplianceByConfigRulesResponse>
describeAggregateComplianceByConfigRules({
required String configurationAggregatorName,
ConfigRuleComplianceFilters? filters,
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
0,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'StarlingDoveService.DescribeAggregateComplianceByConfigRules'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigurationAggregatorName': configurationAggregatorName,
if (filters != null) 'Filters': filters,
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeAggregateComplianceByConfigRulesResponse.fromJson(
jsonResponse.body);
}