describeComplianceByResource method
Indicates whether the specified Amazon Web Services resources are compliant. If a resource is noncompliant, this operation returns the number of Config rules that the resource does not comply with.
A resource is compliant if it complies with all the Config rules that evaluate it. It is noncompliant if it does not comply with one or more of these rules.
If Config has no current evaluation results for the resource, it returns
INSUFFICIENT_DATA. This result might indicate one of the
following conditions about the rules that evaluate the resource:
-
Config has never invoked an evaluation for the rule. To check whether it
has, use the
DescribeConfigRuleEvaluationStatusaction to get theLastSuccessfulInvocationTimeandLastFailedInvocationTime. -
The rule's Lambda function is failing to send evaluation results to
Config. Verify that the role that you assigned to your configuration
recorder includes the
config:PutEvaluationspermission. If the rule is a custom rule, verify that the Lambda execution role includes theconfig:PutEvaluationspermission. -
The rule's Lambda function has returned
NOT_APPLICABLEfor all evaluation results. This can occur if the resources were deleted or removed from the rule's scope.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
Parameter complianceTypes :
Filters the results by compliance.
Parameter limit :
The maximum number of evaluation results returned on each page. The
default is 10. You cannot specify a number greater than 100. If you
specify 0, Config uses the default.
Parameter nextToken :
The nextToken string returned on a previous page that you use
to get the next page of results in a paginated response.
Parameter resourceId :
The ID of the Amazon Web Services resource for which you want compliance
information. You can specify only one resource ID. If you specify a
resource ID, you must also specify a type for ResourceType.
Parameter resourceType :
The types of Amazon Web Services resources for which you want compliance
information (for example, AWS::EC2::Instance). For this
operation, you can specify that the resource type is an Amazon Web
Services account by specifying AWS::::Account.
Implementation
Future<DescribeComplianceByResourceResponse> describeComplianceByResource({
List<ComplianceType>? complianceTypes,
int? limit,
String? nextToken,
String? resourceId,
String? resourceType,
}) async {
_s.validateNumRange(
'limit',
limit,
0,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.DescribeComplianceByResource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (complianceTypes != null)
'ComplianceTypes': complianceTypes.map((e) => e.value).toList(),
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
if (resourceId != null) 'ResourceId': resourceId,
if (resourceType != null) 'ResourceType': resourceType,
},
);
return DescribeComplianceByResourceResponse.fromJson(jsonResponse.body);
}