getOrganizationCustomRulePolicy method
Future<GetOrganizationCustomRulePolicyResponse>
getOrganizationCustomRulePolicy({
- required String organizationConfigRuleName,
Returns the policy definition containing the logic for your organization Config Custom Policy rule.
May throw NoSuchOrganizationConfigRuleException.
May throw OrganizationAccessDeniedException.
Parameter organizationConfigRuleName :
The name of your organization Config Custom Policy rule.
Implementation
Future<GetOrganizationCustomRulePolicyResponse>
getOrganizationCustomRulePolicy({
required String organizationConfigRuleName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.GetOrganizationCustomRulePolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OrganizationConfigRuleName': organizationConfigRuleName,
},
);
return GetOrganizationCustomRulePolicyResponse.fromJson(jsonResponse.body);
}