putConnector method
- required ConnectorConfiguration connectorConfiguration,
- List<
Tag> ? tags,
Creates a connector that specifies the connection between a third-party cloud service provider and Config.
A connector is required to create a service-linked configuration recorder for a third-party cloud service provider using the PutThirdPartyServiceLinkedConfigurationRecorder operation.
This API creates a service-linked role
AWSServiceRoleForConfigThirdParty in your account. The
service-linked role is created only when the role does not exist in your
account.
To update the connector configuration, you must delete all associated configuration recorders, delete the connector, and recreate it with the updated configuration.
Use TagResource and UntagResource to update tags after creation.
May throw ConflictException.
May throw InsufficientPermissionsException.
May throw MaxNumberOfConnectorsExceededException.
May throw ValidationException.
Parameter connectorConfiguration :
The provider-specific configuration for connecting to the third-party
cloud service provider.
Parameter tags :
The tags for the connector. Each tag consists of a key and an optional
value, both of which you define.
Implementation
Future<PutConnectorResponse> putConnector({
required ConnectorConfiguration connectorConfiguration,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutConnector'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConnectorConfiguration': connectorConfiguration,
if (tags != null) 'Tags': tags,
},
);
return PutConnectorResponse.fromJson(jsonResponse.body);
}