putExternalEvaluation method
Future<void>
putExternalEvaluation({
- required String configRuleName,
- required ExternalEvaluation externalEvaluation,
Add or updates the evaluations for process checks. This API checks if the rule is a process check when the name of the Config rule is provided.
May throw InvalidParameterValueException.
May throw NoSuchConfigRuleException.
Parameter configRuleName :
The name of the Config rule.
Parameter externalEvaluation :
An ExternalEvaluation object that provides details about
compliance.
Implementation
Future<void> putExternalEvaluation({
required String configRuleName,
required ExternalEvaluation externalEvaluation,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.PutExternalEvaluation'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigRuleName': configRuleName,
'ExternalEvaluation': externalEvaluation,
},
);
}