stopConfigurationRecorder method
Stops the customer managed configuration recorder. The customer managed configuration recorder will stop recording configuration changes for the resource types you have specified.
May throw NoSuchConfigurationRecorderException.
May throw UnmodifiableEntityException.
Parameter configurationRecorderName :
The name of the customer managed configuration recorder that you want to
stop.
Implementation
Future<void> stopConfigurationRecorder({
required String configurationRecorderName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StarlingDoveService.StopConfigurationRecorder'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConfigurationRecorderName': configurationRecorderName,
},
);
}