associateRoutingProfileQueues method
Associates a set of queues with a routing profile.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter routingProfileId :
The identifier of the routing profile.
Parameter manualAssignmentQueueConfigs :
The manual assignment queues to associate with this routing profile.
Note: Use this config for chat, email, and task contacts. It does not support voice contacts.
Parameter queueConfigs :
The queues to associate with this routing profile.
Implementation
Future<void> associateRoutingProfileQueues({
required String instanceId,
required String routingProfileId,
List<RoutingProfileManualAssignmentQueueConfig>?
manualAssignmentQueueConfigs,
List<RoutingProfileQueueConfig>? queueConfigs,
}) async {
final $payload = <String, dynamic>{
if (manualAssignmentQueueConfigs != null)
'ManualAssignmentQueueConfigs': manualAssignmentQueueConfigs,
if (queueConfigs != null) 'QueueConfigs': queueConfigs,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/associate-queues',
exceptionFnMap: _exceptionFns,
);
}