batchCreateDataTableValue method
Creates values for attributes in a data table. The value may be a default or it may be associated with a primary value. The value must pass all customer defined validation as well as the default validation for the value type. The operation must conform to Batch Operation API Standards. Although the standard specifies that successful and failed entities are listed separately in the response, authorization fails if any primary values or attributes are unauthorized. The combination of primary values and the attribute name serve as the identifier for the individual item request.
May throw AccessDeniedException.
May throw ConflictException.
May throw DuplicateResourceException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter dataTableId :
The unique identifier for the data table. Must also accept the table ARN
with or without a version alias. If no alias is provided, the default
behavior is identical to providing the $LATEST alias.
Parameter instanceId :
The unique identifier for the Amazon Connect instance.
Parameter values :
A list of values to create. Each value must specify the attribute name and
optionally primary values if the table has primary attributes.
Implementation
Future<BatchCreateDataTableValueResponse> batchCreateDataTableValue({
required String dataTableId,
required String instanceId,
required List<DataTableValue> values,
}) async {
final $payload = <String, dynamic>{
'Values': values,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/values/create',
exceptionFnMap: _exceptionFns,
);
return BatchCreateDataTableValueResponse.fromJson(response);
}