createQuickConnect method
Creates a quick connect for the specified Connect Customer instance.
May throw DuplicateResourceException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter name :
A unique name of the quick connect.
Parameter quickConnectConfig :
Configuration settings for the quick connect.
Parameter description :
The description of the quick connect.
Parameter tags :
The tags used to organize, track, or control access for this resource. For
example, { "Tags": {"key1":"value1", "key2":"value2"} }.
Implementation
Future<CreateQuickConnectResponse> createQuickConnect({
required String instanceId,
required String name,
required QuickConnectConfig quickConnectConfig,
String? description,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'Name': name,
'QuickConnectConfig': quickConnectConfig,
if (description != null) 'Description': description,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/quick-connects/${Uri.encodeComponent(instanceId)}',
exceptionFnMap: _exceptionFns,
);
return CreateQuickConnectResponse.fromJson(response);
}