createWorkspacePage method
Associates a view with a page in a workspace, defining what users see when they navigate to that page.
May throw AccessDeniedException.
May throw DuplicateResourceException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter page :
The page identifier. Valid system pages include HOME and
AGENT_EXPERIENCE. Custom pages cannot use the
aws: or connect: prefixes.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the view to associate with the page.
Parameter workspaceId :
The identifier of the workspace.
Parameter inputData :
A JSON string containing input parameters for the view, validated against
the view's input schema.
Parameter slug :
The URL-friendly identifier for the page.
Implementation
Future<void> createWorkspacePage({
required String instanceId,
required String page,
required String resourceArn,
required String workspaceId,
String? inputData,
String? slug,
}) async {
final $payload = <String, dynamic>{
'Page': page,
'ResourceArn': resourceArn,
if (inputData != null) 'InputData': inputData,
if (slug != null) 'Slug': slug,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/workspaces/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(workspaceId)}/pages',
exceptionFnMap: _exceptionFns,
);
}