deleteEvaluationForm method
Deletes an evaluation form in the specified Connect Customer instance.
- If the version property is provided, only the specified version of the evaluation form is deleted.
- If no version is provided, then the full form (all versions) is deleted.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter evaluationFormId :
The unique identifier for the evaluation form.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter evaluationFormVersion :
The unique identifier for the evaluation form.
Implementation
Future<void> deleteEvaluationForm({
required String evaluationFormId,
required String instanceId,
int? evaluationFormVersion,
}) async {
final $query = <String, List<String>>{
if (evaluationFormVersion != null)
'version': [evaluationFormVersion.toString()],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/evaluation-forms/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(evaluationFormId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}