deleteNotification method
Deletes a notification. Once deleted, the notification is no longer visible to all users and cannot be managed through the Admin Website or APIs.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter notificationId :
The unique identifier for the notification to delete.
Implementation
Future<void> deleteNotification({
required String instanceId,
required String notificationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/notifications/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(notificationId)}',
exceptionFnMap: _exceptionFns,
);
}