deleteTrafficDistributionGroup method
Deletes a traffic distribution group. This API can be called only in the Region where the traffic distribution group is created.
For more information about deleting traffic distribution groups, see Delete traffic distribution groups in the Connect Customer Administrator Guide.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw ResourceInUseException.
May throw ThrottlingException.
Parameter trafficDistributionGroupId :
The identifier of the traffic distribution group. This can be the ID or
the ARN of the traffic distribution group.
Implementation
Future<void> deleteTrafficDistributionGroup({
required String trafficDistributionGroupId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/traffic-distribution-group/${Uri.encodeComponent(trafficDistributionGroupId)}',
exceptionFnMap: _exceptionFns,
);
}