describeContactFlow method
Describes the specified flow.
You can also create and update flows using the Connect Customer Flow language.
Use the $SAVED alias in the request to describe the
SAVED content of a Flow. For example,
arn:aws:.../contact-flow/{id}:$SAVED. After a flow is
published, $SAVED needs to be supplied to view saved content
that has not been published.
Use arn:aws:.../contact-flow/{id}:{version} to retrieve the
content of a specific flow version.
In the response, Status indicates the flow status as either
SAVED or PUBLISHED. The PUBLISHED
status will initiate validation on the content. SAVED does
not initiate validation of the content. SAVED |
PUBLISHED
May throw ContactFlowNotPublishedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter contactFlowId :
The identifier of the flow.
Parameter instanceId :
The identifier of the Connect Customer instance.
Implementation
Future<DescribeContactFlowResponse> describeContactFlow({
required String contactFlowId,
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/contact-flows/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactFlowId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeContactFlowResponse.fromJson(response);
}