describeDataTable method
Returns all properties for a data table except for attributes and values. All properties from CreateDataTable are returned as well as properties for region replication, versioning, and system tables. "Describe" is a deprecated term but is allowed to maintain consistency with existing operations.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter dataTableId :
The unique identifier for the data table. Must also accept the table ARN
with or without a version alias. If no alias is provided, the default
behavior is identical to providing the $LATEST alias.
Parameter instanceId :
The unique identifier for the Amazon Connect instance.
Implementation
Future<DescribeDataTableResponse> describeDataTable({
required String dataTableId,
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeDataTableResponse.fromJson(response);
}