describePhoneNumber method
Gets details and status of a phone number that’s claimed to your Connect Customer instance or traffic distribution group.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter phoneNumberId :
A unique identifier for the phone number.
Implementation
Future<DescribePhoneNumberResponse> describePhoneNumber({
required String phoneNumberId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/phone-number/${Uri.encodeComponent(phoneNumberId)}',
exceptionFnMap: _exceptionFns,
);
return DescribePhoneNumberResponse.fromJson(response);
}