describePredefinedAttribute method
Describes a predefined attribute for the specified Connect Customer instance. A predefined attribute is made up of a name and a value. You can use predefined attributes for:
- Routing proficiency (for example, agent certification) that has predefined values (for example, a list of possible certifications). For more information, see Create predefined attributes for routing contacts to agents.
- Contact information that varies between transfers or conferences, such as the name of the business unit handling the contact. For more information, see Use contact segment attributes.
Endpoints: See Connect Customer endpoints and quotas.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find the instance
ID in the Amazon Resource Name (ARN) of the instance.
Parameter name :
The name of the predefined attribute.
Implementation
Future<DescribePredefinedAttributeResponse> describePredefinedAttribute({
required String instanceId,
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/predefined-attributes/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return DescribePredefinedAttributeResponse.fromJson(response);
}