describeTestCase method
Describes the specified test case and allows you to get the content and metadata of the test case for the specified Amazon Connect instance.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance.
Parameter testCaseId :
The identifier of the test case.
Parameter status :
The status of the test case version to retrieve. If not specified, returns
the published version if available, otherwise returns the saved version.
Implementation
Future<DescribeTestCaseResponse> describeTestCase({
required String instanceId,
required String testCaseId,
TestCaseStatus? status,
}) async {
final $query = <String, List<String>>{
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/test-cases/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(testCaseId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeTestCaseResponse.fromJson(response);
}