disassociateRoutingProfileQueues method
Disassociates a set of queues from a routing profile.
Up to 10 queue references can be disassociated in a single API call. More than 10 queue references results in a single call results in an InvalidParameterException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter routingProfileId :
The identifier of the routing profile.
Parameter manualAssignmentQueueReferences :
The manual assignment queues to disassociate with this routing profile.
Parameter queueReferences :
The queues to disassociate from this routing profile.
Implementation
Future<void> disassociateRoutingProfileQueues({
required String instanceId,
required String routingProfileId,
List<RoutingProfileQueueReference>? manualAssignmentQueueReferences,
List<RoutingProfileQueueReference>? queueReferences,
}) async {
final $payload = <String, dynamic>{
if (manualAssignmentQueueReferences != null)
'ManualAssignmentQueueReferences': manualAssignmentQueueReferences,
if (queueReferences != null) 'QueueReferences': queueReferences,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/routing-profiles/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(routingProfileId)}/disassociate-queues',
exceptionFnMap: _exceptionFns,
);
}