listAttachedFilesConfigurations method
Provides summary information about the attached files configurations for the specified Connect Customer instance.
This API returns effective configurations (custom overrides or defaults) for each attachment scope. If no custom configuration exists for a scope, the default configuration values are returned.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter maxResults :
The maximum number of results to return per page. The default MaxResult
size is 100.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListAttachedFilesConfigurationsResponse>
listAttachedFilesConfigurations({
required String instanceId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/attached-files-configurations/${Uri.encodeComponent(instanceId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAttachedFilesConfigurationsResponse.fromJson(response);
}