listDataTableAttributes method
Returns all attributes for a specified data table. A maximum of 100 attributes per data table is allowed. Customers can request an increase by using Amazon Web Services Service Quotas. The response can be filtered by specific attribute IDs for CloudFormation integration.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter dataTableId :
The unique identifier for the data table whose attributes should be
listed.
Parameter instanceId :
The unique identifier for the Amazon Connect instance.
Parameter attributeIds :
Optional list of specific attribute IDs to retrieve. Used for
CloudFormation to effectively describe attributes by ID. If NextToken is
provided, this parameter is ignored.
Parameter maxResults :
The maximum number of data table attributes to return in one page of
results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListDataTableAttributesResponse> listDataTableAttributes({
required String dataTableId,
required String instanceId,
List<String>? attributeIds,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (attributeIds != null) 'AttributeIds': attributeIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/data-tables/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(dataTableId)}/attributes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataTableAttributesResponse.fromJson(response);
}