listDefaultVocabularies method
Lists the default vocabularies for the specified Connect Customer instance.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter languageCode :
The language code of the vocabulary entries. For a list of languages and
their corresponding language codes, see What
is Amazon Transcribe?
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListDefaultVocabulariesResponse> listDefaultVocabularies({
required String instanceId,
VocabularyLanguageCode? languageCode,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (languageCode != null) 'LanguageCode': languageCode.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/default-vocabulary-summary/${Uri.encodeComponent(instanceId)}',
exceptionFnMap: _exceptionFns,
);
return ListDefaultVocabulariesResponse.fromJson(response);
}