listUserNotifications method
Retrieves a paginated list of notifications for a specific user, including the notification status for that user.
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Amazon Connect instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter userId :
The identifier of the user.
Parameter maxResults :
The maximum number of results to return per page. Valid range is 1-1000.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response to retrieve the next page of results.
Implementation
Future<ListUserNotificationsResponse> listUserNotifications({
required String instanceId,
required String userId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/users/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(userId)}/notifications',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListUserNotificationsResponse.fromJson(response);
}