startContactRecording method
Starts recording the contact:
- If the API is called before the agent joins the call, recording starts when the agent joins the call.
- If the API is called after the agent joins the call, recording starts at the time of the API call.
You can use this API to override the recording behavior configured in the Set recording behavior block.
Only voice recordings are supported at this time.
May throw InternalServiceException.
May throw InvalidActiveRegionException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter contactId :
The identifier of the contact.
Parameter initialContactId :
The identifier of the contact. This is the identifier of the contact
associated with the first interaction with the contact center.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter voiceRecordingConfiguration :
The person being recorded.
Implementation
Future<void> startContactRecording({
required String contactId,
required String initialContactId,
required String instanceId,
required VoiceRecordingConfiguration voiceRecordingConfiguration,
}) async {
final $payload = <String, dynamic>{
'ContactId': contactId,
'InitialContactId': initialContactId,
'InstanceId': instanceId,
'VoiceRecordingConfiguration': voiceRecordingConfiguration,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/contact/start-recording',
exceptionFnMap: _exceptionFns,
);
}