untagContact method
Removes the specified tags from the contact resource. For more information about this API is used, see Set up granular billing for a detailed view of your Connect Customer usage.
May throw InternalServiceException.
May throw InvalidActiveRegionException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter contactId :
The identifier of the contact in this instance of Connect Customer.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter tagKeys :
A list of tag keys. Existing tags on the contact whose keys are members of
this list will be removed.
Implementation
Future<void> untagContact({
required String contactId,
required String instanceId,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'TagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/contact/tags/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(contactId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}