updateParticipantAuthentication method
Instructs Connect Customer to resume the authentication process. The subsequent actions depend on the request body contents:
- If a code is provided: Connect retrieves the identity information from Amazon Cognito and imports it into Connect Customer Profiles.
- If an error is provided: The error branch of the Authenticate Customer block is executed.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter state :
The state query parameter that was provided by Cognito in the
redirectUri. This will also match the state
parameter provided in the AuthenticationUrl from the GetAuthenticationUrl
response.
Parameter code :
The code query parameter provided by Cognito in the
redirectUri.
Parameter error :
The error query parameter provided by Cognito in the
redirectUri.
Parameter errorDescription :
The error_description parameter provided by Cognito in the
redirectUri.
Implementation
Future<void> updateParticipantAuthentication({
required String instanceId,
required String state,
String? code,
String? error,
String? errorDescription,
}) async {
final $payload = <String, dynamic>{
'InstanceId': instanceId,
'State': state,
if (code != null) 'Code': code,
if (error != null) 'Error': error,
if (errorDescription != null) 'ErrorDescription': errorDescription,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/contact/update-participant-authentication',
exceptionFnMap: _exceptionFns,
);
}