updateQuickConnectConfig method
Updates the configuration settings for the specified quick connect.
May throw InternalServiceException.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter instanceId :
The identifier of the Connect Customer instance. You can find
the instance ID in the Amazon Resource Name (ARN) of the instance.
Parameter quickConnectConfig :
Information about the configuration settings for the quick connect.
Parameter quickConnectId :
The identifier for the quick connect.
Implementation
Future<void> updateQuickConnectConfig({
required String instanceId,
required QuickConnectConfig quickConnectConfig,
required String quickConnectId,
}) async {
final $payload = <String, dynamic>{
'QuickConnectConfig': quickConnectConfig,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/quick-connects/${Uri.encodeComponent(instanceId)}/${Uri.encodeComponent(quickConnectId)}/config',
exceptionFnMap: _exceptionFns,
);
}