batchGetCaseRule method
Gets a batch of case rules. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter caseRules :
A list of case rule identifiers.
Parameter domainId :
Unique identifier of a Cases domain.
Implementation
Future<BatchGetCaseRuleResponse> batchGetCaseRule({
required List<CaseRuleIdentifier> caseRules,
required String domainId,
}) async {
final $payload = <String, dynamic>{
'caseRules': caseRules,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/domains/${Uri.encodeComponent(domainId)}/rules-batch',
exceptionFnMap: _exceptionFns,
);
return BatchGetCaseRuleResponse.fromJson(response);
}