createDomain method
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts. Each Amazon Connect instance can be associated with only one Cases domain.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name for your Cases domain. It must be unique for your Amazon Web
Services account.
Implementation
Future<CreateDomainResponse> createDomain({
required String name,
}) async {
final $payload = <String, dynamic>{
'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/domains',
exceptionFnMap: _exceptionFns,
);
return CreateDomainResponse.fromJson(response);
}