deleteCaseRule method
Deletes a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter caseRuleId :
Unique identifier of a case rule.
Parameter domainId :
Unique identifier of a Cases domain.
Implementation
Future<void> deleteCaseRule({
required String caseRuleId,
required String domainId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/domains/${Uri.encodeComponent(domainId)}/case-rules/${Uri.encodeComponent(caseRuleId)}',
exceptionFnMap: _exceptionFns,
);
}