listCasesForContact method
Lists cases for a given contact.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter contactArn :
A unique identifier of a contact in Amazon Connect.
Parameter domainId :
The unique identifier of the Cases domain.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListCasesForContactResponse> listCasesForContact({
required String contactArn,
required String domainId,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'contactArn': contactArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/domains/${Uri.encodeComponent(domainId)}/list-cases-for-contact',
exceptionFnMap: _exceptionFns,
);
return ListCasesForContactResponse.fromJson(response);
}