putCaseEventConfiguration method
Future<void>
putCaseEventConfiguration({
- required String domainId,
- required EventBridgeConfiguration eventBridge,
Adds case event publishing configuration. For a complete list of fields you can add to the event message, see Create case fields in the Amazon Connect Administrator Guide
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainId :
The unique identifier of the Cases domain.
Parameter eventBridge :
Configuration to enable EventBridge case event delivery and determine what
data is delivered.
Implementation
Future<void> putCaseEventConfiguration({
required String domainId,
required EventBridgeConfiguration eventBridge,
}) async {
final $payload = <String, dynamic>{
'eventBridge': eventBridge,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/domains/${Uri.encodeComponent(domainId)}/case-event-configuration',
exceptionFnMap: _exceptionFns,
);
}