updateCaseRule method
Updates a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter caseRuleId :
Unique identifier of a case rule.
Parameter domainId :
Unique identifier of a Cases domain.
Parameter description :
Description of a case rule.
Parameter name :
Name of the case rule.
Parameter rule :
Represents what rule type should take place, under what conditions.
Implementation
Future<void> updateCaseRule({
required String caseRuleId,
required String domainId,
String? description,
String? name,
CaseRuleDetails? rule,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (name != null) 'name': name,
if (rule != null) 'rule': rule,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/domains/${Uri.encodeComponent(domainId)}/case-rules/${Uri.encodeComponent(caseRuleId)}',
exceptionFnMap: _exceptionFns,
);
}