ConnectContactLens class
Amazon Connect Contact Lens enables you to analyze conversations between
customer and agents, by using speech transcription, natural language
processing, and intelligent search capabilities. It performs sentiment
analysis, detects issues, and enables you to automatically categorize
contacts.
Amazon Connect Contact Lens provides both real-time and post-call analytics of customer-agent conversations. For more information, see Analyze conversations using speech analytics in the Amazon Connect Administrator Guide.
Constructors
- ConnectContactLens({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
listRealtimeContactAnalysisSegments(
{required String contactId, required String instanceId, int? maxResults, String? nextToken}) → Future< ListRealtimeContactAnalysisSegmentsResponse> - Provides a list of analysis segments for a real-time analysis session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited