ControlCatalog class
Welcome to the Control Catalog API reference. This guide is for developers who need detailed information about how to programmatically identify and filter the common controls and related metadata that are available to Amazon Web Services customers. This API reference provides descriptions, syntax, and usage examples for each of the actions and data types that are supported by Control Catalog.
Use the following links to get started with the Control Catalog API:
- Actions: An alphabetical list of all Control Catalog API operations.
- Data types: An alphabetical list of all Control Catalog data types.
- Common parameters: Parameters that all operations can use.
- Common errors: Client and server errors that all operations can return.
Constructors
- ControlCatalog({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getControl(
{required String controlArn}) → Future< GetControlResponse> -
Returns details about a specific control, most notably a list of Amazon
Web Services Regions where this control is supported. Input a value for
the ControlArn parameter, in ARN form.
GetControlaccepts controltower or controlcatalog control ARNs as input. Returns a controlcatalog ARN format. -
listCommonControls(
{CommonControlFilter? commonControlFilter, int? maxResults, String? nextToken}) → Future< ListCommonControlsResponse> - Returns a paginated list of common controls from the Amazon Web Services Control Catalog.
-
listControlMappings(
{ControlMappingFilter? filter, int? maxResults, String? nextToken}) → Future< ListControlMappingsResponse> - Returns a paginated list of control mappings from the Control Catalog. Control mappings show relationships between controls and other entities, such as common controls or compliance frameworks.
-
listControls(
{ControlFilter? filter, int? maxResults, String? nextToken}) → Future< ListControlsResponse> - Returns a paginated list of all available controls in the Control Catalog library. Allows you to discover available controls. The list of controls is given as structures of type controlSummary. The ARN is returned in the global controlcatalog format, as shown in the examples.
-
listDomains(
{int? maxResults, String? nextToken}) → Future< ListDomainsResponse> - Returns a paginated list of domains from the Control Catalog.
-
listObjectives(
{int? maxResults, String? nextToken, ObjectiveFilter? objectiveFilter}) → Future< ListObjectivesResponse> - Returns a paginated list of objectives from the Control Catalog.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited