listControlMappings method
Returns a paginated list of control mappings from the Control Catalog. Control mappings show relationships between controls and other entities, such as common controls or compliance frameworks.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
An optional filter that narrows the results to specific control mappings
based on control ARNs, common control ARNs, or mapping types.
Parameter maxResults :
The maximum number of results on a page or for an API request call.
Parameter nextToken :
The pagination token that's used to fetch the next set of results.
Implementation
Future<ListControlMappingsResponse> listControlMappings({
ControlMappingFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'Filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-control-mappings',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListControlMappingsResponse.fromJson(response);
}