createLandingZone method
Creates a new landing zone. This API call starts an asynchronous operation that creates and configures a landing zone, based on the parameters specified in the manifest JSON file.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter version :
The landing zone version, for example, 3.0.
Parameter manifest :
The manifest JSON file is a text file that describes your Amazon Web
Services resources. For examples, review Launch
your landing zone.
Parameter remediationTypes :
Specifies the types of remediation actions to apply when creating the
landing zone, such as automatic drift correction or compliance
enforcement.
Parameter tags :
Tags to be applied to the landing zone.
Implementation
Future<CreateLandingZoneOutput> createLandingZone({
required String version,
Object? manifest,
List<RemediationType>? remediationTypes,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'version': version,
if (manifest != null) 'manifest': manifest,
if (remediationTypes != null)
'remediationTypes': remediationTypes.map((e) => e.value).toList(),
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/create-landingzone',
exceptionFnMap: _exceptionFns,
);
return CreateLandingZoneOutput.fromJson(response);
}