listLandingZones method
Returns the landing zone ARN for the landing zone deployed in your managed account. This API also creates an ARN for existing accounts that do not yet have a landing zone ARN.
Returns one landing zone ARN.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of returned landing zone ARNs, which is one.
Parameter nextToken :
The token to continue the list from a previous API call with the same
parameters.
Implementation
Future<ListLandingZonesOutput> listLandingZones({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-landingzones',
exceptionFnMap: _exceptionFns,
);
return ListLandingZonesOutput.fromJson(response);
}