putReportDefinition method
Creates a new report using the description that you provide.
May throw DuplicateReportNameException.
May throw InternalErrorException.
May throw ReportLimitReachedException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter reportDefinition :
Represents the output of the PutReportDefinition operation. The content
consists of the detailed metadata and data file information.
Parameter tags :
The tags to be assigned to the report definition resource.
Implementation
Future<void> putReportDefinition({
required ReportDefinition reportDefinition,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrigamiServiceGatewayService.PutReportDefinition'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReportDefinition': reportDefinition,
if (tags != null) 'Tags': tags,
},
);
}