cost_optimization_hub_2022_07_26 library
Classes
- AwsClientCredentials
- AWS credentials.
- CostOptimizationHub
- You can use the Cost Optimization Hub API to programmatically identify, filter, aggregate, and quantify savings for your cost optimization recommendations across multiple Amazon Web Services Regions and Amazon Web Services accounts in your organization.