batchGetCalculatedAttributeForProfile method
Fetch the possible attribute values given the attribute name.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter calculatedAttributeName :
The unique name of the calculated attribute.
Parameter domainName :
The unique name of the domain.
Parameter profileIds :
List of unique identifiers for customer profiles to retrieve.
Parameter conditionOverrides :
Overrides the condition block within the original calculated attribute
definition.
Implementation
Future<BatchGetCalculatedAttributeForProfileResponse>
batchGetCalculatedAttributeForProfile({
required String calculatedAttributeName,
required String domainName,
required List<String> profileIds,
ConditionOverrides? conditionOverrides,
}) async {
final $payload = <String, dynamic>{
'ProfileIds': profileIds,
if (conditionOverrides != null) 'ConditionOverrides': conditionOverrides,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/calculated-attributes/${Uri.encodeComponent(calculatedAttributeName)}/batch-get-for-profiles',
exceptionFnMap: _exceptionFns,
);
return BatchGetCalculatedAttributeForProfileResponse.fromJson(response);
}