getEventStream method
Returns information about the specified event stream in a specific domain.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter eventStreamName :
The name of the event stream provided during create operations.
Implementation
Future<GetEventStreamResponse> getEventStream({
required String domainName,
required String eventStreamName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/event-streams/${Uri.encodeComponent(eventStreamName)}',
exceptionFnMap: _exceptionFns,
);
return GetEventStreamResponse.fromJson(response);
}