getMatches method
Before calling this API, use CreateDomain
or UpdateDomain
to enable identity resolution: set Matching to true.
GetMatches returns potentially matching profiles, based on the results of the latest run of a machine learning process.
After the Identity Resolution Job completes, use the GetMatches
API to return and review the results. Or, if you have configured
ExportingConfig in the MatchingRequest, you can
download the results from S3.
Amazon Connect uses the following profile attributes to identify matches:
- PhoneNumber
- HomePhoneNumber
- BusinessPhoneNumber
- MobilePhoneNumber
- EmailAddress
- PersonalEmailAddress
- BusinessEmailAddress
- FullName
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<GetMatchesResponse> getMatches({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/domains/${Uri.encodeComponent(domainName)}/matches',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetMatchesResponse.fromJson(response);
}