getProfileHistoryRecord method
Returns a history record for a specific profile, for a specific domain.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain for which to return a profile history
record.
Parameter id :
The unique identifier of the profile history record to return.
Parameter profileId :
The unique identifier of the profile for which to return a history record.
Implementation
Future<GetProfileHistoryRecordResponse> getProfileHistoryRecord({
required String domainName,
required String id,
required String profileId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/profiles/${Uri.encodeComponent(profileId)}/history-records/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return GetProfileHistoryRecordResponse.fromJson(response);
}