listAccountIntegrations method
Lists all of the integrations associated to a specific URI in the AWS account.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter uri :
The URI of the S3 bucket or any other type of data source.
Parameter includeHidden :
Boolean to indicate if hidden integration should be returned. Defaults to
False.
Parameter maxResults :
The maximum number of objects returned per page.
Parameter nextToken :
The pagination token from the previous ListAccountIntegrations API call.
Implementation
Future<ListAccountIntegrationsResponse> listAccountIntegrations({
required String uri,
bool? includeHidden,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (includeHidden != null) 'include-hidden': [includeHidden.toString()],
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final $payload = <String, dynamic>{
'Uri': uri,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/integrations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAccountIntegrationsResponse.fromJson(response);
}