listCalculatedAttributesForProfile method
Retrieve a list of calculated attributes for a customer profile.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain.
Parameter profileId :
The unique identifier of a customer profile.
Parameter maxResults :
The maximum number of calculated attributes returned per page.
Parameter nextToken :
The pagination token from the previous call to
ListCalculatedAttributesForProfile.
Implementation
Future<ListCalculatedAttributesForProfileResponse>
listCalculatedAttributesForProfile({
required String domainName,
required String profileId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/profile/${Uri.encodeComponent(profileId)}/calculated-attributes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCalculatedAttributesForProfileResponse.fromJson(response);
}