stopUploadJob method
This API stops the processing of an upload job.
May throw AccessDeniedException.
May throw BadRequestException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter domainName :
The unique name of the domain containing the upload job to stop.
Parameter jobId :
The unique identifier of the upload job to stop.
Implementation
Future<void> stopUploadJob({
required String domainName,
required String jobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PUT',
requestUri:
'/domains/${Uri.encodeComponent(domainName)}/upload-jobs/${Uri.encodeComponent(jobId)}/stop',
exceptionFnMap: _exceptionFns,
);
}