listRulesets method
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return in this request.
Parameter nextToken :
A token generated by DataBrew that specifies where to continue pagination
if a previous request was truncated. To get the next set of pages, pass in
the NextToken value from the response object of the previous page call.
Parameter targetArn :
The Amazon Resource Name (ARN) of a resource (dataset). Using this
parameter indicates to return only those rulesets that are associated with
the specified resource.
Implementation
Future<ListRulesetsResponse> listRulesets({
int? maxResults,
String? nextToken,
String? targetArn,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (targetArn != null) 'targetArn': [targetArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/rulesets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRulesetsResponse.fromJson(response);
}