sendProjectSessionAction method
Performs a recipe step within an interactive DataBrew session that's currently open.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter name :
The name of the project to apply the action to.
Parameter clientSessionId :
A unique identifier for an interactive session that's currently open and
ready for work. The action will be performed on this session.
Parameter preview :
If true, the result of the recipe step will be returned, but not applied.
Parameter stepIndex :
The index from which to preview a step. This index is used to preview the
result of steps that have already been applied, so that the resulting view
frame is from earlier in the view frame stack.
Implementation
Future<SendProjectSessionActionResponse> sendProjectSessionAction({
required String name,
String? clientSessionId,
bool? preview,
RecipeStep? recipeStep,
int? stepIndex,
ViewFrame? viewFrame,
}) async {
_s.validateNumRange(
'stepIndex',
stepIndex,
0,
1152921504606846976,
);
final $payload = <String, dynamic>{
if (clientSessionId != null) 'ClientSessionId': clientSessionId,
if (preview != null) 'Preview': preview,
if (recipeStep != null) 'RecipeStep': recipeStep,
if (stepIndex != null) 'StepIndex': stepIndex,
if (viewFrame != null) 'ViewFrame': viewFrame,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/projects/${Uri.encodeComponent(name)}/sendProjectSessionAction',
exceptionFnMap: _exceptionFns,
);
return SendProjectSessionActionResponse.fromJson(response);
}