startProjectSession method
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter name :
The name of the project to act upon.
Parameter assumeControl :
A value that, if true, enables you to take control of a session, even if a
different client is currently accessing the project.
Implementation
Future<StartProjectSessionResponse> startProjectSession({
required String name,
bool? assumeControl,
}) async {
final $payload = <String, dynamic>{
if (assumeControl != null) 'AssumeControl': assumeControl,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/projects/${Uri.encodeComponent(name)}/startProjectSession',
exceptionFnMap: _exceptionFns,
);
return StartProjectSessionResponse.fromJson(response);
}