tagResource method
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The DataBrew resource to which tags should be added. The value for this
parameter is an Amazon Resource Name (ARN). For DataBrew, you can tag a
dataset, a job, a project, or a recipe.
Parameter tags :
One or more tags to be assigned to the resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}