data_sync library
Classes
- AwsClientCredentials
- AWS credentials.
- DataSync
- DataSync is an online data movement service that simplifies data migration and helps you quickly, easily, and securely transfer your file or object data to, from, and between Amazon Web Services storage services.