describeTaskExecution method
Provides information about an execution of your DataSync task. You can use this operation to help monitor the progress of an ongoing data transfer or check the results of the transfer.
May throw InternalException.
May throw InvalidRequestException.
Parameter taskExecutionArn :
Specifies the Amazon Resource Name (ARN) of the task execution that you
want information about.
Implementation
Future<DescribeTaskExecutionResponse> describeTaskExecution({
required String taskExecutionArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'FmrsService.DescribeTaskExecution'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TaskExecutionArn': taskExecutionArn,
},
);
return DescribeTaskExecutionResponse.fromJson(jsonResponse.body);
}