updateLocationFsxLustre method

Future<void> updateLocationFsxLustre({
  1. required String locationArn,
  2. String? subdirectory,
})

Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you're using with DataSync.

For more information, see Configuring DataSync transfers with FSx for Lustre.

May throw InternalException. May throw InvalidRequestException.

Parameter locationArn : Specifies the Amazon Resource Name (ARN) of the FSx for Lustre transfer location that you're updating.

Parameter subdirectory : Specifies a mount path for your FSx for Lustre file system. The path can include subdirectories.

When the location is used as a source, DataSync reads data from the mount path. When the location is used as a destination, DataSync writes data to the mount path. If you don't include this parameter, DataSync uses the file system's root directory (/).

Implementation

Future<void> updateLocationFsxLustre({
  required String locationArn,
  String? subdirectory,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'FmrsService.UpdateLocationFsxLustre'
  };
  await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'LocationArn': locationArn,
      if (subdirectory != null) 'Subdirectory': subdirectory,
    },
  );
}