batchGetAttributesMetadata method
Gets the attribute metadata.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter attributeIdentifiers :
The attribute identifier.
Parameter domainIdentifier :
The domain ID where you want to get the attribute metadata.
Parameter entityIdentifier :
The entity ID for which you want to get attribute metadata.
Parameter entityType :
The entity type for which you want to get attribute metadata.
Parameter entityRevision :
The entity revision for which you want to get attribute metadata.
Implementation
Future<BatchGetAttributesMetadataOutput> batchGetAttributesMetadata({
required List<String> attributeIdentifiers,
required String domainIdentifier,
required String entityIdentifier,
required AttributeEntityType entityType,
String? entityRevision,
}) async {
final $query = <String, List<String>>{
'attributeIdentifier': attributeIdentifiers,
if (entityRevision != null) 'entityRevision': [entityRevision],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/attributes-metadata',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return BatchGetAttributesMetadataOutput.fromJson(response);
}