createEnvironmentProfile method
Creates an Amazon DataZone environment profile.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain in which this environment profile is
created.
Parameter environmentBlueprintIdentifier :
The ID of the blueprint with which this environment profile is created.
Parameter name :
The name of this Amazon DataZone environment profile.
Parameter projectIdentifier :
The identifier of the project in which to create the environment profile.
Parameter awsAccountId :
The Amazon Web Services account in which the Amazon DataZone environment
is created.
Parameter awsAccountRegion :
The Amazon Web Services region in which this environment profile is
created.
Parameter description :
The description of this Amazon DataZone environment profile.
Parameter userParameters :
The user parameters of this Amazon DataZone environment profile.
Implementation
Future<CreateEnvironmentProfileOutput> createEnvironmentProfile({
required String domainIdentifier,
required String environmentBlueprintIdentifier,
required String name,
required String projectIdentifier,
String? awsAccountId,
String? awsAccountRegion,
String? description,
List<EnvironmentParameter>? userParameters,
}) async {
final $payload = <String, dynamic>{
'environmentBlueprintIdentifier': environmentBlueprintIdentifier,
'name': name,
'projectIdentifier': projectIdentifier,
if (awsAccountId != null) 'awsAccountId': awsAccountId,
if (awsAccountRegion != null) 'awsAccountRegion': awsAccountRegion,
if (description != null) 'description': description,
if (userParameters != null) 'userParameters': userParameters,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environment-profiles',
exceptionFnMap: _exceptionFns,
);
return CreateEnvironmentProfileOutput.fromJson(response);
}