deleteAssetType method
Deletes an asset type in Amazon DataZone.
Prerequisites:
- The asset type must exist in the domain.
- You must have DeleteAssetType permission.
- The asset type must not be in use (e.g., assigned to any asset). If used, deletion will fail.
- You should retrieve the asset type using get-asset-type to confirm its presence before deletion.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain in which the asset type is deleted.
Parameter identifier :
The identifier of the asset type that is deleted.
Implementation
Future<void> deleteAssetType({
required String domainIdentifier,
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/asset-types/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}