deleteDomain method
Deletes a Amazon DataZone domain.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The identifier of the Amazon Web Services domain that is to be deleted.
Parameter clientToken :
A unique, case-sensitive identifier that is provided to ensure the
idempotency of the request.
Parameter skipDeletionCheck :
Specifies the optional flag to delete all child entities within the
domain.
Implementation
Future<DeleteDomainOutput> deleteDomain({
required String identifier,
String? clientToken,
bool? skipDeletionCheck,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
if (skipDeletionCheck != null)
'skipDeletionCheck': [skipDeletionCheck.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v2/domains/${Uri.encodeComponent(identifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeleteDomainOutput.fromJson(response);
}