deleteDomainUnit method
Deletes a domain unit.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where you want to delete a domain unit.
Parameter identifier :
The ID of the domain unit that you want to delete.
Implementation
Future<void> deleteDomainUnit({
required String domainIdentifier,
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/domain-units/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}