disassociateGovernedTerms method
Disassociates restricted terms from an asset.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where you want to disassociate restricted terms from
an asset.
Parameter entityIdentifier :
The ID of an asset from which you want to disassociate restricted terms.
Parameter entityType :
The type of the asset from which you want to disassociate restricted
terms.
Parameter governedGlossaryTerms :
The restricted glossary terms that you want to disassociate from an asset.
Implementation
Future<void> disassociateGovernedTerms({
required String domainIdentifier,
required String entityIdentifier,
required GovernedEntityType entityType,
required List<String> governedGlossaryTerms,
}) async {
final $payload = <String, dynamic>{
'governedGlossaryTerms': governedGlossaryTerms,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/disassociate-governed-terms',
exceptionFnMap: _exceptionFns,
);
}