getEnvironmentCredentials method
Gets the credentials of an environment in Amazon DataZone.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain in which this environment and its
credentials exist.
Parameter environmentIdentifier :
The ID of the environment whose credentials this operation gets.
Implementation
Future<GetEnvironmentCredentialsOutput> getEnvironmentCredentials({
required String domainIdentifier,
required String environmentIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environments/${Uri.encodeComponent(environmentIdentifier)}/credentials',
exceptionFnMap: _exceptionFns,
);
return GetEnvironmentCredentialsOutput.fromJson(response);
}