getListing method
Gets a listing (a record of an asset at a given time). If you specify a listing version, only details that are specific to that version are returned.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain.
Parameter identifier :
The ID of the listing.
Parameter listingRevision :
The revision of the listing.
Implementation
Future<GetListingOutput> getListing({
required String domainIdentifier,
required String identifier,
String? listingRevision,
}) async {
final $query = <String, List<String>>{
if (listingRevision != null) 'listingRevision': [listingRevision],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/listings/${Uri.encodeComponent(identifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetListingOutput.fromJson(response);
}