getTimeSeriesDataPoint method
Gets the existing data point for the asset.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain that houses the asset for which you
want to get the data point.
Parameter entityIdentifier :
The ID of the asset for which you want to get the data point.
Parameter entityType :
The type of the asset for which you want to get the data point.
Parameter formName :
The name of the time series form that houses the data point that you want
to get.
Parameter identifier :
The ID of the data point that you want to get.
Implementation
Future<GetTimeSeriesDataPointOutput> getTimeSeriesDataPoint({
required String domainIdentifier,
required String entityIdentifier,
required TimeSeriesEntityType entityType,
required String formName,
required String identifier,
}) async {
final $query = <String, List<String>>{
'formName': [formName],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/time-series-data-points/${Uri.encodeComponent(identifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetTimeSeriesDataPointOutput.fromJson(response);
}