listAccountsInAccountPool method
Lists the accounts in the specified account pool.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain in which the accounts in the specified account pool
are to be listed.
Parameter identifier :
The ID of the account pool whose accounts are to be listed.
Parameter maxResults :
The maximum number of accounts to return in a single call to
ListAccountsInAccountPool. When the number of accounts to be listed is
greater than the value of MaxResults, the response contains a NextToken
value that you can use in a subsequent call to ListAccountsInAccountPool
to list the next set of accounts.
Parameter nextToken :
When the number of accounts is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value for MaxResults
that is less than the number of accounts, the response includes a
pagination token named NextToken. You can specify this NextToken value in
a subsequent call to ListAccountsInAccountPool to list the next set of
accounts.
Implementation
Future<ListAccountsInAccountPoolOutput> listAccountsInAccountPool({
required String domainIdentifier,
required String identifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/account-pools/${Uri.encodeComponent(identifier)}/accounts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAccountsInAccountPoolOutput.fromJson(response);
}