listLineageEvents method
Lists lineage events.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where you want to list lineage events.
Parameter maxResults :
The maximum number of lineage events to return in a single call to
ListLineageEvents. When the number of lineage events to be listed is
greater than the value of MaxResults, the response contains a NextToken
value that you can use in a subsequent call to ListLineageEvents to list
the next set of lineage events.
Parameter nextToken :
When the number of lineage events is greater than the default value for
the MaxResults parameter, or if you explicitly specify a value for
MaxResults that is less than the number of lineage events, the response
includes a pagination token named NextToken. You can specify this
NextToken value in a subsequent call to ListLineageEvents to list the next
set of lineage events.
Parameter processingStatus :
The processing status of a lineage event.
Parameter sortOrder :
The sort order of the lineage events.
Parameter timestampAfter :
The after timestamp of a lineage event.
Parameter timestampBefore :
The before timestamp of a lineage event.
Implementation
Future<ListLineageEventsOutput> listLineageEvents({
required String domainIdentifier,
int? maxResults,
String? nextToken,
LineageEventProcessingStatus? processingStatus,
SortOrder? sortOrder,
DateTime? timestampAfter,
DateTime? timestampBefore,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (processingStatus != null)
'processingStatus': [processingStatus.value],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
if (timestampAfter != null)
'timestampAfter': [_s.iso8601ToJson(timestampAfter).toString()],
if (timestampBefore != null)
'timestampBefore': [_s.iso8601ToJson(timestampBefore).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/lineage/events',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListLineageEventsOutput.fromJson(response);
}