listNotebookRuns method
Lists notebook runs in Amazon SageMaker Unified Studio.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon SageMaker Unified Studio domain in which to
list notebook runs.
Parameter owningProjectIdentifier :
The identifier of the project that owns the notebook runs.
Parameter maxResults :
The maximum number of notebook runs to return in a single call. When the
number of notebook runs exceeds the value of MaxResults, the
response contains a NextToken value.
Parameter nextToken :
When the number of notebook runs is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value
for MaxResults that is less than the number of notebook runs,
the response includes a pagination token named NextToken. You
can specify this NextToken value in a subsequent call to
ListNotebookRuns to list the next set of notebook runs.
Parameter notebookIdentifier :
The identifier of the notebook to filter runs by.
Parameter scheduleIdentifier :
The identifier of the schedule to filter notebook runs by.
Parameter sortOrder :
The sort order for the results.
Parameter status :
The status to filter notebook runs by.
Implementation
Future<ListNotebookRunsOutput> listNotebookRuns({
required String domainIdentifier,
required String owningProjectIdentifier,
int? maxResults,
String? nextToken,
String? notebookIdentifier,
String? scheduleIdentifier,
SortOrder? sortOrder,
NotebookRunStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
'owningProjectIdentifier': [owningProjectIdentifier],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (notebookIdentifier != null)
'notebookIdentifier': [notebookIdentifier],
if (scheduleIdentifier != null)
'scheduleIdentifier': [scheduleIdentifier],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/notebook-runs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListNotebookRunsOutput.fromJson(response);
}