listSubscriptionRequests method
- required String domainIdentifier,
- String? approverProjectId,
- int? maxResults,
- String? nextToken,
- String? owningGroupId,
- String? owningIamPrincipalArn,
- String? owningProjectId,
- String? owningUserId,
- SortKey? sortBy,
- SortOrder? sortOrder,
- SubscriptionRequestStatus? status,
- String? subscribedListingId,
Lists Amazon DataZone subscription requests.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain.
Parameter approverProjectId :
The identifier of the subscription request approver's project.
Parameter maxResults :
The maximum number of subscription requests to return in a single call to
ListSubscriptionRequests. When the number of subscription
requests to be listed is greater than the value of
MaxResults, the response contains a NextToken
value that you can use in a subsequent call to
ListSubscriptionRequests to list the next set of subscription
requests.
Parameter nextToken :
When the number of subscription requests is greater than the default value
for the MaxResults parameter, or if you explicitly specify a
value for MaxResults that is less than the number of
subscription requests, the response includes a pagination token named
NextToken. You can specify this NextToken value
in a subsequent call to ListSubscriptionRequests to list the
next set of subscription requests.
Parameter owningGroupId :
The ID of the owning group.
Parameter owningIamPrincipalArn :
The ARN of the owning IAM principal.
Parameter owningProjectId :
The identifier of the project for the subscription requests.
Parameter owningUserId :
The ID of the owning user.
Parameter sortBy :
Specifies the way to sort the results of this action.
Parameter sortOrder :
Specifies the sort order for the results of this action.
Parameter status :
Specifies the status of the subscription requests.
Parameter subscribedListingId :
The identifier of the subscribed listing.
Implementation
Future<ListSubscriptionRequestsOutput> listSubscriptionRequests({
required String domainIdentifier,
String? approverProjectId,
int? maxResults,
String? nextToken,
String? owningGroupId,
String? owningIamPrincipalArn,
String? owningProjectId,
String? owningUserId,
SortKey? sortBy,
SortOrder? sortOrder,
SubscriptionRequestStatus? status,
String? subscribedListingId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (approverProjectId != null) 'approverProjectId': [approverProjectId],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (owningGroupId != null) 'owningGroupId': [owningGroupId],
if (owningIamPrincipalArn != null)
'owningIamPrincipalArn': [owningIamPrincipalArn],
if (owningProjectId != null) 'owningProjectId': [owningProjectId],
if (owningUserId != null) 'owningUserId': [owningUserId],
if (sortBy != null) 'sortBy': [sortBy.value],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
if (status != null) 'status': [status.value],
if (subscribedListingId != null)
'subscribedListingId': [subscribedListingId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscription-requests',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSubscriptionRequestsOutput.fromJson(response);
}