listSubscriptionTargets method
Lists subscription targets in Amazon DataZone.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain where you want to list
subscription targets.
Parameter environmentIdentifier :
The identifier of the environment where you want to list subscription
targets.
Parameter maxResults :
The maximum number of subscription targets to return in a single call to
ListSubscriptionTargets. When the number of subscription
targets to be listed is greater than the value of MaxResults,
the response contains a NextToken value that you can use in a
subsequent call to ListSubscriptionTargets to list the next
set of subscription targets.
Parameter nextToken :
When the number of subscription targets is greater than the default value
for the MaxResults parameter, or if you explicitly specify a
value for MaxResults that is less than the number of
subscription targets, the response includes a pagination token named
NextToken. You can specify this NextToken value
in a subsequent call to ListSubscriptionTargets to list the
next set of subscription targets.
Parameter sortBy :
Specifies the way in which the results of this action are to be sorted.
Parameter sortOrder :
Specifies the sort order for the results of this action.
Implementation
Future<ListSubscriptionTargetsOutput> listSubscriptionTargets({
required String domainIdentifier,
required String environmentIdentifier,
int? maxResults,
String? nextToken,
SortKey? sortBy,
SortOrder? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (sortBy != null) 'sortBy': [sortBy.value],
if (sortOrder != null) 'sortOrder': [sortOrder.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environments/${Uri.encodeComponent(environmentIdentifier)}/subscription-targets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSubscriptionTargetsOutput.fromJson(response);
}