listTimeSeriesDataPoints method
Lists time series data points.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain that houses the assets for which you
want to list time series data points.
Parameter entityIdentifier :
The ID of the asset for which you want to list data points.
Parameter entityType :
The type of the asset for which you want to list data points.
Parameter formName :
The name of the time series data points form.
Parameter endedAt :
The timestamp at which the data points that you wanted to list ended.
Parameter maxResults :
The maximum number of data points to return in a single call to
ListTimeSeriesDataPoints. When the number of data points to be listed is
greater than the value of MaxResults, the response contains a NextToken
value that you can use in a subsequent call to ListTimeSeriesDataPoints to
list the next set of data points.
Parameter nextToken :
When the number of data points is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value for MaxResults
that is less than the number of data points, the response includes a
pagination token named NextToken. You can specify this NextToken value in
a subsequent call to ListTimeSeriesDataPoints to list the next set of data
points.
Parameter startedAt :
The timestamp at which the data points that you want to list started.
Implementation
Future<ListTimeSeriesDataPointsOutput> listTimeSeriesDataPoints({
required String domainIdentifier,
required String entityIdentifier,
required TimeSeriesEntityType entityType,
required String formName,
DateTime? endedAt,
int? maxResults,
String? nextToken,
DateTime? startedAt,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
'formName': [formName],
if (endedAt != null) 'endedAt': [_s.iso8601ToJson(endedAt).toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (startedAt != null)
'startedAt': [_s.iso8601ToJson(startedAt).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/time-series-data-points',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListTimeSeriesDataPointsOutput.fromJson(response);
}