postTimeSeriesDataPoints method
Posts time series data points to Amazon DataZone for the specified asset.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the Amazon DataZone domain in which you want to post time series
data points.
Parameter entityIdentifier :
The ID of the asset for which you want to post time series data points.
Parameter entityType :
The type of the asset for which you want to post data points.
Parameter forms :
The forms that contain the data points that you want to post.
Parameter clientToken :
A unique, case-sensitive identifier that is provided to ensure the
idempotency of the request.
Implementation
Future<PostTimeSeriesDataPointsOutput> postTimeSeriesDataPoints({
required String domainIdentifier,
required String entityIdentifier,
required TimeSeriesEntityType entityType,
required List<TimeSeriesDataPointFormInput> forms,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'forms': forms,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/time-series-data-points',
exceptionFnMap: _exceptionFns,
);
return PostTimeSeriesDataPointsOutput.fromJson(response);
}