removeEntityOwner method
Removes an owner from an entity.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The ID of the domain where you want to remove an owner from an entity.
Parameter entityIdentifier :
The ID of the entity from which you want to remove an owner.
Parameter entityType :
The type of the entity from which you want to remove an owner.
Parameter owner :
The owner that you want to remove from an entity.
Parameter clientToken :
A unique, case-sensitive identifier that is provided to ensure the
idempotency of the request.
Implementation
Future<void> removeEntityOwner({
required String domainIdentifier,
required String entityIdentifier,
required DataZoneEntityType entityType,
required OwnerProperties owner,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'owner': owner,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/entities/${Uri.encodeComponent(entityType.value)}/${Uri.encodeComponent(entityIdentifier)}/removeOwner',
exceptionFnMap: _exceptionFns,
);
}