updateEnvironment method
Updates the specified environment in Amazon DataZone.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the domain in which the environment is to be updated.
Parameter identifier :
The identifier of the environment that is to be updated.
Parameter blueprintVersion :
The blueprint version to which the environment should be updated. You can
only specify the following string for this parameter: latest.
Parameter description :
The description to be updated as part of the
UpdateEnvironment action.
Parameter environmentConfigurationName :
The configuration name of the environment.
Parameter glossaryTerms :
The glossary terms to be updated as part of the
UpdateEnvironment action.
Parameter name :
The name to be updated as part of the UpdateEnvironment
action.
Parameter userParameters :
The user parameters of the environment.
Implementation
Future<UpdateEnvironmentOutput> updateEnvironment({
required String domainIdentifier,
required String identifier,
String? blueprintVersion,
String? description,
String? environmentConfigurationName,
List<String>? glossaryTerms,
String? name,
List<EnvironmentParameter>? userParameters,
}) async {
final $payload = <String, dynamic>{
if (blueprintVersion != null) 'blueprintVersion': blueprintVersion,
if (description != null) 'description': description,
if (environmentConfigurationName != null)
'environmentConfigurationName': environmentConfigurationName,
if (glossaryTerms != null) 'glossaryTerms': glossaryTerms,
if (name != null) 'name': name,
if (userParameters != null) 'userParameters': userParameters,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/environments/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateEnvironmentOutput.fromJson(response);
}