updateGlossary method
Updates the business glossary in Amazon DataZone.
Prerequisites:
- The glossary must exist in the given domain.
-
The caller must have the
datazone:UpdateGlossarypermission to update it. - When updating the name, the new name must be unique within the domain.
- The glossary must not be deleted or in a terminal state.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which a business glossary
is to be updated.
Parameter identifier :
The identifier of the business glossary to be updated.
Parameter clientToken :
A unique, case-sensitive identifier that is provided to ensure the
idempotency of the request.
Parameter description :
The description to be updated as part of the UpdateGlossary
action.
Parameter name :
The name to be updated as part of the UpdateGlossary action.
Parameter status :
The status to be updated as part of the UpdateGlossary
action.
Implementation
Future<UpdateGlossaryOutput> updateGlossary({
required String domainIdentifier,
required String identifier,
String? clientToken,
String? description,
String? name,
GlossaryStatus? status,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'description': description,
if (name != null) 'name': name,
if (status != null) 'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/glossaries/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateGlossaryOutput.fromJson(response);
}