updateGroupProfile method
Updates the specified group profile in Amazon DataZone.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which a group profile is
updated.
Parameter groupIdentifier :
The identifier of the group profile that is updated.
Parameter status :
The status of the group profile that is updated.
Implementation
Future<UpdateGroupProfileOutput> updateGroupProfile({
required String domainIdentifier,
required String groupIdentifier,
required GroupProfileStatus status,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/group-profiles/${Uri.encodeComponent(groupIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateGroupProfileOutput.fromJson(response);
}