updateSubscriptionGrantStatus method
Updates the status of the specified subscription grant status in Amazon DataZone.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter assetIdentifier :
The identifier of the asset the subscription grant status of which is to
be updated.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which a subscription grant
status is to be updated.
Parameter identifier :
The identifier of the subscription grant the status of which is to be
updated.
Parameter status :
The status to be updated as part of the
UpdateSubscriptionGrantStatus action.
Parameter failureCause :
Specifies the error message that is returned if the operation cannot be
successfully completed.
Parameter targetName :
The target name to be updated as part of the
UpdateSubscriptionGrantStatus action.
Implementation
Future<UpdateSubscriptionGrantStatusOutput> updateSubscriptionGrantStatus({
required String assetIdentifier,
required String domainIdentifier,
required String identifier,
required SubscriptionGrantStatus status,
FailureCause? failureCause,
String? targetName,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
if (failureCause != null) 'failureCause': failureCause,
if (targetName != null) 'targetName': targetName,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/subscription-grants/${Uri.encodeComponent(identifier)}/status/${Uri.encodeComponent(assetIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateSubscriptionGrantStatusOutput.fromJson(response);
}