updateUserProfile method
Updates the specified user profile in Amazon DataZone.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainIdentifier :
The identifier of the Amazon DataZone domain in which a user profile is
updated.
Parameter status :
The status of the user profile that are to be updated.
Parameter userIdentifier :
The identifier of the user whose user profile is to be updated.
Parameter sessionName :
The session name for IAM role sessions.
Parameter type :
The type of the user profile that are to be updated.
Implementation
Future<UpdateUserProfileOutput> updateUserProfile({
required String domainIdentifier,
required UserProfileStatus status,
required String userIdentifier,
String? sessionName,
UserProfileType? type,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
if (sessionName != null) 'sessionName': sessionName,
if (type != null) 'type': type.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v2/domains/${Uri.encodeComponent(domainIdentifier)}/user-profiles/${Uri.encodeComponent(userIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateUserProfileOutput.fromJson(response);
}