cancelMetadataModelCreation method
Cancels a single metadata model creation operation that was started with
StartMetadataModelCreation.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter migrationProjectIdentifier :
The migration project name or Amazon Resource Name (ARN).
Parameter requestIdentifier :
The identifier for the metadata model creation operation to cancel. This
operation was initiated by StartMetadataModelCreation.
Implementation
Future<CancelMetadataModelCreationResponse> cancelMetadataModelCreation({
required String migrationProjectIdentifier,
required String requestIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.CancelMetadataModelCreation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MigrationProjectIdentifier': migrationProjectIdentifier,
'RequestIdentifier': requestIdentifier,
},
);
return CancelMetadataModelCreationResponse.fromJson(jsonResponse.body);
}