createReplicationInstance method
- required String replicationInstanceClass,
- required String replicationInstanceIdentifier,
- int? allocatedStorage,
- bool? autoMinorVersionUpgrade,
- String? availabilityZone,
- String? dnsNameServers,
- String? engineVersion,
- KerberosAuthenticationSettings? kerberosAuthenticationSettings,
- String? kmsKeyId,
- bool? multiAZ,
- String? networkType,
- String? preferredMaintenanceWindow,
- bool? publiclyAccessible,
- String? replicationSubnetGroupIdentifier,
- String? resourceIdentifier,
- List<
Tag> ? tags, - List<
String> ? vpcSecurityGroupIds,
Creates the replication instance using the specified parameters.
DMS requires that your account have certain roles with appropriate permissions before you can create a replication instance. For information on the required roles, see Creating the IAM Roles to Use With the CLI and DMS API. For information on the required permissions, see IAM Permissions Needed to Use DMS.
May throw AccessDeniedFault.
May throw InsufficientResourceCapacityFault.
May throw InvalidResourceStateFault.
May throw InvalidSubnet.
May throw KMSKeyNotAccessibleFault.
May throw ReplicationSubnetGroupDoesNotCoverEnoughAZs.
May throw ResourceAlreadyExistsFault.
May throw ResourceNotFoundFault.
May throw ResourceQuotaExceededFault.
May throw StorageQuotaExceededFault.
Parameter replicationInstanceClass :
The compute and memory capacity of the replication instance as defined for
the specified replication instance class. For example to specify the
instance class dms.c4.large, set this parameter to
"dms.c4.large".
For more information on the settings and capacities for the available replication instance classes, see Choosing the right DMS replication instance; and, Selecting the best size for a replication instance.
Parameter replicationInstanceIdentifier :
The replication instance identifier. This parameter is stored as a
lowercase string.
Constraints:
- Must contain 1-63 alphanumeric characters or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
myrepinstance
Parameter allocatedStorage :
The amount of storage (in gigabytes) to be initially allocated for the
replication instance.
Parameter autoMinorVersionUpgrade :
A value that indicates whether minor engine upgrades are applied
automatically to the replication instance during the maintenance window.
This parameter defaults to true.
Default: true
Parameter availabilityZone :
The Availability Zone where the replication instance will be created. The
default value is a random, system-chosen Availability Zone in the
endpoint's Amazon Web Services Region, for example:
us-east-1d.
Parameter dnsNameServers :
A list of custom DNS name servers supported for the replication instance
to access your on-premise source or target database. This list overrides
the default name servers supported by the replication instance. You can
specify a comma-separated list of internet addresses for up to four
on-premise DNS name servers. For example:
"1.1.1.1,2.2.2.2,3.3.3.3,4.4.4.4"
Parameter engineVersion :
The engine version number of the replication instance.
If an engine version number is not specified when a replication instance is created, the default is the latest engine version available.
Parameter kerberosAuthenticationSettings :
Specifies the settings required for kerberos authentication when creating
the replication instance.
Parameter kmsKeyId :
An KMS key identifier that is used to encrypt the data on the replication
instance.
If you don't specify a value for the KmsKeyId parameter, then
DMS uses your default encryption key.
KMS creates the default encryption key for your Amazon Web Services account. Your Amazon Web Services account has a different default encryption key for each Amazon Web Services Region.
Parameter multiAZ :
Specifies whether the replication instance is a Multi-AZ deployment. You
can't set the AvailabilityZone parameter if the Multi-AZ
parameter is set to true.
Parameter networkType :
The type of IP address protocol used by a replication instance, such as
IPv4 only or Dual-stack that supports both IPv4 and IPv6 addressing. IPv6
only is not yet supported.
Parameter preferredMaintenanceWindow :
The weekly time range during which system maintenance can occur, in
Universal Coordinated Time (UTC).
Format: ddd:hh24:mi-ddd:hh24:mi
Default: A 30-minute window selected at random from an 8-hour block of time per Amazon Web Services Region, occurring on a random day of the week.
Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Minimum 30-minute window.
Parameter publiclyAccessible :
Specifies the accessibility options for the replication instance. A value
of true represents an instance with a public IP address. A
value of false represents an instance with a private IP
address. The default value is true.
Parameter replicationSubnetGroupIdentifier :
A subnet group to associate with the replication instance.
Parameter resourceIdentifier :
A friendly name for the resource identifier at the end of the
EndpointArn response parameter that is returned in the
created Endpoint object. The value for this parameter can
have up to 31 characters. It can contain only ASCII letters, digits, and
hyphen ('-'). Also, it can't end with a hyphen or contain two consecutive
hyphens, and can only begin with a letter, such as
Example-App-ARN1. For example, this value might result in the
EndpointArn value
arn:aws:dms:eu-west-1:012345678901:rep:Example-App-ARN1. If
you don't specify a ResourceIdentifier value, DMS generates a
default identifier value for the end of EndpointArn.
Parameter tags :
One or more tags to be assigned to the replication instance.
Parameter vpcSecurityGroupIds :
Specifies the VPC security group to be used with the replication instance.
The VPC security group must work with the VPC containing the replication
instance.
Implementation
Future<CreateReplicationInstanceResponse> createReplicationInstance({
required String replicationInstanceClass,
required String replicationInstanceIdentifier,
int? allocatedStorage,
bool? autoMinorVersionUpgrade,
String? availabilityZone,
String? dnsNameServers,
String? engineVersion,
KerberosAuthenticationSettings? kerberosAuthenticationSettings,
String? kmsKeyId,
bool? multiAZ,
String? networkType,
String? preferredMaintenanceWindow,
bool? publiclyAccessible,
String? replicationSubnetGroupIdentifier,
String? resourceIdentifier,
List<Tag>? tags,
List<String>? vpcSecurityGroupIds,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.CreateReplicationInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReplicationInstanceClass': replicationInstanceClass,
'ReplicationInstanceIdentifier': replicationInstanceIdentifier,
if (allocatedStorage != null) 'AllocatedStorage': allocatedStorage,
if (autoMinorVersionUpgrade != null)
'AutoMinorVersionUpgrade': autoMinorVersionUpgrade,
if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
if (dnsNameServers != null) 'DnsNameServers': dnsNameServers,
if (engineVersion != null) 'EngineVersion': engineVersion,
if (kerberosAuthenticationSettings != null)
'KerberosAuthenticationSettings': kerberosAuthenticationSettings,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (multiAZ != null) 'MultiAZ': multiAZ,
if (networkType != null) 'NetworkType': networkType,
if (preferredMaintenanceWindow != null)
'PreferredMaintenanceWindow': preferredMaintenanceWindow,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible,
if (replicationSubnetGroupIdentifier != null)
'ReplicationSubnetGroupIdentifier': replicationSubnetGroupIdentifier,
if (resourceIdentifier != null)
'ResourceIdentifier': resourceIdentifier,
if (tags != null) 'Tags': tags,
if (vpcSecurityGroupIds != null)
'VpcSecurityGroupIds': vpcSecurityGroupIds,
},
);
return CreateReplicationInstanceResponse.fromJson(jsonResponse.body);
}