describeMetadataModelImports method
Returns a paginated list of metadata model imports.
May throw ResourceNotFoundFault.
Parameter migrationProjectIdentifier :
The migration project name or Amazon Resource Name (ARN).
Parameter filters :
Filters applied to the metadata model imports described in the form of
key-value pairs.
Parameter marker :
Specifies the unique pagination token that makes it possible to display
the next page of results. If this parameter is specified, the response
includes only records beyond the marker, up to the value specified by
MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again using
the returned token and keeping all other arguments unchanged.
Parameter maxRecords :
A paginated list of metadata model imports.
Implementation
Future<DescribeMetadataModelImportsResponse> describeMetadataModelImports({
required String migrationProjectIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.DescribeMetadataModelImports'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MigrationProjectIdentifier': migrationProjectIdentifier,
if (filters != null) 'Filters': filters,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords,
},
);
return DescribeMetadataModelImportsResponse.fromJson(jsonResponse.body);
}