describeReplicationTableStatistics method
Returns table and schema statistics for one or more provisioned replications that use a given DMS Serverless replication configuration.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter replicationConfigArn :
The replication config to describe.
Parameter filters :
Filters applied to the replication table statistics.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that the remaining results
can be retrieved.
Implementation
Future<DescribeReplicationTableStatisticsResponse>
describeReplicationTableStatistics({
required String replicationConfigArn,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.DescribeReplicationTableStatistics'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReplicationConfigArn': replicationConfigArn,
if (filters != null) 'Filters': filters,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords,
},
);
return DescribeReplicationTableStatisticsResponse.fromJson(
jsonResponse.body);
}