rebootReplicationInstance method
Reboots a replication instance. Rebooting results in a momentary outage, until the replication instance becomes available again.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter replicationInstanceArn :
The Amazon Resource Name (ARN) of the replication instance.
Parameter forceFailover :
If this parameter is true, the reboot is conducted through a
Multi-AZ failover. If the instance isn't configured for Multi-AZ, then you
can't specify true. ( --force-planned-failover
and --force-failover can't both be set to true.)
Parameter forcePlannedFailover :
If this parameter is true, the reboot is conducted through a
planned Multi-AZ failover where resources are released and cleaned up
prior to conducting the failover. If the instance isn''t configured for
Multi-AZ, then you can't specify true. (
--force-planned-failover and --force-failover
can't both be set to true.)
Implementation
Future<RebootReplicationInstanceResponse> rebootReplicationInstance({
required String replicationInstanceArn,
bool? forceFailover,
bool? forcePlannedFailover,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.RebootReplicationInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ReplicationInstanceArn': replicationInstanceArn,
if (forceFailover != null) 'ForceFailover': forceFailover,
if (forcePlannedFailover != null)
'ForcePlannedFailover': forcePlannedFailover,
},
);
return RebootReplicationInstanceResponse.fromJson(jsonResponse.body);
}