startRecommendations method
- required String databaseId,
- required RecommendationSettings settings,
You can create recommendations for multiple source databases using BatchStartRecommendations.
May throw AccessDeniedFault.
May throw InvalidResourceStateFault.
May throw ResourceNotFoundFault.
Parameter databaseId :
The identifier of the source database to analyze and provide
recommendations for.
Parameter settings :
The settings in JSON format that Fleet Advisor uses to determine target
engine recommendations. These parameters include target instance sizing
and availability and durability settings. For target instance sizing,
Fleet Advisor supports the following two options: total capacity and
resource utilization. For availability and durability, Fleet Advisor
supports the following two options: production (Multi-AZ deployments) and
Dev/Test (Single-AZ deployments).
Implementation
Future<void> startRecommendations({
required String databaseId,
required RecommendationSettings settings,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonDMSv20160101.StartRecommendations'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatabaseId': databaseId,
'Settings': settings,
},
);
}