deleteFleet method
Deletes a fleet.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The farm ID of the farm to remove from the fleet.
Parameter fleetId :
The fleet ID of the fleet to delete.
Parameter clientToken :
The unique token which the server uses to recognize retries of the same
request.
Implementation
Future<void> deleteFleet({
required String farmId,
required String fleetId,
String? clientToken,
}) async {
final headers = <String, String>{
if (clientToken != null) 'X-Amz-Client-Token': clientToken.toString(),
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets/${Uri.encodeComponent(fleetId)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}