disassociateMemberFromFleet method
Disassociates a member from a fleet.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The farm ID of the fleet to disassociate a member from.
Parameter fleetId :
The fleet ID of the fleet to from which to disassociate a member.
Parameter principalId :
A member's principal ID to disassociate from a fleet.
Implementation
Future<void> disassociateMemberFromFleet({
required String farmId,
required String fleetId,
required String principalId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets/${Uri.encodeComponent(fleetId)}/members/${Uri.encodeComponent(principalId)}',
exceptionFnMap: _exceptionFns,
);
}