listFleets method
Lists fleets.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The farm ID of the fleets.
Parameter displayName :
The display names of a list of fleets.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Parameter principalId :
The principal ID of the members to include in the fleet.
Parameter status :
The status of the fleet.
Implementation
Future<ListFleetsResponse> listFleets({
required String farmId,
String? displayName,
int? maxResults,
String? nextToken,
String? principalId,
FleetStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (displayName != null) 'displayName': [displayName],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (principalId != null) 'principalId': [principalId],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2023-10-12/farms/${Uri.encodeComponent(farmId)}/fleets',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFleetsResponse.fromJson(response);
}