listLicenseEndpoints method
Lists license endpoints.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Implementation
Future<ListLicenseEndpointsResponse> listLicenseEndpoints({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2023-10-12/license-endpoints',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListLicenseEndpointsResponse.fromJson(response);
}