listQueueFleetAssociations method
Lists queue-fleet associations.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter farmId :
The farm ID for the queue-fleet association list.
Parameter fleetId :
The fleet ID for the queue-fleet association list.
Parameter maxResults :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
The token for the next set of results, or null to start from
the beginning.
Parameter queueId :
The queue ID for the queue-fleet association list.
Implementation
Future<ListQueueFleetAssociationsResponse> listQueueFleetAssociations({
required String farmId,
String? fleetId,
int? maxResults,
String? nextToken,
String? queueId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (fleetId != null) 'fleetId': [fleetId],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (queueId != null) 'queueId': [queueId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queue-fleet-associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListQueueFleetAssociationsResponse.fromJson(response);
}