updateMonitorSettings method
Updates the settings for a Deadline Cloud monitor. Keys present in the request are upserted; keys absent are left unchanged. Send an empty string value to delete a key.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter monitorId :
The unique identifier of the monitor to update settings for.
Parameter settings :
The monitor settings to update as key-value pairs. Keys present in the
request are upserted; keys absent are left unchanged. Send an empty string
value to delete a key.
Implementation
Future<void> updateMonitorSettings({
required String monitorId,
required Map<String, String> settings,
}) async {
final $payload = <String, dynamic>{
'settings': settings,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/2023-10-12/monitors/${Uri.encodeComponent(monitorId)}/settings',
exceptionFnMap: _exceptionFns,
);
}