updateQueueLimitAssociation method
Updates the status of the queue. If you set the status to one of the
STOP_LIMIT_USAGE* values, there will be a delay before the
status transitions to the STOPPED state.
May throw AccessDeniedException.
May throw InternalServerErrorException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter farmId :
The unique identifier of the farm that contains the associated queues and
limits.
Parameter limitId :
The unique identifier of the limit associated to the queue.
Parameter queueId :
The unique identifier of the queue associated to the limit.
Parameter status :
Sets the status of the limit. You can mark the limit active, or you can
stop usage of the limit and either complete existing tasks or cancel any
existing tasks immediately.
Implementation
Future<void> updateQueueLimitAssociation({
required String farmId,
required String limitId,
required String queueId,
required UpdateQueueLimitAssociationStatus status,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/2023-10-12/farms/${Uri.encodeComponent(farmId)}/queue-limit-associations/${Uri.encodeComponent(queueId)}/${Uri.encodeComponent(limitId)}',
exceptionFnMap: _exceptionFns,
);
}