disassociateMembership method
Removes the member account from the specified behavior graph. This
operation can only be called by an invited member account that has the
ENABLED status.
DisassociateMembership cannot be called by an organization
account in the organization behavior graph. For the organization behavior
graph, the Detective administrator account determines which organization
accounts to enable or disable as member accounts.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter graphArn :
The ARN of the behavior graph to remove the member account from.
The member account's member status in the behavior graph must be
ENABLED.
Implementation
Future<void> disassociateMembership({
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'GraphArn': graphArn,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/membership/removal',
exceptionFnMap: _exceptionFns,
);
}