getMembers method
Returns the membership details for specified member accounts for a behavior graph.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter accountIds :
The list of Amazon Web Services account identifiers for the member account
for which to return member details. You can request details for up to 50
member accounts at a time.
You cannot use GetMembers to retrieve information about
member accounts that were removed from the behavior graph.
Parameter graphArn :
The ARN of the behavior graph for which to request the member details.
Implementation
Future<GetMembersResponse> getMembers({
required List<String> accountIds,
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'AccountIds': accountIds,
'GraphArn': graphArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/graph/members/get',
exceptionFnMap: _exceptionFns,
);
return GetMembersResponse.fromJson(response);
}