listOrganizationAdminAccounts method
Returns information about the Detective administrator account for an organization. Can only be called by the organization management account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
For requests to get the next page of results, the pagination token that
was returned with the previous set of results. The initial request does
not include a pagination token.
Implementation
Future<ListOrganizationAdminAccountsResponse> listOrganizationAdminAccounts({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
200,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/orgs/adminAccountslist',
exceptionFnMap: _exceptionFns,
);
return ListOrganizationAdminAccountsResponse.fromJson(response);
}