startMonitoringMember method
Sends a request to enable data ingest for a member account that has a
status of ACCEPTED_BUT_DISABLED.
For valid member accounts, the status is updated as follows.
-
If Detective enabled the member account, then the new status is
ENABLED. -
If Detective cannot enable the member account, the status remains
ACCEPTED_BUT_DISABLED.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter accountId :
The account ID of the member account to try to enable.
The account must be an invited member account with a status of
ACCEPTED_BUT_DISABLED.
Parameter graphArn :
The ARN of the behavior graph.
Implementation
Future<void> startMonitoringMember({
required String accountId,
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'AccountId': accountId,
'GraphArn': graphArn,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/graph/member/monitoringstate',
exceptionFnMap: _exceptionFns,
);
}