tagResource method
Applies tag values to a behavior graph.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the behavior graph to assign the tags to.
Parameter tags :
The tags to assign to the behavior graph. You can add up to 50 tags. For
each tag, you provide the tag key and the tag value. Each tag key can
contain up to 128 characters. Each tag value can contain up to 256
characters.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}