updateDatasourcePackages method
Starts a data source package for the Detective behavior graph.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter datasourcePackages :
The data source package to start for the behavior graph.
Parameter graphArn :
The ARN of the behavior graph.
Implementation
Future<void> updateDatasourcePackages({
required List<DatasourcePackage> datasourcePackages,
required String graphArn,
}) async {
final $payload = <String, dynamic>{
'DatasourcePackages': datasourcePackages.map((e) => e.value).toList(),
'GraphArn': graphArn,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/graph/datasources/update',
exceptionFnMap: _exceptionFns,
);
}