getBacklogTask method
Gets a backlog task for the specified agent space and task id
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter agentSpaceId :
The unique identifier for the agent space containing the task
Parameter taskId :
The unique identifier of the task to retrieve
Implementation
Future<GetBacklogTaskResponse> getBacklogTask({
required String agentSpaceId,
required String taskId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/backlog/agent-space/${Uri.encodeComponent(agentSpaceId)}/tasks/${Uri.encodeComponent(taskId)}',
hostPrefix: 'dp.',
exceptionFnMap: _exceptionFns,
);
return GetBacklogTaskResponse.fromJson(response);
}