listJournalRecords method
List journal records for a specific execution
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter agentSpaceId :
The unique identifier for the agent space containing the execution
Parameter executionId :
The unique identifier of the execution whose journal records to retrieve
Parameter limit :
Maximum number of records to return in a single response (1-100, default:
100)
Parameter nextToken :
Token for retrieving the next page of results
Parameter order :
Sort order for the records based on timestamp (default: DESC)
Parameter recordType :
Filter records by type (empty string returns all types)
Implementation
Future<ListJournalRecordsResponse> listJournalRecords({
required String agentSpaceId,
required String executionId,
int? limit,
String? nextToken,
OrderType? order,
String? recordType,
}) async {
final $payload = <String, dynamic>{
'executionId': executionId,
if (limit != null) 'limit': limit,
if (nextToken != null) 'nextToken': nextToken,
if (order != null) 'order': order.value,
if (recordType != null) 'recordType': recordType,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/journal/agent-space/${Uri.encodeComponent(agentSpaceId)}/journalRecords',
hostPrefix: 'dp.',
exceptionFnMap: _exceptionFns,
);
return ListJournalRecordsResponse.fromJson(response);
}