describeOrganizationOverview method
Returns an overview of your organization's history based on the specified time range. The overview includes the total reactive and proactive insights.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter fromTime :
The start of the time range passed in. The start time granularity is at
the day level. The floor of the start time is used. Returned information
occurred after this day.
Parameter accountIds :
The ID of the Amazon Web Services account.
Parameter organizationalUnitIds :
The ID of the organizational unit.
Parameter toTime :
The end of the time range passed in. The start time granularity is at the
day level. The floor of the start time is used. Returned information
occurred before this day. If this is not specified, then the current day
is used.
Implementation
Future<DescribeOrganizationOverviewResponse> describeOrganizationOverview({
required DateTime fromTime,
List<String>? accountIds,
List<String>? organizationalUnitIds,
DateTime? toTime,
}) async {
final $payload = <String, dynamic>{
'FromTime': unixTimestampToJson(fromTime),
if (accountIds != null) 'AccountIds': accountIds,
if (organizationalUnitIds != null)
'OrganizationalUnitIds': organizationalUnitIds,
if (toTime != null) 'ToTime': unixTimestampToJson(toTime),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/organization/overview',
exceptionFnMap: _exceptionFns,
);
return DescribeOrganizationOverviewResponse.fromJson(response);
}