listMonitoredResources method
Returns the list of all log groups that are being monitored and tagged by DevOps Guru.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filters :
Filters to determine which monitored resources you want to retrieve. You
can filter by resource type or resource permission status.
Parameter maxResults :
The maximum number of results to return with a single call. To retrieve
the remaining results, make another call with the returned
nextToken value.
Parameter nextToken :
The pagination token to use to retrieve the next page of results for this
operation. If this value is null, it retrieves the first page.
Implementation
Future<ListMonitoredResourcesResponse> listMonitoredResources({
ListMonitoredResourcesFilters? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/monitoredResources',
exceptionFnMap: _exceptionFns,
);
return ListMonitoredResourcesResponse.fromJson(response);
}