startCostEstimation method
Future<void>
startCostEstimation({
- required CostEstimationResourceCollectionFilter resourceCollection,
- String? clientToken,
Starts the creation of an estimate of the monthly cost to analyze your Amazon Web Services resources.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceCollection :
The collection of Amazon Web Services resources used to create a monthly
DevOps Guru cost estimate.
Parameter clientToken :
The idempotency token used to identify each cost estimate request.
Implementation
Future<void> startCostEstimation({
required CostEstimationResourceCollectionFilter resourceCollection,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'ResourceCollection': resourceCollection,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/cost-estimation',
exceptionFnMap: _exceptionFns,
);
}