deleteTestGridProject method
Deletes a Selenium testing project and all content generated under it. You cannot delete a project if it has active sessions.
May throw ArgumentException.
May throw CannotDeleteException.
May throw InternalServiceException.
May throw NotFoundException.
Parameter projectArn :
The ARN of the project to delete, from CreateTestGridProject or
ListTestGridProjects.
Implementation
Future<void> deleteTestGridProject({
required String projectArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.DeleteTestGridProject'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'projectArn': projectArn,
},
);
}