renewOffering method
Explicitly sets the quantity of devices to renew for an offering, starting
from the effectiveDate of the next period. The API returns a
NotEligible error if the user is not permitted to invoke the
operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.
May throw ArgumentException.
May throw LimitExceededException.
May throw NotEligibleException.
May throw NotFoundException.
May throw ServiceAccountException.
Parameter offeringId :
The ID of a request to renew an offering.
Parameter quantity :
The quantity requested in an offering renewal.
Implementation
Future<RenewOfferingResult> renewOffering({
required String offeringId,
required int quantity,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DeviceFarm_20150623.RenewOffering'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'offeringId': offeringId,
'quantity': quantity,
},
);
return RenewOfferingResult.fromJson(jsonResponse.body);
}