allocateConnectionOnInterconnect method
Allocates a VLAN number and a specified amount of bandwidth for use by a hosted connection on the specified interconnect.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter bandwidth :
The bandwidth of the connection. The possible values are 50Mbps, 100Mbps,
200Mbps, 300Mbps, 400Mbps, 500Mbps, 1Gbps, 2Gbps, 5Gbps, and 10Gbps. Note
that only those Direct Connect Partners who have met specific requirements
are allowed to create a 1Gbps, 2Gbps, 5Gbps or 10Gbps hosted connection.
Parameter connectionName :
The name of the provisioned connection.
Parameter interconnectId :
The ID of the interconnect on which the connection will be provisioned.
Parameter ownerAccount :
The ID of the Amazon Web Services account of the customer for whom the
connection will be provisioned.
Parameter vlan :
The dedicated VLAN provisioned to the connection.
Implementation
Future<Connection> allocateConnectionOnInterconnect({
required String bandwidth,
required String connectionName,
required String interconnectId,
required String ownerAccount,
required int vlan,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.AllocateConnectionOnInterconnect'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'bandwidth': bandwidth,
'connectionName': connectionName,
'interconnectId': interconnectId,
'ownerAccount': ownerAccount,
'vlan': vlan,
},
);
return Connection.fromJson(jsonResponse.body);
}