describeConnections method
Displays the specified connection or all connections in this Region.
May throw DirectConnectClientException.
May throw DirectConnectServerException.
Parameter connectionId :
The ID of the connection.
Parameter maxResults :
The maximum number of results to return with a single call. To retrieve
the remaining results, make another call with the returned
nextToken value.
If MaxResults is given a value larger than 100, only 100
results are returned.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<Connections> describeConnections({
String? connectionId,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'OvertureService.DescribeConnections'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (connectionId != null) 'connectionId': connectionId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return Connections.fromJson(jsonResponse.body);
}