deleteADAssessment method
Deletes a directory assessment and all associated data. This operation permanently removes the assessment results, validation reports, and configuration information.
You cannot delete system-initiated assessments. You can delete customer-created assessments even if they are in progress.
May throw ClientException.
May throw EntityDoesNotExistException.
May throw InvalidParameterException.
May throw ServiceException.
May throw UnsupportedOperationException.
Parameter assessmentId :
The unique identifier of the directory assessment to delete.
Implementation
Future<DeleteADAssessmentResult> deleteADAssessment({
required String assessmentId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DirectoryService_20150416.DeleteADAssessment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AssessmentId': assessmentId,
},
);
return DeleteADAssessmentResult.fromJson(jsonResponse.body);
}