updateConditionalForwarder method
Updates a conditional forwarder that has been set up for your Amazon Web Services directory.
May throw ClientException.
May throw DirectoryUnavailableException.
May throw EntityDoesNotExistException.
May throw InvalidParameterException.
May throw ServiceException.
May throw UnsupportedOperationException.
Parameter directoryId :
The directory ID of the Amazon Web Services directory for which to update
the conditional forwarder.
Parameter remoteDomainName :
The fully qualified domain name (FQDN) of the remote domain with which you
will set up a trust relationship.
Parameter dnsIpAddrs :
The updated IP addresses of the remote DNS server associated with the
conditional forwarder.
Parameter dnsIpv6Addrs :
The updated IPv6 addresses of the remote DNS server associated with the
conditional forwarder.
Implementation
Future<void> updateConditionalForwarder({
required String directoryId,
required String remoteDomainName,
List<String>? dnsIpAddrs,
List<String>? dnsIpv6Addrs,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'DirectoryService_20150416.UpdateConditionalForwarder'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DirectoryId': directoryId,
'RemoteDomainName': remoteDomainName,
if (dnsIpAddrs != null) 'DnsIpAddrs': dnsIpAddrs,
if (dnsIpv6Addrs != null) 'DnsIpv6Addrs': dnsIpv6Addrs,
},
);
}