disableUser method
Deactivates an active user account. For information about how to enable an inactive user account, see ResetUserPassword in the Directory Service API Reference.
May throw AccessDeniedException.
May throw ConflictException.
May throw DirectoryUnavailableException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter directoryId :
The identifier (ID) of the directory that's associated with the user.
Parameter sAMAccountName :
The name of the user.
Parameter clientToken :
A unique and case-sensitive identifier that you provide to make sure the
idempotency of the request, so multiple identical calls have the same
effect as one single call.
A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.
If you submit a request with the same client token but change one of the
other parameters within the 8-hour idempotency window, Directory Service
Data returns an ConflictException.
Implementation
Future<void> disableUser({
required String directoryId,
required String sAMAccountName,
String? clientToken,
}) async {
final $query = <String, List<String>>{
'DirectoryId': [directoryId],
};
final $payload = <String, dynamic>{
'SAMAccountName': sAMAccountName,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/Users/DisableUser',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}