deleteLifecyclePolicy method
Deletes the specified lifecycle policy and halts the automated operations that the policy specified.
For more information about deleting a policy, see Delete lifecycle policies.
May throw InternalServerException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter policyId :
The identifier of the lifecycle policy.
Implementation
Future<void> deleteLifecyclePolicy({
required String policyId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/policies/${Uri.encodeComponent(policyId)}',
exceptionFnMap: _exceptionFns,
);
}