copyDBClusterSnapshot method
Copies a snapshot of a cluster.
To copy a cluster snapshot from a shared manual cluster snapshot,
SourceDBClusterSnapshotIdentifier must be the Amazon Resource
Name (ARN) of the shared cluster snapshot. You can only copy a shared DB
cluster snapshot, whether encrypted or not, in the same Amazon Web
Services Region.
To cancel the copy operation after it is in progress, delete the target
cluster snapshot identified by
TargetDBClusterSnapshotIdentifier while that cluster snapshot
is in the copying status.
May throw DBClusterSnapshotAlreadyExistsFault.
May throw DBClusterSnapshotNotFoundFault.
May throw InvalidDBClusterSnapshotStateFault.
May throw InvalidDBClusterStateFault.
May throw KMSKeyNotAccessibleFault.
May throw SnapshotQuotaExceededFault.
Parameter sourceDBClusterSnapshotIdentifier :
The identifier of the cluster snapshot to copy. This parameter is not case
sensitive.
Constraints:
- Must specify a valid cluster snapshot in the available state.
- If the source cluster snapshot is in the same Amazon Web Services Region as the copy, specify a valid snapshot identifier.
- If the source cluster snapshot is in a different Amazon Web Services Region or owned by another Amazon Web Services account, specify the snapshot ARN.
my-cluster-snapshot1
Parameter targetDBClusterSnapshotIdentifier :
The identifier of the new cluster snapshot to create from the source
cluster snapshot. This parameter is not case sensitive.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- The first character must be a letter.
- Cannot end with a hyphen or contain two consecutive hyphens.
my-cluster-snapshot2
Parameter copyTags :
Set to true to copy all tags from the source cluster snapshot
to the target cluster snapshot, and otherwise false. The
default is false.
Parameter kmsKeyId :
The KMS key ID for an encrypted cluster snapshot. The KMS key ID is the
Amazon Resource Name (ARN), KMS key identifier, or the KMS key alias for
the KMS encryption key.
If you copy an encrypted cluster snapshot from your Amazon Web Services
account, you can specify a value for KmsKeyId to encrypt the
copy with a new KMS encryption key. If you don't specify a value for
KmsKeyId, then the copy of the cluster snapshot is encrypted
with the same KMS key as the source cluster snapshot.
If you copy an encrypted cluster snapshot that is shared from another
Amazon Web Services account, then you must specify a value for
KmsKeyId.
To copy an encrypted cluster snapshot to another Amazon Web Services
Region, set KmsKeyId to the KMS key ID that you want to use
to encrypt the copy of the cluster snapshot in the destination Region. KMS
encryption keys are specific to the Amazon Web Services Region that they
are created in, and you can't use encryption keys from one Amazon Web
Services Region in another Amazon Web Services Region.
If you copy an unencrypted cluster snapshot and specify a value for the
KmsKeyId parameter, an error is returned.
Parameter preSignedUrl :
The URL that contains a Signature Version 4 signed request for
theCopyDBClusterSnapshot API action in the Amazon Web
Services Region that contains the source cluster snapshot to copy. You
must use the PreSignedUrl parameter when copying a cluster
snapshot from another Amazon Web Services Region.
If you are using an Amazon Web Services SDK tool or the CLI, you can
specify SourceRegion (or --source-region for the
CLI) instead of specifying PreSignedUrl manually. Specifying
SourceRegion autogenerates a pre-signed URL that is a valid
request for the operation that can be executed in the source Amazon Web
Services Region.
The presigned URL must be a valid request for the
CopyDBClusterSnapshot API action that can be executed in the
source Amazon Web Services Region that contains the cluster snapshot to be
copied. The presigned URL request must contain the following parameter
values:
-
SourceRegion- The ID of the region that contains the snapshot to be copied. -
SourceDBClusterSnapshotIdentifier- The identifier for the the encrypted cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted cluster snapshot from the us-east-1 Amazon Web Services Region, then yourSourceDBClusterSnapshotIdentifierlooks something like the following:arn:aws:rds:us-east-1:12345678012:sample-cluster:sample-cluster-snapshot. -
TargetDBClusterSnapshotIdentifier- The identifier for the new cluster snapshot to be created. This parameter isn't case sensitive.
Parameter tags :
The tags to be assigned to the cluster snapshot.
Implementation
Future<CopyDBClusterSnapshotResult> copyDBClusterSnapshot({
required String sourceDBClusterSnapshotIdentifier,
required String targetDBClusterSnapshotIdentifier,
bool? copyTags,
String? kmsKeyId,
String? preSignedUrl,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'SourceDBClusterSnapshotIdentifier': sourceDBClusterSnapshotIdentifier,
'TargetDBClusterSnapshotIdentifier': targetDBClusterSnapshotIdentifier,
if (copyTags != null) 'CopyTags': copyTags.toString(),
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (preSignedUrl != null) 'PreSignedUrl': preSignedUrl,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CopyDBClusterSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CopyDBClusterSnapshotResult',
);
return CopyDBClusterSnapshotResult.fromXml($result);
}