createClusterSnapshot method
Creates a snapshot of an elastic cluster.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterArn :
The ARN identifier of the elastic cluster of which you want to create a
snapshot.
Parameter snapshotName :
The name of the new elastic cluster snapshot.
Parameter tags :
The tags to be assigned to the new elastic cluster snapshot.
Implementation
Future<CreateClusterSnapshotOutput> createClusterSnapshot({
required String clusterArn,
required String snapshotName,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'clusterArn': clusterArn,
'snapshotName': snapshotName,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/cluster-snapshot',
exceptionFnMap: _exceptionFns,
);
return CreateClusterSnapshotOutput.fromJson(response);
}