listClusterSnapshots method
Returns information about snapshots for a specified elastic cluster.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterArn :
The ARN identifier of the elastic cluster.
Parameter maxResults :
The maximum number of elastic cluster snapshot results to receive in the
response.
Parameter nextToken :
A pagination token provided by a previous request. If this parameter is
specified, the response includes only records beyond this token, up to the
value specified by max-results.
If there is no more data in the responce, the nextToken will
not be returned.
Parameter snapshotType :
The type of cluster snapshots to be returned. You can specify one of the
following values:
-
automated- Return all cluster snapshots that Amazon DocumentDB has automatically created for your Amazon Web Services account. -
manual- Return all cluster snapshots that you have manually created for your Amazon Web Services account.
Implementation
Future<ListClusterSnapshotsOutput> listClusterSnapshots({
String? clusterArn,
int? maxResults,
String? nextToken,
String? snapshotType,
}) async {
final $query = <String, List<String>>{
if (clusterArn != null) 'clusterArn': [clusterArn],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (snapshotType != null) 'snapshotType': [snapshotType],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/cluster-snapshots',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListClusterSnapshotsOutput.fromJson(response);
}