listClusters method
Returns information about provisioned Amazon DocumentDB elastic clusters.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of elastic cluster snapshot results to receive in the
response.
Parameter nextToken :
A pagination token provided by a previous request. If this parameter is
specified, the response includes only records beyond this token, up to the
value specified by max-results.
If there is no more data in the responce, the nextToken will
not be returned.
Implementation
Future<ListClustersOutput> listClusters({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/clusters',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListClustersOutput.fromJson(response);
}