createLaunchConfigurationTemplate method
Creates a new Launch Configuration Template.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter copyPrivateIp :
Copy private IP.
Parameter copyTags :
Copy tags.
Parameter exportBucketArn :
S3 bucket ARN to export Source Network templates.
Parameter launchDisposition :
Launch disposition.
Parameter launchIntoSourceInstance :
DRS will set the 'launch into instance ID' of any source server when
performing a drill, recovery or failback to the previous region or
availability zone, using the instance ID of the source instance.
Parameter licensing :
Licensing.
Parameter postLaunchEnabled :
Whether we want to activate post-launch actions.
Parameter tags :
Request to associate tags during creation of a Launch Configuration
Template.
Parameter targetInstanceTypeRightSizingMethod :
Target instance type right-sizing method.
Implementation
Future<CreateLaunchConfigurationTemplateResponse>
createLaunchConfigurationTemplate({
bool? copyPrivateIp,
bool? copyTags,
String? exportBucketArn,
LaunchDisposition? launchDisposition,
bool? launchIntoSourceInstance,
Licensing? licensing,
bool? postLaunchEnabled,
Map<String, String>? tags,
TargetInstanceTypeRightSizingMethod? targetInstanceTypeRightSizingMethod,
}) async {
final $payload = <String, dynamic>{
if (copyPrivateIp != null) 'copyPrivateIp': copyPrivateIp,
if (copyTags != null) 'copyTags': copyTags,
if (exportBucketArn != null) 'exportBucketArn': exportBucketArn,
if (launchDisposition != null)
'launchDisposition': launchDisposition.value,
if (launchIntoSourceInstance != null)
'launchIntoSourceInstance': launchIntoSourceInstance,
if (licensing != null) 'licensing': licensing,
if (postLaunchEnabled != null) 'postLaunchEnabled': postLaunchEnabled,
if (tags != null) 'tags': tags,
if (targetInstanceTypeRightSizingMethod != null)
'targetInstanceTypeRightSizingMethod':
targetInstanceTypeRightSizingMethod.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateLaunchConfigurationTemplate',
exceptionFnMap: _exceptionFns,
);
return CreateLaunchConfigurationTemplateResponse.fromJson(response);
}