disconnectRecoveryInstance method
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter recoveryInstanceID :
The ID of the Recovery Instance to disconnect.
Implementation
Future<void> disconnectRecoveryInstance({
required String recoveryInstanceID,
}) async {
final $payload = <String, dynamic>{
'recoveryInstanceID': recoveryInstanceID,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DisconnectRecoveryInstance',
exceptionFnMap: _exceptionFns,
);
}