reverseReplication method
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region
- starts replication back to origin region. For failback instances on origin region - starts replication to target region to re-protect them.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter recoveryInstanceID :
The ID of the Recovery Instance that we want to reverse the replication
for.
Implementation
Future<ReverseReplicationResponse> reverseReplication({
required String recoveryInstanceID,
}) async {
final $payload = <String, dynamic>{
'recoveryInstanceID': recoveryInstanceID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ReverseReplication',
exceptionFnMap: _exceptionFns,
);
return ReverseReplicationResponse.fromJson(response);
}