startRecovery method
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter sourceServers :
The Source Servers that we want to start a Recovery Job for.
Parameter isDrill :
Whether this Source Server Recovery operation is a drill or not.
Parameter tags :
The tags to be associated with the Recovery Job.
Implementation
Future<StartRecoveryResponse> startRecovery({
required List<StartRecoveryRequestSourceServer> sourceServers,
bool? isDrill,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'sourceServers': sourceServers,
if (isDrill != null) 'isDrill': isDrill,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StartRecovery',
exceptionFnMap: _exceptionFns,
);
return StartRecoveryResponse.fromJson(response);
}