startSourceNetworkRecovery method
Deploy VPC for the specified Source Network and modify launch templates to use this network. The VPC will be deployed using a dedicated CloudFormation stack.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter sourceNetworks :
The Source Networks that we want to start a Recovery Job for.
Parameter deployAsNew :
Don't update existing CloudFormation Stack, recover the network using a
new stack.
Parameter tags :
The tags to be associated with the Source Network recovery Job.
Implementation
Future<StartSourceNetworkRecoveryResponse> startSourceNetworkRecovery({
required List<StartSourceNetworkRecoveryRequestNetworkEntry> sourceNetworks,
bool? deployAsNew,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'sourceNetworks': sourceNetworks,
if (deployAsNew != null) 'deployAsNew': deployAsNew,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StartSourceNetworkRecovery',
exceptionFnMap: _exceptionFns,
);
return StartSourceNetworkRecoveryResponse.fromJson(response);
}