stopFailback method
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter recoveryInstanceID :
The ID of the Recovery Instance we want to stop failback for.
Implementation
Future<void> stopFailback({
required String recoveryInstanceID,
}) async {
final $payload = <String, dynamic>{
'recoveryInstanceID': recoveryInstanceID,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StopFailback',
exceptionFnMap: _exceptionFns,
);
}