stopReplication method
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter sourceServerID :
The ID of the Source Server to stop replication for.
Implementation
Future<StopReplicationResponse> stopReplication({
required String sourceServerID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StopReplication',
exceptionFnMap: _exceptionFns,
);
return StopReplicationResponse.fromJson(response);
}