updateFailbackReplicationConfiguration method
Allows you to update the failback replication configuration of a Recovery Instance by ID.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UninitializedAccountException.
Parameter recoveryInstanceID :
The ID of the Recovery Instance.
Parameter bandwidthThrottling :
Configure bandwidth throttling for the outbound data transfer rate of the
Recovery Instance in Mbps.
Parameter internetProtocol :
Which version of the Internet Protocol to use for replication of data.
(IPv4 or IPv6)
Parameter name :
The name of the Failback Replication Configuration.
Parameter usePrivateIP :
Whether to use Private IP for the failback replication of the Recovery
Instance.
Implementation
Future<void> updateFailbackReplicationConfiguration({
required String recoveryInstanceID,
int? bandwidthThrottling,
InternetProtocol? internetProtocol,
String? name,
bool? usePrivateIP,
}) async {
_s.validateNumRange(
'bandwidthThrottling',
bandwidthThrottling,
0,
1152921504606846976,
);
final $payload = <String, dynamic>{
'recoveryInstanceID': recoveryInstanceID,
if (bandwidthThrottling != null)
'bandwidthThrottling': bandwidthThrottling,
if (internetProtocol != null) 'internetProtocol': internetProtocol.value,
if (name != null) 'name': name,
if (usePrivateIP != null) 'usePrivateIP': usePrivateIP,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateFailbackReplicationConfiguration',
exceptionFnMap: _exceptionFns,
);
}