getClusterPolicy method

Future<GetClusterPolicyOutput> getClusterPolicy({
  1. required String identifier,
})

Retrieves the resource-based policy document attached to a cluster. This policy defines the access permissions and conditions for the cluster.

May throw ResourceNotFoundException. May throw ValidationException.

Parameter identifier : The ID of the cluster to retrieve the policy from.

Implementation

Future<GetClusterPolicyOutput> getClusterPolicy({
  required String identifier,
}) async {
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/cluster/${Uri.encodeComponent(identifier)}/policy',
    exceptionFnMap: _exceptionFns,
  );
  return GetClusterPolicyOutput.fromJson(response);
}