listStreams method
Retrieves information about a list of streams for a cluster.
May throw ResourceNotFoundException.
Parameter clusterIdentifier :
The ID of the cluster for which to list streams.
Parameter maxResults :
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to display the next page of results.
Default: 10.
Parameter nextToken :
If your initial ListStreams operation returns a nextToken, you can include
the returned nextToken in following ListStreams operations, which returns
results in the next page.
Implementation
Future<ListStreamsOutput> listStreams({
required String clusterIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/stream/${Uri.encodeComponent(clusterIdentifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListStreamsOutput.fromJson(response);
}