untagResource method
Removes a tag from a resource.
May throw ResourceNotFoundException.
Parameter resourceArn :
The ARN of the resource from which to remove tags.
Parameter tagKeys :
The array of keys of the tags that you want to remove.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}