batchWriteItem method
The BatchWriteItem operation puts or deletes multiple items
in one or more tables. A single call to BatchWriteItem can
transmit up to 16MB of data over the network, consisting of up to 25 item
put or delete operations. While individual items can be up to 400 KB once
stored, it's important to note that an item's representation might be
greater than 400KB while being sent in DynamoDB's JSON format for the API
call. For more details on this distinction, see Naming
Rules and Data Types.
The individual PutItem and DeleteItem operations
specified in BatchWriteItem are atomic; however
BatchWriteItem as a whole is not. If any requested operations
fail because the table's provisioned throughput is exceeded or an internal
processing failure occurs, the failed operations are returned in the
UnprocessedItems response parameter. You can investigate and
optionally resend the requests. Typically, you would call
BatchWriteItem in a loop. Each iteration would check for
unprocessed items and submit a new BatchWriteItem request
with those unprocessed items until all items have been processed.
For tables and indexes with provisioned capacity, if none of the items can
be processed due to insufficient provisioned throughput on all of the
tables in the request, then BatchWriteItem returns a
ProvisionedThroughputExceededException. For all tables and
indexes, if none of the items can be processed due to other throttling
scenarios (such as exceeding partition level limits), then
BatchWriteItem returns a ThrottlingException.
For more information, see Batch
Operations and Error Handling in the Amazon DynamoDB Developer
Guide.
With BatchWriteItem, you can efficiently write or delete
large amounts of data, such as from Amazon EMR, or copy data from another
database into DynamoDB. In order to improve performance with these
large-scale operations, BatchWriteItem does not behave in the
same way as individual PutItem and DeleteItem
calls would. For example, you cannot specify conditions on individual put
and delete requests, and BatchWriteItem does not return
deleted items in the response.
If you use a programming language that supports concurrency, you can use
threads to write items in parallel. Your application must include the
necessary logic to manage the threads. With languages that don't support
threading, you must update or delete the specified items one at a time. In
both situations, BatchWriteItem performs the specified put
and delete operations in parallel, giving you the power of the thread pool
approach without having to introduce complexity into your application.
Parallel processing reduces latency, but each specified put and delete request consumes the same number of write capacity units whether it is processed in parallel or not. Delete operations on nonexistent items consume one write capacity unit.
If one or more of the following is true, DynamoDB rejects the entire batch write operation:
-
One or more tables specified in the
BatchWriteItemrequest does not exist. - Primary key attributes specified on an item in the request do not match those in the corresponding table's primary key schema.
-
You try to perform multiple operations on the same item in the same
BatchWriteItemrequest. For example, you cannot put and delete the same item in the sameBatchWriteItemrequest. - Your request contains at least two items with identical hash and range keys (which essentially is two put operations).
- There are more than 25 requests in the batch.
- Any individual item in a batch exceeds 400 KB.
- The total request size exceeds 16 MB.
- Any individual items with keys exceeding the key length limits. For a partition key, the limit is 2048 bytes and for a sort key, the limit is 1024 bytes.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw ItemCollectionSizeLimitExceededException.
May throw ProvisionedThroughputExceededException.
May throw ReplicatedWriteConflictException.
May throw RequestLimitExceeded.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter requestItems :
A map of one or more table names or table ARNs and, for each table, a list
of operations to be performed (DeleteRequest or
PutRequest). Each element in the map consists of the
following:
-
DeleteRequest- Perform aDeleteItemoperation on the specified item. The item to be deleted is identified by aKeysubelement:-
Key- A map of primary key attribute values that uniquely identify the item. Each entry in this map consists of an attribute name and an attribute value. For each primary key, you must provide all of the key attributes. For example, with a simple primary key, you only need to provide a value for the partition key. For a composite primary key, you must provide values for both the partition key and the sort key.
-
-
PutRequest- Perform aPutItemoperation on the specified item. The item to be put is identified by anItemsubelement:-
Item- A map of attributes and their values. Each entry in this map consists of an attribute name and an attribute value. Attribute values must not be null; string and binary type attributes must have lengths greater than zero; and set type attributes must not be empty. Requests that contain empty values are rejected with aValidationExceptionexception.If you specify any attributes that are part of an index key, then the data types for those attributes must match those of the schema in the table's attribute definition.
-
Parameter returnItemCollectionMetrics :
Determines whether item collection metrics are returned. If set to
SIZE, the response includes statistics about item
collections, if any, that were modified during the operation are returned
in the response. If set to NONE (the default), no statistics
are returned.
Implementation
Future<BatchWriteItemOutput> batchWriteItem({
required Map<String, List<WriteRequest>> requestItems,
ReturnConsumedCapacity? returnConsumedCapacity,
ReturnItemCollectionMetrics? returnItemCollectionMetrics,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.BatchWriteItem'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RequestItems': requestItems,
if (returnConsumedCapacity != null)
'ReturnConsumedCapacity': returnConsumedCapacity.value,
if (returnItemCollectionMetrics != null)
'ReturnItemCollectionMetrics': returnItemCollectionMetrics.value,
},
);
return BatchWriteItemOutput.fromJson(jsonResponse.body);
}