tagResource method
Associate a set of tags with an Amazon DynamoDB resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking. You can call TagResource up to five times per second, per account.
-
TagResourceis an asynchronous operation. If you issue a ListTagsOfResource request immediately after aTagResourcerequest, DynamoDB might return your previous tag set, if there was one, or an empty tag set. This is becauseListTagsOfResourceuses an eventually consistent query, and the metadata for your tags or table might not be available at that moment. Wait for a few seconds, and then try theListTagsOfResourcerequest again. -
The application or removal of tags using
TagResourceandUntagResourceAPIs is eventually consistent.ListTagsOfResourceAPI will only reflect the changes after a few seconds.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter resourceArn :
Identifies the Amazon DynamoDB resource to which tags should be added.
This value is an Amazon Resource Name (ARN).
Parameter tags :
The tags to be assigned to the Amazon DynamoDB resource.
Implementation
Future<void> tagResource({
required String resourceArn,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'Tags': tags,
},
);
}