untagResource method
Removes the association of tags from an Amazon DynamoDB resource. You can
call UntagResource up to five times per second, per account.
-
UntagResourceis an asynchronous operation. If you issue a ListTagsOfResource request immediately after anUntagResourcerequest, DynamoDB might return your previous tag set, if there was one, or an empty tag set. This is becauseListTagsOfResourceuses an eventually consistent query, and the metadata for your tags or table might not be available at that moment. Wait for a few seconds, and then try theListTagsOfResourcerequest again. -
The application or removal of tags using
TagResourceandUntagResourceAPIs is eventually consistent.ListTagsOfResourceAPI will only reflect the changes after a few seconds.
May throw InternalServerError.
May throw InvalidEndpointException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The DynamoDB resource that the tags will be removed from. This value is an
Amazon Resource Name (ARN).
Parameter tagKeys :
A list of tag keys. Existing tags of the resource whose keys are members
of this list will be removed from the DynamoDB resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'DynamoDB_20120810.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
);
}