dynamo_document library
Classes
- AwsClientCredentials
- AWS credentials.
- BatchGetOutput
- BatchWriteOutput
- ConditionDC
- DocumentClient
- The document client simplifies working with items in Amazon DynamoDB by abstracting away the notion of attribute values. This abstraction annotates native Dart types supplied as input parameters, as well as converts annotated response data to native Dart types.
- DynamoDB
- Amazon DynamoDB is a fully managed NoSQL database service that provides fast and predictable performance with seamless scalability. DynamoDB lets you offload the administrative burdens of operating and scaling a distributed database, so that you don't have to worry about hardware provisioning, setup and configuration, replication, software patching, or cluster scaling.
- ExpectedAttributeValueDC
- GetDC
- GetOutput
- ItemCollectionMetricsDC
- KeysAndProjection
- Operation
- OperationOutput
- QueryOutputDC
- TransactGetOutput
- TransactWrite
- UpdateDC
- UpdateOperation
- Write
Extensions
-
AttributeTranslator
on Map<
String, AttributeValue> ? -
AttributeTranslatorNonNullable
on Map<
String, AttributeValue> -
DynamicTranslator
on Map<
String, dynamic> ? -
DynamicTranslatorNonNull
on Map<
String, dynamic>
Functions
-
toAttributeValue(
dynamic value) → AttributeValue -
toDartType(
AttributeValue value) → dynamic