startSnapshot method
Creates a new Amazon EBS snapshot. The new snapshot enters the
pending state after the request completes.
After creating the snapshot, use PutSnapshotBlock to write blocks of data to the snapshot.
May throw AccessDeniedException.
May throw ConcurrentLimitExceededException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestThrottledException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter volumeSize :
The size of the volume, in GiB. The maximum size is 65536 GiB
(64 TiB).
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Idempotency ensures that an API request
completes only once. With an idempotent request, if the original request
completes successfully. The subsequent retries with the same client token
return the result from the original successful request and they have no
additional effect.
If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.
For more information, see Idempotency for StartSnapshot API in the Amazon Elastic Compute Cloud User Guide.
Parameter description :
A description for the snapshot.
Parameter encrypted :
Indicates whether to encrypt the snapshot.
You can't specify Encrypted and ParentSnapshotId in the
same request. If you specify both parameters, the request fails with
ValidationException.
The encryption status of the snapshot depends on the values that you specify for Encrypted, KmsKeyArn, and ParentSnapshotId, and whether your Amazon Web Services account is enabled for encryption by default. For more information, see Using encryption in the Amazon Elastic Compute Cloud User Guide.
Parameter kmsKeyArn :
The Amazon Resource Name (ARN) of the Key Management Service (KMS) key to
be used to encrypt the snapshot.
The encryption status of the snapshot depends on the values that you specify for Encrypted, KmsKeyArn, and ParentSnapshotId, and whether your Amazon Web Services account is enabled for encryption by default. For more information, see Using encryption in the Amazon Elastic Compute Cloud User Guide.
Parameter parentSnapshotId :
The ID of the parent snapshot. If there is no parent snapshot, or if you
are creating the first snapshot for an on-premises volume, omit this
parameter.
You can't specify ParentSnapshotId and Encrypted in the same
request. If you specify both parameters, the request fails with
ValidationException.
The encryption status of the snapshot depends on the values that you specify for Encrypted, KmsKeyArn, and ParentSnapshotId, and whether your Amazon Web Services account is enabled for encryption by default. For more information, see Using encryption in the Amazon Elastic Compute Cloud User Guide.
Parameter tags :
The tags to apply to the snapshot.
Parameter timeout :
The amount of time (in minutes) after which the snapshot is automatically
cancelled if:
- No blocks are written to the snapshot.
- The snapshot is not completed after writing the last block of data.
60 minutes.
Implementation
Future<StartSnapshotResponse> startSnapshot({
required int volumeSize,
String? clientToken,
String? description,
bool? encrypted,
String? kmsKeyArn,
String? parentSnapshotId,
List<Tag>? tags,
int? timeout,
}) async {
_s.validateNumRange(
'volumeSize',
volumeSize,
1,
1152921504606846976,
isRequired: true,
);
_s.validateNumRange(
'timeout',
timeout,
10,
4320,
);
final $payload = <String, dynamic>{
'VolumeSize': volumeSize,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (encrypted != null) 'Encrypted': encrypted,
if (kmsKeyArn != null) 'KmsKeyArn': kmsKeyArn,
if (parentSnapshotId != null) 'ParentSnapshotId': parentSnapshotId,
if (tags != null) 'Tags': tags,
if (timeout != null) 'Timeout': timeout,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/snapshots',
exceptionFnMap: _exceptionFns,
);
return StartSnapshotResponse.fromJson(response);
}