registerPullTimeUpdateExclusion method
Future<RegisterPullTimeUpdateExclusionResponse>
registerPullTimeUpdateExclusion({
- required String principalArn,
Adds an IAM principal to the pull time update exclusion list for a registry. Amazon ECR will not record the pull time if an excluded principal pulls an image.
May throw ExclusionAlreadyExistsException.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ServerException.
May throw ValidationException.
Parameter principalArn :
The ARN of the IAM principal to exclude from having image pull times
recorded.
Implementation
Future<RegisterPullTimeUpdateExclusionResponse>
registerPullTimeUpdateExclusion({
required String principalArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerRegistry_V20150921.RegisterPullTimeUpdateExclusion'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'principalArn': principalArn,
},
);
return RegisterPullTimeUpdateExclusionResponse.fromJson(jsonResponse.body);
}