describeDaemonRevisions method
Describes one or more of your daemon revisions.
A daemon revision is a snapshot of a daemon's configuration at the time a deployment was initiated. It captures the daemon task definition, container images, tag propagation, and execute command settings. Daemon revisions are immutable.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ServerException.
May throw UnsupportedFeatureException.
Parameter daemonRevisionArns :
The ARN of the daemon revisions to describe. You can specify up to 20
ARNs.
Implementation
Future<DescribeDaemonRevisionsResponse> describeDaemonRevisions({
required List<String> daemonRevisionArns,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.DescribeDaemonRevisions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'daemonRevisionArns': daemonRevisionArns,
},
);
return DescribeDaemonRevisionsResponse.fromJson(jsonResponse.body);
}