describeServices method
Describes the specified services running in your cluster.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ServerException.
Parameter services :
A list of services to describe. You may specify up to 10 services to
describe in a single operation.
Parameter cluster :
The short name or full Amazon Resource Name (ARN)the cluster that hosts
the service to describe. If you do not specify a cluster, the default
cluster is assumed. This parameter is required if the service or services
you are describing were launched in any cluster other than the default
cluster.
Parameter include :
Determines whether you want to see the resource tags for the service. If
TAGS is specified, the tags are included in the response. If
this field is omitted, tags aren't included in the response.
Implementation
Future<DescribeServicesResponse> describeServices({
required List<String> services,
String? cluster,
List<ServiceField>? include,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.DescribeServices'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'services': services,
if (cluster != null) 'cluster': cluster,
if (include != null) 'include': include.map((e) => e.value).toList(),
},
);
return DescribeServicesResponse.fromJson(jsonResponse.body);
}