listClusters method
Returns a list of existing clusters.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw ServerException.
Parameter maxResults :
The maximum number of cluster results that ListClusters
returned in paginated output. When this parameter is used,
ListClusters only returns maxResults results in
a single page along with a nextToken response element. The
remaining results of the initial request can be seen by sending another
ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If this parameter isn't used,
then ListClusters returns up to 100 results and a
nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a ListClusters
request indicating that more results are available to fulfill the request
and further calls are needed. If maxResults was provided,
it's possible the number of results to be fewer than
maxResults.
Implementation
Future<ListClustersResponse> listClusters({
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.ListClusters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListClustersResponse.fromJson(jsonResponse.body);
}