listServicesByNamespace method
This operation lists all of the services that are associated with a Cloud
Map namespace. This list might include services in different clusters. In
contrast, ListServices can only list services in one cluster
at a time. If you need to filter the list of services in a single cluster
by various parameters, use ListServices. For more
information, see Service
Connect in the Amazon Elastic Container Service Developer
Guide.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw NamespaceNotFoundException.
May throw ServerException.
Parameter namespace :
The namespace name or full Amazon Resource Name (ARN) of the Cloud Map
namespace to list the services in.
Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see Service Connect in the Amazon Elastic Container Service Developer Guide.
Parameter maxResults :
The maximum number of service results that
ListServicesByNamespace returns in paginated output. When
this parameter is used, ListServicesByNamespace only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListServicesByNamespace request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListServicesByNamespace returns up
to 10 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value that's returned from a
ListServicesByNamespace request. It indicates that more
results are available to fulfill the request and further calls are needed.
If maxResults is returned, it is possible the number of
results is less than maxResults.
Implementation
Future<ListServicesByNamespaceResponse> listServicesByNamespace({
required String namespace,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.ListServicesByNamespace'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'namespace': namespace,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListServicesByNamespaceResponse.fromJson(jsonResponse.body);
}