registerTaskDefinition method
- required List<
ContainerDefinition> containerDefinitions, - required String family,
- String? cpu,
- bool? enableFaultInjection,
- EphemeralStorage? ephemeralStorage,
- String? executionRoleArn,
- List<
InferenceAccelerator> ? inferenceAccelerators, - IpcMode? ipcMode,
- String? memory,
- NetworkMode? networkMode,
- PidMode? pidMode,
- List<
TaskDefinitionPlacementConstraint> ? placementConstraints, - ProxyConfiguration? proxyConfiguration,
- List<
Compatibility> ? requiresCompatibilities, - RuntimePlatform? runtimePlatform,
- List<
Tag> ? tags, - String? taskRoleArn,
- List<
Volume> ? volumes,
Registers a new task definition from the supplied family and
containerDefinitions. Optionally, you can add data volumes to
your containers with the volumes parameter. For more
information about task definition parameters and defaults, see Amazon
ECS Task Definitions in the Amazon Elastic Container Service
Developer Guide.
You can specify a role for your task with the taskRoleArn
parameter. When you specify a role for a task, its containers can then use
the latest versions of the CLI or SDKs to make API requests to the Amazon
Web Services services that are specified in the policy that's associated
with the role. For more information, see IAM
Roles for Tasks in the Amazon Elastic Container Service Developer
Guide.
You can specify a Docker networking mode for the containers in your task
definition with the networkMode parameter. If you specify the
awsvpc network mode, the task is allocated an elastic network
interface, and you must specify a NetworkConfiguration
when you create a service or run a task with the task definition. For more
information, see Task
Networking in the Amazon Elastic Container Service Developer
Guide.
May throw AccessDeniedException.
May throw ClientException.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ServerException.
Parameter containerDefinitions :
A list of container definitions in JSON format that describe the different
containers that make up your task.
Parameter family :
You must specify a family for a task definition. You can use
it track multiple versions of the same task definition. The
family is used as a name for your task definition. Up to 255
letters (uppercase and lowercase), numbers, underscores, and hyphens are
allowed.
Parameter cpu :
The number of CPU units used by the task. It can be expressed as an
integer using CPU units (for example, 1024) or as a string
using vCPUs (for example, 1 vCPU or 1 vcpu) in a
task definition. String values are converted to an integer indicating the
CPU units when the task definition is registered.
If you're using the EC2 launch type or external launch type, this field is
optional. Supported values are between 128 CPU units
(0.125 vCPUs) and 196608 CPU units
(192 vCPUs). If you do not specify a value, the parameter is
ignored.
This field is required for Fargate. For information about the valid values, see Task size in the Amazon Elastic Container Service Developer Guide.
Parameter enableFaultInjection :
Enables fault injection when you register your task definition and allows
for fault injection requests to be accepted from the task's containers.
The default value is false.
Parameter ephemeralStorage :
The amount of ephemeral storage to allocate for the task. This parameter
is used to expand the total amount of ephemeral storage available, beyond
the default amount, for tasks hosted on Fargate. For more information, see
Using
data volumes in tasks in the Amazon ECS Developer Guide.
-
Linux platform version
1.4.0or later. -
Windows platform version
1.0.0or later.
Parameter executionRoleArn :
The Amazon Resource Name (ARN) of the task execution role that grants the
Amazon ECS container agent permission to make Amazon Web Services API
calls on your behalf. For informationabout the required IAM roles for
Amazon ECS, see IAM
roles for Amazon ECS in the Amazon Elastic Container Service
Developer Guide.
Parameter inferenceAccelerators :
The Elastic Inference accelerators to use for the containers in the task.
Parameter ipcMode :
The IPC resource namespace to use for the containers in the task. The
valid values are host, task, or
none. If host is specified, then all containers
within the tasks that specified the host IPC mode on the same
container instance share the same IPC resources with the host Amazon EC2
instance. If task is specified, all containers within the
specified task share the same IPC resources. If none is
specified, then IPC resources within the containers of a task are private
and not shared with other containers in a task or on the container
instance. If no value is specified, then the IPC resource namespace
sharing depends on the Docker daemon setting on the container instance.
If the host IPC mode is used, be aware that there is a
heightened risk of undesired IPC namespace expose.
If you are setting namespaced kernel parameters using
systemControls for the containers in the task, the following
will apply to your IPC resource namespace. For more information, see System
Controls in the Amazon Elastic Container Service Developer
Guide.
-
For tasks that use the
hostIPC mode, IPC namespace relatedsystemControlsare not supported. -
For tasks that use the
taskIPC mode, IPC namespace relatedsystemControlswill apply to all containers within a task.
Parameter memory :
The amount of memory (in MiB) used by the task. It can be expressed as an
integer using MiB (for example ,1024) or as a string using GB
(for example, 1GB or 1 GB) in a task definition.
String values are converted to an integer indicating the MiB when the task
definition is registered.
If using the EC2 launch type, this field is optional.
If using the Fargate launch type, this field is required and you must use
one of the following values. This determines your range of supported
values for the cpu parameter.
The CPU units cannot be less than 1 vCPU when you use Windows containers on Fargate.
-
512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available
cpuvalues: 256 (.25 vCPU) -
1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available
cpuvalues: 512 (.5 vCPU) -
2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7
GB), 8192 (8 GB) - Available
cpuvalues: 1024 (1 vCPU) -
Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) -
Available
cpuvalues: 2048 (2 vCPU) -
Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) -
Available
cpuvalues: 4096 (4 vCPU) -
Between 16 GB and 60 GB in 4 GB increments - Available
cpuvalues: 8192 (8 vCPU)This option requires Linux platform
1.4.0or later. -
Between 32GB and 120 GB in 8 GB increments - Available
cpuvalues: 16384 (16 vCPU)This option requires Linux platform
1.4.0or later.
Parameter networkMode :
The Docker networking mode to use for the containers in the task. The
valid values are none, bridge,
awsvpc, and host. If no network mode is
specified, the default is bridge.
For Amazon ECS tasks on Fargate, the awsvpc network mode is
required. For Amazon ECS tasks on Amazon EC2 Linux instances, any network
mode can be used. For Amazon ECS tasks on Amazon EC2 Windows instances,
<default> or awsvpc can be used. If the
network mode is set to none, you cannot specify port mappings
in your container definitions, and the tasks containers do not have
external connectivity. The host and awsvpc
network modes offer the highest networking performance for containers
because they use the EC2 network stack instead of the virtualized network
stack provided by the bridge mode.
With the host and awsvpc network modes, exposed
container ports are mapped directly to the corresponding host port (for
the host network mode) or the attached elastic network
interface port (for the awsvpc network mode), so you cannot
take advantage of dynamic host port mappings.
If the network mode is awsvpc, the task is allocated an
elastic network interface, and you must specify a NetworkConfiguration
value when you create a service or run a task with the task definition.
For more information, see Task
Networking in the Amazon Elastic Container Service Developer
Guide.
If the network mode is host, you cannot run multiple
instantiations of the same task on a single container instance when port
mappings are used.
Parameter pidMode :
The process namespace to use for the containers in the task. The valid
values are host or task. On Fargate for Linux
containers, the only valid value is task. For example,
monitoring sidecars might need pidMode to access information
about other containers running in the same task.
If host is specified, all containers within the tasks that
specified the host PID mode on the same container instance
share the same process namespace with the host Amazon EC2 instance.
If task is specified, all containers within the specified
task share the same process namespace.
If no value is specified, the The default is a private namespace for each container.
If the host PID mode is used, there's a heightened risk of
undesired process namespace exposure.
Parameter placementConstraints :
An array of placement constraint objects to use for the task. You can
specify a maximum of 10 constraints for each task. This limit includes
constraints in the task definition and those specified at runtime.
Parameter proxyConfiguration :
The configuration details for the App Mesh proxy.
For tasks hosted on Amazon EC2 instances, the container instances require
at least version 1.26.0 of the container agent and at least
version 1.26.0-1 of the ecs-init package to use
a proxy configuration. If your container instances are launched from the
Amazon ECS-optimized AMI version 20190301 or later, then they
contain the required versions of the container agent and
ecs-init. For more information, see Amazon
ECS-optimized AMI versions in the Amazon Elastic Container Service
Developer Guide.
Parameter requiresCompatibilities :
The task launch type that Amazon ECS validates the task definition
against. A client exception is returned if the task definition doesn't
validate against the compatibilities specified. If no value is specified,
the parameter is omitted from the response.
Parameter runtimePlatform :
The operating system that your tasks definitions run on.
Parameter tags :
The metadata that you apply to the task definition to help you categorize
and organize them. Each tag consists of a key and an optional value. You
define both of them.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8
- Maximum value length - 256 Unicode characters in UTF-8
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
Parameter taskRoleArn :
The short name or full Amazon Resource Name (ARN) of the IAM role that
containers in this task can assume. All containers in this task are
granted the permissions that are specified in this role. For more
information, see IAM
Roles for Tasks in the Amazon Elastic Container Service Developer
Guide.
Parameter volumes :
A list of volume definitions in JSON format that containers in your task
might use.
Implementation
Future<RegisterTaskDefinitionResponse> registerTaskDefinition({
required List<ContainerDefinition> containerDefinitions,
required String family,
String? cpu,
bool? enableFaultInjection,
EphemeralStorage? ephemeralStorage,
String? executionRoleArn,
List<InferenceAccelerator>? inferenceAccelerators,
IpcMode? ipcMode,
String? memory,
NetworkMode? networkMode,
PidMode? pidMode,
List<TaskDefinitionPlacementConstraint>? placementConstraints,
ProxyConfiguration? proxyConfiguration,
List<Compatibility>? requiresCompatibilities,
RuntimePlatform? runtimePlatform,
List<Tag>? tags,
String? taskRoleArn,
List<Volume>? volumes,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AmazonEC2ContainerServiceV20141113.RegisterTaskDefinition'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'containerDefinitions': containerDefinitions,
'family': family,
if (cpu != null) 'cpu': cpu,
if (enableFaultInjection != null)
'enableFaultInjection': enableFaultInjection,
if (ephemeralStorage != null) 'ephemeralStorage': ephemeralStorage,
if (executionRoleArn != null) 'executionRoleArn': executionRoleArn,
if (inferenceAccelerators != null)
'inferenceAccelerators': inferenceAccelerators,
if (ipcMode != null) 'ipcMode': ipcMode.value,
if (memory != null) 'memory': memory,
if (networkMode != null) 'networkMode': networkMode.value,
if (pidMode != null) 'pidMode': pidMode.value,
if (placementConstraints != null)
'placementConstraints': placementConstraints,
if (proxyConfiguration != null)
'proxyConfiguration': proxyConfiguration,
if (requiresCompatibilities != null)
'requiresCompatibilities':
requiresCompatibilities.map((e) => e.value).toList(),
if (runtimePlatform != null) 'runtimePlatform': runtimePlatform,
if (tags != null) 'tags': tags,
if (taskRoleArn != null) 'taskRoleArn': taskRoleArn,
if (volumes != null) 'volumes': volumes,
},
);
return RegisterTaskDefinitionResponse.fromJson(jsonResponse.body);
}