startTask method
- required List<
String> containerInstances, - required String taskDefinition,
- String? cluster,
- bool? enableECSManagedTags,
- bool? enableExecuteCommand,
- String? group,
- NetworkConfiguration? networkConfiguration,
- TaskOverride? overrides,
- PropagateTags? propagateTags,
- String? referenceId,
- String? startedBy,
- List<
Tag> ? tags, - List<
TaskVolumeConfiguration> ? volumeConfigurations,
Starts a new task from the specified task definition on the specified
container instance or instances.
Alternatively, you can useRunTask to place tasks for you. For
more information, see Scheduling
Tasks in the Amazon Elastic Container Service Developer Guide.
You can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume when creating or updating a service. For more information, see Amazon EBS volumes in the Amazon Elastic Container Service Developer Guide.
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw NamespaceNotFoundException.
May throw ServerException.
May throw UnsupportedFeatureException.
Parameter containerInstances :
The container instance IDs or full ARN entries for the container instances
where you would like to place your task. You can specify up to 10
container instances.
Parameter taskDefinition :
The family and revision
(family:revision) or full ARN of the task definition to
start. If a revision isn't specified, the latest
ACTIVE revision is used.
Parameter cluster :
The short name or full Amazon Resource Name (ARN) of the cluster where to
start your task. If you do not specify a cluster, the default cluster is
assumed.
Parameter enableECSManagedTags :
Specifies whether to use Amazon ECS managed tags for the task. For more
information, see Tagging
Your Amazon ECS Resources in the Amazon Elastic Container Service
Developer Guide.
Parameter enableExecuteCommand :
Whether or not the execute command functionality is turned on for the
task. If true, this turns on the execute command
functionality on all containers in the task.
Parameter group :
The name of the task group to associate with the task. The default value
is the family name of the task definition (for example,
family:my-family-name).
Parameter networkConfiguration :
The VPC subnet and security group configuration for tasks that receive
their own elastic network interface by using the awsvpc
networking mode.
Parameter overrides :
A list of container overrides in JSON format that specify the name of a
container in the specified task definition and the overrides it receives.
You can override the default command for a container (that's specified in
the task definition or Docker image) with a command override.
You can also override existing environment variables (that are specified
in the task definition or Docker image) on a container or add new
environment variables to it with an environment override.
Parameter propagateTags :
Specifies whether to propagate the tags from the task definition or the
service to the task. If no value is specified, the tags aren't propagated.
Parameter referenceId :
This parameter is only used by Amazon ECS. It is not intended for use by
customers.
Parameter startedBy :
An optional tag specified when a task is started. For example, if you
automatically trigger a task to run a batch process job, you could apply a
unique identifier for that job to your task with the
startedBy parameter. You can then identify which tasks belong
to that job by filtering the results of a ListTasks
call with the startedBy value. Up to 36 letters (uppercase
and lowercase), numbers, hyphens (-), forward slash (/), and underscores
(_) are allowed.
If a task is started by an Amazon ECS service, the startedBy
parameter contains the deployment ID of the service that starts it.
Parameter tags :
The metadata that you apply to the task to help you categorize and
organize them. Each tag consists of a key and an optional value, both of
which you define.
The following basic restrictions apply to tags:
- Maximum number of tags per resource - 50
- For each resource, each tag key must be unique, and each tag key can have only one value.
- Maximum key length - 128 Unicode characters in UTF-8
- Maximum value length - 256 Unicode characters in UTF-8
- If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
- Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
Parameter volumeConfigurations :
The details of the volume that was configuredAtLaunch. You
can configure the size, volumeType, IOPS, throughput, snapshot and
encryption in TaskManagedEBSVolumeConfiguration.
The name of the volume must match the name from
the task definition.
Implementation
Future<StartTaskResponse> startTask({
required List<String> containerInstances,
required String taskDefinition,
String? cluster,
bool? enableECSManagedTags,
bool? enableExecuteCommand,
String? group,
NetworkConfiguration? networkConfiguration,
TaskOverride? overrides,
PropagateTags? propagateTags,
String? referenceId,
String? startedBy,
List<Tag>? tags,
List<TaskVolumeConfiguration>? volumeConfigurations,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.StartTask'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'containerInstances': containerInstances,
'taskDefinition': taskDefinition,
if (cluster != null) 'cluster': cluster,
if (enableECSManagedTags != null)
'enableECSManagedTags': enableECSManagedTags,
if (enableExecuteCommand != null)
'enableExecuteCommand': enableExecuteCommand,
if (group != null) 'group': group,
if (networkConfiguration != null)
'networkConfiguration': networkConfiguration,
if (overrides != null) 'overrides': overrides,
if (propagateTags != null) 'propagateTags': propagateTags.value,
if (referenceId != null) 'referenceId': referenceId,
if (startedBy != null) 'startedBy': startedBy,
if (tags != null) 'tags': tags,
if (volumeConfigurations != null)
'volumeConfigurations': volumeConfigurations,
},
);
return StartTaskResponse.fromJson(jsonResponse.body);
}