updateTaskProtection method
Updates the protection status of a task. You can set
protectionEnabled to true to protect your task
from termination during scale-in events from Service
Autoscaling or deployments.
Task-protection, by default, expires after 2 hours at which point Amazon
ECS clears the protectionEnabled property making the task
eligible for termination by a subsequent scale-in event.
You can specify a custom expiration period for task protection from 1
minute to up to 2,880 minutes (48 hours). To specify the custom expiration
period, set the expiresInMinutes property. The
expiresInMinutes property is always reset when you invoke
this operation for a task that already has protectionEnabled
set to true. You can keep extending the protection expiration
period of a task by invoking this operation repeatedly.
To learn more about Amazon ECS task protection, see Task scale-in protection in the Amazon Elastic Container Service Developer Guide .
May throw AccessDeniedException.
May throw ClientException.
May throw ClusterNotFoundException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServerException.
May throw UnsupportedFeatureException.
Parameter cluster :
The short name or full Amazon Resource Name (ARN) of the cluster that
hosts the service that the task sets exist in.
Parameter protectionEnabled :
Specify true to mark a task for protection and
false to unset protection, making it eligible for
termination.
Parameter tasks :
A list of up to 10 task IDs or full ARN entries.
Parameter expiresInMinutes :
If you set protectionEnabled to true, you can
specify the duration for task protection in minutes. You can specify a
value from 1 minute to up to 2,880 minutes (48 hours). During this time,
your task will not be terminated by scale-in events from Service Auto
Scaling or deployments. After this time period lapses,
protectionEnabled will be reset to false.
If you don’t specify the time, then the task is automatically protected for 120 minutes (2 hours).
Implementation
Future<UpdateTaskProtectionResponse> updateTaskProtection({
required String cluster,
required bool protectionEnabled,
required List<String> tasks,
int? expiresInMinutes,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonEC2ContainerServiceV20141113.UpdateTaskProtection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'cluster': cluster,
'protectionEnabled': protectionEnabled,
'tasks': tasks,
if (expiresInMinutes != null) 'expiresInMinutes': expiresInMinutes,
},
);
return UpdateTaskProtectionResponse.fromJson(jsonResponse.body);
}