Efs class
Amazon Elastic File System (Amazon EFS) provides simple, scalable file storage for use with Amazon EC2 Linux and Mac instances in the Amazon Web Services Cloud. With Amazon EFS, storage capacity is elastic, growing and shrinking automatically as you add and remove files, so that your applications have the storage they need, when they need it. For more information, see the Amazon Elastic File System API Reference and the Amazon Elastic File System User Guide.
Constructors
- Efs({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessPoint(
{required String fileSystemId, String? clientToken, PosixUser? posixUser, RootDirectory? rootDirectory, List< Tag> ? tags}) → Future<AccessPointDescription> -
Creates an EFS access point. An access point is an application-specific
view into an EFS file system that applies an operating system user and
group, and a file system path, to any file system request made through the
access point. The operating system user and group override any identity
information provided by the NFS client. The file system path is exposed as
the access point's root directory. Applications using the access point can
only access data in the application's own directory and any
subdirectories. A file system can have a maximum of 10,000 access points
unless you request an increase. To learn more, see Mounting
a file system using EFS access points.
This operation requires permissions for the
elasticfilesystem:CreateAccessPointaction. -
createFileSystem(
{String? availabilityZoneName, bool? backup, String? creationToken, bool? encrypted, String? kmsKeyId, PerformanceMode? performanceMode, double? provisionedThroughputInMibps, List< Tag> ? tags, ThroughputMode? throughputMode}) → Future<FileSystemDescription> - Creates a new, empty file system. The operation requires a creation token in the request that Amazon EFS uses to ensure idempotent creation (calling the operation with same creation token has no effect). If a file system does not currently exist that is owned by the caller's Amazon Web Services account with the specified creation token, this operation does the following:
-
createMountTarget(
{required String fileSystemId, required String subnetId, String? ipAddress, IpAddressType? ipAddressType, String? ipv6Address, List< String> ? securityGroups}) → Future<MountTargetDescription> - Creates a mount target for a file system. You can then mount the file system on EC2 instances by using the mount target.
-
createReplicationConfiguration(
{required List< DestinationToCreate> destinations, required String sourceFileSystemId}) → Future<ReplicationConfigurationDescription> - Creates a replication configuration to either a new or existing EFS file system. For more information, see Amazon EFS replication in the Amazon EFS User Guide. The replication configuration specifies the following:
-
createTags(
{required String fileSystemId, required List< Tag> tags}) → Future<void> - Name
-
deleteAccessPoint(
{required String accessPointId}) → Future< void> - Deletes the specified access point. After deletion is complete, new clients can no longer connect to the access points. Clients connected to the access point at the time of deletion will continue to function until they terminate their connection.
-
deleteFileSystem(
{required String fileSystemId}) → Future< void> - Deletes a file system, permanently severing access to its contents. Upon return, the file system no longer exists and you can't access any contents of the deleted file system.
-
deleteFileSystemPolicy(
{required String fileSystemId}) → Future< void> -
Deletes the
FileSystemPolicyfor the specified file system. The defaultFileSystemPolicygoes into effect once the existing policy is deleted. For more information about the default file system policy, see Using Resource-based Policies with EFS. -
deleteMountTarget(
{required String mountTargetId}) → Future< void> - Deletes the specified mount target.
-
deleteReplicationConfiguration(
{required String sourceFileSystemId, DeletionMode? deletionMode}) → Future< void> -
Deletes a replication configuration. Deleting a replication configuration
ends the replication process. After a replication configuration is
deleted, the destination file system becomes
Writeableand its replication overwrite protection is re-enabled. For more information, see Delete a replication configuration. -
deleteTags(
{required String fileSystemId, required List< String> tagKeys}) → Future<void> - DeleteTags
-
describeAccessPoints(
{String? accessPointId, String? fileSystemId, int? maxResults, String? nextToken}) → Future< DescribeAccessPointsResponse> -
Returns the description of a specific Amazon EFS access point if the
AccessPointIdis provided. If you provide an EFSFileSystemId, it returns descriptions of all access points for that file system. You can provide either anAccessPointIdor aFileSystemIdin the request, but not both. -
describeAccountPreferences(
{int? maxResults, String? nextToken}) → Future< DescribeAccountPreferencesResponse> - Returns the account preferences settings for the Amazon Web Services account associated with the user making the request, in the current Amazon Web Services Region.
-
describeBackupPolicy(
{required String fileSystemId}) → Future< BackupPolicyDescription> - Returns the backup policy for the specified EFS file system.
-
describeFileSystemPolicy(
{required String fileSystemId}) → Future< FileSystemPolicyDescription> -
Returns the
FileSystemPolicyfor the specified EFS file system. -
describeFileSystems(
{String? creationToken, String? fileSystemId, String? marker, int? maxItems}) → Future< DescribeFileSystemsResponse> -
Returns the description of a specific Amazon EFS file system if either the
file system
CreationTokenor theFileSystemIdis provided. Otherwise, it returns descriptions of all file systems owned by the caller's Amazon Web Services account in the Amazon Web Services Region of the endpoint that you're calling. -
describeLifecycleConfiguration(
{required String fileSystemId}) → Future< LifecycleConfigurationDescription> -
Returns the current
LifecycleConfigurationobject for the specified EFS file system. Lifecycle management uses theLifecycleConfigurationobject to identify when to move files between storage classes. For a file system without aLifecycleConfigurationobject, the call returns an empty array in the response. -
describeMountTargets(
{String? accessPointId, String? fileSystemId, String? marker, int? maxItems, String? mountTargetId}) → Future< DescribeMountTargetsResponse> - Returns the descriptions of all the current mount targets, or a specific mount target, for a file system. When requesting all of the current mount targets, the order of mount targets returned in the response is unspecified.
-
describeMountTargetSecurityGroups(
{required String mountTargetId}) → Future< DescribeMountTargetSecurityGroupsResponse> -
Returns the security groups currently in effect for a mount target. This
operation requires that the network interface of the mount target has been
created and the lifecycle state of the mount target is not
deleted. -
describeReplicationConfigurations(
{String? fileSystemId, int? maxResults, String? nextToken}) → Future< DescribeReplicationConfigurationsResponse> - Retrieves the replication configuration for a specific file system. If a file system is not specified, all of the replication configurations for the Amazon Web Services account in an Amazon Web Services Region are retrieved.
-
describeTags(
{required String fileSystemId, String? marker, int? maxItems}) → Future< DescribeTagsResponse> - DescribeTags
-
listTagsForResource(
{required String resourceId, int? maxResults, String? nextToken}) → Future< ListTagsForResourceResponse> - Lists all tags for a top-level EFS resource. You must provide the ID of the resource that you want to retrieve the tags for.
-
modifyMountTargetSecurityGroups(
{required String mountTargetId, List< String> ? securityGroups}) → Future<void> - Modifies the set of security groups in effect for a mount target.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAccountPreferences(
{required ResourceIdType resourceIdType}) → Future< PutAccountPreferencesResponse> - Use this operation to set the account preference in the current Amazon Web Services Region to use long 17 character (63 bit) or short 8 character (32 bit) resource IDs for new EFS file system and mount target resources. All existing resource IDs are not affected by any changes you make. You can set the ID preference during the opt-in period as EFS transitions to long resource IDs. For more information, see Managing Amazon EFS resource IDs.
-
putBackupPolicy(
{required BackupPolicy backupPolicy, required String fileSystemId}) → Future< BackupPolicyDescription> - Updates the file system's backup policy. Use this action to start or stop automatic backups of the file system.
-
putFileSystemPolicy(
{required String fileSystemId, required String policy, bool? bypassPolicyLockoutSafetyCheck}) → Future< FileSystemPolicyDescription> -
Applies an Amazon EFS
FileSystemPolicyto an Amazon EFS file system. A file system policy is an IAM resource-based policy and can contain multiple policy statements. A file system always has exactly one file system policy, which can be the default policy or an explicit policy set or updated using this API operation. EFS file system policies have a 20,000 character limit. When an explicit policy is set, it overrides the default policy. For more information about the default file system policy, see Default EFS file system policy. This operation requires permissions for theelasticfilesystem:PutFileSystemPolicyaction. -
putLifecycleConfiguration(
{required String fileSystemId, required List< LifecyclePolicy> lifecyclePolicies}) → Future<LifecycleConfigurationDescription> -
Use this action to manage storage for your file system. A
LifecycleConfigurationconsists of one or moreLifecyclePolicyobjects that define the following: -
tagResource(
{required String resourceId, required List< Tag> tags}) → Future<void> - Creates a tag for an EFS resource. You can create tags for EFS file systems and access points using this API operation.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceId, required List< String> tagKeys}) → Future<void> - Removes tags from an EFS resource. You can remove tags from EFS file systems and access points using this API operation.
-
updateFileSystem(
{required String fileSystemId, double? provisionedThroughputInMibps, ThroughputMode? throughputMode}) → Future< FileSystemDescription> - Updates the throughput mode or the amount of provisioned throughput of an existing file system.
-
updateFileSystemProtection(
{required String fileSystemId, ReplicationOverwriteProtection? replicationOverwriteProtection}) → Future< FileSystemProtectionDescription> - Updates protection on the file system.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited