createMountTarget method
Creates a mount target for a file system. You can then mount the file system on EC2 instances by using the mount target.
You can create one mount target in each Availability Zone in your VPC. All EC2 instances in a VPC within a given Availability Zone share a single mount target for a given file system. If you have multiple subnets in an Availability Zone, you create a mount target in one of the subnets. EC2 instances do not need to be in the same subnet as the mount target in order to access their file system.
You can create only one mount target for a One Zone file system. You must
create that mount target in the same Availability Zone in which the file
system is located. Use the AvailabilityZoneName and
AvailabiltyZoneId properties in the
DescribeFileSystems response object to get this information. Use
the subnetId associated with the file system's Availability
Zone when creating the mount target.
For more information, see Amazon EFS: How it Works.
To create a mount target for a file system, the file system's lifecycle
state must be available. For more information, see
DescribeFileSystems.
In the request, provide the following:
- The file system ID for which you are creating the mount target.
-
A subnet ID, which determines the following:
- The VPC in which Amazon EFS creates the mount target
- The Availability Zone in which Amazon EFS creates the mount target
- The IP address range from which Amazon EFS selects the IP address of the mount target (if you don't specify an IP address in the request)
MountTargetId and an IpAddress. You
use this IP address when mounting the file system in an EC2 instance. You
can also use the mount target's DNS name when mounting the file system.
The EC2 instance on which you mount the file system by using the mount
target can resolve the mount target's DNS name to its IP address. For more
information, see How
it Works: Implementation Overview.
Note that you can create mount targets for a file system in only one VPC, and there can be only one mount target per Availability Zone. That is, if the file system already has one or more mount targets created for it, the subnet specified in the request to add another mount target must meet the following requirements:
- Must belong to the same VPC as the subnets of the existing mount targets
- Must not be in the same Availability Zone as any of the subnets of the existing mount targets
- Creates a new mount target in the specified subnet.
-
Also creates a new network interface in the subnet as follows:
-
If the request provides an
IpAddress, Amazon EFS assigns that IP address to the network interface. Otherwise, Amazon EFS assigns a free address in the subnet (in the same way that the Amazon EC2CreateNetworkInterfacecall does when a request does not specify a primary private IP address). -
If the request provides
SecurityGroups, this network interface is associated with those security groups. Otherwise, it belongs to the default security group for the subnet's VPC. -
Assigns the description
Mount target fsmt-id for file system fs-idwherefsmt-idis the mount target ID, andfs-idis theFileSystemId. -
Sets the
requesterManagedproperty of the network interface totrue, and therequesterIdvalue toEFS.
NetworkInterfaceIdfield in the mount target's description to the network interface ID, and theIpAddressfield to its address. If network interface creation fails, the entireCreateMountTargetoperation fails. -
If the request provides an
This operation requires permissions for the following action on the file system:
-
elasticfilesystem:CreateMountTarget
-
ec2:DescribeSubnets -
ec2:DescribeNetworkInterfaces -
ec2:CreateNetworkInterface
May throw AvailabilityZonesMismatch.
May throw BadRequest.
May throw FileSystemNotFound.
May throw IncorrectFileSystemLifeCycleState.
May throw InternalServerError.
May throw IpAddressInUse.
May throw MountTargetConflict.
May throw NetworkInterfaceLimitExceeded.
May throw NoFreeAddressesInSubnet.
May throw SecurityGroupLimitExceeded.
May throw SecurityGroupNotFound.
May throw SubnetNotFound.
May throw UnsupportedAvailabilityZone.
Parameter fileSystemId :
The ID of the file system for which to create the mount target.
Parameter subnetId :
The ID of the subnet to add the mount target in. For One Zone file
systems, use the subnet that is associated with the file system's
Availability Zone.
Parameter ipAddress :
If the IP address type for the mount target is IPv4, then specify the IPv4
address within the address range of the specified subnet.
Parameter ipAddressType :
Specify the type of IP address of the mount target you are creating.
Options are IPv4, dual stack, or IPv6. If you don’t specify an
IpAddressType, then IPv4 is used.
- IPV4_ONLY – Create mount target with IPv4 only subnet or dual-stack subnet.
- DUAL_STACK – Create mount target with dual-stack subnet.
- IPV6_ONLY – Create mount target with IPv6 only subnet.
Parameter ipv6Address :
If the IP address type for the mount target is IPv6, then specify the IPv6
address within the address range of the specified subnet.
Parameter securityGroups :
VPC security group IDs, of the form sg-xxxxxxxx. These must
be for the same VPC as the subnet specified. The maximum number of
security groups depends on account quota. For more information, see Amazon
VPC Quotas in the Amazon VPC User Guide (see the Security
Groups table).
Implementation
Future<MountTargetDescription> createMountTarget({
required String fileSystemId,
required String subnetId,
String? ipAddress,
IpAddressType? ipAddressType,
String? ipv6Address,
List<String>? securityGroups,
}) async {
final $payload = <String, dynamic>{
'FileSystemId': fileSystemId,
'SubnetId': subnetId,
if (ipAddress != null) 'IpAddress': ipAddress,
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (ipv6Address != null) 'Ipv6Address': ipv6Address,
if (securityGroups != null) 'SecurityGroups': securityGroups,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2015-02-01/mount-targets',
exceptionFnMap: _exceptionFns,
);
return MountTargetDescription.fromJson(response);
}