updateFileSystem method
Updates the throughput mode or the amount of provisioned throughput of an existing file system.
May throw BadRequest.
May throw FileSystemNotFound.
May throw IncorrectFileSystemLifeCycleState.
May throw InsufficientThroughputCapacity.
May throw InternalServerError.
May throw ThroughputLimitExceeded.
May throw TooManyRequests.
Parameter fileSystemId :
The ID of the file system that you want to update.
Parameter provisionedThroughputInMibps :
(Optional) The throughput, measured in mebibytes per second (MiBps), that
you want to provision for a file system that you're creating. Required if
ThroughputMode is set to provisioned. Valid
values are 1-3414 MiBps, with the upper limit depending on Region. To
increase this limit, contact Amazon Web Services Support. For more
information, see Amazon
EFS quotas that you can increase in the Amazon EFS User Guide.
Parameter throughputMode :
(Optional) Updates the file system's throughput mode. If you're not
updating your throughput mode, you don't need to provide this value in
your request. If you are changing the ThroughputMode to
provisioned, you must also set a value for
ProvisionedThroughputInMibps.
Implementation
Future<FileSystemDescription> updateFileSystem({
required String fileSystemId,
double? provisionedThroughputInMibps,
ThroughputMode? throughputMode,
}) async {
_s.validateNumRange(
'provisionedThroughputInMibps',
provisionedThroughputInMibps,
1.0,
1152921504606846976,
);
final $payload = <String, dynamic>{
if (provisionedThroughputInMibps != null)
'ProvisionedThroughputInMibps': provisionedThroughputInMibps,
if (throughputMode != null) 'ThroughputMode': throughputMode.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/2015-02-01/file-systems/${Uri.encodeComponent(fileSystemId)}',
exceptionFnMap: _exceptionFns,
);
return FileSystemDescription.fromJson(response);
}