describeAddonVersions method
Describes the versions for an add-on.
Information such as the Kubernetes versions that you can use the add-on
with, the owner, publisher, and the
type of the add-on are returned.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter addonName :
The name of the add-on. The name must match one of the names returned by
ListAddons .
Parameter kubernetesVersion :
The Kubernetes versions that you can use the add-on with.
Parameter maxResults :
The maximum number of results, returned in paginated output. You receive
maxResults in a single page, along with a
nextToken response element. You can see the remaining results
of the initial request by sending another request with the returned
nextToken value. This value can be between 1 and 100. If you
don't use this parameter, 100 results and a nextToken value,
if applicable, are returned.
Parameter nextToken :
The nextToken value returned from a previous paginated
request, where maxResults was used and the results exceeded
the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value. This
value is null when there are no more results to return.
Parameter owners :
The owner of the add-on. For valid owners, don't specify a
value for this property.
Parameter publishers :
The publisher of the add-on. For valid publishers, don't
specify a value for this property.
Parameter types :
The type of the add-on. For valid types, don't specify a
value for this property.
Implementation
Future<DescribeAddonVersionsResponse> describeAddonVersions({
String? addonName,
String? kubernetesVersion,
int? maxResults,
String? nextToken,
List<String>? owners,
List<String>? publishers,
List<String>? types,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (addonName != null) 'addonName': [addonName],
if (kubernetesVersion != null) 'kubernetesVersion': [kubernetesVersion],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (owners != null) 'owners': owners,
if (publishers != null) 'publishers': publishers,
if (types != null) 'types': types,
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/addons/supported-versions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeAddonVersionsResponse.fromJson(response);
}