describeCluster method
Describes an Amazon EKS cluster.
The API server endpoint and certificate authority data returned by this
operation are required for kubelet and kubectl
to communicate with your Kubernetes API server. For more information, see
Creating
or updating a kubeconfig file for an Amazon EKS cluster.
May throw ClientException.
May throw ResourceNotFoundException.
May throw ServerException.
May throw ServiceUnavailableException.
Parameter name :
The name of your cluster.
Implementation
Future<DescribeClusterResponse> describeCluster({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/clusters/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return DescribeClusterResponse.fromJson(response);
}