describeInsight method
Returns details about an insight that you specify using its ID.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter clusterName :
The name of the cluster to describe the insight for.
Parameter id :
The identity of the insight to describe.
Implementation
Future<DescribeInsightResponse> describeInsight({
required String clusterName,
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/clusters/${Uri.encodeComponent(clusterName)}/insights/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return DescribeInsightResponse.fromJson(response);
}