describeUpdate method
Describes an update to an Amazon EKS resource.
When the status of the update is Successful, the update is
complete. If an update fails, the status is Failed, and an
error detail explains the reason for the failure.
May throw ClientException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ServerException.
Parameter name :
The name of the Amazon EKS cluster associated with the update.
Parameter updateId :
The ID of the update to describe.
Parameter addonName :
The name of the add-on. The name must match one of the names returned by
ListAddons . This parameter is required if the update is
an add-on update.
Parameter capabilityName :
The name of the capability for which you want to describe updates.
Parameter nodegroupName :
The name of the Amazon EKS node group associated with the update. This
parameter is required if the update is a node group update.
Implementation
Future<DescribeUpdateResponse> describeUpdate({
required String name,
required String updateId,
String? addonName,
String? capabilityName,
String? nodegroupName,
}) async {
final $query = <String, List<String>>{
if (addonName != null) 'addonName': [addonName],
if (capabilityName != null) 'capabilityName': [capabilityName],
if (nodegroupName != null) 'nodegroupName': [nodegroupName],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/clusters/${Uri.encodeComponent(name)}/updates/${Uri.encodeComponent(updateId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeUpdateResponse.fromJson(response);
}