listCapabilities method
Lists all managed capabilities in your Amazon EKS cluster. You can use this operation to get an overview of all capabilities and their current status.
May throw InvalidParameterException.
May throw ServerException.
Parameter clusterName :
The name of the Amazon EKS cluster for which you want to list
capabilities.
Parameter maxResults :
The maximum number of results to return in a single call. To retrieve the
remaining results, make another call with the returned
nextToken value. If you don't specify a value, the default is
100 results.
Parameter nextToken :
The nextToken value returned from a previous paginated
request, where maxResults was used and the results exceeded
the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value. This
value is null when there are no more results to return.
Implementation
Future<ListCapabilitiesResponse> listCapabilities({
required String clusterName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/clusters/${Uri.encodeComponent(clusterName)}/capabilities',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCapabilitiesResponse.fromJson(response);
}