EksAuth class
The Amazon EKS Auth API and the AssumeRoleForPodIdentity action
are only used by the EKS Pod Identity Agent.
Constructors
- EksAuth({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assumeRoleForPodIdentity(
{required String clusterName, required String token}) → Future< AssumeRoleForPodIdentityResponse> -
The Amazon EKS Auth API and the
AssumeRoleForPodIdentityaction are only used by the EKS Pod Identity Agent. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited