describeServerlessCacheSnapshots method
Returns information about serverless cache snapshots. By default, this API lists all of the customer’s serverless cache snapshots. It can also describe a single serverless cache snapshot, or the snapshots associated with a particular serverless cache. Available for Valkey, Redis OSS and Serverless Memcached only.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw ServerlessCacheNotFoundFault.
May throw ServerlessCacheSnapshotNotFoundFault.
Parameter maxResults :
The maximum number of records to include in the response. If more records
exist than the specified max-results value, a market is included in the
response so that remaining results can be retrieved. Available for Valkey,
Redis OSS and Serverless Memcached only.The default is 50. The Validation
Constraints are a maximum of 50.
Parameter nextToken :
An optional marker returned from a prior request to support pagination of
results from this operation. If this parameter is specified, the response
includes only records beyond the marker, up to the value specified by
max-results. Available for Valkey, Redis OSS and Serverless Memcached
only.
Parameter serverlessCacheName :
The identifier of serverless cache. If this parameter is specified, only
snapshots associated with that specific serverless cache are described.
Available for Valkey, Redis OSS and Serverless Memcached only.
Parameter serverlessCacheSnapshotName :
The identifier of the serverless cache’s snapshot. If this parameter is
specified, only this snapshot is described. Available for Valkey, Redis
OSS and Serverless Memcached only.
Parameter snapshotType :
The type of snapshot that is being described. Available for Valkey, Redis
OSS and Serverless Memcached only.
Implementation
Future<DescribeServerlessCacheSnapshotsResponse>
describeServerlessCacheSnapshots({
int? maxResults,
String? nextToken,
String? serverlessCacheName,
String? serverlessCacheSnapshotName,
String? snapshotType,
}) async {
final $request = <String, String>{
if (maxResults != null) 'MaxResults': maxResults.toString(),
if (nextToken != null) 'NextToken': nextToken,
if (serverlessCacheName != null)
'ServerlessCacheName': serverlessCacheName,
if (serverlessCacheSnapshotName != null)
'ServerlessCacheSnapshotName': serverlessCacheSnapshotName,
if (snapshotType != null) 'SnapshotType': snapshotType,
};
final $result = await _protocol.send(
$request,
action: 'DescribeServerlessCacheSnapshots',
version: '2015-02-02',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeServerlessCacheSnapshotsResult',
);
return DescribeServerlessCacheSnapshotsResponse.fromXml($result);
}