deleteApplication method
Deletes the specified application along with all associated versions and configurations. The application versions will not be deleted from your Amazon S3 bucket.
May throw OperationInProgressException.
Parameter applicationName :
The name of the application to delete.
Parameter terminateEnvByForce :
When set to true, running environments will be terminated before deleting
the application.
Implementation
Future<void> deleteApplication({
required String applicationName,
bool? terminateEnvByForce,
}) async {
final $request = <String, String>{
'ApplicationName': applicationName,
if (terminateEnvByForce != null)
'TerminateEnvByForce': terminateEnvByForce.toString(),
};
await _protocol.send(
$request,
action: 'DeleteApplication',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}