describeEvents method
Returns list of event descriptions matching criteria up to the last 6 weeks.
Parameter applicationName :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
include only those associated with this application.
Parameter endTime :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those that occur up to, but not including, the EndTime.
Parameter environmentId :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those associated with this environment.
Parameter environmentName :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those associated with this environment.
Parameter maxRecords :
Specifies the maximum number of events that can be returned, beginning
with the most recent event.
Parameter nextToken :
Pagination token. If specified, the events return the next batch of
results.
Parameter platformArn :
The ARN of a custom platform version. If specified, AWS Elastic Beanstalk
restricts the returned descriptions to those associated with this custom
platform version.
Parameter requestId :
If specified, AWS Elastic Beanstalk restricts the described events to
include only those associated with this request ID.
Parameter severity :
If specified, limits the events returned from this call to include only
those with the specified severity or higher.
Parameter startTime :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those that occur on or after this time.
Parameter templateName :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those that are associated with this environment configuration.
Parameter versionLabel :
If specified, AWS Elastic Beanstalk restricts the returned descriptions to
those associated with this application version.
Implementation
Future<EventDescriptionsMessage> describeEvents({
String? applicationName,
DateTime? endTime,
String? environmentId,
String? environmentName,
int? maxRecords,
String? nextToken,
String? platformArn,
String? requestId,
EventSeverity? severity,
DateTime? startTime,
String? templateName,
String? versionLabel,
}) async {
_s.validateNumRange(
'maxRecords',
maxRecords,
1,
1000,
);
final $request = <String, String>{
if (applicationName != null) 'ApplicationName': applicationName,
if (endTime != null) 'EndTime': _s.iso8601ToJson(endTime),
if (environmentId != null) 'EnvironmentId': environmentId,
if (environmentName != null) 'EnvironmentName': environmentName,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (nextToken != null) 'NextToken': nextToken,
if (platformArn != null) 'PlatformArn': platformArn,
if (requestId != null) 'RequestId': requestId,
if (severity != null) 'Severity': severity.value,
if (startTime != null) 'StartTime': _s.iso8601ToJson(startTime),
if (templateName != null) 'TemplateName': templateName,
if (versionLabel != null) 'VersionLabel': versionLabel,
};
final $result = await _protocol.send(
$request,
action: 'DescribeEvents',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeEventsResult',
);
return EventDescriptionsMessage.fromXml($result);
}