describeLoadBalancers method
Describes the specified the load balancers. If no load balancers are specified, the call describes all of your load balancers.
May throw AccessPointNotFoundException.
May throw DependencyThrottleException.
Parameter loadBalancerNames :
The names of the load balancers.
Parameter marker :
The marker for the next set of results. (You received this marker from a
previous call.)
Parameter pageSize :
The maximum number of results to return with this call (a number from 1 to
400). The default is 400.
Implementation
Future<DescribeAccessPointsOutput> describeLoadBalancers({
List<String>? loadBalancerNames,
String? marker,
int? pageSize,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
400,
);
final $request = <String, String>{
if (loadBalancerNames != null)
if (loadBalancerNames.isEmpty)
'LoadBalancerNames': ''
else
for (var i1 = 0; i1 < loadBalancerNames.length; i1++)
'LoadBalancerNames.member.${i1 + 1}': loadBalancerNames[i1],
if (marker != null) 'Marker': marker,
if (pageSize != null) 'PageSize': pageSize.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeLoadBalancers',
version: '2012-06-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeLoadBalancersResult',
);
return DescribeAccessPointsOutput.fromXml($result);
}