describeTrustStoreRevocations method
Describes the revocation files in use by the specified trust store or revocation files.
May throw RevocationIdNotFoundException.
May throw TrustStoreNotFoundException.
Parameter trustStoreArn :
The Amazon Resource Name (ARN) of the trust store.
Parameter marker :
The marker for the next set of results. (You received this marker from a
previous call.)
Parameter pageSize :
The maximum number of results to return with this call.
Parameter revocationIds :
The revocation IDs of the revocation files you want to describe.
Implementation
Future<DescribeTrustStoreRevocationsOutput> describeTrustStoreRevocations({
required String trustStoreArn,
String? marker,
int? pageSize,
List<int>? revocationIds,
}) async {
_s.validateNumRange(
'pageSize',
pageSize,
1,
400,
);
final $request = <String, String>{
'TrustStoreArn': trustStoreArn,
if (marker != null) 'Marker': marker,
if (pageSize != null) 'PageSize': pageSize.toString(),
if (revocationIds != null)
if (revocationIds.isEmpty)
'RevocationIds': ''
else
for (var i1 = 0; i1 < revocationIds.length; i1++)
'RevocationIds.member.${i1 + 1}': revocationIds[i1].toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeTrustStoreRevocations',
version: '2015-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeTrustStoreRevocationsResult',
);
return DescribeTrustStoreRevocationsOutput.fromXml($result);
}