removeTrustStoreRevocations method
Removes the specified revocation file from the specified trust store.
May throw RevocationIdNotFoundException.
May throw TrustStoreNotFoundException.
Parameter revocationIds :
The revocation IDs of the revocation files you want to remove.
Parameter trustStoreArn :
The Amazon Resource Name (ARN) of the trust store.
Implementation
Future<void> removeTrustStoreRevocations({
required List<int> revocationIds,
required String trustStoreArn,
}) async {
final $request = <String, String>{
if (revocationIds.isEmpty)
'RevocationIds': ''
else
for (var i1 = 0; i1 < revocationIds.length; i1++)
'RevocationIds.member.${i1 + 1}': revocationIds[i1].toString(),
'TrustStoreArn': trustStoreArn,
};
await _protocol.send(
$request,
action: 'RemoveTrustStoreRevocations',
version: '2015-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RemoveTrustStoreRevocationsResult',
);
}