acceptInboundCrossClusterSearchConnection method
Future<AcceptInboundCrossClusterSearchConnectionResponse>
acceptInboundCrossClusterSearchConnection({
- required String crossClusterSearchConnectionId,
Allows the destination domain owner to accept an inbound cross-cluster search connection request.
May throw DisabledOperationException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter crossClusterSearchConnectionId :
The id of the inbound connection that you want to accept.
Implementation
Future<AcceptInboundCrossClusterSearchConnectionResponse>
acceptInboundCrossClusterSearchConnection({
required String crossClusterSearchConnectionId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PUT',
requestUri:
'/2015-01-01/es/ccs/inboundConnection/${Uri.encodeComponent(crossClusterSearchConnectionId)}/accept',
exceptionFnMap: _exceptionFns,
);
return AcceptInboundCrossClusterSearchConnectionResponse.fromJson(response);
}