dissociatePackage method
Dissociates a package from the Amazon ES domain.
May throw AccessDeniedException.
May throw BaseException.
May throw ConflictException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
Name of the domain that you want to associate the package with.
Parameter packageID :
Internal ID of the package that you want to associate with a domain. Use
DescribePackages to find this value.
Implementation
Future<DissociatePackageResponse> dissociatePackage({
required String domainName,
required String packageID,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/2015-01-01/packages/dissociate/${Uri.encodeComponent(packageID)}/${Uri.encodeComponent(domainName)}',
exceptionFnMap: _exceptionFns,
);
return DissociatePackageResponse.fromJson(response);
}