getUpgradeStatus method
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Implementation
Future<GetUpgradeStatusResponse> getUpgradeStatus({
required String domainName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2015-01-01/es/upgradeDomain/${Uri.encodeComponent(domainName)}/status',
exceptionFnMap: _exceptionFns,
);
return GetUpgradeStatusResponse.fromJson(response);
}