createPersistentAppUI method
Creates a persistent application user interface.
May throw InternalServerException.
May throw InvalidRequestException.
Parameter targetResourceArn :
The unique Amazon Resource Name (ARN) of the target resource.
Parameter eMRContainersConfig :
The EMR containers configuration.
Parameter profilerType :
The profiler type for the persistent application user interface.
Parameter tags :
Tags for the persistent application user interface.
Parameter xReferer :
The cross reference for the persistent application user interface.
Implementation
Future<CreatePersistentAppUIOutput> createPersistentAppUI({
required String targetResourceArn,
EMRContainersConfig? eMRContainersConfig,
ProfilerType? profilerType,
List<Tag>? tags,
String? xReferer,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.CreatePersistentAppUI'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TargetResourceArn': targetResourceArn,
if (eMRContainersConfig != null)
'EMRContainersConfig': eMRContainersConfig,
if (profilerType != null) 'ProfilerType': profilerType.value,
if (tags != null) 'Tags': tags,
if (xReferer != null) 'XReferer': xReferer,
},
);
return CreatePersistentAppUIOutput.fromJson(jsonResponse.body);
}