setVisibleToAllUsers method
Sets the Cluster$VisibleToAllUsers value for an Amazon EMR cluster.
When
true, IAM principals in the Amazon Web Services account
can perform Amazon EMR cluster actions that their IAM policies allow. When
false, only the IAM principal that created the cluster and
the Amazon Web Services account root user can perform Amazon EMR actions
on the cluster, regardless of IAM permissions policies attached to other
IAM principals.
This action works on running clusters. When you create a cluster, use the RunJobFlowInput$VisibleToAllUsers parameter.
For more information, see Understanding the Amazon EMR Cluster VisibleToAllUsers Setting in the Amazon EMR Management Guide.
May throw InternalServerError.
Parameter jobFlowIds :
The unique identifier of the job flow (cluster).
Parameter visibleToAllUsers :
A value of true indicates that an IAM principal in the Amazon
Web Services account can perform Amazon EMR actions on the cluster that
the IAM policies attached to the principal allow. A value of
false indicates that only the IAM principal that created the
cluster and the Amazon Web Services root user can perform Amazon EMR
actions on the cluster.
Implementation
Future<void> setVisibleToAllUsers({
required List<String> jobFlowIds,
required bool visibleToAllUsers,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ElasticMapReduce.SetVisibleToAllUsers'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobFlowIds': jobFlowIds,
'VisibleToAllUsers': visibleToAllUsers,
},
);
}