deleteJobTemplate method
Deletes a job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
May throw InternalServerException.
May throw ValidationException.
Parameter id :
The ID of the job template that will be deleted.
Implementation
Future<DeleteJobTemplateResponse> deleteJobTemplate({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/jobtemplates/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return DeleteJobTemplateResponse.fromJson(response);
}