deleteVirtualCluster method
Deletes a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
May throw InternalServerException.
May throw ValidationException.
Parameter id :
The ID of the virtual cluster that will be deleted.
Implementation
Future<DeleteVirtualClusterResponse> deleteVirtualCluster({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/virtualclusters/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return DeleteVirtualClusterResponse.fromJson(response);
}