listManagedEndpoints method
Lists managed endpoints based on a set of parameters. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
May throw InternalServerException.
May throw ValidationException.
Parameter virtualClusterId :
The ID of the virtual cluster.
Parameter createdAfter :
The date and time after which the endpoints are created.
Parameter createdBefore :
The date and time before which the endpoints are created.
Parameter maxResults :
The maximum number of managed endpoints that can be listed.
Parameter nextToken :
The token for the next set of managed endpoints to return.
Parameter states :
The states of the managed endpoints.
Parameter types :
The types of the managed endpoints.
Implementation
Future<ListManagedEndpointsResponse> listManagedEndpoints({
required String virtualClusterId,
DateTime? createdAfter,
DateTime? createdBefore,
int? maxResults,
String? nextToken,
List<EndpointState>? states,
List<String>? types,
}) async {
final $query = <String, List<String>>{
if (createdAfter != null)
'createdAfter': [_s.iso8601ToJson(createdAfter).toString()],
if (createdBefore != null)
'createdBefore': [_s.iso8601ToJson(createdBefore).toString()],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (states != null) 'states': states.map((e) => e.value).toList(),
if (types != null) 'types': types,
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/virtualclusters/${Uri.encodeComponent(virtualClusterId)}/endpoints',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListManagedEndpointsResponse.fromJson(response);
}