getResourceDashboard method
Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
For resources in a running state, the application UI is a live user interface such as the Spark web UI. For terminated resources, the application UI is a persistent application user interface such as the Spark History Server.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter applicationId :
The ID of the application that the resource belongs to.
Parameter resourceId :
The ID of the resource.
Parameter resourceType :
The type of resource to access the dashboard for. Currently, only
Session is supported.
Implementation
Future<GetResourceDashboardResponse> getResourceDashboard({
required String applicationId,
required String resourceId,
required ResourceType resourceType,
}) async {
final $query = <String, List<String>>{
'resourceId': [resourceId],
'resourceType': [resourceType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/dashboard',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetResourceDashboardResponse.fromJson(response);
}