EntityResolution class
Welcome to the Entity Resolution API Reference.
Entity Resolution is an Amazon Web Services service that provides pre-configured entity resolution capabilities that enable developers and analysts at advertising and marketing companies to build an accurate and complete view of their consumers.
With Entity Resolution, you can match source records containing consumer identifiers, such as name, email address, and phone number. This is true even when these records have incomplete or conflicting identifiers. For example, Entity Resolution can effectively match a source record from a customer relationship management (CRM) system with a source record from a marketing system containing campaign information.
To learn more about Entity Resolution concepts, procedures, and best practices, see the Entity Resolution User Guide.
Constructors
- EntityResolution({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addPolicyStatement(
{required List< String> action, required String arn, required StatementEffect effect, required List<String> principal, required String statementId, String? condition}) → Future<AddPolicyStatementOutput> -
Adds a policy statement object. To retrieve a list of existing policy
statements, use the
GetPolicyAPI. -
batchDeleteUniqueId(
{required List< String> uniqueIds, required String workflowName, String? inputSource}) → Future<BatchDeleteUniqueIdOutput> - Deletes multiple unique IDs in a matching workflow.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createIdMappingWorkflow(
{required IdMappingTechniques idMappingTechniques, required List< IdMappingWorkflowInputSource> inputSourceConfig, required String workflowName, String? description, IdMappingIncrementalRunConfig? incrementalRunConfig, List<IdMappingWorkflowOutputSource> ? outputSourceConfig, String? roleArn, Map<String, String> ? tags}) → Future<CreateIdMappingWorkflowOutput> -
Creates an
IdMappingWorkflowobject which stores the configuration of the data processing job to be run. EachIdMappingWorkflowmust have a unique workflow name. To modify an existing workflow, use the UpdateIdMappingWorkflow API. -
createIdNamespace(
{required String idNamespaceName, required IdNamespaceType type, String? description, List< IdNamespaceIdMappingWorkflowProperties> ? idMappingWorkflowProperties, List<IdNamespaceInputSource> ? inputSourceConfig, String? roleArn, Map<String, String> ? tags}) → Future<CreateIdNamespaceOutput> - Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it. Each ID namespace must have a unique name. To modify an existing ID namespace, use the UpdateIdNamespace API.
-
createMatchingWorkflow(
{required List< InputSource> inputSourceConfig, required List<OutputSource> outputSourceConfig, required ResolutionTechniques resolutionTechniques, required String roleArn, required String workflowName, String? description, IncrementalRunConfig? incrementalRunConfig, Map<String, String> ? tags}) → Future<CreateMatchingWorkflowOutput> -
Creates a matching workflow that defines the configuration for a data
processing job. The workflow name must be unique. To modify an existing
workflow, use
UpdateMatchingWorkflow. -
createSchemaMapping(
{required List< SchemaInputAttribute> mappedInputFields, required String schemaName, String? description, Map<String, String> ? tags}) → Future<CreateSchemaMappingOutput> -
Creates a schema mapping, which defines the schema of the input customer
records table. The
SchemaMappingalso provides Entity Resolution with some metadata about the table, such as the attribute types of the columns and which columns to match on. -
deleteIdMappingWorkflow(
{required String workflowName}) → Future< DeleteIdMappingWorkflowOutput> -
Deletes the
IdMappingWorkflowwith a given name. This operation will succeed even if a workflow with the given name does not exist. -
deleteIdNamespace(
{required String idNamespaceName}) → Future< DeleteIdNamespaceOutput> -
Deletes the
IdNamespacewith a given name. -
deleteMatchingWorkflow(
{required String workflowName}) → Future< DeleteMatchingWorkflowOutput> -
Deletes the
MatchingWorkflowwith a given name. This operation will succeed even if a workflow with the given name does not exist. -
deletePolicyStatement(
{required String arn, required String statementId}) → Future< DeletePolicyStatementOutput> - Deletes the policy statement.
-
deleteSchemaMapping(
{required String schemaName}) → Future< DeleteSchemaMappingOutput> -
Deletes the
SchemaMappingwith a given name. This operation will succeed even if a schema with the given name does not exist. This operation will fail if there is aMatchingWorkflowobject that references theSchemaMappingin the workflow'sInputSourceConfig. -
generateMatchId(
{required List< Record> records, required String workflowName, ProcessingType? processingType}) → Future<GenerateMatchIdOutput> - Generates or retrieves Match IDs for records using a rule-based matching workflow. When you call this operation, it processes your records against the workflow's matching rules to identify potential matches. For existing records, it retrieves their Match IDs and associated rules. For records without matches, it generates new Match IDs. The operation saves results to Amazon S3.
-
getIdMappingJob(
{required String jobId, required String workflowName}) → Future< GetIdMappingJobOutput> - Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
getIdMappingWorkflow(
{required String workflowName}) → Future< GetIdMappingWorkflowOutput> -
Returns the
IdMappingWorkflowwith a given name, if it exists. -
getIdNamespace(
{required String idNamespaceName}) → Future< GetIdNamespaceOutput> -
Returns the
IdNamespacewith a given name, if it exists. -
getMatchId(
{required Map< String, String> record, required String workflowName, bool? applyNormalization}) → Future<GetMatchIdOutput> - Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
-
getMatchingJob(
{required String jobId, required String workflowName}) → Future< GetMatchingJobOutput> - Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
getMatchingWorkflow(
{required String workflowName}) → Future< GetMatchingWorkflowOutput> -
Returns the
MatchingWorkflowwith a given name, if it exists. -
getPolicy(
{required String arn}) → Future< GetPolicyOutput> - Returns the resource-based policy.
-
getProviderService(
{required String providerName, required String providerServiceName}) → Future< GetProviderServiceOutput> -
Returns the
ProviderServiceof a given name. -
getSchemaMapping(
{required String schemaName}) → Future< GetSchemaMappingOutput> - Returns the SchemaMapping of a given name.
-
listIdMappingJobs(
{required String workflowName, int? maxResults, String? nextToken}) → Future< ListIdMappingJobsOutput> - Lists all ID mapping jobs for a given workflow.
-
listIdMappingWorkflows(
{int? maxResults, String? nextToken}) → Future< ListIdMappingWorkflowsOutput> -
Returns a list of all the
IdMappingWorkflowsthat have been created for an Amazon Web Services account. -
listIdNamespaces(
{int? maxResults, String? nextToken}) → Future< ListIdNamespacesOutput> - Returns a list of all ID namespaces.
-
listMatchingJobs(
{required String workflowName, int? maxResults, String? nextToken}) → Future< ListMatchingJobsOutput> - Lists all jobs for a given workflow.
-
listMatchingWorkflows(
{int? maxResults, String? nextToken}) → Future< ListMatchingWorkflowsOutput> -
Returns a list of all the
MatchingWorkflowsthat have been created for an Amazon Web Services account. -
listProviderServices(
{int? maxResults, String? nextToken, String? providerName}) → Future< ListProviderServicesOutput> -
Returns a list of all the
ProviderServicesthat are available in this Amazon Web Services Region. -
listSchemaMappings(
{int? maxResults, String? nextToken}) → Future< ListSchemaMappingsOutput> -
Returns a list of all the
SchemaMappingsthat have been created for an Amazon Web Services account. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> -
Displays the tags associated with an Entity Resolution resource. In Entity
Resolution,
SchemaMapping, andMatchingWorkflowcan be tagged. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putPolicy(
{required String arn, required String policy, String? token}) → Future< PutPolicyOutput> - Updates the resource-based policy.
-
startIdMappingJob(
{required String workflowName, JobType? jobType, List< IdMappingJobOutputSource> ? outputSourceConfig}) → Future<StartIdMappingJobOutput> -
Starts the
IdMappingJobof a workflow. The workflow must have previously been created using theCreateIdMappingWorkflowendpoint. -
startMatchingJob(
{required String workflowName}) → Future< StartMatchingJobOutput> -
Starts the
MatchingJobof a workflow. The workflow must have previously been created using theCreateMatchingWorkflowendpoint. -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> -
Assigns one or more tags (key-value pairs) to the specified Entity
Resolution resource. Tags can help you organize and categorize your
resources. You can also use them to scope user permissions by granting a
user permission to access or change only resources with certain tag
values. In Entity Resolution,
SchemaMappingandMatchingWorkflowcan be tagged. Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters. You can use theTagResourceaction with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> -
Removes one or more tags from the specified Entity Resolution resource. In
Entity Resolution,
SchemaMapping, andMatchingWorkflowcan be tagged. -
updateIdMappingWorkflow(
{required IdMappingTechniques idMappingTechniques, required List< IdMappingWorkflowInputSource> inputSourceConfig, required String workflowName, String? description, IdMappingIncrementalRunConfig? incrementalRunConfig, List<IdMappingWorkflowOutputSource> ? outputSourceConfig, String? roleArn}) → Future<UpdateIdMappingWorkflowOutput> -
Updates an existing
IdMappingWorkflow. This method is identical to CreateIdMappingWorkflow, except it uses an HTTPPUTrequest instead of aPOSTrequest, and theIdMappingWorkflowmust already exist for the method to succeed. -
updateIdNamespace(
{required String idNamespaceName, String? description, List< IdNamespaceIdMappingWorkflowProperties> ? idMappingWorkflowProperties, List<IdNamespaceInputSource> ? inputSourceConfig, String? roleArn}) → Future<UpdateIdNamespaceOutput> - Updates an existing ID namespace.
-
updateMatchingWorkflow(
{required List< InputSource> inputSourceConfig, required List<OutputSource> outputSourceConfig, required ResolutionTechniques resolutionTechniques, required String roleArn, required String workflowName, String? description, IncrementalRunConfig? incrementalRunConfig}) → Future<UpdateMatchingWorkflowOutput> - Updates an existing matching workflow. The workflow must already exist for this operation to succeed.
-
updateSchemaMapping(
{required List< SchemaInputAttribute> mappedInputFields, required String schemaName, String? description}) → Future<UpdateSchemaMappingOutput> - Updates a schema mapping.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited