deletePolicyStatement method
Deletes the policy statement.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The ARN of the resource for which the policy need to be deleted.
Parameter statementId :
A statement identifier that differentiates the statement from others in
the same policy.
Implementation
Future<DeletePolicyStatementOutput> deletePolicyStatement({
required String arn,
required String statementId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/policies/${Uri.encodeComponent(arn)}/${Uri.encodeComponent(statementId)}',
exceptionFnMap: _exceptionFns,
);
return DeletePolicyStatementOutput.fromJson(response);
}