getMatchId method

Future<GetMatchIdOutput> getMatchId({
  1. required Map<String, String> record,
  2. required String workflowName,
  3. bool? applyNormalization,
})

Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.

You can call this API as a dry run of an incremental load on the rule-based matching workflow.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter record : The record to fetch the Match ID for.

Parameter workflowName : The name of the workflow.

Parameter applyNormalization : Normalizes the attributes defined in the schema in the input data. For example, if an attribute has an AttributeType of PHONE_NUMBER, and the data in the input table is in a format of 1234567890, Entity Resolution will normalize this field in the output to (123)-456-7890.

Implementation

Future<GetMatchIdOutput> getMatchId({
  required Map<String, String> record,
  required String workflowName,
  bool? applyNormalization,
}) async {
  final $payload = <String, dynamic>{
    'record': record,
    if (applyNormalization != null) 'applyNormalization': applyNormalization,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri:
        '/matchingworkflows/${Uri.encodeComponent(workflowName)}/matches',
    exceptionFnMap: _exceptionFns,
  );
  return GetMatchIdOutput.fromJson(response);
}