listPartnerEventSourceAccounts method

Future<ListPartnerEventSourceAccountsResponse> listPartnerEventSourceAccounts({
  1. required String eventSourceName,
  2. int? limit,
  3. String? nextToken,
})

An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with. This operation is not used by Amazon Web Services customers.

May throw InternalException. May throw OperationDisabledException. May throw ResourceNotFoundException.

Parameter eventSourceName : The name of the partner event source to display account information about.

Parameter limit : Specifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results.

Parameter nextToken : The token returned by a previous call, which you can use to retrieve the next set of results.

The value of nextToken is a unique pagination token for each page. To retrieve the next page of results, make the call again using the returned token. Keep all other arguments unchanged.

Using an expired pagination token results in an HTTP 400 InvalidToken error.

Implementation

Future<ListPartnerEventSourceAccountsResponse>
    listPartnerEventSourceAccounts({
  required String eventSourceName,
  int? limit,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'limit',
    limit,
    1,
    100,
  );
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.1',
    'X-Amz-Target': 'AWSEvents.ListPartnerEventSourceAccounts'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'EventSourceName': eventSourceName,
      if (limit != null) 'Limit': limit,
      if (nextToken != null) 'NextToken': nextToken,
    },
  );

  return ListPartnerEventSourceAccountsResponse.fromJson(jsonResponse.body);
}