deleteEnvironmentConnector method
Deletes a connector from an Amazon EVS environment.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter connectorId :
A unique ID for the connector to be deleted.
Parameter environmentId :
A unique ID for the environment that the connector belongs to.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the connector deletion request. If you do not specify a
client token, a randomly generated token is used for the request to ensure
idempotency.
Implementation
Future<DeleteEnvironmentConnectorResponse> deleteEnvironmentConnector({
required String connectorId,
required String environmentId,
String? clientToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonElasticVMwareService.DeleteEnvironmentConnector'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'connectorId': connectorId,
'environmentId': environmentId,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
},
);
return DeleteEnvironmentConnectorResponse.fromJson(jsonResponse.body);
}