tagResource method
Associates the specified tags to an Amazon EVS resource with the specified
resourceArn. If existing tags on a resource are not specified
in the request parameters, they aren't changed. When a resource is
deleted, the tags associated with that resource are also deleted. Tags
that you create for Amazon EVS resources don't propagate to any other
resources associated with the environment. For example, if you tag an
environment with this operation, that tag doesn't automatically propagate
to the VLAN subnets and hosts associated with the environment.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw TagPolicyException.
May throw TooManyTagsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to add tags to.
Parameter tags :
Metadata that assists with categorization and organization. Each tag
consists of a key and an optional value. You define both. Tags don't
propagate to any other environment or Amazon Web Services resources.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonElasticVMwareService.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'resourceArn': resourceArn,
'tags': tags,
},
);
}