createFileSystem method
- required FileSystemType fileSystemType,
- required List<
String> subnetIds, - String? clientRequestToken,
- String? fileSystemTypeVersion,
- String? kmsKeyId,
- CreateFileSystemLustreConfiguration? lustreConfiguration,
- NetworkType? networkType,
- CreateFileSystemOntapConfiguration? ontapConfiguration,
- CreateFileSystemOpenZFSConfiguration? openZFSConfiguration,
- List<
String> ? securityGroupIds, - int? storageCapacity,
- StorageType? storageType,
- List<
Tag> ? tags, - CreateFileSystemWindowsConfiguration? windowsConfiguration,
Creates a new, empty Amazon FSx file system. You can create the following
supported Amazon FSx file systems using the CreateFileSystem
API operation:
- Amazon FSx for Lustre
- Amazon FSx for NetApp ONTAP
- Amazon FSx for OpenZFS
- Amazon FSx for Windows File Server
CreateFileSystem operation without the risk of creating an
extra file system. This approach can be useful when an initial call fails
in a way that makes it unclear whether a file system was created. Examples
are if a transport level timeout occurred, or your connection was reset.
If you use the same client request token and the initial call created a
file system, the client receives success as long as the parameters are the
same.
If a file system with the specified client request token exists and the
parameters match, CreateFileSystem returns the description of
the existing file system. If a file system with the specified client
request token exists and the parameters don't match, this call returns
IncompatibleParameterError. If a file system with the
specified client request token doesn't exist,
CreateFileSystem does the following:
-
Creates a new, empty Amazon FSx file system with an assigned ID, and an
initial lifecycle state of
CREATING. - Returns the description of the file system in JSON format.
May throw ActiveDirectoryError.
May throw BadRequest.
May throw IncompatibleParameterError.
May throw InternalServerError.
May throw InvalidExportPath.
May throw InvalidImportPath.
May throw InvalidNetworkSettings.
May throw InvalidPerUnitStorageThroughput.
May throw MissingFileSystemConfiguration.
May throw ServiceLimitExceeded.
Parameter fileSystemType :
The type of Amazon FSx file system to create. Valid values are
WINDOWS, LUSTRE, ONTAP, and
OPENZFS.
Parameter subnetIds :
Specifies the IDs of the subnets that the file system will be accessible
from. For Windows and ONTAP MULTI_AZ_1 deployment
types,provide exactly two subnet IDs, one for the preferred file server
and one for the standby file server. You specify one of these subnets as
the preferred subnet using the WindowsConfiguration >
PreferredSubnetID or OntapConfiguration >
PreferredSubnetID properties. For more information about Multi-AZ
file system configuration, see
Availability and durability: Single-AZ and Multi-AZ file systems in
the Amazon FSx for Windows User Guide and
Availability and durability in the Amazon FSx for ONTAP User
Guide.
For Windows SINGLE_AZ_1 and SINGLE_AZ_2 and all
Lustre deployment types, provide exactly one subnet ID. The file server is
launched in that subnet's Availability Zone.
Parameter clientRequestToken :
A string of up to 63 ASCII characters that Amazon FSx uses to ensure
idempotent creation. This string is automatically filled on your behalf
when you use the Command Line Interface (CLI) or an Amazon Web Services
SDK.
Parameter fileSystemTypeVersion :
For FSx for Lustre file systems, sets the Lustre version for the file
system that you're creating. Valid values are 2.10,
2.12, and 2.15:
-
2.10is supported by the Scratch and Persistent_1 Lustre deployment types. -
2.12is supported by all Lustre deployment types, except forPERSISTENT_2with a metadata configuration mode. -
2.15is supported by all Lustre deployment types and is recommended for all new file systems.
2.10, except for the following deployments:
-
Default value is
2.12whenDeploymentTypeis set toPERSISTENT_2without a metadata configuration mode. -
Default value is
2.15whenDeploymentTypeis set toPERSISTENT_2with a metadata configuration mode.
Parameter networkType :
The network type of the Amazon FSx file system that you are creating.
Valid values are IPV4 (which supports IPv4 only) and
DUAL (for dual-stack mode, which supports both IPv4 and
IPv6). The default is IPV4. Supported for FSx for OpenZFS,
FSx for ONTAP, and FSx for Windows File Server file systems.
Parameter openZFSConfiguration :
The OpenZFS configuration for the file system that's being created.
Parameter securityGroupIds :
A list of IDs specifying the security groups to apply to all network
interfaces created for file system access. This list isn't returned in
later requests to describe the file system.
Parameter storageCapacity :
Sets the storage capacity of the file system that you're creating, in
gibibytes (GiB).
FSx for Lustre file systems - The amount of storage capacity that
you can configure depends on the value that you set for
StorageType and the Lustre DeploymentType, as
follows:
-
For
SCRATCH_2,PERSISTENT_2, andPERSISTENT_1deployment types using SSD storage type, the valid values are 1200 GiB, 2400 GiB, and increments of 2400 GiB. -
For
PERSISTENT_1HDD file systems, valid values are increments of 6000 GiB for 12 MB/s/TiB file systems and increments of 1800 GiB for 40 MB/s/TiB file systems. -
For
SCRATCH_1deployment type, valid values are 1200 GiB, 2400 GiB, and increments of 3600 GiB.
HAPairs
property. The minimum value is calculated as 1,024 * HAPairs
and the maximum is calculated as 524,288 * HAPairs.
FSx for OpenZFS file systems - The amount of storage capacity that you can configure is from 64 GiB up to 524,288 GiB (512 TiB).
FSx for Windows File Server file systems - The amount of storage
capacity that you can configure depends on the value that you set for
StorageType as follows:
- For SSD storage, valid values are 32 GiB-65,536 GiB (64 TiB).
- For HDD storage, valid values are 2000 GiB-65,536 GiB (64 TiB).
Parameter storageType :
Sets the storage class for the file system that you're creating. Valid
values are SSD, HDD, and
INTELLIGENT_TIERING.
-
Set to
SSDto use solid state drive storage. SSD is supported on all Windows, Lustre, ONTAP, and OpenZFS deployment types. -
Set to
HDDto use hard disk drive storage, which is supported onSINGLE_AZ_2andMULTI_AZ_1Windows file system deployment types, and onPERSISTENT_1Lustre file system deployment types. -
Set to
INTELLIGENT_TIERINGto use fully elastic, intelligently-tiered storage. Intelligent-Tiering is only available for OpenZFS file systems with the Multi-AZ deployment type and for Lustre file systems with the Persistent_2 deployment type.
SSD. For more information, see
Storage type options in the FSx for Windows File Server User
Guide, FSx
for Lustre storage classes in the FSx for Lustre User Guide,
and Working
with Intelligent-Tiering in the Amazon FSx for OpenZFS User
Guide.
Parameter tags :
The tags to apply to the file system that's being created. The key value
of the Name tag appears in the console as the file system
name.
Parameter windowsConfiguration :
The Microsoft Windows configuration for the file system that's being
created.
Implementation
Future<CreateFileSystemResponse> createFileSystem({
required FileSystemType fileSystemType,
required List<String> subnetIds,
String? clientRequestToken,
String? fileSystemTypeVersion,
String? kmsKeyId,
CreateFileSystemLustreConfiguration? lustreConfiguration,
NetworkType? networkType,
CreateFileSystemOntapConfiguration? ontapConfiguration,
CreateFileSystemOpenZFSConfiguration? openZFSConfiguration,
List<String>? securityGroupIds,
int? storageCapacity,
StorageType? storageType,
List<Tag>? tags,
CreateFileSystemWindowsConfiguration? windowsConfiguration,
}) async {
_s.validateNumRange(
'storageCapacity',
storageCapacity,
0,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSimbaAPIService_v20180301.CreateFileSystem'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileSystemType': fileSystemType.value,
'SubnetIds': subnetIds,
'ClientRequestToken':
clientRequestToken ?? _s.generateIdempotencyToken(),
if (fileSystemTypeVersion != null)
'FileSystemTypeVersion': fileSystemTypeVersion,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (lustreConfiguration != null)
'LustreConfiguration': lustreConfiguration,
if (networkType != null) 'NetworkType': networkType.value,
if (ontapConfiguration != null)
'OntapConfiguration': ontapConfiguration,
if (openZFSConfiguration != null)
'OpenZFSConfiguration': openZFSConfiguration,
if (securityGroupIds != null) 'SecurityGroupIds': securityGroupIds,
if (storageCapacity != null) 'StorageCapacity': storageCapacity,
if (storageType != null) 'StorageType': storageType.value,
if (tags != null) 'Tags': tags,
if (windowsConfiguration != null)
'WindowsConfiguration': windowsConfiguration,
},
);
return CreateFileSystemResponse.fromJson(jsonResponse.body);
}