describeS3AccessPointAttachments method
Describes one or more S3 access points attached to Amazon FSx volumes.
The requester requires the following permission to perform this action:
-
fsx:DescribeS3AccessPointAttachments
May throw BadRequest.
May throw InternalServerError.
May throw S3AccessPointAttachmentNotFound.
May throw UnsupportedOperation.
Parameter filters :
Enter a filter Name and Values pair to view a select set of S3 access
point attachments.
Parameter names :
The names of the S3 access point attachments whose descriptions you want
to retrieve.
Implementation
Future<DescribeS3AccessPointAttachmentsResponse>
describeS3AccessPointAttachments({
List<S3AccessPointAttachmentsFilter>? filters,
int? maxResults,
List<String>? names,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
2147483647,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSSimbaAPIService_v20180301.DescribeS3AccessPointAttachments'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (names != null) 'Names': names,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeS3AccessPointAttachmentsResponse.fromJson(jsonResponse.body);
}