deleteKxClusterNode method
Deletes the specified nodes from a cluster.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterName :
The name of the cluster, for which you want to delete the nodes.
Parameter environmentId :
A unique identifier for the kdb environment.
Parameter nodeId :
A unique identifier for the node that you want to delete.
Implementation
Future<void> deleteKxClusterNode({
required String clusterName,
required String environmentId,
required String nodeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/kx/environments/${Uri.encodeComponent(environmentId)}/clusters/${Uri.encodeComponent(clusterName)}/nodes/${Uri.encodeComponent(nodeId)}',
exceptionFnMap: _exceptionFns,
);
}