untagResource method
Removes metadata tags from a FinSpace resource.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter resourceArn :
A FinSpace resource from which you want to remove a tag or tags. The value
for this parameter is an Amazon Resource Name (ARN).
Parameter tagKeys :
The tag keys (names) of one or more tags to be removed.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}