listDataViews method
Lists all available Dataviews for a Dataset.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter datasetId :
The unique identifier of the Dataset for which to retrieve Dataviews.
Parameter maxResults :
The maximum number of results per page.
Parameter nextToken :
A token that indicates where a results page should begin.
Implementation
Future<ListDataViewsResponse> listDataViews({
required String datasetId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/datasets/${Uri.encodeComponent(datasetId)}/dataviewsv2',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataViewsResponse.fromJson(response);
}