Fis class
Amazon Web Services Fault Injection Service is a managed service that enables you to perform fault injection experiments on your Amazon Web Services workloads. For more information, see the Fault Injection Service User Guide.
Constructors
- Fis({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createExperimentTemplate(
{required Map< String, CreateExperimentTemplateActionInput> actions, required String description, required String roleArn, required List<CreateExperimentTemplateStopConditionInput> stopConditions, String? clientToken, CreateExperimentTemplateExperimentOptionsInput? experimentOptions, CreateExperimentTemplateReportConfigurationInput? experimentReportConfiguration, CreateExperimentTemplateLogConfigurationInput? logConfiguration, Map<String, String> ? tags, Map<String, CreateExperimentTemplateTargetInput> ? targets}) → Future<CreateExperimentTemplateResponse> - Creates an experiment template.
-
createTargetAccountConfiguration(
{required String accountId, required String experimentTemplateId, required String roleArn, String? clientToken, String? description}) → Future< CreateTargetAccountConfigurationResponse> -
Creates a target account configuration for the experiment template. A
target account configuration is required when
accountTargetingofexperimentOptionsis set tomulti-account. For more information, see experiment options in the Fault Injection Service User Guide. -
deleteExperimentTemplate(
{required String id}) → Future< DeleteExperimentTemplateResponse> - Deletes the specified experiment template.
-
deleteTargetAccountConfiguration(
{required String accountId, required String experimentTemplateId}) → Future< DeleteTargetAccountConfigurationResponse> - Deletes the specified target account configuration of the experiment template.
-
getAction(
{required String id}) → Future< GetActionResponse> - Gets information about the specified FIS action.
-
getExperiment(
{required String id}) → Future< GetExperimentResponse> - Gets information about the specified experiment.
-
getExperimentTargetAccountConfiguration(
{required String accountId, required String experimentId}) → Future< GetExperimentTargetAccountConfigurationResponse> - Gets information about the specified target account configuration of the experiment.
-
getExperimentTemplate(
{required String id}) → Future< GetExperimentTemplateResponse> - Gets information about the specified experiment template.
-
getSafetyLever(
{required String id}) → Future< GetSafetyLeverResponse> - Gets information about the specified safety lever.
-
getTargetAccountConfiguration(
{required String accountId, required String experimentTemplateId}) → Future< GetTargetAccountConfigurationResponse> - Gets information about the specified target account configuration of the experiment template.
-
getTargetResourceType(
{required String resourceType}) → Future< GetTargetResourceTypeResponse> - Gets information about the specified resource type.
-
listActions(
{int? maxResults, String? nextToken}) → Future< ListActionsResponse> - Lists the available FIS actions.
-
listExperimentResolvedTargets(
{required String experimentId, int? maxResults, String? nextToken, String? targetName}) → Future< ListExperimentResolvedTargetsResponse> - Lists the resolved targets information of the specified experiment.
-
listExperiments(
{String? experimentTemplateId, int? maxResults, String? nextToken}) → Future< ListExperimentsResponse> - Lists your experiments.
-
listExperimentTargetAccountConfigurations(
{required String experimentId, String? nextToken}) → Future< ListExperimentTargetAccountConfigurationsResponse> - Lists the target account configurations of the specified experiment.
-
listExperimentTemplates(
{int? maxResults, String? nextToken}) → Future< ListExperimentTemplatesResponse> - Lists your experiment templates.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags for the specified resource.
-
listTargetAccountConfigurations(
{required String experimentTemplateId, int? maxResults, String? nextToken}) → Future< ListTargetAccountConfigurationsResponse> - Lists the target account configurations of the specified experiment template.
-
listTargetResourceTypes(
{int? maxResults, String? nextToken}) → Future< ListTargetResourceTypesResponse> - Lists the target resource types.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startExperiment(
{required String experimentTemplateId, String? clientToken, StartExperimentExperimentOptionsInput? experimentOptions, Map< String, String> ? tags}) → Future<StartExperimentResponse> - Starts running an experiment from the specified experiment template.
-
stopExperiment(
{required String id}) → Future< StopExperimentResponse> - Stops the specified experiment.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Applies the specified tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, List< String> ? tagKeys}) → Future<void> - Removes the specified tags from the specified resource.
-
updateExperimentTemplate(
{required String id, Map< String, UpdateExperimentTemplateActionInputItem> ? actions, String? description, UpdateExperimentTemplateExperimentOptionsInput? experimentOptions, UpdateExperimentTemplateReportConfigurationInput? experimentReportConfiguration, UpdateExperimentTemplateLogConfigurationInput? logConfiguration, String? roleArn, List<UpdateExperimentTemplateStopConditionInput> ? stopConditions, Map<String, UpdateExperimentTemplateTargetInput> ? targets}) → Future<UpdateExperimentTemplateResponse> - Updates the specified experiment template.
-
updateSafetyLeverState(
{required String id, required UpdateSafetyLeverStateInput state}) → Future< UpdateSafetyLeverStateResponse> - Updates the specified safety lever state.
-
updateTargetAccountConfiguration(
{required String accountId, required String experimentTemplateId, String? description, String? roleArn}) → Future< UpdateTargetAccountConfigurationResponse> - Updates the target account configuration for the specified experiment template.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited