getComplianceDetail method
Returns detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy.
The reasons for resources being considered compliant depend on the Firewall Manager policy type.
May throw InternalErrorException.
May throw InvalidInputException.
May throw InvalidOperationException.
May throw ResourceNotFoundException.
Parameter memberAccount :
The Amazon Web Services account that owns the resources that you want to
get the details for.
Parameter policyId :
The ID of the policy that you want to get the details for.
PolicyId is returned by PutPolicy and by
ListPolicies.
Implementation
Future<GetComplianceDetailResponse> getComplianceDetail({
required String memberAccount,
required String policyId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.GetComplianceDetail'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MemberAccount': memberAccount,
'PolicyId': policyId,
},
);
return GetComplianceDetailResponse.fromJson(jsonResponse.body);
}