listAdminAccountsForOrganization method
Returns a AdminAccounts object that lists the Firewall
Manager administrators within the organization that are onboarded to
Firewall Manager by AssociateAdminAccount.
This operation can be called only from the organization's management account.
May throw InternalErrorException.
May throw InvalidOperationException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter maxResults :
The maximum number of objects that you want Firewall Manager to return for
this request. If more objects are available, in the response, Firewall
Manager provides a NextToken value that you can use in a
subsequent call to get the next batch of objects.
Parameter nextToken :
When you request a list of objects with a MaxResults setting,
if the number of objects that are still available for retrieval exceeds
the maximum you requested, Firewall Manager returns a
NextToken value in the response. To retrieve the next batch
of objects, use the token returned from the prior request in your next
request.
Implementation
Future<ListAdminAccountsForOrganizationResponse>
listAdminAccountsForOrganization({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.ListAdminAccountsForOrganization'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListAdminAccountsForOrganizationResponse.fromJson(jsonResponse.body);
}