untagResource method
Removes one or more tags from an Amazon Web Services resource.
May throw InternalErrorException.
May throw InvalidInputException.
May throw InvalidOperationException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource to return tags for. The
Firewall Manager resources that support tagging are policies, applications
lists, and protocols lists.
Parameter tagKeys :
The keys of the tags to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSFMS_20180101.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
);
}