deleteDataset method
Deletes an Amazon Forecast dataset that was created using the CreateDataset
operation. You can only delete datasets that have a status of
ACTIVE or CREATE_FAILED. To get the status use
the DescribeDataset
operation.
May throw InvalidInputException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter datasetArn :
The Amazon Resource Name (ARN) of the dataset to delete.
Implementation
Future<void> deleteDataset({
required String datasetArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.DeleteDataset'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DatasetArn': datasetArn,
},
);
}