listWhatIfForecasts method
Returns a list of what-if forecasts created using the CreateWhatIfForecast operation. For each what-if forecast, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the what-if forecast ARN with the DescribeWhatIfForecast operation.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter filters :
An array of filters. For each filter, you provide a condition and a match
statement. The condition is either IS or IS_NOT,
which specifies whether to include or exclude the what-if forecast export
jobs that match the statement from the list, respectively. The match
statement consists of a key and a value.
Filter properties
-
Condition- The condition to apply. Valid values areISandIS_NOT. To include the forecast export jobs that match the statement, specifyIS. To exclude matching forecast export jobs, specifyIS_NOT. -
Key- The name of the parameter to filter on. Valid values areWhatIfForecastArnandStatus. -
Value- The value to match.
"Filters": [ { "Condition": "IS", "Key": "WhatIfForecastArn",
"Value":
"arn:aws:forecast:us-west-2:
Parameter maxResults :
The number of items to return in the response.
Parameter nextToken :
If the result of the previous request was truncated, the response includes
a NextToken. To retrieve the next set of results, use the
token in the next request. Tokens expire after 24 hours.
Implementation
Future<ListWhatIfForecastsResponse> listWhatIfForecasts({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonForecast.ListWhatIfForecasts'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListWhatIfForecastsResponse.fromJson(jsonResponse.body);
}