FraudDetector class
This is the Amazon Fraud Detector API Reference. This guide is for developers who need detailed information about Amazon Fraud Detector API actions, data types, and errors. For more information about Amazon Fraud Detector features, see the Amazon Fraud Detector User Guide.
We provide the Query API as well as AWS software development kits (SDK) for Amazon Fraud Detector in Java and Python programming languages.
The Amazon Fraud Detector Query API provides HTTPS requests that use the
HTTP verb GET or POST and a Query parameter Action. AWS SDK
provides libraries, sample code, tutorials, and other resources for software
developers who prefer to build applications using language-specific APIs
instead of submitting a request over HTTP or HTTPS. These libraries provide
basic functions that automatically take care of tasks such as
cryptographically signing your requests, retrying requests, and handling
error responses, so that it is easier for you to get started. For more
information about the AWS SDKs, go to Tools to build on AWS
page, scroll down to the SDK section, and choose plus (+) sign to
expand the section.
Constructors
- FraudDetector({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchCreateVariable(
{required List< VariableEntry> variableEntries, List<Tag> ? tags}) → Future<BatchCreateVariableResult> - Creates a batch of variables.
-
batchGetVariable(
{required List< String> names}) → Future<BatchGetVariableResult> - Gets a batch of variables.
-
cancelBatchImportJob(
{required String jobId}) → Future< void> - Cancels an in-progress batch import job.
-
cancelBatchPredictionJob(
{required String jobId}) → Future< void> - Cancels the specified batch prediction job.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createBatchImportJob(
{required String eventTypeName, required String iamRoleArn, required String inputPath, required String jobId, required String outputPath, List< Tag> ? tags}) → Future<void> - Creates a batch import job.
-
createBatchPredictionJob(
{required String detectorName, required String eventTypeName, required String iamRoleArn, required String inputPath, required String jobId, required String outputPath, String? detectorVersion, List< Tag> ? tags}) → Future<void> - Creates a batch prediction job.
-
createDetectorVersion(
{required String detectorId, required List< Rule> rules, String? description, List<String> ? externalModelEndpoints, List<ModelVersion> ? modelVersions, RuleExecutionMode? ruleExecutionMode, List<Tag> ? tags}) → Future<CreateDetectorVersionResult> -
Creates a detector version. The detector version starts in a
DRAFTstatus. -
createList(
{required String name, String? description, List< String> ? elements, List<Tag> ? tags, String? variableType}) → Future<void> - Creates a list.
-
createModel(
{required String eventTypeName, required String modelId, required ModelTypeEnum modelType, String? description, List< Tag> ? tags}) → Future<void> - Creates a model using the specified model type.
-
createModelVersion(
{required String modelId, required ModelTypeEnum modelType, required TrainingDataSchema trainingDataSchema, required TrainingDataSourceEnum trainingDataSource, ExternalEventsDetail? externalEventsDetail, IngestedEventsDetail? ingestedEventsDetail, List< Tag> ? tags}) → Future<CreateModelVersionResult> - Creates a version of the model using the specified model type and model id.
-
createRule(
{required String detectorId, required String expression, required Language language, required List< String> outcomes, required String ruleId, String? description, List<Tag> ? tags}) → Future<CreateRuleResult> - Creates a rule for use with the specified detector.
-
createVariable(
{required DataSource dataSource, required DataType dataType, required String defaultValue, required String name, String? description, List< Tag> ? tags, String? variableType}) → Future<void> - Creates a variable.
-
deleteBatchImportJob(
{required String jobId}) → Future< void> - Deletes the specified batch import job ID record. This action does not delete the data that was batch imported.
-
deleteBatchPredictionJob(
{required String jobId}) → Future< void> - Deletes a batch prediction job.
-
deleteDetector(
{required String detectorId}) → Future< void> - Deletes the detector. Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector.
-
deleteDetectorVersion(
{required String detectorId, required String detectorVersionId}) → Future< void> -
Deletes the detector version. You cannot delete detector versions that are
in
ACTIVEstatus. -
deleteEntityType(
{required String name}) → Future< void> - Deletes an entity type.
-
deleteEvent(
{required String eventId, required String eventTypeName, bool? deleteAuditHistory}) → Future< void> - Deletes the specified event.
-
deleteEventsByEventType(
{required String eventTypeName}) → Future< DeleteEventsByEventTypeResult> - Deletes all events of a particular event type.
-
deleteEventType(
{required String name}) → Future< void> - Deletes an event type.
-
deleteExternalModel(
{required String modelEndpoint}) → Future< void> - Removes a SageMaker model from Amazon Fraud Detector.
-
deleteLabel(
{required String name}) → Future< void> - Deletes a label.
-
deleteList(
{required String name}) → Future< void> - Deletes the list, provided it is not used in a rule.
-
deleteModel(
{required String modelId, required ModelTypeEnum modelType}) → Future< void> - Deletes a model.
-
deleteModelVersion(
{required String modelId, required ModelTypeEnum modelType, required String modelVersionNumber}) → Future< void> - Deletes a model version.
-
deleteOutcome(
{required String name}) → Future< void> - Deletes an outcome.
-
deleteRule(
{required Rule rule}) → Future< void> -
Deletes the rule. You cannot delete a rule if it is used by an
ACTIVEorINACTIVEdetector version. -
deleteVariable(
{required String name}) → Future< void> - Deletes a variable.
-
describeDetector(
{required String detectorId, int? maxResults, String? nextToken}) → Future< DescribeDetectorResult> - Gets all versions for a specified detector.
-
describeModelVersions(
{int? maxResults, String? modelId, ModelTypeEnum? modelType, String? modelVersionNumber, String? nextToken}) → Future< DescribeModelVersionsResult> - Gets all of the model versions for the specified model type or for the specified model type and model ID. You can also get details for a single, specified model version.
-
getBatchImportJobs(
{String? jobId, int? maxResults, String? nextToken}) → Future< GetBatchImportJobsResult> -
Gets all batch import jobs or a specific job of the specified ID. This is
a paginated API. If you provide a null
maxResults, this action retrieves a maximum of 50 records per page. If you provide amaxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from theGetBatchImportJobsResponseas part of your request. A null pagination token fetches the records from the beginning. -
getBatchPredictionJobs(
{String? jobId, int? maxResults, String? nextToken}) → Future< GetBatchPredictionJobsResult> - Gets all batch prediction jobs or a specific job if you specify a job ID. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from the GetBatchPredictionJobsResponse as part of your request. A null pagination token fetches the records from the beginning.
-
getDeleteEventsByEventTypeStatus(
{required String eventTypeName}) → Future< GetDeleteEventsByEventTypeStatusResult> -
Retrieves the status of a
DeleteEventsByEventTypeaction. -
getDetectors(
{String? detectorId, int? maxResults, String? nextToken}) → Future< GetDetectorsResult> -
Gets all detectors or a single detector if a
detectorIdis specified. This is a paginated API. If you provide a nullmaxResults, this action retrieves a maximum of 10 records per page. If you provide amaxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from theGetDetectorsResponseas part of your request. A null pagination token fetches the records from the beginning. -
getDetectorVersion(
{required String detectorId, required String detectorVersionId}) → Future< GetDetectorVersionResult> - Gets a particular detector version.
-
getEntityTypes(
{int? maxResults, String? name, String? nextToken}) → Future< GetEntityTypesResult> -
Gets all entity types or a specific entity type if a name is specified.
This is a paginated API. If you provide a null
maxResults, this action retrieves a maximum of 10 records per page. If you provide amaxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from theGetEntityTypesResponseas part of your request. A null pagination token fetches the records from the beginning. -
getEvent(
{required String eventId, required String eventTypeName}) → Future< GetEventResult> - Retrieves details of events stored with Amazon Fraud Detector. This action does not retrieve prediction results.
-
getEventPrediction(
{required String detectorId, required List< Entity> entities, required String eventId, required String eventTimestamp, required String eventTypeName, required Map<String, String> eventVariables, String? detectorVersionId, Map<String, ModelEndpointDataBlob> ? externalModelEndpointDataBlobs}) → Future<GetEventPredictionResult> -
Evaluates an event against a detector version. If a version ID is not
provided, the detector’s (
ACTIVE) version is used. -
getEventPredictionMetadata(
{required String detectorId, required String detectorVersionId, required String eventId, required String eventTypeName, required String predictionTimestamp}) → Future< GetEventPredictionMetadataResult> - Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period.
-
getEventTypes(
{int? maxResults, String? name, String? nextToken}) → Future< GetEventTypesResult> -
Gets all event types or a specific event type if name is provided. This is
a paginated API. If you provide a null
maxResults, this action retrieves a maximum of 10 records per page. If you provide amaxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from theGetEventTypesResponseas part of your request. A null pagination token fetches the records from the beginning. -
getExternalModels(
{int? maxResults, String? modelEndpoint, String? nextToken}) → Future< GetExternalModelsResult> -
Gets the details for one or more Amazon SageMaker models that have been
imported into the service. This is a paginated API. If you provide a null
maxResults, this actions retrieves a maximum of 10 records per page. If you provide amaxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from theGetExternalModelsResultas part of your request. A null pagination token fetches the records from the beginning. -
getKMSEncryptionKey(
) → Future< GetKMSEncryptionKeyResult> - Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector.
-
getLabels(
{int? maxResults, String? name, String? nextToken}) → Future< GetLabelsResult> -
Gets all labels or a specific label if name is provided. This is a
paginated API. If you provide a null
maxResults, this action retrieves a maximum of 50 records per page. If you provide amaxResults, the value must be between 10 and 50. To get the next page results, provide the pagination token from theGetGetLabelsResponseas part of your request. A null pagination token fetches the records from the beginning. -
getListElements(
{required String name, int? maxResults, String? nextToken}) → Future< GetListElementsResult> - Gets all the elements in the specified list.
-
getListsMetadata(
{int? maxResults, String? name, String? nextToken}) → Future< GetListsMetadataResult> - Gets the metadata of either all the lists under the account or the specified list.
-
getModels(
{int? maxResults, String? modelId, ModelTypeEnum? modelType, String? nextToken}) → Future< GetModelsResult> - Gets one or more models. Gets all models for the Amazon Web Services account if no model type and no model id provided. Gets all models for the Amazon Web Services account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified.
-
getModelVersion(
{required String modelId, required ModelTypeEnum modelType, required String modelVersionNumber}) → Future< GetModelVersionResult> - Gets the details of the specified model version.
-
getOutcomes(
{int? maxResults, String? name, String? nextToken}) → Future< GetOutcomesResult> -
Gets one or more outcomes. This is a paginated API. If you provide a null
maxResults, this actions retrieves a maximum of 100 records per page. If you provide amaxResults, the value must be between 50 and 100. To get the next page results, provide the pagination token from theGetOutcomesResultas part of your request. A null pagination token fetches the records from the beginning. -
getRules(
{required String detectorId, int? maxResults, String? nextToken, String? ruleId, String? ruleVersion}) → Future< GetRulesResult> -
Get all rules for a detector (paginated) if
ruleIdandruleVersionare not specified. Gets all rules for the detector and theruleIdif present (paginated). Gets a specific rule if both theruleIdand theruleVersionare specified. -
getVariables(
{int? maxResults, String? name, String? nextToken}) → Future< GetVariablesResult> -
Gets all of the variables or the specific variable. This is a paginated
API. Providing null
maxSizePerPageresults in retrieving maximum of 100 records per page. If you providemaxSizePerPagethe value must be between 50 and 100. To get the next page result, a provide a pagination token fromGetVariablesResultas part of your request. Null pagination token fetches the records from the beginning. -
listEventPredictions(
{FilterCondition? detectorId, FilterCondition? detectorVersionId, FilterCondition? eventId, FilterCondition? eventType, int? maxResults, String? nextToken, PredictionTimeRange? predictionTimeRange}) → Future< ListEventPredictionsResult> - Gets a list of past predictions. The list can be filtered by detector ID, detector version ID, event ID, event type, or by specifying a time period. If filter is not specified, the most recent prediction is returned.
-
listTagsForResource(
{required String resourceARN, int? maxResults, String? nextToken}) → Future< ListTagsForResourceResult> - Lists all tags associated with the resource. This is a paginated API. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putDetector(
{required String detectorId, required String eventTypeName, String? description, List< Tag> ? tags}) → Future<void> - Creates or updates a detector.
-
putEntityType(
{required String name, String? description, List< Tag> ? tags}) → Future<void> - Creates or updates an entity type. An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account.
-
putEventType(
{required List< String> entityTypes, required List<String> eventVariables, required String name, String? description, EventIngestion? eventIngestion, EventOrchestration? eventOrchestration, List<String> ? labels, List<Tag> ? tags}) → Future<void> - Creates or updates an event type. An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications.
-
putExternalModel(
{required ModelInputConfiguration inputConfiguration, required String invokeModelEndpointRoleArn, required String modelEndpoint, required ModelEndpointStatus modelEndpointStatus, required ModelSource modelSource, required ModelOutputConfiguration outputConfiguration, List< Tag> ? tags}) → Future<void> - Creates or updates an Amazon SageMaker model endpoint. You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables.
-
putKMSEncryptionKey(
{required String kmsEncryptionKeyArn}) → Future< void> - Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.
-
putLabel(
{required String name, String? description, List< Tag> ? tags}) → Future<void> - Creates or updates label. A label classifies an event as fraudulent or legitimate. Labels are associated with event types and used to train supervised machine learning models in Amazon Fraud Detector.
-
putOutcome(
{required String name, String? description, List< Tag> ? tags}) → Future<void> - Creates or updates an outcome.
-
sendEvent(
{required List< Entity> entities, required String eventId, required String eventTimestamp, required String eventTypeName, required Map<String, String> eventVariables, String? assignedLabel, String? labelTimestamp}) → Future<void> -
Stores events in Amazon Fraud Detector without generating fraud
predictions for those events. For example, you can use
SendEventto upload a historical dataset, which you can then later use to train a model. -
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> - Assigns tags to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes tags from a resource.
-
updateDetectorVersion(
{required String detectorId, required String detectorVersionId, required List< String> externalModelEndpoints, required List<Rule> rules, String? description, List<ModelVersion> ? modelVersions, RuleExecutionMode? ruleExecutionMode}) → Future<void> -
Updates a detector version. The detector version attributes that you can
update include models, external model endpoints, rules, rule execution
mode, and description. You can only update a
DRAFTdetector version. -
updateDetectorVersionMetadata(
{required String description, required String detectorId, required String detectorVersionId}) → Future< void> -
Updates the detector version's description. You can update the metadata
for any detector version (
DRAFT, ACTIVE,orINACTIVE). -
updateDetectorVersionStatus(
{required String detectorId, required String detectorVersionId, required DetectorVersionStatus status}) → Future< void> -
Updates the detector version’s status. You can perform the following
promotions or demotions using
UpdateDetectorVersionStatus:DRAFTtoACTIVE,ACTIVEtoINACTIVE, andINACTIVEtoACTIVE. -
updateEventLabel(
{required String assignedLabel, required String eventId, required String eventTypeName, required String labelTimestamp}) → Future< void> - Updates the specified event with a new label.
-
updateList(
{required String name, String? description, List< String> ? elements, ListUpdateMode? updateMode, String? variableType}) → Future<void> - Updates a list.
-
updateModel(
{required String modelId, required ModelTypeEnum modelType, String? description}) → Future< void> - Updates model description.
-
updateModelVersion(
{required String majorVersionNumber, required String modelId, required ModelTypeEnum modelType, ExternalEventsDetail? externalEventsDetail, IngestedEventsDetail? ingestedEventsDetail, List< Tag> ? tags}) → Future<UpdateModelVersionResult> - Updates a model version. Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03.
-
updateModelVersionStatus(
{required String modelId, required ModelTypeEnum modelType, required String modelVersionNumber, required ModelVersionStatus status}) → Future< void> - Updates the status of a model version.
-
updateRuleMetadata(
{required String description, required Rule rule}) → Future< void> - Updates a rule's metadata. The description attribute can be updated.
-
updateRuleVersion(
{required String expression, required Language language, required List< String> outcomes, required Rule rule, String? description, List<Tag> ? tags}) → Future<UpdateRuleVersionResult> - Updates a rule version resulting in a new rule version. Updates a rule version resulting in a new rule version (version 1, 2, 3 ...).
-
updateVariable(
{required String name, String? defaultValue, String? description, String? variableType}) → Future< void> - Updates a variable.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited