deleteList method
Deletes the list, provided it is not used in a rule.
When you delete a list, Amazon Fraud Detector permanently deletes that list and the elements in the list.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the list to delete.
Implementation
Future<void> deleteList({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSHawksNestServiceFacade.DeleteList'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'name': name,
},
);
}