getAccountActivity method
Future<GetAccountActivityResponse>
getAccountActivity({
- required String activityId,
- LanguageCode? languageCode,
Returns a specific activity record that is available to the customer.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter activityId :
A unique identifier that identifies the activity.
Parameter languageCode :
The language code used to return translated title and description fields.
Implementation
Future<GetAccountActivityResponse> getAccountActivity({
required String activityId,
LanguageCode? languageCode,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSFreeTierService.GetAccountActivity'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'activityId': activityId,
if (languageCode != null) 'languageCode': languageCode.value,
},
);
return GetAccountActivityResponse.fromJson(jsonResponse.body);
}