getAccountPlanState method
This returns all of the information related to the state of the account plan related to Free Tier.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Implementation
Future<GetAccountPlanStateResponse> getAccountPlanState() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSFreeTierService.GetAccountPlanState'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetAccountPlanStateResponse.fromJson(jsonResponse.body);
}