claimGameServer method
This API works with the following fleet types: EC2 (FleetIQ)
Locates an available game server and temporarily reserves it to host
gameplay and players. This operation is called from a game client or
client service (such as a matchmaker) to request hosting resources for a
new game session. In response, Amazon GameLift Servers FleetIQ locates an
available game server, places it in CLAIMED status for 60
seconds, and returns connection information that players can use to
connect to the game server.
To claim a game server, identify a game server group. You can also specify
a game server ID, although this approach bypasses Amazon GameLift Servers
FleetIQ placement optimization. Optionally, include game data to pass to
the game server at the start of a game session, such as a game map or
player information. Add filter options to further restrict how a game
server is chosen, such as only allowing game servers on
ACTIVE instances to be claimed.
When a game server is successfully claimed, connection information is
returned. A claimed game server's utilization status remains
AVAILABLE while the claim status is set to
CLAIMED for up to 60 seconds. This time period gives the game
server time to update its status to UTILIZED after players
join. If the game server's status is not updated within 60 seconds, the
game server reverts to unclaimed status and is available to be claimed by
another request. The claim time period is a fixed value and is not
configurable.
If you try to claim a specific game server, this request will fail in the following cases:
-
If the game server utilization status is
UTILIZED. -
If the game server claim status is
CLAIMED. -
If the game server is running on an instance in
DRAININGstatus and the provided filter option does not allow placing onDRAININGinstances.
Amazon GameLift Servers FleetIQ Guide
May throw ConflictException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw OutOfCapacityException.
May throw UnauthorizedException.
Parameter gameServerGroupName :
A unique identifier for the game server group where the game server is
running. If you are not specifying a game server to claim, this value
identifies where you want Amazon GameLift Servers FleetIQ to look for an
available game server to claim.
Parameter filterOption :
Object that restricts how a claimed game server is chosen.
Parameter gameServerData :
A set of custom game server properties, formatted as a single string
value. This data is passed to a game client or service when it requests
information on game servers.
Parameter gameServerId :
A custom string that uniquely identifies the game server to claim. If this
parameter is left empty, Amazon GameLift Servers FleetIQ searches for an
available game server in the specified game server group.
Implementation
Future<ClaimGameServerOutput> claimGameServer({
required String gameServerGroupName,
ClaimFilterOption? filterOption,
String? gameServerData,
String? gameServerId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.ClaimGameServer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GameServerGroupName': gameServerGroupName,
if (filterOption != null) 'FilterOption': filterOption,
if (gameServerData != null) 'GameServerData': gameServerData,
if (gameServerId != null) 'GameServerId': gameServerId,
},
);
return ClaimGameServerOutput.fromJson(jsonResponse.body);
}