createScript method
This API works with the following fleet types: EC2, Anywhere
Creates a new script record for your Amazon GameLift Servers Realtime script. Realtime scripts are JavaScript that provide configuration settings and optional custom game logic for your game. The script is deployed when you create a Amazon GameLift Servers Realtime fleet to host your game sessions. Script logic is executed during an active game session.
To create a new script record, specify a script name and provide the script file(s). The script files and all dependencies must be zipped into a single file. You can pull the zip file from either of these locations:
- A locally available directory. Use the ZipFile parameter for this option.
- An Amazon Simple Storage Service (Amazon S3) bucket under your Amazon Web Services account. Use the StorageLocation parameter for this option. You'll need to have an Identity Access Management (IAM) role that allows the Amazon GameLift Servers service to access your S3 bucket.
Learn more
Amazon GameLift Servers Amazon GameLift Servers Realtime
Set Up a Role for Amazon GameLift Servers Access
Related actions
May throw ConflictException.
May throw InternalServiceException.
May throw InvalidRequestException.
May throw TaggingFailedException.
May throw UnauthorizedException.
Parameter name :
A descriptive label that is associated with a script. Script names do not
need to be unique. You can use UpdateScript
to change this value later.
Parameter nodeJsVersion :
The Node.js version used for execution of your Realtime script. The valid
values are 10.x | 24.x. By default,
NodeJsVersion is 10.x. This value cannot be
updated later.
Parameter storageLocation :
The location of the Amazon S3 bucket where a zipped file containing your
Realtime scripts is stored. The storage location must specify the Amazon
S3 bucket name, the zip file name (the "key"), and a role ARN that allows
Amazon GameLift Servers to access the Amazon S3 storage location. The S3
bucket must be in the same Region where you want to create a new script.
By default, Amazon GameLift Servers uploads the latest version of the zip
file; if you have S3 object versioning turned on, you can use the
ObjectVersion parameter to specify an earlier version.
Parameter tags :
A list of labels to assign to the new script resource. Tags are
developer-defined key-value pairs. Tagging Amazon Web Services resources
are useful for resource management, access management and cost allocation.
For more information, see
Tagging Amazon Web Services Resources in the Amazon Web Services
General Reference. Once the resource is created, you can use TagResource,
UntagResource,
and ListTagsForResource
to add, remove, and view tags. The maximum tag limit may be lower than
stated. See the Amazon Web Services General Reference for actual tagging
limits.
Parameter version :
Version information that is associated with a build or script. Version
strings do not need to be unique. You can use UpdateScript
to change this value later.
Parameter zipFile :
A data object containing your Realtime scripts and dependencies as a zip
file. The zip file can have one or multiple files. Maximum size of a zip
file is 5 MB.
When using the Amazon Web Services CLI tool to create a script, this
parameter is set to the zip file name. It must be prepended with the
string "fileb://" to indicate that the file data is a binary object. For
example: --zip-file fileb://myRealtimeScript.zip.
Implementation
Future<CreateScriptOutput> createScript({
String? name,
String? nodeJsVersion,
S3Location? storageLocation,
List<Tag>? tags,
String? version,
Uint8List? zipFile,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.CreateScript'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (name != null) 'Name': name,
if (nodeJsVersion != null) 'NodeJsVersion': nodeJsVersion,
if (storageLocation != null) 'StorageLocation': storageLocation,
if (tags != null) 'Tags': tags,
if (version != null) 'Version': version,
if (zipFile != null) 'ZipFile': base64Encode(zipFile),
},
);
return CreateScriptOutput.fromJson(jsonResponse.body);
}