deleteContainerFleet method
This API works with the following fleet types: Container
Deletes all resources and information related to a container fleet and
shuts down currently running fleet instances, including those in remote
locations. The container fleet must be in ACTIVE status to be
deleted.
To delete a fleet, specify the fleet ID to be terminated. During the
deletion process, the fleet status is changed to DELETING.
Learn more
Setting up Amazon GameLift Servers Fleets
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw TaggingFailedException.
May throw UnauthorizedException.
May throw UnsupportedRegionException.
Parameter fleetId :
A unique identifier for the container fleet to delete. You can use either
the fleet ID or ARN value.
Implementation
Future<void> deleteContainerFleet({
required String fleetId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DeleteContainerFleet'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FleetId': fleetId,
},
);
}