deleteMatchmakingRuleSet method
This API works with the following fleet types: EC2, Anywhere, Container
Deletes an existing matchmaking rule set. To delete the rule set, provide the rule set name. Rule sets cannot be deleted if they are currently being used by a matchmaking configuration.
Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw TaggingFailedException.
May throw UnsupportedRegionException.
Parameter name :
A unique identifier for the matchmaking rule set to be deleted. (Note: The
rule set name is different from the optional "name" field in the rule set
body.) You can use either the rule set name or ARN value.
Implementation
Future<void> deleteMatchmakingRuleSet({
required String name,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DeleteMatchmakingRuleSet'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
},
);
}