describeFleetUtilization method
This API works with the following fleet types: EC2, Container
Retrieves utilization statistics for one or more fleets. Utilization data provides a snapshot of how the fleet's hosting resources are currently being used. For fleets with remote locations, this operation retrieves data for the fleet's home Region only. See DescribeFleetLocationUtilization to get utilization statistics for a fleet's remote locations.
This operation can be used in the following ways:
- To get utilization data for one or more specific fleets, provide a list of fleet IDs or fleet ARNs.
- To get utilization data for all fleets, do not provide a fleet identifier.
If successful, a FleetUtilization
object is returned for each requested fleet ID, unless the fleet
identifier is not found. Each fleet utilization object includes a
Location property, which is set to the fleet's home Region.
Learn more
Setting up Amazon GameLift Servers Fleets
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
Parameter fleetIds :
A unique identifier for the fleet to retrieve utilization data for. You
can use either the fleet ID or ARN value. To retrieve attributes for all
current fleets, do not include this parameter.
Parameter limit :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages. This
parameter is ignored when the request specifies one or a list of fleet
IDs.
Parameter nextToken :
A token that indicates the start of the next sequential page of results.
Use the token that is returned with a previous call to this operation. To
start at the beginning of the result set, do not specify a value. This
parameter is ignored when the request specifies one or a list of fleet
IDs.
Implementation
Future<DescribeFleetUtilizationOutput> describeFleetUtilization({
List<String>? fleetIds,
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.DescribeFleetUtilization'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (fleetIds != null) 'FleetIds': fleetIds,
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeFleetUtilizationOutput.fromJson(jsonResponse.body);
}