listContainerGroupDefinitionVersions method
This API works with the following fleet types: Container
Retrieves all versions of a container group definition. Use the pagination parameters to retrieve results in a set of sequential pages.
Request options:
- Get all versions of a specified container group definition. Specify the container group definition name or ARN value. (If the ARN value has a version number, it's ignored.)
If successful, this operation returns the complete properties of a set of container group definition versions that match the request. Learn more
May throw InternalServiceException.
May throw InvalidRequestException.
May throw NotFoundException.
May throw UnauthorizedException.
May throw UnsupportedRegionException.
Parameter name :
The unique identifier for the container group definition to retrieve
properties for. You can use either the Name or
ARN value.
Parameter limit :
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
Parameter nextToken :
A token that indicates the start of the next sequential page of results.
Use the token that is returned with a previous call to this operation. To
start at the beginning of the result set, do not specify a value.
Implementation
Future<ListContainerGroupDefinitionVersionsOutput>
listContainerGroupDefinitionVersions({
required String name,
int? limit,
String? nextToken,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'GameLift.ListContainerGroupDefinitionVersions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListContainerGroupDefinitionVersionsOutput.fromJson(
jsonResponse.body);
}