createStreamSessionAdminShell method
Creates an administrative terminal session with full access to the live
runtime environment of the Amazon GameLift Streams stream session. Use the
returned credentials (SessionId, StreamUrl and
TokenValue) with the Amazon Web Services Systems Manager Session
Manager plugin for the CLI to access the terminal session.
The stream session must be in one of the following statuses:
ACTIVE, CONNECTED,
PENDING_CLIENT_RECONNECTION, or RECONNECTING.
The StreamUrl is valid for 60 seconds. After it expires, call
this operation again to get a new URL.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw StreamSessionAccessNotReadyException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
The stream group that runs this stream session.
This value is an Amazon
Resource Name (ARN) or ID that uniquely identifies the stream group
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
Parameter streamSessionIdentifier :
An Amazon
Resource Name (ARN) or ID that uniquely identifies the stream session
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567.
Example ID: ABC123def4567.
Implementation
Future<CreateStreamSessionAdminShellOutput> createStreamSessionAdminShell({
required String identifier,
required String streamSessionIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/streamgroups/${Uri.encodeComponent(identifier)}/streamsessions/${Uri.encodeComponent(streamSessionIdentifier)}/access',
exceptionFnMap: _exceptionFns,
);
return CreateStreamSessionAdminShellOutput.fromJson(response);
}