getStreamGroup method
Retrieves properties for a Amazon GameLift Streams stream group resource. Specify the ID of the stream group that you want to retrieve. If the operation is successful, it returns properties for the requested stream group.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identifier :
An Amazon
Resource Name (ARN) or ID that uniquely identifies the stream group
resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
Implementation
Future<GetStreamGroupOutput> getStreamGroup({
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/streamgroups/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
return GetStreamGroupOutput.fromJson(response);
}