batchGetBlueprints method
Retrieves information about a list of blueprints.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter names :
A list of blueprint names.
Parameter includeBlueprint :
Specifies whether or not to include the blueprint in the response.
Parameter includeParameterSpec :
Specifies whether or not to include the parameters, as a JSON string, for
the blueprint in the response.
Implementation
Future<BatchGetBlueprintsResponse> batchGetBlueprints({
required List<String> names,
bool? includeBlueprint,
bool? includeParameterSpec,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.BatchGetBlueprints'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Names': names,
if (includeBlueprint != null) 'IncludeBlueprint': includeBlueprint,
if (includeParameterSpec != null)
'IncludeParameterSpec': includeParameterSpec,
},
);
return BatchGetBlueprintsResponse.fromJson(jsonResponse.body);
}