batchGetIterableForms method
Retrieves multiple items from an iterable form on an asset in Glue Data Catalog in a single request.
May throw AccessDeniedException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw ThrottlingException.
Parameter assetIdentifier :
The unique identifier of the asset.
Parameter itemIdentifiers :
The list of item identifiers to retrieve. Each identifier can be an item
ID or item name.
Parameter iterableFormName :
The name of the iterable form to retrieve items from.
Implementation
Future<BatchGetIterableFormsResponse> batchGetIterableForms({
required String assetIdentifier,
required List<String> itemIdentifiers,
required String iterableFormName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.BatchGetIterableForms'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AssetIdentifier': assetIdentifier,
'ItemIdentifiers': itemIdentifiers,
'IterableFormName': iterableFormName,
},
);
return BatchGetIterableFormsResponse.fromJson(jsonResponse.body);
}