deleteCatalog method
Removes the specified catalog from the Glue Data Catalog.
After completing this operation, you no longer have access to the databases, tables (and all table versions and partitions that might belong to the tables) and the user-defined functions in the deleted catalog. Glue deletes these "orphaned" resources asynchronously in a timely manner, at the discretion of the service.
To ensure the immediate deletion of all related resources before calling
the DeleteCatalog operation, use
DeleteTableVersion (or BatchDeleteTableVersion),
DeletePartition (or BatchDeletePartition),
DeleteTable (or BatchDeleteTable),
DeleteUserDefinedFunction and DeleteDatabase to
delete any resources that belong to the catalog.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw FederationSourceException.
May throw GlueEncryptionException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter catalogId :
The ID of the catalog.
Implementation
Future<void> deleteCatalog({
required String catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteCatalog'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CatalogId': catalogId,
},
);
}