deleteMLTransform method
Deletes an Glue machine learning transform. Machine learning transforms
are a special type of transform that use machine learning to learn the
details of the transformation to be performed by learning from examples
provided by humans. These transformations are then saved by Glue. If you
no longer need a transform, you can delete it by calling
DeleteMLTransforms. However, any Glue jobs that still
reference the deleted transform will no longer succeed.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter transformId :
The unique identifier of the transform to delete.
Implementation
Future<DeleteMLTransformResponse> deleteMLTransform({
required String transformId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteMLTransform'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TransformId': transformId,
},
);
return DeleteMLTransformResponse.fromJson(jsonResponse.body);
}