deleteRegistry method
Delete the entire registry including schema and all of its versions. To
get the status of the delete operation, you can call the
GetRegistry API after the asynchronous call. Deleting a
registry will deactivate all online operations for the registry such as
the UpdateRegistry, CreateSchema,
UpdateSchema, and RegisterSchemaVersion APIs.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InvalidInputException.
Parameter registryId :
This is a wrapper structure that may contain the registry name and Amazon
Resource Name (ARN).
Implementation
Future<DeleteRegistryResponse> deleteRegistry({
required RegistryId registryId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteRegistry'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'RegistryId': registryId,
},
);
return DeleteRegistryResponse.fromJson(jsonResponse.body);
}