deleteSchema method
Deletes the entire schema set, including the schema set and all of its
versions. To get the status of the delete operation, you can call
GetSchema API after the asynchronous call. Deleting a
registry will deactivate all online operations for the schema, such as the
GetSchemaByDefinition, and RegisterSchemaVersion
APIs.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InvalidInputException.
Parameter schemaId :
This is a wrapper structure that may contain the schema name and Amazon
Resource Name (ARN).
Implementation
Future<DeleteSchemaResponse> deleteSchema({
required SchemaId schemaId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DeleteSchema'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SchemaId': schemaId,
},
);
return DeleteSchemaResponse.fromJson(jsonResponse.body);
}