describeConnectionType method
The DescribeConnectionType API provides full details of the
supported options for a given connection type in Glue. The response
includes authentication configuration details that show supported
authentication types and properties, and RestConfiguration for custom
REST-based connection types registered via
RegisterConnectionType.
See also: ListConnectionTypes,
RegisterConnectionType, DeleteConnectionType
May throw AccessDeniedException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw ValidationException.
Parameter connectionType :
The name of the connection type to be described.
Implementation
Future<DescribeConnectionTypeResponse> describeConnectionType({
required String connectionType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.DescribeConnectionType'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ConnectionType': connectionType,
},
);
return DescribeConnectionTypeResponse.fromJson(jsonResponse.body);
}