getBlueprintRuns method
Retrieves the details of blueprint runs for a specified blueprint.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter blueprintName :
The name of the blueprint.
Parameter maxResults :
The maximum size of a list to return.
Parameter nextToken :
A continuation token, if this is a continuation request.
Implementation
Future<GetBlueprintRunsResponse> getBlueprintRuns({
required String blueprintName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetBlueprintRuns'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'BlueprintName': blueprintName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetBlueprintRunsResponse.fromJson(jsonResponse.body);
}