getCatalog method
The name of the Catalog to retrieve. This should be all lowercase.
May throw AccessDeniedException.
May throw EntityNotFoundException.
May throw FederationSourceException.
May throw FederationSourceRetryableException.
May throw GlueEncryptionException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter catalogId :
The ID of the parent catalog in which the catalog resides. If none is
provided, the Amazon Web Services Account Number is used by default.
Implementation
Future<GetCatalogResponse> getCatalog({
required String catalogId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetCatalog'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CatalogId': catalogId,
},
);
return GetCatalogResponse.fromJson(jsonResponse.body);
}