getColumnStatisticsTaskRun method
Future<GetColumnStatisticsTaskRunResponse>
getColumnStatisticsTaskRun({
- required String columnStatisticsTaskRunId,
Get the associated metadata/information for a task run, given a task run ID.
May throw EntityNotFoundException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter columnStatisticsTaskRunId :
The identifier for the particular column statistics task run.
Implementation
Future<GetColumnStatisticsTaskRunResponse> getColumnStatisticsTaskRun({
required String columnStatisticsTaskRunId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetColumnStatisticsTaskRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ColumnStatisticsTaskRunId': columnStatisticsTaskRunId,
},
);
return GetColumnStatisticsTaskRunResponse.fromJson(jsonResponse.body);
}