getGlueIdentityCenterConfiguration method
Retrieves the current Glue Identity Center configuration details, including the associated Identity Center instance and application information.
May throw AccessDeniedException.
May throw ConcurrentModificationException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Implementation
Future<GetGlueIdentityCenterConfigurationResponse>
getGlueIdentityCenterConfiguration() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.GetGlueIdentityCenterConfiguration'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetGlueIdentityCenterConfigurationResponse.fromJson(
jsonResponse.body);
}