listBlueprints method
Lists all the blueprint names in an account.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter maxResults :
The maximum size of a list to return.
Parameter nextToken :
A continuation token, if this is a continuation request.
Parameter tags :
Filters the list by an Amazon Web Services resource tag.
Implementation
Future<ListBlueprintsResponse> listBlueprints({
int? maxResults,
String? nextToken,
Map<String, String>? tags,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.ListBlueprints'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (tags != null) 'Tags': tags,
},
);
return ListBlueprintsResponse.fromJson(jsonResponse.body);
}