listIterableForms method
Lists the items in an iterable form on an asset in Glue Data Catalog. For example, lists the columns of a table asset.
May throw AccessDeniedException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw ThrottlingException.
Parameter assetIdentifier :
The unique identifier of the asset.
Parameter iterableFormName :
The name of the iterable form to list items from.
Parameter maxResults :
The maximum number of results to return in the response.
Parameter nextToken :
A continuation token, if this is a continuation call.
Implementation
Future<ListIterableFormsResponse> listIterableForms({
required String assetIdentifier,
required String iterableFormName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.ListIterableForms'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AssetIdentifier': assetIdentifier,
'IterableFormName': iterableFormName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListIterableFormsResponse.fromJson(jsonResponse.body);
}