stopMaterializedViewRefreshTaskRun method
Stops a materialized view refresh task run, for a specified table and columns.
May throw AccessDeniedException.
May throw InvalidInputException.
May throw MaterializedViewRefreshTaskNotRunningException.
May throw MaterializedViewRefreshTaskStoppingException.
May throw OperationTimeoutException.
Parameter catalogId :
The ID of the Data Catalog where the table reside. If none is supplied,
the account ID is used by default.
Parameter databaseName :
The name of the database where the table resides.
Parameter tableName :
The name of the table to generate statistics.
Implementation
Future<void> stopMaterializedViewRefreshTaskRun({
required String catalogId,
required String databaseName,
required String tableName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.StopMaterializedViewRefreshTaskRun'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CatalogId': catalogId,
'DatabaseName': databaseName,
'TableName': tableName,
},
);
}