updateIntegrationResourceProperty method
- required String resourceArn,
- SourceProcessingProperties? sourceProcessingProperties,
- TargetProcessingProperties? targetProcessingProperties,
This API can be used for updating the ResourceProperty of the
Glue connection (for the source) or Glue database ARN (for the target).
These properties can include the role to access the connection or
database. Since the same resource can be used across multiple
integrations, updating resource properties will impact all the
integrations using it.
May throw AccessDeniedException.
May throw EntityNotFoundException.
May throw InternalServerException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The connection ARN of the source, or the database ARN of the target.
Parameter sourceProcessingProperties :
The resource properties associated with the integration source.
Parameter targetProcessingProperties :
The resource properties associated with the integration target.
Implementation
Future<UpdateIntegrationResourcePropertyResponse>
updateIntegrationResourceProperty({
required String resourceArn,
SourceProcessingProperties? sourceProcessingProperties,
TargetProcessingProperties? targetProcessingProperties,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSGlue.UpdateIntegrationResourceProperty'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
if (sourceProcessingProperties != null)
'SourceProcessingProperties': sourceProcessingProperties,
if (targetProcessingProperties != null)
'TargetProcessingProperties': targetProcessingProperties,
},
);
return UpdateIntegrationResourcePropertyResponse.fromJson(
jsonResponse.body);
}