acceptInvitation method
Accepts the invitation to be monitored by a GuardDuty administrator account.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the detector of the GuardDuty member account.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter invitationId :
The value that is used to validate the administrator account to the member
account.
Parameter masterId :
The account ID of the GuardDuty administrator account whose invitation
you're accepting.
Implementation
Future<void> acceptInvitation({
required String detectorId,
required String invitationId,
required String masterId,
}) async {
final $payload = <String, dynamic>{
'invitationId': invitationId,
'masterId': masterId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/detector/${Uri.encodeComponent(detectorId)}/master',
exceptionFnMap: _exceptionFns,
);
}