deleteDetector method
Deletes an Amazon GuardDuty detector that is specified by the detector ID.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the detector that you want to delete.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Implementation
Future<void> deleteDetector({
required String detectorId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/detector/${Uri.encodeComponent(detectorId)}',
exceptionFnMap: _exceptionFns,
);
}