deleteFilter method
Deletes the filter specified by the filter name.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the detector that is associated with the filter.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter filterName :
The name of the filter that you want to delete.
Implementation
Future<void> deleteFilter({
required String detectorId,
required String filterName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/filter/${Uri.encodeComponent(filterName)}',
exceptionFnMap: _exceptionFns,
);
}