deleteTrustedEntitySet method
Deletes the trusted entity set that is associated with the specified
trustedEntitySetId.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the detector associated with the trusted entity set
resource.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter trustedEntitySetId :
The unique ID that helps GuardDuty identify which trusted entity set needs
to be deleted.
Implementation
Future<void> deleteTrustedEntitySet({
required String detectorId,
required String trustedEntitySetId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/trustedentityset/${Uri.encodeComponent(trustedEntitySetId)}',
exceptionFnMap: _exceptionFns,
);
}