getMalwareScanSettings method
Returns the details of the malware scan settings.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter detectorId :
The unique ID of the detector that is associated with this scan.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Implementation
Future<GetMalwareScanSettingsResponse> getMalwareScanSettings({
required String detectorId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/malware-scan-settings',
exceptionFnMap: _exceptionFns,
);
return GetMalwareScanSettingsResponse.fromJson(response);
}