getMemberDetectors method
Describes which data sources are enabled for the member account's detector.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter accountIds :
A list of member account IDs.
Parameter detectorId :
The detector ID for the administrator account.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Implementation
Future<GetMemberDetectorsResponse> getMemberDetectors({
required List<String> accountIds,
required String detectorId,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/member/detector/get',
exceptionFnMap: _exceptionFns,
);
return GetMemberDetectorsResponse.fromJson(response);
}