updateMemberDetectors method
Contains information on member accounts to be updated.
Specifying both EKS Runtime Monitoring
(EKS_RUNTIME_MONITORING) and Runtime Monitoring
(RUNTIME_MONITORING) will cause an error. You can add only
one of these two features because Runtime Monitoring already includes the
threat detection for Amazon EKS resources. For more information, see Runtime
Monitoring.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.
May throw BadRequestException.
May throw InternalServerErrorException.
Parameter accountIds :
A list of member account IDs to be updated.
Parameter detectorId :
The detector ID of the administrator account.
To find the detectorId in the current Region, see the
Settings page in the GuardDuty console, or run the ListDetectors
API.
Parameter dataSources :
Describes which data sources will be updated.
Parameter features :
A list of features that will be updated for the specified member accounts.
Implementation
Future<UpdateMemberDetectorsResponse> updateMemberDetectors({
required List<String> accountIds,
required String detectorId,
DataSourceConfigurations? dataSources,
List<MemberFeaturesConfiguration>? features,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
if (dataSources != null) 'dataSources': dataSources,
if (features != null) 'features': features,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/detector/${Uri.encodeComponent(detectorId)}/member/detector/update',
exceptionFnMap: _exceptionFns,
);
return UpdateMemberDetectorsResponse.fromJson(response);
}