describeEventTypes method
Returns the event types that meet the specified filter criteria. You can use this API operation to find information about the Health event, such as the category, Amazon Web Services service, and event code. The metadata for each event appears in the EventType object.
If you don't specify a filter criteria, the API operation returns all event types, in no particular order.
May throw InvalidPaginationToken.
May throw UnsupportedLocale.
Parameter filter :
Values to narrow the results returned.
Parameter locale :
The locale (language) to return information in. English (en) is the
default and the only supported value at this time.
Parameter maxResults :
The maximum number of items to return in one batch, between 10 and 100,
inclusive.
Parameter nextToken :
If the results of a search are large, only a portion of the results are
returned, and a nextToken pagination token is returned in the
response. To retrieve the next batch of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
Implementation
Future<DescribeEventTypesResponse> describeEventTypes({
EventTypeFilter? filter,
String? locale,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
10,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSHealth_20160804.DescribeEventTypes'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'filter': filter,
if (locale != null) 'locale': locale,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return DescribeEventTypesResponse.fromJson(jsonResponse.body);
}