enableHealthServiceAccessForOrganization method
Enables Health to work with Organizations. You can use the organizational view feature to aggregate events from all Amazon Web Services accounts in your organization in a centralized location.
This operation also creates a service-linked role for the management account in the organization.
-
You must have a Business, Enterprise On-Ramp, or Enterprise Support plan
from Amazon Web Services
Support to use the Health API. If you call the Health API from an
Amazon Web Services account that doesn't have a Business, Enterprise
On-Ramp, or Enterprise Support plan, you receive a
SubscriptionRequiredExceptionerror. - You must have permission to call this operation from the organization's management account. For example IAM policies, see Health identity-based policy examples.
May throw ConcurrentModificationException.
Implementation
Future<void> enableHealthServiceAccessForOrganization() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSHealth_20160804.EnableHealthServiceAccessForOrganization'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}