createInstanceProfile method
Creates a new instance profile. For information about instance profiles, see Using roles for applications on Amazon EC2 in the IAM User Guide, and Instance profiles in the Amazon EC2 User Guide.
For information about the number of instance profiles you can create, see IAM object quotas in the IAM User Guide.
May throw ConcurrentModificationException.
May throw EntityAlreadyExistsException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ServiceFailureException.
Parameter instanceProfileName :
The name of the instance profile to create.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
Parameter path :
The path to the instance profile. For more information about paths, see IAM
Identifiers in the IAM User Guide.
This parameter is optional. If it is not included, it defaults to a slash (/).
This parameter allows (through its regex pattern) a string of
characters consisting of either a forward slash (/) by itself or a string
that must begin and end with forward slashes. In addition, it can contain
any ASCII character from the ! (\u0021) through the DEL
character (\u007F), including most punctuation characters,
digits, and upper and lowercased letters.
Parameter tags :
A list of tags that you want to attach to the newly created IAM instance
profile. Each tag consists of a key name and an associated value. For more
information about tagging, see Tagging
IAM resources in the IAM User Guide.
Implementation
Future<CreateInstanceProfileResponse> createInstanceProfile({
required String instanceProfileName,
String? path,
List<Tag>? tags,
}) async {
final $request = <String, String>{
'InstanceProfileName': instanceProfileName,
if (path != null) 'Path': path,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.member.${i1 + 1}.${e3.key}': e3.value,
};
final $result = await _protocol.send(
$request,
action: 'CreateInstanceProfile',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateInstanceProfileResult',
);
return CreateInstanceProfileResponse.fromXml($result);
}