deleteVirtualMFADevice method
Deletes a virtual MFA device.
May throw ConcurrentModificationException.
May throw DeleteConflictException.
May throw LimitExceededException.
May throw NoSuchEntityException.
May throw ServiceFailureException.
Parameter serialNumber :
The serial number that uniquely identifies the MFA device. For virtual MFA
devices, the serial number is the same as the ARN.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: =,.@:/-
Implementation
Future<void> deleteVirtualMFADevice({
required String serialNumber,
}) async {
final $request = <String, String>{
'SerialNumber': serialNumber,
};
await _protocol.send(
$request,
action: 'DeleteVirtualMFADevice',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}