disableOutboundWebIdentityFederation method
Disables the outbound identity federation feature for your Amazon Web
Services account. When disabled, IAM principals in the account cannot use
the GetWebIdentityToken API to obtain JSON Web Tokens (JWTs)
for authentication with external services. This operation does not affect
tokens that were issued before the feature was disabled.
May throw FeatureDisabledException.
Implementation
Future<void> disableOutboundWebIdentityFederation() async {
final $request = <String, String>{};
await _protocol.send(
$request,
action: 'DisableOutboundWebIdentityFederation',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}