generateServiceLastAccessedDetails method
- required String arn,
- AccessAdvisorUsageGranularityType? granularity,
Generates a report that includes details about when an IAM resource (user,
group, role, or policy) was last used in an attempt to access Amazon Web
Services services. Recent activity usually appears within four hours. IAM
reports activity for at least the last 400 days, or less if your Region
began supporting this feature within the last year. For more information,
see Regions
where data is tracked. For more information about services and actions
for which action last accessed information is displayed, see IAM
action last accessed information services and actions.
The GenerateServiceLastAccessedDetails operation returns a
JobId. Use this parameter in the following operations to
retrieve the following details from your report:
-
GetServiceLastAccessedDetails
– Use this operation for users, groups, roles, or policies to list every
Amazon Web Services service that the resource could access using
permissions policies. For each service, the response includes information
about the most recent access attempt.
The
JobIdreturned byGenerateServiceLastAccessedDetailmust be used by the same role within a session, or by the same user when used to callGetServiceLastAccessedDetail. - GetServiceLastAccessedDetailsWithEntities – Use this operation for groups and policies to list information about the associated entities (users or roles) that attempted to access a specific Amazon Web Services service.
GenerateServiceLastAccessedDetails
request, use the JobId parameter in the same operations and
test the JobStatus response parameter.
For additional information about the permissions policies that allow an identity (user, group, or role) to access specific services, use the ListPoliciesGrantingServiceAccess operation. For more information about service and action last accessed data, see Reducing permissions using service last accessed data in the IAM User Guide.
May throw InvalidInputException.
May throw NoSuchEntityException.
Parameter arn :
The ARN of the IAM resource (user, group, role, or managed policy) used to
generate information about when the resource was last used in an attempt
to access an Amazon Web Services service.
Parameter granularity :
The level of detail that you want to generate. You can specify whether you
want to generate information about the last attempt to access services or
actions. If you specify service-level granularity, this operation
generates only service data. If you specify action-level granularity, it
generates service and action data. If you don't include this optional
parameter, the operation generates service data.
Implementation
Future<GenerateServiceLastAccessedDetailsResponse>
generateServiceLastAccessedDetails({
required String arn,
AccessAdvisorUsageGranularityType? granularity,
}) async {
final $request = <String, String>{
'Arn': arn,
if (granularity != null) 'Granularity': granularity.value,
};
final $result = await _protocol.send(
$request,
action: 'GenerateServiceLastAccessedDetails',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GenerateServiceLastAccessedDetailsResult',
);
return GenerateServiceLastAccessedDetailsResponse.fromXml($result);
}