getCredentialReport method
Retrieves a credential report for the Amazon Web Services account. For more information about the credential report, see Getting credential reports in the IAM User Guide.
May throw CredentialReportExpiredException.
May throw CredentialReportNotPresentException.
May throw CredentialReportNotReadyException.
May throw ServiceFailureException.
Implementation
Future<GetCredentialReportResponse> getCredentialReport() async {
final $request = <String, String>{};
final $result = await _protocol.send(
$request,
action: 'GetCredentialReport',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetCredentialReportResult',
);
return GetCredentialReportResponse.fromXml($result);
}