listOrganizationsFeatures method
Lists the centralized root access features enabled for your organization. For more information, see Centrally manage root access for member accounts.
May throw AccountNotManagementOrDelegatedAdministratorException.
May throw OrganizationNotFoundException.
May throw OrganizationNotInAllFeaturesModeException.
May throw ServiceAccessNotEnabledException.
Implementation
Future<ListOrganizationsFeaturesResponse> listOrganizationsFeatures() async {
final $request = <String, String>{};
final $result = await _protocol.send(
$request,
action: 'ListOrganizationsFeatures',
version: '2010-05-08',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListOrganizationsFeaturesResult',
);
return ListOrganizationsFeaturesResponse.fromXml($result);
}