Identitystore class
The Identity Store service used by IAM Identity Center provides a single place to retrieve all of your identities (users and groups). For more information, see the IAM Identity Center User Guide.
This reference guide describes the identity store operations that you can call programmatically and includes detailed information about data types and errors.
Constructors
- Identitystore({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createGroup(
{required String identityStoreId, String? description, String? displayName}) → Future< CreateGroupResponse> - Creates a group within the specified identity store.
-
createGroupMembership(
{required String groupId, required String identityStoreId, required MemberId memberId}) → Future< CreateGroupMembershipResponse> -
Creates a relationship between a member and a group. The following
identifiers must be specified:
GroupId,IdentityStoreId, andMemberId. -
createUser(
{required String identityStoreId, List< Address> ? addresses, String? birthdate, String? displayName, List<Email> ? emails, Map<String, Object> ? extensions, String? locale, Name? name, String? nickName, List<PhoneNumber> ? phoneNumbers, List<Photo> ? photos, String? preferredLanguage, String? profileUrl, List<Role> ? roles, String? timezone, String? title, String? userName, String? userType, String? website}) → Future<CreateUserResponse> - Creates a user within the specified identity store.
-
deleteGroup(
{required String groupId, required String identityStoreId}) → Future< void> -
Delete a group within an identity store given
GroupId. -
deleteGroupMembership(
{required String identityStoreId, required String membershipId}) → Future< void> -
Delete a membership within a group given
MembershipId. -
deleteUser(
{required String identityStoreId, required String userId}) → Future< void> -
Deletes a user within an identity store given
UserId. -
describeGroup(
{required String groupId, required String identityStoreId}) → Future< DescribeGroupResponse> -
Retrieves the group metadata and attributes from
GroupIdin an identity store. -
describeGroupMembership(
{required String identityStoreId, required String membershipId}) → Future< DescribeGroupMembershipResponse> -
Retrieves membership metadata and attributes from
MembershipIdin an identity store. -
describeUser(
{required String identityStoreId, required String userId, List< String> ? extensions}) → Future<DescribeUserResponse> -
Retrieves the user metadata and attributes from the
UserIdin an identity store. -
getGroupId(
{required AlternateIdentifier alternateIdentifier, required String identityStoreId}) → Future< GetGroupIdResponse> -
Retrieves
GroupIdin an identity store. -
getGroupMembershipId(
{required String groupId, required String identityStoreId, required MemberId memberId}) → Future< GetGroupMembershipIdResponse> -
Retrieves the
MembershipIdin an identity store. -
getUserId(
{required AlternateIdentifier alternateIdentifier, required String identityStoreId}) → Future< GetUserIdResponse> -
Retrieves the
UserIdin an identity store. -
isMemberInGroups(
{required List< String> groupIds, required String identityStoreId, required MemberId memberId}) → Future<IsMemberInGroupsResponse> - Checks the user's membership in all requested groups and returns if the member exists in all queried groups.
-
listGroupMemberships(
{required String groupId, required String identityStoreId, int? maxResults, String? nextToken}) → Future< ListGroupMembershipsResponse> -
For the specified group in the specified identity store, returns the list
of all
GroupMembershipobjects and returns results in paginated form. -
listGroupMembershipsForMember(
{required String identityStoreId, required MemberId memberId, int? maxResults, String? nextToken}) → Future< ListGroupMembershipsForMemberResponse> -
For the specified member in the specified identity store, returns the list
of all
GroupMembershipobjects and returns results in paginated form. -
listGroups(
{required String identityStoreId, List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListGroupsResponse> -
Lists all groups in the identity store. Returns a paginated list of
complete
Groupobjects. Filtering for aGroupby theDisplayNameattribute is deprecated. Instead, use theGetGroupIdAPI action. -
listUsers(
{required String identityStoreId, List< String> ? extensions, List<Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListUsersResponse> -
Lists all users in the identity store. Returns a paginated list of
complete
Userobjects. Filtering for aUserby theUserNameattribute is deprecated. Instead, use theGetUserIdAPI action. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateGroup(
{required String groupId, required String identityStoreId, required List< AttributeOperation> operations}) → Future<void> - Updates the specified group metadata and attributes in the specified identity store.
-
updateUser(
{required String identityStoreId, required List< AttributeOperation> operations, required String userId}) → Future<void> - Updates the specified user metadata and attributes in the specified identity store.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited