updateGroup method
Updates the specified group metadata and attributes in the specified identity store.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter groupId :
The identifier for a group in the identity store.
Parameter identityStoreId :
The globally unique identifier for the identity store.
Parameter operations :
A list of AttributeOperation objects to apply to the
requested group. These operations might add, replace, or remove an
attribute. For more information on the attributes that can be added,
replaced, or removed, see Group.
Implementation
Future<void> updateGroup({
required String groupId,
required String identityStoreId,
required List<AttributeOperation> operations,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSIdentityStore.UpdateGroup'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GroupId': groupId,
'IdentityStoreId': identityStoreId,
'Operations': operations,
},
);
}