listImagePackages method

Future<ListImagePackagesResponse> listImagePackages({
  1. required String imageBuildVersionArn,
  2. int? maxResults,
  3. String? nextToken,
})

List the Packages that are associated with an Image Build Version, as determined by Amazon Web Services Systems Manager Inventory at build time.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter imageBuildVersionArn : Filter results for the ListImagePackages request by the Image Build Version ARN

Parameter maxResults : Specify the maximum number of items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Implementation

Future<ListImagePackagesResponse> listImagePackages({
  required String imageBuildVersionArn,
  int? maxResults,
  String? nextToken,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $payload = <String, dynamic>{
    'imageBuildVersionArn': imageBuildVersionArn,
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListImagePackages',
    exceptionFnMap: _exceptionFns,
  );
  return ListImagePackagesResponse.fromJson(response);
}