listWorkflowBuildVersions method

Future<ListWorkflowBuildVersionsResponse> listWorkflowBuildVersions({
  1. int? maxResults,
  2. String? nextToken,
  3. String? workflowVersionArn,
})

Returns a list of build versions for a specific workflow resource.

May throw CallRateLimitExceededException. May throw ClientException. May throw ForbiddenException. May throw InvalidPaginationTokenException. May throw InvalidRequestException. May throw ServiceException. May throw ServiceUnavailableException.

Parameter maxResults : Specify the maximum number of items to return in a request.

Parameter nextToken : A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Parameter workflowVersionArn : The Amazon Resource Name (ARN) of the workflow resource for which to get a list of build versions.

Implementation

Future<ListWorkflowBuildVersionsResponse> listWorkflowBuildVersions({
  int? maxResults,
  String? nextToken,
  String? workflowVersionArn,
}) async {
  _s.validateNumRange(
    'maxResults',
    maxResults,
    1,
    25,
  );
  final $payload = <String, dynamic>{
    if (maxResults != null) 'maxResults': maxResults,
    if (nextToken != null) 'nextToken': nextToken,
    if (workflowVersionArn != null) 'workflowVersionArn': workflowVersionArn,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/ListWorkflowBuildVersions',
    exceptionFnMap: _exceptionFns,
  );
  return ListWorkflowBuildVersionsResponse.fromJson(response);
}