listWorkflowExecutions method
Returns a list of workflow runtime instance metadata objects for a specific image build version.
May throw CallRateLimitExceededException.
May throw ClientException.
May throw ForbiddenException.
May throw InvalidPaginationTokenException.
May throw InvalidRequestException.
May throw ServiceException.
May throw ServiceUnavailableException.
Parameter imageBuildVersionArn :
List all workflow runtime instances for the specified image build version
resource ARN.
Parameter maxResults :
Specify the maximum number of items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListWorkflowExecutionsResponse> listWorkflowExecutions({
required String imageBuildVersionArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $payload = <String, dynamic>{
'imageBuildVersionArn': imageBuildVersionArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListWorkflowExecutions',
exceptionFnMap: _exceptionFns,
);
return ListWorkflowExecutionsResponse.fromJson(response);
}