batchGetCodeSnippet method
Retrieves code snippets from findings that Amazon Inspector detected code vulnerabilities in.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter findingArns :
An array of finding ARNs for the findings you want to retrieve code
snippets from.
Implementation
Future<BatchGetCodeSnippetResponse> batchGetCodeSnippet({
required List<String> findingArns,
}) async {
final $payload = <String, dynamic>{
'findingArns': findingArns,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/codesnippet/batchget',
exceptionFnMap: _exceptionFns,
);
return BatchGetCodeSnippetResponse.fromJson(response);
}