batchGetMemberEc2DeepInspectionStatus method
Retrieves Amazon Inspector deep inspection activation status of multiple member accounts within your organization. You must be the delegated administrator of an organization in Amazon Inspector to use this API.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
The unique identifiers for the Amazon Web Services accounts to retrieve
Amazon Inspector deep inspection activation status for.
Implementation
Future<BatchGetMemberEc2DeepInspectionStatusResponse>
batchGetMemberEc2DeepInspectionStatus({
List<String>? accountIds,
}) async {
final $payload = <String, dynamic>{
if (accountIds != null) 'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ec2deepinspectionstatus/member/batch/get',
exceptionFnMap: _exceptionFns,
);
return BatchGetMemberEc2DeepInspectionStatusResponse.fromJson(response);
}