getClustersForImage method
Returns a list of clusters and metadata associated with an image.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
The resource Id for the Amazon ECR image.
Parameter maxResults :
The maximum number of results to be returned in a single page of results.
Parameter nextToken :
The pagination token from a previous request used to retrieve the next
page of results.
Implementation
Future<GetClustersForImageResponse> getClustersForImage({
required ClusterForImageFilterCriteria filter,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/cluster/get',
exceptionFnMap: _exceptionFns,
);
return GetClustersForImageResponse.fromJson(response);
}