listUsageTotals method
Lists the Amazon Inspector usage totals over the last 30 days.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
The Amazon Web Services account IDs to retrieve usage totals for.
Parameter maxResults :
The maximum number of results the response can return. If your request
would return more than the maximum the response will return a
nextToken value, use this value when you call the action
again to get the remaining results.
Parameter nextToken :
A token to use for paginating results that are returned in the response.
Set the value of this parameter to null for the first request to a list
action. If your response returns more than the maxResults
maximum value it will also return a nextToken value. For
subsequent calls, use the nextToken value returned from the
previous request to continue listing results after the first page.
Implementation
Future<ListUsageTotalsResponse> listUsageTotals({
List<String>? accountIds,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
if (accountIds != null) 'accountIds': accountIds,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/usage/list',
exceptionFnMap: _exceptionFns,
);
return ListUsageTotalsResponse.fromJson(response);
}