updateEc2DeepInspectionConfiguration method
Activates, deactivates Amazon Inspector deep inspection, or updates custom paths for your account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter activateDeepInspection :
Specify TRUE to activate Amazon Inspector deep inspection in
your account, or FALSE to deactivate. Member accounts in an
organization cannot deactivate deep inspection, instead the delegated
administrator for the organization can deactivate a member account using
BatchUpdateMemberEc2DeepInspectionStatus.
Parameter packagePaths :
The Amazon Inspector deep inspection custom paths you are adding for your
account.
Implementation
Future<UpdateEc2DeepInspectionConfigurationResponse>
updateEc2DeepInspectionConfiguration({
bool? activateDeepInspection,
List<String>? packagePaths,
}) async {
final $payload = <String, dynamic>{
if (activateDeepInspection != null)
'activateDeepInspection': activateDeepInspection,
if (packagePaths != null) 'packagePaths': packagePaths,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ec2deepinspectionconfiguration/update',
exceptionFnMap: _exceptionFns,
);
return UpdateEc2DeepInspectionConfigurationResponse.fromJson(response);
}