Interconnect class
Provides managed connections between your AWS network resources and select partner network resources.
Constructors
- Interconnect({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptConnectionProposal(
{required String activationKey, required AttachPoint attachPoint, String? clientToken, String? description, Map< String, String> ? tags}) → Future<AcceptConnectionProposalResponse> - Accepts a connection proposal which was generated at a supported partner's portal.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createConnection(
{required AttachPoint attachPoint, required String bandwidth, required String environmentId, String? clientToken, String? description, RemoteAccountIdentifier? remoteAccount, Map< String, String> ? tags}) → Future<CreateConnectionResponse> - Initiates the process to create a Connection across the specified Environment.
-
deleteConnection(
{required String identifier, String? clientToken}) → Future< DeleteConnectionResponse> - Deletes an existing Connection with the supplied identifier.
-
describeConnectionProposal(
{required String activationKey}) → Future< DescribeConnectionProposalResponse> - Describes the details of a connection proposal generated at a partner's portal.
-
getConnection(
{required String identifier}) → Future< GetConnectionResponse> - Describes the current state of a Connection resource as specified by the identifier.
-
getEnvironment(
{required String id}) → Future< GetEnvironmentResponse> - Describes a specific Environment
-
listAttachPoints(
{required String environmentId, int? maxResults, String? nextToken}) → Future< ListAttachPointsResponse> - Lists all Attach Points the caller has access to that are valid for the specified Environment.
-
listConnections(
{AttachPoint? attachPoint, String? environmentId, int? maxResults, String? nextToken, Provider? provider, ConnectionState? state}) → Future< ListConnectionsResponse> - Lists all connection objects to which the caller has access.
-
listEnvironments(
{String? location, int? maxResults, String? nextToken, Provider? provider}) → Future< ListEnvironmentsResponse> - Lists all of the environments that can produce connections that will land in the called AWS region.
-
listTagsForResource(
{required String arn}) → Future< ListTagsForResourceResponse> - List all current tags on the specified resource. Currently this supports Connection resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String arn, required Map< String, String> tags}) → Future<void> - Add new tags to the specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String arn, required List< String> tagKeys}) → Future<void> - Removes tags from the specified resource.
-
updateConnection(
{required String identifier, String? bandwidth, String? clientToken, String? description}) → Future< UpdateConnectionResponse> - Modifies an existing connection. Currently we support modifications to the connection's description and/or bandwidth.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited