getQueryStatus method
Returns the current status of a query for the Amazon CloudWatch Internet
Monitor query interface, for a specified query ID and monitor. When you
run a query, check the status to make sure that the query has
SUCCEEDED before you review the results.
-
QUEUED: The query is scheduled to run. -
RUNNING: The query is in progress but not complete. -
SUCCEEDED: The query completed sucessfully. -
FAILED: The query failed due to an error. -
CANCELED: The query was canceled.
May throw AccessDeniedException.
May throw InternalServerException.
May throw LimitExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter monitorName :
The name of the monitor.
Parameter queryId :
The ID of the query that you want to return the status for. A
QueryId is an internally-generated dentifier for a specific
query.
Implementation
Future<GetQueryStatusOutput> getQueryStatus({
required String monitorName,
required String queryId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v20210603/Monitors/${Uri.encodeComponent(monitorName)}/Queries/${Uri.encodeComponent(queryId)}/Status',
exceptionFnMap: _exceptionFns,
);
return GetQueryStatusOutput.fromJson(response);
}