deleteDimension method
Removes the specified dimension from your Amazon Web Services accounts.
Requires permission to access the DeleteDimension action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
Parameter name :
The unique identifier for the dimension that you want to delete.
Implementation
Future<void> deleteDimension({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/dimensions/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
}