describeAuditFinding method
Gets information about a single audit finding. Properties include the reason for noncompliance, the severity of the issue, and the start time when the audit that returned the finding.
Requires permission to access the DescribeAuditFinding action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter findingId :
A unique identifier for a single audit finding. You can use this
identifier to apply mitigation actions to the finding.
Implementation
Future<DescribeAuditFindingResponse> describeAuditFinding({
required String findingId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/audit/findings/${Uri.encodeComponent(findingId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeAuditFindingResponse.fromJson(response);
}