describeEndpoint method
Returns or creates a unique endpoint specific to the Amazon Web Services account making the call. Requires permission to access the DescribeEndpoint action.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter endpointType :
The endpoint type. Valid endpoint types include:
-
iot:Data- Returns a VeriSign signed data endpoint.
-
iot:Data-ATS- Returns an ATS signed data endpoint.
-
iot:CredentialProvider- Returns an IoT credentials provider API endpoint.
-
iot:Jobs- Returns an IoT device management Jobs API endpoint.
iot:Data-ATS endpoint type to avoid issues related to the
widespread distrust of Symantec certificate authorities. ATS Signed
Certificates are more secure and are trusted by most popular browsers.
Implementation
Future<DescribeEndpointResponse> describeEndpoint({
String? endpointType,
}) async {
final $query = <String, List<String>>{
if (endpointType != null) 'endpointType': [endpointType],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/endpoint',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeEndpointResponse.fromJson(response);
}