describeManagedJobTemplate method
View details of a managed job template.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter templateName :
The unique name of a managed job template, which is required.
Parameter templateVersion :
An optional parameter to specify version of a managed template. If not
specified, the pre-defined default version is returned.
Implementation
Future<DescribeManagedJobTemplateResponse> describeManagedJobTemplate({
required String templateName,
String? templateVersion,
}) async {
final $query = <String, List<String>>{
if (templateVersion != null) 'templateVersion': [templateVersion],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/managed-job-templates/${Uri.encodeComponent(templateName)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeManagedJobTemplateResponse.fromJson(response);
}