listManagedJobTemplates method
Returns a list of managed job templates.
May throw InternalServerException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter maxResults :
Maximum number of entries that can be returned.
Parameter nextToken :
The token to retrieve the next set of results.
Parameter templateName :
An optional parameter for template name. If specified, only the versions
of the managed job templates that have the specified template name will be
returned.
Implementation
Future<ListManagedJobTemplatesResponse> listManagedJobTemplates({
int? maxResults,
String? nextToken,
String? templateName,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (templateName != null) 'templateName': [templateName],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/managed-job-templates',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListManagedJobTemplatesResponse.fromJson(response);
}