sendDirectMessage method
Sends an MQTT message directly to a specific client identified by its client ID.
SendDirectMessage targets a single client ID. The receiving
client does not need to subscribe to the topic, but the receiver's policy
must allow iot:Receive on the specified topic.
Requires permission to access the SendDirectMessage action.
For more information about messaging costs, see Amazon Web Services IoT Core pricing.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw RequestEntityTooLargeException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
Parameter clientId :
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Parameter topic :
The topic of the outbound MQTT Publish message to the receiving client.
For more information, see Amazon
Web Services IoT Core message broker and protocol limits and quotas.
Parameter confirmation :
A Boolean value that specifies whether to wait for delivery confirmation
from the receiving client.
When set to true, the API delivers the message at QoS 1 and
waits for the client to send a delivery confirmation (PUBACK) before
returning a successful response. If delivery confirmation is not received
within the specified timeout period, the API returns HTTP
504.
When set to false, the API delivers the message at QoS 0 and
returns after Amazon Web Services IoT Core attempts to deliver the
message.
Valid values: true | false
Default value: false
Parameter contentType :
The MQTT5 content type property forwarded to the receiving client (for
example, application/json).
Parameter correlationData :
The base64-encoded binary data used by the sender of the request message
to identify which request the response message is for when it's received.
correlationData is an HTTP header value in the API.
Parameter payload :
The message body. MQTT accepts text, binary, and empty (null) message
payloads.
Parameter payloadFormatIndicator :
An Enum string value that indicates whether the payload is
formatted as UTF-8. payloadFormatIndicator is an HTTP header
value in the API.
Parameter responseTopic :
A UTF-8 encoded string that's used as the topic name for a response
message. The response topic describes the topic which the receiver should
publish to as part of the request-response flow. The topic must not
contain wildcard characters. For more information, see Amazon
Web Services IoT Core message broker and protocol limits and quotas.
Parameter timeout :
An integer that represents the maximum time, in seconds, to wait for a
delivery confirmation (PUBACK) from the receiving client after the message
has been delivered. This parameter is only used when
confirmation is set to true. If
confirmation is false, this parameter is
ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
Parameter userProperties :
A JSON string that contains an array of JSON objects. If you don't use
Amazon Web Services SDK or CLI, you must encode the JSON string to base64
format before adding it to the HTTP header. userProperties is
an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON
string which represents two User Properties. Note that it needs to be
base64-encoded:
[{"deviceName": "alpha"}, {"deviceCnt": "45"}]
Implementation
Future<SendDirectMessageResponse> sendDirectMessage({
required String clientId,
required String topic,
bool? confirmation,
String? contentType,
String? correlationData,
Uint8List? payload,
PayloadFormatIndicator? payloadFormatIndicator,
String? responseTopic,
int? timeout,
Object? userProperties,
}) async {
final headers = <String, String>{
if (correlationData != null)
'x-amz-mqtt5-correlation-data': correlationData.toString(),
if (payloadFormatIndicator != null)
'x-amz-mqtt5-payload-format-indicator': payloadFormatIndicator.value,
if (userProperties != null)
'x-amz-mqtt5-user-properties':
base64Encode(utf8.encode(jsonEncode(userProperties))),
};
final $query = <String, List<String>>{
'topic': [topic],
if (confirmation != null) 'confirmation': [confirmation.toString()],
if (contentType != null) 'contentType': [contentType],
if (responseTopic != null) 'responseTopic': [responseTopic],
if (timeout != null) 'timeout': [timeout.toString()],
};
final response = await _protocol.send(
payload: payload,
method: 'POST',
requestUri: '/connections/${Uri.encodeComponent(clientId)}/messages',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return SendDirectMessageResponse.fromJson(response);
}