listSuiteDefinitions method
Lists the Device Advisor test suites you have created.
Requires permission to access the ListSuiteDefinitions action.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return at once.
Parameter nextToken :
A token used to get the next set of results.
Implementation
Future<ListSuiteDefinitionsResponse> listSuiteDefinitions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/suiteDefinitions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSuiteDefinitionsResponse.fromJson(response);
}