stopSuiteRun method
Stops a Device Advisor test suite run that is currently running.
Requires permission to access the StopSuiteRun action.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter suiteDefinitionId :
Suite definition ID of the test suite run to be stopped.
Parameter suiteRunId :
Suite run ID of the test suite run to be stopped.
Implementation
Future<void> stopSuiteRun({
required String suiteDefinitionId,
required String suiteRunId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/suiteDefinitions/${Uri.encodeComponent(suiteDefinitionId)}/suiteRuns/${Uri.encodeComponent(suiteRunId)}/stop',
exceptionFnMap: _exceptionFns,
);
}