IoTEventsData class
IoT Events monitors your equipment or device fleets for failures or changes in operation, and triggers actions when such events occur. You can use IoT Events Data API commands to send inputs to detectors, list detectors, and view or update a detector's status.
For more information, see What is IoT Events? in the IoT Events Developer Guide.
Constructors
- IoTEventsData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchAcknowledgeAlarm(
{required List< AcknowledgeAlarmActionRequest> acknowledgeActionRequests}) → Future<BatchAcknowledgeAlarmResponse> -
Acknowledges one or more alarms. The alarms change to the
ACKNOWLEDGEDstate after you acknowledge them. -
batchDeleteDetector(
{required List< DeleteDetectorRequest> detectors}) → Future<BatchDeleteDetectorResponse> - Deletes one or more detectors that were created. When a detector is deleted, its state will be cleared and the detector will be removed from the list of detectors. The deleted detector will no longer appear if referenced in the ListDetectors API call.
-
batchDisableAlarm(
{required List< DisableAlarmActionRequest> disableActionRequests}) → Future<BatchDisableAlarmResponse> -
Disables one or more alarms. The alarms change to the
DISABLEDstate after you disable them. -
batchEnableAlarm(
{required List< EnableAlarmActionRequest> enableActionRequests}) → Future<BatchEnableAlarmResponse> -
Enables one or more alarms. The alarms change to the
NORMALstate after you enable them. -
batchPutMessage(
{required List< Message> messages}) → Future<BatchPutMessageResponse> -
Sends a set of messages to the IoT Events system. Each message payload is
transformed into the input you specify (
"inputName") and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn't guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response. -
batchResetAlarm(
{required List< ResetAlarmActionRequest> resetActionRequests}) → Future<BatchResetAlarmResponse> -
Resets one or more alarms. The alarms return to the
NORMALstate after you reset them. -
batchSnoozeAlarm(
{required List< SnoozeAlarmActionRequest> snoozeActionRequests}) → Future<BatchSnoozeAlarmResponse> -
Changes one or more alarms to the snooze mode. The alarms change to the
SNOOZE_DISABLEDstate after you set them to the snooze mode. -
batchUpdateDetector(
{required List< UpdateDetectorRequest> detectors}) → Future<BatchUpdateDetectorResponse> - Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
describeAlarm(
{required String alarmModelName, String? keyValue}) → Future< DescribeAlarmResponse> - Retrieves information about an alarm.
-
describeDetector(
{required String detectorModelName, String? keyValue}) → Future< DescribeDetectorResponse> - Returns information about the specified detector (instance).
-
listAlarms(
{required String alarmModelName, int? maxResults, String? nextToken}) → Future< ListAlarmsResponse> - Lists one or more alarms. The operation returns only the metadata associated with each alarm.
-
listDetectors(
{required String detectorModelName, int? maxResults, String? nextToken, String? stateName}) → Future< ListDetectorsResponse> - Lists detectors (the instances of a detector model).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited