deregisterAccountAssociation method
Deregister an account association from a managed thing.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountAssociationId :
The unique identifier of the account association to be deregistered.
Parameter managedThingId :
The identifier of the managed thing to be deregistered from the account
association.
Implementation
Future<void> deregisterAccountAssociation({
required String accountAssociationId,
required String managedThingId,
}) async {
final $payload = <String, dynamic>{
'AccountAssociationId': accountAssociationId,
'ManagedThingId': managedThingId,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/managed-thing-associations/deregister',
exceptionFnMap: _exceptionFns,
);
}