getAccountAssociation method
Future<GetAccountAssociationResponse>
getAccountAssociation({
- required String accountAssociationId,
Get an account association for an Amazon Web Services account linked to a customer-managed destination.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountAssociationId :
The unique identifier of the account association to retrieve.
Implementation
Future<GetAccountAssociationResponse> getAccountAssociation({
required String accountAssociationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/account-associations/${Uri.encodeComponent(accountAssociationId)}',
exceptionFnMap: _exceptionFns,
);
return GetAccountAssociationResponse.fromJson(response);
}