updateCloudConnector method
Update an existing cloud connector.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter identifier :
The unique identifier of the cloud connector to update.
Parameter description :
The new description to assign to the cloud connector.
Parameter name :
The new display name to assign to the cloud connector.
Implementation
Future<void> updateCloudConnector({
required String identifier,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'Description': description,
if (name != null) 'Name': name,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/cloud-connectors/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}