updateNotificationConfiguration method
Future<void>
updateNotificationConfiguration({
- required String destinationName,
- required EventType eventType,
Update a notification configuration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter destinationName :
The name of the destination for the notification configuration.
Parameter eventType :
The type of event triggering a device notification to the customer-managed
destination.
Implementation
Future<void> updateNotificationConfiguration({
required String destinationName,
required EventType eventType,
}) async {
final $payload = <String, dynamic>{
'DestinationName': destinationName,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/notification-configurations/${Uri.encodeComponent(eventType.value)}',
exceptionFnMap: _exceptionFns,
);
}