deleteAssetModelInterfaceRelationship method
Deletes an interface relationship between an asset model and an interface asset model.
May throw ConflictingOperationException.
May throw InternalFailureException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter assetModelId :
The ID of the asset model. This can be either the actual ID in UUID
format, or else externalId: followed by the external ID.
Parameter interfaceAssetModelId :
The ID of the interface asset model. This can be either the actual ID in
UUID format, or else externalId: followed by the external ID.
Parameter clientToken :
A unique case-sensitive identifier that you can provide to ensure the
idempotency of the request. Don't reuse this client token if a new
idempotent request is required.
Implementation
Future<DeleteAssetModelInterfaceRelationshipResponse>
deleteAssetModelInterfaceRelationship({
required String assetModelId,
required String interfaceAssetModelId,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/asset-models/${Uri.encodeComponent(assetModelId)}/interface/${Uri.encodeComponent(interfaceAssetModelId)}/asset-model-interface-relationship',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeleteAssetModelInterfaceRelationshipResponse.fromJson(response);
}