IoTTwinMaker class
IoT TwinMaker is a service with which you can build operational digital twins of physical systems. IoT TwinMaker overlays measurements and analysis from real-world sensors, cameras, and enterprise applications so you can create data visualizations to monitor your physical factory, building, or industrial plant. You can use this real-world data to monitor operations and diagnose and repair errors.
Constructors
- IoTTwinMaker({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchPutPropertyValues(
{required List< PropertyValueEntry> entries, required String workspaceId}) → Future<BatchPutPropertyValuesResponse> - Sets values for multiple time series properties.
-
cancelMetadataTransferJob(
{required String metadataTransferJobId}) → Future< CancelMetadataTransferJobResponse> - Cancels the metadata transfer job.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createComponentType(
{required String componentTypeId, required String workspaceId, String? componentTypeName, Map< String, CompositeComponentTypeRequest> ? compositeComponentTypes, String? description, List<String> ? extendsFrom, Map<String, FunctionRequest> ? functions, bool? isSingleton, Map<String, PropertyDefinitionRequest> ? propertyDefinitions, Map<String, PropertyGroupRequest> ? propertyGroups, Map<String, String> ? tags}) → Future<CreateComponentTypeResponse> - Creates a component type.
-
createEntity(
{required String entityName, required String workspaceId, Map< String, ComponentRequest> ? components, Map<String, CompositeComponentRequest> ? compositeComponents, String? description, String? entityId, String? parentEntityId, Map<String, String> ? tags}) → Future<CreateEntityResponse> - Creates an entity.
-
createMetadataTransferJob(
{required DestinationConfiguration destination, required List< SourceConfiguration> sources, String? description, String? metadataTransferJobId}) → Future<CreateMetadataTransferJobResponse> - Creates a new metadata transfer job.
-
createScene(
{required String contentLocation, required String sceneId, required String workspaceId, List< String> ? capabilities, String? description, Map<String, String> ? sceneMetadata, Map<String, String> ? tags}) → Future<CreateSceneResponse> - Creates a scene.
-
createSyncJob(
{required String syncRole, required String syncSource, required String workspaceId, Map< String, String> ? tags}) → Future<CreateSyncJobResponse> - This action creates a SyncJob.
-
createWorkspace(
{required String workspaceId, String? description, String? role, String? s3Location, Map< String, String> ? tags}) → Future<CreateWorkspaceResponse> - Creates a workplace.
-
deleteComponentType(
{required String componentTypeId, required String workspaceId}) → Future< DeleteComponentTypeResponse> - Deletes a component type.
-
deleteEntity(
{required String entityId, required String workspaceId, bool? isRecursive}) → Future< DeleteEntityResponse> - Deletes an entity.
-
deleteScene(
{required String sceneId, required String workspaceId}) → Future< void> - Deletes a scene.
-
deleteSyncJob(
{required String syncSource, required String workspaceId}) → Future< DeleteSyncJobResponse> - Delete the SyncJob.
-
deleteWorkspace(
{required String workspaceId}) → Future< DeleteWorkspaceResponse> - Deletes a workspace.
-
executeQuery(
{required String queryStatement, required String workspaceId, int? maxResults, String? nextToken}) → Future< ExecuteQueryResponse> - Run queries to access information from your knowledge graph of entities within individual workspaces.
-
getComponentType(
{required String componentTypeId, required String workspaceId}) → Future< GetComponentTypeResponse> - Retrieves information about a component type.
-
getEntity(
{required String entityId, required String workspaceId}) → Future< GetEntityResponse> - Retrieves information about an entity.
-
getMetadataTransferJob(
{required String metadataTransferJobId}) → Future< GetMetadataTransferJobResponse> - Gets a nmetadata transfer job.
-
getPricingPlan(
) → Future< GetPricingPlanResponse> - Gets the pricing plan.
-
getPropertyValue(
{required List< String> selectedProperties, required String workspaceId, String? componentName, String? componentPath, String? componentTypeId, String? entityId, int? maxResults, String? nextToken, String? propertyGroupName, TabularConditions? tabularConditions}) → Future<GetPropertyValueResponse> - Gets the property values for a component, component type, entity, or workspace.
-
getPropertyValueHistory(
{required List< String> selectedProperties, required String workspaceId, String? componentName, String? componentPath, String? componentTypeId, DateTime? endDateTime, String? endTime, String? entityId, InterpolationParameters? interpolation, int? maxResults, String? nextToken, OrderByTime? orderByTime, List<PropertyFilter> ? propertyFilters, DateTime? startDateTime, String? startTime}) → Future<GetPropertyValueHistoryResponse> - Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
getScene(
{required String sceneId, required String workspaceId}) → Future< GetSceneResponse> - Retrieves information about a scene.
-
getSyncJob(
{required String syncSource, String? workspaceId}) → Future< GetSyncJobResponse> - Gets the SyncJob.
-
getWorkspace(
{required String workspaceId}) → Future< GetWorkspaceResponse> - Retrieves information about a workspace.
-
listComponents(
{required String entityId, required String workspaceId, String? componentPath, int? maxResults, String? nextToken}) → Future< ListComponentsResponse> - This API lists the components of an entity.
-
listComponentTypes(
{required String workspaceId, List< ListComponentTypesFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListComponentTypesResponse> - Lists all component types in a workspace.
-
listEntities(
{required String workspaceId, List< ListEntitiesFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListEntitiesResponse> - Lists all entities in a workspace.
-
listMetadataTransferJobs(
{required DestinationType destinationType, required SourceType sourceType, List< ListMetadataTransferJobsFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListMetadataTransferJobsResponse> - Lists the metadata transfer jobs.
-
listProperties(
{required String entityId, required String workspaceId, String? componentName, String? componentPath, int? maxResults, String? nextToken}) → Future< ListPropertiesResponse> - This API lists the properties of a component.
-
listScenes(
{required String workspaceId, int? maxResults, String? nextToken}) → Future< ListScenesResponse> - Lists all scenes in a workspace.
-
listSyncJobs(
{required String workspaceId, int? maxResults, String? nextToken}) → Future< ListSyncJobsResponse> - List all SyncJobs.
-
listSyncResources(
{required String syncSource, required String workspaceId, List< SyncResourceFilter> ? filters, int? maxResults, String? nextToken}) → Future<ListSyncResourcesResponse> - Lists the sync resources.
-
listTagsForResource(
{required String resourceARN, int? maxResults, String? nextToken}) → Future< ListTagsForResourceResponse> - Lists all tags associated with a resource.
-
listWorkspaces(
{int? maxResults, String? nextToken}) → Future< ListWorkspacesResponse> - Retrieves information about workspaces in the current account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceARN, required Map< String, String> tags}) → Future<void> - Adds tags to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> - Removes tags from a resource.
-
updateComponentType(
{required String componentTypeId, required String workspaceId, String? componentTypeName, Map< String, CompositeComponentTypeRequest> ? compositeComponentTypes, String? description, List<String> ? extendsFrom, Map<String, FunctionRequest> ? functions, bool? isSingleton, Map<String, PropertyDefinitionRequest> ? propertyDefinitions, Map<String, PropertyGroupRequest> ? propertyGroups}) → Future<UpdateComponentTypeResponse> - Updates information in a component type.
-
updateEntity(
{required String entityId, required String workspaceId, Map< String, ComponentUpdateRequest> ? componentUpdates, Map<String, CompositeComponentUpdateRequest> ? compositeComponentUpdates, String? description, String? entityName, ParentEntityUpdateRequest? parentEntityUpdate}) → Future<UpdateEntityResponse> - Updates an entity.
-
updatePricingPlan(
{required PricingMode pricingMode, List< String> ? bundleNames}) → Future<UpdatePricingPlanResponse> - Update the pricing plan.
-
updateScene(
{required String sceneId, required String workspaceId, List< String> ? capabilities, String? contentLocation, String? description, Map<String, String> ? sceneMetadata}) → Future<UpdateSceneResponse> - Updates a scene.
-
updateWorkspace(
{required String workspaceId, String? description, String? role, String? s3Location}) → Future< UpdateWorkspaceResponse> - Updates a workspace.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited