associateAwsAccountWithPartnerAccount method
Associates a partner account with your AWS account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sidewalk :
The Sidewalk account credentials.
Parameter clientRequestToken :
Each resource must have a unique client request token. The client token is
used to implement idempotency. It ensures that the request completes no
more than one time. If you retry a request with the same token and the
same parameters, the request will complete successfully. However, if you
try to create a new resource using the same token but different
parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs
will automatically generate a unique client request. For more information
about idempotency, see Ensuring
idempotency in Amazon EC2 API requests.
Parameter tags :
The tags to attach to the specified resource. Tags are metadata that you
can use to manage a resource.
Implementation
Future<AssociateAwsAccountWithPartnerAccountResponse>
associateAwsAccountWithPartnerAccount({
required SidewalkAccountInfo sidewalk,
String? clientRequestToken,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'Sidewalk': sidewalk,
'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/partner-accounts',
exceptionFnMap: _exceptionFns,
);
return AssociateAwsAccountWithPartnerAccountResponse.fromJson(response);
}