createMulticastGroup method
Creates a multicast group.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clientRequestToken :
Each resource must have a unique client request token. The client token is
used to implement idempotency. It ensures that the request completes no
more than one time. If you retry a request with the same token and the
same parameters, the request will complete successfully. However, if you
try to create a new resource using the same token but different
parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs
will automatically generate a unique client request. For more information
about idempotency, see Ensuring
idempotency in Amazon EC2 API requests.
Parameter description :
The description of the multicast group.
Implementation
Future<CreateMulticastGroupResponse> createMulticastGroup({
required LoRaWANMulticast loRaWAN,
String? clientRequestToken,
String? description,
String? name,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'LoRaWAN': loRaWAN,
'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (name != null) 'Name': name,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/multicast-groups',
exceptionFnMap: _exceptionFns,
);
return CreateMulticastGroupResponse.fromJson(response);
}