createNetworkAnalyzerConfiguration method
Creates a new network analyzer configuration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter multicastGroups :
Multicast Group resources to add to the network analyzer configruation.
Provide the MulticastGroupId of the resource to add in the
input array.
Parameter wirelessDevices :
Wireless device resources to add to the network analyzer configuration.
Provide the WirelessDeviceId of the resource to add in the
input array.
Parameter wirelessGateways :
Wireless gateway resources to add to the network analyzer configuration.
Provide the WirelessGatewayId of the resource to add in the
input array.
Implementation
Future<CreateNetworkAnalyzerConfigurationResponse>
createNetworkAnalyzerConfiguration({
required String name,
String? clientRequestToken,
String? description,
List<String>? multicastGroups,
List<Tag>? tags,
TraceContent? traceContent,
List<String>? wirelessDevices,
List<String>? wirelessGateways,
}) async {
final $payload = <String, dynamic>{
'Name': name,
'ClientRequestToken': clientRequestToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (multicastGroups != null) 'MulticastGroups': multicastGroups,
if (tags != null) 'Tags': tags,
if (traceContent != null) 'TraceContent': traceContent,
if (wirelessDevices != null) 'WirelessDevices': wirelessDevices,
if (wirelessGateways != null) 'WirelessGateways': wirelessGateways,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-analyzer-configurations',
exceptionFnMap: _exceptionFns,
);
return CreateNetworkAnalyzerConfigurationResponse.fromJson(response);
}