listPositionConfigurations method
List position configurations for a given resource, such as positioning solvers.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nextToken :
To retrieve the next set of results, the nextToken value from
a previous response; otherwise null to receive the first set of
results.
Parameter resourceType :
Resource type for which position configurations are listed.
Implementation
Future<ListPositionConfigurationsResponse> listPositionConfigurations({
int? maxResults,
String? nextToken,
PositionResourceType? resourceType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (resourceType != null) 'resourceType': [resourceType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/position-configurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListPositionConfigurationsResponse.fromJson(response);
}