listWirelessDevices method
Lists the wireless devices registered to your AWS account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter destinationName :
A filter to list only the wireless devices that use as uplink destination.
Parameter deviceProfileId :
A filter to list only the wireless devices that use this device profile.
Parameter maxResults :
The maximum number of results to return in this operation.
Parameter nextToken :
To retrieve the next set of results, the nextToken value from
a previous response; otherwise null to receive the first set of
results.
Parameter serviceProfileId :
A filter to list only the wireless devices that use this service profile.
Parameter wirelessDeviceType :
A filter to list only the wireless devices that use this wireless device
type.
Implementation
Future<ListWirelessDevicesResponse> listWirelessDevices({
String? destinationName,
String? deviceProfileId,
String? fuotaTaskId,
int? maxResults,
String? multicastGroupId,
String? nextToken,
String? serviceProfileId,
WirelessDeviceType? wirelessDeviceType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
250,
);
final $query = <String, List<String>>{
if (destinationName != null) 'destinationName': [destinationName],
if (deviceProfileId != null) 'deviceProfileId': [deviceProfileId],
if (fuotaTaskId != null) 'fuotaTaskId': [fuotaTaskId],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (multicastGroupId != null) 'multicastGroupId': [multicastGroupId],
if (nextToken != null) 'nextToken': [nextToken],
if (serviceProfileId != null) 'serviceProfileId': [serviceProfileId],
if (wirelessDeviceType != null)
'wirelessDeviceType': [wirelessDeviceType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/wireless-devices',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListWirelessDevicesResponse.fromJson(response);
}