listWirelessGatewayTaskDefinitions method
List the wireless gateway tasks definitions registered to your AWS account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return in this operation.
Parameter nextToken :
To retrieve the next set of results, the nextToken value from
a previous response; otherwise null to receive the first set of
results.
Parameter taskDefinitionType :
A filter to list only the wireless gateway task definitions that use this
task definition type.
Implementation
Future<ListWirelessGatewayTaskDefinitionsResponse>
listWirelessGatewayTaskDefinitions({
int? maxResults,
String? nextToken,
WirelessGatewayTaskDefinitionType? taskDefinitionType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
250,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (taskDefinitionType != null)
'taskDefinitionType': [taskDefinitionType.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/wireless-gateway-task-definitions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListWirelessGatewayTaskDefinitionsResponse.fromJson(response);
}