updatePosition method
Update the position information of a resource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter position :
The position information of the resource.
Parameter resourceIdentifier :
Resource identifier of the resource for which position is updated.
Parameter resourceType :
Resource type of the resource for which position is updated.
Implementation
Future<void> updatePosition({
required List<double> position,
required String resourceIdentifier,
required PositionResourceType resourceType,
}) async {
final $query = <String, List<String>>{
'resourceType': [resourceType.value],
};
final $payload = <String, dynamic>{
'Position': position,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/positions/${Uri.encodeComponent(resourceIdentifier)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}