createAdConfiguration method
Creates a new ad configuration to be used for server-side ad insertion.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw PendingVerification.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter mediaTailorPlaybackConfigurations :
List of integration configurations with MediaTailor resources. The first
item in the list is the default playback configuration used for the ad
configuration. To select a different configuration per viewing session,
see Generate
and Sign IVS Playback Tokens.
Parameter name :
Ad configuration name. Defaults to “”.
Parameter tags :
Array of 1-50 maps, each of the form string:string
(key:value). See Best
practices and strategies in Tagging Amazon Web Services Resources
and Tag Editor for details, including restrictions that apply to tags
and "Tag naming limits and requirements"; Amazon IVS has no
service-specific constraints beyond what is documented there.
Implementation
Future<CreateAdConfigurationResponse> createAdConfiguration({
required List<MediaTailorPlaybackConfiguration>
mediaTailorPlaybackConfigurations,
String? name,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'mediaTailorPlaybackConfigurations': mediaTailorPlaybackConfigurations,
if (name != null) 'name': name,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateAdConfiguration',
exceptionFnMap: _exceptionFns,
);
return CreateAdConfigurationResponse.fromJson(response);
}