tagResource method
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
ARN of the resource for which tags are to be added or updated. The ARN
must be URL-encoded.
Parameter tags :
Array of tags to be added or updated. Array of maps, each of the form
string:string (key:value). See Best
practices and strategies in Tagging Amazon Web Services Resources
and Tag Editor for details, including restrictions that apply to tags
and "Tag naming limits and requirements"; Amazon IVS has no
service-specific constraints beyond what is documented there.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}