deletePublicKey method
Deletes the specified public key used to sign stage participant tokens. This invalidates future participant tokens generated using the key pair’s private key.
May throw AccessDeniedException.
May throw ConflictException.
May throw PendingVerification.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter arn :
ARN of the public key to be deleted.
Implementation
Future<void> deletePublicKey({
required String arn,
}) async {
final $payload = <String, dynamic>{
'arn': arn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeletePublicKey',
exceptionFnMap: _exceptionFns,
);
}