importPublicKey method
Import a public key to be used for signing stage participant tokens.
May throw AccessDeniedException.
May throw ConflictException.
May throw PendingVerification.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter publicKeyMaterial :
The content of the public key to be imported.
Parameter name :
Name of the public key to be imported.
Parameter tags :
Tags attached to the resource. Array of maps, each of the form
string:string (key:value). See Best
practices and strategies in Tagging AWS Resources and Tag
Editor for details, including restrictions that apply to tags and "Tag
naming limits and requirements"; Amazon IVS has no constraints on tags
beyond what is documented there.
Implementation
Future<ImportPublicKeyResponse> importPublicKey({
required String publicKeyMaterial,
String? name,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'publicKeyMaterial': publicKeyMaterial,
if (name != null) 'name': name,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ImportPublicKey',
exceptionFnMap: _exceptionFns,
);
return ImportPublicKeyResponse.fromJson(response);
}