listParticipantReplicas method
Lists all the replicas for a participant from a source stage.
May throw AccessDeniedException.
May throw ValidationException.
Parameter participantId :
Participant ID of the publisher that has been replicated. This is assigned
by IVS and returned by CreateParticipantToken or the
jti (JWT ID) used to create
a self signed token.
Parameter sourceStageArn :
ARN of the stage where the participant is publishing.
Parameter maxResults :
Maximum number of results to return. Default: 50.
Parameter nextToken :
The first participant to retrieve. This is used for pagination; see the
nextToken response field.
Implementation
Future<ListParticipantReplicasResponse> listParticipantReplicas({
required String participantId,
required String sourceStageArn,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
'participantId': participantId,
'sourceStageArn': sourceStageArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListParticipantReplicas',
exceptionFnMap: _exceptionFns,
);
return ListParticipantReplicasResponse.fromJson(response);
}