stopParticipantReplication method
Stops a replicated participant session.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter destinationStageArn :
ARN of the stage where the participant has been replicated.
Parameter participantId :
Participant ID of the publisher that has been replicated. This is assigned
by IVS and returned by CreateParticipantToken or the
jti (JWT ID) used to
create a self signed token.
Parameter sourceStageArn :
ARN of the stage where the participant is publishing.
Implementation
Future<StopParticipantReplicationResponse> stopParticipantReplication({
required String destinationStageArn,
required String participantId,
required String sourceStageArn,
}) async {
final $payload = <String, dynamic>{
'destinationStageArn': destinationStageArn,
'participantId': participantId,
'sourceStageArn': sourceStageArn,
};
final response = await _protocol.sendRaw(
payload: $payload,
method: 'POST',
requestUri: '/StopParticipantReplication',
exceptionFnMap: _exceptionFns,
);
final $json = await _s.jsonFromResponse(response);
return StopParticipantReplicationResponse(
accessControlAllowOrigin: _s.extractHeaderStringValue(
response.headers, 'Access-Control-Allow-Origin'),
accessControlExposeHeaders: _s.extractHeaderStringValue(
response.headers, 'Access-Control-Expose-Headers'),
cacheControl:
_s.extractHeaderStringValue(response.headers, 'Cache-Control'),
contentSecurityPolicy: _s.extractHeaderStringValue(
response.headers, 'Content-Security-Policy'),
strictTransportSecurity: _s.extractHeaderStringValue(
response.headers, 'Strict-Transport-Security'),
xContentTypeOptions: _s.extractHeaderStringValue(
response.headers, 'X-Content-Type-Options'),
xFrameOptions:
_s.extractHeaderStringValue(response.headers, 'X-Frame-Options'),
);
}