Ivschat class
Introduction
The Amazon IVS Chat control-plane API enables you to create and manage Amazon IVS Chat resources. You also need to integrate with the Amazon IVS Chat Messaging API, to enable users to interact with chat rooms in real time.
The API is an AWS regional service. For a list of supported regions and Amazon IVS Chat HTTPS service endpoints, see the Amazon IVS Chat information on the Amazon IVS page in the AWS General Reference.
This document describes HTTP operations. There is a separate messaging API for managing Chat resources; see the Amazon IVS Chat Messaging API Reference.
Notes on terminology:
- You create service applications using the Amazon IVS Chat API. We refer to these as applications.
- You create front-end client applications (browser and Android/iOS apps) using the Amazon IVS Chat Messaging API. We refer to these as clients.
The following resources are part of Amazon IVS Chat:
- LoggingConfiguration — A configuration that allows customers to store and record sent messages in a chat room. See the Logging Configuration endpoints for more information.
- Room — The central Amazon IVS Chat resource through which clients connect to and exchange chat messages. See the Room endpoints for more information.
A tag is a metadata label that you assign to an AWS resource. A tag
comprises a key and a value, both set by you. For example, you
might set a tag as topic:nature to label a particular video
category. See Best
practices and strategies in Tagging Amazon Web Services Resources and
Tag Editor for details, including restrictions that apply to tags and
"Tag naming limits and requirements"; Amazon IVS Chat has no
service-specific constraints beyond what is documented there.
Tags can help you identify and organize your AWS resources. For example, you can use the same tag for different resources to indicate that they are related. You can also use tags to manage access (see Access Tags).
The Amazon IVS Chat API has these tag-related operations: TagResource, UntagResource, and ListTagsForResource. The following resource supports tagging: Room.
At most 50 tags can be applied to a resource.
API Access Security
Your Amazon IVS Chat applications (service applications and clients) must be authenticated and authorized to access Amazon IVS Chat resources. Note the differences between these concepts:
- Authentication is about verifying identity. Requests to the Amazon IVS Chat API must be signed to verify your identity.
- Authorization is about granting permissions. Your IAM roles need to have permissions for Amazon IVS Chat API requests.
Signing API Requests
HTTP API requests must be signed with an AWS SigV4 signature using your AWS security credentials. The AWS Command Line Interface (CLI) and the AWS SDKs take care of signing the underlying API calls for you. However, if your application calls the Amazon IVS Chat HTTP API directly, it’s your responsibility to sign the requests.
You generate a signature using valid AWS credentials for an IAM role that
has permission to perform the requested action. For example, DeleteMessage
requests must be made using an IAM role that has the
ivschat:DeleteMessage permission.
For more information:
- Authentication and generating signatures — See Authenticating Requests (Amazon Web Services Signature Version 4) in the Amazon Web Services General Reference.
- Managing Amazon IVS permissions — See Identity and Access Management on the Security page of the Amazon IVS User Guide.
ARNs uniquely identify AWS resources. An ARN is required when you need to specify a resource unambiguously across all of AWS, such as in IAM policies and API calls. For more information, see Amazon Resource Names in the AWS General Reference.
Constructors
- Ivschat({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createChatToken(
{required String roomIdentifier, required String userId, Map< String, String> ? attributes, List<ChatTokenCapability> ? capabilities, int? sessionDurationInMinutes}) → Future<CreateChatTokenResponse> - Creates an encrypted token that is used by a chat participant to establish an individual WebSocket chat connection to a room. When the token is used to connect to chat, the connection is valid for the session duration specified in the request. The token becomes invalid at the token-expiration timestamp included in the response.
-
createLoggingConfiguration(
{required DestinationConfiguration destinationConfiguration, String? name, Map< String, String> ? tags}) → Future<CreateLoggingConfigurationResponse> - Creates a logging configuration that allows clients to store and record sent messages.
-
createRoom(
{List< String> ? loggingConfigurationIdentifiers, int? maximumMessageLength, int? maximumMessageRatePerSecond, MessageReviewHandler? messageReviewHandler, String? name, Map<String, String> ? tags}) → Future<CreateRoomResponse> - Creates a room that allows clients to connect and pass messages.
-
deleteLoggingConfiguration(
{required String identifier}) → Future< void> - Deletes the specified logging configuration.
-
deleteMessage(
{required String id, required String roomIdentifier, String? reason}) → Future< DeleteMessageResponse> -
Sends an event to a specific room which directs clients to delete a
specific message; that is, unrender it from view and delete it from the
client’s chat history. This event’s
EventNameisaws:DELETE_MESSAGE. This replicates the DeleteMessage WebSocket operation in the Amazon IVS Chat Messaging API. -
deleteRoom(
{required String identifier}) → Future< void> - Deletes the specified room.
-
disconnectUser(
{required String roomIdentifier, required String userId, String? reason}) → Future< void> - Disconnects all connections using a specified user ID from a room. This replicates the DisconnectUser WebSocket operation in the Amazon IVS Chat Messaging API.
-
getLoggingConfiguration(
{required String identifier}) → Future< GetLoggingConfigurationResponse> - Gets the specified logging configuration.
-
getRoom(
{required String identifier}) → Future< GetRoomResponse> - Gets the specified room.
-
listLoggingConfigurations(
{int? maxResults, String? nextToken}) → Future< ListLoggingConfigurationsResponse> - Gets summary information about all your logging configurations in the AWS region where the API request is processed.
-
listRooms(
{String? loggingConfigurationIdentifier, int? maxResults, String? messageReviewHandlerUri, String? name, String? nextToken}) → Future< ListRoomsResponse> -
Gets summary information about all your rooms in the AWS region where the
API request is processed. Results are sorted in descending order of
updateTime. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Gets information about AWS tags for the specified ARN.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendEvent(
{required String eventName, required String roomIdentifier, Map< String, String> ? attributes}) → Future<SendEventResponse> - Sends an event to a room. Use this within your application’s business logic to send events to clients of a room; e.g., to notify clients to change the way the chat UI is rendered.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds or updates tags for the AWS resource with the specified ARN.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes tags from the resource with the specified ARN.
-
updateLoggingConfiguration(
{required String identifier, DestinationConfiguration? destinationConfiguration, String? name}) → Future< UpdateLoggingConfigurationResponse> - Updates a specified logging configuration.
-
updateRoom(
{required String identifier, List< String> ? loggingConfigurationIdentifiers, int? maximumMessageLength, int? maximumMessageRatePerSecond, MessageReviewHandler? messageReviewHandler, String? name}) → Future<UpdateRoomResponse> - Updates a room’s configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited