createLoggingConfiguration method
Creates a logging configuration that allows clients to store and record sent messages.
May throw AccessDeniedException.
May throw ConflictException.
May throw PendingVerification.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter destinationConfiguration :
A complex type that contains a destination configuration for where chat
content will be logged. There can be only one type of destination
(cloudWatchLogs, firehose, or s3)
in a destinationConfiguration.
Parameter name :
Logging-configuration name. The value does not need to be unique.
Parameter tags :
Tags to attach to the resource. Array of maps, each of the form
string:string (key:value). See Best
practices and strategies in Tagging Amazon Web Services Resources
and Tag Editor for details, including restrictions that apply to tags
and "Tag naming limits and requirements"; Amazon IVS Chat has no
constraints on tags beyond what is documented there.
Implementation
Future<CreateLoggingConfigurationResponse> createLoggingConfiguration({
required DestinationConfiguration destinationConfiguration,
String? name,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'destinationConfiguration': destinationConfiguration,
if (name != null) 'name': name,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateLoggingConfiguration',
exceptionFnMap: _exceptionFns,
);
return CreateLoggingConfigurationResponse.fromJson(response);
}