describeConfigurationRevision method
Returns a description of this revision of the configuration.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw UnauthorizedException.
Parameter arn :
The Amazon Resource Name (ARN) that uniquely identifies an MSK
configuration and all of its revisions.
Parameter revision :
A string that uniquely identifies a revision of an MSK configuration.
Implementation
Future<DescribeConfigurationRevisionResponse> describeConfigurationRevision({
required String arn,
required int revision,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/configurations/${Uri.encodeComponent(arn)}/revisions/${Uri.encodeComponent(revision.toString())}',
exceptionFnMap: _exceptionFns,
);
return DescribeConfigurationRevisionResponse.fromJson(response);
}