getBootstrapBrokers method
A list of brokers that a client application can use to bootstrap. This
list doesn't necessarily include all of the brokers in the cluster. The
following Python 3.6 example shows how you can use the Amazon Resource
Name (ARN) of a cluster to get its bootstrap brokers. If you don't know
the ARN of your cluster, you can use the ListClusters
operation to get the ARNs of all the clusters in this account and Region.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw UnauthorizedException.
Parameter clusterArn :
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
Implementation
Future<GetBootstrapBrokersResponse> getBootstrapBrokers({
required String clusterArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v1/clusters/${Uri.encodeComponent(clusterArn)}/bootstrap-brokers',
exceptionFnMap: _exceptionFns,
);
return GetBootstrapBrokersResponse.fromJson(response);
}