listReplicators method
Lists the replicators.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter maxResults :
The maximum number of results to return in the response. If there are more
results, the response includes a NextToken parameter.
Parameter nextToken :
If the response of ListReplicators is truncated, it returns a NextToken in
the response. This NextToken should be sent in the subsequent request to
ListReplicators.
Parameter replicatorNameFilter :
Returns replicators starting with given name.
Implementation
Future<ListReplicatorsResponse> listReplicators({
int? maxResults,
String? nextToken,
String? replicatorNameFilter,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (replicatorNameFilter != null)
'replicatorNameFilter': [replicatorNameFilter],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/replication/v1/replicators',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReplicatorsResponse.fromJson(response);
}