updateBrokerType method
Updates EC2 instance type.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter clusterArn :
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
Parameter currentVersion :
The cluster version that you want to change. After this operation
completes successfully, the cluster will have a new version.
Parameter targetInstanceType :
The Amazon MSK broker type that you want all of the brokers in this
cluster to be.
Implementation
Future<UpdateBrokerTypeResponse> updateBrokerType({
required String clusterArn,
required String currentVersion,
required String targetInstanceType,
}) async {
final $payload = <String, dynamic>{
'currentVersion': currentVersion,
'targetInstanceType': targetInstanceType,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/v1/clusters/${Uri.encodeComponent(clusterArn)}/nodes/type',
exceptionFnMap: _exceptionFns,
);
return UpdateBrokerTypeResponse.fromJson(response);
}