KafkaConnect class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
close ()
→ void
Closes the internal HTTP client if none was provided at creation.
If a client was passed as a constructor argument, this becomes a noop.
createConnector ({required Capacity capacity , required Map <String , String > connectorConfiguration , required String connectorName , required KafkaCluster kafkaCluster , required KafkaClusterClientAuthentication kafkaClusterClientAuthentication , required KafkaClusterEncryptionInTransit kafkaClusterEncryptionInTransit , required String kafkaConnectVersion , required List <Plugin > plugins , required String serviceExecutionRoleArn , String ? connectorDescription , LogDelivery? logDelivery , NetworkType? networkType , Map <String , String > ? tags , WorkerConfiguration? workerConfiguration })
→ Future <CreateConnectorResponse >
Creates a connector using the specified properties.
createCustomPlugin ({required CustomPluginContentType contentType , required CustomPluginLocation location , required String name , String ? description , Map <String , String > ? tags })
→ Future <CreateCustomPluginResponse >
Creates a custom plugin using the specified properties.
createWorkerConfiguration ({required String name , required String propertiesFileContent , String ? description , Map <String , String > ? tags })
→ Future <CreateWorkerConfigurationResponse >
Creates a worker configuration using the specified properties.
deleteConnector ({required String connectorArn , String ? currentVersion })
→ Future <DeleteConnectorResponse >
Deletes the specified connector.
deleteCustomPlugin ({required String customPluginArn })
→ Future <DeleteCustomPluginResponse >
Deletes a custom plugin.
deleteWorkerConfiguration ({required String workerConfigurationArn })
→ Future <DeleteWorkerConfigurationResponse >
Deletes the specified worker configuration.
describeConnector ({required String connectorArn })
→ Future <DescribeConnectorResponse >
Returns summary information about the connector.
describeConnectorOperation ({required String connectorOperationArn })
→ Future <DescribeConnectorOperationResponse >
Returns information about the specified connector's operations.
describeCustomPlugin ({required String customPluginArn })
→ Future <DescribeCustomPluginResponse >
A summary description of the custom plugin.
describeWorkerConfiguration ({required String workerConfigurationArn })
→ Future <DescribeWorkerConfigurationResponse >
Returns information about a worker configuration.
listConnectorOperations ({required String connectorArn , int ? maxResults , String ? nextToken })
→ Future <ListConnectorOperationsResponse >
Lists information about a connector's operation(s).
listConnectors ({String ? connectorNamePrefix , int ? maxResults , String ? nextToken })
→ Future <ListConnectorsResponse >
Returns a list of all the connectors in this account and Region. The list
is limited to connectors whose name starts with the specified prefix. The
response also includes a description of each of the listed connectors.
listCustomPlugins ({int ? maxResults , String ? namePrefix , String ? nextToken })
→ Future <ListCustomPluginsResponse >
Returns a list of all of the custom plugins in this account and Region.
listTagsForResource ({required String resourceArn })
→ Future <ListTagsForResourceResponse >
Lists all the tags attached to the specified resource.
listWorkerConfigurations ({int ? maxResults , String ? namePrefix , String ? nextToken })
→ Future <ListWorkerConfigurationsResponse >
Returns a list of all of the worker configurations in this account and
Region.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagResource ({required String resourceArn , required Map <String , String > tags })
→ Future <void >
Attaches tags to the specified resource.
toString ()
→ String
A string representation of this object.
inherited
untagResource ({required String resourceArn , required List <String > tagKeys })
→ Future <void >
Removes tags from the specified resource.
updateConnector ({required String connectorArn , required String currentVersion , CapacityUpdate? capacity , Map <String , String > ? connectorConfiguration })
→ Future <UpdateConnectorResponse >
Updates the specified connector. For request body, specify only one
parameter: either capacity or
connectorConfiguration.