listCustomPlugins method
Returns a list of all of the custom plugins in this account and Region.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
May throw UnauthorizedException.
Parameter maxResults :
The maximum number of custom plugins to list in one response.
Parameter namePrefix :
Lists custom plugin names that start with the specified text string.
Parameter nextToken :
If the response of a ListCustomPlugins operation is truncated, it will
include a NextToken. Send this NextToken in a subsequent request to
continue listing from where the previous operation left off.
Implementation
Future<ListCustomPluginsResponse> listCustomPlugins({
int? maxResults,
String? namePrefix,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (namePrefix != null) 'namePrefix': [namePrefix],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/custom-plugins',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCustomPluginsResponse.fromJson(response);
}