createIndex method
- required String name,
- required String roleArn,
- String? clientToken,
- String? description,
- IndexEdition? edition,
- ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration,
- List<
Tag> ? tags, - UserContextPolicy? userContextPolicy,
- UserGroupResolutionConfiguration? userGroupResolutionConfiguration,
- List<
UserTokenConfiguration> ? userTokenConfigurations,
Creates an Amazon Kendra index. Index creation is an asynchronous API. To
determine if index creation has completed, check the Status
field returned from a call to DescribeIndex. The
Status field is set to ACTIVE when the index is
ready to use.
Once the index is active, you can index your documents using the
BatchPutDocument API or using one of the supported data
sources.
For an example of creating an index and data source using the Python SDK, see Getting started with Python SDK. For an example of creating an index and data source using the Java SDK, see Getting started with Java SDK.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceAlreadyExistException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
A name for the index.
Parameter roleArn :
The Amazon Resource Name (ARN) of an IAM role with permission to access
your Amazon CloudWatch logs and metrics. For more information, see IAM
access roles for Amazon Kendra.
Parameter clientToken :
A token that you provide to identify the request to create an index.
Multiple calls to the CreateIndex API with the same client
token will create only one index.
Parameter description :
A description for the index.
Parameter edition :
The Amazon Kendra edition to use for the index. Choose
DEVELOPER_EDITION for indexes intended for development,
testing, or proof of concept. Use ENTERPRISE_EDITION for
production. Use GEN_AI_ENTERPRISE_EDITION for creating
generative AI applications. Once you set the edition for an index, it
can't be changed.
The Edition parameter is optional. If you don't supply a
value, the default is ENTERPRISE_EDITION.
For more information on quota limits for Gen AI Enterprise Edition, Enterprise Edition, and Developer Edition indices, see Quotas.
Parameter serverSideEncryptionConfiguration :
The identifier of the KMS customer managed key (CMK) that's used to
encrypt data indexed by Amazon Kendra. Amazon Kendra doesn't support
asymmetric CMKs.
Parameter tags :
A list of key-value pairs that identify or categorize the index. You can
also use tags to help control access to the index. Tag keys and values can
consist of Unicode letters, digits, white space, and any of the following
symbols: _ . : / = + - @.
Parameter userContextPolicy :
The user context policy.
- ATTRIBUTE_FILTER
-
All indexed content is searchable and displayable for all users. If you
want to filter search results on user context, you can use the attribute
filters of
_user_idand_group_idsor you can provide user and group information inUserContext. - USER_TOKEN
- Enables token-based user access control to filter search results on user context. All documents with no access control and all documents accessible to the user will be searchable and displayable.
Parameter userGroupResolutionConfiguration :
Gets users and groups from IAM Identity Center identity source. To
configure this, see UserGroupResolutionConfiguration.
This is useful for user context filtering, where search results are
filtered based on the user or their group access to documents.
Parameter userTokenConfigurations :
The user token configuration.
Implementation
Future<CreateIndexResponse> createIndex({
required String name,
required String roleArn,
String? clientToken,
String? description,
IndexEdition? edition,
ServerSideEncryptionConfiguration? serverSideEncryptionConfiguration,
List<Tag>? tags,
UserContextPolicy? userContextPolicy,
UserGroupResolutionConfiguration? userGroupResolutionConfiguration,
List<UserTokenConfiguration>? userTokenConfigurations,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.CreateIndex'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'RoleArn': roleArn,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (description != null) 'Description': description,
if (edition != null) 'Edition': edition.value,
if (serverSideEncryptionConfiguration != null)
'ServerSideEncryptionConfiguration':
serverSideEncryptionConfiguration,
if (tags != null) 'Tags': tags,
if (userContextPolicy != null)
'UserContextPolicy': userContextPolicy.value,
if (userGroupResolutionConfiguration != null)
'UserGroupResolutionConfiguration': userGroupResolutionConfiguration,
if (userTokenConfigurations != null)
'UserTokenConfigurations': userTokenConfigurations,
},
);
return CreateIndexResponse.fromJson(jsonResponse.body);
}