describeDataSource method
Gets information about an Amazon Kendra data source connector.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The identifier of the data source connector.
Parameter indexId :
The identifier of the index used with the data source connector.
Implementation
Future<DescribeDataSourceResponse> describeDataSource({
required String id,
required String indexId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.DescribeDataSource'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'IndexId': indexId,
},
);
return DescribeDataSourceResponse.fromJson(jsonResponse.body);
}