describeFeaturedResultsSet method
Gets information about a set of featured results. Features results are placed above all other results for certain queries. If there's an exact match of a query, then one or more specific documents are featured in the search results.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter featuredResultsSetId :
The identifier of the set of featured results that you want to get
information on.
Parameter indexId :
The identifier of the index used for featuring results.
Implementation
Future<DescribeFeaturedResultsSetResponse> describeFeaturedResultsSet({
required String featuredResultsSetId,
required String indexId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.DescribeFeaturedResultsSet'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FeaturedResultsSetId': featuredResultsSetId,
'IndexId': indexId,
},
);
return DescribeFeaturedResultsSetResponse.fromJson(jsonResponse.body);
}