describeQuerySuggestionsConfig method
Future<DescribeQuerySuggestionsConfigResponse>
describeQuerySuggestionsConfig({
- required String indexId,
Gets information on the settings of query suggestions for an index.
This is used to check the current settings applied to query suggestions.
DescribeQuerySuggestionsConfig is currently not supported in
the Amazon Web Services GovCloud (US-West) region.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter indexId :
The identifier of the index with query suggestions that you want to get
information on.
Implementation
Future<DescribeQuerySuggestionsConfigResponse>
describeQuerySuggestionsConfig({
required String indexId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSKendraFrontendService.DescribeQuerySuggestionsConfig'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'IndexId': indexId,
},
);
return DescribeQuerySuggestionsConfigResponse.fromJson(jsonResponse.body);
}