KendraRanking class
Amazon Kendra Intelligent Ranking uses Amazon Kendra semantic search capabilities to intelligently re-rank a search service's results.
Constructors
- KendraRanking({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createRescoreExecutionPlan(
{required String name, CapacityUnitsConfiguration? capacityUnits, String? clientToken, String? description, List< Tag> ? tags}) → Future<CreateRescoreExecutionPlanResponse> -
Creates a rescore execution plan. A rescore execution plan is an Amazon
Kendra Intelligent Ranking resource used for provisioning the
RescoreAPI. You set the number of capacity units that you require for Amazon Kendra Intelligent Ranking to rescore or re-rank a search service's results. -
deleteRescoreExecutionPlan(
{required String id}) → Future< void> -
Deletes a rescore execution plan. A rescore execution plan is an Amazon
Kendra Intelligent Ranking resource used for provisioning the
RescoreAPI. -
describeRescoreExecutionPlan(
{required String id}) → Future< DescribeRescoreExecutionPlanResponse> -
Gets information about a rescore execution plan. A rescore execution plan
is an Amazon Kendra Intelligent Ranking resource used for provisioning the
RescoreAPI. -
listRescoreExecutionPlans(
{int? maxResults, String? nextToken}) → Future< ListRescoreExecutionPlansResponse> -
Lists your rescore execution plans. A rescore execution plan is an Amazon
Kendra Intelligent Ranking resource used for provisioning the
RescoreAPI. -
listTagsForResource(
{required String resourceARN}) → Future< ListTagsForResourceResponse> - Gets a list of tags associated with a specified resource. A rescore execution plan is an example of a resource that can have tags associated with it.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rescore(
{required List< Document> documents, required String rescoreExecutionPlanId, required String searchQuery}) → Future<RescoreResult> - Rescores or re-ranks search results from a search service such as OpenSearch (self managed). You use the semantic search capabilities of Amazon Kendra Intelligent Ranking to improve the search service's results.
-
tagResource(
{required String resourceARN, required List< Tag> tags}) → Future<void> -
Adds a specified tag to a specified rescore execution plan. A rescore
execution plan is an Amazon Kendra Intelligent Ranking resource used for
provisioning the
RescoreAPI. If the tag already exists, the existing value is replaced with the new value. -
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceARN, required List< String> tagKeys}) → Future<void> -
Removes a tag from a rescore execution plan. A rescore execution plan is
an Amazon Kendra Intelligent Ranking resource used for provisioning the
Rescoreoperation. -
updateRescoreExecutionPlan(
{required String id, CapacityUnitsConfiguration? capacityUnits, String? description, String? name}) → Future< void> -
Updates a rescore execution plan. A rescore execution plan is an Amazon
Kendra Intelligent Ranking resource used for provisioning the
RescoreAPI. You can update the number of capacity units you require for Amazon Kendra Intelligent Ranking to rescore or re-rank a search service's results.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited