createTable method
- required String keyspaceName,
- required SchemaDefinition schemaDefinition,
- required String tableName,
- AutoScalingSpecification? autoScalingSpecification,
- CapacitySpecification? capacitySpecification,
- CdcSpecification? cdcSpecification,
- ClientSideTimestamps? clientSideTimestamps,
- Comment? comment,
- int? defaultTimeToLive,
- EncryptionSpecification? encryptionSpecification,
- PointInTimeRecovery? pointInTimeRecovery,
- List<
ReplicaSpecification> ? replicaSpecifications, - List<
Tag> ? tags, - TimeToLive? ttl,
- WarmThroughputSpecification? warmThroughputSpecification,
The CreateTable operation adds a new table to the specified
keyspace. Within a keyspace, table names must be unique.
CreateTable is an asynchronous operation. When the request is
received, the status of the table is set to CREATING. You can
monitor the creation status of the new table by using the
GetTable operation, which returns the current
status of the table. You can start using a table when the
status is ACTIVE.
For more information, see Create a table in the Amazon Keyspaces Developer Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter keyspaceName :
The name of the keyspace that the table is going to be created in.
Parameter schemaDefinition :
The schemaDefinition consists of the following parameters.
For each column to be created:
-
name- The name of the column. -
type- An Amazon Keyspaces data type. For more information, see Data types in the Amazon Keyspaces Developer Guide.
-
partitionKeys- The partition key can be a single column, or it can be a compound value composed of two or more columns. The partition key portion of the primary key is required and determines how Amazon Keyspaces stores your data. -
name- The name of each partition key column. -
clusteringKeys- The optional clustering column portion of your primary key determines how the data is clustered and sorted within each partition. -
name- The name of the clustering column. -
orderBy- Sets the ascendant (ASC) or descendant (DESC) order modifier.To define a column as static use
staticColumns- Static columns store values that are shared by all rows in the same partition: -
name- The name of the column. -
type- An Amazon Keyspaces data type.
Parameter tableName :
The name of the table.
Parameter autoScalingSpecification :
The optional auto scaling settings for a table in provisioned capacity
mode. Specifies if the service can manage throughput capacity
automatically on your behalf.
Auto scaling helps you provision throughput capacity for variable workloads efficiently by increasing and decreasing your table's read and write capacity automatically in response to application traffic. For more information, see Managing throughput capacity automatically with Amazon Keyspaces auto scaling in the Amazon Keyspaces Developer Guide.
By default, auto scaling is disabled for a table.
Parameter capacitySpecification :
Specifies the read/write throughput capacity mode for the table. The
options are:
-
throughputMode:PAY_PER_REQUESTand -
throughputMode:PROVISIONED- Provisioned capacity mode requiresreadCapacityUnitsandwriteCapacityUnitsas input.
throughput_mode:PAY_PER_REQUEST.
For more information, see Read/write capacity modes in the Amazon Keyspaces Developer Guide.
Parameter cdcSpecification :
The CDC stream settings of the table.
Parameter clientSideTimestamps :
Enables client-side timestamps for the table. By default, the setting is
disabled. You can enable client-side timestamps with the following option:
-
status: "enabled"
Parameter comment :
This parameter allows to enter a description of the table.
Parameter defaultTimeToLive :
The default Time to Live setting in seconds for the table.
For more information, see Setting the default TTL value for a table in the Amazon Keyspaces Developer Guide.
Parameter encryptionSpecification :
Specifies how the encryption key for encryption at rest is managed for the
table. You can choose one of the following KMS key (KMS key):
-
type:AWS_OWNED_KMS_KEY- This key is owned by Amazon Keyspaces. -
type:CUSTOMER_MANAGED_KMS_KEY- This key is stored in your account and is created, owned, and managed by you. This option requires thekms_key_identifierof the KMS key in Amazon Resource Name (ARN) format as input.
type:AWS_OWNED_KMS_KEY.
For more information, see Encryption at rest in the Amazon Keyspaces Developer Guide.
Parameter pointInTimeRecovery :
Specifies if pointInTimeRecovery is enabled or disabled for
the table. The options are:
-
status=ENABLED -
status=DISABLED
status=DISABLED.
For more information, see Point-in-time recovery in the Amazon Keyspaces Developer Guide.
Parameter replicaSpecifications :
The optional Amazon Web Services Region specific settings of a
multi-Region table. These settings overwrite the general settings of the
table for the specified Region.
For a multi-Region table in provisioned capacity mode, you can configure the table's read capacity differently for each Region's replica. The write capacity, however, remains synchronized between all replicas to ensure that there's enough capacity to replicate writes across all Regions. To define the read capacity for a table replica in a specific Region, you can do so by configuring the following parameters.
-
region: The Region where these settings are applied. (Required) -
readCapacityUnits: The provisioned read capacity units. (Optional) -
readCapacityAutoScaling: The read capacity auto scaling settings for the table. (Optional)
Parameter tags :
A list of key-value pair tags to be attached to the resource.
For more information, see Adding tags and labels to Amazon Keyspaces resources in the Amazon Keyspaces Developer Guide.
Parameter ttl :
Enables Time to Live custom settings for the table. The options are:
-
status:enabled -
status:disabled
status:disabled. After ttl is
enabled, you can't disable it for the table.
For more information, see Expiring data by using Amazon Keyspaces Time to Live (TTL) in the Amazon Keyspaces Developer Guide.
Parameter warmThroughputSpecification :
Specifies the warm throughput settings for the table. Pre-warming a table
helps you avoid capacity exceeded exceptions by pre-provisioning read and
write capacity units to reduce cold start latency when your table receives
traffic.
For more information about pre-warming in Amazon Keyspaces, see Pre-warm a table in Amazon Keyspaces in the Amazon Keyspaces Developer Guide.
Implementation
Future<CreateTableResponse> createTable({
required String keyspaceName,
required SchemaDefinition schemaDefinition,
required String tableName,
AutoScalingSpecification? autoScalingSpecification,
CapacitySpecification? capacitySpecification,
CdcSpecification? cdcSpecification,
ClientSideTimestamps? clientSideTimestamps,
Comment? comment,
int? defaultTimeToLive,
EncryptionSpecification? encryptionSpecification,
PointInTimeRecovery? pointInTimeRecovery,
List<ReplicaSpecification>? replicaSpecifications,
List<Tag>? tags,
TimeToLive? ttl,
WarmThroughputSpecification? warmThroughputSpecification,
}) async {
_s.validateNumRange(
'defaultTimeToLive',
defaultTimeToLive,
0,
630720000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'KeyspacesService.CreateTable'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'keyspaceName': keyspaceName,
'schemaDefinition': schemaDefinition,
'tableName': tableName,
if (autoScalingSpecification != null)
'autoScalingSpecification': autoScalingSpecification,
if (capacitySpecification != null)
'capacitySpecification': capacitySpecification,
if (cdcSpecification != null) 'cdcSpecification': cdcSpecification,
if (clientSideTimestamps != null)
'clientSideTimestamps': clientSideTimestamps,
if (comment != null) 'comment': comment,
if (defaultTimeToLive != null) 'defaultTimeToLive': defaultTimeToLive,
if (encryptionSpecification != null)
'encryptionSpecification': encryptionSpecification,
if (pointInTimeRecovery != null)
'pointInTimeRecovery': pointInTimeRecovery,
if (replicaSpecifications != null)
'replicaSpecifications': replicaSpecifications,
if (tags != null) 'tags': tags,
if (ttl != null) 'ttl': ttl,
if (warmThroughputSpecification != null)
'warmThroughputSpecification': warmThroughputSpecification,
},
);
return CreateTableResponse.fromJson(jsonResponse.body);
}