getType method
The GetType operation returns information about the type, for
example the field definitions, the timestamp when the type was last
modified, the level of nesting, the status, and details about if the type
is used in other types and tables.
To read keyspace metadata using GetType, the IAM principal
needs Select action permissions for the system keyspace. To
configure the required permissions, see Permissions
to view a UDT in the Amazon Keyspaces Developer Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter keyspaceName :
The name of the keyspace that contains this type.
Parameter typeName :
The formatted name of the type. For example, if the name of the type was
created without double quotes, Amazon Keyspaces saved the name in
lower-case characters. If the name was created in double quotes, you must
use double quotes to specify the type name.
Implementation
Future<GetTypeResponse> getType({
required String keyspaceName,
required String typeName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'KeyspacesService.GetType'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'keyspaceName': keyspaceName,
'typeName': typeName,
},
);
return GetTypeResponse.fromJson(jsonResponse.body);
}