getRecords method
Retrieves data records from a specified shard in an Amazon Keyspaces data stream. This operation returns a collection of data records from the shard, including the primary key columns and information about modifications made to the captured table data. Each record represents a single data modification in the Amazon Keyspaces table and includes metadata about when the change occurred.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter shardIterator :
The unique identifier of the shard iterator. A shard iterator specifies
the position in the shard from which you want to start reading data
records sequentially. You obtain this value by calling the
GetShardIterator operation. Each shard iterator is valid for
15 minutes after creation.
Parameter maxResults :
The maximum number of records to return in a single
GetRecords request. The default value is 100. You can specify
a limit between 1 and 1000, but the actual number returned might be less
than the specified maximum if the size of the data for the returned
records exceeds the internal size limit.
Implementation
Future<GetRecordsOutput> getRecords({
required String shardIterator,
int? maxResults,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'KeyspacesStreams.GetRecords'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'shardIterator': shardIterator,
if (maxResults != null) 'maxResults': maxResults,
},
);
return GetRecordsOutput.fromJson(jsonResponse.body);
}