startStreamEncryption method
Enables or updates server-side encryption using an Amazon Web Services KMS
key for a specified stream.
Starting encryption is an asynchronous operation. Upon receiving the
request, Kinesis Data Streams returns immediately and sets the status of
the stream to UPDATING. After the update is complete, Kinesis
Data Streams sets the status of the stream back to ACTIVE.
Updating or applying encryption normally takes a few seconds to complete,
but it can take minutes. You can continue to read and write data to your
stream while its status is UPDATING. Once the status of the
stream is ACTIVE, encryption begins for records written to
the stream.
API Limits: You can successfully apply a new Amazon Web Services KMS key for server-side encryption 25 times in a rolling 24-hour period.
Note: It can take up to 5 seconds after the stream is in an
ACTIVE status before all records written to the stream are
encrypted. After you enable encryption, you can verify that encryption is
applied by inspecting the API response from PutRecord or
PutRecords.
May throw AccessDeniedException.
May throw InvalidArgumentException.
May throw KMSAccessDeniedException.
May throw KMSDisabledException.
May throw KMSInvalidStateException.
May throw KMSNotFoundException.
May throw KMSOptInRequired.
May throw KMSThrottlingException.
May throw LimitExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter encryptionType :
The encryption type to use. The only valid value is KMS.
Parameter keyId :
The GUID for the customer-managed Amazon Web Services KMS key to use for
encryption. This value can be a globally unique identifier, a fully
specified Amazon Resource Name (ARN) to either an alias or a key, or an
alias name prefixed by "alias/".You can also use a master key owned by
Kinesis Data Streams by specifying the alias aws/kinesis.
-
Key ARN example:
arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012 -
Alias ARN example:
arn:aws:kms:us-east-1:123456789012:alias/MyAliasName -
Globally unique key ID example:
12345678-1234-1234-1234-123456789012 -
Alias name example:
alias/MyAliasName -
Master key owned by Kinesis Data Streams:
alias/aws/kinesis
Parameter streamARN :
The ARN of the stream.
Parameter streamId :
Not Implemented. Reserved for future use.
Parameter streamName :
The name of the stream for which to start encrypting records.
Implementation
Future<void> startStreamEncryption({
required EncryptionType encryptionType,
required String keyId,
String? streamARN,
String? streamId,
String? streamName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Kinesis_20131202.StartStreamEncryption'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EncryptionType': encryptionType.value,
'KeyId': keyId,
if (streamARN != null) 'StreamARN': streamARN,
if (streamId != null) 'StreamId': streamId,
if (streamName != null) 'StreamName': streamName,
},
);
}