updateAccountSettings method
Future<UpdateAccountSettingsOutput>
updateAccountSettings({
- required MinimumThroughputBillingCommitmentInput minimumThroughputBillingCommitment,
Updates the account-level settings for Amazon Kinesis Data Streams.
Updating account settings is a synchronous operation. Upon receiving the request, Kinesis Data Streams will return immediately with your account’s updated settings.
API limits
- Certain account configurations have minimum commitment windows. Attempting to update your settings prior to the end of the minimum commitment window might have certain restrictions.
-
This API has a call limit of 5 transactions per second (TPS) for each
Amazon Web Services account. TPS over 5 will initiate the
LimitExceededException.
May throw InvalidArgumentException.
May throw LimitExceededException.
May throw ValidationException.
Parameter minimumThroughputBillingCommitment :
Specifies the minimum throughput billing commitment configuration for your
account.
Implementation
Future<UpdateAccountSettingsOutput> updateAccountSettings({
required MinimumThroughputBillingCommitmentInput
minimumThroughputBillingCommitment,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Kinesis_20131202.UpdateAccountSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MinimumThroughputBillingCommitment':
minimumThroughputBillingCommitment,
},
);
return UpdateAccountSettingsOutput.fromJson(jsonResponse.body);
}