Deletes a specified signaling channel. DeleteSignalingChannel
is an asynchronous operation. If you don't specify the channel's current
version, the most recent version is deleted.
Describes a stream’s edge configuration that was set using the
StartEdgeConfigurationUpdate API and the latest status of the
edge agent's recorder and uploader jobs. Use this API to get the status of
the configuration to determine if the configuration is in sync with the
Edge Agent. Use this API to evaluate the health of the Edge Agent.
Returns the most current information about the signaling channel. You must
specify either the name or the Amazon Resource Name (ARN) of the channel
that you want to describe.
Gets an endpoint for a specified stream for either reading or writing. Use
this endpoint in your application to read from the specified stream (using
the GetMedia or GetMediaForFragmentList
operations) or write to it (using the PutMedia operation).
In the request, specify the stream either by StreamName or
StreamARN.
Provides an endpoint for the specified signaling channel to send and
receive messages. This API uses the
SingleMasterChannelEndpointConfiguration input parameter,
which consists of the Protocols and Role
properties.
Returns an array of ChannelInfo objects. Each object
describes a signaling channel. To retrieve only those channels that
satisfy a specific condition, you can specify a
ChannelNameCondition.
Returns an array of StreamInfo objects. Each object describes
a stream. To retrieve only streams that satisfy a specific condition, you
can specify a StreamNameCondition.
An asynchronous API that updates a stream’s existing edge configuration.
The Kinesis Video Stream will sync the stream’s edge configuration with
the Edge Agent IoT Greengrass component that runs on an IoT Hub Device,
setup at your premise. The time to sync can vary and depends on the
connectivity of the Hub Device. The SyncStatus will be
updated as the edge configuration is acknowledged, and synced with the
Edge Agent.
Adds one or more tags to a signaling channel. A tag is a key-value
pair (the value is optional) that you can define and assign to Amazon Web
Services resources. If you specify a tag that already exists, the tag
value is replaced with the value that you specify in the request. For more
information, see Using
Cost Allocation Tags in the Billing and Cost Management and Cost
Management User Guide.
Adds one or more tags to a stream. A tag is a key-value pair (the
value is optional) that you can define and assign to Amazon Web Services
resources. If you specify a tag that already exists, the tag value is
replaced with the value that you specify in the request. For more
information, see Using
Cost Allocation Tags in the Billing and Cost Management and Cost
Management User Guide.
Removes one or more tags from a signaling channel. In the request, specify
only a tag key or keys; don't specify the value. If you specify a tag key
that does not exist, it's ignored.
Removes one or more tags from a stream. In the request, specify only a tag
key or keys; don't specify the value. If you specify a tag key that does
not exist, it's ignored.
Increases or decreases the stream's data retention period by the value
that you specify. To indicate whether you want to increase or decrease the
data retention period, specify the Operation parameter in the
request body. In the request, you must specify either the
StreamName or the StreamARN.