describeEdgeConfiguration method
Describes a stream’s edge configuration that was set using the
StartEdgeConfigurationUpdate API and the latest status of the
edge agent's recorder and uploader jobs. Use this API to get the status of
the configuration to determine if the configuration is in sync with the
Edge Agent. Use this API to evaluate the health of the Edge Agent.
May throw AccessDeniedException.
May throw ClientLimitExceededException.
May throw InvalidArgumentException.
May throw ResourceNotFoundException.
May throw StreamEdgeConfigurationNotFoundException.
Parameter streamARN :
The Amazon Resource Name (ARN) of the stream. Specify either the
StreamNameor the StreamARN.
Parameter streamName :
The name of the stream whose edge configuration you want to update.
Specify either the StreamName or the StreamARN.
Implementation
Future<DescribeEdgeConfigurationOutput> describeEdgeConfiguration({
String? streamARN,
String? streamName,
}) async {
final $payload = <String, dynamic>{
if (streamARN != null) 'StreamARN': streamARN,
if (streamName != null) 'StreamName': streamName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/describeEdgeConfiguration',
exceptionFnMap: _exceptionFns,
);
return DescribeEdgeConfigurationOutput.fromJson(response);
}