describeMappedResourceConfiguration method
Returns the most current information about the stream. The
streamName or streamARN should be provided in
the input.
May throw AccessDeniedException.
May throw ClientLimitExceededException.
May throw InvalidArgumentException.
May throw ResourceNotFoundException.
Parameter maxResults :
The maximum number of results to return in the response.
Parameter nextToken :
The token to provide in your next request, to get another batch of
results.
Parameter streamARN :
The Amazon Resource Name (ARN) of the stream.
Parameter streamName :
The name of the stream.
Implementation
Future<DescribeMappedResourceConfigurationOutput>
describeMappedResourceConfiguration({
int? maxResults,
String? nextToken,
String? streamARN,
String? streamName,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (streamARN != null) 'StreamARN': streamARN,
if (streamName != null) 'StreamName': streamName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/describeMappedResourceConfiguration',
exceptionFnMap: _exceptionFns,
);
return DescribeMappedResourceConfigurationOutput.fromJson(response);
}