updateMediaStorageConfiguration method
Future<void>
updateMediaStorageConfiguration({
- required String channelARN,
- required MediaStorageConfiguration mediaStorageConfiguration,
Associates a SignalingChannel to a stream to store the media.
There are two signaling modes that you can specify :
-
If
StorageStatusis enabled, the data will be stored in theStreamARNprovided. In order for WebRTC Ingestion to work, the stream must have data retention enabled. -
If
StorageStatusis disabled, no data will be stored, and theStreamARNparameter will not be needed.
May throw AccessDeniedException.
May throw ClientLimitExceededException.
May throw InvalidArgumentException.
May throw NoDataRetentionException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter channelARN :
The Amazon Resource Name (ARN) of the channel.
Parameter mediaStorageConfiguration :
A structure that encapsulates, or contains, the media storage
configuration properties.
Implementation
Future<void> updateMediaStorageConfiguration({
required String channelARN,
required MediaStorageConfiguration mediaStorageConfiguration,
}) async {
final $payload = <String, dynamic>{
'ChannelARN': channelARN,
'MediaStorageConfiguration': mediaStorageConfiguration,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/updateMediaStorageConfiguration',
exceptionFnMap: _exceptionFns,
);
}