updateNotificationConfiguration method
Updates the notification information for a stream.
May throw AccessDeniedException.
May throw ClientLimitExceededException.
May throw InvalidArgumentException.
May throw NoDataRetentionException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter notificationConfiguration :
The structure containing the information required for notifications. If
the structure is null, the configuration will be deleted from the stream.
Parameter streamARN :
The Amazon Resource Name (ARN) of the Kinesis video stream from where you
want to update the notification configuration. You must specify either the
StreamName or the StreamARN.
Parameter streamName :
The name of the stream from which to update the notification
configuration. You must specify either the StreamName or the
StreamARN.
Implementation
Future<void> updateNotificationConfiguration({
NotificationConfiguration? notificationConfiguration,
String? streamARN,
String? streamName,
}) async {
final $payload = <String, dynamic>{
if (notificationConfiguration != null)
'NotificationConfiguration': notificationConfiguration,
if (streamARN != null) 'StreamARN': streamARN,
if (streamName != null) 'StreamName': streamName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/updateNotificationConfiguration',
exceptionFnMap: _exceptionFns,
);
}