deleteAlias method
Deletes the specified alias. Because an alias is not a property of a KMS key, you can delete and change the aliases of a KMS key without affecting the KMS key. Also, aliases do not appear in the response from the DescribeKey operation. To get the aliases of all KMS keys, use the ListAliases operation.
Each KMS key can have multiple aliases. To change the alias of a KMS key, use DeleteAlias to delete the current alias and CreateAlias to create a new alias. To associate an existing alias with a different KMS key, call UpdateAlias.
Cross-account use: No. You cannot perform this operation on an alias in a different Amazon Web Services account.
Required permissions
- kms:DeleteAlias on the alias (IAM policy).
- kms:DeleteAlias on the KMS key (key policy).
Related operations:
Eventual consistency: The KMS API follows an eventual consistency model. For more information, see KMS eventual consistency.May throw DependencyTimeoutException.
May throw KMSInternalException.
May throw KMSInvalidStateException.
May throw NotFoundException.
Parameter aliasName :
The alias to be deleted. The alias name must begin with
alias/ followed by the alias name, such as
alias/ExampleAlias.
Implementation
Future<void> deleteAlias({
required String aliasName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.DeleteAlias'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AliasName': aliasName,
},
);
}