listRetirableGrants method
Returns information about all grants in the Amazon Web Services account and Region that have the specified retiring principal or retiring service principal.
You can specify any principal in your Amazon Web Services account. The grants that are returned include grants for KMS keys in your Amazon Web Services account and other Amazon Web Services accounts. You might use this operation to determine which grants you may retire. To retire a grant, use the RetireGrant operation.
For detailed information about grants, including grant terminology, see Grants in KMS in the Key Management Service Developer Guide . For examples of creating grants in several programming languages, see Use CreateGrant with an Amazon Web Services SDK or CLI.
Cross-account use: You must specify a principal in your Amazon Web
Services account. This operation returns a list of grants where the
retiring principal specified in the ListRetirableGrants
request is the same retiring principal on the grant. This can include
grants on KMS keys owned by other Amazon Web Services accounts, but you do
not need kms:ListRetirableGrants permission (or any other
additional permission) in any Amazon Web Services account other than your
own.
Required permissions: kms:ListRetirableGrants (IAM policy) in your Amazon Web Services account.
The RetiringServicePrincipal filter is only usable by callers
in a service principal.
Related operations:
May throw DependencyTimeoutException.
May throw InvalidArnException.
May throw InvalidMarkerException.
May throw KMSInternalException.
May throw NotFoundException.
Parameter limit :
Use this parameter to specify the maximum number of items to return. When
this value is present, KMS does not return more than the specified number
of items, but it might return fewer.
This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50.
Parameter marker :
Use this parameter in a subsequent request after you receive a response
with truncated results. Set it to the value of NextMarker
from the truncated response you just received.
Parameter retiringPrincipal :
The retiring principal for which to list grants. Enter a principal in your
Amazon Web Services account.
To specify the retiring principal, use the Amazon Resource Name (ARN) of an Amazon Web Services principal. Valid principals include Amazon Web Services accounts, IAM users, IAM roles, federated users, and assumed role users. For help with the ARN syntax for a principal, see IAM ARNs in the Identity and Access Management User Guide .
You must specify either RetiringPrincipal or
RetiringServicePrincipal, but not both.
Parameter retiringServicePrincipal :
The retiring service principal for which to list grants. This filter is
only usable by callers in a service principal.
You must specify either RetiringPrincipal or
RetiringServicePrincipal, but not both.
Implementation
Future<ListGrantsResponse> listRetirableGrants({
int? limit,
String? marker,
String? retiringPrincipal,
String? retiringServicePrincipal,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TrentService.ListRetirableGrants'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (limit != null) 'Limit': limit,
if (marker != null) 'Marker': marker,
if (retiringPrincipal != null) 'RetiringPrincipal': retiringPrincipal,
if (retiringServicePrincipal != null)
'RetiringServicePrincipal': retiringServicePrincipal,
},
);
return ListGrantsResponse.fromJson(jsonResponse.body);
}