deregisterResource method
Deregisters the resource as managed by the Data Catalog.
When you deregister a path, Lake Formation removes the path from the inline policy attached to your service-linked role.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw OperationTimeoutException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource that you want to
deregister.
Implementation
Future<void> deregisterResource({
required String resourceArn,
}) async {
final $payload = <String, dynamic>{
'ResourceArn': resourceArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeregisterResource',
exceptionFnMap: _exceptionFns,
);
}