getWorkUnits method
Retrieves the work units generated by the StartQueryPlanning
operation.
May throw AccessDeniedException.
May throw ExpiredException.
May throw InternalServiceException.
May throw InvalidInputException.
May throw WorkUnitsNotReadyYetException.
Parameter queryId :
The ID of the plan query operation.
Parameter nextToken :
A continuation token, if this is a continuation call.
Parameter pageSize :
The size of each page to get in the Amazon Web Services service call. This
does not affect the number of items returned in the command's output.
Setting a smaller page size results in more calls to the Amazon Web
Services service, retrieving fewer items in each call. This can help
prevent the Amazon Web Services service calls from timing out.
Implementation
Future<GetWorkUnitsResponse> getWorkUnits({
required String queryId,
String? nextToken,
int? pageSize,
}) async {
final $payload = <String, dynamic>{
'QueryId': queryId,
if (nextToken != null) 'NextToken': nextToken,
if (pageSize != null) 'PageSize': pageSize,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetWorkUnits',
exceptionFnMap: _exceptionFns,
);
return GetWorkUnitsResponse.fromJson(response);
}