listTableStorageOptimizers method
Returns the configuration of all storage optimizers associated with a specified table.
May throw AccessDeniedException.
May throw EntityNotFoundException.
May throw InternalServiceException.
May throw InvalidInputException.
Parameter databaseName :
Name of the database where the table is present.
Parameter tableName :
Name of the table.
Parameter catalogId :
The Catalog ID of the table.
Parameter maxResults :
The number of storage optimizers to return on each call.
Parameter nextToken :
A continuation token, if this is a continuation call.
Parameter storageOptimizerType :
The specific type of storage optimizers to list. The supported value is
compaction.
Implementation
Future<ListTableStorageOptimizersResponse> listTableStorageOptimizers({
required String databaseName,
required String tableName,
String? catalogId,
int? maxResults,
String? nextToken,
OptimizerType? storageOptimizerType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'DatabaseName': databaseName,
'TableName': tableName,
if (catalogId != null) 'CatalogId': catalogId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (storageOptimizerType != null)
'StorageOptimizerType': storageOptimizerType.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListTableStorageOptimizers',
exceptionFnMap: _exceptionFns,
);
return ListTableStorageOptimizersResponse.fromJson(response);
}