deleteFunction method

Future<DeleteFunctionResponse> deleteFunction({
  1. required String functionName,
  2. String? qualifier,
})

Deletes a Lambda function. To delete a specific function version, use the Qualifier parameter. Otherwise, all versions and aliases are deleted. This doesn't require the user to have explicit permissions for DeleteAlias. To delete Lambda event source mappings that invoke a function, use DeleteEventSourceMapping. For Amazon Web Services services and resources that invoke your function directly, delete the trigger in the service where you originally configured it.

May throw InvalidParameterValueException. May throw ResourceConflictException. May throw ResourceNotFoundException. May throw ServiceException. May throw TooManyRequestsException.

Parameter functionName : The name or ARN of the Lambda function or version.

Name formats

  • Function namemy-function (name-only), my-function:1 (with version).
  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.
  • Partial ARN123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Parameter qualifier : Specify a version to delete. You can't delete a version that an alias references.

Implementation

Future<DeleteFunctionResponse> deleteFunction({
  required String functionName,
  String? qualifier,
}) async {
  final $query = <String, List<String>>{
    if (qualifier != null) 'Qualifier': [qualifier],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri: '/2015-03-31/functions/${Uri.encodeComponent(functionName)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return DeleteFunctionResponse.fromJson(response);
}