getFunctionConcurrency method
Returns details about the reserved concurrency configuration for a function. To set a concurrency limit for a function, use PutFunctionConcurrency.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter functionName :
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
Implementation
Future<GetFunctionConcurrencyResponse> getFunctionConcurrency({
required String functionName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2019-09-30/functions/${Uri.encodeComponent(functionName)}/concurrency',
exceptionFnMap: _exceptionFns,
);
return GetFunctionConcurrencyResponse.fromJson(response);
}