invoke method
Invokes a Lambda function. You can invoke a function synchronously (and
wait for the response), or asynchronously. By default, Lambda invokes your
function synchronously (i.e. theInvocationType is
RequestResponse). To invoke a function asynchronously, set
InvocationType to Event. Lambda passes the
ClientContext object to your function for synchronous
invocations only.
For synchronous invocations, the maximum payload size is 6 MB. For asynchronous invocations, the maximum payload size is 1 MB.
For synchronous invocation, details about the function response, including errors, are included in the response body and headers. For either invocation type, you can find more information in the execution log and trace.
When an error occurs, your function may be invoked multiple times. Retry behavior varies by error type, client, event source, and invocation type. For example, if you invoke a function asynchronously and it returns an error, Lambda executes the function up to two more times. For more information, see Error handling and automatic retries in Lambda.
For asynchronous invocation, Lambda adds events to a queue before sending them to your function. If your function does not have enough capacity to keep up with the queue, events may be lost. Occasionally, your function may receive the same event multiple times, even if no error occurs. To retain events that were not processed, configure your function with a dead-letter queue.
The status code in the API response doesn't reflect function errors. Error
codes are reserved for errors that prevent your function from executing,
such as permissions errors, quota
errors, or issues with your function's code and configuration. For
example, Lambda returns TooManyRequestsException if running
the function would cause you to exceed a concurrency limit at either the
account level (ConcurrentInvocationLimitExceeded) or function
level (ReservedFunctionConcurrentInvocationLimitExceeded).
For functions with a long timeout, your client might disconnect during synchronous invocation while it waits for a response. Configure your HTTP client, SDK, firewall, proxy, or operating system to allow for long connections with timeout or keep-alive settings.
This operation requires permission for the lambda:InvokeFunction action. For details on how to set up permissions for cross-account invocations, see Granting function access to other accounts.
May throw DurableExecutionAlreadyStartedException.
May throw EC2AccessDeniedException.
May throw EC2ThrottledException.
May throw EC2UnexpectedException.
May throw EFSIOException.
May throw EFSMountConnectivityException.
May throw EFSMountFailureException.
May throw EFSMountTimeoutException.
May throw ENILimitReachedException.
May throw InvalidParameterValueException.
May throw InvalidRequestContentException.
May throw InvalidRuntimeException.
May throw InvalidSecurityGroupIDException.
May throw InvalidSubnetIDException.
May throw InvalidZipFileException.
May throw KMSAccessDeniedException.
May throw KMSDisabledException.
May throw KMSInvalidStateException.
May throw KMSNotFoundException.
May throw NoPublishedVersionException.
May throw RecursiveInvocationException.
May throw RequestTooLargeException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
May throw ResourceNotReadyException.
May throw S3FilesMountConnectivityException.
May throw S3FilesMountFailureException.
May throw S3FilesMountTimeoutException.
May throw SerializedRequestEntityTooLargeException.
May throw ServiceException.
May throw SnapStartException.
May throw SnapStartNotReadyException.
May throw SnapStartTimeoutException.
May throw SubnetIPAddressLimitReachedException.
May throw TooManyRequestsException.
May throw UnsupportedMediaTypeException.
Parameter functionName :
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
Parameter clientContext :
Up to 3,583 bytes of base64-encoded data about the invoking client to pass
to the function in the context object. Lambda passes the
ClientContext object to your function for synchronous
invocations only.
Parameter durableExecutionName :
Optional unique name for the durable execution. When you start your
special function, you can give it a unique name to identify this specific
execution. It's like giving a nickname to a task.
Parameter invocationType :
Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
Parameter logType :
Set to Tail to include the execution log in the response.
Applies to synchronously invoked functions only.
Parameter payload :
The JSON that you want to provide to your Lambda function as input. The
maximum payload size is 6 MB for synchronous invocations and 1 MB for
asynchronous invocations.
You can enter the JSON directly. For example, --payload '{ "key":
"value" }'. You can also specify a file path. For example,
--payload file://payload.json.
Parameter qualifier :
Specify a version or alias to invoke a published version of the function.
Parameter tenantId :
The identifier of the tenant in a multi-tenant Lambda function.
Implementation
Future<InvocationResponse> invoke({
required String functionName,
String? clientContext,
String? durableExecutionName,
InvocationType? invocationType,
LogType? logType,
Uint8List? payload,
String? qualifier,
String? tenantId,
}) async {
final headers = <String, String>{
if (clientContext != null)
'X-Amz-Client-Context': clientContext.toString(),
if (durableExecutionName != null)
'X-Amz-Durable-Execution-Name': durableExecutionName.toString(),
if (invocationType != null) 'X-Amz-Invocation-Type': invocationType.value,
if (logType != null) 'X-Amz-Log-Type': logType.value,
if (tenantId != null) 'X-Amz-Tenant-Id': tenantId.toString(),
};
final $query = <String, List<String>>{
if (qualifier != null) 'Qualifier': [qualifier],
};
final response = await _protocol.sendRaw(
payload: payload,
method: 'POST',
requestUri:
'/2015-03-31/functions/${Uri.encodeComponent(functionName)}/invocations',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return InvocationResponse(
payload: await response.stream.toBytes(),
durableExecutionArn: _s.extractHeaderStringValue(
response.headers, 'X-Amz-Durable-Execution-Arn'),
executedVersion: _s.extractHeaderStringValue(
response.headers, 'X-Amz-Executed-Version'),
functionError:
_s.extractHeaderStringValue(response.headers, 'X-Amz-Function-Error'),
logResult:
_s.extractHeaderStringValue(response.headers, 'X-Amz-Log-Result'),
statusCode: response.statusCode,
);
}