listDeploymentEvents method
Lists the events of a deployment.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter deploymentId :
The ID of the deployment.
Parameter maxResults :
The maximum number of items to return for this request. To get the next
page of items, make another request with the token returned in the output.
Parameter nextToken :
The token returned from a previous paginated request. Pagination continues
from the end of the items returned by the previous request.
Implementation
Future<ListDeploymentEventsOutput> listDeploymentEvents({
required String deploymentId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
'deploymentId': deploymentId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listDeploymentEvents',
exceptionFnMap: _exceptionFns,
);
return ListDeploymentEventsOutput.fromJson(response);
}