createResourcePolicy method
Creates a new resource policy with the specified policy statements.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter policy :
A resource policy to add to the resource. The policy is a JSON structure
that contains one or more statements that define the policy. The policy
must follow the IAM syntax. For more information about the contents of a
JSON policy document, see
IAM JSON policy reference .
If the policy isn't valid, Amazon Lex returns a validation exception.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the bot or bot alias that the resource
policy is attached to.
Implementation
Future<CreateResourcePolicyResponse> createResourcePolicy({
required String policy,
required String resourceArn,
}) async {
final $payload = <String, dynamic>{
'policy': policy,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/policy/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
return CreateResourcePolicyResponse.fromJson(response);
}