deleteBotLocale method
Removes a locale from a bot.
When you delete a locale, all intents, slots, and slot types defined for the locale are also deleted.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The unique identifier of the bot that contains the locale.
Parameter botVersion :
The version of the bot that contains the locale.
Parameter localeId :
The identifier of the language and locale that will be deleted. The string
must match one of the supported locales. For more information, see Supported
languages.
Implementation
Future<DeleteBotLocaleResponse> deleteBotLocale({
required String botId,
required String botVersion,
required String localeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteBotLocaleResponse.fromJson(response);
}