deleteBotReplica method
The action to delete the replicated bot in the secondary region.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The unique ID of the replicated bot to be deleted from the secondary
region
Parameter replicaRegion :
The secondary region of the replicated bot that will be deleted.
Implementation
Future<DeleteBotReplicaResponse> deleteBotReplica({
required String botId,
required String replicaRegion,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/replicas/${Uri.encodeComponent(replicaRegion)}',
exceptionFnMap: _exceptionFns,
);
return DeleteBotReplicaResponse.fromJson(response);
}