deleteSlot method
Deletes the specified slot from an intent.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot associated with the slot to delete.
Parameter botVersion :
The version of the bot associated with the slot to delete.
Parameter intentId :
The identifier of the intent associated with the slot.
Parameter localeId :
The identifier of the language and locale that the slot will be deleted
from. The string must match one of the supported locales. For more
information, see Supported
languages.
Parameter slotId :
The identifier of the slot to delete.
Implementation
Future<void> deleteSlot({
required String botId,
required String botVersion,
required String intentId,
required String localeId,
required String slotId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/intents/${Uri.encodeComponent(intentId)}/slots/${Uri.encodeComponent(slotId)}',
exceptionFnMap: _exceptionFns,
);
}