describeBotLocale method
Describes the settings that a bot has for a specific locale.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot associated with the locale.
Parameter botVersion :
The version of the bot associated with the locale.
Parameter localeId :
The unique identifier of the locale to describe. The string must match one
of the supported locales. For more information, see Supported
languages.
Implementation
Future<DescribeBotLocaleResponse> describeBotLocale({
required String botId,
required String botVersion,
required String localeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeBotLocaleResponse.fromJson(response);
}