describeIntent method
Returns metadata about an intent.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot associated with the intent.
Parameter botVersion :
The version of the bot associated with the intent.
Parameter intentId :
The identifier of the intent to describe.
Parameter localeId :
The identifier of the language and locale of the intent to describe. The
string must match one of the supported locales. For more information, see
Supported
languages.
Implementation
Future<DescribeIntentResponse> describeIntent({
required String botId,
required String botVersion,
required String intentId,
required String localeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/intents/${Uri.encodeComponent(intentId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeIntentResponse.fromJson(response);
}