describeResourcePolicy method
Gets the resource policy and policy revision for a bot or bot alias.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the bot or bot alias that the resource
policy is attached to.
Implementation
Future<DescribeResourcePolicyResponse> describeResourcePolicy({
required String resourceArn,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/policy/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
return DescribeResourcePolicyResponse.fromJson(response);
}