describeSlot method
Gets metadata information about a slot.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot associated with the slot.
Parameter botVersion :
The version of the bot associated with the slot.
Parameter intentId :
The identifier of the intent that contains the slot.
Parameter localeId :
The identifier of the language and locale of the slot to describe. The
string must match one of the supported locales. For more information, see
Supported
languages.
Parameter slotId :
The unique identifier for the slot.
Implementation
Future<DescribeSlotResponse> describeSlot({
required String botId,
required String botVersion,
required String intentId,
required String localeId,
required String slotId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/intents/${Uri.encodeComponent(intentId)}/slots/${Uri.encodeComponent(slotId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeSlotResponse.fromJson(response);
}