listBotAliasReplicas method
The action to list the replicated bots created from the source bot alias.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The request for the unique bot ID of the replicated bot created from the
source bot alias.
Parameter replicaRegion :
The request for the secondary region of the replicated bot created from
the source bot alias.
Parameter maxResults :
The request for maximum results to list the replicated bots created from
the source bot alias.
Parameter nextToken :
The request for the next token for the replicated bot created from the
source bot alias.
Implementation
Future<ListBotAliasReplicasResponse> listBotAliasReplicas({
required String botId,
required String replicaRegion,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/replicas/${Uri.encodeComponent(replicaRegion)}/botaliases',
exceptionFnMap: _exceptionFns,
);
return ListBotAliasReplicasResponse.fromJson(response);
}