listBotAliases method
Gets a list of aliases for the specified bot.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The identifier of the bot to list aliases for.
Parameter maxResults :
The maximum number of aliases to return in each page of results. If there
are fewer results than the max page size, only the actual number of
results are returned.
Parameter nextToken :
If the response from the ListBotAliases operation contains
more results than specified in the maxResults parameter, a
token is returned in the response. Use that token in the
nextToken parameter to return the next page of results.
Implementation
Future<ListBotAliasesResponse> listBotAliases({
required String botId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/bots/${Uri.encodeComponent(botId)}/botaliases',
exceptionFnMap: _exceptionFns,
);
return ListBotAliasesResponse.fromJson(response);
}