listTestSetRecords method
The list of test set records.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter testSetId :
The identifier of the test set to list its test set records.
Parameter maxResults :
The maximum number of test set records to return in each page. If there
are fewer records than the max page size, only the actual number of
records are returned.
Parameter nextToken :
If the response from the ListTestSetRecords operation contains more
results than specified in the maxResults parameter, a token is returned in
the response. Use that token in the nextToken parameter to return the next
page of results.
Implementation
Future<ListTestSetRecordsResponse> listTestSetRecords({
required String testSetId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/testsets/${Uri.encodeComponent(testSetId)}/records',
exceptionFnMap: _exceptionFns,
);
return ListTestSetRecordsResponse.fromJson(response);
}