stopBotRecommendation method
Stop an already running Bot Recommendation request.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The unique identifier of the bot containing the bot recommendation to be
stopped.
Parameter botRecommendationId :
The unique identifier of the bot recommendation to be stopped.
Parameter botVersion :
The version of the bot containing the bot recommendation.
Parameter localeId :
The identifier of the language and locale of the bot recommendation to
stop. The string must match one of the supported locales. For more
information, see Supported
languages
Implementation
Future<StopBotRecommendationResponse> stopBotRecommendation({
required String botId,
required String botRecommendationId,
required String botVersion,
required String localeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PUT',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/botrecommendations/${Uri.encodeComponent(botRecommendationId)}/stopbotrecommendation',
exceptionFnMap: _exceptionFns,
);
return StopBotRecommendationResponse.fromJson(response);
}