updateBotRecommendation method
Updates an existing bot recommendation request.
May throw ConflictException.
May throw InternalServerException.
May throw PreconditionFailedException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter botId :
The unique identifier of the bot containing the bot recommendation to be
updated.
Parameter botRecommendationId :
The unique identifier of the bot recommendation to be updated.
Parameter botVersion :
The version of the bot containing the bot recommendation to be updated.
Parameter encryptionSetting :
The object representing the passwords that will be used to encrypt the
data related to the bot recommendation results, as well as the KMS key ARN
used to encrypt the associated metadata.
Parameter localeId :
The identifier of the language and locale of the bot recommendation to
update. The string must match one of the supported locales. For more
information, see Supported
languages
Implementation
Future<UpdateBotRecommendationResponse> updateBotRecommendation({
required String botId,
required String botRecommendationId,
required String botVersion,
required EncryptionSetting encryptionSetting,
required String localeId,
}) async {
final $payload = <String, dynamic>{
'encryptionSetting': encryptionSetting,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/bots/${Uri.encodeComponent(botId)}/botversions/${Uri.encodeComponent(botVersion)}/botlocales/${Uri.encodeComponent(localeId)}/botrecommendations/${Uri.encodeComponent(botRecommendationId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateBotRecommendationResponse.fromJson(response);
}