deleteSession method
Removes session information for a specified bot, alias, and user ID.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter botAlias :
The alias in use for the bot that contains the session data.
Parameter botName :
The name of the bot that contains the session data.
Parameter userId :
The identifier of the user associated with the session data.
Implementation
Future<DeleteSessionResponse> deleteSession({
required String botAlias,
required String botName,
required String userId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/bot/${Uri.encodeComponent(botName)}/alias/${Uri.encodeComponent(botAlias)}/user/${Uri.encodeComponent(userId)}/session',
exceptionFnMap: _exceptionFns,
);
return DeleteSessionResponse.fromJson(response);
}