getLicenseConversionTask method
Future<GetLicenseConversionTaskResponse>
getLicenseConversionTask({
- required String licenseConversionTaskId,
Gets information about the specified license type conversion task.
May throw AccessDeniedException.
May throw AuthorizationException.
May throw InvalidParameterValueException.
May throw RateLimitExceededException.
May throw ServerInternalException.
Parameter licenseConversionTaskId :
ID of the license type conversion task to retrieve information on.
Implementation
Future<GetLicenseConversionTaskResponse> getLicenseConversionTask({
required String licenseConversionTaskId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSLicenseManager.GetLicenseConversionTask'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'LicenseConversionTaskId': licenseConversionTaskId,
},
);
return GetLicenseConversionTaskResponse.fromJson(jsonResponse.body);
}