LicenseManagerLinuxSubscriptions class
With License Manager, you can discover and track your commercial Linux subscriptions on running Amazon EC2 instances.
Constructors
- LicenseManagerLinuxSubscriptions({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deregisterSubscriptionProvider(
{required String subscriptionProviderArn}) → Future< void> - Remove a third-party subscription provider from the Bring Your Own License (BYOL) subscriptions registered to your account.
-
getRegisteredSubscriptionProvider(
{required String subscriptionProviderArn}) → Future< GetRegisteredSubscriptionProviderResponse> - Get details for a Bring Your Own License (BYOL) subscription that's registered to your account.
-
getServiceSettings(
) → Future< GetServiceSettingsResponse> - Lists the Linux subscriptions service settings for your account.
-
listLinuxSubscriptionInstances(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListLinuxSubscriptionInstancesResponse> - Lists the running Amazon EC2 instances that were discovered with commercial Linux subscriptions.
-
listLinuxSubscriptions(
{List< Filter> ? filters, int? maxResults, String? nextToken}) → Future<ListLinuxSubscriptionsResponse> - Lists the Linux subscriptions that have been discovered. If you have linked your organization, the returned results will include data aggregated across your accounts in Organizations.
-
listRegisteredSubscriptionProviders(
{int? maxResults, String? nextToken, List< SubscriptionProviderSource> ? subscriptionProviderSources}) → Future<ListRegisteredSubscriptionProvidersResponse> - List Bring Your Own License (BYOL) subscription registration resources for your account.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - List the metadata tags that are assigned to the specified Amazon Web Services resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerSubscriptionProvider(
{required String secretArn, required SubscriptionProviderSource subscriptionProviderSource, Map< String, String> ? tags}) → Future<RegisterSubscriptionProviderResponse> - Register the supported third-party subscription provider for your Bring Your Own License (BYOL) subscription.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Add metadata tags to the specified Amazon Web Services resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Remove one or more metadata tag from the specified Amazon Web Services resource.
-
updateServiceSettings(
{required LinuxSubscriptionsDiscovery linuxSubscriptionsDiscovery, required LinuxSubscriptionsDiscoverySettings linuxSubscriptionsDiscoverySettings, bool? allowUpdate}) → Future< UpdateServiceSettingsResponse> - Updates the service settings for Linux subscriptions.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited