listLinuxSubscriptionInstances method
Lists the running Amazon EC2 instances that were discovered with commercial Linux subscriptions.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filters :
An array of structures that you can use to filter the results by your
specified criteria. For example, you can specify Region in
the Name, with the contains operator to list all
subscriptions that match a partial string in the Value, such
as us-west.
For each filter, you can specify one of the following values for the
Name key to streamline results:
-
AccountID -
AmiID -
DualSubscription -
InstanceID -
InstanceType -
ProductCode -
Region -
Status -
UsageOperation
Operator
values to define the behavior of the filter:
-
contains -
equals -
Notequal
Parameter maxResults :
The maximum items to return in a request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListLinuxSubscriptionInstancesResponse>
listLinuxSubscriptionInstances({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/subscription/ListLinuxSubscriptionInstances',
exceptionFnMap: _exceptionFns,
);
return ListLinuxSubscriptionInstancesResponse.fromJson(response);
}