registerSubscriptionProvider method
Register the supported third-party subscription provider for your Bring Your Own License (BYOL) subscription.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter secretArn :
The Amazon Resource Name (ARN) of the secret where you've stored your
subscription provider's access token. For RHEL subscriptions managed
through the Red Hat Subscription Manager (RHSM), the secret contains your
Red Hat Offline token.
Parameter subscriptionProviderSource :
The supported Linux subscription provider to register.
Parameter tags :
The metadata tags to assign to your registered Linux subscription provider
resource.
Implementation
Future<RegisterSubscriptionProviderResponse> registerSubscriptionProvider({
required String secretArn,
required SubscriptionProviderSource subscriptionProviderSource,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'SecretArn': secretArn,
'SubscriptionProviderSource': subscriptionProviderSource.value,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/subscription/RegisterSubscriptionProvider',
exceptionFnMap: _exceptionFns,
);
return RegisterSubscriptionProviderResponse.fromJson(response);
}