disassociateUser method
Disassociates the user from an EC2 instance providing user-based subscriptions.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domain :
The domain name of the Active Directory that contains information for the
user to disassociate.
Parameter identityProvider :
An object that specifies details for the Active Directory identity
provider.
Parameter instanceId :
The ID of the EC2 instance which provides user-based subscriptions.
Parameter instanceUserArn :
The Amazon Resource Name (ARN) of the user to disassociate from the EC2
instance.
Parameter username :
The user name from the Active Directory identity provider for the user.
Implementation
Future<DisassociateUserResponse> disassociateUser({
String? domain,
IdentityProvider? identityProvider,
String? instanceId,
String? instanceUserArn,
String? username,
}) async {
final $payload = <String, dynamic>{
if (domain != null) 'Domain': domain,
if (identityProvider != null) 'IdentityProvider': identityProvider,
if (instanceId != null) 'InstanceId': instanceId,
if (instanceUserArn != null) 'InstanceUserArn': instanceUserArn,
if (username != null) 'Username': username,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/user/DisassociateUser',
exceptionFnMap: _exceptionFns,
);
return DisassociateUserResponse.fromJson(response);
}