listUserAssociations method
Lists user associations for an identity provider.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter identityProvider :
An object that specifies details for the identity provider.
Parameter instanceId :
The ID of the EC2 instance, which provides user-based subscriptions.
Parameter filters :
You can use the following filters to streamline results:
- Status
- Username
- Domain
Parameter maxResults :
The maximum number of results to return from a single request.
Parameter nextToken :
A token to specify where to start paginating. This is the nextToken from a
previously truncated response.
Implementation
Future<ListUserAssociationsResponse> listUserAssociations({
required IdentityProvider identityProvider,
required String instanceId,
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
'IdentityProvider': identityProvider,
'InstanceId': instanceId,
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/user/ListUserAssociations',
exceptionFnMap: _exceptionFns,
);
return ListUserAssociationsResponse.fromJson(response);
}