stopProductSubscription method

Future<StopProductSubscriptionResponse> stopProductSubscription({
  1. String? domain,
  2. IdentityProvider? identityProvider,
  3. String? product,
  4. String? productUserArn,
  5. String? username,
})

Stops a product subscription for a user with the specified identity provider.

May throw AccessDeniedException. May throw ConflictException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ServiceQuotaExceededException. May throw ThrottlingException. May throw ValidationException.

Parameter domain : The domain name of the Active Directory that contains the user for whom to stop the product subscription.

Parameter identityProvider : An object that specifies details for the identity provider.

Parameter product : The name of the user-based subscription product.

Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL | OFFICE_PROFESSIONAL_PLUS | REMOTE_DESKTOP_SERVICES

Parameter productUserArn : The Amazon Resource Name (ARN) of the product user.

Parameter username : The user name from the identity provider for the user.

Implementation

Future<StopProductSubscriptionResponse> stopProductSubscription({
  String? domain,
  IdentityProvider? identityProvider,
  String? product,
  String? productUserArn,
  String? username,
}) async {
  final $payload = <String, dynamic>{
    if (domain != null) 'Domain': domain,
    if (identityProvider != null) 'IdentityProvider': identityProvider,
    if (product != null) 'Product': product,
    if (productUserArn != null) 'ProductUserArn': productUserArn,
    if (username != null) 'Username': username,
  };
  final response = await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/user/StopProductSubscription',
    exceptionFnMap: _exceptionFns,
  );
  return StopProductSubscriptionResponse.fromJson(response);
}