createCloudFormationStack method
- required List<
InstanceEntry> instances,
Creates an AWS CloudFormation stack, which creates a new Amazon EC2
instance from an exported Amazon Lightsail snapshot. This operation
results in a CloudFormation stack record that can be used to track the AWS
CloudFormation stack created. Use the get cloud formation stack
records operation to get a list of the CloudFormation stacks
created.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instances :
An array of parameters that will be used to create the new Amazon EC2
instance. You can only pass one instance entry at a time in this array.
You will get an invalid parameter error if you pass more than one instance
entry in this array.
Implementation
Future<CreateCloudFormationStackResult> createCloudFormationStack({
required List<InstanceEntry> instances,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.CreateCloudFormationStack'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instances': instances,
},
);
return CreateCloudFormationStackResult.fromJson(jsonResponse.body);
}