deleteDisk method
Deletes the specified block storage disk. The disk must be in the
available state (not attached to a Lightsail instance).
The delete disk operation supports tag-based access control
via resource tags applied to the resource identified by disk
name. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter diskName :
The unique name of the disk you want to delete (my-disk).
Parameter forceDeleteAddOns :
A Boolean value to indicate whether to delete all add-ons for the disk.
Implementation
Future<DeleteDiskResult> deleteDisk({
required String diskName,
bool? forceDeleteAddOns,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.DeleteDisk'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'diskName': diskName,
if (forceDeleteAddOns != null) 'forceDeleteAddOns': forceDeleteAddOns,
},
);
return DeleteDiskResult.fromJson(jsonResponse.body);
}