deleteDomain method
Deletes the specified domain recordset and all of its domain records.
The delete domain operation supports tag-based access control
via resource tags applied to the resource identified by domain
name. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter domainName :
The specific domain name to delete.
Implementation
Future<DeleteDomainResult> deleteDomain({
required String domainName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.DeleteDomain'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'domainName': domainName,
},
);
return DeleteDomainResult.fromJson(jsonResponse.body);
}