deleteInstance method
Deletes an Amazon Lightsail instance.
The delete instance operation supports tag-based access
control via resource tags applied to the resource identified by
instance name. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instanceName :
The name of the instance to delete.
Parameter forceDeleteAddOns :
A Boolean value to indicate whether to delete all add-ons for the
instance.
Implementation
Future<DeleteInstanceResult> deleteInstance({
required String instanceName,
bool? forceDeleteAddOns,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.DeleteInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instanceName': instanceName,
if (forceDeleteAddOns != null) 'forceDeleteAddOns': forceDeleteAddOns,
},
);
return DeleteInstanceResult.fromJson(jsonResponse.body);
}