getKeyPairs method
Returns information about all key pairs in the user's account.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter includeDefaultKeyPair :
A Boolean value that indicates whether to include the default key pair in
the response of your request.
Parameter pageToken :
The token to advance to the next page of results from your request.
To get a page token, perform an initial GetKeyPairs request.
If your results are paginated, the response will return a next page token
that you can specify as the page token in a subsequent request.
Implementation
Future<GetKeyPairsResult> getKeyPairs({
bool? includeDefaultKeyPair,
String? pageToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.GetKeyPairs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (includeDefaultKeyPair != null)
'includeDefaultKeyPair': includeDefaultKeyPair,
if (pageToken != null) 'pageToken': pageToken,
},
);
return GetKeyPairsResult.fromJson(jsonResponse.body);
}