registerContainerImage method
Registers a container image to your Amazon Lightsail container service.
May throw AccessDeniedException.
May throw InvalidInputException.
May throw NotFoundException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter digest :
The digest of the container image to be registered.
Parameter label :
The label for the container image when it's registered to the container
service.
Use a descriptive label that you can use to track the different versions of your registered container images.
Use the GetContainerImages action to return the container
images registered to a Lightsail container service. The label is the
portion of the following image name example:
-
:container-service-1.
mycontainerservice,
and the label that you specify is mystaticwebsite, then the
name of the registered container image will be
:mycontainerservice.mystaticwebsite.1.
The number at the end of these image name examples represents the version
of the registered container image. If you push and register another
container image to the same Lightsail container service, with the same
label, then the version number for the new registered container image will
be 2. If you push and register another container image, the
version number will be 3, and so on.
Parameter serviceName :
The name of the container service for which to register a container image.
Implementation
Future<RegisterContainerImageResult> registerContainerImage({
required String digest,
required String label,
required String serviceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.RegisterContainerImage'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'digest': digest,
'label': label,
'serviceName': serviceName,
},
);
return RegisterContainerImageResult.fromJson(jsonResponse.body);
}