startInstance method
Starts a specific Amazon Lightsail instance from a stopped state. To
restart an instance, use the reboot instance operation.
The start instance operation supports tag-based access
control via resource tags applied to the resource identified by
instance name. For more information, see the Amazon
Lightsail Developer Guide.
May throw AccessDeniedException.
May throw AccountSetupInProgressException.
May throw InvalidInputException.
May throw NotFoundException.
May throw OperationFailureException.
May throw RegionSetupInProgressException.
May throw ServiceException.
May throw UnauthenticatedException.
Parameter instanceName :
The name of the instance (a virtual private server) to start.
Implementation
Future<StartInstanceResult> startInstance({
required String instanceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Lightsail_20161128.StartInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'instanceName': instanceName,
},
);
return StartInstanceResult.fromJson(jsonResponse.body);
}