lightsail_2016_11_28 library
Classes
- AwsClientCredentials
- AWS credentials.
- Lightsail
- Amazon Lightsail is the easiest way to get started with Amazon Web Services (Amazon Web Services) for developers who need to build websites or web applications. It includes everything you need to launch your project quickly