Location class
"Suite of geospatial services including Maps, Places, Routes, Tracking, and Geofencing"
Constructors
- Location({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateTrackerConsumer(
{required String consumerArn, required String trackerName}) → Future< void> - Creates an association between a geofence collection and a tracker resource. This allows the tracker resource to communicate location data to the linked geofence collection.
-
batchDeleteDevicePositionHistory(
{required List< String> deviceIds, required String trackerName}) → Future<BatchDeleteDevicePositionHistoryResponse> - Deletes the position history of one or more devices from a tracker resource.
-
batchDeleteGeofence(
{required String collectionName, required List< String> geofenceIds}) → Future<BatchDeleteGeofenceResponse> - Deletes a batch of geofences from a geofence collection.
-
batchEvaluateGeofences(
{required String collectionName, required List< DevicePositionUpdate> devicePositionUpdates}) → Future<BatchEvaluateGeofencesResponse> - Evaluates device positions against the geofence geometries from a given geofence collection.
-
batchGetDevicePosition(
{required List< String> deviceIds, required String trackerName}) → Future<BatchGetDevicePositionResponse> - Lists the latest device positions for requested devices.
-
batchPutGeofence(
{required String collectionName, required List< BatchPutGeofenceRequestEntry> entries}) → Future<BatchPutGeofenceResponse> - A batch request for storing geofence geometries into a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request.
-
batchUpdateDevicePosition(
{required String trackerName, required List< DevicePositionUpdate> updates}) → Future<BatchUpdateDevicePositionResponse> - Uploads position update data for one or more devices to a tracker resource (up to 10 devices per batch). Amazon Location uses the data when it reports the last known device position and position history. Amazon Location retains location data for 30 days.
-
calculateRoute(
{required String calculatorName, required List< double> departurePosition, required List<double> destinationPosition, DateTime? arrivalTime, CalculateRouteCarModeOptions? carModeOptions, bool? departNow, DateTime? departureTime, DistanceUnit? distanceUnit, bool? includeLegGeometry, String? key, OptimizationMode? optimizeFor, TravelMode? travelMode, CalculateRouteTruckModeOptions? truckModeOptions, List<List< ? waypointPositions}) → Future<double> >CalculateRouteResponse> - Calculates a route
-
calculateRouteMatrix(
{required String calculatorName, required List< List< departurePositions, required List<double> >List< destinationPositions, CalculateRouteCarModeOptions? carModeOptions, bool? departNow, DateTime? departureTime, DistanceUnit? distanceUnit, String? key, TravelMode? travelMode, CalculateRouteTruckModeOptions? truckModeOptions}) → Future<double> >CalculateRouteMatrixResponse> - Calculates a route matrix
-
cancelJob(
{required String jobId}) → Future< CancelJobResponse> -
CancelJobcancels a job that is currently running or pending. If the job is already in a terminal state (Completed,Failed, orCancelled), the operation returns successfully with the current status. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createGeofenceCollection(
{required String collectionName, String? description, String? kmsKeyId, PricingPlan? pricingPlan, String? pricingPlanDataSource, Map< String, String> ? tags}) → Future<CreateGeofenceCollectionResponse> - Creates a geofence collection, which manages and stores geofences.
-
createKey(
{required String keyName, required ApiKeyRestrictions restrictions, String? description, DateTime? expireTime, bool? noExpiry, Map< String, String> ? tags}) → Future<CreateKeyResponse> - Creates an API key resource in your Amazon Web Services account, which lets you grant actions for Amazon Location resources to the API key bearer.
-
createMap(
{required MapConfiguration configuration, required String mapName, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreateMapResponse> -
May throw
AccessDeniedException. May throwConflictException. May throwInternalServerException. May throwServiceQuotaExceededException. May throwThrottlingException. May throwValidationException. -
createPlaceIndex(
{required String dataSource, required String indexName, DataSourceConfiguration? dataSourceConfiguration, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreatePlaceIndexResponse> - SearchPlaceIndexForText
-
createRouteCalculator(
{required String calculatorName, required String dataSource, String? description, PricingPlan? pricingPlan, Map< String, String> ? tags}) → Future<CreateRouteCalculatorResponse> - You can send requests to a route calculator resource to estimate travel time, distance, and get directions. A route calculator sources traffic and road network data from your chosen data provider.
-
createTracker(
{required String trackerName, String? description, bool? eventBridgeEnabled, bool? kmsKeyEnableGeospatialQueries, String? kmsKeyId, PositionFiltering? positionFiltering, PricingPlan? pricingPlan, String? pricingPlanDataSource, Map< String, String> ? tags}) → Future<CreateTrackerResponse> - Creates a tracker resource in your Amazon Web Services account, which lets you retrieve current and historical location of devices.
-
deleteGeofenceCollection(
{required String collectionName}) → Future< void> - Deletes a geofence collection from your Amazon Web Services account.
-
deleteKey(
{required String keyName, bool? forceDelete}) → Future< void> - Deletes the specified API key. The API key must have been deactivated more than 90 days previously.
-
deleteMap(
{required String mapName}) → Future< void> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
deletePlaceIndex(
{required String indexName}) → Future< void> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
deleteRouteCalculator(
{required String calculatorName}) → Future< void> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
deleteTracker(
{required String trackerName}) → Future< void> - Deletes a tracker resource from your Amazon Web Services account.
-
describeGeofenceCollection(
{required String collectionName}) → Future< DescribeGeofenceCollectionResponse> - Retrieves the geofence collection details.
-
describeKey(
{required String keyName}) → Future< DescribeKeyResponse> - Retrieves the API key resource details.
-
describeMap(
{required String mapName}) → Future< DescribeMapResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
describePlaceIndex(
{required String indexName}) → Future< DescribePlaceIndexResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
describeRouteCalculator(
{required String calculatorName}) → Future< DescribeRouteCalculatorResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
describeTracker(
{required String trackerName}) → Future< DescribeTrackerResponse> - Retrieves the tracker resource details.
-
disassociateTrackerConsumer(
{required String consumerArn, required String trackerName}) → Future< void> - Removes the association between a tracker resource and a geofence collection.
-
forecastGeofenceEvents(
{required String collectionName, required ForecastGeofenceEventsDeviceState deviceState, DistanceUnit? distanceUnit, int? maxResults, String? nextToken, SpeedUnit? speedUnit, double? timeHorizonMinutes}) → Future< ForecastGeofenceEventsResponse> - This action forecasts future geofence events that are likely to occur within a specified time horizon if a device continues moving at its current speed. Each forecasted event is associated with a geofence from a provided geofence collection. A forecast event can have one of the following states:
-
getDevicePosition(
{required String deviceId, required String trackerName}) → Future< GetDevicePositionResponse> - Retrieves a device's most recent position according to its sample time.
-
getDevicePositionHistory(
{required String deviceId, required String trackerName, DateTime? endTimeExclusive, int? maxResults, String? nextToken, DateTime? startTimeInclusive}) → Future< GetDevicePositionHistoryResponse> - Retrieves the device position history from a tracker resource within a specified range of time.
-
getGeofence(
{required String collectionName, required String geofenceId}) → Future< GetGeofenceResponse> - Retrieves the geofence details from a geofence collection.
-
getJob(
{required String jobId}) → Future< GetJobResponse> -
GetJobretrieves detailed information about a specific job, including its current status, configuration, and error information if the job failed. -
getMapGlyphs(
{required String fontStack, required String fontUnicodeRange, required String mapName, String? key}) → Future< GetMapGlyphsResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
getMapSprites(
{required String fileName, required String mapName, String? key}) → Future< GetMapSpritesResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
getMapStyleDescriptor(
{required String mapName, String? key}) → Future< GetMapStyleDescriptorResponse> - The style descriptor contains specifications on how features render on a map. For example, what data to display, what order to display the data in, and the style for the data. Style descriptors follow the Mapbox Style Specification.
-
getMapTile(
{required String mapName, required String x, required String y, required String z, String? key}) → Future< GetMapTileResponse> - The origin (0, 0) is the top left of the map. Increasing the zoom level by 1 doubles both the X and Y dimensions, so a tile containing data for the entire world at (0/0/0) will be split into 4 tiles at zoom 1 (1/0/0, 1/0/1, 1/1/0, 1/1/1).
-
getPlace(
{required String indexName, required String placeId, String? key, String? language}) → Future< GetPlaceResponse> - PlaceId
-
listDevicePositions(
{required String trackerName, TrackingFilterGeometry? filterGeometry, int? maxResults, String? nextToken}) → Future< ListDevicePositionsResponse> - A batch request to retrieve all device positions.
-
listGeofenceCollections(
{int? maxResults, String? nextToken}) → Future< ListGeofenceCollectionsResponse> - Lists geofence collections in your Amazon Web Services account.
-
listGeofences(
{required String collectionName, int? maxResults, String? nextToken}) → Future< ListGeofencesResponse> - Lists geofences stored in a given geofence collection.
-
listJobs(
{JobsFilter? filter, int? maxResults, String? nextToken}) → Future< ListJobsResponse> -
ListJobsretrieves a list of jobs with optional filtering and pagination support. -
listKeys(
{ApiKeyFilter? filter, int? maxResults, String? nextToken}) → Future< ListKeysResponse> - Lists API key resources in your Amazon Web Services account.
-
listMaps(
{int? maxResults, String? nextToken}) → Future< ListMapsResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwThrottlingException. May throwValidationException. -
listPlaceIndexes(
{int? maxResults, String? nextToken}) → Future< ListPlaceIndexesResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwThrottlingException. May throwValidationException. -
listRouteCalculators(
{int? maxResults, String? nextToken}) → Future< ListRouteCalculatorsResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwThrottlingException. May throwValidationException. -
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Returns a list of tags that are applied to the specified Amazon Location resource.
-
listTrackerConsumers(
{required String trackerName, int? maxResults, String? nextToken}) → Future< ListTrackerConsumersResponse> - Lists geofence collections currently associated to the given tracker resource.
-
listTrackers(
{int? maxResults, String? nextToken}) → Future< ListTrackersResponse> - Lists tracker resources in your Amazon Web Services account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putGeofence(
{required String collectionName, required String geofenceId, required GeofenceGeometry geometry, Map< String, String> ? geofenceProperties}) → Future<PutGeofenceResponse> - Stores a geofence geometry in a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request.
-
searchPlaceIndexForPosition(
{required String indexName, required List< double> position, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForPositionResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
searchPlaceIndexForSuggestions(
{required String indexName, required String text, List< double> ? biasPosition, List<double> ? filterBBox, List<String> ? filterCategories, List<String> ? filterCountries, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForSuggestionsResponse> - Optional parameters let you narrow your search results by bounding box or country, or bias your search toward a specific position on the globe.
-
searchPlaceIndexForText(
{required String indexName, required String text, List< double> ? biasPosition, List<double> ? filterBBox, List<String> ? filterCategories, List<String> ? filterCountries, String? key, String? language, int? maxResults}) → Future<SearchPlaceIndexForTextResponse> - Optional parameters let you narrow your search results by bounding box or country, or bias your search toward a specific position on the globe. Search results are returned in order of highest to lowest relevance.
-
startJob(
{required JobAction action, required String executionRoleArn, required JobInputOptions inputOptions, required JobOutputOptions outputOptions, JobActionOptions? actionOptions, String? clientToken, String? name, Map< String, String> ? tags}) → Future<StartJobResponse> -
StartJobstarts a new asynchronous bulk processing job. You specify the input data location in Amazon S3, the action to perform, and the output location where results are written. -
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Assigns one or more tags (key-value pairs) to the specified Amazon Location Service resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from the specified Amazon Location resource.
-
updateGeofenceCollection(
{required String collectionName, String? description, PricingPlan? pricingPlan, String? pricingPlanDataSource}) → Future< UpdateGeofenceCollectionResponse> - Updates the specified properties of a given geofence collection.
-
updateKey(
{required String keyName, String? description, DateTime? expireTime, bool? forceUpdate, bool? noExpiry, ApiKeyRestrictions? restrictions}) → Future< UpdateKeyResponse> - Updates the specified properties of a given API key resource.
-
updateMap(
{required String mapName, MapConfigurationUpdate? configurationUpdate, String? description, PricingPlan? pricingPlan}) → Future< UpdateMapResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
updatePlaceIndex(
{required String indexName, DataSourceConfiguration? dataSourceConfiguration, String? description, PricingPlan? pricingPlan}) → Future< UpdatePlaceIndexResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
updateRouteCalculator(
{required String calculatorName, String? description, PricingPlan? pricingPlan}) → Future< UpdateRouteCalculatorResponse> -
May throw
AccessDeniedException. May throwInternalServerException. May throwResourceNotFoundException. May throwThrottlingException. May throwValidationException. -
updateTracker(
{required String trackerName, String? description, bool? eventBridgeEnabled, bool? kmsKeyEnableGeospatialQueries, PositionFiltering? positionFiltering, PricingPlan? pricingPlan, String? pricingPlanDataSource}) → Future< UpdateTrackerResponse> - Updates the specified properties of a given tracker resource.
-
verifyDevicePosition(
{required DeviceState deviceState, required String trackerName, DistanceUnit? distanceUnit}) → Future< VerifyDevicePositionResponse> - Verifies the integrity of the device's position by determining if it was reported behind a proxy, and by comparing it to an inferred position estimated based on the device's state.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited