associateTrackerConsumer method
Creates an association between a geofence collection and a tracker resource. This allows the tracker resource to communicate location data to the linked geofence collection.
You can associate up to five geofence collections to each tracker resource.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter consumerArn :
The Amazon Resource Name (ARN) for the geofence collection to be
associated to tracker resource. Used when you need to specify a resource
across all Amazon Web Services.
-
Format example:
arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollectionConsumer
Parameter trackerName :
The name of the tracker resource to be associated with a geofence
collection.
Implementation
Future<void> associateTrackerConsumer({
required String consumerArn,
required String trackerName,
}) async {
final $payload = <String, dynamic>{
'ConsumerArn': consumerArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/tracking/v0/trackers/${Uri.encodeComponent(trackerName)}/consumers',
hostPrefix: 'cp.tracking.',
exceptionFnMap: _exceptionFns,
);
}