deleteRouteCalculator method
Deletes a route calculator resource from your Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter calculatorName :
The name of the route calculator resource to be deleted.
Implementation
Future<void> deleteRouteCalculator({
required String calculatorName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/routes/v0/calculators/${Uri.encodeComponent(calculatorName)}',
exceptionFnMap: _exceptionFns,
);
}