disassociateTrackerConsumer method
Removes the association between a tracker resource and a geofence collection.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter consumerArn :
The Amazon Resource Name (ARN) for the geofence collection to be
disassociated from the tracker resource. Used when you need to specify a
resource across all Amazon Web Services.
-
Format example:
arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollectionConsumer
Parameter trackerName :
The name of the tracker resource to be dissociated from the consumer.
Implementation
Future<void> disassociateTrackerConsumer({
required String consumerArn,
required String trackerName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/tracking/v0/trackers/${Uri.encodeComponent(trackerName)}/consumers/${Uri.encodeComponent(consumerArn)}',
hostPrefix: 'cp.tracking.',
exceptionFnMap: _exceptionFns,
);
}