updateMap method
Updates the specified properties of a given map resource.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter mapName :
The name of the map resource to update.
Parameter configurationUpdate :
Updates the parts of the map configuration that can be updated, including
the political view.
Parameter description :
Updates the description for the map resource.
Parameter pricingPlan :
No longer used. If included, the only allowed value is
RequestBasedUsage.
Implementation
Future<UpdateMapResponse> updateMap({
required String mapName,
MapConfigurationUpdate? configurationUpdate,
String? description,
PricingPlan? pricingPlan,
}) async {
final $payload = <String, dynamic>{
if (configurationUpdate != null)
'ConfigurationUpdate': configurationUpdate,
if (description != null) 'Description': description,
if (pricingPlan != null) 'PricingPlan': pricingPlan.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/maps/v0/maps/${Uri.encodeComponent(mapName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateMapResponse.fromJson(response);
}