deleteApplicationFromEnvironment method
Deletes a specific application from the specific runtime environment where it was previously deployed. You cannot delete a runtime environment using DeleteEnvironment if any application has ever been deployed to it. This API removes the association of the application with the runtime environment so you can delete the environment smoothly.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the application you want to delete.
Parameter environmentId :
The unique identifier of the runtime environment where the application was
previously deployed.
Implementation
Future<void> deleteApplicationFromEnvironment({
required String applicationId,
required String environmentId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/environment/${Uri.encodeComponent(environmentId)}',
exceptionFnMap: _exceptionFns,
);
}