getAccountBalance method
The GetAccountBalance operation retrieves the Prepaid HITs
balance in your Amazon Mechanical Turk account if you are a Prepaid
Requester. Alternatively, this operation will retrieve the remaining
available AWS Billing usage if you have enabled AWS Billing. Note: If you
have enabled AWS Billing and still have a remaining Prepaid HITs balance,
this balance can be viewed on the My Account page in the Requester
console.
May throw RequestError.
May throw ServiceFault.
Implementation
Future<GetAccountBalanceResponse> getAccountBalance() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'MTurkRequesterServiceV20170117.GetAccountBalance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return GetAccountBalanceResponse.fromJson(jsonResponse.body);
}