createSampleFindings method
Creates sample findings.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter findingTypes :
An array of finding types, one for each type of sample finding to create.
To create a sample of every type of finding that Amazon Macie supports,
don't include this array in your request.
Implementation
Future<void> createSampleFindings({
List<FindingType>? findingTypes,
}) async {
final $payload = <String, dynamic>{
if (findingTypes != null)
'findingTypes': findingTypes.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/findings/sample',
exceptionFnMap: _exceptionFns,
);
}