deleteInvitations method
Deletes Amazon Macie membership invitations that were received from specific accounts.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountIds :
An array that lists Amazon Web Services account IDs, one for each account
that sent an invitation to delete.
Implementation
Future<DeleteInvitationsResponse> deleteInvitations({
required List<String> accountIds,
}) async {
final $payload = <String, dynamic>{
'accountIds': accountIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/invitations/delete',
exceptionFnMap: _exceptionFns,
);
return DeleteInvitationsResponse.fromJson(response);
}