disassociateMember method
Disassociates an Amazon Macie administrator account from a member account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The unique identifier for the Amazon Macie resource that the request
applies to.
Implementation
Future<void> disassociateMember({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/members/disassociate/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}