enableOrganizationAdminAccount method
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter adminAccountId :
The Amazon Web Services account ID for the account to designate as the
delegated Amazon Macie administrator account for the organization.
Parameter clientToken :
A unique, case-sensitive token that you provide to ensure the idempotency
of the request.
Implementation
Future<void> enableOrganizationAdminAccount({
required String adminAccountId,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'adminAccountId': adminAccountId,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/admin',
exceptionFnMap: _exceptionFns,
);
}