getBucketStatistics method
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountId :
The unique identifier for the Amazon Web Services account.
Implementation
Future<GetBucketStatisticsResponse> getBucketStatistics({
String? accountId,
}) async {
final $payload = <String, dynamic>{
if (accountId != null) 'accountId': accountId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/datasources/s3/statistics',
exceptionFnMap: _exceptionFns,
);
return GetBucketStatisticsResponse.fromJson(response);
}