getFindings method
Retrieves the details of one or more findings.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter findingIds :
An array of strings that lists the unique identifiers for the findings to
retrieve. You can specify as many as 50 unique identifiers in this array.
Parameter sortCriteria :
The criteria for sorting the results of the request.
Implementation
Future<GetFindingsResponse> getFindings({
required List<String> findingIds,
SortCriteria? sortCriteria,
}) async {
final $payload = <String, dynamic>{
'findingIds': findingIds,
if (sortCriteria != null) 'sortCriteria': sortCriteria,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/findings/describe',
exceptionFnMap: _exceptionFns,
);
return GetFindingsResponse.fromJson(response);
}