getSensitivityInspectionTemplate method
Future<GetSensitivityInspectionTemplateResponse>
getSensitivityInspectionTemplate({
- required String id,
Retrieves the settings for the sensitivity inspection template for an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The unique identifier for the Amazon Macie resource that the request
applies to.
Implementation
Future<GetSensitivityInspectionTemplateResponse>
getSensitivityInspectionTemplate({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/templates/sensitivity-inspections/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return GetSensitivityInspectionTemplateResponse.fromJson(response);
}