listClassificationScopes method
Retrieves a subset of information about the classification scope for an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the classification scope to retrieve the unique identifier
for.
Parameter nextToken :
The nextToken string that specifies which page of results to return in a
paginated response.
Implementation
Future<ListClassificationScopesResponse> listClassificationScopes({
String? name,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (name != null) 'name': [name],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/classification-scopes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListClassificationScopesResponse.fromJson(response);
}