listManagedDataIdentifiers method
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
Parameter nextToken :
The nextToken string that specifies which page of results to return in a
paginated response.
Implementation
Future<ListManagedDataIdentifiersResponse> listManagedDataIdentifiers({
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/managed-data-identifiers/list',
exceptionFnMap: _exceptionFns,
);
return ListManagedDataIdentifiersResponse.fromJson(response);
}