listMembers method
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of items to include in each page of a paginated
response.
Parameter nextToken :
The nextToken string that specifies which page of results to return in a
paginated response.
Parameter onlyAssociated :
Specifies which accounts to include in the response, based on the status
of an account's relationship with the administrator account. By default,
the response includes only current member accounts. To include all
accounts, set this value to false.
Implementation
Future<ListMembersResponse> listMembers({
int? maxResults,
String? nextToken,
String? onlyAssociated,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
25,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (onlyAssociated != null) 'onlyAssociated': [onlyAssociated],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/members',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMembersResponse.fromJson(response);
}