listResourceProfileArtifacts method
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the S3 bucket that the request applies
to.
Parameter nextToken :
The nextToken string that specifies which page of results to return in a
paginated response.
Implementation
Future<ListResourceProfileArtifactsResponse> listResourceProfileArtifacts({
required String resourceArn,
String? nextToken,
}) async {
final $query = <String, List<String>>{
'resourceArn': [resourceArn],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/resource-profiles/artifacts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListResourceProfileArtifactsResponse.fromJson(response);
}