tagResource method
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource.
Parameter tags :
A map of key-value pairs that specifies the tags to associate with the
resource.
A resource can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}