updateMemberSession method
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The unique identifier for the Amazon Macie resource that the request
applies to.
Parameter status :
Specifies the new status for the account. Valid values are: ENABLED,
resume all Amazon Macie activities for the account; and, PAUSED, suspend
all Macie activities for the account.
Implementation
Future<void> updateMemberSession({
required String id,
required MacieStatus status,
}) async {
final $payload = <String, dynamic>{
'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/macie/members/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}