updateResourceProfileDetections method
Updates the sensitivity scoring settings for an S3 bucket.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the S3 bucket that the request applies
to.
Parameter suppressDataIdentifiers :
An array of objects, one for each custom data identifier or managed data
identifier that detected a type of sensitive data to exclude from the
bucket's score. To include all sensitive data types in the score, don't
specify any values for this array.
Implementation
Future<void> updateResourceProfileDetections({
required String resourceArn,
List<SuppressDataIdentifier>? suppressDataIdentifiers,
}) async {
final $query = <String, List<String>>{
'resourceArn': [resourceArn],
};
final $payload = <String, dynamic>{
if (suppressDataIdentifiers != null)
'suppressDataIdentifiers': suppressDataIdentifiers,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/resource-profiles/detections',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}