getAccessor method
Returns detailed information about an accessor. An accessor object is a container that has the information required for token based access to your Ethereum nodes.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter accessorId :
The unique identifier of the accessor.
Implementation
Future<GetAccessorOutput> getAccessor({
required String accessorId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accessors/${Uri.encodeComponent(accessorId)}',
exceptionFnMap: _exceptionFns,
);
return GetAccessorOutput.fromJson(response);
}