untagResource method
Removes the specified tags from the Amazon Managed Blockchain resource.
For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.
May throw InternalServiceErrorException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ResourceNotReadyException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the resource. For more information about
ARNs and their format, see Amazon
Resource Names (ARNs) in the Amazon Web Services General
Reference.
Parameter tagKeys :
The tag keys.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}