MarketplaceDeployment class
The AWS Marketplace Deployment Service supports the Quick Launch experience, which is a deployment option for software as a service (SaaS) products. Quick Launch simplifies and reduces the time, resources, and steps required to configure, deploy, and launch a products. The AWS Marketplace Deployment Service provides sellers with a secure method for passing deployment parameters, such as API keys and external IDs, to buyers during the Quick Launch experience.
Constructors
- MarketplaceDeployment({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists all tags that have been added to a deployment parameter resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putDeploymentParameter(
{required String agreementId, required String catalog, required DeploymentParameterInput deploymentParameter, required String productId, String? clientToken, DateTime? expirationDate, Map< String, String> ? tags}) → Future<PutDeploymentParameterResponse> -
Creates or updates a deployment parameter and is targeted by
catalogandagreementId. -
tagResource(
{required String resourceArn, Map< String, String> ? tags}) → Future<void> - Tags a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag or list of tags from a resource.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited