createRouterNetworkInterface method
Creates a new router network interface in AWS Elemental MediaConnect.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw RouterNetworkInterfaceServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter configuration :
The configuration settings for the router network interface.
Parameter name :
The name of the router network interface.
Parameter clientToken :
A unique identifier for the request to ensure idempotency.
Parameter regionName :
The Amazon Web Services Region for the router network interface. Defaults
to the current region if not specified.
Parameter tags :
Key-value pairs that can be used to tag and organize this router network
interface.
Implementation
Future<CreateRouterNetworkInterfaceResponse> createRouterNetworkInterface({
required RouterNetworkInterfaceConfiguration configuration,
required String name,
String? clientToken,
String? regionName,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'configuration': configuration,
'name': name,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (regionName != null) 'regionName': regionName,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/routerNetworkInterface',
exceptionFnMap: _exceptionFns,
);
return CreateRouterNetworkInterfaceResponse.fromJson(response);
}