updateBridgeSource method
Updates an existing bridge source.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter bridgeArn :
The Amazon Resource Name (ARN) of the bridge that you want to update.
Parameter sourceName :
The name of the source that you want to update.
Parameter flowSource :
The name of the flow that you want to update.
Parameter networkSource :
The network for the bridge source.
Implementation
Future<UpdateBridgeSourceResponse> updateBridgeSource({
required String bridgeArn,
required String sourceName,
UpdateBridgeFlowSourceRequest? flowSource,
UpdateBridgeNetworkSourceRequest? networkSource,
}) async {
final $payload = <String, dynamic>{
if (flowSource != null) 'flowSource': flowSource,
if (networkSource != null) 'networkSource': networkSource,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/bridges/${Uri.encodeComponent(bridgeArn)}/sources/${Uri.encodeComponent(sourceName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateBridgeSourceResponse.fromJson(response);
}