updateFlow method
Future<UpdateFlowResponse>
updateFlow({
- required String flowArn,
- EncodingConfig? encodingConfig,
- FlowSize? flowSize,
- UpdateMaintenance? maintenance,
- NdiConfig? ndiConfig,
- UpdateFailoverConfig? sourceFailoverConfig,
- MonitoringConfig? sourceMonitoringConfig,
Updates an existing flow.
-
If you have a
MEDIUMflow and you want to change the flow source to NDIĀ®:-
First, use the
UpdateFlowoperation to upgrade the flow size toLARGE. -
After that, you can then use the
UpdateFlowSourceoperation to configure the NDI source.
-
First, use the
-
If you're switching from an NDI source to a transport stream (TS) source
and want to downgrade the flow size:
-
First, use the
UpdateFlowSourceoperation to change the flow source type. -
After that, you can then use the
UpdateFlowoperation to downgrade the flow size toMEDIUM.
-
First, use the
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
Parameter flowArn :
The Amazon Resource Name (ARN) of the flow that you want to update.
Parameter flowSize :
Determines the processing capacity and feature set of the flow.
Parameter maintenance :
The maintenance setting of the flow.
Parameter ndiConfig :
Specifies the configuration settings for a flow's NDI source or output.
Required when the flow includes an NDI source or output.
Parameter sourceFailoverConfig :
The settings for source failover.
Parameter sourceMonitoringConfig :
The settings for source monitoring.
Implementation
Future<UpdateFlowResponse> updateFlow({
required String flowArn,
EncodingConfig? encodingConfig,
FlowSize? flowSize,
UpdateMaintenance? maintenance,
NdiConfig? ndiConfig,
UpdateFailoverConfig? sourceFailoverConfig,
MonitoringConfig? sourceMonitoringConfig,
}) async {
final $payload = <String, dynamic>{
if (encodingConfig != null) 'encodingConfig': encodingConfig,
if (flowSize != null) 'flowSize': flowSize.value,
if (maintenance != null) 'maintenance': maintenance,
if (ndiConfig != null) 'ndiConfig': ndiConfig,
if (sourceFailoverConfig != null)
'sourceFailoverConfig': sourceFailoverConfig,
if (sourceMonitoringConfig != null)
'sourceMonitoringConfig': sourceMonitoringConfig,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/v1/flows/${Uri.encodeComponent(flowArn)}',
exceptionFnMap: _exceptionFns,
);
return UpdateFlowResponse.fromJson(response);
}