tagResource method
Add tags to a MediaConvert queue, preset, job, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-mediaconvert-resources.html.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
Parameter arn :
The Amazon Resource Name (ARN) of the resource that you want to tag. To
get the ARN, send a GET request with the resource name.
Parameter tags :
The tags that you want to add to the resource. You can tag resources with
a key-value pair or with only a key.
Implementation
Future<void> tagResource({
required String arn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'arn': arn,
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/2017-08-29/tags',
exceptionFnMap: _exceptionFns,
);
}