claimDevice method
Send a request to claim an AWS Elemental device that you have purchased from a third-party vendor. After the request succeeds, you will own the device.
May throw BadGatewayException.
May throw BadRequestException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
May throw UnprocessableEntityException.
Parameter id :
The id of the device you want to claim.
Implementation
Future<void> claimDevice({
String? id,
}) async {
final $payload = <String, dynamic>{
if (id != null) 'id': id,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/prod/claimDevice',
exceptionFnMap: _exceptionFns,
);
}