createChannel method
- AnywhereSettings? anywhereSettings,
- CdiInputSpecification? cdiInputSpecification,
- ChannelClass? channelClass,
- ChannelEngineVersionRequest? channelEngineVersion,
- List<
String> ? channelSecurityGroups, - List<
OutputDestination> ? destinations, - bool? dryRun,
- EncoderSettings? encoderSettings,
- InferenceSettings? inferenceSettings,
- List<
InputAttachment> ? inputAttachments, - InputSpecification? inputSpecification,
- LinkedChannelSettings? linkedChannelSettings,
- LogLevel? logLevel,
- MaintenanceCreateSettings? maintenance,
- String? name,
- String? requestId,
- String? reserved,
- String? roleArn,
- Map<
String, String> ? tags, - VpcOutputSettings? vpc,
Creates a new channel
May throw BadGatewayException.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw GatewayTimeoutException.
May throw InternalServerErrorException.
May throw TooManyRequestsException.
May throw UnprocessableEntityException.
Parameter anywhereSettings :
The Elemental Anywhere settings for this channel.
Parameter cdiInputSpecification :
Specification of CDI inputs for this channel
Parameter channelClass :
The class for this channel. STANDARD for a channel with two pipelines or
SINGLE_PIPELINE for a channel with one pipeline.
Parameter channelEngineVersion :
The desired engine version for this channel.
Parameter channelSecurityGroups :
A list of IDs for all the Input Security Groups attached to the channel.
Parameter inferenceSettings :
Include this setting to include Elemental Inference features in this
channel.
Parameter inputAttachments :
List of input attachments for channel.
Parameter inputSpecification :
Specification of network and file inputs for this channel
Parameter linkedChannelSettings :
The linked channel settings for the channel.
Parameter logLevel :
The log level to write to CloudWatch Logs.
Parameter maintenance :
Maintenance settings for this channel.
Parameter name :
Name of channel.
Parameter requestId :
Unique request ID to be specified. This is needed to prevent retries from
creating multiple resources.
Parameter reserved :
Deprecated field that's only usable by whitelisted customers.
Parameter roleArn :
An optional Amazon Resource Name (ARN) of the role to assume when running
the Channel.
Parameter tags :
A collection of key-value pairs.
Parameter vpc :
Settings for the VPC outputs
Implementation
Future<CreateChannelResponse> createChannel({
AnywhereSettings? anywhereSettings,
CdiInputSpecification? cdiInputSpecification,
ChannelClass? channelClass,
ChannelEngineVersionRequest? channelEngineVersion,
List<String>? channelSecurityGroups,
List<OutputDestination>? destinations,
bool? dryRun,
EncoderSettings? encoderSettings,
InferenceSettings? inferenceSettings,
List<InputAttachment>? inputAttachments,
InputSpecification? inputSpecification,
LinkedChannelSettings? linkedChannelSettings,
LogLevel? logLevel,
MaintenanceCreateSettings? maintenance,
String? name,
String? requestId,
String? reserved,
String? roleArn,
Map<String, String>? tags,
VpcOutputSettings? vpc,
}) async {
final $payload = <String, dynamic>{
if (anywhereSettings != null) 'anywhereSettings': anywhereSettings,
if (cdiInputSpecification != null)
'cdiInputSpecification': cdiInputSpecification,
if (channelClass != null) 'channelClass': channelClass.value,
if (channelEngineVersion != null)
'channelEngineVersion': channelEngineVersion,
if (channelSecurityGroups != null)
'channelSecurityGroups': channelSecurityGroups,
if (destinations != null) 'destinations': destinations,
if (dryRun != null) 'dryRun': dryRun,
if (encoderSettings != null) 'encoderSettings': encoderSettings,
if (inferenceSettings != null) 'inferenceSettings': inferenceSettings,
if (inputAttachments != null) 'inputAttachments': inputAttachments,
if (inputSpecification != null) 'inputSpecification': inputSpecification,
if (linkedChannelSettings != null)
'linkedChannelSettings': linkedChannelSettings,
if (logLevel != null) 'logLevel': logLevel.value,
if (maintenance != null) 'maintenance': maintenance,
if (name != null) 'name': name,
'requestId': requestId ?? _s.generateIdempotencyToken(),
if (reserved != null) 'reserved': reserved,
if (roleArn != null) 'roleArn': roleArn,
if (tags != null) 'tags': tags,
if (vpc != null) 'vpc': vpc,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/prod/channels',
exceptionFnMap: _exceptionFns,
);
return CreateChannelResponse.fromJson(response);
}