Create a channel to start receiving content streams. The channel
represents the input to MediaPackage for incoming live content from an
encoder such as AWS Elemental MediaLive. The channel receives content, and
after packaging it, outputs it through an origin endpoint to downstream
devices (such as video players or CDNs) that request the content. You can
create only one channel with each request. We recommend that you spread
out channels between channel groups, such as putting redundant channels in
the same AWS Region in different channel groups.
Create a channel group to group your channels and origin endpoints. A
channel group is the top-level resource that consists of channels and
origin endpoints that are associated with it and that provides predictable
URLs for stream delivery. All channels and origin endpoints within the
channel group are guaranteed to share the DNS. You can create only one
channel group with each request.
The endpoint is attached to a channel, and represents the output of the
live content. You can associate multiple endpoints to a single channel.
Each endpoint gives players and downstream CDNs (such as Amazon
CloudFront) access to the content for playback. Content can't be served
from a channel until it has an endpoint. You can create only one endpoint
with each request.
Delete a channel to stop AWS Elemental MediaPackage from receiving further
content. You must delete the channel's origin endpoints before you can
delete the channel.
Delete a channel group. You must delete the channel group's channels and
origin endpoints before you can delete the channel group. If you delete a
channel group, you'll lose access to the egress domain and will have to
create a new channel group to replace it.
Origin endpoints can serve content until they're deleted. Delete the
endpoint if it should no longer respond to playback requests. You must
delete all endpoints from a channel before you can delete the channel.
Retrieves the specified channel policy that's configured in AWS Elemental
MediaPackage. With policies, you can specify who has access to AWS
resources and what actions they can perform on those resources.
Retrieves the specified origin endpoint that's configured in AWS Elemental
MediaPackage to obtain its playback URL and to view the packaging settings
that it's currently using.
Attaches an IAM policy to the specified channel. With policies, you can
specify who has access to AWS resources and what actions they can perform
on those resources. You can attach only one policy with each request.
Resetting the channel can help to clear errors from misconfigurations in
the encoder. A reset refreshes the ingest stream and removes previous
content.
Resetting the origin endpoint can help to resolve unexpected behavior and
other content packaging issues. It also helps to preserve special events
when you don't want the previous content to be available for viewing. A
reset clears out all previous content from the origin endpoint.
Update the specified channel. You can edit if MediaPackage sends ingest or
egress access logs to the CloudWatch log group, if content will be
encrypted, the description on a channel, and your channel's policy
settings. You can't edit the name of the channel or CloudFront
distribution details.
Update the specified channel group. You can edit the description on a
channel group for easier identification later from the AWS Elemental
MediaPackage console. You can't edit the name of the channel group.
Update the specified origin endpoint. Edit the packaging preferences on an
endpoint to optimize the viewing experience. You can't edit the name of
the endpoint.