getChannelPolicy method
Retrieves the specified channel policy that's configured in AWS Elemental MediaPackage. With policies, you can specify who has access to AWS resources and what actions they can perform on those resources.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelGroupName :
The name that describes the channel group. The name is the primary
identifier for the channel group, and must be unique for your account in
the AWS Region.
Parameter channelName :
The name that describes the channel. The name is the primary identifier
for the channel, and must be unique for your account in the AWS Region and
channel group.
Implementation
Future<GetChannelPolicyResponse> getChannelPolicy({
required String channelGroupName,
required String channelName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/channelGroup/${Uri.encodeComponent(channelGroupName)}/channel/${Uri.encodeComponent(channelName)}/policy',
exceptionFnMap: _exceptionFns,
);
return GetChannelPolicyResponse.fromJson(response);
}