deleteFunction method
Deletes a function. MediaTailor prevents deletion of a function that is still referenced by a playback configuration or by another function. Remove all references before deleting. For more information about functions, see Working with functions in the MediaTailor User Guide.
Parameter functionId :
The identifier of the function to delete.
Implementation
Future<void> deleteFunction({
required String functionId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/function/${Uri.encodeComponent(functionId)}',
exceptionFnMap: _exceptionFns,
);
}