deletePrefetchSchedule method
Deletes a prefetch schedule for a specific playback configuration. If you
call DeletePrefetchSchedule on an expired prefetch schedule,
MediaTailor returns an HTTP 404 status code. For more information about ad
prefetching, see Using
ad prefetching in the MediaTailor User Guide.
Parameter name :
The name of the prefetch schedule. If the action is successful, the
service sends back an HTTP 204 response with an empty HTTP body.
Parameter playbackConfigurationName :
The name of the playback configuration for this prefetch schedule.
Implementation
Future<void> deletePrefetchSchedule({
required String name,
required String playbackConfigurationName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/prefetchSchedule/${Uri.encodeComponent(playbackConfigurationName)}/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
}