describeProgram method
Describes a program within a channel. For information about programs, see Working with programs in the MediaTailor User Guide.
Parameter channelName :
The name of the channel associated with this Program.
Parameter programName :
The name of the program.
Implementation
Future<DescribeProgramResponse> describeProgram({
required String channelName,
required String programName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/channel/${Uri.encodeComponent(channelName)}/program/${Uri.encodeComponent(programName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeProgramResponse.fromJson(response);
}