getChannelPolicy method
Returns the channel's IAM policy. IAM policies are used to control access to your channel.
Parameter channelName :
The name of the channel associated with this Channel Policy.
Implementation
Future<GetChannelPolicyResponse> getChannelPolicy({
required String channelName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/channel/${Uri.encodeComponent(channelName)}/policy',
exceptionFnMap: _exceptionFns,
);
return GetChannelPolicyResponse.fromJson(response);
}