listFunctions method
Retrieves all functions associated with your AWS account in the current Region. For more information about functions, see Working with functions in the MediaTailor User Guide.
Parameter maxResults :
The maximum number of functions that you want MediaTailor to return in
response to the current request. If there are more than
MaxResults functions, use the value of NextToken
in the response to get the next page of results.
The default value is 100. MediaTailor uses token-based pagination, which
means that a response might contain fewer than MaxResults
items, including 0 items, even when more results are available. To
retrieve all results, you must continue making requests using the
NextToken value from each response until the response no
longer includes a NextToken value.
Parameter nextToken :
Pagination token returned by the list request when results exceed the
maximum allowed. Use the token to fetch the next page of results.
For the first ListFunctions request, omit this value. For
subsequent requests, get the value of NextToken from the
previous response and specify that value for NextToken in the
request. Continue making requests until the response no longer includes a
NextToken value, which indicates that all results have been
retrieved.
Implementation
Future<ListFunctionsResponse> listFunctions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/functions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFunctionsResponse.fromJson(response);
}