updateSourceLocation method
Updates a source location. A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
Parameter httpConfiguration :
The HTTP configuration for the source location.
Parameter sourceLocationName :
The name of the source location.
Parameter accessConfiguration :
Access configuration parameters. Configures the type of authentication
used to access content from your source location.
Parameter defaultSegmentDeliveryConfiguration :
The optional configuration for the host server that serves segments.
Parameter segmentDeliveryConfigurations :
A list of the segment delivery configurations associated with this
resource.
Implementation
Future<UpdateSourceLocationResponse> updateSourceLocation({
required HttpConfiguration httpConfiguration,
required String sourceLocationName,
AccessConfiguration? accessConfiguration,
DefaultSegmentDeliveryConfiguration? defaultSegmentDeliveryConfiguration,
List<SegmentDeliveryConfiguration>? segmentDeliveryConfigurations,
}) async {
final $payload = <String, dynamic>{
'HttpConfiguration': httpConfiguration,
if (accessConfiguration != null)
'AccessConfiguration': accessConfiguration,
if (defaultSegmentDeliveryConfiguration != null)
'DefaultSegmentDeliveryConfiguration':
defaultSegmentDeliveryConfiguration,
if (segmentDeliveryConfigurations != null)
'SegmentDeliveryConfigurations': segmentDeliveryConfigurations,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/sourceLocation/${Uri.encodeComponent(sourceLocationName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateSourceLocationResponse.fromJson(response);
}