deleteACL method
Deletes an Access Control List. The ACL must first be disassociated from the cluster before it can be deleted. For more information, see Authenticating users with Access Contol Lists (ACLs).
May throw ACLNotFoundFault.
May throw InvalidACLStateFault.
May throw InvalidParameterValueException.
Parameter aCLName :
The name of the Access Control List to delete.
Implementation
Future<DeleteACLResponse> deleteACL({
required String aCLName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.DeleteACL'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ACLName': aCLName,
},
);
return DeleteACLResponse.fromJson(jsonResponse.body);
}