describeMultiRegionParameterGroups method
Returns a list of multi-region parameter groups.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw MultiRegionParameterGroupNotFoundFault.
May throw ServiceLinkedRoleNotFoundFault.
Parameter maxResults :
The maximum number of records to include in the response. If more records
exist than the specified MaxResults value, a token is included in the
response so that the remaining results can be retrieved.
Parameter multiRegionParameterGroupName :
The request for information on a specific multi-region parameter group.
Parameter nextToken :
An optional token returned from a prior request. Use this token for
pagination of results from this action. If this parameter is specified,
the response includes only results beyond the token, up to the value
specified by MaxResults.
Implementation
Future<DescribeMultiRegionParameterGroupsResponse>
describeMultiRegionParameterGroups({
int? maxResults,
String? multiRegionParameterGroupName,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.DescribeMultiRegionParameterGroups'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (multiRegionParameterGroupName != null)
'MultiRegionParameterGroupName': multiRegionParameterGroupName,
if (nextToken != null) 'NextToken': nextToken,
},
);
return DescribeMultiRegionParameterGroupsResponse.fromJson(
jsonResponse.body);
}