describeMultiRegionParameters method
Returns the detailed parameter list for a particular multi-region parameter group.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
May throw MultiRegionParameterGroupNotFoundFault.
May throw ServiceLinkedRoleNotFoundFault.
Parameter multiRegionParameterGroupName :
The name of the multi-region parameter group to return details for.
Parameter maxResults :
The maximum number of records to include in the response. If more records
exist than the specified MaxResults value, a token is included in the
response so that the remaining results can be retrieved.
Parameter nextToken :
An optional token returned from a prior request. Use this token for
pagination of results from this action. If this parameter is specified,
the response includes only results beyond the token, up to the value
specified by MaxResults.
Parameter source :
The parameter types to return. Valid values: user | system |
engine-default
Implementation
Future<DescribeMultiRegionParametersResponse> describeMultiRegionParameters({
required String multiRegionParameterGroupName,
int? maxResults,
String? nextToken,
String? source,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.DescribeMultiRegionParameters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'MultiRegionParameterGroupName': multiRegionParameterGroupName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (source != null) 'Source': source,
},
);
return DescribeMultiRegionParametersResponse.fromJson(jsonResponse.body);
}