describeServiceUpdates method
Returns details of the service updates.
May throw InvalidParameterCombinationException.
May throw InvalidParameterValueException.
Parameter clusterNames :
The list of cluster names to identify service updates to apply.
Parameter maxResults :
The maximum number of records to include in the response. If more records
exist than the specified MaxResults value, a token is included in the
response so that the remaining results can be retrieved.
Parameter nextToken :
An optional argument to pass in case the total number of records exceeds
the value of MaxResults. If nextToken is returned, there are more results
available. The value of nextToken is a unique pagination token for each
page. Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged.
Parameter serviceUpdateName :
The unique ID of the service update to describe.
Parameter status :
The status(es) of the service updates to filter on.
Implementation
Future<DescribeServiceUpdatesResponse> describeServiceUpdates({
List<String>? clusterNames,
int? maxResults,
String? nextToken,
String? serviceUpdateName,
List<ServiceUpdateStatus>? status,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.DescribeServiceUpdates'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (clusterNames != null) 'ClusterNames': clusterNames,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (serviceUpdateName != null) 'ServiceUpdateName': serviceUpdateName,
if (status != null) 'Status': status.map((e) => e.value).toList(),
},
);
return DescribeServiceUpdatesResponse.fromJson(jsonResponse.body);
}