resetParameterGroup method
Modifies the parameters of a parameter group to the engine or system default value. You can reset specific parameters by submitting a list of parameter names. To reset the entire parameter group, specify the AllParameters and ParameterGroupName parameters.
May throw InvalidParameterCombinationException.
May throw InvalidParameterGroupStateFault.
May throw InvalidParameterValueException.
May throw ParameterGroupNotFoundFault.
May throw ServiceLinkedRoleNotFoundFault.
Parameter parameterGroupName :
The name of the parameter group to reset.
Parameter allParameters :
If true, all parameters in the parameter group are reset to their default
values. If false, only the parameters listed by ParameterNames are reset
to their default values.
Parameter parameterNames :
An array of parameter names to reset to their default values. If
AllParameters is true, do not use ParameterNames. If AllParameters is
false, you must specify the name of at least one parameter to reset.
Implementation
Future<ResetParameterGroupResponse> resetParameterGroup({
required String parameterGroupName,
bool? allParameters,
List<String>? parameterNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonMemoryDB.ResetParameterGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ParameterGroupName': parameterGroupName,
if (allParameters != null) 'AllParameters': allParameters,
if (parameterNames != null) 'ParameterNames': parameterNames,
},
);
return ResetParameterGroupResponse.fromJson(jsonResponse.body);
}