deleteJob method
Deletes a single Job by ID.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
Parameter jobID :
Request to delete Job from service by Job ID.
Parameter accountID :
Request to delete Job from service by Account ID.
Implementation
Future<void> deleteJob({
required String jobID,
String? accountID,
}) async {
final $payload = <String, dynamic>{
'jobID': jobID,
if (accountID != null) 'accountID': accountID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteJob',
exceptionFnMap: _exceptionFns,
);
}