deleteNetworkMigrationDefinition method
Deletes a network migration definition. This operation removes the migration definition and all associated metadata.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition to delete.
Implementation
Future<void> deleteNetworkMigrationDefinition({
required String networkMigrationDefinitionID,
}) async {
final $payload = <String, dynamic>{
'networkMigrationDefinitionID': networkMigrationDefinitionID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/DeleteNetworkMigrationDefinition',
exceptionFnMap: _exceptionFns,
);
}