deleteSourceServer method
Deletes a single source server by ID.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
Parameter sourceServerID :
Request to delete Source Server from service by Server ID.
Parameter accountID :
Request to delete Source Server from service by Account ID.
Implementation
Future<void> deleteSourceServer({
required String sourceServerID,
String? accountID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
if (accountID != null) 'accountID': accountID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteSourceServer',
exceptionFnMap: _exceptionFns,
);
}