describeReplicationConfigurationTemplates method
Future<DescribeReplicationConfigurationTemplatesResponse>
describeReplicationConfigurationTemplates({})
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter maxResults :
Request to describe Replication Configuration template by max results.
Parameter nextToken :
Request to describe Replication Configuration template by next token.
Parameter replicationConfigurationTemplateIDs :
Request to describe Replication Configuration template by template IDs.
Implementation
Future<DescribeReplicationConfigurationTemplatesResponse>
describeReplicationConfigurationTemplates({
int? maxResults,
String? nextToken,
List<String>? replicationConfigurationTemplateIDs,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (replicationConfigurationTemplateIDs != null)
'replicationConfigurationTemplateIDs':
replicationConfigurationTemplateIDs,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DescribeReplicationConfigurationTemplates',
exceptionFnMap: _exceptionFns,
);
return DescribeReplicationConfigurationTemplatesResponse.fromJson(response);
}