finalizeCutover method
Finalizes the cutover immediately for specific Source Servers. All AWS resources created by Application Migration Service for enabling the replication of these source servers will be terminated / deleted within 90 minutes. Launched Test or Cutover instances will NOT be terminated. The AWS Replication Agent will receive a command to uninstall itself (within 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be changed to DISCONNECTED; The SourceServer.lifeCycle.state will be changed to CUTOVER; The totalStorageBytes property fo each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
May throw ValidationException.
Parameter sourceServerID :
Request to finalize Cutover by Source Server ID.
Parameter accountID :
Request to finalize Cutover by Source Account ID.
Implementation
Future<SourceServer> finalizeCutover({
required String sourceServerID,
String? accountID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
if (accountID != null) 'accountID': accountID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/FinalizeCutover',
exceptionFnMap: _exceptionFns,
);
return SourceServer.fromJson(response);
}