getLaunchConfiguration method
Lists all LaunchConfigurations available, filtered by Source Server IDs.
May throw ResourceNotFoundException.
May throw UninitializedAccountException.
Parameter sourceServerID :
Request to get Launch Configuration information by Source Server ID.
Parameter accountID :
Request to get Launch Configuration information by Account ID.
Implementation
Future<LaunchConfiguration> getLaunchConfiguration({
required String sourceServerID,
String? accountID,
}) async {
final $payload = <String, dynamic>{
'sourceServerID': sourceServerID,
if (accountID != null) 'accountID': accountID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetLaunchConfiguration',
exceptionFnMap: _exceptionFns,
);
return LaunchConfiguration.fromJson(response);
}