getNetworkMigrationDefinition method
Future<NetworkMigrationDefinition>
getNetworkMigrationDefinition({
- required String networkMigrationDefinitionID,
Retrieves the details of a network migration definition including source and target configurations.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition to retrieve.
Implementation
Future<NetworkMigrationDefinition> getNetworkMigrationDefinition({
required String networkMigrationDefinitionID,
}) async {
final $payload = <String, dynamic>{
'networkMigrationDefinitionID': networkMigrationDefinitionID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/GetNetworkMigrationDefinition',
exceptionFnMap: _exceptionFns,
);
return NetworkMigrationDefinition.fromJson(response);
}