getNetworkMigrationMapperSegmentConstruct method
Future<GetNetworkMigrationMapperSegmentConstructResponse>
getNetworkMigrationMapperSegmentConstruct({})
Retrieves detailed information about a specific construct within a mapper segment, including its properties and configuration data.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter constructID :
The unique identifier of the construct within the segment.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition.
Parameter networkMigrationExecutionID :
The unique identifier of the network migration execution.
Parameter segmentID :
The unique identifier of the mapper segment.
Implementation
Future<GetNetworkMigrationMapperSegmentConstructResponse>
getNetworkMigrationMapperSegmentConstruct({
required String constructID,
required String networkMigrationDefinitionID,
required String networkMigrationExecutionID,
required String segmentID,
}) async {
final $payload = <String, dynamic>{
'constructID': constructID,
'networkMigrationDefinitionID': networkMigrationDefinitionID,
'networkMigrationExecutionID': networkMigrationExecutionID,
'segmentID': segmentID,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/network-migration/GetNetworkMigrationMapperSegmentConstruct',
exceptionFnMap: _exceptionFns,
);
return GetNetworkMigrationMapperSegmentConstructResponse.fromJson(response);
}