listNetworkMigrationDeployedStacks method
Lists CloudFormation stacks that have been deployed as part of the network migration.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition.
Parameter networkMigrationExecutionID :
The unique identifier of the network migration execution.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListNetworkMigrationDeployedStacksResponse>
listNetworkMigrationDeployedStacks({
required String networkMigrationDefinitionID,
required String networkMigrationExecutionID,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'networkMigrationDefinitionID': networkMigrationDefinitionID,
'networkMigrationExecutionID': networkMigrationExecutionID,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/ListNetworkMigrationDeployedStacks',
exceptionFnMap: _exceptionFns,
);
return ListNetworkMigrationDeployedStacksResponse.fromJson(response);
}