startNetworkMigrationCodeGeneration method
Starts a code generation job to convert network migration mappings into infrastructure-as-code templates.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter networkMigrationDefinitionID :
The unique identifier of the network migration definition.
Parameter networkMigrationExecutionID :
The unique identifier of the network migration execution.
Parameter codeGenerationOutputFormatTypes :
The output format types for code generation, such as CloudFormation or
Terraform.
Implementation
Future<StartNetworkMigrationCodeGenerationResponse>
startNetworkMigrationCodeGeneration({
required String networkMigrationDefinitionID,
required String networkMigrationExecutionID,
List<CodeGenerationOutputFormatType>? codeGenerationOutputFormatTypes,
}) async {
final $payload = <String, dynamic>{
'networkMigrationDefinitionID': networkMigrationDefinitionID,
'networkMigrationExecutionID': networkMigrationExecutionID,
if (codeGenerationOutputFormatTypes != null)
'codeGenerationOutputFormatTypes':
codeGenerationOutputFormatTypes.map((e) => e.value).toList(),
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/network-migration/StartNetworkMigrationCodeGeneration',
exceptionFnMap: _exceptionFns,
);
return StartNetworkMigrationCodeGenerationResponse.fromJson(response);
}