deleteWorkflow method
Delete a migration workflow. You must pause a running workflow in Migration Hub Orchestrator console to delete it.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The ID of the migration workflow you want to delete.
Implementation
Future<DeleteMigrationWorkflowResponse> deleteWorkflow({
required String id,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/migrationworkflow/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return DeleteMigrationWorkflowResponse.fromJson(response);
}