deleteRoute method
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationIdentifier :
The ID of the application to delete the route from.
Parameter environmentIdentifier :
The ID of the environment to delete the route from.
Parameter routeIdentifier :
The ID of the route to delete.
Implementation
Future<DeleteRouteResponse> deleteRoute({
required String applicationIdentifier,
required String environmentIdentifier,
required String routeIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/environments/${Uri.encodeComponent(environmentIdentifier)}/applications/${Uri.encodeComponent(applicationIdentifier)}/routes/${Uri.encodeComponent(routeIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return DeleteRouteResponse.fromJson(response);
}