deleteInactiveApprovalTeamVersion method
Deletes an inactive approval team. For more information, see Team health in the Multi-party approval User Guide.
You can also use this operation to delete a team draft. For more information, see Interacting with drafts in the Multi-party approval User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
Amaazon Resource Name (ARN) for the team.
Parameter versionId :
Version ID for the team.
Implementation
Future<void> deleteInactiveApprovalTeamVersion({
required String arn,
required String versionId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/approval-teams/${Uri.encodeComponent(arn)}/${Uri.encodeComponent(versionId)}',
exceptionFnMap: _exceptionFns,
);
}