tagResource method
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Amazon MWAA environment. For
example,
arn:aws:airflow:us-east-1:123456789012:environment/MyMWAAEnvironment.
Parameter tags :
The key-value tag pairs you want to associate to your environment. For
example, "Environment": "Staging". For more information,
refer to Tagging
Amazon Web Services resources.
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}