removeFromGlobalCluster method
Detaches a Neptune DB cluster from a Neptune global database. A secondary cluster becomes a normal standalone cluster with read-write capability instead of being read-only, and no longer receives data from the primary cluster.
May throw DBClusterNotFoundFault.
May throw GlobalClusterNotFoundFault.
May throw InvalidGlobalClusterStateFault.
Parameter dbClusterIdentifier :
The Amazon Resource Name (ARN) identifying the cluster to be detached from
the Neptune global database cluster.
Parameter globalClusterIdentifier :
The identifier of the Neptune global database from which to detach the
specified Neptune DB cluster.
Implementation
Future<RemoveFromGlobalClusterResult> removeFromGlobalCluster({
required String dbClusterIdentifier,
required String globalClusterIdentifier,
}) async {
final $request = <String, String>{
'DbClusterIdentifier': dbClusterIdentifier,
'GlobalClusterIdentifier': globalClusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'RemoveFromGlobalCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RemoveFromGlobalClusterResult',
);
return RemoveFromGlobalClusterResult.fromXml($result);
}