restoreDBClusterFromSnapshot method
- required String dBClusterIdentifier,
- required String engine,
- required String snapshotIdentifier,
- List<
String> ? availabilityZones, - bool? copyTagsToSnapshot,
- String? dBClusterParameterGroupName,
- String? dBSubnetGroupName,
- String? databaseName,
- bool? deletionProtection,
- List<
String> ? enableCloudwatchLogsExports, - bool? enableIAMDatabaseAuthentication,
- String? engineVersion,
- String? kmsKeyId,
- String? optionGroupName,
- int? port,
- ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
- String? storageType,
- List<
Tag> ? tags, - List<
String> ? vpcSecurityGroupIds,
Creates a new DB cluster from a DB snapshot or DB cluster snapshot.
If a DB snapshot is specified, the target DB cluster is created from the source DB snapshot with a default configuration and default security group.
If a DB cluster snapshot is specified, the target DB cluster is created from the source DB cluster restore point with the same configuration as the original source DB cluster, except that the new DB cluster is created with the default security group.
May throw DBClusterAlreadyExistsFault.
May throw DBClusterParameterGroupNotFoundFault.
May throw DBClusterQuotaExceededFault.
May throw DBClusterSnapshotNotFoundFault.
May throw DBSnapshotNotFoundFault.
May throw DBSubnetGroupNotFoundFault.
May throw InsufficientDBClusterCapacityFault.
May throw InsufficientStorageClusterCapacityFault.
May throw InvalidDBClusterSnapshotStateFault.
May throw InvalidDBSnapshotStateFault.
May throw InvalidRestoreFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw OptionGroupNotFoundFault.
May throw StorageQuotaExceededFault.
Parameter dBClusterIdentifier :
The name of the DB cluster to create from the DB snapshot or DB cluster
snapshot. This parameter isn't case-sensitive.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens
- First character must be a letter
- Cannot end with a hyphen or contain two consecutive hyphens
my-snapshot-id
Parameter engine :
The database engine to use for the new DB cluster.
Default: The same as source
Constraint: Must be compatible with the engine of the source
Parameter snapshotIdentifier :
The identifier for the DB snapshot or DB cluster snapshot to restore from.
You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot.
Constraints:
- Must match the identifier of an existing Snapshot.
Parameter availabilityZones :
Provides the list of EC2 Availability Zones that instances in the restored
DB cluster can be created in.
Parameter copyTagsToSnapshot :
If set to true, tags are copied to any snapshot of the
restored DB cluster that is created.
Parameter dBClusterParameterGroupName :
The name of the DB cluster parameter group to associate with the new DB
cluster.
Constraints:
- If supplied, must match the name of an existing DBClusterParameterGroup.
Parameter dBSubnetGroupName :
The name of the DB subnet group to use for the new DB cluster.
Constraints: If supplied, must match the name of an existing DBSubnetGroup.
Example: mySubnetgroup
Parameter databaseName :
Not supported.
Parameter deletionProtection :
A value that indicates whether the DB cluster has deletion protection
enabled. The database can't be deleted when deletion protection is
enabled. By default, deletion protection is disabled.
Parameter enableCloudwatchLogsExports :
The list of logs that the restored DB cluster is to export to Amazon
CloudWatch Logs.
Parameter enableIAMDatabaseAuthentication :
True to enable mapping of Amazon Identity and Access Management (IAM)
accounts to database accounts, and otherwise false.
Default: false
Parameter engineVersion :
The version of the database engine to use for the new DB cluster.
Parameter kmsKeyId :
The Amazon KMS key identifier to use when restoring an encrypted DB
cluster from a DB snapshot or DB cluster snapshot.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a DB cluster with the same Amazon account that owns the KMS encryption key used to encrypt the new DB cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
If you do not specify a value for the KmsKeyId parameter,
then the following will occur:
-
If the DB snapshot or DB cluster snapshot in
SnapshotIdentifieris encrypted, then the restored DB cluster is encrypted using the KMS key that was used to encrypt the DB snapshot or DB cluster snapshot. -
If the DB snapshot or DB cluster snapshot in
SnapshotIdentifieris not encrypted, then the restored DB cluster is not encrypted.
Parameter optionGroupName :
(Not supported by Neptune)
Parameter port :
The port number on which the new DB cluster accepts connections.
Constraints: Value must be 1150-65535
Default: The same port as the original DB cluster.
Parameter serverlessV2ScalingConfiguration :
Contains the scaling configuration of a Neptune Serverless DB cluster.
For more information, see Using Amazon Neptune Serverless in the Amazon Neptune User Guide.
Parameter storageType :
Specifies the storage type to be associated with the DB cluster.
Valid values: standard, iopt1
Default: standard
Parameter tags :
The tags to be assigned to the restored DB cluster.
Parameter vpcSecurityGroupIds :
A list of VPC security groups that the new DB cluster will belong to.
Implementation
Future<RestoreDBClusterFromSnapshotResult> restoreDBClusterFromSnapshot({
required String dBClusterIdentifier,
required String engine,
required String snapshotIdentifier,
List<String>? availabilityZones,
bool? copyTagsToSnapshot,
String? dBClusterParameterGroupName,
String? dBSubnetGroupName,
String? databaseName,
bool? deletionProtection,
List<String>? enableCloudwatchLogsExports,
bool? enableIAMDatabaseAuthentication,
String? engineVersion,
String? kmsKeyId,
String? optionGroupName,
int? port,
ServerlessV2ScalingConfiguration? serverlessV2ScalingConfiguration,
String? storageType,
List<Tag>? tags,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
'Engine': engine,
'SnapshotIdentifier': snapshotIdentifier,
if (availabilityZones != null)
if (availabilityZones.isEmpty)
'AvailabilityZones': ''
else
for (var i1 = 0; i1 < availabilityZones.length; i1++)
'AvailabilityZones.AvailabilityZone.${i1 + 1}':
availabilityZones[i1],
if (copyTagsToSnapshot != null)
'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
if (dBClusterParameterGroupName != null)
'DBClusterParameterGroupName': dBClusterParameterGroupName,
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (databaseName != null) 'DatabaseName': databaseName,
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (enableIAMDatabaseAuthentication != null)
'EnableIAMDatabaseAuthentication':
enableIAMDatabaseAuthentication.toString(),
if (engineVersion != null) 'EngineVersion': engineVersion,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (optionGroupName != null) 'OptionGroupName': optionGroupName,
if (port != null) 'Port': port.toString(),
if (serverlessV2ScalingConfiguration != null)
for (var e1 in serverlessV2ScalingConfiguration.toQueryMap().entries)
'ServerlessV2ScalingConfiguration.${e1.key}': e1.value,
if (storageType != null) 'StorageType': storageType,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreDBClusterFromSnapshot',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreDBClusterFromSnapshotResult',
);
return RestoreDBClusterFromSnapshotResult.fromXml($result);
}