tagResource method
Adds tags to the specified resource.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
ARN of the resource for which tags need to be added.
Parameter tags :
The tags to be assigned to the Neptune Analytics resource.
The tags are metadata that are specified as a list of key-value pairs:
Key (string) – A key is the required name of the tag. The string
value can be from 1 to 128 Unicode characters in length. It can't be
prefixed with aws: and can only contain the set of Unicode
characters specified by this Java regular expression:
"^([\p{L}\p{Z}\p{N}_.:/=+-]*)$").
Value (string) – A value is the optional value of the tag. The
string value can be from 1 to 256 Unicode characters in length. It can't
be prefixed with aws: and can only contain the set of Unicode
characters specified by this Java regular expression:
"^([\p{L}\p{Z}\p{N}_.:/=+-]*)$").
Implementation
Future<void> tagResource({
required String resourceArn,
required Map<String, String> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
}