updateGraph method
Updates the configuration of a specified Neptune Analytics graph
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter graphIdentifier :
The unique identifier of the Neptune Analytics graph.
Parameter deletionProtection :
A value that indicates whether the graph has deletion protection enabled.
The graph can't be deleted when deletion protection is enabled.
Parameter provisionedMemory :
The provisioned memory-optimized Neptune Capacity Units (m-NCUs) to use
for the graph.
Min = 16
Parameter publicConnectivity :
Specifies whether or not the graph can be reachable over the internet. All
access to graphs is IAM authenticated. (true to enable, or
false to disable.
Implementation
Future<UpdateGraphOutput> updateGraph({
required String graphIdentifier,
bool? deletionProtection,
int? provisionedMemory,
bool? publicConnectivity,
}) async {
_s.validateNumRange(
'provisionedMemory',
provisionedMemory,
16,
24576,
);
final $payload = <String, dynamic>{
if (deletionProtection != null) 'deletionProtection': deletionProtection,
if (provisionedMemory != null) 'provisionedMemory': provisionedMemory,
if (publicConnectivity != null) 'publicConnectivity': publicConnectivity,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/graphs/${Uri.encodeComponent(graphIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return UpdateGraphOutput.fromJson(response);
}