deleteSparqlStatistics method
Deletes SPARQL statistics
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:DeleteStatistics IAM action in that cluster.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw PreconditionsFailedException.
May throw ReadOnlyViolationException.
May throw StatisticsNotAvailableException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Implementation
Future<DeleteSparqlStatisticsOutput> deleteSparqlStatistics() async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/sparql/statistics',
exceptionFnMap: _exceptionFns,
);
return DeleteSparqlStatisticsOutput.fromJson(response);
}