getLoaderJobStatus method

Future<GetLoaderJobStatusOutput> getLoaderJobStatus({
  1. required String loadId,
  2. bool? details,
  3. bool? errors,
  4. int? errorsPerPage,
  5. int? page,
})

Gets status information about a specified load job. Neptune keeps track of the most recent 1,024 bulk load jobs, and stores the last 10,000 error details per job.

See Neptune Loader Get-Status API for more information.

When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:GetLoaderJobStatus IAM action in that cluster..

May throw BadRequestException. May throw BulkLoadIdNotFoundException. May throw ClientTimeoutException. May throw ConstraintViolationException. May throw IllegalArgumentException. May throw InternalFailureException. May throw InvalidArgumentException. May throw InvalidParameterException. May throw LoadUrlAccessDeniedException. May throw MissingParameterException. May throw PreconditionsFailedException. May throw TooManyRequestsException. May throw UnsupportedOperationException.

Parameter loadId : The load ID of the load job to get the status of.

Parameter details : Flag indicating whether or not to include details beyond the overall status (TRUE or FALSE; the default is FALSE).

Parameter errors : Flag indicating whether or not to include a list of errors encountered (TRUE or FALSE; the default is FALSE).

The list of errors is paged. The page and errorsPerPage parameters allow you to page through all the errors.

Parameter errorsPerPage : The number of errors returned in each page (a positive integer; the default is 10). Only valid when the errors parameter set to TRUE.

Parameter page : The error page number (a positive integer; the default is 1). Only valid when the errors parameter is set to TRUE.

Implementation

Future<GetLoaderJobStatusOutput> getLoaderJobStatus({
  required String loadId,
  bool? details,
  bool? errors,
  int? errorsPerPage,
  int? page,
}) async {
  _s.validateNumRange(
    'errorsPerPage',
    errorsPerPage,
    1,
    1152921504606846976,
  );
  _s.validateNumRange(
    'page',
    page,
    1,
    1152921504606846976,
  );
  final $query = <String, List<String>>{
    if (details != null) 'details': [details.toString()],
    if (errors != null) 'errors': [errors.toString()],
    if (errorsPerPage != null) 'errorsPerPage': [errorsPerPage.toString()],
    if (page != null) 'page': [page.toString()],
  };
  final response = await _protocol.send(
    payload: null,
    method: 'GET',
    requestUri: '/loader/${Uri.encodeComponent(loadId)}',
    queryParams: $query,
    exceptionFnMap: _exceptionFns,
  );
  return GetLoaderJobStatusOutput.fromJson(response);
}