listMLEndpoints method
Lists existing inference endpoints. See Managing inference endpoints using the endpoints command.
When invoking this operation in a Neptune cluster that has IAM authentication enabled, the IAM user or role making the request must have a policy attached that allows the neptune-db:ListMLEndpoints IAM action in that cluster.
May throw BadRequestException.
May throw ClientTimeoutException.
May throw ConstraintViolationException.
May throw IllegalArgumentException.
May throw InvalidArgumentException.
May throw InvalidParameterException.
May throw MissingParameterException.
May throw MLResourceNotFoundException.
May throw PreconditionsFailedException.
May throw TooManyRequestsException.
May throw UnsupportedOperationException.
Parameter maxItems :
The maximum number of items to return (from 1 to 1024; the default is 10.
Parameter neptuneIamRoleArn :
The ARN of an IAM role that provides Neptune access to SageMaker and
Amazon S3 resources. This must be listed in your DB cluster parameter
group or an error will occur.
Implementation
Future<ListMLEndpointsOutput> listMLEndpoints({
int? maxItems,
String? neptuneIamRoleArn,
}) async {
_s.validateNumRange(
'maxItems',
maxItems,
1,
1152921504606846976,
);
final $query = <String, List<String>>{
if (maxItems != null) 'maxItems': [maxItems.toString()],
if (neptuneIamRoleArn != null) 'neptuneIamRoleArn': [neptuneIamRoleArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/ml/endpoints',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMLEndpointsOutput.fromJson(response);
}