createRuleGroup method
- required int capacity,
- required String ruleGroupName,
- required RuleGroupType type,
- bool? analyzeRuleGroup,
- String? description,
- bool? dryRun,
- EncryptionConfiguration? encryptionConfiguration,
- RuleGroup? ruleGroup,
- String? rules,
- SourceMetadata? sourceMetadata,
- SummaryConfiguration? summaryConfiguration,
- List<
Tag> ? tags,
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
You provide your rule group specification in your request using either
RuleGroup or Rules.
May throw InsufficientCapacityException.
May throw InternalServerError.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ThrottlingException.
Parameter capacity :
The maximum operating resources that this rule group can use. Rule group
capacity is fixed at creation. When you update a rule group, you are
limited to this capacity. When you reference a rule group from a firewall
policy, Network Firewall reserves this capacity for the rule group.
You can retrieve the capacity that would be required for a rule group
before you create the rule group by calling CreateRuleGroup with
DryRun set to TRUE.
Capacity for a stateless rule group
For a stateless rule group, the capacity required is the sum of the capacity requirements of the individual rules that you expect to have in the rule group.
To calculate the capacity requirement of a single rule, multiply the capacity requirement values of each of the rule's match settings:
- A match setting with no criteria specified has a value of 1.
-
A match setting with
Anyspecified has a value of 1. - All other match settings have a value equal to the number of elements provided in the setting. For example, a protocol setting \["UDP"\] and a source setting \["10.0.0.0/24"\] each have a value of 1. A protocol setting \["UDP","TCP"\] has a value of 2. A source setting \["10.0.0.0/24","10.0.0.1/24","10.0.0.2/24"\] has a value of 3.
Capacity for a stateful rule group
For a stateful rule group, the minimum capacity required is the number of individual rules that you expect to have in the rule group.
Parameter ruleGroupName :
The descriptive name of the rule group. You can't change the name of a
rule group after you create it.
Parameter type :
Indicates whether the rule group is stateless or stateful. If the rule
group is stateless, it contains stateless rules. If it is stateful, it
contains stateful rules.
Parameter analyzeRuleGroup :
Indicates whether you want Network Firewall to analyze the stateless rules
in the rule group for rule behavior such as asymmetric routing. If set to
TRUE, Network Firewall runs the analysis and then creates the
rule group for you. To run the stateless rule group analyzer without
creating the rule group, set DryRun to TRUE.
Parameter description :
A description of the rule group.
Parameter dryRun :
Indicates whether you want Network Firewall to just check the validity of
the request, rather than run the request.
If set to TRUE, Network Firewall checks whether the request
can run successfully, but doesn't actually make the requested changes. The
call returns the value that the request would return if you ran it with
dry run set to FALSE, but doesn't make additions or changes
to your resources. This option allows you to make sure that you have the
required permissions to run the request and that your request parameters
are valid.
If set to FALSE, Network Firewall makes the requested changes
to your resources.
Parameter encryptionConfiguration :
A complex type that contains settings for encryption of your rule group
resources.
Parameter ruleGroup :
An object that defines the rule group rules.
Parameter rules :
A string containing stateful rule group rules specifications in Suricata
flat format, with one rule per line. Use this to import your existing
Suricata compatible rule groups.
You can provide your rule group specification in Suricata flat format
through this setting when you create or update your rule group. The call
response returns a RuleGroup object that Network Firewall has
populated from your string.
Parameter sourceMetadata :
A complex type that contains metadata about the rule group that your own
rule group is copied from. You can use the metadata to keep track of
updates made to the originating rule group.
Parameter summaryConfiguration :
An object that contains a RuleOptions array of strings. You
use RuleOptions to determine which of the following
RuleSummary values are returned in response to
DescribeRuleGroupSummary.
-
Metadata- returns -
Msg -
SID
Parameter tags :
The key:value pairs to associate with the resource.
Implementation
Future<CreateRuleGroupResponse> createRuleGroup({
required int capacity,
required String ruleGroupName,
required RuleGroupType type,
bool? analyzeRuleGroup,
String? description,
bool? dryRun,
EncryptionConfiguration? encryptionConfiguration,
RuleGroup? ruleGroup,
String? rules,
SourceMetadata? sourceMetadata,
SummaryConfiguration? summaryConfiguration,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.CreateRuleGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Capacity': capacity,
'RuleGroupName': ruleGroupName,
'Type': type.value,
if (analyzeRuleGroup != null) 'AnalyzeRuleGroup': analyzeRuleGroup,
if (description != null) 'Description': description,
if (dryRun != null) 'DryRun': dryRun,
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (ruleGroup != null) 'RuleGroup': ruleGroup,
if (rules != null) 'Rules': rules,
if (sourceMetadata != null) 'SourceMetadata': sourceMetadata,
if (summaryConfiguration != null)
'SummaryConfiguration': summaryConfiguration,
if (tags != null) 'Tags': tags,
},
);
return CreateRuleGroupResponse.fromJson(jsonResponse.body);
}