deleteProxyRules method

Future<DeleteProxyRulesResponse> deleteProxyRules({
  1. required List<String> rules,
  2. String? proxyRuleGroupArn,
  3. String? proxyRuleGroupName,
})

Deletes the specified ProxyRule(s). currently attached to a ProxyRuleGroup

May throw InternalServerError. May throw InvalidRequestException. May throw ResourceNotFoundException. May throw ThrottlingException.

Parameter rules : The proxy rule(s) to remove from the existing proxy rule group.

Parameter proxyRuleGroupArn : The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.

Parameter proxyRuleGroupName : The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Implementation

Future<DeleteProxyRulesResponse> deleteProxyRules({
  required List<String> rules,
  String? proxyRuleGroupArn,
  String? proxyRuleGroupName,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target': 'NetworkFirewall_20201112.DeleteProxyRules'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'Rules': rules,
      if (proxyRuleGroupArn != null) 'ProxyRuleGroupArn': proxyRuleGroupArn,
      if (proxyRuleGroupName != null)
        'ProxyRuleGroupName': proxyRuleGroupName,
    },
  );

  return DeleteProxyRulesResponse.fromJson(jsonResponse.body);
}