describeContainerAssociation method
Retrieves the configuration and status of a container association.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter containerAssociationArn :
The Amazon Resource Name (ARN) of the container association.
You must specify the ARN or the name, and you can specify both.
Parameter containerAssociationName :
The descriptive name of the container association.
You must specify the ARN or the name, and you can specify both.
Implementation
Future<DescribeContainerAssociationResponse> describeContainerAssociation({
String? containerAssociationArn,
String? containerAssociationName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.DescribeContainerAssociation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (containerAssociationArn != null)
'ContainerAssociationArn': containerAssociationArn,
if (containerAssociationName != null)
'ContainerAssociationName': containerAssociationName,
},
);
return DescribeContainerAssociationResponse.fromJson(jsonResponse.body);
}