getAnalysisReportResults method
The results of a COMPLETED analysis report generated with
StartAnalysisReport.
For more information, see AnalysisTypeReportResult.
May throw InternalServerError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter analysisReportId :
The unique ID of the query that ran when you requested an analysis report.
Parameter firewallArn :
The Amazon Resource Name (ARN) of the firewall.
You must specify the ARN or the name, and you can specify both.
Parameter firewallName :
The descriptive name of the firewall. You can't change the name of a
firewall after you create it.
You must specify the ARN or the name, and you can specify both.
Parameter maxResults :
The maximum number of objects that you want Network Firewall to return for
this request. If more objects are available, in the response, Network
Firewall provides a NextToken value that you can use in a
subsequent call to get the next batch of objects.
Parameter nextToken :
When you request a list of objects with a MaxResults setting,
if the number of objects that are still available for retrieval exceeds
the maximum you requested, Network Firewall returns a
NextToken value in the response. To retrieve the next batch
of objects, use the token returned from the prior request in your next
request.
Implementation
Future<GetAnalysisReportResultsResponse> getAnalysisReportResults({
required String analysisReportId,
String? firewallArn,
String? firewallName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.GetAnalysisReportResults'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AnalysisReportId': analysisReportId,
if (firewallArn != null) 'FirewallArn': firewallArn,
if (firewallName != null) 'FirewallName': firewallName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetAnalysisReportResultsResponse.fromJson(jsonResponse.body);
}