updateRuleGroup method
- required String updateToken,
- bool? analyzeRuleGroup,
- String? description,
- bool? dryRun,
- EncryptionConfiguration? encryptionConfiguration,
- RuleGroup? ruleGroup,
- String? ruleGroupArn,
- String? ruleGroupName,
- String? rules,
- SourceMetadata? sourceMetadata,
- SummaryConfiguration? summaryConfiguration,
- RuleGroupType? type,
Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.
To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.
May throw InternalServerError.
May throw InvalidRequestException.
May throw InvalidTokenException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter updateToken :
A token used for optimistic locking. Network Firewall returns a token to
your requests that access the rule group. The token marks the state of the
rule group resource at the time of the request.
To make changes to the rule group, you provide the token in your request.
Network Firewall uses the token to ensure that the rule group hasn't
changed since you last retrieved it. If it has changed, the operation
fails with an InvalidTokenException. If this happens,
retrieve the rule group again to get a current copy of it with a current
token. Reapply your changes as needed, then try the operation again using
the new token.
Parameter analyzeRuleGroup :
Indicates whether you want Network Firewall to analyze the stateless rules
in the rule group for rule behavior such as asymmetric routing. If set to
TRUE, Network Firewall runs the analysis and then updates the
rule group for you. To run the stateless rule group analyzer without
updating the rule group, set DryRun to TRUE.
Parameter description :
A description of the rule group.
Parameter dryRun :
Indicates whether you want Network Firewall to just check the validity of
the request, rather than run the request.
If set to TRUE, Network Firewall checks whether the request
can run successfully, but doesn't actually make the requested changes. The
call returns the value that the request would return if you ran it with
dry run set to FALSE, but doesn't make additions or changes
to your resources. This option allows you to make sure that you have the
required permissions to run the request and that your request parameters
are valid.
If set to FALSE, Network Firewall makes the requested changes
to your resources.
Parameter encryptionConfiguration :
A complex type that contains settings for encryption of your rule group
resources.
Parameter ruleGroup :
An object that defines the rule group rules.
Parameter ruleGroupArn :
The Amazon Resource Name (ARN) of the rule group.
You must specify the ARN or the name, and you can specify both.
Parameter ruleGroupName :
The descriptive name of the rule group. You can't change the name of a
rule group after you create it.
You must specify the ARN or the name, and you can specify both.
Parameter rules :
A string containing stateful rule group rules specifications in Suricata
flat format, with one rule per line. Use this to import your existing
Suricata compatible rule groups.
You can provide your rule group specification in Suricata flat format
through this setting when you create or update your rule group. The call
response returns a RuleGroup object that Network Firewall has
populated from your string.
Parameter sourceMetadata :
A complex type that contains metadata about the rule group that your own
rule group is copied from. You can use the metadata to keep track of
updates made to the originating rule group.
Parameter summaryConfiguration :
Updates the selected summary configuration for a rule group.
Changes affect subsequent responses from DescribeRuleGroupSummary.
Parameter type :
Indicates whether the rule group is stateless or stateful. If the rule
group is stateless, it contains stateless rules. If it is stateful, it
contains stateful rules.
Implementation
Future<UpdateRuleGroupResponse> updateRuleGroup({
required String updateToken,
bool? analyzeRuleGroup,
String? description,
bool? dryRun,
EncryptionConfiguration? encryptionConfiguration,
RuleGroup? ruleGroup,
String? ruleGroupArn,
String? ruleGroupName,
String? rules,
SourceMetadata? sourceMetadata,
SummaryConfiguration? summaryConfiguration,
RuleGroupType? type,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'NetworkFirewall_20201112.UpdateRuleGroup'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'UpdateToken': updateToken,
if (analyzeRuleGroup != null) 'AnalyzeRuleGroup': analyzeRuleGroup,
if (description != null) 'Description': description,
if (dryRun != null) 'DryRun': dryRun,
if (encryptionConfiguration != null)
'EncryptionConfiguration': encryptionConfiguration,
if (ruleGroup != null) 'RuleGroup': ruleGroup,
if (ruleGroupArn != null) 'RuleGroupArn': ruleGroupArn,
if (ruleGroupName != null) 'RuleGroupName': ruleGroupName,
if (rules != null) 'Rules': rules,
if (sourceMetadata != null) 'SourceMetadata': sourceMetadata,
if (summaryConfiguration != null)
'SummaryConfiguration': summaryConfiguration,
if (type != null) 'Type': type.value,
},
);
return UpdateRuleGroupResponse.fromJson(jsonResponse.body);
}