deleteScope method
Deletes a scope that has been defined.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter scopeId :
The identifier for the scope that includes the resources you want to get
data results for. A scope ID is an internally-generated identifier that
includes all the resources for a specific root account.
Implementation
Future<void> deleteScope({
required String scopeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/scopes/${Uri.encodeComponent(scopeId)}',
exceptionFnMap: _exceptionFns,
);
}