getScope method
Gets information about a scope, including the name, status, tags, and target details. The scope in Network Flow Monitor is an account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter scopeId :
The identifier for the scope that includes the resources you want to get
data results for. A scope ID is an internally-generated identifier that
includes all the resources for a specific root account. A scope ID is
returned from a CreateScope API call.
Implementation
Future<GetScopeOutput> getScope({
required String scopeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/scopes/${Uri.encodeComponent(scopeId)}',
exceptionFnMap: _exceptionFns,
);
return GetScopeOutput.fromJson(response);
}