listOrganizationServiceAccessStatus method
Gets the status of the Service Linked Role (SLR) deployment for the accounts in a given Amazon Web Services Organization.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListOrganizationServiceAccessStatusResponse>
listOrganizationServiceAccessStatus({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/organizations/service-access',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListOrganizationServiceAccessStatusResponse.fromJson(response);
}