startOrganizationServiceAccessUpdate method
Future<StartOrganizationServiceAccessUpdateResponse>
startOrganizationServiceAccessUpdate({
- required String action,
Enables the Network Manager service for an Amazon Web Services Organization. This can only be called by a management account within the organization.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter action :
The action to take for the update request. This can be either
ENABLE or DISABLE.
Implementation
Future<StartOrganizationServiceAccessUpdateResponse>
startOrganizationServiceAccessUpdate({
required String action,
}) async {
final $payload = <String, dynamic>{
'Action': action,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/organizations/service-access',
exceptionFnMap: _exceptionFns,
);
return StartOrganizationServiceAccessUpdateResponse.fromJson(response);
}