NetworkMonitor class
Amazon CloudWatch Network Monitor is an Amazon Web Services active network monitoring service that identifies if a network issues exists within the Amazon Web Services network or your own company network. Within Network Monitor you'll choose the source VPCs and subnets from the Amazon Web Services network in which you operate and then you'll choose the destination IP addresses from your on-premises network. From these sources and destinations, Network Monitor creates a monitor containing all the possible source and destination combinations, each of which is called a probe, within a single monitor. These probes then monitor network traffic to help you identify where network issues might be affecting your traffic.
Before you begin, ensure the Amazon Web Services CLI is configured in the Amazon Web Services Account where you will create the Network Monitor resource. Network Monitor doesn’t support creation on cross-account resources, but you can create a Network Monitor in any subnet belonging to a VPC owned by your Account.
For more information, see Using Amazon CloudWatch Network Monitor in the Amazon CloudWatch User Guide.
Constructors
- NetworkMonitor({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createMonitor(
{required String monitorName, int? aggregationPeriod, String? clientToken, List< CreateMonitorProbeInput> ? probes, Map<String, String> ? tags}) → Future<CreateMonitorOutput> - Creates a monitor between a source subnet and destination IP address. Within a monitor you'll create one or more probes that monitor network traffic between your source Amazon Web Services VPC subnets and your destination IP addresses. Each probe then aggregates and sends metrics to Amazon CloudWatch.
-
createProbe(
{required String monitorName, required ProbeInput probe, String? clientToken, Map< String, String> ? tags}) → Future<CreateProbeOutput> -
Create a probe within a monitor. Once you create a probe, and it begins
monitoring your network traffic, you'll incur billing charges for that
probe. This action requires the
monitorNameparameter. RunListMonitorsto get a list of monitor names. Note the name of themonitorNameyou want to create the probe for. -
deleteMonitor(
{required String monitorName}) → Future< void> - Deletes a specified monitor.
-
deleteProbe(
{required String monitorName, required String probeId}) → Future< void> - Deletes the specified probe. Once a probe is deleted you'll no longer incur any billing fees for that probe.
-
getMonitor(
{required String monitorName}) → Future< GetMonitorOutput> - Returns details about a specific monitor.
-
getProbe(
{required String monitorName, required String probeId}) → Future< GetProbeOutput> -
Returns the details about a probe. This action requires both the
monitorNameandprobeIdparameters. RunListMonitorsto get a list of monitor names. RunGetMonitorto get a list of probes and probe IDs. -
listMonitors(
{int? maxResults, String? nextToken, String? state}) → Future< ListMonitorsOutput> - Returns a list of all of your monitors.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists the tags assigned to this resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds key-value pairs to a monitor or probe.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a key-value pair from a monitor or probe.
-
updateMonitor(
{required int aggregationPeriod, required String monitorName}) → Future< UpdateMonitorOutput> -
Updates the
aggregationPeriodfor a monitor. Monitors support anaggregationPeriodof either30or60seconds. This action requires themonitorNameandprobeIdparameter. RunListMonitorsto get a list of monitor names. -
updateProbe(
{required String monitorName, required String probeId, String? destination, int? destinationPort, int? packetSize, Protocol? protocol, ProbeState? state}) → Future< UpdateProbeOutput> -
Updates a monitor probe. This action requires both the
monitorNameandprobeIdparameters. RunListMonitorsto get a list of monitor names. RunGetMonitorto get a list of probes and probe IDs.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited