deleteProbe method
Deletes the specified probe. Once a probe is deleted you'll no longer incur any billing fees for that probe.
This action requires both the monitorName and
probeId parameters. Run ListMonitors to get a
list of monitor names. Run GetMonitor to get a list of probes
and probe IDs. You can only delete a single probe at a time using this
action.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter monitorName :
The name of the monitor to delete.
Parameter probeId :
The ID of the probe to delete.
Implementation
Future<void> deleteProbe({
required String monitorName,
required String probeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/monitors/${Uri.encodeComponent(monitorName)}/probes/${Uri.encodeComponent(probeId)}',
exceptionFnMap: _exceptionFns,
);
}