associateManagedNotificationAdditionalChannel method
Associates an additional Channel with a particular
ManagedNotificationConfiguration.
Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelArn :
The Amazon Resource Name (ARN) of the Channel to associate with the
ManagedNotificationConfiguration.
Supported ARNs include Amazon Q Developer in chat applications, the Console Mobile Application, and email (notifications-contacts).
Parameter managedNotificationConfigurationArn :
The Amazon Resource Name (ARN) of the
ManagedNotificationConfiguration to associate with the
additional Channel.
Implementation
Future<void> associateManagedNotificationAdditionalChannel({
required String channelArn,
required String managedNotificationConfigurationArn,
}) async {
final $payload = <String, dynamic>{
'managedNotificationConfigurationArn':
managedNotificationConfigurationArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/channels/associate-managed-notification/${Uri.encodeComponent(channelArn)}',
exceptionFnMap: _exceptionFns,
);
}