listManagedNotificationChannelAssociations method
Future<ListManagedNotificationChannelAssociationsResponse>
listManagedNotificationChannelAssociations({})
Returns a list of Account contacts and Channels associated with a
ManagedNotificationConfiguration, in paginated format.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter managedNotificationConfigurationArn :
The Amazon Resource Name (ARN) of the
ManagedNotificationConfiguration to match.
Parameter maxResults :
The maximum number of results to be returned in this call. Defaults to 20.
Parameter nextToken :
The start token for paginated calls. Retrieved from the response of a
previous ListManagedNotificationChannelAssociations call.
Implementation
Future<ListManagedNotificationChannelAssociationsResponse>
listManagedNotificationChannelAssociations({
required String managedNotificationConfigurationArn,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
'managedNotificationConfigurationArn': [
managedNotificationConfigurationArn
],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/channels/list-managed-notification-channel-associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListManagedNotificationChannelAssociationsResponse.fromJson(
response);
}