listManagedNotificationConfigurations method
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelIdentifier :
The identifier or ARN of the notification channel to filter configurations
by.
Parameter maxResults :
The maximum number of results to be returned in this call. Defaults to 20.
Parameter nextToken :
The start token for paginated calls. Retrieved from the response of a
previous ListManagedNotificationChannelAssociations call. Next token uses
Base64 encoding.
Implementation
Future<ListManagedNotificationConfigurationsResponse>
listManagedNotificationConfigurations({
String? channelIdentifier,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (channelIdentifier != null) 'channelIdentifier': [channelIdentifier],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/managed-notification-configurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListManagedNotificationConfigurationsResponse.fromJson(response);
}