listMemberAccounts method
Returns a list of member accounts associated with a notification configuration.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter notificationConfigurationArn :
The Amazon Resource Name (ARN) of the notification configuration used to
filter the member accounts.
Parameter maxResults :
The maximum number of results to return in a single call. Valid values are
1-100.
Parameter memberAccount :
The member account identifier used to filter the results.
Parameter nextToken :
The token for the next page of results. Use the value returned in the
previous response.
Parameter organizationalUnitId :
The organizational unit ID used to filter the member accounts.
Parameter status :
The status used to filter the member accounts.
Implementation
Future<ListMemberAccountsResponse> listMemberAccounts({
required String notificationConfigurationArn,
int? maxResults,
String? memberAccount,
String? nextToken,
String? organizationalUnitId,
MemberAccountNotificationConfigurationStatus? status,
}) async {
final $query = <String, List<String>>{
'notificationConfigurationArn': [notificationConfigurationArn],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (memberAccount != null) 'memberAccount': [memberAccount],
if (nextToken != null) 'nextToken': [nextToken],
if (organizationalUnitId != null)
'organizationalUnitId': [organizationalUnitId],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/list-member-accounts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMemberAccountsResponse.fromJson(response);
}