listNotificationConfigurations method
Returns a list of abbreviated NotificationConfigurations
according to specified filters, in reverse chronological order (newest
first).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter channelArn :
The Amazon Resource Name (ARN) of the Channel to match.
Parameter eventRuleSource :
The matched event source.
Must match one of the valid EventBridge sources. Only Amazon Web Services
service sourced events are supported. For example, aws.ec2
and aws.cloudwatch. For more information, see Event
delivery from Amazon Web Services services in the Amazon
EventBridge User Guide.
Parameter maxResults :
The maximum number of results to be returned in this call. Defaults to 20.
Parameter nextToken :
The start token for paginated calls. Retrieved from the response of a
previous ListEventRules call. Next token uses Base64
encoding.
Parameter status :
The NotificationConfiguration status to match.
-
Values:
-
ACTIVE-
All
EventRulesareACTIVEand any call can be run.
-
All
-
PARTIALLY_ACTIVE-
Some
EventRulesareACTIVEand some areINACTIVE. Any call can be run. - Any call can be run.
-
Some
-
INACTIVE-
All
EventRulesareINACTIVEand any call can be run.
-
All
-
DELETING-
This
NotificationConfigurationis being deleted. -
Only
GETandLISTcalls can be run.
-
This
-
Parameter subtype :
The subtype used to filter the notification configurations in the request.
Implementation
Future<ListNotificationConfigurationsResponse>
listNotificationConfigurations({
String? channelArn,
String? eventRuleSource,
int? maxResults,
String? nextToken,
NotificationConfigurationStatus? status,
NotificationConfigurationSubtype? subtype,
}) async {
final $query = <String, List<String>>{
if (channelArn != null) 'channelArn': [channelArn],
if (eventRuleSource != null) 'eventRuleSource': [eventRuleSource],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (status != null) 'status': [status.value],
if (subtype != null) 'subtype': [subtype.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/notification-configurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListNotificationConfigurationsResponse.fromJson(response);
}