listNotificationEvents method
Returns a list of NotificationEvents according to specified
filters, in reverse chronological order (newest first).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter aggregateNotificationEventArn :
The Amazon Resource Name (ARN) of the
aggregatedNotificationEventArn to match.
Parameter endTime :
Latest time of events to return from this call.
Parameter includeChildEvents :
Include aggregated child events in the result.
Parameter locale :
The locale code of the language used for the retrieved
NotificationEvent. The default locale is English
(en_US).
Parameter maxResults :
The maximum number of results to be returned in this call. Defaults to 20.
Parameter nextToken :
The start token for paginated calls. Retrieved from the response of a
previous ListEventRules call. Next token uses Base64
encoding.
Parameter organizationalUnitId :
The unique identifier of the organizational unit used to filter
notification events.
Parameter source :
The matched event source.
Must match one of the valid EventBridge sources. Only Amazon Web Services
service sourced events are supported. For example, aws.ec2
and aws.cloudwatch. For more information, see Event
delivery from Amazon Web Services services in the Amazon
EventBridge User Guide.
Parameter startTime :
The earliest time of events to return from this call.
Implementation
Future<ListNotificationEventsResponse> listNotificationEvents({
String? aggregateNotificationEventArn,
DateTime? endTime,
bool? includeChildEvents,
LocaleCode? locale,
int? maxResults,
String? nextToken,
String? organizationalUnitId,
String? source,
DateTime? startTime,
}) async {
final $query = <String, List<String>>{
if (aggregateNotificationEventArn != null)
'aggregateNotificationEventArn': [aggregateNotificationEventArn],
if (endTime != null) 'endTime': [_s.iso8601ToJson(endTime).toString()],
if (includeChildEvents != null)
'includeChildEvents': [includeChildEvents.toString()],
if (locale != null) 'locale': [locale.value],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (organizationalUnitId != null)
'organizationalUnitId': [organizationalUnitId],
if (source != null) 'source': [source],
if (startTime != null)
'startTime': [_s.iso8601ToJson(startTime).toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/notification-events',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListNotificationEventsResponse.fromJson(response);
}