getWorkflowRun method
Retrieves the current state, configuration, and execution details of a workflow run.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter workflowDefinitionName :
The name of the workflow definition containing the workflow run.
Parameter workflowRunId :
The unique identifier of the workflow run to retrieve.
Implementation
Future<GetWorkflowRunResponse> getWorkflowRun({
required String workflowDefinitionName,
required String workflowRunId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/workflow-definitions/${Uri.encodeComponent(workflowDefinitionName)}/workflow-runs/${Uri.encodeComponent(workflowRunId)}',
exceptionFnMap: _exceptionFns,
);
return GetWorkflowRunResponse.fromJson(response);
}