deleteLink method
Deletes a link between a monitoring account sink and a source account. You must run this operation in the source account.
May throw InternalServiceFault.
May throw InvalidParameterException.
May throw MissingRequiredParameterException.
May throw ResourceNotFoundException.
Parameter identifier :
The ARN of the link to delete.
Implementation
Future<void> deleteLink({
required String identifier,
}) async {
final $payload = <String, dynamic>{
'Identifier': identifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteLink',
exceptionFnMap: _exceptionFns,
);
}