listAttachedLinks method
Returns a list of source account links that are linked to this monitoring account sink.
To use this operation, provide the sink ARN. To retrieve a list of sink ARNs, use ListSinks.
To find a list of links for one source account, use ListLinks.
May throw InternalServiceFault.
May throw InvalidParameterException.
May throw MissingRequiredParameterException.
May throw ResourceNotFoundException.
Parameter sinkIdentifier :
The ARN of the sink that you want to retrieve links for.
Parameter maxResults :
Limits the number of returned links to the specified number.
Parameter nextToken :
The token for the next set of items to return. You received this token
from a previous call.
Implementation
Future<ListAttachedLinksOutput> listAttachedLinks({
required String sinkIdentifier,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $payload = <String, dynamic>{
'SinkIdentifier': sinkIdentifier,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListAttachedLinks',
exceptionFnMap: _exceptionFns,
);
return ListAttachedLinksOutput.fromJson(response);
}