untagResource method
Removes one or more tags from the specified resource.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the resource that you're removing tags from.
The ARN format of a sink is
arn:aws:oam:Region:account-id:sink/sink-id
The ARN format of a link is
arn:aws:oam:Region:account-id:link/link-id
For more information about ARN format, see CloudWatch Logs resources and operations.
Parameter tagKeys :
The list of tag keys to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}