createTelemetryPipeline method
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter configuration :
The configuration that defines how the telemetry pipeline processes data,
including sources, processors, and destinations. For more information
about pipeline components, see the Amazon
CloudWatch User Guide
Parameter name :
The name of the telemetry pipeline to create. The name must be unique
within your account.
Parameter tags :
The key-value pairs to associate with the telemetry pipeline resource for
categorization and management purposes.
Implementation
Future<CreateTelemetryPipelineOutput> createTelemetryPipeline({
required TelemetryPipelineConfiguration configuration,
required String name,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'Configuration': configuration,
'Name': name,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CreateTelemetryPipeline',
exceptionFnMap: _exceptionFns,
);
return CreateTelemetryPipelineOutput.fromJson(response);
}