getTelemetryEvaluationStatus method
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
May throw AccessDeniedException.
May throw InternalServerException.
May throw TooManyRequestsException.
Implementation
Future<GetTelemetryEvaluationStatusOutput>
getTelemetryEvaluationStatus() async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/GetTelemetryEvaluationStatus',
exceptionFnMap: _exceptionFns,
);
return GetTelemetryEvaluationStatusOutput.fromJson(response);
}