getTelemetryRuleForOrganization method
Future<GetTelemetryRuleForOrganizationOutput>
getTelemetryRuleForOrganization({
- required String ruleIdentifier,
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization's management account or a delegated administrator account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter ruleIdentifier :
The identifier (name or ARN) of the organization telemetry rule to
retrieve.
Implementation
Future<GetTelemetryRuleForOrganizationOutput>
getTelemetryRuleForOrganization({
required String ruleIdentifier,
}) async {
final $payload = <String, dynamic>{
'RuleIdentifier': ruleIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetTelemetryRuleForOrganization',
exceptionFnMap: _exceptionFns,
);
return GetTelemetryRuleForOrganizationOutput.fromJson(response);
}