stopTelemetryEnrichment method
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw TooManyRequestsException.
Implementation
Future<StopTelemetryEnrichmentOutput> stopTelemetryEnrichment() async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/StopTelemetryEnrichment',
exceptionFnMap: _exceptionFns,
);
return StopTelemetryEnrichmentOutput.fromJson(response);
}