updateTelemetryRuleForOrganization method
Future<UpdateTelemetryRuleForOrganizationOutput>
updateTelemetryRuleForOrganization({
- required TelemetryRule rule,
- required String ruleIdentifier,
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter rule :
The new configuration details for the organization telemetry rule,
including resource type, telemetry type, and destination configuration.
Parameter ruleIdentifier :
The identifier (name or ARN) of the organization telemetry rule to update.
Implementation
Future<UpdateTelemetryRuleForOrganizationOutput>
updateTelemetryRuleForOrganization({
required TelemetryRule rule,
required String ruleIdentifier,
}) async {
final $payload = <String, dynamic>{
'Rule': rule,
'RuleIdentifier': ruleIdentifier,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateTelemetryRuleForOrganization',
exceptionFnMap: _exceptionFns,
);
return UpdateTelemetryRuleForOrganizationOutput.fromJson(response);
}