createCloudExadataInfrastructure method
- required int computeCount,
- required String displayName,
- required String shape,
- required int storageCount,
- String? availabilityZone,
- String? availabilityZoneId,
- String? clientToken,
- List<
CustomerContact> ? customerContactsToSendToOCI, - String? databaseServerType,
- MaintenanceWindow? maintenanceWindow,
- String? storageServerType,
- Map<
String, String> ? tags,
Creates an Exadata infrastructure.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter computeCount :
The number of database servers for the Exadata infrastructure. Valid
values for this parameter depend on the shape. To get information about
the minimum and maximum values, use the ListDbSystemShapes
operation.
Parameter displayName :
A user-friendly name for the Exadata infrastructure.
Parameter shape :
The model name of the Exadata infrastructure. For the list of valid model
names, use the ListDbSystemShapes operation.
Parameter storageCount :
The number of storage servers to activate for this Exadata infrastructure.
Valid values for this parameter depend on the shape. To get information
about the minimum and maximum values, use the
ListDbSystemShapes operation.
Parameter availabilityZone :
The name of the Availability Zone (AZ) where the Exadata infrastructure is
located.
This operation requires that you specify a value for either
availabilityZone or availabilityZoneId.
Example: us-east-1a
Parameter availabilityZoneId :
The AZ ID of the AZ where the Exadata infrastructure is located.
This operation requires that you specify a value for either
availabilityZone or availabilityZoneId.
Example: use1-az1
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. If you don't specify a client token, the
Amazon Web Services SDK automatically generates a client token and uses it
for the request to ensure idempotency. The client token is valid for up to
24 hours after it's first used.
Parameter customerContactsToSendToOCI :
The email addresses of contacts to receive notification from Oracle about
maintenance updates for the Exadata infrastructure.
Parameter databaseServerType :
The database server model type of the Exadata infrastructure. For the list
of valid model names, use the ListDbSystemShapes operation.
Parameter maintenanceWindow :
The maintenance window configuration for the Exadata Cloud infrastructure.
This allows you to define when maintenance operations such as patching and updates can be performed on the infrastructure.
Parameter storageServerType :
The storage server model type of the Exadata infrastructure. For the list
of valid model names, use the ListDbSystemShapes operation.
Parameter tags :
The list of resource tags to apply to the Exadata infrastructure.
Implementation
Future<CreateCloudExadataInfrastructureOutput>
createCloudExadataInfrastructure({
required int computeCount,
required String displayName,
required String shape,
required int storageCount,
String? availabilityZone,
String? availabilityZoneId,
String? clientToken,
List<CustomerContact>? customerContactsToSendToOCI,
String? databaseServerType,
MaintenanceWindow? maintenanceWindow,
String? storageServerType,
Map<String, String>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.CreateCloudExadataInfrastructure'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'computeCount': computeCount,
'displayName': displayName,
'shape': shape,
'storageCount': storageCount,
if (availabilityZone != null) 'availabilityZone': availabilityZone,
if (availabilityZoneId != null)
'availabilityZoneId': availabilityZoneId,
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (customerContactsToSendToOCI != null)
'customerContactsToSendToOCI': customerContactsToSendToOCI,
if (databaseServerType != null)
'databaseServerType': databaseServerType,
if (maintenanceWindow != null) 'maintenanceWindow': maintenanceWindow,
if (storageServerType != null) 'storageServerType': storageServerType,
if (tags != null) 'tags': tags,
},
);
return CreateCloudExadataInfrastructureOutput.fromJson(jsonResponse.body);
}