getCloudExadataInfrastructureUnallocatedResources method
Future<GetCloudExadataInfrastructureUnallocatedResourcesOutput>
getCloudExadataInfrastructureUnallocatedResources({})
Retrieves information about unallocated resources in a specified Cloud Exadata Infrastructure.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cloudExadataInfrastructureId :
The unique identifier of the Cloud Exadata infrastructure for which to
retrieve unallocated resources.
Parameter dbServers :
The database servers to include in the unallocated resources query.
Implementation
Future<GetCloudExadataInfrastructureUnallocatedResourcesOutput>
getCloudExadataInfrastructureUnallocatedResources({
required String cloudExadataInfrastructureId,
List<String>? dbServers,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.GetCloudExadataInfrastructureUnallocatedResources'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
if (dbServers != null) 'dbServers': dbServers,
},
);
return GetCloudExadataInfrastructureUnallocatedResourcesOutput.fromJson(
jsonResponse.body);
}