getDbServer method
Returns information about the specified database server.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cloudExadataInfrastructureId :
The unique identifier of the Oracle Exadata infrastructure that contains
the database server.
Parameter dbServerId :
The unique identifier of the database server to retrieve information
about.
Implementation
Future<GetDbServerOutput> getDbServer({
required String cloudExadataInfrastructureId,
required String dbServerId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.GetDbServer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
'dbServerId': dbServerId,
},
);
return GetDbServerOutput.fromJson(jsonResponse.body);
}