listCloudVmClusters method
Returns information about the VM clusters owned by your Amazon Web Services account or only the ones on the specified Exadata infrastructure.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cloudExadataInfrastructureId :
The unique identifier of the Oracle Exadata infrastructure.
Parameter maxResults :
The maximum number of items to return for this request. To get the next
page of items, make another request with the token returned in the output.
Default: 10
Parameter nextToken :
The token returned from a previous paginated request. Pagination continues
from the end of the items returned by the previous request.
Implementation
Future<ListCloudVmClustersOutput> listCloudVmClusters({
String? cloudExadataInfrastructureId,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.ListCloudVmClusters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (cloudExadataInfrastructureId != null)
'cloudExadataInfrastructureId': cloudExadataInfrastructureId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListCloudVmClustersOutput.fromJson(jsonResponse.body);
}