listDbSystemShapes method
Returns information about the shapes that are available for an Exadata infrastructure.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter availabilityZone :
The logical name of the AZ, for example, us-east-1a. This name varies
depending on the account.
Parameter availabilityZoneId :
The physical ID of the AZ, for example, use1-az4. This ID persists across
accounts.
Parameter maxResults :
The maximum number of items to return for this request. To get the next
page of items, make another request with the token returned in the output.
Default: 10
Parameter nextToken :
The token returned from a previous paginated request. Pagination continues
from the end of the items returned by the previous request.
Implementation
Future<ListDbSystemShapesOutput> listDbSystemShapes({
String? availabilityZone,
String? availabilityZoneId,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Odb.ListDbSystemShapes'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (availabilityZone != null) 'availabilityZone': availabilityZone,
if (availabilityZoneId != null)
'availabilityZoneId': availabilityZoneId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListDbSystemShapesOutput.fromJson(jsonResponse.body);
}