batchDeleteReadSet method
Deletes one or more read sets. If the operation is successful, it returns
a response with no body. If there is an error with deleting one of the
read sets, the operation returns an error list. If the operation
successfully deletes only a subset of files, it will return an error list
for the remaining files that fail to be deleted. There is a limit of 100
read sets that can be deleted in each BatchDeleteReadSet API
call.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter ids :
The read sets' IDs.
Parameter sequenceStoreId :
The read sets' sequence store ID.
Implementation
Future<BatchDeleteReadSetResponse> batchDeleteReadSet({
required List<String> ids,
required String sequenceStoreId,
}) async {
final $payload = <String, dynamic>{
'ids': ids,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/readset/batch/delete',
exceptionFnMap: _exceptionFns,
);
return BatchDeleteReadSetResponse.fromJson(response);
}