deleteRunGroup method
Deletes a run group and returns a response with no body if the operation is successful.
To verify that the run group is deleted:
-
Use
ListRunGroupsto confirm the workflow no longer appears in the list. -
Use
GetRunGroupto verify the workflow cannot be found.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The run group's ID.
Implementation
Future<void> deleteRunGroup({
required String id,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/runGroup/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}