getAnnotationStoreVersion method
Retrieves the metadata for an annotation store version.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name given to an annotation store version to distinguish it from
others.
Parameter versionName :
The name given to an annotation store version to distinguish it from
others.
Implementation
Future<GetAnnotationStoreVersionResponse> getAnnotationStoreVersion({
required String name,
required String versionName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/annotationStore/${Uri.encodeComponent(name)}/version/${Uri.encodeComponent(versionName)}',
exceptionFnMap: _exceptionFns,
);
return GetAnnotationStoreVersionResponse.fromJson(response);
}