listAnnotationImportJobs method
Retrieves a list of annotation import jobs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
A filter to apply to the list.
Parameter ids :
IDs of annotation import jobs to retrieve.
Parameter maxResults :
The maximum number of jobs to return in one page of results.
Parameter nextToken :
Specifies the pagination token from a previous request to retrieve the
next page of results.
Implementation
Future<ListAnnotationImportJobsResponse> listAnnotationImportJobs({
ListAnnotationImportJobsFilter? filter,
List<String>? ids,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
if (ids != null) 'ids': ids,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/import/annotations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAnnotationImportJobsResponse.fromJson(response);
}