listAnnotationStoreVersions method
Lists the versions of an annotation store.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of an annotation store.
Parameter filter :
A filter to apply to the list of annotation store versions.
Parameter maxResults :
The maximum number of annotation store versions to return in one page of
results.
Parameter nextToken :
Specifies the pagination token from a previous request to retrieve the
next page of results.
Implementation
Future<ListAnnotationStoreVersionsResponse> listAnnotationStoreVersions({
required String name,
ListAnnotationStoreVersionsFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/annotationStore/${Uri.encodeComponent(name)}/versions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAnnotationStoreVersionsResponse.fromJson(response);
}