listMultipartReadSetUploads method
Lists in-progress multipart read set uploads for a sequence store and
returns it in a JSON formatted output. Multipart read set uploads are
initiated by the CreateMultipartReadSetUploads API operation.
This operation returns a response with no body when the upload is
complete.
May throw AccessDeniedException.
May throw InternalServerException.
May throw NotSupportedOperationException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter sequenceStoreId :
The Sequence Store ID used for the multipart uploads.
Parameter maxResults :
The maximum number of multipart uploads returned in a page.
Parameter nextToken :
Next token returned in the response of a previous
ListMultipartReadSetUploads call. Used to get the next page of results.
Implementation
Future<ListMultipartReadSetUploadsResponse> listMultipartReadSetUploads({
required String sequenceStoreId,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/uploads',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListMultipartReadSetUploadsResponse.fromJson(response);
}