listReferenceStores method
Retrieves a list of reference stores linked to your account and returns their metadata in JSON format.
For more information, see Creating a reference store in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ThrottlingException.
May throw ValidationException.
Parameter filter :
A filter to apply to the list.
Parameter maxResults :
The maximum number of stores to return in one page of results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListReferenceStoresResponse> listReferenceStores({
ReferenceStoreFilter? filter,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $payload = <String, dynamic>{
if (filter != null) 'filter': filter,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/referencestores',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListReferenceStoresResponse.fromJson(response);
}