listRunCaches method
Retrieves a list of your run caches and the metadata for each cache.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return.
Parameter startingToken :
Optional pagination token returned from a prior call to the
ListRunCaches API operation.
Implementation
Future<ListRunCachesResponse> listRunCaches({
int? maxResults,
String? startingToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (startingToken != null) 'startingToken': [startingToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/runCache',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRunCachesResponse.fromJson(response);
}