listRunTasks method
Returns a list of tasks and status information within their specified run. Use this operation to monitor runs and to identify which specific tasks have failed.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The run's ID.
Parameter maxResults :
The maximum number of run tasks to return in one page of results.
Parameter startingToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter status :
Filter the list by status.
Implementation
Future<ListRunTasksResponse> listRunTasks({
required String id,
int? maxResults,
String? startingToken,
TaskStatus? status,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (startingToken != null) 'startingToken': [startingToken],
if (status != null) 'status': [status.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/run/${Uri.encodeComponent(id)}/task',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRunTasksResponse.fromJson(response);
}