listWorkflows method
Retrieves a list of existing workflows. You can filter for specific
workflows by their name and type. Using the type parameter, specify
PRIVATE to retrieve a list of private workflows or specify
READY2RUN for a list of all Ready2Run workflows. If you do
not specify the type of workflow, this operation returns a list of
existing workflows.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of workflows to return in one page of results.
Parameter name :
Filter the list by workflow name.
Parameter startingToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Parameter type :
Filter the list by workflow type.
Implementation
Future<ListWorkflowsResponse> listWorkflows({
int? maxResults,
String? name,
String? startingToken,
WorkflowType? type,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (name != null) 'name': [name],
if (startingToken != null) 'startingToken': [startingToken],
if (type != null) 'type': [type.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/workflow',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListWorkflowsResponse.fromJson(response);
}