startReadSetExportJob method
Starts a read set export job. When the export job is finished, the read
set is exported to an Amazon S3 bucket which can be retrieved using the
GetReadSetExportJob API operation.
To monitor the status of the export job, use the
ListReadSetExportJobs API operation.
May throw AccessDeniedException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter destination :
A location for exported files in Amazon S3.
Parameter roleArn :
A service role for the job.
Parameter sequenceStoreId :
The read set's sequence store ID.
Parameter sources :
The job's source files.
Parameter clientToken :
To ensure that jobs don't run multiple times, specify a unique token for
each job.
Implementation
Future<StartReadSetExportJobResponse> startReadSetExportJob({
required String destination,
required String roleArn,
required String sequenceStoreId,
required List<ExportReadSet> sources,
String? clientToken,
}) async {
final $payload = <String, dynamic>{
'destination': destination,
'roleArn': roleArn,
'sources': sources,
if (clientToken != null) 'clientToken': clientToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/sequencestore/${Uri.encodeComponent(sequenceStoreId)}/exportjob',
exceptionFnMap: _exceptionFns,
);
return StartReadSetExportJobResponse.fromJson(response);
}