updateWorkflow method
Updates information about a workflow.
You can update the following workflow information:
- Name
- Description
- Default storage type
- Default storage capacity (with workflow ID)
GetWorkflow API operation.
For more information, see Update a private workflow in the Amazon Web Services HealthOmics User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw RequestTimeoutException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter id :
The workflow's ID.
Parameter description :
A description for the workflow.
Parameter name :
A name for the workflow.
Parameter readmeMarkdown :
The markdown content for the workflow's README file. This provides
documentation and usage information for users of the workflow.
Parameter storageCapacity :
The default static storage capacity (in gibibytes) for runs that use this
workflow or workflow version.
Parameter storageType :
The default storage type for runs that use this workflow. STATIC storage
allocates a fixed amount of storage. DYNAMIC storage dynamically scales
the storage up or down, based on file system utilization. For more
information about static and dynamic storage, see Running
workflows in the Amazon Web Services HealthOmics User Guide.
Implementation
Future<void> updateWorkflow({
required String id,
String? description,
String? name,
String? readmeMarkdown,
int? storageCapacity,
StorageType? storageType,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'description': description,
if (name != null) 'name': name,
if (readmeMarkdown != null) 'readmeMarkdown': readmeMarkdown,
if (storageCapacity != null) 'storageCapacity': storageCapacity,
if (storageType != null) 'storageType': storageType.value,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/workflow/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}