deleteDirectQueryDataSource method
Deletes a previously configured direct query data source from Amazon OpenSearch Service.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter dataSourceName :
A unique, user-defined label to identify the data source within your
OpenSearch Service environment.
Implementation
Future<void> deleteDirectQueryDataSource({
required String dataSourceName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/2021-01-01/opensearch/directQueryDataSource/${Uri.encodeComponent(dataSourceName)}',
exceptionFnMap: _exceptionFns,
);
}