describeDomainHealth method
Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The name of the domain.
Implementation
Future<DescribeDomainHealthResponse> describeDomainHealth({
required String domainName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/health',
exceptionFnMap: _exceptionFns,
);
return DescribeDomainHealthResponse.fromJson(response);
}