describeDryRunProgress method
Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain. For more information, see Determining whether a change will cause a blue/green deployment.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The name of the domain.
Parameter dryRunId :
The unique identifier of the dry run.
Parameter loadDryRunConfig :
Whether to include the configuration of the dry run in the response. The
configuration specifies the updates that you're planning to make on the
domain.
Implementation
Future<DescribeDryRunProgressResponse> describeDryRunProgress({
required String domainName,
String? dryRunId,
bool? loadDryRunConfig,
}) async {
final $query = <String, List<String>>{
if (dryRunId != null) 'dryRunId': [dryRunId],
if (loadDryRunConfig != null)
'loadDryRunConfig': [loadDryRunConfig.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/dryRun',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeDryRunProgressResponse.fromJson(response);
}