getCapability method
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
May throw AccessDeniedException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of the OpenSearch UI application.
Parameter capabilityName :
The name of the capability to retrieve information about.
Implementation
Future<GetCapabilityResponse> getCapability({
required String applicationId,
required String capabilityName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/application/${Uri.encodeComponent(applicationId)}/capability/${Uri.encodeComponent(capabilityName)}',
exceptionFnMap: _exceptionFns,
);
return GetCapabilityResponse.fromJson(response);
}