getDirectQueryDataSource method
Future<GetDirectQueryDataSourceResponse>
getDirectQueryDataSource({
- required String dataSourceName,
Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter dataSourceName :
A unique, user-defined label that identifies the data source within your
OpenSearch Service environment.
Implementation
Future<GetDirectQueryDataSourceResponse> getDirectQueryDataSource({
required String dataSourceName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/directQueryDataSource/${Uri.encodeComponent(dataSourceName)}',
exceptionFnMap: _exceptionFns,
);
return GetDirectQueryDataSourceResponse.fromJson(response);
}