listDirectQueryDataSources method
Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.
May throw BaseException.
May throw DisabledOperationException.
May throw InternalException.
May throw ResourceNotFoundException.
May throw ValidationException.
Implementation
Future<ListDirectQueryDataSourcesResponse> listDirectQueryDataSources({
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (nextToken != null) 'nexttoken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/2021-01-01/opensearch/directQueryDataSource',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDirectQueryDataSourcesResponse.fromJson(response);
}