listScheduledActions method
Retrieves a list of configuration changes that are scheduled for a domain. These changes can be service software updates or blue/green Auto-Tune enhancements.
May throw BaseException.
May throw InternalException.
May throw InvalidPaginationTokenException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter domainName :
The name of the domain.
Parameter maxResults :
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to get the next page of
results.
Parameter nextToken :
If your initial ListScheduledActions operation returns a
nextToken, you can include the returned
nextToken in subsequent ListScheduledActions
operations, which returns results in the next page.
Implementation
Future<ListScheduledActionsResponse> listScheduledActions({
required String domainName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/2021-01-01/opensearch/domain/${Uri.encodeComponent(domainName)}/scheduledActions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListScheduledActionsResponse.fromJson(response);
}