listHandshakesForOrganization method
Lists the recent handshakes that you have sent.
You can view CANCELED, ACCEPTED,
DECLINED, or EXPIRED handshakes in API responses
for 30 days before they are deleted.
You can only call this operation from the management account or a member account that is a delegated administrator.
May throw AccessDeniedException.
May throw AWSOrganizationsNotInUseException.
May throw ConcurrentModificationException.
May throw InvalidInputException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter filter :
A HandshakeFilter object. Contains the filer used to select
the handshakes for an operation.
Parameter maxResults :
The maximum number of items to return in the response. If more results
exist than the specified MaxResults value, a token is
included in the response so that you can retrieve the remaining results.
Parameter nextToken :
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from.
Implementation
Future<ListHandshakesForOrganizationResponse> listHandshakesForOrganization({
HandshakeFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrganizationsV20161128.ListHandshakesForOrganization'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListHandshakesForOrganizationResponse.fromJson(jsonResponse.body);
}