putResourcePolicy method
Creates or updates a resource policy.
You can only call this operation from the management account..
May throw AccessDeniedException.
May throw AWSOrganizationsNotInUseException.
May throw ConcurrentModificationException.
May throw ConstraintViolationException.
May throw InvalidInputException.
May throw ServiceException.
May throw TooManyRequestsException.
May throw UnsupportedAPIEndpointException.
Parameter content :
If provided, the new content for the resource policy. The text must be
correctly formatted JSON that complies with the syntax for the resource
policy's type. For more information, see SCP
syntax in the Organizations User Guide.
Parameter tags :
A list of tags that you want to attach to the newly created resource
policy. For each tag in the list, you must specify both a tag key and a
value. You can set the value to an empty string, but you can't set it to
null. For more information about tagging, see Tagging
Organizations resources in the Organizations User Guide.
Implementation
Future<PutResourcePolicyResponse> putResourcePolicy({
required String content,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSOrganizationsV20161128.PutResourcePolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Content': content,
if (tags != null) 'Tags': tags,
},
);
return PutResourcePolicyResponse.fromJson(jsonResponse.body);
}