cancelCapacityTask method
Cancels the capacity task.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw NotFoundException.
May throw ValidationException.
Parameter capacityTaskId :
ID of the capacity task that you want to cancel.
Parameter outpostIdentifier :
ID or ARN of the Outpost associated with the capacity task that you want
to cancel.
Implementation
Future<void> cancelCapacityTask({
required String capacityTaskId,
required String outpostIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/outposts/${Uri.encodeComponent(outpostIdentifier)}/capacity/${Uri.encodeComponent(capacityTaskId)}',
exceptionFnMap: _exceptionFns,
);
}