listPackageImportJobs method
Returns a list of package import jobs.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
The maximum number of package import jobs to return in one page of
results.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListPackageImportJobsResponse> listPackageImportJobs({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
25,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/packages/import-jobs',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListPackageImportJobsResponse.fromJson(response);
}