sendEmailVerificationCode method
Sends an email verification code to the specified email address for account verification purposes.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
The catalog identifier for the partner account.
Parameter email :
The email address to send the verification code to.
Implementation
Future<void> sendEmailVerificationCode({
required String catalog,
required String email,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PartnerCentralAccount.SendEmailVerificationCode'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
'Email': email,
},
);
}