startProfileUpdateTask method
Initiates a profile update task to modify partner profile information asynchronously.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
The catalog identifier for the partner account.
Parameter identifier :
The unique identifier of the partner account.
Parameter taskDetails :
The details of the profile updates to be performed.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request.
Implementation
Future<StartProfileUpdateTaskResponse> startProfileUpdateTask({
required String catalog,
required String identifier,
required TaskDetails taskDetails,
String? clientToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PartnerCentralAccount.StartProfileUpdateTask'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
'Identifier': identifier,
'TaskDetails': taskDetails,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
},
);
return StartProfileUpdateTaskResponse.fromJson(jsonResponse.body);
}