deleteResourceSnapshotJob method
Use this action to deletes a previously created resource snapshot job. The job must be in a stopped state before it can be deleted.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
Specifies the catalog from which to delete the snapshot job. Valid values
are AWS and Sandbox.
Parameter resourceSnapshotJobIdentifier :
The unique identifier of the resource snapshot job to be deleted.
Implementation
Future<void> deleteResourceSnapshotJob({
required String catalog,
required String resourceSnapshotJobIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSPartnerCentralSelling.DeleteResourceSnapshotJob'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
'ResourceSnapshotJobIdentifier': resourceSnapshotJobIdentifier,
},
);
}