getSellingSystemSettings method
Retrieves the currently set system settings, which include the IAM Role used for resource snapshot jobs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
Specifies the catalog in which the settings are defined. Acceptable values
include AWS for production and Sandbox for
testing environments.
Implementation
Future<GetSellingSystemSettingsResponse> getSellingSystemSettings({
required String catalog,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSPartnerCentralSelling.GetSellingSystemSettings'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
},
);
return GetSellingSystemSettingsResponse.fromJson(jsonResponse.body);
}