stopResourceSnapshotJob method
Stops a resource snapshot job. The job must be started prior to being stopped.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter catalog :
Specifies the catalog related to the request. Valid values are:
- AWS: Stops the request from the production AWS environment.
- Sandbox: Stops the request from a sandbox environment used for testing or development purposes.
Parameter resourceSnapshotJobIdentifier :
The identifier of the job to stop.
Implementation
Future<void> stopResourceSnapshotJob({
required String catalog,
required String resourceSnapshotJobIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSPartnerCentralSelling.StopResourceSnapshotJob'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Catalog': catalog,
'ResourceSnapshotJobIdentifier': resourceSnapshotJobIdentifier,
},
);
}