associateMpaTeam method
Associates a Multi-Party Approval (MPA) team with a protected operation. For more information, see Multi-Party Approval in the Amazon Web Services Payment Cryptography User Guide.
Cross-account use: This operation can't be used across different Amazon Web Services accounts.
Related operations:
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter action :
The protected operation to associate with the MPA team. Currently, the
only supported value is IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE.
Parameter mpaTeamArn :
The ARN of the MPA team to associate with the protected operation.
Parameter requesterComment :
The comment from the requester explaining the reason for the association.
Implementation
Future<AssociateMpaTeamOutput> associateMpaTeam({
required MpaOperation action,
required String mpaTeamArn,
String? requesterComment,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PaymentCryptographyControlPlane.AssociateMpaTeam'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Action': action.value,
'MpaTeamArn': mpaTeamArn,
if (requesterComment != null) 'RequesterComment': requesterComment,
},
);
return AssociateMpaTeamOutput.fromJson(jsonResponse.body);
}