disassociateMpaTeam method
Future<DisassociateMpaTeamOutput>
disassociateMpaTeam({
- required MpaOperation action,
- String? requesterComment,
Removes the association between a Multi-Party Approval (MPA) team and a protected operation.
Cross-account use: This operation can't be used across different Amazon Web Services accounts.
Related operations:
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter action :
The protected operation to disassociate from the MPA team. Currently, the
only supported value is IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE.
Parameter requesterComment :
The comment from the requester explaining the reason for the
disassociation.
Implementation
Future<DisassociateMpaTeamOutput> disassociateMpaTeam({
required MpaOperation action,
String? requesterComment,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PaymentCryptographyControlPlane.DisassociateMpaTeam'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Action': action.value,
if (requesterComment != null) 'RequesterComment': requesterComment,
},
);
return DisassociateMpaTeamOutput.fromJson(jsonResponse.body);
}