getPublicKeyCertificate method
Gets the public key certificate of the asymmetric key pair that exists within Amazon Web Services Payment Cryptography.
Unlike the private key of an asymmetric key, which never leaves Amazon Web
Services Payment Cryptography unencrypted, callers with
GetPublicKeyCertificate permission can download the public
key certificate of the asymmetric key. You can share the public key
certificate to allow others to encrypt messages and verify signatures
outside of Amazon Web Services Payment Cryptography
Cross-account use: This operation supports cross-account use when the key has a resource-based policy that grants access. For more information, see Resource-based policies.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter keyIdentifier :
The KeyARN of the asymmetric key pair.
Implementation
Future<GetPublicKeyCertificateOutput> getPublicKeyCertificate({
required String keyIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PaymentCryptographyControlPlane.GetPublicKeyCertificate'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'KeyIdentifier': keyIdentifier,
},
);
return GetPublicKeyCertificateOutput.fromJson(jsonResponse.body);
}