listKeys method
Lists the keys in the caller's Amazon Web Services account and Amazon Web Services Region. You can filter the list of keys.
This is a paginated operation, which means that each response might
contain only a subset of all the keys. When the response contains only a
subset of keys, it includes a NextToken value. Use this value
in a subsequent ListKeys request to get more keys. When you
receive a response with no NextToken (or an empty or null value), that
means there are no more keys to get.
Cross-account use: This operation can't be used across different Amazon Web Services accounts.
Related operations:
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw ValidationException.
Parameter keyState :
The key state of the keys you want to list.
Parameter maxResults :
Use this parameter to specify the maximum number of items to return. When
this value is present, Amazon Web Services Payment Cryptography does not
return more than the specified number of items, but it might return fewer.
This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50.
Parameter nextToken :
Use this parameter in a subsequent request after you receive a response
with truncated results. Set it to the value of NextToken from
the truncated response you just received.
Implementation
Future<ListKeysOutput> listKeys({
KeyState? keyState,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'PaymentCryptographyControlPlane.ListKeys'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (keyState != null) 'KeyState': keyState.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListKeysOutput.fromJson(jsonResponse.body);
}