PcaConnectorAd class
Amazon Web Services Private CA Connector for Active Directory creates a connector between Amazon Web Services Private CA and Active Directory (AD) that enables you to provision security certificates for AD signed by a private CA that you own. For more information, see Amazon Web Services Private CA Connector for Active Directory.
Constructors
- PcaConnectorAd({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createConnector(
{required String certificateAuthorityArn, required String directoryId, required VpcInformation vpcInformation, String? clientToken, Map< String, String> ? tags}) → Future<CreateConnectorResponse> - Creates a connector between Amazon Web Services Private CA and an Active Directory. You must specify the private CA, directory ID, and security groups.
-
createDirectoryRegistration(
{required String directoryId, String? clientToken, Map< String, String> ? tags}) → Future<CreateDirectoryRegistrationResponse> - Creates a directory registration that authorizes communication between Amazon Web Services Private CA and an Active Directory
-
createServicePrincipalName(
{required String connectorArn, required String directoryRegistrationArn, String? clientToken}) → Future< void> - Creates a service principal name (SPN) for the service account in Active Directory. Kerberos authentication uses SPNs to associate a service instance with a service sign-in account.
-
createTemplate(
{required String connectorArn, required TemplateDefinition definition, required String name, String? clientToken, Map< String, String> ? tags}) → Future<CreateTemplateResponse> - Creates an Active Directory compatible certificate template. The connectors issues certificates using these templates based on the requester’s Active Directory group membership.
-
createTemplateGroupAccessControlEntry(
{required AccessRights accessRights, required String groupDisplayName, required String groupSecurityIdentifier, required String templateArn, String? clientToken}) → Future< void> - Create a group access control entry. Allow or deny Active Directory groups from enrolling and/or autoenrolling with the template based on the group security identifiers (SIDs).
-
deleteConnector(
{required String connectorArn}) → Future< void> - Deletes a connector for Active Directory. You must provide the Amazon Resource Name (ARN) of the connector that you want to delete. You can find the ARN by calling the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_ListConnectors action. Deleting a connector does not deregister your directory with Amazon Web Services Private CA. You can deregister your directory by calling the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_DeleteDirectoryRegistration action.
-
deleteDirectoryRegistration(
{required String directoryRegistrationArn}) → Future< void> - Deletes a directory registration. Deleting a directory registration deauthorizes Amazon Web Services Private CA with the directory.
-
deleteServicePrincipalName(
{required String connectorArn, required String directoryRegistrationArn}) → Future< void> - Deletes the service principal name (SPN) used by a connector to authenticate with your Active Directory.
-
deleteTemplate(
{required String templateArn}) → Future< void> - Deletes a template. Certificates issued using the template are still valid until they are revoked or expired.
-
deleteTemplateGroupAccessControlEntry(
{required String groupSecurityIdentifier, required String templateArn}) → Future< void> - Deletes a group access control entry.
-
getConnector(
{required String connectorArn}) → Future< GetConnectorResponse> - Lists information about your connector. You specify the connector on input by its ARN (Amazon Resource Name).
-
getDirectoryRegistration(
{required String directoryRegistrationArn}) → Future< GetDirectoryRegistrationResponse> - A structure that contains information about your directory registration.
-
getServicePrincipalName(
{required String connectorArn, required String directoryRegistrationArn}) → Future< GetServicePrincipalNameResponse> - Lists the service principal name that the connector uses to authenticate with Active Directory.
-
getTemplate(
{required String templateArn}) → Future< GetTemplateResponse> - Retrieves a certificate template that the connector uses to issue certificates from a private CA.
-
getTemplateGroupAccessControlEntry(
{required String groupSecurityIdentifier, required String templateArn}) → Future< GetTemplateGroupAccessControlEntryResponse> - Retrieves the group access control entries for a template.
-
listConnectors(
{int? maxResults, String? nextToken}) → Future< ListConnectorsResponse> - Lists the connectors that you created by using the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector action.
-
listDirectoryRegistrations(
{int? maxResults, String? nextToken}) → Future< ListDirectoryRegistrationsResponse> - Lists the directory registrations that you created by using the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration action.
-
listServicePrincipalNames(
{required String directoryRegistrationArn, int? maxResults, String? nextToken}) → Future< ListServicePrincipalNamesResponse> - Lists the service principal names that the connector uses to authenticate with Active Directory.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags, if any, that are associated with your resource.
-
listTemplateGroupAccessControlEntries(
{required String templateArn, int? maxResults, String? nextToken}) → Future< ListTemplateGroupAccessControlEntriesResponse> - Lists group access control entries you created.
-
listTemplates(
{required String connectorArn, int? maxResults, String? nextToken}) → Future< ListTemplatesResponse> - Lists the templates, if any, that are associated with a connector.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds one or more tags to your resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from your resource.
-
updateTemplate(
{required String templateArn, TemplateDefinition? definition, bool? reenrollAllCertificateHolders}) → Future< void> - Update template configuration to define the information included in certificates.
-
updateTemplateGroupAccessControlEntry(
{required String groupSecurityIdentifier, required String templateArn, AccessRights? accessRights, String? groupDisplayName}) → Future< void> - Update a group access control entry you created using CreateTemplateGroupAccessControlEntry.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited