createDirectoryRegistration method
Creates a directory registration that authorizes communication between Amazon Web Services Private CA and an Active Directory
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter directoryId :
The identifier of the Active Directory.
Parameter clientToken :
Idempotency token.
Parameter tags :
Metadata assigned to a directory registration consisting of a key-value
pair.
Implementation
Future<CreateDirectoryRegistrationResponse> createDirectoryRegistration({
required String directoryId,
String? clientToken,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'DirectoryId': directoryId,
'ClientToken': clientToken ?? _s.generateIdempotencyToken(),
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/directoryRegistrations',
exceptionFnMap: _exceptionFns,
);
return CreateDirectoryRegistrationResponse.fromJson(response);
}