deleteConnector method
Deletes a connector for Active Directory. You must provide the Amazon Resource Name (ARN) of the connector that you want to delete. You can find the ARN by calling the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_ListConnectors action. Deleting a connector does not deregister your directory with Amazon Web Services Private CA. You can deregister your directory by calling the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_DeleteDirectoryRegistration action.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter connectorArn :
The Amazon Resource Name (ARN) that was returned when you called CreateConnector.
Implementation
Future<void> deleteConnector({
required String connectorArn,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/connectors/${Uri.encodeComponent(connectorArn)}',
exceptionFnMap: _exceptionFns,
);
}