updateTemplateGroupAccessControlEntry method
Update a group access control entry you created using CreateTemplateGroupAccessControlEntry.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter groupSecurityIdentifier :
Security identifier (SID) of the group object from Active Directory. The
SID starts with "S-".
Parameter templateArn :
The Amazon Resource Name (ARN) that was returned when you called CreateTemplate.
Parameter accessRights :
Allow or deny permissions for an Active Directory group to enroll or
autoenroll certificates for a template.
Parameter groupDisplayName :
Name of the Active Directory group. This name does not need to match the
group name in Active Directory.
Implementation
Future<void> updateTemplateGroupAccessControlEntry({
required String groupSecurityIdentifier,
required String templateArn,
AccessRights? accessRights,
String? groupDisplayName,
}) async {
final $payload = <String, dynamic>{
if (accessRights != null) 'AccessRights': accessRights,
if (groupDisplayName != null) 'GroupDisplayName': groupDisplayName,
};
await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/templates/${Uri.encodeComponent(templateArn)}/accessControlEntries/${Uri.encodeComponent(groupSecurityIdentifier)}',
exceptionFnMap: _exceptionFns,
);
}