getCluster method
Returns detailed information about a running cluster in your account. This API action provides networking information, endpoint information for communication with the scheduler, and provisioning status.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter clusterIdentifier :
The name or ID of the cluster.
Implementation
Future<GetClusterResponse> getCluster({
required String clusterIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSParallelComputingService.GetCluster'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'clusterIdentifier': clusterIdentifier,
},
);
return GetClusterResponse.fromJson(jsonResponse.body);
}