registerComputeNodeGroupInstance method

Future<RegisterComputeNodeGroupInstanceResponse> registerComputeNodeGroupInstance({
  1. required String bootstrapId,
  2. required String clusterIdentifier,
})
PCS uses this API action to register the compute nodes it launches in your account.

May throw AccessDeniedException. May throw InternalServerException.

Parameter bootstrapId : The client-generated token to allow for retries.

Parameter clusterIdentifier : The name or ID of the cluster to register the compute node group instance in.

Implementation

Future<RegisterComputeNodeGroupInstanceResponse>
    registerComputeNodeGroupInstance({
  required String bootstrapId,
  required String clusterIdentifier,
}) async {
  final headers = <String, String>{
    'Content-Type': 'application/x-amz-json-1.0',
    'X-Amz-Target':
        'AWSParallelComputingService.RegisterComputeNodeGroupInstance'
  };
  final jsonResponse = await _protocol.send(
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    // TODO queryParams
    headers: headers,
    payload: {
      'bootstrapId': bootstrapId,
      'clusterIdentifier': clusterIdentifier,
    },
  );

  return RegisterComputeNodeGroupInstanceResponse.fromJson(jsonResponse.body);
}