pcs_2023_02_10 library
Classes
- AwsClientCredentials
- AWS credentials.
- Pcs
- Parallel Computing Service (PCS) is a managed service that makes it easier for you to run and scale your high performance computing (HPC) workloads, and build scientific and engineering models on Amazon Web Services using Slurm. For more information, see the Parallel Computing Service User Guide.