describeBatchSegmentJob method
Future<DescribeBatchSegmentJobResponse>
describeBatchSegmentJob({
- required String batchSegmentJobArn,
Gets the properties of a batch segment job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate segments.
May throw InvalidInputException.
May throw ResourceNotFoundException.
Parameter batchSegmentJobArn :
The ARN of the batch segment job to describe.
Implementation
Future<DescribeBatchSegmentJobResponse> describeBatchSegmentJob({
required String batchSegmentJobArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonPersonalize.DescribeBatchSegmentJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'batchSegmentJobArn': batchSegmentJobArn,
},
);
return DescribeBatchSegmentJobResponse.fromJson(jsonResponse.body);
}