listMetricAttributionMetrics method
Lists the metrics for the metric attribution.
May throw InvalidInputException.
May throw InvalidNextTokenException.
Parameter maxResults :
The maximum number of metrics to return in one page of results.
Parameter metricAttributionArn :
The Amazon Resource Name (ARN) of the metric attribution to retrieve
attributes for.
Parameter nextToken :
Specify the pagination token from a previous request to retrieve the next
page of results.
Implementation
Future<ListMetricAttributionMetricsResponse> listMetricAttributionMetrics({
int? maxResults,
String? metricAttributionArn,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonPersonalize.ListMetricAttributionMetrics'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (metricAttributionArn != null)
'metricAttributionArn': metricAttributionArn,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListMetricAttributionMetricsResponse.fromJson(jsonResponse.body);
}