updateCampaign method
Updates a campaign to deploy a retrained solution version with an existing
campaign, change your campaign's minProvisionedTPS, or modify
your campaign's configuration. For example, you can set
enableMetadataWithRecommendations to true for an existing
campaign.
To update a campaign to start automatically using the latest solution version, specify the following:
-
For the
SolutionVersionArnparameter, specify the Amazon Resource Name (ARN) of your solution inSolutionArn/$LATESTformat. -
In the
campaignConfig, setsyncWithLatestSolutionVersiontotrue.
May throw InvalidInputException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter campaignArn :
The Amazon Resource Name (ARN) of the campaign.
Parameter campaignConfig :
The configuration details of a campaign.
Parameter minProvisionedTPS :
Specifies the requested minimum provisioned transactions (recommendations)
per second that Amazon Personalize will support. A high
minProvisionedTPS will increase your bill. We recommend
starting with 1 for minProvisionedTPS (the default). Track
your usage using Amazon CloudWatch metrics, and increase the
minProvisionedTPS as necessary.
Parameter solutionVersionArn :
The Amazon Resource Name (ARN) of a new model to deploy. To specify the
latest solution version of your solution, specify the ARN of your
solution in SolutionArn/$LATEST format. You must use
this format if you set syncWithLatestSolutionVersion to
True in the CampaignConfig.
To deploy a model that isn't the latest solution version of your solution, specify the ARN of the solution version.
For more information about automatic campaign updates, see Enabling automatic campaign updates.
Implementation
Future<UpdateCampaignResponse> updateCampaign({
required String campaignArn,
CampaignConfig? campaignConfig,
int? minProvisionedTPS,
String? solutionVersionArn,
}) async {
_s.validateNumRange(
'minProvisionedTPS',
minProvisionedTPS,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonPersonalize.UpdateCampaign'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'campaignArn': campaignArn,
if (campaignConfig != null) 'campaignConfig': campaignConfig,
if (minProvisionedTPS != null) 'minProvisionedTPS': minProvisionedTPS,
if (solutionVersionArn != null)
'solutionVersionArn': solutionVersionArn,
},
);
return UpdateCampaignResponse.fromJson(jsonResponse.body);
}