cancelComponentDeployment method
Future<CancelComponentDeploymentOutput>
cancelComponentDeployment({
- required String componentName,
Attempts to cancel a component deployment (for a component that is in the
IN_PROGRESS deployment status).
For more information about components, see Proton components in the Proton User Guide.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter componentName :
The name of the component with the deployment to cancel.
Implementation
Future<CancelComponentDeploymentOutput> cancelComponentDeployment({
required String componentName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.CancelComponentDeployment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'componentName': componentName,
},
);
return CancelComponentDeploymentOutput.fromJson(jsonResponse.body);
}