cancelServicePipelineDeployment method
Future<CancelServicePipelineDeploymentOutput>
cancelServicePipelineDeployment({
- required String serviceName,
Attempts to cancel a service pipeline deployment on an
UpdateServicePipeline action, if the deployment is
IN_PROGRESS. For more information, see Update
a service pipeline in the Proton User guide.
The following list includes potential cancellation scenarios.
-
If the cancellation attempt succeeds, the resulting deployment state is
CANCELLED. -
If the cancellation attempt fails, the resulting deployment state is
FAILED. -
If the current UpdateServicePipeline action succeeds before the
cancellation attempt starts, the resulting deployment state is
SUCCEEDEDand the cancellation attempt has no effect.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter serviceName :
The name of the service with the service pipeline deployment to cancel.
Implementation
Future<CancelServicePipelineDeploymentOutput>
cancelServicePipelineDeployment({
required String serviceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.CancelServicePipelineDeployment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'serviceName': serviceName,
},
);
return CancelServicePipelineDeploymentOutput.fromJson(jsonResponse.body);
}