getServiceInstance method
Get detailed data for a service instance. A service instance is an instantiation of service template and it runs in a specific environment.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of a service instance that you want to get the detailed data for.
Parameter serviceName :
The name of the service that you want the service instance input for.
Implementation
Future<GetServiceInstanceOutput> getServiceInstance({
required String name,
required String serviceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.GetServiceInstance'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'name': name,
'serviceName': serviceName,
},
);
return GetServiceInstanceOutput.fromJson(jsonResponse.body);
}