getServiceSyncBlockerSummary method
Get detailed data for the service sync blocker summary.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter serviceName :
The name of the service that you want to get the service sync blocker
summary for. If given only the service name, all instances are blocked.
Parameter serviceInstanceName :
The name of the service instance that you want to get the service sync
blocker summary for. If given bothe the instance name and the service
name, only the instance is blocked.
Implementation
Future<GetServiceSyncBlockerSummaryOutput> getServiceSyncBlockerSummary({
required String serviceName,
String? serviceInstanceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.GetServiceSyncBlockerSummary'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'serviceName': serviceName,
if (serviceInstanceName != null)
'serviceInstanceName': serviceInstanceName,
},
);
return GetServiceSyncBlockerSummaryOutput.fromJson(jsonResponse.body);
}