listComponentProvisionedResources method
List provisioned resources for a component with details.
For more information about components, see Proton components in the Proton User Guide.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter componentName :
The name of the component whose provisioned resources you want.
Parameter nextToken :
A token that indicates the location of the next provisioned resource in
the array of provisioned resources, after the list of provisioned
resources that was previously requested.
Implementation
Future<ListComponentProvisionedResourcesOutput>
listComponentProvisionedResources({
required String componentName,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.ListComponentProvisionedResources'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'componentName': componentName,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListComponentProvisionedResourcesOutput.fromJson(jsonResponse.body);
}