listRepositorySyncDefinitions method
List repository sync definitions with detail data.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter repositoryName :
The repository name.
Parameter repositoryProvider :
The repository provider.
Parameter syncType :
The sync type. The only supported value is TEMPLATE_SYNC.
Parameter nextToken :
A token that indicates the location of the next repository sync definition
in the array of repository sync definitions, after the list of repository
sync definitions previously requested.
Implementation
Future<ListRepositorySyncDefinitionsOutput> listRepositorySyncDefinitions({
required String repositoryName,
required RepositoryProvider repositoryProvider,
required SyncType syncType,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.ListRepositorySyncDefinitions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'repositoryName': repositoryName,
'repositoryProvider': repositoryProvider.value,
'syncType': syncType.value,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListRepositorySyncDefinitionsOutput.fromJson(jsonResponse.body);
}