updateServiceSyncConfig method
Update the Proton Ops config file.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter branch :
The name of the code repository branch where the Proton Ops file is found.
Parameter filePath :
The path to the Proton Ops file.
Parameter repositoryName :
The name of the repository where the Proton Ops file is found.
Parameter repositoryProvider :
The name of the repository provider where the Proton Ops file is found.
Parameter serviceName :
The name of the service the Proton Ops file is for.
Implementation
Future<UpdateServiceSyncConfigOutput> updateServiceSyncConfig({
required String branch,
required String filePath,
required String repositoryName,
required RepositoryProvider repositoryProvider,
required String serviceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AwsProton20200720.UpdateServiceSyncConfig'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'branch': branch,
'filePath': filePath,
'repositoryName': repositoryName,
'repositoryProvider': repositoryProvider.value,
'serviceName': serviceName,
},
);
return UpdateServiceSyncConfigOutput.fromJson(jsonResponse.body);
}