deleteLibraryItem method
Deletes a library item for an Amazon Q App, removing it from the library so it can no longer be discovered or used by other users.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Parameter libraryItemId :
The unique identifier of the library item to delete.
Implementation
Future<void> deleteLibraryItem({
required String instanceId,
required String libraryItemId,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'libraryItemId': libraryItemId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/catalog.deleteItem',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}