disassociateLibraryItemReview method
Removes a rating or review previously submitted by the user for a library item.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Parameter libraryItemId :
The unique identifier of the library item to remove the review from.
Implementation
Future<void> disassociateLibraryItemReview({
required String instanceId,
required String libraryItemId,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'libraryItemId': libraryItemId,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/catalog.disassociateItemRating',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}