exportQAppSessionData method
Exports the collected data of a Q App data collection session.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Parameter sessionId :
The unique identifier of the Q App data collection session.
Implementation
Future<ExportQAppSessionDataOutput> exportQAppSessionData({
required String instanceId,
required String sessionId,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'sessionId': sessionId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/runtime.exportQAppSessionData',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ExportQAppSessionDataOutput.fromJson(response);
}