updateQAppSessionMetadata method
Updates the configuration metadata of a session for a given Q App
sessionId.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter instanceId :
The unique identifier of the Amazon Q Business application environment
instance.
Parameter sessionId :
The unique identifier of the Q App session to update configuration for.
Parameter sharingConfiguration :
The new sharing configuration for the Q App data collection session.
Parameter sessionName :
The new name for the Q App session.
Implementation
Future<UpdateQAppSessionMetadataOutput> updateQAppSessionMetadata({
required String instanceId,
required String sessionId,
required SessionSharingConfiguration sharingConfiguration,
String? sessionName,
}) async {
final headers = <String, String>{
'instance-id': instanceId.toString(),
};
final $payload = <String, dynamic>{
'sessionId': sessionId,
'sharingConfiguration': sharingConfiguration,
if (sessionName != null) 'sessionName': sessionName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/runtime.updateQAppSessionMetadata',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return UpdateQAppSessionMetadataOutput.fromJson(response);
}