deleteChatControlsConfiguration method
Deletes chat controls configured for an existing Amazon Q Business application.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the application the chat controls have been configured
for.
Implementation
Future<void> deleteChatControlsConfiguration({
required String applicationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/chatcontrols',
exceptionFnMap: _exceptionFns,
);
}