deleteChatResponseConfiguration method
Deletes a specified chat response configuration from an Amazon Q Business application.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The unique identifier of theAmazon Q Business application from which to
delete the chat response configuration.
Parameter chatResponseConfigurationId :
The unique identifier of the chat response configuration to delete from
the specified application.
Implementation
Future<void> deleteChatResponseConfiguration({
required String applicationId,
required String chatResponseConfigurationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/chatresponseconfigurations/${Uri.encodeComponent(chatResponseConfigurationId)}',
exceptionFnMap: _exceptionFns,
);
}