deleteDataSource method
Deletes an Amazon Q Business data source connector. While the data source
is being deleted, the Status field returned by a call to the
DescribeDataSource API is set to DELETING.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application used with the data
source connector.
Parameter dataSourceId :
The identifier of the data source connector that you want to delete.
Parameter indexId :
The identifier of the index used with the data source connector.
Implementation
Future<void> deleteDataSource({
required String applicationId,
required String dataSourceId,
required String indexId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}/datasources/${Uri.encodeComponent(dataSourceId)}',
exceptionFnMap: _exceptionFns,
);
}