getChatControlsConfiguration method
Gets information about chat controls configured for an existing Amazon Q Business application.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the application for which the chat controls are
configured.
Parameter maxResults :
The maximum number of configured chat controls to return.
Parameter nextToken :
If the maxResults response was incomplete because there is
more data to retrieve, Amazon Q Business returns a pagination token in the
response. You can use this pagination token to retrieve the next set of
Amazon Q Business chat controls configured.
Implementation
Future<GetChatControlsConfigurationResponse> getChatControlsConfiguration({
required String applicationId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/chatcontrols',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetChatControlsConfigurationResponse.fromJson(response);
}