getDataSource method
Gets information about an existing Amazon Q Business data source connector.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application.
Parameter dataSourceId :
The identifier of the data source connector.
Parameter indexId :
The identfier of the index used with the data source connector.
Implementation
Future<GetDataSourceResponse> getDataSource({
required String applicationId,
required String dataSourceId,
required String indexId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}/datasources/${Uri.encodeComponent(dataSourceId)}',
exceptionFnMap: _exceptionFns,
);
return GetDataSourceResponse.fromJson(response);
}