getIndex method
Gets information about an existing Amazon Q Business index.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application connected to the
index.
Parameter indexId :
The identifier of the Amazon Q Business index you want information on.
Implementation
Future<GetIndexResponse> getIndex({
required String applicationId,
required String indexId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}',
exceptionFnMap: _exceptionFns,
);
return GetIndexResponse.fromJson(response);
}