getPlugin method
Gets information about an existing Amazon Q Business plugin.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the application which contains the plugin.
Parameter pluginId :
The identifier of the plugin.
Implementation
Future<GetPluginResponse> getPlugin({
required String applicationId,
required String pluginId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/plugins/${Uri.encodeComponent(pluginId)}',
exceptionFnMap: _exceptionFns,
);
return GetPluginResponse.fromJson(response);
}