getUser method
Describes the universally unique identifier (UUID) associated with a local user in a data source.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the application connected to the user.
Parameter userId :
The user email address attached to the user.
Implementation
Future<GetUserResponse> getUser({
required String applicationId,
required String userId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/users/${Uri.encodeComponent(userId)}',
exceptionFnMap: _exceptionFns,
);
return GetUserResponse.fromJson(response);
}