listConversations method
Lists one or more Amazon Q Business conversations.
May throw AccessDeniedException.
May throw InternalServerException.
May throw LicenseNotFoundException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application.
Parameter maxResults :
The maximum number of Amazon Q Business conversations to return.
Parameter nextToken :
If the maxResults response was incomplete because there is
more data to retrieve, Amazon Q Business returns a pagination token in the
response. You can use this pagination token to retrieve the next set of
Amazon Q Business conversations.
Parameter userId :
The identifier of the user involved in the Amazon Q Business web
experience conversation.
Implementation
Future<ListConversationsResponse> listConversations({
required String applicationId,
int? maxResults,
String? nextToken,
String? userId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (userId != null) 'userId': [userId],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/conversations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListConversationsResponse.fromJson(response);
}