stopDataSourceSyncJob method
Stops an Amazon Q Business data source connector synchronization job already in progress.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationId :
The identifier of the Amazon Q Business application that the data source
is connected to.
Parameter dataSourceId :
The identifier of the data source connector.
Parameter indexId :
The identifier of the index used with the Amazon Q Business data source
connector.
Implementation
Future<void> stopDataSourceSyncJob({
required String applicationId,
required String dataSourceId,
required String indexId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/applications/${Uri.encodeComponent(applicationId)}/indices/${Uri.encodeComponent(indexId)}/datasources/${Uri.encodeComponent(dataSourceId)}/stopsync',
exceptionFnMap: _exceptionFns,
);
}