tagResource method
Adds the specified tag to the specified Amazon Q Business application or data source resource. If the tag already exists, the existing value is replaced with the new value.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceARN :
The Amazon Resource Name (ARN) of the Amazon Q Business application or
data source to tag.
Parameter tags :
A list of tag keys to add to the Amazon Q Business application or data
source. If a tag already exists, the existing value is replaced with the
new value.
Implementation
Future<void> tagResource({
required String resourceARN,
required List<Tag> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/tags/${Uri.encodeComponent(resourceARN)}',
exceptionFnMap: _exceptionFns,
);
}