deleteAIPrompt method
Deletes an Amazon Q in Connect AI Prompt.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter aiPromptId :
The identifier of the Amazon Q in Connect AI prompt. Can be either the ID
or the ARN. URLs cannot contain the ARN.
Parameter assistantId :
The identifier of the Amazon Q in Connect assistant. Can be either the ID
or the ARN. URLs cannot contain the ARN.
Implementation
Future<void> deleteAIPrompt({
required String aiPromptId,
required String assistantId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/assistants/${Uri.encodeComponent(assistantId)}/aiprompts/${Uri.encodeComponent(aiPromptId)}',
exceptionFnMap: _exceptionFns,
);
}