deleteAIPromptVersion method
Delete and Amazon Q in Connect AI Prompt version.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter aiPromptId :
The identifier of the Amazon Q in Connect AI prompt.
Parameter assistantId :
The identifier of the Amazon Q in Connect assistant. Can be either the ID
or the ARN. URLs cannot contain the ARN.
Parameter versionNumber :
The version number of the AI Prompt version to be deleted.
Implementation
Future<void> deleteAIPromptVersion({
required String aiPromptId,
required String assistantId,
required int versionNumber,
}) async {
_s.validateNumRange(
'versionNumber',
versionNumber,
1,
1152921504606846976,
isRequired: true,
);
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/assistants/${Uri.encodeComponent(assistantId)}/aiprompts/${Uri.encodeComponent(aiPromptId)}/versions/${Uri.encodeComponent(versionNumber.toString())}',
exceptionFnMap: _exceptionFns,
);
}