deleteMessageTemplate method
Deletes an Amazon Q in Connect message template entirely or a specific
version of the message template if version is supplied in the request. You
can provide the message template identifier as
<message-template-id>:<versionNumber> to delete a
specific version of the message template. If it is not supplied, the
message template and all available versions will be deleted.
May throw AccessDeniedException.
May throw ConflictException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter knowledgeBaseId :
The identifier of the knowledge base. Can be either the ID or the ARN.
URLs cannot contain the ARN.
Parameter messageTemplateId :
The identifier of the message template. Can be either the ID or the ARN.
Implementation
Future<void> deleteMessageTemplate({
required String knowledgeBaseId,
required String messageTemplateId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/knowledgeBases/${Uri.encodeComponent(knowledgeBaseId)}/messageTemplates/${Uri.encodeComponent(messageTemplateId)}',
exceptionFnMap: _exceptionFns,
);
}