listContentAssociations method
Lists the content associations.
For more information about content associations--what they are and when they are used--see Integrate Amazon Q in Connect with step-by-step guides in the Amazon Connect Administrator Guide.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter contentId :
The identifier of the content.
Parameter knowledgeBaseId :
The identifier of the knowledge base.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of results.
Implementation
Future<ListContentAssociationsResponse> listContentAssociations({
required String contentId,
required String knowledgeBaseId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/knowledgeBases/${Uri.encodeComponent(knowledgeBaseId)}/contents/${Uri.encodeComponent(contentId)}/associations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListContentAssociationsResponse.fromJson(response);
}