batchCreateTopicReviewedAnswer method
Creates new reviewed answers for a Q Topic.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter answers :
The definition of the Answers to be created.
Parameter awsAccountId :
The ID of the Amazon Web Services account that you want to create a
reviewed answer in.
Parameter topicId :
The ID for the topic reviewed answer that you want to create. This ID is
unique per Amazon Web Services Region for each Amazon Web Services
account.
Implementation
Future<BatchCreateTopicReviewedAnswerResponse>
batchCreateTopicReviewedAnswer({
required List<CreateTopicReviewedAnswer> answers,
required String awsAccountId,
required String topicId,
}) async {
final $payload = <String, dynamic>{
'Answers': answers,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/batch-create-reviewed-answers',
exceptionFnMap: _exceptionFns,
);
return BatchCreateTopicReviewedAnswerResponse.fromJson(response);
}