deleteActionConnector method
Hard deletes an action connector, making it unrecoverable. This operation removes the connector and all its associated configurations. Any resources currently using this action connector will no longer be able to perform actions through it.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter actionConnectorId :
The unique identifier of the action connector to delete.
Parameter awsAccountId :
The Amazon Web Services account ID that contains the action connector to
delete.
Implementation
Future<DeleteActionConnectorResponse> deleteActionConnector({
required String actionConnectorId,
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/action-connectors/${Uri.encodeComponent(actionConnectorId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteActionConnectorResponse.fromJson(response);
}