deleteDefaultQBusinessApplication method
Deletes a linked Amazon Q Business application from an Quick Sight account
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Quick Sight account that you want to disconnect from a
Amazon Q Business application.
Parameter namespace :
The Quick Sight namespace that you want to delete a linked Amazon Q
Business application from. If this field is left blank, the Amazon Q
Business application is deleted from the default namespace. Currently, the
default namespace is the only valid value for this parameter.
Implementation
Future<DeleteDefaultQBusinessApplicationResponse>
deleteDefaultQBusinessApplication({
required String awsAccountId,
String? namespace,
}) async {
final $query = <String, List<String>>{
if (namespace != null) 'namespace': [namespace],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/default-qbusiness-application',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DeleteDefaultQBusinessApplicationResponse.fromJson(response);
}