deleteIdentityPropagationConfig method
Future<DeleteIdentityPropagationConfigResponse>
deleteIdentityPropagationConfig({
- required String awsAccountId,
- required ServiceType service,
Deletes all access scopes and authorized targets that are associated with a service from the Quick Sight IAM Identity Center application.
This operation is only supported for Quick Sight accounts that use IAM Identity Center.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that you want to delete an
identity propagation configuration from.
Parameter service :
The name of the Amazon Web Services service that you want to delete the
associated access scopes and authorized targets from.
Implementation
Future<DeleteIdentityPropagationConfigResponse>
deleteIdentityPropagationConfig({
required String awsAccountId,
required ServiceType service,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/identity-propagation-config/${Uri.encodeComponent(service.value)}',
exceptionFnMap: _exceptionFns,
);
return DeleteIdentityPropagationConfigResponse.fromJson(response);
}