deleteNamespace method
Deletes a namespace and the users and groups that are associated with the namespace. This is an asynchronous process. Assets including dashboards, analyses, datasets and data sources are not deleted. To delete these assets, you use the API operations for the relevant asset.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that you want to delete the
Quick Sight namespace from.
Parameter namespace :
The namespace that you want to delete.
Implementation
Future<DeleteNamespaceResponse> deleteNamespace({
required String awsAccountId,
required String namespace,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}',
exceptionFnMap: _exceptionFns,
);
return DeleteNamespaceResponse.fromJson(response);
}