deleteUserCustomPermission method
Deletes a custom permissions profile from a user.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the custom
permission configuration that you want to delete.
Parameter namespace :
The namespace that the user belongs to.
Parameter userName :
The username of the user that you want to remove custom permissions from.
Implementation
Future<DeleteUserCustomPermissionResponse> deleteUserCustomPermission({
required String awsAccountId,
required String namespace,
required String userName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/users/${Uri.encodeComponent(userName)}/custom-permission',
exceptionFnMap: _exceptionFns,
);
return DeleteUserCustomPermissionResponse.fromJson(response);
}