deleteVPCConnection method
Deletes a VPC connection.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The Amazon Web Services account ID of the account where you want to delete
a VPC connection.
Parameter vPCConnectionId :
The ID of the VPC connection that you're creating. This ID is a unique
identifier for each Amazon Web Services Region in an Amazon Web Services
account.
Implementation
Future<DeleteVPCConnectionResponse> deleteVPCConnection({
required String awsAccountId,
required String vPCConnectionId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/vpc-connections/${Uri.encodeComponent(vPCConnectionId)}',
exceptionFnMap: _exceptionFns,
);
return DeleteVPCConnectionResponse.fromJson(response);
}