describeAccountCustomPermission method
Future<DescribeAccountCustomPermissionResponse>
describeAccountCustomPermission({
- required String awsAccountId,
Describes the custom permissions profile that is applied to an account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account for which you want to describe
the applied custom permissions profile.
Implementation
Future<DescribeAccountCustomPermissionResponse>
describeAccountCustomPermission({
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/custom-permission',
exceptionFnMap: _exceptionFns,
);
return DescribeAccountCustomPermissionResponse.fromJson(response);
}