describeAccountSettings method
Describes the settings that were used when your Quick Sight subscription was first created in this Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that contains the settings that
you want to list.
Implementation
Future<DescribeAccountSettingsResponse> describeAccountSettings({
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/settings',
exceptionFnMap: _exceptionFns,
);
return DescribeAccountSettingsResponse.fromJson(response);
}