describeAnalysisDefinition method
Provides a detailed description of the definition of an analysis.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter analysisId :
The ID of the analysis that you're describing. The ID is part of the URL
of the analysis.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the analysis. You
must be using the Amazon Web Services account that the analysis is in.
Implementation
Future<DescribeAnalysisDefinitionResponse> describeAnalysisDefinition({
required String analysisId,
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/analyses/${Uri.encodeComponent(analysisId)}/definition',
exceptionFnMap: _exceptionFns,
);
return DescribeAnalysisDefinitionResponse.fromJson(response);
}