describeAssetBundleExportJob method
Describes an existing export job.
Poll job descriptions after a job starts to know the status of the job.
When a job succeeds, a URL is provided to download the exported assets'
data from. Download URLs are valid for five minutes after they are
generated. You can call the DescribeAssetBundleExportJob API
for a new download URL as needed.
Job descriptions are available for 14 days after the job starts.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter assetBundleExportJobId :
The ID of the job that you want described. The job ID is set when you
start a new job with a StartAssetBundleExportJob API call.
Parameter awsAccountId :
The ID of the Amazon Web Services account the export job is executed in.
Implementation
Future<DescribeAssetBundleExportJobResponse> describeAssetBundleExportJob({
required String assetBundleExportJobId,
required String awsAccountId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/asset-bundle-export-jobs/${Uri.encodeComponent(assetBundleExportJobId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeAssetBundleExportJobResponse.fromJson(response);
}