describeDashboardPermissions method
Describes read and write permissions for a dashboard.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the dashboard that
you're describing permissions for.
Parameter dashboardId :
The ID for the dashboard, also added to the IAM policy.
Implementation
Future<DescribeDashboardPermissionsResponse> describeDashboardPermissions({
required String awsAccountId,
required String dashboardId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return DescribeDashboardPermissionsResponse.fromJson(response);
}