describeDashboardSnapshotJobResult method
Describes the result of an existing snapshot job that has finished running.
A finished snapshot job will return a COMPLETED or
FAILED status when you poll the job with a
DescribeDashboardSnapshotJob API call.
If the job has not finished running, this operation returns a message that
says Dashboard Snapshot Job with id .
Registered user support
This API can be called as before to get the result of a job started by the
same Quick Sight user. The result for the user will be returned in
RegisteredUsers response attribute. The attribute will
contain a list with at most one object in it.
Possible error scenarios
The request fails with an Access Denied error in the following scenarios:
- The credentials have expired.
- The job was started by a different user.
- The registered user doesn't have access to the specified dashboard.
-
DASHBOARD_ACCESS_DENIED- The registered user lost access to the dashboard. -
CAPABILITY_RESTRICTED- The registered user is restricted from exporting data in all selected formats.
-
CAPABILITY_RESTRICTED- The registered user is restricted from exporting data in some selected formats. -
RLS_CHANGED- Row-level security settings have changed. Re-run the job with current settings. -
CLS_CHANGED- Column-level security settings have changed. Re-run the job with current settings. -
DATASET_DELETED- The dataset has been deleted. Verify the dataset exists before re-running the job.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that the dashboard snapshot job
is executed in.
Parameter dashboardId :
The ID of the dashboard that you have started a snapshot job for.
Parameter snapshotJobId :
The ID of the job to be described. The job ID is set when you start a new
job with a StartDashboardSnapshotJob API call.
Implementation
Future<DescribeDashboardSnapshotJobResultResponse>
describeDashboardSnapshotJobResult({
required String awsAccountId,
required String dashboardId,
required String snapshotJobId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/dashboards/${Uri.encodeComponent(dashboardId)}/snapshot-jobs/${Uri.encodeComponent(snapshotJobId)}/result',
exceptionFnMap: _exceptionFns,
);
return DescribeDashboardSnapshotJobResultResponse.fromJson(response);
}