describeFolderPermissions method
Describes permissions for a folder.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID for the Amazon Web Services account that contains the folder.
Parameter folderId :
The ID of the folder.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter namespace :
The namespace of the folder whose permissions you want described.
Parameter nextToken :
A pagination token for the next set of results.
Implementation
Future<DescribeFolderPermissionsResponse> describeFolderPermissions({
required String awsAccountId,
required String folderId,
int? maxResults,
String? namespace,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (namespace != null) 'namespace': [namespace],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/folders/${Uri.encodeComponent(folderId)}/permissions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeFolderPermissionsResponse.fromJson(response);
}