describeKeyRegistration method
Describes all customer managed key registrations in a Quick Sight account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the customer
managed key registration that you want to describe.
Parameter defaultKeyOnly :
Determines whether the request returns the default key only.
Implementation
Future<DescribeKeyRegistrationResponse> describeKeyRegistration({
required String awsAccountId,
bool? defaultKeyOnly,
}) async {
final $query = <String, List<String>>{
if (defaultKeyOnly != null)
'default-key-only': [defaultKeyOnly.toString()],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/key-registration',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeKeyRegistrationResponse.fromJson(response);
}