describeThemeAlias method
Describes the alias for a theme.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter aliasName :
The name of the theme alias that you want to describe.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the theme alias
that you're describing.
Parameter themeId :
The ID for the theme.
Implementation
Future<DescribeThemeAliasResponse> describeThemeAlias({
required String aliasName,
required String awsAccountId,
required String themeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}/aliases/${Uri.encodeComponent(aliasName)}',
exceptionFnMap: _exceptionFns,
);
return DescribeThemeAliasResponse.fromJson(response);
}