describeThemePermissions method
Describes the read and write permissions for a theme.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the theme that
you're describing.
Parameter themeId :
The ID for the theme that you want to describe permissions for.
Implementation
Future<DescribeThemePermissionsResponse> describeThemePermissions({
required String awsAccountId,
required String themeId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/themes/${Uri.encodeComponent(themeId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return DescribeThemePermissionsResponse.fromJson(response);
}