describeTopicRefresh method
Describes the status of a topic refresh.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the topic whose
refresh you want to describe.
Parameter refreshId :
The ID of the refresh, which is performed when the topic is created or
updated.
Parameter topicId :
The ID of the topic that you want to describe. This ID is unique per
Amazon Web Services Region for each Amazon Web Services account.
Implementation
Future<DescribeTopicRefreshResponse> describeTopicRefresh({
required String awsAccountId,
required String refreshId,
required String topicId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/refresh/${Uri.encodeComponent(refreshId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeTopicRefreshResponse.fromJson(response);
}