getFlowMetadata method
Retrieves the metadata of a flow, not including its definition specifying the steps.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the flow that you
are getting metadata for.
Parameter flowId :
The unique identifier of the flow.
Implementation
Future<GetFlowMetadataOutput> getFlowMetadata({
required String awsAccountId,
required String flowId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/flows/${Uri.encodeComponent(flowId)}/metadata',
exceptionFnMap: _exceptionFns,
);
return GetFlowMetadataOutput.fromJson(response);
}