getFlowPermissions method
Get permissions for a flow.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the flow that you
are getting permissions for.
Parameter flowId :
The unique identifier of the flow to get permissions from.
Implementation
Future<GetFlowPermissionsOutput> getFlowPermissions({
required String awsAccountId,
required String flowId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/flows/${Uri.encodeComponent(flowId)}/permissions',
exceptionFnMap: _exceptionFns,
);
return GetFlowPermissionsOutput.fromJson(response);
}