listFlows method
Lists flows in an Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the flow list that
you are getting.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter nextToken :
The token to request the next set of results, or null if you want to
retrieve the first set.
Implementation
Future<ListFlowsOutput> listFlows({
required String awsAccountId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/flows',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFlowsOutput.fromJson(response);
}