listThemes method
Lists all the themes in the current Amazon Web Services account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnsupportedUserEditionException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the themes that
you're listing.
Parameter maxResults :
The maximum number of results to be returned per request.
Parameter nextToken :
The token for the next set of results, or null if there are no more
results.
Parameter type :
The type of themes that you want to list. Valid options include the
following:
-
ALL (default)- Display all existing themes. -
CUSTOM- Display only the themes created by people using Amazon Quick Sight. -
QUICKSIGHT- Display only the starting themes defined by Quick Sight.
Implementation
Future<ListThemesResponse> listThemes({
required String awsAccountId,
int? maxResults,
String? nextToken,
ThemeType? type,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
if (type != null) 'type': [type.value],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts/${Uri.encodeComponent(awsAccountId)}/themes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListThemesResponse.fromJson(response);
}