listTopicReviewedAnswers method
Lists all reviewed answers for a Q Topic.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that containd the reviewed
answers that you want listed.
Parameter topicId :
The ID for the topic that contains the reviewed answer that you want to
list. This ID is unique per Amazon Web Services Region for each Amazon Web
Services account.
Implementation
Future<ListTopicReviewedAnswersResponse> listTopicReviewedAnswers({
required String awsAccountId,
required String topicId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/reviewed-answers',
exceptionFnMap: _exceptionFns,
);
return ListTopicReviewedAnswersResponse.fromJson(response);
}