searchActionConnectors method
Searches for action connectors in the specified Amazon Web Services account using filters. You can search by connector name, type, or user permissions.
May throw AccessDeniedException.
May throw InvalidNextTokenException.
May throw InvalidParameterValueException.
May throw ThrottlingException.
Parameter awsAccountId :
The Amazon Web Services account ID in which to search for action
connectors.
Parameter filters :
The search filters to apply. You can filter by connector name, type, or
user permissions. Maximum of one filter is supported.
Parameter maxResults :
The maximum number of action connectors to return in a single response.
Valid range is 1 to 100.
Parameter nextToken :
A pagination token to retrieve the next set of results. Use the token
returned from a previous call to continue searching.
Implementation
Future<SearchActionConnectorsResponse> searchActionConnectors({
required String awsAccountId,
required List<ActionConnectorSearchFilter> filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'max-results': [maxResults.toString()],
if (nextToken != null) 'next-token': [nextToken],
};
final $payload = <String, dynamic>{
'Filters': filters,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/search/action-connectors',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return SearchActionConnectorsResponse.fromJson(response);
}