updateIdentityPropagationConfig method
Adds or updates services and authorized targets to configure what the Quick Sight IAM Identity Center application can access.
This operation is only supported for Quick Sight accounts using IAM Identity Center
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the identity
propagation configuration that you want to update.
Parameter service :
The name of the Amazon Web Services service that contains the authorized
targets that you want to add or update.
Parameter authorizedTargets :
Specifies a list of application ARNs that represent the authorized targets
for a service.
Implementation
Future<UpdateIdentityPropagationConfigResponse>
updateIdentityPropagationConfig({
required String awsAccountId,
required ServiceType service,
List<String>? authorizedTargets,
}) async {
final $payload = <String, dynamic>{
if (authorizedTargets != null) 'AuthorizedTargets': authorizedTargets,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/identity-propagation-config/${Uri.encodeComponent(service.value)}',
exceptionFnMap: _exceptionFns,
);
return UpdateIdentityPropagationConfigResponse.fromJson(response);
}