updateQPersonalizationConfiguration method
Future<UpdateQPersonalizationConfigurationResponse>
updateQPersonalizationConfiguration({
- required String awsAccountId,
- required PersonalizationMode personalizationMode,
Updates a personalization configuration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account account that contains the
personalization configuration that the user wants to update.
Parameter personalizationMode :
An option to allow Amazon Quick Sight to customize data stories with user
specific metadata, specifically location and job information, in your IAM
Identity Center instance.
Implementation
Future<UpdateQPersonalizationConfigurationResponse>
updateQPersonalizationConfiguration({
required String awsAccountId,
required PersonalizationMode personalizationMode,
}) async {
final $payload = <String, dynamic>{
'PersonalizationMode': personalizationMode.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/q-personalization-configuration',
exceptionFnMap: _exceptionFns,
);
return UpdateQPersonalizationConfigurationResponse.fromJson(response);
}