updateSPICECapacityConfiguration method
Future<UpdateSPICECapacityConfigurationResponse>
updateSPICECapacityConfiguration({
- required String awsAccountId,
- required PurchaseMode purchaseMode,
Updates the SPICE capacity configuration for a Quick Sight account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the SPICE
configuration that you want to update.
Parameter purchaseMode :
Determines how SPICE capacity can be purchased. The following options are
available.
-
MANUAL: SPICE capacity can only be purchased manually. -
AUTO_PURCHASE: Extra SPICE capacity is automatically purchased on your behalf as needed. SPICE capacity can also be purchased manually with this option.
Implementation
Future<UpdateSPICECapacityConfigurationResponse>
updateSPICECapacityConfiguration({
required String awsAccountId,
required PurchaseMode purchaseMode,
}) async {
final $payload = <String, dynamic>{
'PurchaseMode': purchaseMode.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/spice-capacity-configuration',
exceptionFnMap: _exceptionFns,
);
return UpdateSPICECapacityConfigurationResponse.fromJson(response);
}