updateSelfUpgradeConfiguration method
Updates the self-upgrade configuration for a Quick account.
May throw AccessDeniedException.
May throw InternalFailureException.
May throw InvalidParameterException.
May throw InvalidParameterValueException.
May throw PreconditionNotMetException.
May throw ResourceNotFoundException.
May throw ResourceUnavailableException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the Quick
self-upgrade configuration that you want to update.
Parameter namespace :
The Quick namespace that you want to update the Quick self-upgrade
configuration for.
Parameter selfUpgradeStatus :
The self-upgrade status that you want to set for the Quick account.
Implementation
Future<UpdateSelfUpgradeConfigurationResponse>
updateSelfUpgradeConfiguration({
required String awsAccountId,
required String namespace,
required SelfUpgradeStatus selfUpgradeStatus,
}) async {
final $payload = <String, dynamic>{
'SelfUpgradeStatus': selfUpgradeStatus.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/namespaces/${Uri.encodeComponent(namespace)}/self-upgrade-configuration',
exceptionFnMap: _exceptionFns,
);
return UpdateSelfUpgradeConfigurationResponse.fromJson(response);
}