updateSpace method
Updates the metadata of an Amazon QuickSight space.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the space.
Parameter spaceId :
The ID of the space that you want to update.
Parameter description :
A new description for the space.
Parameter name :
A new display name for the space.
Implementation
Future<UpdateSpaceResponse> updateSpace({
required String awsAccountId,
required String spaceId,
String? description,
String? name,
}) async {
final $payload = <String, dynamic>{
if (description != null) 'Description': description,
if (name != null) 'Name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/accounts/${Uri.encodeComponent(awsAccountId)}/spaces/${Uri.encodeComponent(spaceId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateSpaceResponse.fromJson(response);
}