updateTopicRefreshSchedule method
Updates a topic refresh schedule.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalFailureException.
May throw InvalidParameterValueException.
May throw LimitExceededException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter awsAccountId :
The ID of the Amazon Web Services account that contains the topic whose
refresh schedule you want to update.
Parameter datasetId :
The ID of the dataset.
Parameter refreshSchedule :
The definition of a refresh schedule.
Parameter topicId :
The ID of the topic that you want to modify. This ID is unique per Amazon
Web Services Region for each Amazon Web Services account.
Implementation
Future<UpdateTopicRefreshScheduleResponse> updateTopicRefreshSchedule({
required String awsAccountId,
required String datasetId,
required TopicRefreshSchedule refreshSchedule,
required String topicId,
}) async {
final $payload = <String, dynamic>{
'RefreshSchedule': refreshSchedule,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/accounts/${Uri.encodeComponent(awsAccountId)}/topics/${Uri.encodeComponent(topicId)}/schedules/${Uri.encodeComponent(datasetId)}',
exceptionFnMap: _exceptionFns,
);
return UpdateTopicRefreshScheduleResponse.fromJson(response);
}