createResourceShare method
Creates a resource share. You can provide a list of the Amazon Resource Names (ARNs) for the resources that you want to share, a list of principals you want to share the resources with, the permissions to grant those principals, and optionally source constraints to enhance security for service principal sharing.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw InvalidStateTransitionException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ResourceShareLimitExceededException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw TagLimitExceededException.
May throw TagPolicyViolationException.
May throw ThrottlingException.
May throw UnknownResourceException.
Parameter name :
Specifies the name of the resource share.
Parameter allowExternalPrincipals :
Specifies whether principals outside your organization in Organizations
can be associated with a resource share. A value of true lets
you share with individual Amazon Web Services accounts that are not
in your organization. A value of false only has meaning if
your account is a member of an Amazon Web Services Organization. The
default value is true.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter permissionArns :
Specifies the Amazon
Resource Names (ARNs) of the RAM permission to associate with the
resource share. If you do not specify an ARN for the permission, RAM
automatically attaches the default version of the permission for each
resource type. You can associate only one permission with each resource
type included in the resource share.
Parameter principals :
Specifies a list of one or more principals to associate with the resource
share.
You can include the following values:
-
An Amazon Web Services account ID, for example:
123456789012 -
An Amazon
Resource Name (ARN) of an organization in Organizations, for example:
organizations::123456789012:organization/o-exampleorgid -
An ARN of an organizational unit (OU) in Organizations, for example:
organizations::123456789012:ou/o-exampleorgid/ou-examplerootid-exampleouid123 -
An ARN of an IAM role, for example:
iam::123456789012:role/rolename -
An ARN of an IAM user, for example:
iam::123456789012user/username -
A service principal name, for example:
service-id.amazonaws.com
Parameter resourceArns :
Specifies a list of one or more ARNs of the resources to associate with
the resource share.
Parameter resourceShareConfiguration :
Specifies the configuration of this resource share.
Parameter sources :
Specifies source constraints (accounts, ARNs, organization IDs, or
organization paths) that limit when service principals can access
resources in this resource share. When a service principal attempts to
access a shared resource, validation is performed to ensure the request
originates from one of the specified sources. This helps prevent confused
deputy attacks by applying constraints on where service principals can
access resources from.
Parameter tags :
Specifies one or more tags to attach to the resource share itself. It
doesn't attach the tags to the resources associated with the resource
share.
Implementation
Future<CreateResourceShareResponse> createResourceShare({
required String name,
bool? allowExternalPrincipals,
String? clientToken,
List<String>? permissionArns,
List<String>? principals,
List<String>? resourceArns,
ResourceShareConfiguration? resourceShareConfiguration,
List<String>? sources,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'name': name,
if (allowExternalPrincipals != null)
'allowExternalPrincipals': allowExternalPrincipals,
if (clientToken != null) 'clientToken': clientToken,
if (permissionArns != null) 'permissionArns': permissionArns,
if (principals != null) 'principals': principals,
if (resourceArns != null) 'resourceArns': resourceArns,
if (resourceShareConfiguration != null)
'resourceShareConfiguration': resourceShareConfiguration,
if (sources != null) 'sources': sources,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/createresourceshare',
exceptionFnMap: _exceptionFns,
);
return CreateResourceShareResponse.fromJson(response);
}