disassociateResourceShare method
Removes the specified principals, resources, or source constraints from participating in the specified resource share.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw InvalidStateTransitionException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ResourceShareLimitExceededException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
May throw UnknownResourceException.
Parameter resourceShareArn :
Specifies Amazon
Resource Name (ARN) of the resource share that you want to remove
resources or principals from.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter principals :
Specifies a list of one or more principals that no longer are to have
access to the resources in this resource share.
You can include the following values:
-
An Amazon Web Services account ID, for example:
123456789012 -
An Amazon
Resource Name (ARN) of an organization in Organizations, for example:
organizations::123456789012:organization/o-exampleorgid -
An ARN of an organizational unit (OU) in Organizations, for example:
organizations::123456789012:ou/o-exampleorgid/ou-examplerootid-exampleouid123 -
An ARN of an IAM role, for example:
iam::123456789012:role/rolename -
An ARN of an IAM user, for example:
iam::123456789012user/username -
A service principal name, for example:
service-id.amazonaws.com
Parameter resourceArns :
Specifies a list of Amazon
Resource Names (ARNs) for one or more resources that you want to
remove from the resource share. After the operation runs, these resources
are no longer shared with principals associated with the resource share.
Parameter sources :
Specifies source constraints (accounts, ARNs, organization IDs, or
organization paths) to remove from the resource share. This enables
granular management of source constraints while maintaining service
principal associations. At least one source must remain when service
principals are present.
Implementation
Future<DisassociateResourceShareResponse> disassociateResourceShare({
required String resourceShareArn,
String? clientToken,
List<String>? principals,
List<String>? resourceArns,
List<String>? sources,
}) async {
final $payload = <String, dynamic>{
'resourceShareArn': resourceShareArn,
if (clientToken != null) 'clientToken': clientToken,
if (principals != null) 'principals': principals,
if (resourceArns != null) 'resourceArns': resourceArns,
if (sources != null) 'sources': sources,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/disassociateresourceshare',
exceptionFnMap: _exceptionFns,
);
return DisassociateResourceShareResponse.fromJson(response);
}