getResourceShareAssociations method
Retrieves the lists of resources and principals that associated for resource shares that you own.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter associationType :
Specifies whether you want to retrieve the associations that involve a
specified resource or principal.
-
PRINCIPAL– list the principals whose associations you want to see. -
RESOURCE– list the resources whose associations you want to see.
Parameter associationStatus :
Specifies that you want to retrieve only associations that have this
status.
Parameter maxResults :
Specifies the total number of results that you want included on each page
of the response. If you do not include this parameter, it defaults to a
value that is specific to the operation. If additional items exist beyond
the number you specify, the NextToken response element is
returned with a value (not null). Include the specified value as the
NextToken request parameter in the next call to the operation
to get the next part of the results. Note that the service might return
fewer results than the maximum even when there are more results available.
You should check NextToken after every operation to ensure
that you receive all of the results.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Parameter principal :
Specifies the ID of the principal whose resource shares you want to
retrieve. This can be an Amazon Web Services account ID, an organization
ID, an organizational unit ID, or the Amazon
Resource Name (ARN) of an individual IAM role or user.
You cannot specify this parameter if the association type is
RESOURCE.
Parameter resourceArn :
Specifies the Amazon
Resource Name (ARN) of a resource whose resource shares you want to
retrieve.
You cannot specify this parameter if the association type is
PRINCIPAL.
Parameter resourceShareArns :
Specifies a list of Amazon
Resource Names (ARNs) of the resource share whose associations you
want to retrieve.
Implementation
Future<GetResourceShareAssociationsResponse> getResourceShareAssociations({
required ResourceShareAssociationType associationType,
ResourceShareAssociationStatus? associationStatus,
int? maxResults,
String? nextToken,
String? principal,
String? resourceArn,
List<String>? resourceShareArns,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
'associationType': associationType.value,
if (associationStatus != null)
'associationStatus': associationStatus.value,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (principal != null) 'principal': principal,
if (resourceArn != null) 'resourceArn': resourceArn,
if (resourceShareArns != null) 'resourceShareArns': resourceShareArns,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/getresourceshareassociations',
exceptionFnMap: _exceptionFns,
);
return GetResourceShareAssociationsResponse.fromJson(response);
}