listPendingInvitationResources method
Lists the resources in a resource share that is shared with you but for
which the invitation is still PENDING. That means that you
haven't accepted or rejected the invitation and the invitation hasn't
expired.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw MissingRequiredParameterException.
May throw ResourceShareInvitationAlreadyRejectedException.
May throw ResourceShareInvitationArnNotFoundException.
May throw ResourceShareInvitationExpiredException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
Parameter resourceShareInvitationArn :
Specifies the Amazon
Resource Name (ARN) of the invitation. You can use
GetResourceShareInvitations to find the ARN of the invitation.
Parameter maxResults :
Specifies the total number of results that you want included on each page
of the response. If you do not include this parameter, it defaults to a
value that is specific to the operation. If additional items exist beyond
the number you specify, the NextToken response element is
returned with a value (not null). Include the specified value as the
NextToken request parameter in the next call to the operation
to get the next part of the results. Note that the service might return
fewer results than the maximum even when there are more results available.
You should check NextToken after every operation to ensure
that you receive all of the results.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Parameter resourceRegionScope :
Specifies that you want the results to include only resources that have
the specified scope.
-
ALL– the results include both global and regional resources or resource types. -
GLOBAL– the results include only global resources or resource types. -
REGIONAL– the results include only regional resources or resource types.
ALL.
Implementation
Future<ListPendingInvitationResourcesResponse>
listPendingInvitationResources({
required String resourceShareInvitationArn,
int? maxResults,
String? nextToken,
ResourceRegionScopeFilter? resourceRegionScope,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
'resourceShareInvitationArn': resourceShareInvitationArn,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (resourceRegionScope != null)
'resourceRegionScope': resourceRegionScope.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listpendinginvitationresources',
exceptionFnMap: _exceptionFns,
);
return ListPendingInvitationResourcesResponse.fromJson(response);
}