promoteResourceShareCreatedFromPolicy method
When you attach a resource-based policy to a resource, RAM automatically
creates a resource share of
featureSet=CREATED_FROM_POLICY with a managed
permission that has the same IAM permissions as the original
resource-based policy. However, this type of managed permission is visible
to only the resource share owner, and the associated resource share can't
be modified by using RAM.
This operation promotes the resource share to a STANDARD
resource share that is fully manageable in RAM. When you promote a
resource share, you can then manage the resource share in RAM and it
becomes visible to all of the principals you shared it with.
May throw InvalidParameterException.
May throw InvalidStateTransitionException.
May throw MalformedArnException.
May throw MissingRequiredParameterException.
May throw OperationNotPermittedException.
May throw ResourceShareLimitExceededException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
May throw UnmatchedPolicyPermissionException.
Parameter resourceShareArn :
Specifies the Amazon
Resource Name (ARN) of the resource share to promote.
Implementation
Future<PromoteResourceShareCreatedFromPolicyResponse>
promoteResourceShareCreatedFromPolicy({
required String resourceShareArn,
}) async {
final $query = <String, List<String>>{
'resourceShareArn': [resourceShareArn],
};
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/promoteresourcesharecreatedfrompolicy',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return PromoteResourceShareCreatedFromPolicyResponse.fromJson(response);
}