replacePermissionAssociations method
Updates all resource shares that use a managed permission to a different managed permission. This operation always applies the default version of the target managed permission. You can optionally specify that the update applies to only resource shares that currently use a specified version. This enables you to update to the latest version, without changing the which managed permission is used.
You can use this operation to update all of your resource shares to use
the current default version of the permission by specifying the same value
for the fromPermissionArn and toPermissionArn
parameters.
You can use the optional fromPermissionVersion parameter to
update only those resources that use a specified version of the managed
permission to the new managed permission.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw OperationNotPermittedException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter fromPermissionArn :
Specifies the Amazon
Resource Name (ARN) of the managed permission that you want to
replace.
Parameter toPermissionArn :
Specifies the ARN of the managed permission that you want to associate
with resource shares in place of the one specified by
fromPerssionArn and fromPermissionVersion.
The operation always associates the version that is currently the default for the specified managed permission.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter fromPermissionVersion :
Specifies that you want to updated the permissions for only those resource
shares that use the specified version of the managed permission.
Implementation
Future<ReplacePermissionAssociationsResponse> replacePermissionAssociations({
required String fromPermissionArn,
required String toPermissionArn,
String? clientToken,
int? fromPermissionVersion,
}) async {
final $payload = <String, dynamic>{
'fromPermissionArn': fromPermissionArn,
'toPermissionArn': toPermissionArn,
if (clientToken != null) 'clientToken': clientToken,
if (fromPermissionVersion != null)
'fromPermissionVersion': fromPermissionVersion,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/replacepermissionassociations',
exceptionFnMap: _exceptionFns,
);
return ReplacePermissionAssociationsResponse.fromJson(response);
}