untagResource method
Removes the specified tag key and value pairs from the specified resource share or managed permission.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter tagKeys :
Specifies a list of one or more tag keys that you want to remove.
Parameter resourceArn :
Specifies the Amazon
Resource Name (ARN) of the managed permission that you want to remove
tags from. You must specify either resourceArn, or
resourceShareArn, but not both.
Parameter resourceShareArn :
Specifies the Amazon
Resource Name (ARN) of the resource share that you want to remove tags
from. The tags are removed from the resource share, not the resources in
the resource share. You must specify either resourceShareArn,
or resourceArn, but not both.
Implementation
Future<void> untagResource({
required List<String> tagKeys,
String? resourceArn,
String? resourceShareArn,
}) async {
final $payload = <String, dynamic>{
'tagKeys': tagKeys,
if (resourceArn != null) 'resourceArn': resourceArn,
if (resourceShareArn != null) 'resourceShareArn': resourceShareArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/untagresource',
exceptionFnMap: _exceptionFns,
);
}