updateResourceShare method
Modifies some of the properties of the specified resource share.
May throw IdempotentParameterMismatchException.
May throw InvalidClientTokenException.
May throw InvalidParameterException.
May throw MalformedArnException.
May throw MissingRequiredParameterException.
May throw OperationNotPermittedException.
May throw ServerInternalException.
May throw ServiceUnavailableException.
May throw UnknownResourceException.
Parameter resourceShareArn :
Specifies the Amazon
Resource Name (ARN) of the resource share that you want to modify.
Parameter allowExternalPrincipals :
Specifies whether principals outside your organization in Organizations
can be associated with a resource share.
Parameter clientToken :
Specifies a unique, case-sensitive identifier that you provide to ensure
the idempotency of the request. This lets you safely retry the request
without accidentally performing the same operation a second time. Passing
the same value to a later call to an operation requires that you also pass
the same value for all other parameters. We recommend that you use a UUID type
of value..
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but
with different parameters, the retry fails with an
IdempotentParameterMismatch error.
Parameter name :
If specified, the new name that you want to attach to the resource share.
Implementation
Future<UpdateResourceShareResponse> updateResourceShare({
required String resourceShareArn,
bool? allowExternalPrincipals,
String? clientToken,
String? name,
}) async {
final $payload = <String, dynamic>{
'resourceShareArn': resourceShareArn,
if (allowExternalPrincipals != null)
'allowExternalPrincipals': allowExternalPrincipals,
if (clientToken != null) 'clientToken': clientToken,
if (name != null) 'name': name,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/updateresourceshare',
exceptionFnMap: _exceptionFns,
);
return UpdateResourceShareResponse.fromJson(response);
}