Rbin class
This is the Recycle Bin API Reference. This documentation provides descriptions and syntax for each of the actions and data types in Recycle Bin.
Recycle Bin is a resource recovery feature that enables you to restore accidentally deleted EBS volumes, EBS snapshots, and EBS-backed AMIs. When using Recycle Bin, if your resources are deleted, they are retained in the Recycle Bin for a time period that you specify.
You can restore a resource from the Recycle Bin at any time before its retention period expires. After you restore a resource from the Recycle Bin, the resource is removed from the Recycle Bin, and you can then use it in the same way you use any other resource of that type in your account. If the retention period expires and the resource is not restored, the resource is permanently deleted from the Recycle Bin and is no longer available for recovery. For more information about Recycle Bin, see Recycle Bin in the Amazon Elastic Compute Cloud User Guide.
Constructors
- Rbin({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createRule(
{required ResourceType resourceType, required RetentionPeriod retentionPeriod, String? description, List< ResourceTag> ? excludeResourceTags, LockConfiguration? lockConfiguration, List<ResourceTag> ? resourceTags, List<Tag> ? tags}) → Future<CreateRuleResponse> - Creates a Recycle Bin retention rule. You can create two types of retention rules:
-
deleteRule(
{required String identifier}) → Future< void> - Deletes a Recycle Bin retention rule. For more information, see Delete Recycle Bin retention rules in the Amazon Elastic Compute Cloud User Guide.
-
getRule(
{required String identifier}) → Future< GetRuleResponse> - Gets information about a Recycle Bin retention rule.
-
listRules(
{required ResourceType resourceType, List< ResourceTag> ? excludeResourceTags, LockState? lockState, int? maxResults, String? nextToken, List<ResourceTag> ? resourceTags}) → Future<ListRulesResponse> - Lists the Recycle Bin retention rules in the Region.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags assigned to a retention rule.
-
lockRule(
{required String identifier, required LockConfiguration lockConfiguration}) → Future< LockRuleResponse> - Locks a Region-level retention rule. A locked retention rule can't be modified or deleted.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required List< Tag> tags}) → Future<void> - Assigns tags to the specified retention rule.
-
toString(
) → String -
A string representation of this object.
inherited
-
unlockRule(
{required String identifier}) → Future< UnlockRuleResponse> - Unlocks a retention rule. After a retention rule is unlocked, it can be modified or deleted only after the unlock delay period expires.
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Unassigns a tag from a retention rule.
-
updateRule(
{required String identifier, String? description, List< ResourceTag> ? excludeResourceTags, List<ResourceTag> ? resourceTags, ResourceType? resourceType, RetentionPeriod? retentionPeriod}) → Future<UpdateRuleResponse> - Updates an existing Recycle Bin retention rule. You can update a retention rule's description, resource tags, and retention period at any time after creation. You can't update a retention rule's resource type after creation. For more information, see Update Recycle Bin retention rules in the Amazon Elastic Compute Cloud User Guide.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited