deleteRule method
Deletes a Recycle Bin retention rule. For more information, see Delete Recycle Bin retention rules in the Amazon Elastic Compute Cloud User Guide.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter identifier :
The unique ID of the retention rule.
Implementation
Future<void> deleteRule({
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/rules/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}