unlockRule method
Unlocks a retention rule. After a retention rule is unlocked, it can be modified or deleted only after the unlock delay period expires.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter identifier :
The unique ID of the retention rule.
Implementation
Future<UnlockRuleResponse> unlockRule({
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PATCH',
requestUri: '/rules/${Uri.encodeComponent(identifier)}/unlock',
exceptionFnMap: _exceptionFns,
);
return UnlockRuleResponse.fromJson(response);
}