addSourceIdentifierToSubscription method
Adds a source identifier to an existing RDS event notification subscription.
May throw SourceNotFoundFault.
May throw SubscriptionNotFoundFault.
Parameter sourceIdentifier :
The identifier of the event source to be added.
Constraints:
-
If the source type is a DB instance, a
DBInstanceIdentifiervalue must be supplied. -
If the source type is a DB cluster, a
DBClusterIdentifiervalue must be supplied. -
If the source type is a DB parameter group, a
DBParameterGroupNamevalue must be supplied. -
If the source type is a DB security group, a
DBSecurityGroupNamevalue must be supplied. -
If the source type is a DB snapshot, a
DBSnapshotIdentifiervalue must be supplied. -
If the source type is a DB cluster snapshot, a
DBClusterSnapshotIdentifiervalue must be supplied. -
If the source type is an RDS Proxy, a
DBProxyNamevalue must be supplied.
Parameter subscriptionName :
The name of the RDS event notification subscription you want to add a
source identifier to.
Implementation
Future<AddSourceIdentifierToSubscriptionResult>
addSourceIdentifierToSubscription({
required String sourceIdentifier,
required String subscriptionName,
}) async {
final $request = <String, String>{
'SourceIdentifier': sourceIdentifier,
'SubscriptionName': subscriptionName,
};
final $result = await _protocol.send(
$request,
action: 'AddSourceIdentifierToSubscription',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'AddSourceIdentifierToSubscriptionResult',
);
return AddSourceIdentifierToSubscriptionResult.fromXml($result);
}