describeDBShardGroups method
Describes existing Aurora Limitless Database DB shard groups.
May throw DBClusterNotFoundFault.
May throw DBShardGroupNotFoundFault.
Parameter dBShardGroupIdentifier :
The user-supplied DB shard group identifier. If this parameter is
specified, information for only the specific DB shard group is returned.
This parameter isn't case-sensitive.
Constraints:
- If supplied, must match an existing DB shard group identifier.
Parameter filters :
A filter that specifies one or more DB shard groups to describe.
Parameter marker :
An optional pagination token provided by a previous
DescribeDBShardGroups request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100
Implementation
Future<DescribeDBShardGroupsResponse> describeDBShardGroups({
String? dBShardGroupIdentifier,
List<Filter>? filters,
String? marker,
int? maxRecords,
}) async {
_s.validateNumRange(
'maxRecords',
maxRecords,
20,
100,
);
final $request = <String, String>{
if (dBShardGroupIdentifier != null)
'DBShardGroupIdentifier': dBShardGroupIdentifier,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeDBShardGroups',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeDBShardGroupsResult',
);
return DescribeDBShardGroupsResponse.fromXml($result);
}