describeGlobalClusters method
Returns information about Aurora global database clusters. This API supports pagination.
For more information on Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide.
May throw GlobalClusterNotFoundFault.
Parameter filters :
A filter that specifies one or more global database clusters to describe.
This parameter is case-sensitive.
Currently, the only supported filter is region.
If used, the request returns information about any global cluster with at least one member (primary or secondary) in the specified Amazon Web Services Regions.
Parameter globalClusterIdentifier :
The user-supplied DB cluster identifier. If this parameter is specified,
information from only the specific DB cluster is returned. This parameter
isn't case-sensitive.
Constraints:
- If supplied, must match an existing DBClusterIdentifier.
Parameter marker :
An optional pagination token provided by a previous
DescribeGlobalClusters request. If this parameter is
specified, the response includes only records beyond the marker, up to the
value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<GlobalClustersMessage> describeGlobalClusters({
List<Filter>? filters,
String? globalClusterIdentifier,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (globalClusterIdentifier != null)
'GlobalClusterIdentifier': globalClusterIdentifier,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeGlobalClusters',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeGlobalClustersResult',
);
return GlobalClustersMessage.fromXml($result);
}