describeIntegrations method
Describe one or more zero-ETL integrations with Amazon Redshift.
May throw IntegrationNotFoundFault.
Parameter filters :
A filter that specifies one or more resources to return.
Parameter integrationIdentifier :
The unique identifier of the integration.
Parameter marker :
An optional pagination token provided by a previous
DescribeIntegrations request. If this parameter is specified,
the response includes only records beyond the marker, up to the value
specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<DescribeIntegrationsResponse> describeIntegrations({
List<Filter>? filters,
String? integrationIdentifier,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (integrationIdentifier != null)
'IntegrationIdentifier': integrationIdentifier,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeIntegrations',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeIntegrationsResult',
);
return DescribeIntegrationsResponse.fromXml($result);
}