describeOptionGroupOptions method
Describes all available options for the specified engine.
Parameter engineName :
The name of the engine to describe options for.
Valid Values:
-
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
Parameter filters :
This parameter isn't currently supported.
Parameter majorEngineVersion :
If specified, filters the results to include only options for the
specified major engine version.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Implementation
Future<OptionGroupOptionsMessage> describeOptionGroupOptions({
required String engineName,
List<Filter>? filters,
String? majorEngineVersion,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
'EngineName': engineName,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (majorEngineVersion != null) 'MajorEngineVersion': majorEngineVersion,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeOptionGroupOptions',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeOptionGroupOptionsResult',
);
return OptionGroupOptionsMessage.fromXml($result);
}