describePendingMaintenanceActions method
Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.
This API follows an eventual consistency model. This means that the result
of the DescribePendingMaintenanceActions command might not be
immediately visible to all subsequent RDS commands. Keep this in mind when
you use DescribePendingMaintenanceActions immediately after
using a previous API command such as
ApplyPendingMaintenanceActions.
May throw ResourceNotFoundFault.
Parameter filters :
A filter that specifies one or more resources to return pending
maintenance actions for.
Supported filters:
-
db-cluster-id- Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list only includes pending maintenance actions for the DB clusters identified by these ARNs. -
db-instance-id- Accepts DB instance identifiers and DB instance ARNs. The results list only includes pending maintenance actions for the DB instances identified by these ARNs.
Parameter marker :
An optional pagination token provided by a previous
DescribePendingMaintenanceActions request. If this parameter
is specified, the response includes only records beyond the marker, up to
a number of records specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more records
exist than the specified MaxRecords value, a pagination token
called a marker is included in the response so that you can retrieve the
remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
Parameter resourceIdentifier :
The ARN of a resource to return pending maintenance actions for.
Implementation
Future<PendingMaintenanceActionsMessage> describePendingMaintenanceActions({
List<Filter>? filters,
String? marker,
int? maxRecords,
String? resourceIdentifier,
}) async {
final $request = <String, String>{
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (resourceIdentifier != null) 'ResourceIdentifier': resourceIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'DescribePendingMaintenanceActions',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribePendingMaintenanceActionsResult',
);
return PendingMaintenanceActionsMessage.fromXml($result);
}