describeServerlessV2PlatformVersions method
Describes the properties of specific platform versions for Aurora Serverless v2.
Parameter defaultOnly :
Specifies whether to return only the default platform versions for each
engine. The default platform version is the version used for new DB
clusters.
Parameter engine :
The database engine to return platform version details for.
Valid Values:
-
aurora-mysql -
aurora-postgresql
Parameter filters :
This parameter isn't currently supported.
Parameter includeAll :
Specifies whether to also include platform versions which are no longer in
use.
Parameter marker :
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by MaxRecords.
Parameter maxRecords :
The maximum number of records to include in the response. If more than the
MaxRecords value is available, a pagination token called a
marker is included in the response so you can retrieve the remaining
results.
Default: 20
Constraints: Minimum 1, maximum 200.
Parameter serverlessV2PlatformVersion :
A specific platform version to return details for.
Example: 3
Implementation
Future<ServerlessV2PlatformVersionsMessage>
describeServerlessV2PlatformVersions({
bool? defaultOnly,
String? engine,
List<Filter>? filters,
bool? includeAll,
String? marker,
int? maxRecords,
String? serverlessV2PlatformVersion,
}) async {
final $request = <String, String>{
if (defaultOnly != null) 'DefaultOnly': defaultOnly.toString(),
if (engine != null) 'Engine': engine,
if (filters != null)
if (filters.isEmpty)
'Filters': ''
else
for (var i1 = 0; i1 < filters.length; i1++)
for (var e3 in filters[i1].toQueryMap().entries)
'Filters.Filter.${i1 + 1}.${e3.key}': e3.value,
if (includeAll != null) 'IncludeAll': includeAll.toString(),
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (serverlessV2PlatformVersion != null)
'ServerlessV2PlatformVersion': serverlessV2PlatformVersion,
};
final $result = await _protocol.send(
$request,
action: 'DescribeServerlessV2PlatformVersions',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeServerlessV2PlatformVersionsResult',
);
return ServerlessV2PlatformVersionsMessage.fromXml($result);
}