modifyCustomDBEngineVersion method
Modifies the status of a custom engine version (CEV). You can find CEVs to
modify by calling DescribeDBEngineVersions.
For more information, see Modifying
CEV status in the Amazon RDS User Guide.
May throw CustomDBEngineVersionNotFoundFault.
May throw InvalidCustomDBEngineVersionStateFault.
Parameter engine :
The database engine.
RDS Custom for Oracle supports the following values:
-
custom-oracle-ee -
custom-oracle-ee-cdb -
custom-oracle-se2 -
custom-oracle-se2-cdb
-
custom-sqlserver-ee -
custom-sqlserver-se -
ccustom-sqlserver-web -
custom-sqlserver-dev
sqlserver-dev-ee.
Parameter engineVersion :
The custom engine version (CEV) that you want to modify. This option is
required for RDS Custom for Oracle, but optional for Amazon RDS. The
combination of Engine and EngineVersion is
unique per customer per Amazon Web Services Region.
Parameter description :
An optional description of your CEV.
Parameter status :
The availability status to be assigned to the CEV. Valid values are as
follows:
- available
- You can use this CEV to create a new RDS Custom DB instance.
- inactive
- You can create a new RDS Custom instance by restoring a DB snapshot with this CEV. You can't patch or create new instances with this CEV.
available to inactive, and from
inactive back to available. To change the
availability status of the CEV, it must not currently be in use by an RDS
Custom instance, snapshot, or automated backup.
Implementation
Future<DBEngineVersion> modifyCustomDBEngineVersion({
required String engine,
required String engineVersion,
String? description,
CustomEngineVersionStatus? status,
}) async {
final $request = <String, String>{
'Engine': engine,
'EngineVersion': engineVersion,
if (description != null) 'Description': description,
if (status != null) 'Status': status.value,
};
final $result = await _protocol.send(
$request,
action: 'ModifyCustomDBEngineVersion',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyCustomDBEngineVersionResult',
);
return DBEngineVersion.fromXml($result);
}