modifyDBProxyTargetGroup method
Modifies the properties of a DBProxyTargetGroup.
May throw DBProxyNotFoundFault.
May throw DBProxyTargetGroupNotFoundFault.
May throw InvalidDBProxyStateFault.
Parameter dBProxyName :
The name of the proxy.
Parameter targetGroupName :
The name of the target group to modify.
Parameter connectionPoolConfig :
The settings that determine the size and behavior of the connection pool
for the target group.
Parameter newName :
The new name for the modified DBProxyTarget. An identifier
must begin with a letter and must contain only ASCII letters, digits, and
hyphens; it can't end with a hyphen or contain two consecutive hyphens.
You can't rename the default target group.
Implementation
Future<ModifyDBProxyTargetGroupResponse> modifyDBProxyTargetGroup({
required String dBProxyName,
required String targetGroupName,
ConnectionPoolConfiguration? connectionPoolConfig,
String? newName,
}) async {
final $request = <String, String>{
'DBProxyName': dBProxyName,
'TargetGroupName': targetGroupName,
if (connectionPoolConfig != null)
for (var e1 in connectionPoolConfig.toQueryMap().entries)
'ConnectionPoolConfig.${e1.key}': e1.value,
if (newName != null) 'NewName': newName,
};
final $result = await _protocol.send(
$request,
action: 'ModifyDBProxyTargetGroup',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ModifyDBProxyTargetGroupResult',
);
return ModifyDBProxyTargetGroupResponse.fromXml($result);
}