restoreDBInstanceFromS3 method
- required String dBInstanceClass,
- required String dBInstanceIdentifier,
- required String engine,
- required String s3BucketName,
- required String s3IngestionRoleArn,
- required String sourceEngine,
- required String sourceEngineVersion,
- List<
AdditionalStorageVolume> ? additionalStorageVolumes, - int? allocatedStorage,
- bool? autoMinorVersionUpgrade,
- String? availabilityZone,
- int? backupRetentionPeriod,
- String? cACertificateIdentifier,
- bool? copyTagsToSnapshot,
- String? dBName,
- String? dBParameterGroupName,
- List<
String> ? dBSecurityGroups, - String? dBSubnetGroupName,
- DatabaseInsightsMode? databaseInsightsMode,
- bool? dedicatedLogVolume,
- bool? deletionProtection,
- List<
String> ? enableCloudwatchLogsExports, - bool? enableIAMDatabaseAuthentication,
- bool? enablePerformanceInsights,
- String? engineLifecycleSupport,
- String? engineVersion,
- int? iops,
- String? kmsKeyId,
- String? licenseModel,
- bool? manageMasterUserPassword,
- String? masterUserPassword,
- String? masterUserSecretKmsKeyId,
- String? masterUsername,
- int? maxAllocatedStorage,
- int? monitoringInterval,
- String? monitoringRoleArn,
- bool? multiAZ,
- String? networkType,
- String? optionGroupName,
- String? performanceInsightsKMSKeyId,
- int? performanceInsightsRetentionPeriod,
- int? port,
- String? preferredBackupWindow,
- String? preferredMaintenanceWindow,
- List<
ProcessorFeature> ? processorFeatures, - bool? publiclyAccessible,
- String? s3Prefix,
- bool? storageEncrypted,
- int? storageThroughput,
- String? storageType,
- List<
TagSpecification> ? tagSpecifications, - List<
Tag> ? tags, - bool? useDefaultProcessorFeatures,
- List<
String> ? vpcSecurityGroupIds,
Amazon Relational Database Service (Amazon RDS) supports importing MySQL databases by using backup files. You can create a backup of your on-premises database, store it on Amazon Simple Storage Service (Amazon S3), and then restore the backup file onto a new Amazon RDS DB instance running MySQL. For more information, see Restoring a backup into an Amazon RDS for MySQL DB instance in the Amazon RDS User Guide.
This operation doesn't apply to RDS Custom.
May throw AuthorizationNotFoundFault.
May throw BackupPolicyNotFoundFault.
May throw CertificateNotFoundFault.
May throw DBInstanceAlreadyExistsFault.
May throw DBParameterGroupNotFoundFault.
May throw DBSecurityGroupNotFoundFault.
May throw DBSubnetGroupDoesNotCoverEnoughAZs.
May throw DBSubnetGroupNotFoundFault.
May throw InstanceQuotaExceededFault.
May throw InsufficientDBInstanceCapacityFault.
May throw InvalidS3BucketFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw NetworkTypeNotSupported.
May throw OptionGroupNotFoundFault.
May throw ProvisionedIopsNotAvailableInAZFault.
May throw StorageQuotaExceededFault.
May throw StorageTypeNotSupportedFault.
May throw VpcEncryptionControlViolationException.
Parameter dBInstanceClass :
The compute and memory capacity of the DB instance, for example
db.m4.large. Not all DB instance classes are available in all Amazon Web
Services Regions, or for all database engines. For the full list of DB
instance classes, and availability for your engine, see DB
Instance Class in the Amazon RDS User Guide.
Importing from Amazon S3 isn't supported on the db.t2.micro DB instance class.
Parameter dBInstanceIdentifier :
The DB instance identifier. This parameter is stored as a lowercase
string.
Constraints:
- Must contain from 1 to 63 letters, numbers, or hyphens.
- First character must be a letter.
- Can't end with a hyphen or contain two consecutive hyphens.
mydbinstance
Parameter engine :
The name of the database engine to be used for this instance.
Valid Values: mysql
Parameter s3BucketName :
The name of your Amazon S3 bucket that contains your database backup file.
Parameter s3IngestionRoleArn :
An Amazon Web Services Identity and Access Management (IAM) role with a
trust policy and a permissions policy that allows Amazon RDS to access
your Amazon S3 bucket. For information about this role, see
Creating an IAM role manually in the Amazon RDS User Guide.
Parameter sourceEngine :
The name of the engine of your source database.
Valid Values: mysql
Parameter sourceEngineVersion :
The version of the database that the backup files were created from.
MySQL versions 5.6 and 5.7 are supported.
Example: 5.6.40
Parameter additionalStorageVolumes :
A list of additional storage volumes to modify or delete for the DB
instance. You can modify or delete up to three additional storage volumes
using the names rdsdbdata2, rdsdbdata3, and
rdsdbdata4. Additional storage volumes are supported for RDS
for Oracle and RDS for SQL Server DB instances only.
Parameter allocatedStorage :
The amount of storage (in gibibytes) to allocate initially for the DB
instance. Follow the allocation rules specified in
CreateDBInstance.
This setting isn't valid for RDS for SQL Server.
Parameter autoMinorVersionUpgrade :
Specifies whether to automatically apply minor engine upgrades to the DB
instance during the maintenance window. By default, minor engine upgrades
are not applied automatically.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
Parameter availabilityZone :
The Availability Zone that the DB instance is created in. For information
about Amazon Web Services Regions and Availability Zones, see Regions
and Availability Zones in the Amazon RDS User Guide.
Default: A random, system-chosen Availability Zone in the endpoint's Amazon Web Services Region.
Example: us-east-1d
Constraint: The AvailabilityZone parameter can't be specified
if the DB instance is a Multi-AZ deployment. The specified Availability
Zone must be in the same Amazon Web Services Region as the current
endpoint.
Parameter backupRetentionPeriod :
The number of days for which automated backups are retained. Setting this
parameter to a positive number enables backups. For more information, see
CreateDBInstance.
Parameter cACertificateIdentifier :
The CA certificate identifier to use for the DB instance's server
certificate.
This setting doesn't apply to RDS Custom DB instances.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
Parameter copyTagsToSnapshot :
Specifies whether to copy all tags from the DB instance to snapshots of
the DB instance. By default, tags are not copied.
Parameter dBName :
The name of the database to create when the DB instance is created. Follow
the naming rules specified in CreateDBInstance.
Parameter dBParameterGroupName :
The name of the DB parameter group to associate with this DB instance.
If you do not specify a value for DBParameterGroupName, then
the default DBParameterGroup for the specified DB engine is
used.
Parameter dBSecurityGroups :
A list of DB security groups to associate with this DB instance.
Default: The default DB security group for the database engine.
Parameter dBSubnetGroupName :
A DB subnet group to associate with this DB instance.
Constraints: If supplied, must match the name of an existing DBSubnetGroup.
Example: mydbsubnetgroup
Parameter databaseInsightsMode :
Specifies the mode of Database Insights to enable for the DB instance.
Parameter dedicatedLogVolume :
Specifies whether to enable a dedicated log volume (DLV) for the DB
instance.
Parameter deletionProtection :
Specifies whether to enable deletion protection for the DB instance. The
database can't be deleted when deletion protection is enabled. By default,
deletion protection isn't enabled. For more information, see
Deleting a DB Instance.
Parameter enableCloudwatchLogsExports :
The list of logs that the restored DB instance is to export to CloudWatch
Logs. The values in the list depend on the DB engine being used. For more
information, see Publishing
Database Logs to Amazon CloudWatch Logs in the Amazon RDS User
Guide.
Parameter enableIAMDatabaseAuthentication :
Specifies whether to enable mapping of Amazon Web Services Identity and
Access Management (IAM) accounts to database accounts. By default, mapping
isn't enabled.
For more information about IAM database authentication, see IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide.
Parameter enablePerformanceInsights :
Specifies whether to enable Performance Insights for the DB instance.
For more information, see Using Amazon Performance Insights in the Amazon RDS User Guide.
Parameter engineLifecycleSupport :
The life cycle type for this DB instance.
You can use this setting to enroll your DB instance into Amazon RDS
Extended Support. With RDS Extended Support, you can run the selected
major engine version on your DB instance past the end of standard support
for that engine version. For more information, see Amazon
RDS Extended Support Amazon RDS in the Amazon RDS User Guide.
This setting applies only to RDS for MySQL and RDS for PostgreSQL. For Amazon Aurora DB instances, the life cycle type is managed by the DB cluster.
Valid Values: open-source-rds-extended-support |
open-source-rds-extended-support-disabled
Default: open-source-rds-extended-support
Parameter engineVersion :
The version number of the database engine to use. Choose the latest minor
version of your database engine. For information about engine versions,
see CreateDBInstance, or call
DescribeDBEngineVersions.
Parameter iops :
The amount of Provisioned IOPS (input/output operations per second) to
allocate initially for the DB instance. For information about valid IOPS
values, see Amazon
RDS Provisioned IOPS storage in the Amazon RDS User Guide.
Parameter kmsKeyId :
The Amazon Web Services KMS key identifier for an encrypted DB instance.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If the StorageEncrypted parameter is enabled, and you do not
specify a value for the KmsKeyId parameter, then Amazon RDS
will use your default KMS key. There is a default KMS key for your Amazon
Web Services account. Your Amazon Web Services account has a different
default KMS key for each Amazon Web Services Region.
Parameter licenseModel :
The license model for this DB instance. Use
general-public-license.
Parameter manageMasterUserPassword :
Specifies whether to manage the master user password with Amazon Web
Services Secrets Manager.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide.
Constraints:
-
Can't manage the master user password with Amazon Web Services Secrets
Manager if
MasterUserPasswordis specified.
Parameter masterUserPassword :
The password for the master user.
Constraints:
-
Can't be specified if
ManageMasterUserPasswordis turned on. - Can include any printable ASCII character except "/", """, or "@". For RDS for Oracle, can't include the "&" (ampersand) or the "'" (single quotes) character.
- RDS for Db2 - Must contain from 8 to 128 characters.
- RDS for MariaDB - Must contain from 8 to 41 characters.
- RDS for Microsoft SQL Server - Must contain from 8 to 128 characters.
- RDS for MySQL - Must contain from 8 to 41 characters.
- RDS for Oracle - Must contain from 8 to 30 characters.
- RDS for PostgreSQL - Must contain from 8 to 128 characters.
Parameter masterUserSecretKmsKeyId :
The Amazon Web Services KMS key identifier to encrypt a secret that is
automatically generated and managed in Amazon Web Services Secrets
Manager.
This setting is valid only if the master user password is managed by RDS in Amazon Web Services Secrets Manager for the DB instance.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If you don't specify MasterUserSecretKmsKeyId, then the
aws/secretsmanager KMS key is used to encrypt the secret. If
the secret is in a different Amazon Web Services account, then you can't
use the aws/secretsmanager KMS key to encrypt the secret, and
you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Parameter masterUsername :
The name for the master user.
Constraints:
- Must be 1 to 16 letters or numbers.
- First character must be a letter.
- Can't be a reserved word for the chosen database engine.
Parameter maxAllocatedStorage :
The upper limit in gibibytes (GiB) to which Amazon RDS can automatically
scale the storage of the DB instance.
For more information about this setting, including limitations that apply to it, see Managing capacity automatically with Amazon RDS storage autoscaling in the Amazon RDS User Guide.
Parameter monitoringInterval :
The interval, in seconds, between points when Enhanced Monitoring metrics
are collected for the DB instance. To disable collecting Enhanced
Monitoring metrics, specify 0.
If MonitoringRoleArn is specified, then you must also set
MonitoringInterval to a value other than 0.
Valid Values: 0, 1, 5, 10, 15, 30, 60
Default: 0
Parameter monitoringRoleArn :
The ARN for the IAM role that permits RDS to send enhanced monitoring
metrics to Amazon CloudWatch Logs. For example,
arn:aws:iam:123456789012:role/emaccess. For information on
creating a monitoring role, see Setting
Up and Enabling Enhanced Monitoring in the Amazon RDS User
Guide.
If MonitoringInterval is set to a value other than 0, then
you must supply a MonitoringRoleArn value.
Parameter multiAZ :
Specifies whether the DB instance is a Multi-AZ deployment. If the DB
instance is a Multi-AZ deployment, you can't set the
AvailabilityZone parameter.
Parameter networkType :
The network type of the DB instance.
Valid Values:
-
IPV4 -
DUAL
DBSubnetGroup specified
for the DB instance. A DBSubnetGroup can support only the
IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon RDS User Guide.
Parameter optionGroupName :
The name of the option group to associate with this DB instance. If this
argument is omitted, the default option group for the specified engine is
used.
Parameter performanceInsightsKMSKeyId :
The Amazon Web Services KMS key identifier for encryption of Performance
Insights data.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
If you do not specify a value for
PerformanceInsightsKMSKeyId, then Amazon RDS uses your
default KMS key. There is a default KMS key for your Amazon Web Services
account. Your Amazon Web Services account has a different default KMS key
for each Amazon Web Services Region.
Parameter performanceInsightsRetentionPeriod :
The number of days to retain Performance Insights data. The default is 7
days. The following values are valid:
- 7
- month * 31, where month is a number of months from 1-23
- 731
- 93 (3 months * 31)
- 341 (11 months * 31)
- 589 (19 months * 31)
- 731
Parameter port :
The port number on which the database accepts connections.
Type: Integer
Valid Values: 1150-65535
Default: 3306
Parameter preferredBackupWindow :
The time range each day during which automated backups are created if
automated backups are enabled. For more information, see Backup
window in the Amazon RDS User Guide.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
Parameter preferredMaintenanceWindow :
The time range each week during which system maintenance can occur, in
Universal Coordinated Time (UTC). For more information, see Amazon
RDS Maintenance Window in the Amazon RDS User Guide.
Constraints:
-
Must be in the format
ddd:hh24:mi-ddd:hh24:mi. - Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun.
- Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred backup window.
- Must be at least 30 minutes.
Parameter processorFeatures :
The number of CPU cores and the number of threads per core for the DB
instance class of the DB instance.
Parameter publiclyAccessible :
Specifies whether the DB instance is publicly accessible.
When the DB instance is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB instance's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB instance's VPC. Access to the DB instance is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB instance doesn't permit it.
When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address.
For more information, see CreateDBInstance.
Parameter s3Prefix :
The prefix of your Amazon S3 bucket.
Parameter storageEncrypted :
Specifies whether the new DB instance is encrypted or not.
Parameter storageThroughput :
Specifies the storage throughput value for the DB instance.
This setting doesn't apply to RDS Custom or Amazon Aurora.
Parameter storageType :
Specifies the storage type to be associated with the DB instance.
Valid Values: gp2 | gp3 | io1 | io2 | standard
If you specify io1, io2, or gp3,
you must also include a value for the Iops parameter.
Default: io1 if the Iops parameter is specified;
otherwise gp2
Parameter tagSpecifications :
Tags to assign to resources associated with the DB instance.
Valid Values:
-
auto-backup- The DB instance's automated backup.
Parameter tags :
A list of tags to associate with this DB instance. For more information,
see Tagging
Amazon RDS Resources in the Amazon RDS User Guide.
Parameter useDefaultProcessorFeatures :
Specifies whether the DB instance class of the DB instance uses its
default processor features.
Parameter vpcSecurityGroupIds :
A list of VPC security groups to associate with this DB instance.
Implementation
Future<RestoreDBInstanceFromS3Result> restoreDBInstanceFromS3({
required String dBInstanceClass,
required String dBInstanceIdentifier,
required String engine,
required String s3BucketName,
required String s3IngestionRoleArn,
required String sourceEngine,
required String sourceEngineVersion,
List<AdditionalStorageVolume>? additionalStorageVolumes,
int? allocatedStorage,
bool? autoMinorVersionUpgrade,
String? availabilityZone,
int? backupRetentionPeriod,
String? cACertificateIdentifier,
bool? copyTagsToSnapshot,
String? dBName,
String? dBParameterGroupName,
List<String>? dBSecurityGroups,
String? dBSubnetGroupName,
DatabaseInsightsMode? databaseInsightsMode,
bool? dedicatedLogVolume,
bool? deletionProtection,
List<String>? enableCloudwatchLogsExports,
bool? enableIAMDatabaseAuthentication,
bool? enablePerformanceInsights,
String? engineLifecycleSupport,
String? engineVersion,
int? iops,
String? kmsKeyId,
String? licenseModel,
bool? manageMasterUserPassword,
String? masterUserPassword,
String? masterUserSecretKmsKeyId,
String? masterUsername,
int? maxAllocatedStorage,
int? monitoringInterval,
String? monitoringRoleArn,
bool? multiAZ,
String? networkType,
String? optionGroupName,
String? performanceInsightsKMSKeyId,
int? performanceInsightsRetentionPeriod,
int? port,
String? preferredBackupWindow,
String? preferredMaintenanceWindow,
List<ProcessorFeature>? processorFeatures,
bool? publiclyAccessible,
String? s3Prefix,
bool? storageEncrypted,
int? storageThroughput,
String? storageType,
List<TagSpecification>? tagSpecifications,
List<Tag>? tags,
bool? useDefaultProcessorFeatures,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'DBInstanceClass': dBInstanceClass,
'DBInstanceIdentifier': dBInstanceIdentifier,
'Engine': engine,
'S3BucketName': s3BucketName,
'S3IngestionRoleArn': s3IngestionRoleArn,
'SourceEngine': sourceEngine,
'SourceEngineVersion': sourceEngineVersion,
if (additionalStorageVolumes != null)
if (additionalStorageVolumes.isEmpty)
'AdditionalStorageVolumes': ''
else
for (var i1 = 0; i1 < additionalStorageVolumes.length; i1++)
for (var e3 in additionalStorageVolumes[i1].toQueryMap().entries)
'AdditionalStorageVolumes.member.${i1 + 1}.${e3.key}': e3.value,
if (allocatedStorage != null)
'AllocatedStorage': allocatedStorage.toString(),
if (autoMinorVersionUpgrade != null)
'AutoMinorVersionUpgrade': autoMinorVersionUpgrade.toString(),
if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
if (backupRetentionPeriod != null)
'BackupRetentionPeriod': backupRetentionPeriod.toString(),
if (cACertificateIdentifier != null)
'CACertificateIdentifier': cACertificateIdentifier,
if (copyTagsToSnapshot != null)
'CopyTagsToSnapshot': copyTagsToSnapshot.toString(),
if (dBName != null) 'DBName': dBName,
if (dBParameterGroupName != null)
'DBParameterGroupName': dBParameterGroupName,
if (dBSecurityGroups != null)
if (dBSecurityGroups.isEmpty)
'DBSecurityGroups': ''
else
for (var i1 = 0; i1 < dBSecurityGroups.length; i1++)
'DBSecurityGroups.DBSecurityGroupName.${i1 + 1}':
dBSecurityGroups[i1],
if (dBSubnetGroupName != null) 'DBSubnetGroupName': dBSubnetGroupName,
if (databaseInsightsMode != null)
'DatabaseInsightsMode': databaseInsightsMode.value,
if (dedicatedLogVolume != null)
'DedicatedLogVolume': dedicatedLogVolume.toString(),
if (deletionProtection != null)
'DeletionProtection': deletionProtection.toString(),
if (enableCloudwatchLogsExports != null)
if (enableCloudwatchLogsExports.isEmpty)
'EnableCloudwatchLogsExports': ''
else
for (var i1 = 0; i1 < enableCloudwatchLogsExports.length; i1++)
'EnableCloudwatchLogsExports.member.${i1 + 1}':
enableCloudwatchLogsExports[i1],
if (enableIAMDatabaseAuthentication != null)
'EnableIAMDatabaseAuthentication':
enableIAMDatabaseAuthentication.toString(),
if (enablePerformanceInsights != null)
'EnablePerformanceInsights': enablePerformanceInsights.toString(),
if (engineLifecycleSupport != null)
'EngineLifecycleSupport': engineLifecycleSupport,
if (engineVersion != null) 'EngineVersion': engineVersion,
if (iops != null) 'Iops': iops.toString(),
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (licenseModel != null) 'LicenseModel': licenseModel,
if (manageMasterUserPassword != null)
'ManageMasterUserPassword': manageMasterUserPassword.toString(),
if (masterUserPassword != null) 'MasterUserPassword': masterUserPassword,
if (masterUserSecretKmsKeyId != null)
'MasterUserSecretKmsKeyId': masterUserSecretKmsKeyId,
if (masterUsername != null) 'MasterUsername': masterUsername,
if (maxAllocatedStorage != null)
'MaxAllocatedStorage': maxAllocatedStorage.toString(),
if (monitoringInterval != null)
'MonitoringInterval': monitoringInterval.toString(),
if (monitoringRoleArn != null) 'MonitoringRoleArn': monitoringRoleArn,
if (multiAZ != null) 'MultiAZ': multiAZ.toString(),
if (networkType != null) 'NetworkType': networkType,
if (optionGroupName != null) 'OptionGroupName': optionGroupName,
if (performanceInsightsKMSKeyId != null)
'PerformanceInsightsKMSKeyId': performanceInsightsKMSKeyId,
if (performanceInsightsRetentionPeriod != null)
'PerformanceInsightsRetentionPeriod':
performanceInsightsRetentionPeriod.toString(),
if (port != null) 'Port': port.toString(),
if (preferredBackupWindow != null)
'PreferredBackupWindow': preferredBackupWindow,
if (preferredMaintenanceWindow != null)
'PreferredMaintenanceWindow': preferredMaintenanceWindow,
if (processorFeatures != null)
if (processorFeatures.isEmpty)
'ProcessorFeatures': ''
else
for (var i1 = 0; i1 < processorFeatures.length; i1++)
for (var e3 in processorFeatures[i1].toQueryMap().entries)
'ProcessorFeatures.ProcessorFeature.${i1 + 1}.${e3.key}':
e3.value,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible.toString(),
if (s3Prefix != null) 'S3Prefix': s3Prefix,
if (storageEncrypted != null)
'StorageEncrypted': storageEncrypted.toString(),
if (storageThroughput != null)
'StorageThroughput': storageThroughput.toString(),
if (storageType != null) 'StorageType': storageType,
if (tagSpecifications != null)
if (tagSpecifications.isEmpty)
'TagSpecifications': ''
else
for (var i1 = 0; i1 < tagSpecifications.length; i1++)
for (var e3 in tagSpecifications[i1].toQueryMap().entries)
'TagSpecifications.item.${i1 + 1}.${e3.key}': e3.value,
if (tags != null)
if (tags.isEmpty)
'Tags': ''
else
for (var i1 = 0; i1 < tags.length; i1++)
for (var e3 in tags[i1].toQueryMap().entries)
'Tags.Tag.${i1 + 1}.${e3.key}': e3.value,
if (useDefaultProcessorFeatures != null)
'UseDefaultProcessorFeatures': useDefaultProcessorFeatures.toString(),
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreDBInstanceFromS3',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreDBInstanceFromS3Result',
);
return RestoreDBInstanceFromS3Result.fromXml($result);
}