startDBCluster method
Starts an Amazon Aurora DB cluster that was stopped using the Amazon Web
Services console, the stop-db-cluster CLI command, or the
StopDBCluster operation.
For more information, see Stopping and Starting an Aurora Cluster in the Amazon Aurora User Guide.
May throw DBClusterNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidDBShardGroupStateFault.
May throw KMSKeyNotAccessibleFault.
May throw VpcEncryptionControlViolationException.
Parameter dBClusterIdentifier :
The DB cluster identifier of the Amazon Aurora DB cluster to be started.
This parameter is stored as a lowercase string.
Implementation
Future<StartDBClusterResult> startDBCluster({
required String dBClusterIdentifier,
}) async {
final $request = <String, String>{
'DBClusterIdentifier': dBClusterIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'StartDBCluster',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'StartDBClusterResult',
);
return StartDBClusterResult.fromXml($result);
}