startDBInstance method
Starts an Amazon RDS DB instance that was stopped using the Amazon Web
Services console, the stop-db-instance CLI command, or the
StopDBInstance operation.
For more information, see Starting an Amazon RDS DB instance That Was Previously Stopped in the Amazon RDS User Guide.
May throw AuthorizationNotFoundFault.
May throw DBClusterNotFoundFault.
May throw DBInstanceNotFoundFault.
May throw DBSubnetGroupDoesNotCoverEnoughAZs.
May throw DBSubnetGroupNotFoundFault.
May throw InsufficientDBInstanceCapacityFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw InvalidSubnet.
May throw InvalidVPCNetworkStateFault.
May throw KMSKeyNotAccessibleFault.
May throw VpcEncryptionControlViolationException.
Parameter dBInstanceIdentifier :
The user-supplied instance identifier.
Implementation
Future<StartDBInstanceResult> startDBInstance({
required String dBInstanceIdentifier,
}) async {
final $request = <String, String>{
'DBInstanceIdentifier': dBInstanceIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'StartDBInstance',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'StartDBInstanceResult',
);
return StartDBInstanceResult.fromXml($result);
}