stopActivityStream method
Stops a database activity stream that was started using the Amazon Web
Services console, the start-activity-stream CLI command, or
the StartActivityStream operation.
For more information, see Monitoring Amazon Aurora with Database Activity Streams in the Amazon Aurora User Guide or Monitoring Amazon RDS with Database Activity Streams in the Amazon RDS User Guide.
May throw DBClusterNotFoundFault.
May throw DBInstanceNotFoundFault.
May throw InvalidDBClusterStateFault.
May throw InvalidDBInstanceStateFault.
May throw ResourceNotFoundFault.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the DB cluster for the database activity
stream. For example,
arn:aws:rds:us-east-1:12345667890:cluster:das-cluster.
Parameter applyImmediately :
Specifies whether or not the database activity stream is to stop as soon
as possible, regardless of the maintenance window for the database.
Implementation
Future<StopActivityStreamResponse> stopActivityStream({
required String resourceArn,
bool? applyImmediately,
}) async {
final $request = <String, String>{
'ResourceArn': resourceArn,
if (applyImmediately != null)
'ApplyImmediately': applyImmediately.toString(),
};
final $result = await _protocol.send(
$request,
action: 'StopActivityStream',
version: '2014-10-31',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'StopActivityStreamResult',
);
return StopActivityStreamResponse.fromXml($result);
}