commitTransaction method
Ends a SQL transaction started with the BeginTransaction
operation and commits the changes.
May throw AccessDeniedException.
May throw BadRequestException.
May throw DatabaseErrorException.
May throw DatabaseNotFoundException.
May throw DatabaseUnavailableException.
May throw ForbiddenException.
May throw HttpEndpointNotEnabledException.
May throw InternalServerErrorException.
May throw InvalidResourceStateException.
May throw InvalidSecretException.
May throw NotFoundException.
May throw SecretsErrorException.
May throw ServiceUnavailableError.
May throw StatementTimeoutException.
May throw TransactionNotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
Parameter secretArn :
The name or ARN of the secret that enables access to the DB cluster.
Parameter transactionId :
The identifier of the transaction to end and commit.
Implementation
Future<CommitTransactionResponse> commitTransaction({
required String resourceArn,
required String secretArn,
required String transactionId,
}) async {
final $payload = <String, dynamic>{
'resourceArn': resourceArn,
'secretArn': secretArn,
'transactionId': transactionId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/CommitTransaction',
exceptionFnMap: _exceptionFns,
);
return CommitTransactionResponse.fromJson(response);
}