createAuthenticationProfile method
Creates an authentication profile with the specified parameters.
May throw AuthenticationProfileAlreadyExistsFault.
May throw AuthenticationProfileQuotaExceededFault.
May throw InvalidAuthenticationProfileRequestFault.
Parameter authenticationProfileContent :
The content of the authentication profile in JSON format. The maximum
length of the JSON string is determined by a quota for your account.
Parameter authenticationProfileName :
The name of the authentication profile to be created.
Implementation
Future<CreateAuthenticationProfileResult> createAuthenticationProfile({
required String authenticationProfileContent,
required String authenticationProfileName,
}) async {
final $request = <String, String>{
'AuthenticationProfileContent': authenticationProfileContent,
'AuthenticationProfileName': authenticationProfileName,
};
final $result = await _protocol.send(
$request,
action: 'CreateAuthenticationProfile',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'CreateAuthenticationProfileResult',
);
return CreateAuthenticationProfileResult.fromXml($result);
}