deleteClusterParameterGroup method
Deletes a specified Amazon Redshift parameter group.
May throw ClusterParameterGroupNotFoundFault.
May throw InvalidClusterParameterGroupStateFault.
Parameter parameterGroupName :
The name of the parameter group to be deleted.
Constraints:
- Must be the name of an existing cluster parameter group.
- Cannot delete a default cluster parameter group.
Implementation
Future<void> deleteClusterParameterGroup({
required String parameterGroupName,
}) async {
final $request = <String, String>{
'ParameterGroupName': parameterGroupName,
};
await _protocol.send(
$request,
action: 'DeleteClusterParameterGroup',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
);
}