deletePartner method

Future<PartnerIntegrationOutputMessage> deletePartner({
  1. required String accountId,
  2. required String clusterIdentifier,
  3. required String databaseName,
  4. required String partnerName,
})

Deletes a partner integration from a cluster. Data can still flow to the cluster until the integration is deleted at the partner's website.

May throw ClusterNotFoundFault. May throw PartnerNotFoundFault. May throw UnauthorizedPartnerIntegrationFault. May throw UnsupportedOperationFault.

Parameter accountId : The Amazon Web Services account ID that owns the cluster.

Parameter clusterIdentifier : The cluster identifier of the cluster that receives data from the partner.

Parameter databaseName : The name of the database that receives data from the partner.

Parameter partnerName : The name of the partner that is authorized to send data.

Implementation

Future<PartnerIntegrationOutputMessage> deletePartner({
  required String accountId,
  required String clusterIdentifier,
  required String databaseName,
  required String partnerName,
}) async {
  final $request = <String, String>{
    'AccountId': accountId,
    'ClusterIdentifier': clusterIdentifier,
    'DatabaseName': databaseName,
    'PartnerName': partnerName,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DeletePartner',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DeletePartnerResult',
  );
  return PartnerIntegrationOutputMessage.fromXml($result);
}