describeCustomDomainAssociations method
Contains information about custom domain associations for a cluster.
May throw CustomDomainAssociationNotFoundFault.
May throw UnsupportedOperationFault.
Parameter customDomainCertificateArn :
The certificate Amazon Resource Name (ARN) for the custom domain
association.
Parameter customDomainName :
The custom domain name for the custom domain association.
Parameter marker :
The marker for the custom domain association.
Parameter maxRecords :
The maximum records setting for the associated custom domain.
Implementation
Future<CustomDomainAssociationsMessage> describeCustomDomainAssociations({
String? customDomainCertificateArn,
String? customDomainName,
String? marker,
int? maxRecords,
}) async {
final $request = <String, String>{
if (customDomainCertificateArn != null)
'CustomDomainCertificateArn': customDomainCertificateArn,
if (customDomainName != null) 'CustomDomainName': customDomainName,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DescribeCustomDomainAssociations',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DescribeCustomDomainAssociationsResult',
);
return CustomDomainAssociationsMessage.fromXml($result);
}