describeEndpointAccess method

Future<EndpointAccessList> describeEndpointAccess({
  1. String? clusterIdentifier,
  2. String? endpointName,
  3. String? marker,
  4. int? maxRecords,
  5. String? resourceOwner,
  6. String? vpcId,
})

Describes a Redshift-managed VPC endpoint.

May throw ClusterNotFoundFault. May throw EndpointNotFoundFault. May throw InvalidClusterStateFault.

Parameter clusterIdentifier : The cluster identifier associated with the described endpoint.

Parameter endpointName : The name of the endpoint to be described.

Parameter marker : An optional pagination token provided by a previous DescribeEndpointAccess request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter.

Parameter maxRecords : The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a Marker is included in the response so that the remaining results can be retrieved.

Parameter resourceOwner : The Amazon Web Services account ID of the owner of the cluster.

Parameter vpcId : The virtual private cloud (VPC) identifier with access to the cluster.

Implementation

Future<EndpointAccessList> describeEndpointAccess({
  String? clusterIdentifier,
  String? endpointName,
  String? marker,
  int? maxRecords,
  String? resourceOwner,
  String? vpcId,
}) async {
  final $request = <String, String>{
    if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
    if (endpointName != null) 'EndpointName': endpointName,
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (resourceOwner != null) 'ResourceOwner': resourceOwner,
    if (vpcId != null) 'VpcId': vpcId,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeEndpointAccess',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeEndpointAccessResult',
  );
  return EndpointAccessList.fromXml($result);
}