describeRedshiftIdcApplications method

Future<DescribeRedshiftIdcApplicationsResult> describeRedshiftIdcApplications({
  1. String? marker,
  2. int? maxRecords,
  3. String? redshiftIdcApplicationArn,
})

Lists the Amazon Redshift IAM Identity Center applications.

May throw DependentServiceAccessDeniedFault. May throw DependentServiceUnavailableFault. May throw RedshiftIdcApplicationNotExistsFault. May throw UnsupportedOperationFault.

Parameter marker : A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Parameter maxRecords : The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Parameter redshiftIdcApplicationArn : The ARN for the Redshift application that integrates with IAM Identity Center.

Implementation

Future<DescribeRedshiftIdcApplicationsResult>
    describeRedshiftIdcApplications({
  String? marker,
  int? maxRecords,
  String? redshiftIdcApplicationArn,
}) async {
  final $request = <String, String>{
    if (marker != null) 'Marker': marker,
    if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
    if (redshiftIdcApplicationArn != null)
      'RedshiftIdcApplicationArn': redshiftIdcApplicationArn,
  };
  final $result = await _protocol.send(
    $request,
    action: 'DescribeRedshiftIdcApplications',
    version: '2012-12-01',
    method: 'POST',
    requestUri: '/',
    exceptionFnMap: _exceptionFns,
    resultWrapper: 'DescribeRedshiftIdcApplicationsResult',
  );
  return DescribeRedshiftIdcApplicationsResult.fromXml($result);
}