disassociateDataShareConsumer method
From a datashare consumer account, remove association for the specified datashare.
May throw InvalidDataShareFault.
May throw InvalidNamespaceFault.
Parameter dataShareArn :
The Amazon Resource Name (ARN) of the datashare to remove association for.
Parameter consumerArn :
The Amazon Resource Name (ARN) of the consumer namespace that association
for the datashare is removed from.
Parameter consumerRegion :
From a datashare consumer account, removes association of a datashare from
all the existing and future namespaces in the specified Amazon Web
Services Region.
Parameter disassociateEntireAccount :
A value that specifies whether association for the datashare is removed
from the entire account.
Implementation
Future<DataShare> disassociateDataShareConsumer({
required String dataShareArn,
String? consumerArn,
String? consumerRegion,
bool? disassociateEntireAccount,
}) async {
final $request = <String, String>{
'DataShareArn': dataShareArn,
if (consumerArn != null) 'ConsumerArn': consumerArn,
if (consumerRegion != null) 'ConsumerRegion': consumerRegion,
if (disassociateEntireAccount != null)
'DisassociateEntireAccount': disassociateEntireAccount.toString(),
};
final $result = await _protocol.send(
$request,
action: 'DisassociateDataShareConsumer',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'DisassociateDataShareConsumerResult',
);
return DataShare.fromXml($result);
}