getReservedNodeExchangeConfigurationOptions method
Gets the configuration options for the reserved-node exchange. These options include information about the source reserved node and target reserved node offering. Details include the node type, the price, the node count, and the offering type.
May throw ClusterNotFoundFault.
May throw ClusterSnapshotNotFoundFault.
May throw DependentServiceUnavailableFault.
May throw InvalidReservedNodeStateFault.
May throw ReservedNodeAlreadyMigratedFault.
May throw ReservedNodeNotFoundFault.
May throw ReservedNodeOfferingNotFoundFault.
May throw UnsupportedOperationFault.
Parameter actionType :
The action type of the reserved-node configuration. The action type can be
an exchange initiated from either a snapshot or a resize.
Parameter clusterIdentifier :
The identifier for the cluster that is the source for a reserved-node
exchange.
Parameter marker :
An optional pagination token provided by a previous
GetReservedNodeExchangeConfigurationOptions request. If this
parameter is specified, the response includes only records beyond the
marker, up to the value specified by the MaxRecords
parameter. You can retrieve the next set of response records by providing
the returned marker value in the Marker parameter and
retrying the request.
Parameter maxRecords :
The maximum number of response records to return in each call. If the
number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a
Marker field of the response. You can retrieve the next set
of records by retrying the command with the returned marker value.
Parameter snapshotIdentifier :
The identifier for the snapshot that is the source for the reserved-node
exchange.
Implementation
Future<GetReservedNodeExchangeConfigurationOptionsOutputMessage>
getReservedNodeExchangeConfigurationOptions({
required ReservedNodeExchangeActionType actionType,
String? clusterIdentifier,
String? marker,
int? maxRecords,
String? snapshotIdentifier,
}) async {
final $request = <String, String>{
'ActionType': actionType.value,
if (clusterIdentifier != null) 'ClusterIdentifier': clusterIdentifier,
if (marker != null) 'Marker': marker,
if (maxRecords != null) 'MaxRecords': maxRecords.toString(),
if (snapshotIdentifier != null) 'SnapshotIdentifier': snapshotIdentifier,
};
final $result = await _protocol.send(
$request,
action: 'GetReservedNodeExchangeConfigurationOptions',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'GetReservedNodeExchangeConfigurationOptionsResult',
);
return GetReservedNodeExchangeConfigurationOptionsOutputMessage.fromXml(
$result);
}