restoreFromClusterSnapshot method
- required String clusterIdentifier,
- String? additionalInfo,
- bool? allowVersionUpgrade,
- AquaConfigurationStatus? aquaConfigurationStatus,
- int? automatedSnapshotRetentionPeriod,
- String? availabilityZone,
- bool? availabilityZoneRelocation,
- String? catalogName,
- String? clusterParameterGroupName,
- List<
String> ? clusterSecurityGroups, - String? clusterSubnetGroupName,
- String? defaultIamRoleArn,
- String? elasticIp,
- bool? encrypted,
- bool? enhancedVpcRouting,
- String? hsmClientCertificateIdentifier,
- String? hsmConfigurationIdentifier,
- List<
String> ? iamRoles, - String? ipAddressType,
- String? kmsKeyId,
- String? maintenanceTrackName,
- bool? manageMasterPassword,
- int? manualSnapshotRetentionPeriod,
- String? masterPasswordSecretKmsKeyId,
- bool? multiAZ,
- String? nodeType,
- int? numberOfNodes,
- String? ownerAccount,
- int? port,
- String? preferredMaintenanceWindow,
- bool? publiclyAccessible,
- String? redshiftIdcApplicationArn,
- String? reservedNodeId,
- String? snapshotArn,
- String? snapshotClusterIdentifier,
- String? snapshotIdentifier,
- String? snapshotScheduleIdentifier,
- String? targetReservedNodeOfferingId,
- List<
String> ? vpcSecurityGroupIds,
Creates a new cluster from a snapshot. By default, Amazon Redshift creates the resulting cluster with the same configuration as the original cluster from which the snapshot was created, except that the new cluster is created with the default cluster security and parameter groups. After Amazon Redshift creates the cluster, you can use the ModifyCluster API to associate a different security group and different parameter group with the restored cluster. If you are using a DS node type, you can also choose to change to another DS node type of the same size during restore.
If you restore a cluster into a VPC, you must provide a cluster subnet group where you want the cluster restored.
VPC Block Public Access (BPA) enables you to block resources in VPCs and subnets that you own in a Region from reaching or being reached from the internet through internet gateways and egress-only internet gateways. If a subnet group for a provisioned cluster is in an account with VPC BPA turned on, the following capabilities are blocked:
- Creating a public cluster
- Restoring a public cluster
- Modifying a private cluster to be public
- Adding a subnet with VPC BPA turned on to the subnet group when there's at least one public cluster within the group
For more information about working with snapshots, go to Amazon Redshift Snapshots in the Amazon Redshift Cluster Management Guide.
May throw AccessToSnapshotDeniedFault.
May throw ClusterAlreadyExistsFault.
May throw ClusterParameterGroupNotFoundFault.
May throw ClusterQuotaExceededFault.
May throw ClusterSecurityGroupNotFoundFault.
May throw ClusterSnapshotNotFoundFault.
May throw ClusterSubnetGroupNotFoundFault.
May throw DependentServiceAccessDeniedFault.
May throw DependentServiceRequestThrottlingFault.
May throw DependentServiceUnavailableFault.
May throw HsmClientCertificateNotFoundFault.
May throw HsmConfigurationNotFoundFault.
May throw InsufficientClusterCapacityFault.
May throw InvalidClusterSnapshotStateFault.
May throw InvalidClusterSubnetGroupStateFault.
May throw InvalidClusterTrackFault.
May throw InvalidElasticIpFault.
May throw InvalidReservedNodeStateFault.
May throw InvalidRestoreFault.
May throw InvalidSubnet.
May throw InvalidTagFault.
May throw InvalidVPCNetworkStateFault.
May throw Ipv6CidrBlockNotFoundFault.
May throw LimitExceededFault.
May throw NumberOfNodesPerClusterLimitExceededFault.
May throw NumberOfNodesQuotaExceededFault.
May throw RedshiftIdcApplicationNotExistsFault.
May throw ReservedNodeAlreadyExistsFault.
May throw ReservedNodeAlreadyMigratedFault.
May throw ReservedNodeNotFoundFault.
May throw ReservedNodeOfferingNotFoundFault.
May throw SnapshotScheduleNotFoundFault.
May throw TagLimitExceededFault.
May throw UnauthorizedOperation.
May throw UnsupportedOperationFault.
Parameter clusterIdentifier :
The identifier of the cluster that will be created from restoring the
snapshot.
Constraints:
- Must contain from 1 to 63 alphanumeric characters or hyphens.
- Alphabetic characters must be lowercase.
- First character must be a letter.
- Cannot end with a hyphen or contain two consecutive hyphens.
- Must be unique for all clusters within an Amazon Web Services account.
Parameter additionalInfo :
Reserved.
Parameter allowVersionUpgrade :
If true, major version upgrades can be applied during the
maintenance window to the Amazon Redshift engine that is running on the
cluster.
Default: true
Parameter aquaConfigurationStatus :
This parameter is retired. It does not set the AQUA configuration status.
Amazon Redshift automatically determines whether to use AQUA (Advanced
Query Accelerator).
Parameter automatedSnapshotRetentionPeriod :
The number of days that automated snapshots are retained. If the value is
0, automated snapshots are disabled. Even if automated snapshots are
disabled, you can still create manual snapshots when you want with
CreateClusterSnapshot.
You can't disable automated snapshots for RG or RA3 node types. Set the automated retention period from 1-35 days.
Default: The value selected for the cluster from which the snapshot was taken.
Constraints: Must be a value from 0 to 35.
Parameter availabilityZone :
The Amazon EC2 Availability Zone in which to restore the cluster.
Default: A random, system-chosen Availability Zone.
Example: us-east-2a
Parameter availabilityZoneRelocation :
The option to enable relocation for an Amazon Redshift cluster between
Availability Zones after the cluster is restored.
Parameter catalogName :
The name of the Glue Data Catalog that will be associated with the cluster
enabled with Amazon Redshift federated permissions.
Constraints:
- Must contain at least one lowercase letter.
- Can only contain lowercase letters (a-z), numbers (0-9), underscores (_), and hyphens (-).
^\[a-z0-9_-\]*\[a-z\]+\[a-z0-9_-\]*$
Example: my-catalog_01
Parameter clusterParameterGroupName :
The name of the parameter group to be associated with this cluster.
Default: The default Amazon Redshift cluster parameter group. For information about the default parameter group, go to Working with Amazon Redshift Parameter Groups.
Constraints:
- Must be 1 to 255 alphanumeric characters or hyphens.
- First character must be a letter.
- Cannot end with a hyphen or contain two consecutive hyphens.
Parameter clusterSecurityGroups :
A list of security groups to be associated with this cluster.
Default: The default cluster security group for Amazon Redshift.
Cluster security groups only apply to clusters outside of VPCs.
Parameter clusterSubnetGroupName :
The name of the subnet group where you want to cluster restored.
A snapshot of cluster in VPC can be restored only in VPC. Therefore, you must provide subnet group name where you want the cluster restored.
Parameter defaultIamRoleArn :
The Amazon Resource Name (ARN) for the IAM role that was set as default
for the cluster when the cluster was last modified while it was restored
from a snapshot.
Parameter elasticIp :
The Elastic IP (EIP) address for the cluster. Don't specify the Elastic IP
address for a publicly accessible cluster with availability zone
relocation turned on.
Parameter encrypted :
Enables support for restoring an unencrypted snapshot to a cluster
encrypted with Key Management Service (KMS) and a customer managed key.
Parameter enhancedVpcRouting :
An option that specifies whether to create the cluster with enhanced VPC
routing enabled. To create a cluster that uses enhanced VPC routing, the
cluster must be in a VPC. For more information, see Enhanced
VPC Routing in the Amazon Redshift Cluster Management Guide.
If this option is true, enhanced VPC routing is enabled.
Default: false
Parameter hsmClientCertificateIdentifier :
Specifies the name of the HSM client certificate the Amazon Redshift
cluster uses to retrieve the data encryption keys stored in an HSM.
Parameter hsmConfigurationIdentifier :
Specifies the name of the HSM configuration that contains the information
the Amazon Redshift cluster can use to retrieve and store keys in an HSM.
Parameter iamRoles :
A list of Identity and Access Management (IAM) roles that can be used by
the cluster to access other Amazon Web Services services. You must supply
the IAM roles in their Amazon Resource Name (ARN) format.
The maximum number of IAM roles that you can associate is subject to a quota. For more information, go to Quotas and limits in the Amazon Redshift Cluster Management Guide.
Parameter ipAddressType :
The IP address type for the cluster. Possible values are ipv4
and dualstack.
Parameter kmsKeyId :
The Key Management Service (KMS) key ID of the encryption key that
encrypts data in the cluster restored from a shared snapshot. You can also
provide the key ID when you restore from an unencrypted snapshot to an
encrypted cluster in the same account. Additionally, you can specify a new
KMS key ID when you restore from an encrypted snapshot in the same account
in order to change it. In that case, the restored cluster is encrypted
with the new KMS key ID.
Parameter maintenanceTrackName :
The name of the maintenance track for the restored cluster. When you take
a snapshot, the snapshot inherits the MaintenanceTrack value
from the cluster. The snapshot might be on a different track than the
cluster that was the source for the snapshot. For example, suppose that
you take a snapshot of a cluster that is on the current track and then
change the cluster to be on the trailing track. In this case, the snapshot
and the source cluster are on different tracks.
Parameter manageMasterPassword :
If true, Amazon Redshift uses Secrets Manager to manage the
restored cluster's admin credentials. If ManageMasterPassword
is false or not set, Amazon Redshift uses the admin credentials the
cluster had at the time the snapshot was taken.
Parameter manualSnapshotRetentionPeriod :
The default number of days to retain a manual snapshot. If the value is
-1, the snapshot is retained indefinitely. This setting doesn't change the
retention period of existing snapshots.
The value must be either -1 or an integer between 1 and 3,653.
Parameter masterPasswordSecretKmsKeyId :
The ID of the Key Management Service (KMS) key used to encrypt and store
the cluster's admin credentials secret. You can only use this parameter if
ManageMasterPassword is true.
Parameter multiAZ :
If true, the snapshot will be restored to a cluster deployed in two
Availability Zones.
Parameter nodeType :
The node type that the restored cluster will be provisioned with.
If you have a DC instance type, you must restore into that same instance type and size. In other words, you can only restore a dc2.large node type into another dc2 type. For more information about node types, see About Clusters and Nodes in the Amazon Redshift Cluster Management Guide.
Parameter numberOfNodes :
The number of nodes specified when provisioning the restored cluster.
Parameter ownerAccount :
The Amazon Web Services account used to create or copy the snapshot.
Required if you are restoring a snapshot you do not own, optional if you
own the snapshot.
Parameter port :
The port number on which the cluster accepts connections.
Default: The same port as the original cluster.
Valid values: For clusters with DC2 nodes, must be within the range
1150-65535. For clusters with RG or RA3 nodes,
must be within the ranges 5431-5455 or
8191-8215.
Parameter preferredMaintenanceWindow :
The weekly time range (in UTC) during which automated cluster maintenance
can occur.
Format: ddd:hh24:mi-ddd:hh24:mi
Default: The value selected for the cluster from which the snapshot was taken. For more information about the time blocks for each region, see Maintenance Windows in Amazon Redshift Cluster Management Guide.
Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun
Constraints: Minimum 30-minute window.
Parameter publiclyAccessible :
If true, the cluster can be accessed from a public network.
Default: false
Parameter redshiftIdcApplicationArn :
The Amazon Resource Name (ARN) of the IAM Identity Center application used
for enabling Amazon Web Services IAM Identity Center trusted identity
propagation on a cluster enabled with Amazon Redshift federated
permissions.
Parameter reservedNodeId :
The identifier of the target reserved node offering.
Parameter snapshotArn :
The Amazon Resource Name (ARN) of the snapshot associated with the message
to restore from a cluster. You must specify this parameter or
snapshotIdentifier, but not both.
Parameter snapshotClusterIdentifier :
The name of the cluster the source snapshot was created from. This
parameter is required if your IAM user has a policy containing a snapshot
resource element that specifies anything other than * for the cluster
name.
Parameter snapshotIdentifier :
The name of the snapshot from which to create the new cluster. This
parameter isn't case sensitive. You must specify this parameter or
snapshotArn, but not both.
Example: my-snapshot-id
Parameter snapshotScheduleIdentifier :
A unique identifier for the snapshot schedule.
Parameter targetReservedNodeOfferingId :
The identifier of the target reserved node offering.
Parameter vpcSecurityGroupIds :
A list of Virtual Private Cloud (VPC) security groups to be associated
with the cluster.
Default: The default VPC security group is associated with the cluster.
VPC security groups only apply to clusters in VPCs.
Implementation
Future<RestoreFromClusterSnapshotResult> restoreFromClusterSnapshot({
required String clusterIdentifier,
String? additionalInfo,
bool? allowVersionUpgrade,
AquaConfigurationStatus? aquaConfigurationStatus,
int? automatedSnapshotRetentionPeriod,
String? availabilityZone,
bool? availabilityZoneRelocation,
String? catalogName,
String? clusterParameterGroupName,
List<String>? clusterSecurityGroups,
String? clusterSubnetGroupName,
String? defaultIamRoleArn,
String? elasticIp,
bool? encrypted,
bool? enhancedVpcRouting,
String? hsmClientCertificateIdentifier,
String? hsmConfigurationIdentifier,
List<String>? iamRoles,
String? ipAddressType,
String? kmsKeyId,
String? maintenanceTrackName,
bool? manageMasterPassword,
int? manualSnapshotRetentionPeriod,
String? masterPasswordSecretKmsKeyId,
bool? multiAZ,
String? nodeType,
int? numberOfNodes,
String? ownerAccount,
int? port,
String? preferredMaintenanceWindow,
bool? publiclyAccessible,
String? redshiftIdcApplicationArn,
String? reservedNodeId,
String? snapshotArn,
String? snapshotClusterIdentifier,
String? snapshotIdentifier,
String? snapshotScheduleIdentifier,
String? targetReservedNodeOfferingId,
List<String>? vpcSecurityGroupIds,
}) async {
final $request = <String, String>{
'ClusterIdentifier': clusterIdentifier,
if (additionalInfo != null) 'AdditionalInfo': additionalInfo,
if (allowVersionUpgrade != null)
'AllowVersionUpgrade': allowVersionUpgrade.toString(),
if (aquaConfigurationStatus != null)
'AquaConfigurationStatus': aquaConfigurationStatus.value,
if (automatedSnapshotRetentionPeriod != null)
'AutomatedSnapshotRetentionPeriod':
automatedSnapshotRetentionPeriod.toString(),
if (availabilityZone != null) 'AvailabilityZone': availabilityZone,
if (availabilityZoneRelocation != null)
'AvailabilityZoneRelocation': availabilityZoneRelocation.toString(),
if (catalogName != null) 'CatalogName': catalogName,
if (clusterParameterGroupName != null)
'ClusterParameterGroupName': clusterParameterGroupName,
if (clusterSecurityGroups != null)
if (clusterSecurityGroups.isEmpty)
'ClusterSecurityGroups': ''
else
for (var i1 = 0; i1 < clusterSecurityGroups.length; i1++)
'ClusterSecurityGroups.ClusterSecurityGroupName.${i1 + 1}':
clusterSecurityGroups[i1],
if (clusterSubnetGroupName != null)
'ClusterSubnetGroupName': clusterSubnetGroupName,
if (defaultIamRoleArn != null) 'DefaultIamRoleArn': defaultIamRoleArn,
if (elasticIp != null) 'ElasticIp': elasticIp,
if (encrypted != null) 'Encrypted': encrypted.toString(),
if (enhancedVpcRouting != null)
'EnhancedVpcRouting': enhancedVpcRouting.toString(),
if (hsmClientCertificateIdentifier != null)
'HsmClientCertificateIdentifier': hsmClientCertificateIdentifier,
if (hsmConfigurationIdentifier != null)
'HsmConfigurationIdentifier': hsmConfigurationIdentifier,
if (iamRoles != null)
if (iamRoles.isEmpty)
'IamRoles': ''
else
for (var i1 = 0; i1 < iamRoles.length; i1++)
'IamRoles.IamRoleArn.${i1 + 1}': iamRoles[i1],
if (ipAddressType != null) 'IpAddressType': ipAddressType,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (maintenanceTrackName != null)
'MaintenanceTrackName': maintenanceTrackName,
if (manageMasterPassword != null)
'ManageMasterPassword': manageMasterPassword.toString(),
if (manualSnapshotRetentionPeriod != null)
'ManualSnapshotRetentionPeriod':
manualSnapshotRetentionPeriod.toString(),
if (masterPasswordSecretKmsKeyId != null)
'MasterPasswordSecretKmsKeyId': masterPasswordSecretKmsKeyId,
if (multiAZ != null) 'MultiAZ': multiAZ.toString(),
if (nodeType != null) 'NodeType': nodeType,
if (numberOfNodes != null) 'NumberOfNodes': numberOfNodes.toString(),
if (ownerAccount != null) 'OwnerAccount': ownerAccount,
if (port != null) 'Port': port.toString(),
if (preferredMaintenanceWindow != null)
'PreferredMaintenanceWindow': preferredMaintenanceWindow,
if (publiclyAccessible != null)
'PubliclyAccessible': publiclyAccessible.toString(),
if (redshiftIdcApplicationArn != null)
'RedshiftIdcApplicationArn': redshiftIdcApplicationArn,
if (reservedNodeId != null) 'ReservedNodeId': reservedNodeId,
if (snapshotArn != null) 'SnapshotArn': snapshotArn,
if (snapshotClusterIdentifier != null)
'SnapshotClusterIdentifier': snapshotClusterIdentifier,
if (snapshotIdentifier != null) 'SnapshotIdentifier': snapshotIdentifier,
if (snapshotScheduleIdentifier != null)
'SnapshotScheduleIdentifier': snapshotScheduleIdentifier,
if (targetReservedNodeOfferingId != null)
'TargetReservedNodeOfferingId': targetReservedNodeOfferingId,
if (vpcSecurityGroupIds != null)
if (vpcSecurityGroupIds.isEmpty)
'VpcSecurityGroupIds': ''
else
for (var i1 = 0; i1 < vpcSecurityGroupIds.length; i1++)
'VpcSecurityGroupIds.VpcSecurityGroupId.${i1 + 1}':
vpcSecurityGroupIds[i1],
};
final $result = await _protocol.send(
$request,
action: 'RestoreFromClusterSnapshot',
version: '2012-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'RestoreFromClusterSnapshotResult',
);
return RestoreFromClusterSnapshotResult.fromXml($result);
}