cancelStatement method
Cancels a running query. To be canceled, a query must be running.
For more information about the Amazon Redshift Data API and CLI usage examples, see Using the Amazon Redshift Data API in the Amazon Redshift Management Guide.
May throw DatabaseConnectionException.
May throw InternalServerException.
May throw QueryTimeoutException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter id :
The identifier of the SQL statement to cancel. This value is a universally
unique identifier (UUID) generated by Amazon Redshift Data API. This
identifier is returned by BatchExecuteStatment,
ExecuteStatment, and ListStatements.
Implementation
Future<CancelStatementResponse> cancelStatement({
required String id,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftData.CancelStatement'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
},
);
return CancelStatementResponse.fromJson(jsonResponse.body);
}