getStatementResultV2 method
Fetches the temporarily cached result of an SQL statement in CSV format.
The ExecuteStatement or BatchExecuteStatement
operation that ran the SQL statement must have specified
ResultFormat as CSV. A token is returned to page
through the statement results.
For more information about the Amazon Redshift Data API and CLI usage examples, see Using the Amazon Redshift Data API in the Amazon Redshift Management Guide.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter id :
The identifier of the SQL statement whose results are to be fetched. This
value is a universally unique identifier (UUID) generated by Amazon
Redshift Data API. A suffix indicates then number of the SQL statement.
For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a
suffix of :2 that indicates the second SQL statement of a
batch query. This identifier is returned by
BatchExecuteStatment, ExecuteStatment, and
ListStatements.
Parameter nextToken :
A value that indicates the starting point for the next set of response
records in a subsequent request. If a value is returned in a response, you
can retrieve the next set of records by providing this returned NextToken
value in the next NextToken parameter and retrying the command. If the
NextToken field is empty, all response records have been retrieved for the
request.
Implementation
Future<GetStatementResultV2Response> getStatementResultV2({
required String id,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftData.GetStatementResultV2'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
if (nextToken != null) 'NextToken': nextToken,
},
);
return GetStatementResultV2Response.fromJson(jsonResponse.body);
}