getNamespace method
Returns information about a namespace in Amazon Redshift Serverless.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter namespaceName :
The name of the namespace to retrieve information for.
Implementation
Future<GetNamespaceResponse> getNamespace({
required String namespaceName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftServerless.GetNamespace'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'namespaceName': namespaceName,
},
);
return GetNamespaceResponse.fromJson(jsonResponse.body);
}