getTrack method
Get the Redshift Serverless version for a specified track.
May throw AccessDeniedException.
May throw ConflictException.
May throw DryRunException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter trackName :
The name of the track of which its version is fetched.
Implementation
Future<GetTrackResponse> getTrack({
required String trackName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftServerless.GetTrack'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'trackName': trackName,
},
);
return GetTrackResponse.fromJson(jsonResponse.body);
}