listTableRestoreStatus method
Returns information about an array of TableRestoreStatus
objects.
May throw InvalidPaginationException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter maxResults :
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to display the next page of results.
Parameter namespaceName :
The namespace from which to list all of the statuses of
RestoreTableFromSnapshot operations .
Parameter nextToken :
If your initial ListTableRestoreStatus operation returns a
nextToken, you can include the returned nextToken in
following ListTableRestoreStatus operations. This will return
results on the next page.
Parameter workgroupName :
The workgroup from which to list all of the statuses of
RestoreTableFromSnapshot operations.
Implementation
Future<ListTableRestoreStatusResponse> listTableRestoreStatus({
int? maxResults,
String? namespaceName,
String? nextToken,
String? workgroupName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftServerless.ListTableRestoreStatus'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (namespaceName != null) 'namespaceName': namespaceName,
if (nextToken != null) 'nextToken': nextToken,
if (workgroupName != null) 'workgroupName': workgroupName,
},
);
return ListTableRestoreStatusResponse.fromJson(jsonResponse.body);
}