listUsageLimits method
Lists all usage limits within Amazon Redshift Serverless.
May throw ConflictException.
May throw InternalServerException.
May throw InvalidPaginationException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter maxResults :
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to get the next page of
results. The default is 100.
Parameter nextToken :
If your initial ListUsageLimits operation returns a
nextToken, you can include the returned
nextToken in following ListUsageLimits
operations, which returns results in the next page.
Parameter resourceArn :
The Amazon Resource Name (ARN) associated with the resource whose usage
limits you want to list.
Parameter usageType :
The Amazon Redshift Serverless feature whose limits you want to see.
Implementation
Future<ListUsageLimitsResponse> listUsageLimits({
int? maxResults,
String? nextToken,
String? resourceArn,
UsageLimitUsageType? usageType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RedshiftServerless.ListUsageLimits'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (resourceArn != null) 'resourceArn': resourceArn,
if (usageType != null) 'usageType': usageType.value,
},
);
return ListUsageLimitsResponse.fromJson(jsonResponse.body);
}