createProjectVersion method
Creates a new version of Amazon Rekognition project (like a Custom Labels
model or a custom adapter) and begins training. Models and adapters are
managed as part of a Rekognition project. The response from
CreateProjectVersion is an Amazon Resource Name (ARN) for the
project version.
The FeatureConfig operation argument allows you to configure specific
model or adapter settings. You can provide a description to the project
version by using the VersionDescription argment. Training can take a while
to complete. You can get the current status by calling
DescribeProjectVersions. Training completed successfully if the
value of the Status field is TRAINING_COMPLETED.
Once training has successfully completed, call
DescribeProjectVersions to get the training results and evaluate
the model.
This operation requires permissions to perform the
rekognition:CreateProjectVersion action.
You can train a model in a project that doesn't have associated datasets
by specifying manifest files in the TrainingData and
TestingData fields.
If you open the console after training a model with manifest files, Amazon Rekognition Custom Labels creates the datasets for you using the most recent manifest files. You can no longer train a model version for the project by specifying manifest files.
Instead of training with a project without associated datasets, we recommend that you use the manifest files to create training and test datasets for the project.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ProvisionedThroughputExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter outputConfig :
The Amazon S3 bucket location to store the results of training. The bucket
can be any S3 bucket in your AWS account. You need
s3:PutObject permission on the bucket.
Parameter projectArn :
The ARN of the Amazon Rekognition project that will manage the project
version you want to train.
Parameter versionName :
A name for the version of the project version. This value must be unique.
Parameter featureConfig :
Feature-specific configuration of the training job. If the job
configuration does not match the feature type associated with the project,
an InvalidParameterException is returned.
Parameter kmsKeyId :
The identifier for your AWS Key Management Service key (AWS KMS key). You
can supply the Amazon Resource Name (ARN) of your KMS key, the ID of your
KMS key, an alias for your KMS key, or an alias ARN. The key is used to
encrypt training images, test images, and manifest files copied into the
service for the project version. Your source images are unaffected. The
key is also used to encrypt training results and manifest files written to
the output Amazon S3 bucket (OutputConfig).
If you choose to use your own KMS key, you need the following permissions on the KMS key.
- kms:CreateGrant
- kms:DescribeKey
- kms:GenerateDataKey
- kms:Decrypt
KmsKeyId, images copied into
the service are encrypted using a key that AWS owns and manages.
Parameter tags :
A set of tags (key-value pairs) that you want to attach to the project
version.
Parameter testingData :
Specifies an external manifest that the service uses to test the project
version. If you specify TestingData you must also specify
TrainingData. The project must not have any associated
datasets.
Parameter trainingData :
Specifies an external manifest that the services uses to train the project
version. If you specify TrainingData you must also specify
TestingData. The project must not have any associated
datasets.
Parameter versionDescription :
A description applied to the project version being created.
Implementation
Future<CreateProjectVersionResponse> createProjectVersion({
required OutputConfig outputConfig,
required String projectArn,
required String versionName,
CustomizationFeatureConfig? featureConfig,
String? kmsKeyId,
Map<String, String>? tags,
TestingData? testingData,
TrainingData? trainingData,
String? versionDescription,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.CreateProjectVersion'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OutputConfig': outputConfig,
'ProjectArn': projectArn,
'VersionName': versionName,
if (featureConfig != null) 'FeatureConfig': featureConfig,
if (kmsKeyId != null) 'KmsKeyId': kmsKeyId,
if (tags != null) 'Tags': tags,
if (testingData != null) 'TestingData': testingData,
if (trainingData != null) 'TrainingData': trainingData,
if (versionDescription != null)
'VersionDescription': versionDescription,
},
);
return CreateProjectVersionResponse.fromJson(jsonResponse.body);
}