deleteProjectVersion method
Deletes a Rekognition project model or project version, like a Amazon Rekognition Custom Labels model or a custom adapter.
You can't delete a project version if it is running or if it is training. To check the status of a project version, use the Status field returned from DescribeProjectVersions. To stop a project version call StopProjectVersion. If the project version is training, wait until it finishes.
This operation requires permissions to perform the
rekognition:DeleteProjectVersion action.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter projectVersionArn :
The Amazon Resource Name (ARN) of the project version that you want to
delete.
Implementation
Future<DeleteProjectVersionResponse> deleteProjectVersion({
required String projectVersionArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.DeleteProjectVersion'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ProjectVersionArn': projectVersionArn,
},
);
return DeleteProjectVersionResponse.fromJson(jsonResponse.body);
}