getLabelDetection method
Gets the label detection results of a Amazon Rekognition Video analysis started by StartLabelDetection.
The label detection operation is started by a call to
StartLabelDetection which returns a job identifier
(JobId). When the label detection operation finishes, Amazon
Rekognition publishes a completion status to the Amazon Simple
Notification Service topic registered in the initial call to
StartlabelDetection.
To get the results of the label detection operation, first check that the
status value published to the Amazon SNS topic is SUCCEEDED.
If so, call GetLabelDetection and pass the job identifier
(JobId) from the initial call to
StartLabelDetection.
GetLabelDetection returns an array of detected labels
(Labels) sorted by the time the labels were detected. You can
also sort by the label name by specifying NAME for the
SortBy input parameter. If there is no NAME
specified, the default sort is by timestamp.
You can select how results are aggregated by using the
AggregateBy input parameter. The default aggregation method
is TIMESTAMPS. You can also aggregate by
SEGMENTS, which aggregates all instances of labels detected
in a given segment.
The returned Labels array may include the following attributes:
- Name - The name of the detected label.
- Confidence - The level of confidence in the label assigned to a detected object.
- Parents - The ancestor labels for a detected label. GetLabelDetection returns a hierarchical taxonomy of detected labels. For example, a detected car might be assigned the label car. The label car has two parent labels: Vehicle (its parent) and Transportation (its grandparent). The response includes the all ancestors for a label, where every ancestor is a unique label. In the previous example, Car, Vehicle, and Transportation are returned as unique labels in the response.
- Aliases - Possible Aliases for the label.
- Categories - The label categories that the detected label belongs to.
- BoundingBox — Bounding boxes are described for all instances of detected common object labels, returned in an array of Instance objects. An Instance object contains a BoundingBox object, describing the location of the label on the input image. It also includes the confidence for the accuracy of the detected bounding box.
-
Timestamp - Time, in milliseconds from the start of the video, that the
label was detected. For aggregation by
SEGMENTS, theStartTimestampMillis,EndTimestampMillis, andDurationMillisstructures are what define a segment. Although the “Timestamp” structure is still returned with each label, its value is set to be the same asStartTimestampMillis.
TIMESTAMPS. If
aggregating by SEGMENTS, information about detected instances
isn’t returned.
The version of the label model used for the detection is also returned.
Note DominantColors isn't returned for
Instances, although it is shown as part of the response in
the sample seen below.
Use MaxResults parameter to limit the number of labels
returned. If there are more results than specified in
MaxResults, the value of NextToken in the
operation response contains a pagination token for getting the next set of
results. To get the next page of results, call
GetlabelDetection and populate the NextToken
request parameter with the token value returned from the previous call to
GetLabelDetection.
If you are retrieving results while using the Amazon Simple Notification Service, note that you will receive an "ERROR" notification if the job encounters an issue.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidPaginationTokenException.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter jobId :
Job identifier for the label detection operation for which you want
results returned. You get the job identifer from an initial call to
StartlabelDetection.
Parameter aggregateBy :
Defines how to aggregate the returned results. Results can be aggregated
by timestamps or segments.
Parameter maxResults :
Maximum number of results to return per paginated call. The largest value
you can specify is 1000. If you specify a value greater than 1000, a
maximum of 1000 results is returned. The default value is 1000.
Parameter nextToken :
If the previous response was incomplete (because there are more labels to
retrieve), Amazon Rekognition Video returns a pagination token in the
response. You can use this pagination token to retrieve the next set of
labels.
Parameter sortBy :
Sort to use for elements in the Labels array. Use
TIMESTAMP to sort array elements by the time labels are
detected. Use NAME to alphabetically group elements for a
label together. Within each label group, the array element are sorted by
detection confidence. The default sort is by TIMESTAMP.
Implementation
Future<GetLabelDetectionResponse> getLabelDetection({
required String jobId,
LabelDetectionAggregateBy? aggregateBy,
int? maxResults,
String? nextToken,
LabelDetectionSortBy? sortBy,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.GetLabelDetection'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
if (aggregateBy != null) 'AggregateBy': aggregateBy.value,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
},
);
return GetLabelDetectionResponse.fromJson(jsonResponse.body);
}