getMediaAnalysisJob method
Retrieves the results for a given media analysis job. Takes a
JobId returned by StartMediaAnalysisJob.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter jobId :
Unique identifier for the media analysis job for which you want to
retrieve results.
Implementation
Future<GetMediaAnalysisJobResponse> getMediaAnalysisJob({
required String jobId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.GetMediaAnalysisJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobId': jobId,
},
);
return GetMediaAnalysisJobResponse.fromJson(jsonResponse.body);
}