putProjectPolicy method
For more information about the format of a project policy document, see Attaching a project policy (SDK) in the Amazon Rekognition Custom Labels Developer Guide.
The response from PutProjectPolicy is a revision ID for the
project policy. You can attach multiple project policies to a project. You
can also update an existing project policy by specifying the policy
revision ID of the existing policy.
To remove a project policy from a project, call DeleteProjectPolicy. To get a list of project policies attached to a project, call ListProjectPolicies.
You copy a model version by calling CopyProjectVersion.
This operation requires permissions to perform the
rekognition:PutProjectPolicy action.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw InvalidPolicyRevisionIdException.
May throw LimitExceededException.
May throw MalformedPolicyDocumentException.
May throw ProvisionedThroughputExceededException.
May throw ResourceAlreadyExistsException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
Parameter policyDocument :
A resource policy to add to the model. The policy is a JSON structure that
contains one or more statements that define the policy. The policy must
follow the IAM syntax. For more information about the contents of a JSON
policy document, see IAM
JSON policy reference.
Parameter policyName :
A name for the policy.
Parameter projectArn :
The Amazon Resource Name (ARN) of the project that the project policy is
attached to.
Parameter policyRevisionId :
The revision ID for the Project Policy. Each time you modify a policy,
Amazon Rekognition Custom Labels generates and assigns a new
PolicyRevisionId and then deletes the previous version of the
policy.
Implementation
Future<PutProjectPolicyResponse> putProjectPolicy({
required String policyDocument,
required String policyName,
required String projectArn,
String? policyRevisionId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.PutProjectPolicy'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PolicyDocument': policyDocument,
'PolicyName': policyName,
'ProjectArn': projectArn,
if (policyRevisionId != null) 'PolicyRevisionId': policyRevisionId,
},
);
return PutProjectPolicyResponse.fromJson(jsonResponse.body);
}