untagResource method
Removes one or more tags from an Amazon Rekognition collection, stream processor, or Custom Labels model.
This operation requires permissions to perform the
rekognition:UntagResource action.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter resourceArn :
Amazon Resource Name (ARN) of the model, collection, or stream processor
that you want to remove the tags from.
Parameter tagKeys :
A list of the tags that you want to remove.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'RekognitionService.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
);
}