RekognitionStreaming class
A real-time video processing service based on Rekognition. This section documents the API operations for Rekognition Face Liveness.
Amazon Rekognition Face Liveness
Constructors
- RekognitionStreaming({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startFaceLivenessSession(
{required String challengeVersions, required String sessionId, required String videoHeight, required String videoWidth, LivenessRequestStream? livenessRequestStream}) → Future< StartFaceLivenessSessionResponse> - Starts a Face Liveness video stream and liveness detection process for a given session.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited