deleteIndex method
Deletes the specified index and turns off Amazon Web Services Resource
Explorer in the specified Amazon Web Services Region. When you delete an
index, Resource Explorer stops discovering and indexing resources in that
Region. Resource Explorer also deletes all views in that Region. These
actions occur as asynchronous background tasks. You can check to see when
the actions are complete by using the GetIndex operation and
checking the Status response value.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter arn :
The Amazon
resource name (ARN) of the index that you want to delete.
Implementation
Future<DeleteIndexOutput> deleteIndex({
required String arn,
}) async {
final $payload = <String, dynamic>{
'Arn': arn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteIndex',
exceptionFnMap: _exceptionFns,
);
return DeleteIndexOutput.fromJson(response);
}