getAccountLevelServiceConfiguration method
Retrieves the status of your account's Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature. Only the management account can invoke this API call.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Implementation
Future<GetAccountLevelServiceConfigurationOutput>
getAccountLevelServiceConfiguration() async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/GetAccountLevelServiceConfiguration',
exceptionFnMap: _exceptionFns,
);
return GetAccountLevelServiceConfigurationOutput.fromJson(response);
}