getServiceIndex method
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region. This operation returns the ARN and type of the index if one exists.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Implementation
Future<GetServiceIndexOutput> getServiceIndex() async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/GetServiceIndex',
exceptionFnMap: _exceptionFns,
);
return GetServiceIndexOutput.fromJson(response);
}