getServiceView method
Retrieves details about a specific Resource Explorer service view. This operation returns the configuration and properties of the specified view.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter serviceViewArn :
The Amazon Resource Name (ARN) of the service view to retrieve details
for.
Implementation
Future<GetServiceViewOutput> getServiceView({
required String serviceViewArn,
}) async {
final $payload = <String, dynamic>{
'ServiceViewArn': serviceViewArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetServiceView',
exceptionFnMap: _exceptionFns,
);
return GetServiceViewOutput.fromJson(response);
}