listResources method
Returns a list of resources and their details that match the specified criteria. This query must use a view. If you don’t explicitly specify a view, then Resource Explorer uses the default view for the Amazon Web Services Region in which you call this operation.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter filters :
An array of strings that specify which resources are included in the
results of queries made using this view. When you use this view in a
Search operation, the filter string is combined with the search's
QueryString parameter using a logical AND
operator.
For information about the supported syntax, see Search query reference for Resource Explorer in the Amazon Web Services Resource Explorer User Guide.
Parameter maxResults :
The maximum number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value
appropriate to the operation. If additional items exist beyond those
included in the current response, the NextToken response
element is present and has a value (is not null). Include that value as
the NextToken request parameter in the next call to the
operation to get the next part of the results.
Parameter nextToken :
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from. The pagination tokens expire after 24 hours.
Parameter viewArn :
Specifies the Amazon resource name (ARN) of the view to use for the query.
If you don't specify a value for this parameter, then the operation
automatically uses the default view for the Amazon Web Services Region in
which you called this operation. If the Region either doesn't have a
default view or if you don't have permission to use the default view, then
the operation fails with a 401 Unauthorized exception.
Implementation
Future<ListResourcesOutput> listResources({
SearchFilter? filters,
int? maxResults,
String? nextToken,
String? viewArn,
}) async {
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (viewArn != null) 'ViewArn': viewArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListResources',
exceptionFnMap: _exceptionFns,
);
return ListResourcesOutput.fromJson(response);
}