listServiceIndexes method
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions. This operation returns information about indexes including their ARNs, types, and Regions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of index results to return in a single response. Valid
values are between 1 and 100.
Parameter nextToken :
The pagination token from a previous ListServiceIndexes
response. Use this token to retrieve the next set of results.
Parameter regions :
A list of Amazon Web Services Regions to include in the search for
indexes. If not specified, indexes from all Regions are returned.
Implementation
Future<ListServiceIndexesOutput> listServiceIndexes({
int? maxResults,
String? nextToken,
List<String>? regions,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (regions != null) 'Regions': regions,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListServiceIndexes',
exceptionFnMap: _exceptionFns,
);
return ListServiceIndexesOutput.fromJson(response);
}