listViews method
Lists the Amazon resource names (ARNs) of the views available in the Amazon Web Services Region in which you call this operation.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value
appropriate to the operation. If additional items exist beyond those
included in the current response, the NextToken response
element is present and has a value (is not null). Include that value as
the NextToken request parameter in the next call to the
operation to get the next part of the results.
Parameter nextToken :
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from. The pagination tokens expire after 24 hours.
Implementation
Future<ListViewsOutput> listViews({
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListViews',
exceptionFnMap: _exceptionFns,
);
return ListViewsOutput.fromJson(response);
}