getGroupConfiguration method
Retrieves the service configuration associated with the specified resource group. For details about the service configuration syntax, see Service configurations for Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:GetGroupConfiguration
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw MethodNotAllowedException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter group :
The name or the Amazon resource name (ARN) of the resource group for which
you want to retrive the service configuration.
Implementation
Future<GetGroupConfigurationOutput> getGroupConfiguration({
String? group,
}) async {
final $payload = <String, dynamic>{
if (group != null) 'Group': group,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/get-group-configuration',
exceptionFnMap: _exceptionFns,
);
return GetGroupConfigurationOutput.fromJson(response);
}