activateKeySigningKey method
Activates a key-signing key (KSK) so that it can be used for signing by
DNSSEC. This operation changes the KSK status to ACTIVE.
May throw ConcurrentModification.
May throw InvalidInput.
May throw InvalidKeySigningKeyStatus.
May throw InvalidKMSArn.
May throw InvalidSigningStatus.
May throw NoSuchKeySigningKey.
Parameter hostedZoneId :
A unique string used to identify a hosted zone.
Parameter name :
A string used to identify a key-signing key (KSK). Name can
include numbers, letters, and underscores (_). Name must be
unique for each key-signing key in the same hosted zone.
Implementation
Future<ActivateKeySigningKeyResponse> activateKeySigningKey({
required String hostedZoneId,
required String name,
}) async {
final $result = await _protocol.send(
method: 'POST',
requestUri:
'/2013-04-01/keysigningkey/${Uri.encodeComponent(hostedZoneId)}/${Uri.encodeComponent(name)}/activate',
exceptionFnMap: _exceptionFns,
);
return ActivateKeySigningKeyResponse.fromXml($result.body);
}