deleteCidrCollection method
Deletes a CIDR collection in the current Amazon Web Services account. The collection must be empty before it can be deleted.
May throw CidrCollectionInUseException.
May throw ConcurrentModification.
May throw InvalidInput.
May throw NoSuchCidrCollectionException.
Parameter id :
The UUID of the collection to delete.
Implementation
Future<void> deleteCidrCollection({
required String id,
}) async {
await _protocol.send(
method: 'DELETE',
requestUri: '/2013-04-01/cidrcollection/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
}