getHostedZone method
Gets information about a specified hosted zone including the four name servers assigned to the hosted zone.
returns the VPCs associated with the specified hosted zone
and does not reflect the VPC associations by Route 53 Profiles. To get the
associations to a Profile, call the ListProfileAssociations
API.
May throw InvalidInput.
May throw NoSuchHostedZone.
Parameter id :
The ID of the hosted zone that you want to get information about.
Implementation
Future<GetHostedZoneResponse> getHostedZone({
required String id,
}) async {
final $result = await _protocol.send(
method: 'GET',
requestUri: '/2013-04-01/hostedzone/${Uri.encodeComponent(id)}',
exceptionFnMap: _exceptionFns,
);
return GetHostedZoneResponse.fromXml($result.body);
}