listCidrCollections method
Returns a paginated list of CIDR collections in the Amazon Web Services account (metadata only).
May throw InvalidInput.
Parameter maxResults :
The maximum number of CIDR collections to return in the response.
Parameter nextToken :
An opaque pagination token to indicate where the service is to begin
enumerating results.
If no value is provided, the listing of results starts from the beginning.
Implementation
Future<ListCidrCollectionsResponse> listCidrCollections({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxresults': [maxResults.toString()],
if (nextToken != null) 'nexttoken': [nextToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/2013-04-01/cidrcollection',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCidrCollectionsResponse.fromXml($result.body);
}