listCidrLocations method
Returns a paginated list of CIDR locations for the given collection (metadata only, does not include CIDR blocks).
May throw InvalidInput.
May throw NoSuchCidrCollectionException.
Parameter collectionId :
The CIDR collection ID.
Parameter maxResults :
The maximum number of CIDR collection locations to return in the response.
Parameter nextToken :
An opaque pagination token to indicate where the service is to begin
enumerating results.
If no value is provided, the listing of results starts from the beginning.
Implementation
Future<ListCidrLocationsResponse> listCidrLocations({
required String collectionId,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'maxresults': [maxResults.toString()],
if (nextToken != null) 'nexttoken': [nextToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/2013-04-01/cidrcollection/${Uri.encodeComponent(collectionId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListCidrLocationsResponse.fromXml($result.body);
}