acceptDomainTransferFromAnotherAwsAccount method
Accepts the transfer of a domain from another Amazon Web Services account to the currentAmazon Web Services account. You initiate a transfer between Amazon Web Services accounts using TransferDomainToAnotherAwsAccount.
If you use the CLI command at accept-domain-transfer-from-another-aws-account, use JSON format as input instead of text because otherwise CLI will throw an error from domain transfer input that includes single quotes.
Use either ListOperations
or GetOperationDetail
to determine whether the operation succeeded. GetOperationDetail
provides additional information, for example, Domain Transfer from
Aws Account 111122223333 has been cancelled.
May throw DomainLimitExceeded.
May throw InvalidInput.
May throw OperationLimitExceeded.
May throw UnsupportedTLD.
Parameter domainName :
The name of the domain that was specified when another Amazon Web Services
account submitted a TransferDomainToAnotherAwsAccount
request.
Parameter password :
The password that was returned by the TransferDomainToAnotherAwsAccount
request.
Implementation
Future<AcceptDomainTransferFromAnotherAwsAccountResponse>
acceptDomainTransferFromAnotherAwsAccount({
required String domainName,
required String password,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'Route53Domains_v20140515.AcceptDomainTransferFromAnotherAwsAccount'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainName': domainName,
'Password': password,
},
);
return AcceptDomainTransferFromAnotherAwsAccountResponse.fromJson(
jsonResponse.body);
}