rejectDomainTransferFromAnotherAwsAccount method
Future<RejectDomainTransferFromAnotherAwsAccountResponse>
rejectDomainTransferFromAnotherAwsAccount({
- required String domainName,
Rejects the transfer of a domain from another Amazon Web Services account to the current Amazon Web Services account. You initiate a transfer betweenAmazon Web Services accounts using TransferDomainToAnotherAwsAccount.
Use either ListOperations
or GetOperationDetail
to determine whether the operation succeeded. GetOperationDetail
provides additional information, for example, Domain Transfer from
Aws Account 111122223333 has been cancelled.
May throw InvalidInput.
May throw OperationLimitExceeded.
May throw UnsupportedTLD.
Parameter domainName :
The name of the domain that was specified when another Amazon Web Services
account submitted a TransferDomainToAnotherAwsAccount
request.
Implementation
Future<RejectDomainTransferFromAnotherAwsAccountResponse>
rejectDomainTransferFromAnotherAwsAccount({
required String domainName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'Route53Domains_v20140515.RejectDomainTransferFromAnotherAwsAccount'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainName': domainName,
},
);
return RejectDomainTransferFromAnotherAwsAccountResponse.fromJson(
jsonResponse.body);
}