listFirewallDomainLists method
Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter globalResolverId :
The ID of the Global Resolver that contains the DNS view the domain lists
are associated to.
Parameter maxResults :
The maximum number of results to retrieve in a single call.
Parameter nextToken :
A pagination token used for large sets of results that can't be returned
in a single response.
Implementation
Future<ListFirewallDomainListsOutput> listFirewallDomainLists({
String? globalResolverId,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (globalResolverId != null) 'global_resolver_id': [globalResolverId],
if (maxResults != null) 'max_results': [maxResults.toString()],
if (nextToken != null) 'next_token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/firewall-domain-lists',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFirewallDomainListsOutput.fromJson(response);
}