listFirewallDomains method
Lists all the domains in DNS Firewall domain list you have created.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter firewallDomainListId :
ID of the DNS Firewall domain list.
Parameter maxResults :
The maximum number of results to retrieve in a single call.
Parameter nextToken :
A pagination token used for large sets of results that can't be returned
in a single response.
Implementation
Future<ListFirewallDomainsOutput> listFirewallDomains({
required String firewallDomainListId,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'max_results': [maxResults.toString()],
if (nextToken != null) 'next_token': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/firewall-domain-lists/${Uri.encodeComponent(firewallDomainListId)}/domains',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFirewallDomainsOutput.fromJson(response);
}