Route53Profiles class
With Amazon Route 53 Profiles you can share Route 53 configurations with VPCs and AWS accounts
Constructors
- Route53Profiles({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateProfile(
{required String name, required String profileId, required String resourceId, List< Tag> ? tags}) → Future<AssociateProfileResponse> - Associates a Route 53 Profiles profile with a VPC. A VPC can have only one Profile associated with it, but a Profile can be associated with 1000 of VPCs (and you can request a higher quota). For more information, see https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities.
-
associateResourceToProfile(
{required String name, required String profileId, required String resourceArn, String? resourceProperties}) → Future< AssociateResourceToProfileResponse> - Associates a DNS reource configuration to a Route 53 Profile.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createProfile(
{required String name, String? clientToken, List< Tag> ? tags}) → Future<CreateProfileResponse> - Creates an empty Route 53 Profile.
-
deleteProfile(
{required String profileId}) → Future< DeleteProfileResponse> - Deletes the specified Route 53 Profile. Before you can delete a profile, you must first disassociate it from all VPCs.
-
disassociateProfile(
{required String profileId, required String resourceId}) → Future< DisassociateProfileResponse> - Dissociates a specified Route 53 Profile from the specified VPC.
-
disassociateResourceFromProfile(
{required String profileId, required String resourceArn}) → Future< DisassociateResourceFromProfileResponse> - Dissoaciated a specified resource, from the Route 53 Profile.
-
getProfile(
{required String profileId}) → Future< GetProfileResponse> - Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile.
-
getProfileAssociation(
{required String profileAssociationId}) → Future< GetProfileAssociationResponse> - Retrieves a Route 53 Profile association for a VPC. A VPC can have only one Profile association, but a Profile can be associated with up to 5000 VPCs.
-
getProfileResourceAssociation(
{required String profileResourceAssociationId}) → Future< GetProfileResourceAssociationResponse> - Returns information about a specified Route 53 Profile resource association.
-
listProfileAssociations(
{int? maxResults, String? nextToken, String? profileId, String? resourceId}) → Future< ListProfileAssociationsResponse> - Lists all the VPCs that the specified Route 53 Profile is associated with.
-
listProfileResourceAssociations(
{required String profileId, int? maxResults, String? nextToken, String? resourceType}) → Future< ListProfileResourceAssociationsResponse> - Lists all the resource associations for the specified Route 53 Profile.
-
listProfiles(
{int? maxResults, String? nextToken}) → Future< ListProfilesResponse> - Lists all the Route 53 Profiles associated with your Amazon Web Services account.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - Lists the tags that you associated with the specified resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds one or more tags to a specified resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes one or more tags from a specified resource.
-
updateProfileResourceAssociation(
{required String profileResourceAssociationId, String? name, String? resourceProperties}) → Future< UpdateProfileResourceAssociationResponse> - Updates the specified Route 53 Profile resourse association.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited