associateProfile method
Associates a Route 53 Profiles profile with a VPC. A VPC can have only one Profile associated with it, but a Profile can be associated with 1000 of VPCs (and you can request a higher quota). For more information, see https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities.
May throw AccessDeniedException.
May throw ConflictException.
May throw InvalidParameterException.
May throw LimitExceededException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
A name for the association.
Parameter profileId :
ID of the Profile.
Parameter resourceId :
The ID of the VPC.
Parameter tags :
A list of the tag keys and values that you want to identify the Profile
association.
Implementation
Future<AssociateProfileResponse> associateProfile({
required String name,
required String profileId,
required String resourceId,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'Name': name,
'ProfileId': profileId,
'ResourceId': resourceId,
if (tags != null) 'Tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/profileassociation',
exceptionFnMap: _exceptionFns,
);
return AssociateProfileResponse.fromJson(response);
}