getProfileAssociation method
Future<GetProfileAssociationResponse>
getProfileAssociation({
- required String profileAssociationId,
Retrieves a Route 53 Profile association for a VPC. A VPC can have only one Profile association, but a Profile can be associated with up to 5000 VPCs.
May throw AccessDeniedException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter profileAssociationId :
The identifier of the association you want to get information about.
Implementation
Future<GetProfileAssociationResponse> getProfileAssociation({
required String profileAssociationId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/profileassociation/${Uri.encodeComponent(profileAssociationId)}',
exceptionFnMap: _exceptionFns,
);
return GetProfileAssociationResponse.fromJson(response);
}