listProfileResourceAssociations method
Lists all the resource associations for the specified Route 53 Profile.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter profileId :
The ID of the Profile.
Parameter maxResults :
The maximum number of objects that you want to return for this request. If
more objects are available, in the response, a NextToken
value, which you can use in a subsequent call to get the next batch of
objects, is provided.
If you don't specify a value for MaxResults, up to 100
objects are returned.
Parameter nextToken :
For the first call to this list request, omit this value.
When you request a list of objects, at most the number of objects
specified by MaxResults is returned. If more objects are
available for retrieval, a NextToken value is returned in the
response. To retrieve the next batch of objects, use the token that was
returned for the prior request in your next request.
Parameter resourceType :
ID of a resource if you want information on only one type.
Implementation
Future<ListProfileResourceAssociationsResponse>
listProfileResourceAssociations({
required String profileId,
int? maxResults,
String? nextToken,
String? resourceType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (resourceType != null) 'resourceType': [resourceType],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/profileresourceassociations/profileid/${Uri.encodeComponent(profileId)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListProfileResourceAssociationsResponse.fromJson(response);
}