Route53RecoveryReadiness class
Recovery readiness
Constructors
- Route53RecoveryReadiness({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCell(
{required String cellName, List< String> ? cells, Map<String, String> ? tags}) → Future<CreateCellResponse> - Creates a cell in an account.
-
createCrossAccountAuthorization(
{required String crossAccountAuthorization}) → Future< CreateCrossAccountAuthorizationResponse> - Creates a cross-account readiness authorization. This lets you authorize another account to work with Route 53 Application Recovery Controller, for example, to check the readiness status of resources in a separate account.
-
createReadinessCheck(
{required String readinessCheckName, required String resourceSetName, Map< String, String> ? tags}) → Future<CreateReadinessCheckResponse> - Creates a readiness check in an account. A readiness check monitors a resource set in your application, such as a set of Amazon Aurora instances, that Application Recovery Controller is auditing recovery readiness for. The audits run once every minute on every resource that's associated with a readiness check.
-
createRecoveryGroup(
{required String recoveryGroupName, List< String> ? cells, Map<String, String> ? tags}) → Future<CreateRecoveryGroupResponse> - Creates a recovery group in an account. A recovery group corresponds to an application and includes a list of the cells that make up the application.
-
createResourceSet(
{required String resourceSetName, required String resourceSetType, required List< Resource> resources, Map<String, String> ? tags}) → Future<CreateResourceSetResponse> - Creates a resource set. A resource set is a set of resources of one type that span multiple cells. You can associate a resource set with a readiness check to monitor the resources for failover readiness.
-
deleteCell(
{required String cellName}) → Future< void> - Delete a cell. When successful, the response code is 204, with no response body.
-
deleteCrossAccountAuthorization(
{required String crossAccountAuthorization}) → Future< void> - Deletes cross account readiness authorization.
-
deleteReadinessCheck(
{required String readinessCheckName}) → Future< void> - Deletes a readiness check.
-
deleteRecoveryGroup(
{required String recoveryGroupName}) → Future< void> - Deletes a recovery group.
-
deleteResourceSet(
{required String resourceSetName}) → Future< void> - Deletes a resource set.
-
getArchitectureRecommendations(
{required String recoveryGroupName, int? maxResults, String? nextToken}) → Future< GetArchitectureRecommendationsResponse> - Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group.
-
getCell(
{required String cellName}) → Future< GetCellResponse> - Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
-
getCellReadinessSummary(
{required String cellName, int? maxResults, String? nextToken}) → Future< GetCellReadinessSummaryResponse> - Gets readiness for a cell. Aggregates the readiness of all the resources that are associated with the cell into a single value.
-
getReadinessCheck(
{required String readinessCheckName}) → Future< GetReadinessCheckResponse> - Gets details about a readiness check.
-
getReadinessCheckResourceStatus(
{required String readinessCheckName, required String resourceIdentifier, int? maxResults, String? nextToken}) → Future< GetReadinessCheckResourceStatusResponse> - Gets individual readiness status for a readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in the recovery group, use GetRecoveryGroupReadinessSummary.
-
getReadinessCheckStatus(
{required String readinessCheckName, int? maxResults, String? nextToken}) → Future< GetReadinessCheckStatusResponse> - Gets the readiness status for an individual readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in a recovery group, use GetRecoveryGroupReadinessSummary.
-
getRecoveryGroup(
{required String recoveryGroupName}) → Future< GetRecoveryGroupResponse> - Gets details about a recovery group, including a list of the cells that are included in it.
-
getRecoveryGroupReadinessSummary(
{required String recoveryGroupName, int? maxResults, String? nextToken}) → Future< GetRecoveryGroupReadinessSummaryResponse> - Displays a summary of information about a recovery group's readiness status. Includes the readiness checks for resources in the recovery group and the readiness status of each one.
-
getResourceSet(
{required String resourceSetName}) → Future< GetResourceSetResponse> - Displays the details about a resource set, including a list of the resources in the set.
-
listCells(
{int? maxResults, String? nextToken}) → Future< ListCellsResponse> - Lists the cells for an account.
-
listCrossAccountAuthorizations(
{int? maxResults, String? nextToken}) → Future< ListCrossAccountAuthorizationsResponse> - Lists the cross-account readiness authorizations that are in place for an account.
-
listReadinessChecks(
{int? maxResults, String? nextToken}) → Future< ListReadinessChecksResponse> - Lists the readiness checks for an account.
-
listRecoveryGroups(
{int? maxResults, String? nextToken}) → Future< ListRecoveryGroupsResponse> - Lists the recovery groups in an account.
-
listResourceSets(
{int? maxResults, String? nextToken}) → Future< ListResourceSetsResponse> - Lists the resource sets in an account.
-
listRules(
{int? maxResults, String? nextToken, String? resourceType}) → Future< ListRulesResponse> - Lists all readiness rules, or lists the readiness rules for a specific resource type.
-
listTagsForResources(
{required String resourceArn}) → Future< ListTagsForResourcesResponse> - Lists the tags for a resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds a tag to a resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from a resource.
-
updateCell(
{required String cellName, required List< String> cells}) → Future<UpdateCellResponse> - Updates a cell to replace the list of nested cells with a new list of nested cells.
-
updateReadinessCheck(
{required String readinessCheckName, required String resourceSetName}) → Future< UpdateReadinessCheckResponse> - Updates a readiness check.
-
updateRecoveryGroup(
{required List< String> cells, required String recoveryGroupName}) → Future<UpdateRecoveryGroupResponse> - Updates a recovery group.
-
updateResourceSet(
{required String resourceSetName, required String resourceSetType, required List< Resource> resources}) → Future<UpdateResourceSetResponse> - Updates a resource set.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited