createReadinessCheck method
Creates a readiness check in an account. A readiness check monitors a resource set in your application, such as a set of Amazon Aurora instances, that Application Recovery Controller is auditing recovery readiness for. The audits run once every minute on every resource that's associated with a readiness check.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter readinessCheckName :
The name of the readiness check to create.
Parameter resourceSetName :
The name of the resource set to check.
Implementation
Future<CreateReadinessCheckResponse> createReadinessCheck({
required String readinessCheckName,
required String resourceSetName,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'readinessCheckName': readinessCheckName,
'resourceSetName': resourceSetName,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/readinesschecks',
exceptionFnMap: _exceptionFns,
);
return CreateReadinessCheckResponse.fromJson(response);
}