getCell method
Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cellName :
The name of the cell.
Implementation
Future<GetCellResponse> getCell({
required String cellName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/cells/${Uri.encodeComponent(cellName)}',
exceptionFnMap: _exceptionFns,
);
return GetCellResponse.fromJson(response);
}