getReadinessCheckStatus method
Gets the readiness status for an individual readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in a recovery group, use GetRecoveryGroupReadinessSummary.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter readinessCheckName :
Name of a readiness check.
Parameter maxResults :
The number of objects that you want to return with this call.
Parameter nextToken :
The token that identifies which batch of results you want to see.
Implementation
Future<GetReadinessCheckStatusResponse> getReadinessCheckStatus({
required String readinessCheckName,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/readinesschecks/${Uri.encodeComponent(readinessCheckName)}/status',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetReadinessCheckStatusResponse.fromJson(response);
}