updateCell method
Updates a cell to replace the list of nested cells with a new list of nested cells.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter cellName :
The name of the cell.
Parameter cells :
A list of cell Amazon Resource Names (ARNs), which completely replaces the
previous list.
Implementation
Future<UpdateCellResponse> updateCell({
required String cellName,
required List<String> cells,
}) async {
final $payload = <String, dynamic>{
'cells': cells,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/cells/${Uri.encodeComponent(cellName)}',
exceptionFnMap: _exceptionFns,
);
return UpdateCellResponse.fromJson(response);
}