This operation aborts a multipart upload. After a multipart upload is
aborted, no additional parts can be uploaded using that upload ID. The
storage consumed by any previously uploaded parts will be freed. However,
if any part uploads are currently in progress, those part uploads might or
might not succeed. As a result, it might be necessary to abort a given
multipart upload multiple times in order to completely free all storage
consumed by all parts.
Creates an S3 Metadata V2 metadata configuration for a general purpose
bucket. For more information, see Accelerating
data discovery with S3 Metadata in the Amazon S3 User Guide.
Creates a session that establishes temporary security credentials to
support fast authentication and authorization for the Zonal endpoint API
operations on directory buckets. For more information about Zonal endpoint
API operations that include the Availability Zone in the request endpoint,
see S3
Express One Zone APIs in the Amazon S3 User Guide.
Deletes the S3 bucket. All objects (including all object versions and
delete markers) in the bucket must be deleted before the bucket itself can
be deleted.
The S3 Intelligent-Tiering storage class is designed to optimize storage
costs by automatically moving data to the most cost-effective storage
access tier, without performance impact or operational overhead. S3
Intelligent-Tiering delivers automatic cost savings in three low latency
and high throughput access tiers. To get the lowest storage cost on data
that can be accessed in minutes to hours, you can choose to activate
additional archiving capabilities.
Deletes the lifecycle configuration from the specified bucket. Amazon S3
removes all the lifecycle configuration rules in the lifecycle subresource
associated with the bucket. Your objects never expire, and Amazon S3 no
longer automatically deletes any objects on the basis of rules contained
in the deleted lifecycle configuration.
Deletes a metrics configuration for the Amazon CloudWatch request metrics
(specified by the metrics configuration ID) from the bucket. Note that
this doesn't include the daily storage metrics.
This operation enables you to delete multiple objects from a bucket using
a single HTTP request. If you know the object keys that you want to
delete, then this operation provides a suitable alternative to sending
individual delete requests, reducing per-request overhead.
Returns the attribute-based access control (ABAC) property of the general
purpose bucket. If ABAC is enabled on your bucket, you can use tags on the
bucket for access control. For more information, see Enabling
ABAC in general purpose buckets.
To use this operation, you must have permission to perform the
s3:GetBucketCORS action. By default, the bucket owner has
this permission and can grant it to others.
Returns the default encryption configuration for an Amazon S3 bucket. By
default, all buckets have a default encryption configuration that uses
server-side encryption with Amazon S3 managed keys (SSE-S3). This
operation also returns the BucketKeyEnabled
and BlockedEncryptionTypes
statuses.
The S3 Intelligent-Tiering storage class is designed to optimize storage
costs by automatically moving data to the most cost-effective storage
access tier, without performance impact or operational overhead. S3
Intelligent-Tiering delivers automatic cost savings in three low latency
and high throughput access tiers. To get the lowest storage cost on data
that can be accessed in minutes to hours, you can choose to activate
additional archiving capabilities.
To use this operation, you must have permission to perform the
s3:GetBucketTagging action. By default, the bucket owner has
this permission and can grant this permission to others.
Retrieves all of the metadata from an object without returning the object
itself. This operation is useful if you're interested only in an object's
metadata.
To use this operation, you must have permission to perform the
s3:GetObjectTagging action. By default, the GET action
returns information about current version of an object. For a versioned
bucket, you can have multiple versions of an object in your bucket. To
retrieve tags of any other version, use the versionId query parameter. You
also need permission for the s3:GetObjectVersionTagging
action.
You can use this operation to determine if a bucket exists and if you have
permission to access it. The action returns a 200 OK HTTP
status code if the bucket exists and you have permission to access it. You
can make a HeadBucket call on any bucket name to any Region
in the partition, and regardless of the permissions on the bucket, you
will receive a response header with the correct bucket location so that
you can then make a proper, signed request to the appropriate Regional
endpoint.
The HEAD operation retrieves metadata from an object without
returning the object itself. This operation is useful if you're interested
only in an object's metadata.
Request headers are limited to 8 KB in size. For more information, see Common
Request Headers.
This action supports list pagination and does not return more than 100
configurations at a time. You should always check the
IsTruncated element in the response. If there are no more
configurations to list, IsTruncated is set to false. If there
are more configurations to list, IsTruncated is set to true,
and there will be a value in NextContinuationToken. You use
the NextContinuationToken value to continue the pagination of
the list by passing the value in continuation-token in the request to
GET the next page.
The S3 Intelligent-Tiering storage class is designed to optimize storage
costs by automatically moving data to the most cost-effective storage
access tier, without performance impact or operational overhead. S3
Intelligent-Tiering delivers automatic cost savings in three low latency
and high throughput access tiers. To get the lowest storage cost on data
that can be accessed in minutes to hours, you can choose to activate
additional archiving capabilities.
Lists the metrics configurations for the bucket. The metrics
configurations are only for the request metrics of the bucket and do not
provide information on daily storage metrics. You can have up to 1,000
configurations per bucket.
This action supports list pagination and does not return more than 100
configurations at a time. Always check the IsTruncated
element in the response. If there are no more configurations to list,
IsTruncated is set to false. If there are more configurations
to list, IsTruncated is set to true, and there is a value in
NextContinuationToken. You use the
NextContinuationToken value to continue the pagination of the
list by passing the value in continuation-token in the
request to GET the next page.
Returns a list of all Amazon S3 directory buckets owned by the
authenticated sender of the request. For more information about directory
buckets, see Directory
buckets in the Amazon S3 User Guide.
This operation lists in-progress multipart uploads in a bucket. An
in-progress multipart upload is a multipart upload that has been initiated
by the CreateMultipartUpload request, but has not yet been
completed or aborted.
The ListMultipartUploads operation returns a maximum of 1,000
multipart uploads in the response. The limit of 1,000 multipart uploads is
also the default value. You can further limit the number of uploads in a
response by specifying the max-uploads request parameter. If
there are more than 1,000 multipart uploads that satisfy your
ListMultipartUploads request, the response returns an
IsTruncated element with the value of true, a
NextKeyMarker element, and a NextUploadIdMarker
element. To list the remaining multipart uploads, you need to make
subsequent ListMultipartUploads requests. In these requests,
include two query parameters: key-marker and
upload-id-marker. Set the value of key-marker to
the NextKeyMarker value from the previous response.
Similarly, set the value of upload-id-marker to the
NextUploadIdMarker value from the previous response.
For more information about multipart uploads, see Uploading
Objects Using Multipart Upload in the Amazon S3 User Guide.
Returns some or all (up to 1,000) of the objects in a bucket with each
request. You can use the request parameters as selection criteria to
return a subset of the objects in a bucket. A 200 OK response
can contain valid or invalid XML. Make sure to design your application to
parse the contents of the response and handle it appropriately. For more
information about listing objects, see Listing
object keys programmatically in the Amazon S3 User Guide. To
get a list of your buckets, see ListBuckets.
Sets the attribute-based access control (ABAC) property of the general
purpose bucket. You must have s3:PutBucketABAC permission to
perform this action. When you enable ABAC, you can use tags for access
control on your buckets. Additionally, when ABAC is enabled, you must use
the TagResource
and UntagResource
actions to manage tags on your buckets. You can nolonger use the PutBucketTagging
and DeleteBucketTagging
actions to tag your bucket. For more information, see Enabling
ABAC in general purpose buckets.
You can choose to have storage class analysis export analysis reports sent
to a comma-separated values (CSV) flat file. See the
DataExport request element. Reports are updated daily and are
based on the object filters that you configure. When selecting data
export, you specify a destination bucket and an optional destination
prefix where the file is written. You can export the data to a destination
bucket in a different account. However, the destination bucket must be in
the same Region as the bucket that you are making the PUT analytics
configuration to. For more information, see Amazon
S3 Analytics – Storage Class Analysis.
To use this operation, you must have permissions to perform the
s3:PutAnalyticsConfiguration action. The bucket owner has
this permission by default. The bucket owner can grant this permission to
others. For more information about permissions, see Permissions
Related to Bucket Subresource Operations and Managing
Access Permissions to Your Amazon S3 Resources.
This operation configures default encryption and Amazon S3 Bucket Keys for
an existing bucket. You can also block
encryption types using this operation.
By default, all buckets have a default encryption configuration that uses
server-side encryption with Amazon S3 managed keys (SSE-S3).
The S3 Intelligent-Tiering storage class is designed to optimize storage
costs by automatically moving data to the most cost-effective storage
access tier, without performance impact or operational overhead. S3
Intelligent-Tiering delivers automatic cost savings in three low latency
and high throughput access tiers. To get the lowest storage cost on data
that can be accessed in minutes to hours, you can choose to activate
additional archiving capabilities.
This implementation of the PUT action adds an S3 Inventory
configuration (identified by the inventory ID) to the bucket. You can have
up to 1,000 inventory configurations per bucket.
Creates a new lifecycle configuration for the bucket or replaces an
existing lifecycle configuration. Keep in mind that this will overwrite an
existing lifecycle configuration, so if you want to retain any
configuration details, they must be included in the new lifecycle
configuration. For information about lifecycle configuration, see Managing
your storage lifecycle.
Sets a metrics configuration (specified by the metrics configuration ID)
for the bucket. You can have up to 1,000 metrics configurations per
bucket. If you're updating an existing metrics configuration, note that
this is a full replacement of the existing metrics configuration. If you
don't include the elements you want to keep, they are erased.
Renames an existing object in a directory bucket that uses the S3 Express
One Zone storage class. You can use RenameObject by
specifying an existing object’s name as the source and the new name of the
object as the destination within the same directory bucket.
To prevent overwriting an object, you can use the
If-None-Match conditional header.
Enables or disables a live inventory table for an S3 Metadata
configuration on a general purpose bucket. For more information, see Accelerating
data discovery with S3 Metadata in the Amazon S3 User Guide.
Enables or disables journal table record expiration for an S3 Metadata
configuration on a general purpose bucket. For more information, see Accelerating
data discovery with S3 Metadata in the Amazon S3 User Guide.
Uploads a part in a multipart upload.
You must initiate a multipart upload (see CreateMultipartUpload)
before you can upload any part. In response to your initiate request,
Amazon S3 returns an upload ID, a unique identifier that you must include
in your upload part request.
Uploads a part by copying data from an existing object as data source. To
specify the data source, you add the request header
x-amz-copy-source in your request. To specify a byte range,
you add the request header x-amz-copy-source-range in your
request.