deleteBucketCors method
Deletes the
cors configuration information set for the
bucket.
To use this operation, you must have permission to perform the
s3:PutBucketCORS action. The bucket owner has this permission
by default and can grant this permission to others.
For information about cors, see Enabling
Cross-Origin Resource Sharing in the Amazon S3 User Guide.
Related Resources
Parameter bucket :
Specifies the bucket whose cors configuration is being
deleted.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deleteBucketCors({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?cors',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}