deleteBucketLifecycle method
Deletes the lifecycle configuration from the specified bucket. Amazon S3 removes all the lifecycle configuration rules in the lifecycle subresource associated with the bucket. Your objects never expire, and Amazon S3 no longer automatically deletes any objects on the basis of rules contained in the deleted lifecycle configuration.
- Permissions
-
-
General purpose bucket permissions - By default, all Amazon S3
resources are private, including buckets, objects, and related
subresources (for example, lifecycle configuration and website
configuration). Only the resource owner (that is, the Amazon Web Services
account that created it) can access the resource. The resource owner can
optionally grant access permissions to others by writing an access policy.
For this operation, a user must have the
s3:PutLifecycleConfigurationpermission.For more information about permissions, see Managing Access Permissions to Your Amazon S3 Resources.
-
Directory bucket permissions - You must have the
s3express:PutLifecycleConfigurationpermission in an IAM identity-based policy to use this operation. Cross-account access to this API operation isn't supported. The resource owner can optionally grant access permissions to others by creating a role or user for them as long as they are within the same account as the owner and resource.For more information about directory bucket policies and permissions, see Authorizing Regional endpoint APIs with IAM in the Amazon S3 User Guide.
-
General purpose bucket permissions - By default, all Amazon S3
resources are private, including buckets, objects, and related
subresources (for example, lifecycle configuration and website
configuration). Only the resource owner (that is, the Amazon Web Services
account that created it) can access the resource. The resource owner can
optionally grant access permissions to others by writing an access policy.
For this operation, a user must have the
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region.amazonaws.com.
Related actions include:
Parameter bucket :
The bucket name of the lifecycle to delete.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deleteBucketLifecycle({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?lifecycle',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}