deleteBucketPolicy method
Deletes the policy of a specified bucket.
- Permissions
-
If you are using an identity other than the root user of the Amazon Web
Services account that owns the bucket, the calling identity must both have
the
DeleteBucketPolicypermissions on the specified bucket and belong to the bucket owner's account in order to use this operation.If you don't have
DeleteBucketPolicypermissions, Amazon S3 returns a403 Access Deniederror. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a405 Method Not Allowederror.-
General purpose bucket permissions - The
s3:DeleteBucketPolicypermission is required in a policy. For more information about general purpose buckets bucket policies, see Using Bucket Policies and User Policies in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation, you must have the
s3express:DeleteBucketPolicypermission in an IAM identity-based policy instead of a bucket policy. Cross-account access to this API operation isn't supported. This operation can only be performed by the Amazon Web Services account that owns the resource. For more information about directory bucket policies and permissions, see Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone in the Amazon S3 User Guide.
-
General purpose bucket permissions - The
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region-code.amazonaws.com.
DeleteBucketPolicy
Parameter bucket :
The bucket name.
Directory buckets - When you use this operation with a directory
bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name
. Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local Zone).
Bucket names must also follow the format
bucket-base-name--zone-id--x-s3 (for example,
DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deleteBucketPolicy({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?policy',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}