deleteBucketTagging method
Deletes tags from the general purpose bucket if attribute based access
control (ABAC) is not enabled for the bucket. When you enable
ABAC for a general purpose bucket, you can no longer use this
operation for that bucket and must use UntagResource
instead.
To use this operation, you must have permission to perform the
s3:PutBucketTagging action. By default, the bucket owner has
this permission and can grant this permission to others.
The following operations are related to DeleteBucketTagging:
Parameter bucket :
The bucket that has the tag set to be removed.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deleteBucketTagging({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?tagging',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}