deleteObject method
Removes an object from a bucket. The behavior depends on the bucket's versioning state:
- If bucket versioning is not enabled, the operation permanently deletes the object.
-
If bucket versioning is enabled, the operation inserts a delete marker,
which becomes the current version of the object. To permanently delete an
object in a versioned bucket, you must include the object’s
versionIdin the request. For more information about versioning-enabled buckets, see Deleting object versions from a versioning-enabled bucket. -
If bucket versioning is suspended, the operation removes the object that
has a null
versionId, if there is one, and inserts a delete marker that becomes the current version of the object. If there isn't an object with a nullversionId, and all versions of the object have aversionId, Amazon S3 does not remove the object and only inserts a delete marker. To permanently delete an object that has aversionId, you must include the object’sversionIdin the request. For more information about versioning-suspended buckets, see Deleting objects from versioning-suspended buckets.
versionId
query parameter. Using this query parameter permanently deletes the
version. If the object deleted is a delete marker, Amazon S3 sets the
response header x-amz-delete-marker to true.
If the object you want to delete is in a bucket where the bucket
versioning configuration is MFA Delete enabled, you must include the
x-amz-mfa request header in the DELETE versionId
request. Requests that include x-amz-mfa must use HTTPS. For
more information about MFA Delete, see Using
MFA Delete in the Amazon S3 User Guide. To see sample requests
that use versioning, see Sample
Request.
You can delete objects by explicitly calling DELETE Object or calling (PutBucketLifecycle)
to enable Amazon S3 to remove them for you. If you want to block users or
accounts from removing or deleting objects from your bucket, you must deny
them the s3:DeleteObject,
s3:DeleteObjectVersion, and
s3:PutLifeCycleConfiguration actions.
- Permissions
-
-
General purpose bucket permissions - The following permissions are
required in your policies when your
DeleteObjectsrequest includes specific headers.-
s3:DeleteObject- To delete an object from a bucket, you must always have thes3:DeleteObjectpermission. -
s3:DeleteObjectVersion- To delete a specific version of an object from a versioning-enabled bucket, you must have thes3:DeleteObjectVersionpermission.
-
-
Directory bucket permissions - To grant access to this API
operation on a directory bucket, we recommend that you use the
CreateSessionAPI operation for session-based authorization. Specifically, you grant thes3express:CreateSessionpermission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make theCreateSessionAPI call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make anotherCreateSessionAPI call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, seeCreateSession.
-
General purpose bucket permissions - The following permissions are
required in your policies when your
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
DeleteObject:
Parameter bucket :
The bucket name of the bucket containing the object.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter key :
Key name of the object to delete.
Parameter bypassGovernanceRetention :
Indicates whether S3 Object Lock should bypass Governance-mode
restrictions to process this operation. To use this header, you must have
the s3:BypassGovernanceRetention permission.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter ifMatch :
Deletes the object if the ETag (entity tag) value provided during the
delete operation matches the ETag of the object in S3. If the ETag values
do not match, the operation returns a 412 Precondition Failed
error.
Expects the ETag value as a string. If-Match does accept a
string value of an '*' (asterisk) character to denote a match of any ETag.
For more information about conditional requests, see RFC 7232.
Parameter ifMatchLastModifiedTime :
If present, the object is deleted only if its modification times matches
the provided Timestamp. If the Timestamp values
do not match, the operation returns a 412 Precondition Failed
error. If the Timestamp matches or if the object doesn’t
exist, the operation returns a 204 Success (No Content)
response.
Parameter ifMatchSize :
If present, the object is deleted only if its size matches the provided
size in bytes. If the Size value does not match, the
operation returns a 412 Precondition Failed error. If the
Size matches or if the object doesn’t exist, the operation
returns a 204 Success (No Content) response.
Parameter mfa :
The concatenation of the authentication device's serial number, a space,
and the value that is displayed on your authentication device. Required to
permanently delete a versioned object if versioning is configured with MFA
delete enabled.
Parameter versionId :
Version ID used to reference a specific version of the object.
Implementation
Future<DeleteObjectOutput> deleteObject({
required String bucket,
required String key,
bool? bypassGovernanceRetention,
String? expectedBucketOwner,
String? ifMatch,
DateTime? ifMatchLastModifiedTime,
int? ifMatchSize,
String? mfa,
RequestPayer? requestPayer,
String? versionId,
}) async {
final headers = <String, String>{
if (bypassGovernanceRetention != null)
'x-amz-bypass-governance-retention':
bypassGovernanceRetention.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (ifMatch != null) 'If-Match': ifMatch.toString(),
if (ifMatchLastModifiedTime != null)
'x-amz-if-match-last-modified-time':
_s.rfc822ToJson(ifMatchLastModifiedTime),
if (ifMatchSize != null) 'x-amz-if-match-size': ifMatchSize.toString(),
if (mfa != null) 'x-amz-mfa': mfa.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (versionId != null) 'versionId': [versionId],
};
final $result = await _protocol.sendRaw(
method: 'DELETE',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?x-id=DeleteObject',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return DeleteObjectOutput(
deleteMarker:
_s.extractHeaderBoolValue($result.headers, 'x-amz-delete-marker'),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
versionId:
_s.extractHeaderStringValue($result.headers, 'x-amz-version-id'),
);
}