deletePublicAccessBlock method
Removes the
PublicAccessBlock configuration for an Amazon S3
bucket. This operation removes the bucket-level configuration only. The
effective public access behavior will still be governed by account-level
settings (which may inherit from organization-level policies). To use this
operation, you must have the s3:PutBucketPublicAccessBlock
permission. For more information about permissions, see Permissions
Related to Bucket Subresource Operations and Managing
Access Permissions to Your Amazon S3 Resources.
The following operations are related to
DeletePublicAccessBlock:
Parameter bucket :
The Amazon S3 bucket whose PublicAccessBlock configuration
you want to delete.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> deletePublicAccessBlock({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/${Uri.encodeComponent(bucket)}?publicAccessBlock',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}