getBucketCors method
To use this operation, you must have permission to perform the
s3:GetBucketCORS action. By default, the bucket owner has
this permission and can grant it to others.
When you use this API operation with an access point, provide the alias of the access point in place of the bucket name.
When you use this API operation with an Object Lambda access point,
provide the alias of the Object Lambda access point in place of the bucket
name. If the Object Lambda access point alias in a request is not valid,
the error code InvalidAccessPointAliasError is returned. For
more information about InvalidAccessPointAliasError, see List
of Error Codes.
For more information about CORS, see Enabling Cross-Origin Resource Sharing.
The following operations are related to GetBucketCors:
Parameter bucket :
The bucket name for which to get the cors configuration.
When you use this API operation with an access point, provide the alias of the access point in place of the bucket name.
When you use this API operation with an Object Lambda access point,
provide the alias of the Object Lambda access point in place of the bucket
name. If the Object Lambda access point alias in a request is not valid,
the error code InvalidAccessPointAliasError is returned. For
more information about InvalidAccessPointAliasError, see List
of Error Codes.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<GetBucketCorsOutput> getBucketCors({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/${Uri.encodeComponent(bucket)}?cors',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetBucketCorsOutput.fromXml($result.body);
}