getBucketLifecycleConfiguration method
Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management.
Bucket lifecycle configuration now supports specifying a lifecycle rule using an object key name prefix, one or more object tags, object size, or any combination of these. Accordingly, this section describes the latest API, which is compatible with the new functionality. The previous version of the API supported filtering based only on an object key name prefix, which is supported for general purpose buckets for backward compatibility. For the related API description, see GetBucketLifecycle.
- Permissions
-
-
General purpose bucket permissions - By default, all Amazon S3
resources are private, including buckets, objects, and related
subresources (for example, lifecycle configuration and website
configuration). Only the resource owner (that is, the Amazon Web Services
account that created it) can access the resource. The resource owner can
optionally grant access permissions to others by writing an access policy.
For this operation, a user must have the
s3:GetLifecycleConfigurationpermission.For more information about permissions, see Managing Access Permissions to Your Amazon S3 Resources.
-
Directory bucket permissions - You must have the
s3express:GetLifecycleConfigurationpermission in an IAM identity-based policy to use this operation. Cross-account access to this API operation isn't supported. The resource owner can optionally grant access permissions to others by creating a role or user for them as long as they are within the same account as the owner and resource.For more information about directory bucket policies and permissions, see Authorizing Regional endpoint APIs with IAM in the Amazon S3 User Guide.
-
General purpose bucket permissions - By default, all Amazon S3
resources are private, including buckets, objects, and related
subresources (for example, lifecycle configuration and website
configuration). Only the resource owner (that is, the Amazon Web Services
account that created it) can access the resource. The resource owner can
optionally grant access permissions to others by writing an access policy.
For this operation, a user must have the
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region.amazonaws.com.
GetBucketLifecycleConfiguration has the following special
error:
-
Error code:
NoSuchLifecycleConfiguration- Description: The lifecycle configuration does not exist.
- HTTP Status Code: 404 Not Found
- SOAP Fault Code Prefix: Client
GetBucketLifecycleConfiguration:
Parameter bucket :
The name of the bucket for which to get the lifecycle information.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<GetBucketLifecycleConfigurationOutput>
getBucketLifecycleConfiguration({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/${Uri.encodeComponent(bucket)}?lifecycle',
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return GetBucketLifecycleConfigurationOutput(
rules: $elem.findElements('Rule').map(LifecycleRule.fromXml).toList(),
transitionDefaultMinimumObjectSize: _s
.extractHeaderStringValue(
$result.headers, 'x-amz-transition-default-minimum-object-size')
?.let(TransitionDefaultMinimumObjectSize.fromString),
);
}