getBucketWebsite method
Returns the website configuration for a bucket. To host website on Amazon
S3, you can configure a bucket as website by adding a website
configuration. For more information about hosting websites, see Hosting
Websites on Amazon S3.
This GET action requires the S3:GetBucketWebsite permission.
By default, only the bucket owner can read the bucket website
configuration. However, bucket owners can allow other users to read the
website configuration by writing a bucket policy granting them the
S3:GetBucketWebsite permission.
The following operations are related to GetBucketWebsite:
Parameter bucket :
The bucket name for which to get the website configuration.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<GetBucketWebsiteOutput> getBucketWebsite({
required String bucket,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/${Uri.encodeComponent(bucket)}?website',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetBucketWebsiteOutput.fromXml($result.body);
}