listBucketInventoryConfigurations method
Returns a list of S3 Inventory configurations for the bucket. You can have up to 1,000 inventory configurations per bucket.
This action supports list pagination and does not return more than 100
configurations at a time. Always check the IsTruncated
element in the response. If there are no more configurations to list,
IsTruncated is set to false. If there are more configurations
to list, IsTruncated is set to true, and there is a value in
NextContinuationToken. You use the
NextContinuationToken value to continue the pagination of the
list by passing the value in continuation-token in the request to
GET the next page.
- Permissions
-
To use this operation, you must have permissions to perform the
s3:GetInventoryConfigurationaction. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.-
General purpose bucket permissions - The
s3:GetInventoryConfigurationpermission is required in a policy. For more information about general purpose buckets permissions, see Using Bucket Policies and User Policies in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation, you must have the
s3express:GetInventoryConfigurationpermission in an IAM identity-based policy instead of a bucket policy. For more information about directory bucket policies and permissions, see Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone in the Amazon S3 User Guide.
-
General purpose bucket permissions - The
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region-code.amazonaws.com.
The following operations are related to
ListBucketInventoryConfigurations:
Parameter bucket :
The name of the bucket containing the inventory configurations to
retrieve.
Directory buckets - When you use this operation with a directory
bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name
. Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local Zone).
Bucket names must also follow the format
bucket-base-name--zone-id--x-s3 (for example,
DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide
Parameter continuationToken :
The marker used to continue an inventory configuration listing that has
been truncated. Use the NextContinuationToken from a
previously truncated list response to continue the listing. The
continuation token is an opaque value that Amazon S3 understands.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<ListBucketInventoryConfigurationsOutput>
listBucketInventoryConfigurations({
required String bucket,
String? continuationToken,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $query = <String, List<String>>{
if (continuationToken != null) 'continuation-token': [continuationToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/${Uri.encodeComponent(bucket)}?inventory&x-id=ListBucketInventoryConfigurations',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListBucketInventoryConfigurationsOutput.fromXml($result.body);
}