listObjectsV2 method
Returns some or all (up to 1,000) of the objects in a bucket with each
request. You can use the request parameters as selection criteria to
return a subset of the objects in a bucket. A 200 OK response
can contain valid or invalid XML. Make sure to design your application to
parse the contents of the response and handle it appropriately. For more
information about listing objects, see Listing
object keys programmatically in the Amazon S3 User Guide. To
get a list of your buckets, see ListBuckets.
-
General purpose bucket - For general purpose buckets,
ListObjectsV2doesn't return prefixes that are related only to in-progress multipart uploads. -
Directory buckets - For directory buckets,
ListObjectsV2response includes the prefixes that are related only to in-progress multipart uploads. -
Directory buckets - For directory buckets, you must make requests
for this API operation to the Zonal endpoint. These endpoints support
virtual-hosted-style requests in the format
https://amzn-s3-demo-bucket.s3express-zone-id.region-code.amazonaws.com/key-name. Path-style requests are not supported. For more information about endpoints in Availability Zones, see Regional and Zonal endpoints for directory buckets in Availability Zones in the Amazon S3 User Guide. For more information about endpoints in Local Zones, see Concepts for directory buckets in Local Zones in the Amazon S3 User Guide.
- Permissions
-
-
General purpose bucket permissions - To use this operation, you
must have READ access to the bucket. You must have permission to perform
the
s3:ListBucketaction. The bucket owner has this permission by default and can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation on a directory bucket, we recommend that you use the
CreateSessionAPI operation for session-based authorization. Specifically, you grant thes3express:CreateSessionpermission to the directory bucket in a bucket policy or an IAM identity-based policy. Then, you make theCreateSessionAPI call on the bucket to obtain a session token. With the session token in your request header, you can make API requests to this operation. After the session token expires, you make anotherCreateSessionAPI call to generate a new session token for use. Amazon Web Services CLI or SDKs create session and refresh the session token automatically to avoid service interruptions when a session expires. For more information about authorization, seeCreateSession.
-
General purpose bucket permissions - To use this operation, you
must have READ access to the bucket. You must have permission to perform
the
- Sorting order of returned objects
-
-
General purpose bucket - For general purpose buckets,
ListObjectsV2returns objects in lexicographical order based on their key names. -
Directory bucket - For directory buckets,
ListObjectsV2does not return objects in lexicographical order.
-
General purpose bucket - For general purpose buckets,
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
ListObjectsV2:
May throw NoSuchBucket.
Parameter bucket :
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter continuationToken :
ContinuationToken indicates to Amazon S3 that the list is
being continued on this bucket with a token.
ContinuationToken is obfuscated and is not a real key. You
can use this ContinuationToken for pagination of the list
results.
Parameter delimiter :
A delimiter is a character that you use to group keys.
CommonPrefixes is filtered out from results if it is not
lexicographically greater than the StartAfter value.
-
Directory buckets - For directory buckets,
/is the only supported delimiter. -
Directory buckets - When you query
ListObjectsV2with a delimiter during in-progress multipart uploads, theCommonPrefixesresponse parameter contains the prefixes that are associated with the in-progress multipart uploads. For more information about multipart uploads, see Multipart Upload Overview in the Amazon S3 User Guide.
Parameter encodingType :
Encoding type used by Amazon S3 to encode the object
keys in the response. Responses are encoded only in UTF-8. An object
key can contain any Unicode character. However, the XML 1.0 parser can't
parse certain characters, such as characters with an ASCII value from 0 to
10. For characters that aren't supported in XML 1.0, you can add this
parameter to request that Amazon S3 encode the keys in the response. For
more information about characters to avoid in object key names, see Object
key naming guidelines.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter fetchOwner :
The owner field is not present in ListObjectsV2 by default.
If you want to return the owner field with each key in the result, then
set the FetchOwner field to true.
Parameter maxKeys :
Sets the maximum number of keys returned in the response. By default, the
action returns up to 1,000 key names. The response might contain fewer
keys but will never contain more.
Parameter optionalObjectAttributes :
Specifies the optional fields that you want returned in the response.
Fields that you do not specify are not returned.
Parameter prefix :
Limits the response to keys that begin with the specified prefix.
Parameter requestPayer :
Confirms that the requester knows that she or he will be charged for the
list objects request in V2 style. Bucket owners need not specify this
parameter in their requests.
Parameter startAfter :
StartAfter is where you want Amazon S3 to start listing from. Amazon S3
starts listing after this specified key. StartAfter can be any key in the
bucket.
Implementation
Future<ListObjectsV2Output> listObjectsV2({
required String bucket,
String? continuationToken,
String? delimiter,
EncodingType? encodingType,
String? expectedBucketOwner,
bool? fetchOwner,
int? maxKeys,
List<OptionalObjectAttributes>? optionalObjectAttributes,
String? prefix,
RequestPayer? requestPayer,
String? startAfter,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (optionalObjectAttributes != null)
'x-amz-optional-object-attributes':
optionalObjectAttributes.map((e) => e.value).join(', '),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
};
final $query = <String, List<String>>{
if (continuationToken != null) 'continuation-token': [continuationToken],
if (delimiter != null) 'delimiter': [delimiter],
if (encodingType != null) 'encoding-type': [encodingType.value],
if (fetchOwner != null) 'fetch-owner': [fetchOwner.toString()],
if (maxKeys != null) 'max-keys': [maxKeys.toString()],
if (prefix != null) 'prefix': [prefix],
if (startAfter != null) 'start-after': [startAfter],
};
final $result = await _protocol.sendRaw(
method: 'GET',
requestUri: '/${Uri.encodeComponent(bucket)}?list-type=2',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return ListObjectsV2Output(
commonPrefixes: $elem
.findElements('CommonPrefixes')
.map(CommonPrefix.fromXml)
.toList(),
contents: $elem.findElements('Contents').map(Object.fromXml).toList(),
continuationToken: _s.extractXmlStringValue($elem, 'ContinuationToken'),
delimiter: _s.extractXmlStringValue($elem, 'Delimiter'),
encodingType: _s
.extractXmlStringValue($elem, 'EncodingType')
?.let(EncodingType.fromString),
isTruncated: _s.extractXmlBoolValue($elem, 'IsTruncated'),
keyCount: _s.extractXmlIntValue($elem, 'KeyCount'),
maxKeys: _s.extractXmlIntValue($elem, 'MaxKeys'),
name: _s.extractXmlStringValue($elem, 'Name'),
nextContinuationToken:
_s.extractXmlStringValue($elem, 'NextContinuationToken'),
prefix: _s.extractXmlStringValue($elem, 'Prefix'),
startAfter: _s.extractXmlStringValue($elem, 'StartAfter'),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
);
}