putBucketMetricsConfiguration method
Sets a metrics configuration (specified by the metrics configuration ID) for the bucket. You can have up to 1,000 metrics configurations per bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased.
- Permissions
-
To use this operation, you must have permissions to perform the
s3:PutMetricsConfigurationaction. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.-
General purpose bucket permissions - The
s3:PutMetricsConfigurationpermission is required in a policy. For more information about general purpose buckets permissions, see Using Bucket Policies and User Policies in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation, you must have the
s3express:PutMetricsConfigurationpermission in an IAM identity-based policy instead of a bucket policy. Cross-account access to this API operation isn't supported. This operation can only be performed by the Amazon Web Services account that owns the resource. For more information about directory bucket policies and permissions, see Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone in the Amazon S3 User Guide.
-
General purpose bucket permissions - The
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region-code.amazonaws.com.
The following operations are related to
PutBucketMetricsConfiguration:
PutBucketMetricsConfiguration has the following special
error:
-
Error code:
TooManyConfigurations- Description: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.
- HTTP Status Code: HTTP 400 Bad Request
Parameter bucket :
The name of the bucket for which the metrics configuration is set.
Directory buckets - When you use this operation with a directory
bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name
. Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local Zone).
Bucket names must also follow the format
bucket-base-name--zone-id--x-s3 (for example,
DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide
Parameter id :
The ID used to identify the metrics configuration. The ID has a 64
character limit and can only contain letters, numbers, periods, dashes,
and underscores.
Parameter metricsConfiguration :
Specifies the metrics configuration.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketMetricsConfiguration({
required String bucket,
required String id,
required MetricsConfiguration metricsConfiguration,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
final $query = <String, List<String>>{
'id': [id],
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?metrics',
queryParams: $query,
headers: headers,
payload: metricsConfiguration.toXml('MetricsConfiguration'),
exceptionFnMap: _exceptionFns,
);
}