putBucketNotificationConfiguration method
Using this API, you can replace an existing notification configuration. The configuration is an XML file that defines the event types that you want Amazon S3 to publish and the destination where you want Amazon S3 to publish an event notification when it detects an event of the specified type.
By default, your bucket has no event notifications configured. That is,
the notification configuration will be an empty
NotificationConfiguration.
This action replaces the existing notification configuration with the configuration you include in the request body.
After Amazon S3 receives this request, it first verifies that any Amazon Simple Notification Service (Amazon SNS) or Amazon Simple Queue Service (Amazon SQS) destination exists, and that the bucket owner has permission to publish to it by sending a test notification. In the case of Lambda destinations, Amazon S3 verifies that the Lambda function permissions grant Amazon S3 permission to invoke the function from the Amazon S3 bucket. For more information, see Configuring Notifications for Amazon S3 Events.
You can disable notifications by adding the empty NotificationConfiguration element.
For more information about the number of event notification configurations that you can create per bucket, see Amazon S3 service quotas in Amazon Web Services General Reference.
By default, only the bucket owner can configure notifications on a bucket.
However, bucket owners can use a bucket policy to grant permission to
other users to set this configuration with the required
s3:PutBucketNotification permission.
If the configuration in the request body includes only one
TopicConfiguration specifying only the
s3:ReducedRedundancyLostObject event type, the response will
also include the x-amz-sns-test-message-id header containing
the message ID of the test notification sent to the topic.
The following action is related to
PutBucketNotificationConfiguration:
Parameter bucket :
The name of the bucket.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter skipDestinationValidation :
Skips validation of Amazon SQS, Amazon SNS, and Lambda destinations. True
or false value.
Implementation
Future<void> putBucketNotificationConfiguration({
required String bucket,
required NotificationConfiguration notificationConfiguration,
String? expectedBucketOwner,
bool? skipDestinationValidation,
}) async {
final headers = <String, String>{
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (skipDestinationValidation != null)
'x-amz-skip-destination-validation':
skipDestinationValidation.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?notification',
headers: headers,
payload: notificationConfiguration.toXml('NotificationConfiguration'),
exceptionFnMap: _exceptionFns,
);
}