putBucketOwnershipControls method
OwnershipControls for an Amazon S3
bucket. To use this operation, you must have the
s3:PutBucketOwnershipControls permission. For more
information about Amazon S3 permissions, see Specifying
permissions in a policy.
For information about Amazon S3 Object Ownership, see Using object ownership.
The following operations are related to
PutBucketOwnershipControls:
Parameter bucket :
The name of the Amazon S3 bucket whose OwnershipControls you
want to set.
Parameter ownershipControls :
The OwnershipControls (BucketOwnerEnforced,
BucketOwnerPreferred, or ObjectWriter) that you want to apply to this
Amazon S3 bucket.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum-algorithm header sent.
Otherwise, Amazon S3 fails the request with the HTTP status code 400
Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash of the OwnershipControls request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketOwnershipControls({
required String bucket,
required OwnershipControls ownershipControls,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?ownershipControls',
headers: headers,
payload: ownershipControls.toXml('OwnershipControls'),
exceptionFnMap: _exceptionFns,
);
}