putBucketPolicy method
Applies an Amazon S3 bucket policy to an Amazon S3 bucket.
- Permissions
-
If you are using an identity other than the root user of the Amazon Web
Services account that owns the bucket, the calling identity must both have
the
PutBucketPolicypermissions on the specified bucket and belong to the bucket owner's account in order to use this operation.If you don't have
PutBucketPolicypermissions, Amazon S3 returns a403 Access Deniederror. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a405 Method Not Allowederror.-
General purpose bucket permissions - The
s3:PutBucketPolicypermission is required in a policy. For more information about general purpose buckets bucket policies, see Using Bucket Policies and User Policies in the Amazon S3 User Guide. -
Directory bucket permissions - To grant access to this API
operation, you must have the
s3express:PutBucketPolicypermission in an IAM identity-based policy instead of a bucket policy. Cross-account access to this API operation isn't supported. This operation can only be performed by the Amazon Web Services account that owns the resource. For more information about directory bucket policies and permissions, see Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone in the Amazon S3 User Guide.
-
General purpose bucket permissions - The
- Example bucket policies
-
General purpose buckets example bucket policies - See Bucket
policy examples in the Amazon S3 User Guide.
Directory bucket example bucket policies - See Example bucket policies for S3 Express One Zone in the Amazon S3 User Guide.
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region-code.amazonaws.com.
PutBucketPolicy:
Parameter bucket :
The name of the bucket.
Directory buckets - When you use this operation with a directory
bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name
. Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local Zone).
Bucket names must also follow the format
bucket-base-name--zone-id--x-s3 (for example,
DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide
Parameter policy :
The bucket policy as a JSON document.
For directory buckets, the only IAM action supported in the bucket policy
is s3express:CreateSession.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the request when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum-algorithm or
x-amz-trailer header sent. Otherwise, Amazon S3 fails the
request with the HTTP status code 400 Bad Request.
For the x-amz-checksum-algorithm header, replace
algorithm with the supported algorithm from the
following list:
-
CRC32 -
CRC32C -
CRC64NVME -
MD5 -
SHA1 -
SHA256 -
SHA512 -
XXHASH3 -
XXHASH64 -
XXHASH128
If the individual checksum value you provide through
x-amz-checksum-algorithm doesn't match the checksum
algorithm you set through x-amz-sdk-checksum-algorithm,
Amazon S3 fails the request with a BadDigest error.
Parameter confirmRemoveSelfBucketAccess :
Set this parameter to true to confirm that you want to remove your
permissions to change this bucket policy in the future.
Parameter contentMD5 :
The MD5 hash of the request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketPolicy({
required String bucket,
required String policy,
ChecksumAlgorithm? checksumAlgorithm,
bool? confirmRemoveSelfBucketAccess,
String? contentMD5,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (confirmRemoveSelfBucketAccess != null)
'x-amz-confirm-remove-self-bucket-access':
confirmRemoveSelfBucketAccess.toString(),
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?policy',
headers: headers,
payload: policy,
exceptionFnMap: _exceptionFns,
);
}