putBucketReplication method
Specify the replication configuration in the request body. In the
replication configuration, you provide the name of the destination bucket
or buckets where you want Amazon S3 to replicate objects, the IAM role
that Amazon S3 can assume to replicate objects on your behalf, and other
relevant information. You can invoke this request for a specific Amazon
Web Services Region by using the
aws:RequestedRegion condition key.
A replication configuration must include at least one rule, and can contain a maximum of 1,000. Each rule identifies a subset of objects to replicate by filtering the objects in the source bucket. To choose additional subsets of objects to replicate, add a rule for each subset.
To specify a subset of the objects in the source bucket to apply a
replication rule to, add the Filter element as a child of the Rule
element. You can filter objects based on an object key prefix, one or more
object tags, or both. When you add the Filter element in the
configuration, you must also add the following elements:
DeleteMarkerReplication, Status, and
Priority.
For information about enabling versioning on a bucket, see Using
Versioning.
- Handling Replication of Encrypted Objects
-
By default, Amazon S3 doesn't replicate objects that are stored at rest
using server-side encryption with KMS keys. To replicate Amazon Web
Services KMS-encrypted objects, add the following:
SourceSelectionCriteria,SseKmsEncryptedObjects,Status,EncryptionConfiguration, andReplicaKmsKeyID. For information about replication configuration, see Replicating Objects Created with SSE Using KMS keys.For information on
PutBucketReplicationerrors, see List of replication-related error codes - Permissions
-
To create a
PutBucketReplicationrequest, you must haves3:PutReplicationConfigurationpermissions for the bucket.By default, a resource owner, in this case the Amazon Web Services account that created the bucket, can perform this operation. The resource owner can also grant others permissions to perform the operation. For more information about permissions, see Specifying Permissions in a Policy and Managing Access Permissions to Your Amazon S3 Resources.
PutBucketReplication:
Parameter bucket :
The name of the bucket
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the request when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The Base64 encoded 128-bit MD5 digest of the data. You must
use this header as a message integrity check to verify that the request
body was not corrupted in transit. For more information, see RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter token :
A token to allow Object Lock to be enabled for an existing bucket.
Implementation
Future<void> putBucketReplication({
required String bucket,
required ReplicationConfiguration replicationConfiguration,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
String? token,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (token != null) 'x-amz-bucket-object-lock-token': token.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?replication',
headers: headers,
payload: replicationConfiguration.toXml('ReplicationConfiguration'),
exceptionFnMap: _exceptionFns,
);
}