putBucketRequestPayment method
The following operations are related to
PutBucketRequestPayment:
Parameter bucket :
The bucket name.
Parameter requestPaymentConfiguration :
Container for Payer.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the request when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The Base64 encoded 128-bit MD5 digest of the data. You must
use this header as a message integrity check to verify that the request
body was not corrupted in transit. For more information, see RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putBucketRequestPayment({
required String bucket,
required RequestPaymentConfiguration requestPaymentConfiguration,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?requestPayment',
headers: headers,
payload: requestPaymentConfiguration.toXml('RequestPaymentConfiguration'),
exceptionFnMap: _exceptionFns,
);
}