putObjectLockConfiguration method
Parameter bucket :
The bucket whose Object Lock configuration you want to create or replace.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash for the request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Parameter objectLockConfiguration :
The Object Lock configuration that you want to apply to the specified
bucket.
Parameter token :
A token to allow Object Lock to be enabled for an existing bucket.
Implementation
Future<PutObjectLockConfigurationOutput> putObjectLockConfiguration({
required String bucket,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
ObjectLockConfiguration? objectLockConfiguration,
RequestPayer? requestPayer,
String? token,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
if (token != null) 'x-amz-bucket-object-lock-token': token.toString(),
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?object-lock',
headers: headers,
payload: objectLockConfiguration?.toXml('ObjectLockConfiguration'),
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return PutObjectLockConfigurationOutput(
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
);
}