putPublicAccessBlock method
PublicAccessBlock configuration for
an Amazon S3 bucket. To use this operation, you must have the
s3:PutBucketPublicAccessBlock permission. For more
information about Amazon S3 permissions, see Specifying
Permissions in a Policy.
For more information about when Amazon S3 considers a bucket or an object
public, see The
Meaning of "Public".
The following operations are related to PutPublicAccessBlock:
- GetPublicAccessBlock
- DeletePublicAccessBlock
- GetBucketPolicyStatus
- Using Amazon S3 Block Public Access
Parameter bucket :
The name of the Amazon S3 bucket whose PublicAccessBlock
configuration you want to set.
Parameter publicAccessBlockConfiguration :
The PublicAccessBlock configuration that you want to apply to
this Amazon S3 bucket. You can enable the configuration options in any
combination. For more information about when Amazon S3 considers a bucket
or object public, see The
Meaning of "Public" in the Amazon S3 User Guide.
Parameter checksumAlgorithm :
Indicates the algorithm used to create the checksum for the object when
you use the SDK. This header will not provide any additional functionality
if you don't use the SDK. When you send this header, there must be a
corresponding x-amz-checksum or x-amz-trailer
header sent. Otherwise, Amazon S3 fails the request with the HTTP status
code 400 Bad Request. For more information, see Checking
object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
Parameter contentMD5 :
The MD5 hash of the PutPublicAccessBlock request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Parameter expectedBucketOwner :
The account ID of the expected bucket owner. If the account ID that you
provide does not match the actual owner of the bucket, the request fails
with the HTTP status code 403 Forbidden (access denied).
Implementation
Future<void> putPublicAccessBlock({
required String bucket,
required PublicAccessBlockConfiguration publicAccessBlockConfiguration,
ChecksumAlgorithm? checksumAlgorithm,
String? contentMD5,
String? expectedBucketOwner,
}) async {
final headers = <String, String>{
if (checksumAlgorithm != null)
'x-amz-sdk-checksum-algorithm': checksumAlgorithm.value,
if (contentMD5 != null) 'Content-MD5': contentMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
};
await _protocol.send(
method: 'PUT',
requestUri: '/${Uri.encodeComponent(bucket)}?publicAccessBlock',
headers: headers,
payload: publicAccessBlockConfiguration
.toXml('PublicAccessBlockConfiguration'),
exceptionFnMap: _exceptionFns,
);
}