uploadPartCopy method
- required String bucket,
- required String copySource,
- required String key,
- required int partNumber,
- required String uploadId,
- String? copySourceIfMatch,
- DateTime? copySourceIfModifiedSince,
- String? copySourceIfNoneMatch,
- DateTime? copySourceIfUnmodifiedSince,
- String? copySourceRange,
- String? copySourceSSECustomerAlgorithm,
- String? copySourceSSECustomerKey,
- String? copySourceSSECustomerKeyMD5,
- String? expectedBucketOwner,
- String? expectedSourceBucketOwner,
- RequestPayer? requestPayer,
- String? sSECustomerAlgorithm,
- String? sSECustomerKey,
- String? sSECustomerKeyMD5,
Uploads a part by copying data from an existing object as data source. To
specify the data source, you add the request header
x-amz-copy-source in your request. To specify a byte range,
you add the request header x-amz-copy-source-range in your
request.
For information about maximum and minimum part sizes and other multipart upload specifications, see Multipart upload limits in the Amazon S3 User Guide. You must initiate a multipart upload before you can upload any part. In response to your initiate request, Amazon S3 returns the upload ID, a unique identifier that you must include in your upload part request.
For conceptual information about multipart uploads, see Uploading Objects Using Multipart Upload in the Amazon S3 User Guide. For information about copying objects using a single atomic action vs. a multipart upload, see Operations on Objects in the Amazon S3 User Guide.
- Authentication and authorization
-
All
UploadPartCopyrequests must be authenticated and signed by using IAM credentials (access key ID and secret access key for the IAM identities). All headers with thex-amz-prefix, includingx-amz-copy-source, must be signed. For more information, see REST Authentication.Directory buckets - You must use IAM credentials to authenticate and authorize your access to the
UploadPartCopyAPI operation, instead of using the temporary security credentials through theCreateSessionAPI operation.Amazon Web Services CLI or SDKs handles authentication and authorization on your behalf.
- Permissions
-
You must have
READaccess to the source object andWRITEaccess to the destination bucket.-
General purpose bucket permissions - You must have the permissions
in a policy based on the bucket types of your source bucket and
destination bucket in an
UploadPartCopyoperation.-
If the source object is in a general purpose bucket, you must have the
s3:GetObjectpermission to read the source object that is being copied. -
If the destination bucket is a general purpose bucket, you must have the
s3:PutObjectpermission to write the object copy to the destination bucket. -
To perform a multipart upload with encryption using an Key Management
Service key, the requester must have permission to the
kms:Decryptandkms:GenerateDataKeyactions on the key. The requester must also have permissions for thekms:GenerateDataKeyaction for theCreateMultipartUploadAPI. Then, the requester needs permissions for thekms:Decryptaction on theUploadPartandUploadPartCopyAPIs. These permissions are required because Amazon S3 must decrypt and read data from the encrypted file parts before it completes the multipart upload. For more information about KMS permissions, see Protecting data using server-side encryption with KMS in the Amazon S3 User Guide. For information about the permissions required to use the multipart upload API, see Multipart upload and permissions and Multipart upload API and permissions in the Amazon S3 User Guide.
-
If the source object is in a general purpose bucket, you must have the
-
Directory bucket permissions - You must have permissions in a
bucket policy or an IAM identity-based policy based on the source and
destination bucket types in an
UploadPartCopyoperation.-
If the source object that you want to copy is in a directory bucket, you
must have the
s3express:CreateSessionpermission in theActionelement of a policy to read the object. If no session mode is specified, the session will be created with the maximum allowable privilege, attemptingReadWritefirst, thenReadOnlyifReadWriteis not permitted. If you want to explicitly restrict the access to be read-only, you can set thes3express:SessionModecondition key toReadOnlyon the copy source bucket. -
If the copy destination is a directory bucket, you must have the
s3express:CreateSessionpermission in theActionelement of a policy to write the object to the destination. Thes3express:SessionModecondition key cannot be set toReadOnlyon the copy destination.
kms:GenerateDataKeyandkms:Decryptpermissions in IAM identity-based policies and KMS key policies for the KMS key.For example policies, see Example bucket policies for S3 Express One Zone and Amazon Web Services Identity and Access Management (IAM) identity-based policies for S3 Express One Zone in the Amazon S3 User Guide.
-
If the source object that you want to copy is in a directory bucket, you
must have the
-
General purpose bucket permissions - You must have the permissions
in a policy based on the bucket types of your source bucket and
destination bucket in an
- Encryption
-
-
General purpose buckets - For information about using server-side
encryption with customer-provided encryption keys with the
UploadPartCopyoperation, see CopyObject and UploadPart. -
Directory buckets - For directory buckets, there are only two
supported options for server-side encryption: server-side encryption with
Amazon S3 managed keys (SSE-S3) (
AES256) and server-side encryption with KMS keys (SSE-KMS) (aws:kms). For more information, see Protecting data with server-side encryption in the Amazon S3 User Guide. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through UploadPartCopy. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
-
General purpose buckets - For information about using server-side
encryption with customer-provided encryption keys with the
- Special errors
-
-
Error Code:
NoSuchUpload- Description: The specified multipart upload does not exist. The upload ID might be invalid, or the multipart upload might have been aborted or completed.
- HTTP Status Code: 404 Not Found
-
Error Code:
InvalidRequest- Description: The specified copy source is not supported as a byte-range copy source.
- HTTP Status Code: 400 Bad Request
-
Error Code:
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
UploadPartCopy:
- CreateMultipartUpload
- UploadPart
- CompleteMultipartUpload
- AbortMultipartUpload
- ListParts
- ListMultipartUploads
Parameter bucket :
The bucket name.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format
Bucket-name.s3express-zone-id.region-code.amazonaws.com.
Path-style requests are not supported. Directory bucket names must be
unique in the chosen Zone (Availability Zone or Local Zone). Bucket names
must follow the format
bucket-base-name--zone-id--x-s3 (for example,
amzn-s3-demo-bucket--usw2-az1--x-s3). For information
about bucket naming restrictions, see Directory
bucket naming rules in the Amazon S3 User Guide.
Access points - When you use this action with an access point for
general purpose buckets, you must provide the alias of the access point in
place of the bucket name or specify the access point ARN. When you use
this action with an access point for directory buckets, you must provide
the access point name in place of the bucket name. When using the access
point ARN, you must direct requests to the access point hostname. The
access point hostname takes the form
AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com.
When using this action with an access point through the Amazon Web
Services SDKs, you provide the access point ARN in place of the bucket
name. For more information about access point ARNs, see Using
access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you
must direct requests to the S3 on Outposts hostname. The S3 on Outposts
hostname takes the form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket must
be the Outposts access point ARN or the access point alias. For more
information about S3 on Outposts, see What
is S3 on Outposts? in the Amazon S3 User Guide.
Parameter copySource :
Specifies the source object for the copy operation. You specify the value
in one of two formats, depending on whether you want to access the source
object through an access
point:
-
For objects not accessed through an access point, specify the name of the
source bucket and key of the source object, separated by a slash (/). For
example, to copy the object
reports/january.pdffrom the bucketawsexamplebucket, useawsexamplebucket/reports/january.pdf. The value must be URL-encoded. -
For objects accessed through access points, specify the Amazon Resource
Name (ARN) of the object as accessed through the access point, in the
format
arn:aws:s3:. For example, to copy the objectreports/january.pdfthrough access pointmy-access-pointowned by account123456789012in Regionus-west-2, use the URL encoding ofarn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf. The value must be URL encoded. Alternatively, for objects accessed through Amazon S3 on Outposts, specify the ARN of the object as accessed in the formatarn:aws:s3-outposts:. For example, to copy the objectreports/january.pdfthrough outpostmy-outpostowned by account123456789012in Regionus-west-2, use the URL encoding ofarn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/object/reports/january.pdf. The value must be URL-encoded.
x-amz-copy-source identifies the
current version of the source object to copy. To copy a specific version
of the source object to copy, append ?versionId=
to the x-amz-copy-source request header (for example,
x-amz-copy-source:
/awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893).
If the current version is a delete marker and you don't specify a
versionId in the x-amz-copy-source request header, Amazon S3
returns a 404 Not Found error, because the object does not
exist. If you specify versionId in the x-amz-copy-source and
the versionId is a delete marker, Amazon S3 returns an HTTP 400 Bad
Request error, because you are not allowed to specify a delete
marker as a version for the x-amz-copy-source.
Parameter key :
Object key for which the multipart upload was initiated.
Parameter partNumber :
Part number of part being copied. This is a positive integer between 1 and
10,000.
Parameter uploadId :
Upload ID identifying the multipart upload whose part is being copied.
Parameter copySourceIfMatch :
Copies the object if its entity tag (ETag) matches the specified tag.
If both of the x-amz-copy-source-if-match and
x-amz-copy-source-if-unmodified-since headers are present in
the request as follows:
x-amz-copy-source-if-match condition evaluates to
true, and;
x-amz-copy-source-if-unmodified-since condition evaluates to
false;
Amazon S3 returns 200 OK and copies the data.
Parameter copySourceIfModifiedSince :
Copies the object if it has been modified since the specified time.
If both of the x-amz-copy-source-if-none-match and
x-amz-copy-source-if-modified-since headers are present in
the request as follows:
x-amz-copy-source-if-none-match condition evaluates to
false, and;
x-amz-copy-source-if-modified-since condition evaluates to
true;
Amazon S3 returns 412 Precondition Failed response code.
Parameter copySourceIfNoneMatch :
Copies the object if its entity tag (ETag) is different than the specified
ETag.
If both of the x-amz-copy-source-if-none-match and
x-amz-copy-source-if-modified-since headers are present in
the request as follows:
x-amz-copy-source-if-none-match condition evaluates to
false, and;
x-amz-copy-source-if-modified-since condition evaluates to
true;
Amazon S3 returns 412 Precondition Failed response code.
Parameter copySourceIfUnmodifiedSince :
Copies the object if it hasn't been modified since the specified time.
If both of the x-amz-copy-source-if-match and
x-amz-copy-source-if-unmodified-since headers are present in
the request as follows:
x-amz-copy-source-if-match condition evaluates to
true, and;
x-amz-copy-source-if-unmodified-since condition evaluates to
false;
Amazon S3 returns 200 OK and copies the data.
Parameter copySourceRange :
The range of bytes to copy from the source object. The range value must
use the form bytes=first-last, where the first and last are the zero-based
byte offsets to copy. For example, bytes=0-9 indicates that you want to
copy the first 10 bytes of the source. You can copy a range only if the
source object is greater than 5 MB.
Parameter copySourceSSECustomerAlgorithm :
Specifies the algorithm to use when decrypting the source object (for
example, AES256).
Parameter copySourceSSECustomerKey :
Specifies the customer-provided encryption key for Amazon S3 to use to
decrypt the source object. The encryption key provided in this header must
be one that was used when the source object was created.
Parameter copySourceSSECustomerKeyMD5 :
Specifies the 128-bit MD5 digest of the encryption key according to RFC
1321. Amazon S3 uses this header for a message integrity check to ensure
that the encryption key was transmitted without error.
Parameter expectedBucketOwner :
The account ID of the expected destination bucket owner. If the account ID
that you provide does not match the actual owner of the destination
bucket, the request fails with the HTTP status code 403
Forbidden (access denied).
Parameter expectedSourceBucketOwner :
The account ID of the expected source bucket owner. If the account ID that
you provide does not match the actual owner of the source bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
Parameter sSECustomerAlgorithm :
Specifies the algorithm to use when encrypting the object (for example,
AES256).
Parameter sSECustomerKey :
Specifies the customer-provided encryption key for Amazon S3 to use in
encrypting data. This value is used to store the object and then it is
discarded; Amazon S3 does not store the encryption key. The key must be
appropriate for use with the algorithm specified in the
x-amz-server-side-encryption-customer-algorithm header. This
must be the same encryption key specified in the initiate multipart upload
request.
Parameter sSECustomerKeyMD5 :
Specifies the 128-bit MD5 digest of the encryption key according to RFC
1321. Amazon S3 uses this header for a message integrity check to ensure
that the encryption key was transmitted without error.
Implementation
Future<UploadPartCopyOutput> uploadPartCopy({
required String bucket,
required String copySource,
required String key,
required int partNumber,
required String uploadId,
String? copySourceIfMatch,
DateTime? copySourceIfModifiedSince,
String? copySourceIfNoneMatch,
DateTime? copySourceIfUnmodifiedSince,
String? copySourceRange,
String? copySourceSSECustomerAlgorithm,
String? copySourceSSECustomerKey,
String? copySourceSSECustomerKeyMD5,
String? expectedBucketOwner,
String? expectedSourceBucketOwner,
RequestPayer? requestPayer,
String? sSECustomerAlgorithm,
String? sSECustomerKey,
String? sSECustomerKeyMD5,
}) async {
final headers = <String, String>{
'x-amz-copy-source': copySource.toString(),
if (copySourceIfMatch != null)
'x-amz-copy-source-if-match': copySourceIfMatch.toString(),
if (copySourceIfModifiedSince != null)
'x-amz-copy-source-if-modified-since':
_s.rfc822ToJson(copySourceIfModifiedSince),
if (copySourceIfNoneMatch != null)
'x-amz-copy-source-if-none-match': copySourceIfNoneMatch.toString(),
if (copySourceIfUnmodifiedSince != null)
'x-amz-copy-source-if-unmodified-since':
_s.rfc822ToJson(copySourceIfUnmodifiedSince),
if (copySourceRange != null)
'x-amz-copy-source-range': copySourceRange.toString(),
if (copySourceSSECustomerAlgorithm != null)
'x-amz-copy-source-server-side-encryption-customer-algorithm':
copySourceSSECustomerAlgorithm.toString(),
if (copySourceSSECustomerKey != null)
'x-amz-copy-source-server-side-encryption-customer-key':
copySourceSSECustomerKey.toString(),
if (copySourceSSECustomerKeyMD5 != null)
'x-amz-copy-source-server-side-encryption-customer-key-MD5':
copySourceSSECustomerKeyMD5.toString(),
if (expectedBucketOwner != null)
'x-amz-expected-bucket-owner': expectedBucketOwner.toString(),
if (expectedSourceBucketOwner != null)
'x-amz-source-expected-bucket-owner':
expectedSourceBucketOwner.toString(),
if (requestPayer != null) 'x-amz-request-payer': requestPayer.value,
if (sSECustomerAlgorithm != null)
'x-amz-server-side-encryption-customer-algorithm':
sSECustomerAlgorithm.toString(),
if (sSECustomerKey != null)
'x-amz-server-side-encryption-customer-key': sSECustomerKey.toString(),
if (sSECustomerKeyMD5 != null)
'x-amz-server-side-encryption-customer-key-MD5':
sSECustomerKeyMD5.toString(),
};
final $query = <String, List<String>>{
'partNumber': [partNumber.toString()],
'uploadId': [uploadId],
};
final $result = await _protocol.sendRaw(
method: 'PUT',
requestUri:
'/${Uri.encodeComponent(bucket)}/${key.split('/').map(Uri.encodeComponent).join('/')}?x-id=UploadPartCopy',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
final $elem = await _s.xmlFromResponse($result);
return UploadPartCopyOutput(
copyPartResult: CopyPartResult.fromXml($elem),
bucketKeyEnabled: _s.extractHeaderBoolValue(
$result.headers, 'x-amz-server-side-encryption-bucket-key-enabled'),
copySourceVersionId: _s.extractHeaderStringValue(
$result.headers, 'x-amz-copy-source-version-id'),
requestCharged: _s
.extractHeaderStringValue($result.headers, 'x-amz-request-charged')
?.let(RequestCharged.fromString),
sSECustomerAlgorithm: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-customer-algorithm'),
sSECustomerKeyMD5: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-customer-key-MD5'),
sSEKMSKeyId: _s.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption-aws-kms-key-id'),
serverSideEncryption: _s
.extractHeaderStringValue(
$result.headers, 'x-amz-server-side-encryption')
?.let(ServerSideEncryption.fromString),
);
}