S3Control class
Amazon Web Services S3 Control provides access to Amazon S3 control plane actions.
Constructors
- S3Control({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associateAccessGrantsIdentityCenter(
{required String accountId, required String identityCenterArn}) → Future< void> - Associate your S3 Access Grants instance with an Amazon Web Services IAM Identity Center instance. Use this action if you want to create access grants for users or groups from your corporate identity directory. First, you must add your corporate identity directory to Amazon Web Services IAM Identity Center. Then, you can associate this IAM Identity Center instance with your S3 Access Grants instance.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAccessGrant(
{required String accessGrantsLocationId, required String accountId, required Grantee grantee, required Permission permission, AccessGrantsLocationConfiguration? accessGrantsLocationConfiguration, String? applicationArn, S3PrefixType? s3PrefixType, List< Tag> ? tags}) → Future<CreateAccessGrantResult> - Creates an access grant that gives a grantee access to your S3 data. The grantee can be an IAM user or role or a directory user, or group. Before you can create a grant, you must have an S3 Access Grants instance in the same Region as the S3 data. You can create an S3 Access Grants instance using the CreateAccessGrantsInstance. You must also have registered at least one S3 data location in your S3 Access Grants instance using CreateAccessGrantsLocation.
-
createAccessGrantsInstance(
{required String accountId, String? identityCenterArn, List< Tag> ? tags}) → Future<CreateAccessGrantsInstanceResult> - Creates an S3 Access Grants instance, which serves as a logical grouping for access grants. You can create one S3 Access Grants instance per Region per account.
-
createAccessGrantsLocation(
{required String accountId, required String iAMRoleArn, required String locationScope, List< Tag> ? tags}) → Future<CreateAccessGrantsLocationResult> - The S3 data location that you would like to register in your S3 Access Grants instance. Your S3 data must be in the same Region as your S3 Access Grants instance. The location can be one of the following:
-
createAccessPoint(
{required String accountId, required String bucket, required String name, String? bucketAccountId, PublicAccessBlockConfiguration? publicAccessBlockConfiguration, Scope? scope, List< Tag> ? tags, VpcConfiguration? vpcConfiguration}) → Future<CreateAccessPointResult> - Creates an access point and associates it to a specified bucket. For more information, see Managing access to shared datasets with access points or Managing access to shared datasets in directory buckets with access points in the Amazon S3 User Guide.
-
createAccessPointForObjectLambda(
{required String accountId, required ObjectLambdaConfiguration configuration, required String name}) → Future< CreateAccessPointForObjectLambdaResult> - Transforming objects with Object Lambda Access Points
-
createBucket(
{required String bucket, BucketCannedACL? acl, CreateBucketConfiguration? createBucketConfiguration, String? grantFullControl, String? grantRead, String? grantReadACP, String? grantWrite, String? grantWriteACP, bool? objectLockEnabledForBucket, String? outpostId}) → Future< CreateBucketResult> - Using Amazon S3 on Outposts
-
createJob(
{required String accountId, required JobOperation operation, required int priority, required JobReport report, required String roleArn, String? clientRequestToken, bool? confirmationRequired, String? description, JobManifest? manifest, JobManifestGenerator? manifestGenerator, List< S3Tag> ? tags}) → Future<CreateJobResult> - This operation creates an S3 Batch Operations job.
-
createMultiRegionAccessPoint(
{required String accountId, required CreateMultiRegionAccessPointInput details, String? clientToken}) → Future< CreateMultiRegionAccessPointResult> - Creating Multi-Region Access Points
-
createStorageLensGroup(
{required String accountId, required StorageLensGroup storageLensGroup, List< Tag> ? tags}) → Future<void> - Creates a new S3 Storage Lens group and associates it with the specified Amazon Web Services account ID. An S3 Storage Lens group is a custom grouping of objects based on prefix, suffix, object tags, object size, object age, or a combination of these filters. For each Storage Lens group that you’ve created, you can also optionally add Amazon Web Services resource tags. For more information about S3 Storage Lens groups, see Working with S3 Storage Lens groups.
-
deleteAccessGrant(
{required String accessGrantId, required String accountId}) → Future< void> - Deletes the access grant from the S3 Access Grants instance. You cannot undo an access grant deletion and the grantee will no longer have access to the S3 data.
-
deleteAccessGrantsInstance(
{required String accountId}) → Future< void> - Deletes your S3 Access Grants instance. You must first delete the access grants and locations before S3 Access Grants can delete the instance. See DeleteAccessGrant and DeleteAccessGrantsLocation. If you have associated an IAM Identity Center instance with your S3 Access Grants instance, you must first dissassociate the Identity Center instance from the S3 Access Grants instance before you can delete the S3 Access Grants instance. See AssociateAccessGrantsIdentityCenter and DissociateAccessGrantsIdentityCenter.
-
deleteAccessGrantsInstanceResourcePolicy(
{required String accountId}) → Future< void> - Deletes the resource policy of the S3 Access Grants instance. The resource policy is used to manage cross-account access to your S3 Access Grants instance. By deleting the resource policy, you delete any cross-account permissions to your S3 Access Grants instance.
-
deleteAccessGrantsLocation(
{required String accessGrantsLocationId, required String accountId}) → Future< void> - Deregisters a location from your S3 Access Grants instance. You can only delete a location registration from an S3 Access Grants instance if there are no grants associated with this location. See Delete a grant for information on how to delete grants. You need to have at least one registered location in your S3 Access Grants instance in order to create access grants.
-
deleteAccessPoint(
{required String accountId, required String name}) → Future< void> - Deletes the specified access point.
-
deleteAccessPointForObjectLambda(
{required String accountId, required String name}) → Future< void> -
The following actions are related to
DeleteAccessPointForObjectLambda: -
deleteAccessPointPolicy(
{required String accountId, required String name}) → Future< void> - Deletes the access point policy for the specified access point.
-
deleteAccessPointPolicyForObjectLambda(
{required String accountId, required String name}) → Future< void> -
The following actions are related to
DeleteAccessPointPolicyForObjectLambda: -
deleteAccessPointScope(
{required String accountId, required String name}) → Future< void> -
Deletes an existing access point scope for a directory bucket.
To use this operation, you must have the permission to perform the
s3express:DeleteAccessPointScopeaction. -
deleteBucket(
{required String accountId, required String bucket}) → Future< void> - Using Amazon S3 on Outposts
-
deleteBucketLifecycleConfiguration(
{required String accountId, required String bucket}) → Future< void> - Using Amazon S3 on Outposts
-
deleteBucketPolicy(
{required String accountId, required String bucket}) → Future< void> - s3-outposts:DeleteBucketPolicy
-
deleteBucketReplication(
{required String accountId, required String bucket}) → Future< void> -
To use this operation, you must have permissions to perform the
s3-outposts:PutReplicationConfigurationaction. The Outposts bucket owner has this permission by default and can grant it to others. For more information about permissions, see Setting up IAM with S3 on Outposts and Managing access to S3 on Outposts buckets in the Amazon S3 User Guide. All Amazon S3 on Outposts REST API requests for this action require an additional parameter ofx-amz-outpost-idto be passed with the request. In addition, you must use an S3 on Outposts endpoint hostname prefix instead ofs3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and thex-amz-outpost-idderived by using the access point ARN, see the Examples section. -
deleteBucketTagging(
{required String accountId, required String bucket}) → Future< void> - Using Amazon S3 on Outposts
-
deleteJobTagging(
{required String accountId, required String jobId}) → Future< void> - Removes the entire tag set from the specified S3 Batch Operations job.
-
deleteMultiRegionAccessPoint(
{required String accountId, required DeleteMultiRegionAccessPointInput details, String? clientToken}) → Future< DeleteMultiRegionAccessPointResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
deletePublicAccessBlock(
{required String accountId}) → Future< void> - PublicAccessBlock
-
deleteStorageLensConfiguration(
{required String accountId, required String configId}) → Future< void> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
deleteStorageLensConfigurationTagging(
{required String accountId, required String configId}) → Future< void> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
deleteStorageLensGroup(
{required String accountId, required String name}) → Future< void> - Deletes an existing S3 Storage Lens group.
-
describeJob(
{required String accountId, required String jobId}) → Future< DescribeJobResult> - Retrieves the configuration parameters and status for a Batch Operations job. For more information, see S3 Batch Operations in the Amazon S3 User Guide.
-
describeMultiRegionAccessPointOperation(
{required String accountId, required String requestTokenARN}) → Future< DescribeMultiRegionAccessPointOperationResult> - Using Multi-Region Access Points
-
dissociateAccessGrantsIdentityCenter(
{required String accountId}) → Future< void> - Dissociates the Amazon Web Services IAM Identity Center instance from the S3 Access Grants instance.
-
getAccessGrant(
{required String accessGrantId, required String accountId}) → Future< GetAccessGrantResult> - Get the details of an access grant from your S3 Access Grants instance.
-
getAccessGrantsInstance(
{required String accountId}) → Future< GetAccessGrantsInstanceResult> - Retrieves the S3 Access Grants instance for a Region in your account.
-
getAccessGrantsInstanceForPrefix(
{required String accountId, required String s3Prefix}) → Future< GetAccessGrantsInstanceForPrefixResult> - Retrieve the S3 Access Grants instance that contains a particular prefix.
-
getAccessGrantsInstanceResourcePolicy(
{required String accountId}) → Future< GetAccessGrantsInstanceResourcePolicyResult> - Returns the resource policy of the S3 Access Grants instance.
-
getAccessGrantsLocation(
{required String accessGrantsLocationId, required String accountId}) → Future< GetAccessGrantsLocationResult> - Retrieves the details of a particular location registered in your S3 Access Grants instance.
-
getAccessPoint(
{required String accountId, required String name}) → Future< GetAccessPointResult> - Returns configuration information about the specified access point.
-
getAccessPointConfigurationForObjectLambda(
{required String accountId, required String name}) → Future< GetAccessPointConfigurationForObjectLambdaResult> -
The following actions are related to
GetAccessPointConfigurationForObjectLambda: -
getAccessPointForObjectLambda(
{required String accountId, required String name}) → Future< GetAccessPointForObjectLambdaResult> -
The following actions are related to
GetAccessPointForObjectLambda: -
getAccessPointPolicy(
{required String accountId, required String name}) → Future< GetAccessPointPolicyResult> - Returns the access point policy associated with the specified access point.
-
getAccessPointPolicyForObjectLambda(
{required String accountId, required String name}) → Future< GetAccessPointPolicyForObjectLambdaResult> -
The following actions are related to
GetAccessPointPolicyForObjectLambda: -
getAccessPointPolicyStatus(
{required String accountId, required String name}) → Future< GetAccessPointPolicyStatusResult> - Managing Data Access with Amazon S3 access points
-
getAccessPointPolicyStatusForObjectLambda(
{required String accountId, required String name}) → Future< GetAccessPointPolicyStatusForObjectLambdaResult> -
Parameter
accountId: The account ID for the account that owns the specified Object Lambda Access Point. -
getAccessPointScope(
{required String accountId, required String name}) → Future< GetAccessPointScopeResult> - Returns the access point scope for a directory bucket.
-
getBucket(
{required String accountId, required String bucket}) → Future< GetBucketResult> - Gets an Amazon S3 on Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide.
-
getBucketLifecycleConfiguration(
{required String accountId, required String bucket}) → Future< GetBucketLifecycleConfigurationResult> - Using Amazon S3 on Outposts
-
getBucketPolicy(
{required String accountId, required String bucket}) → Future< GetBucketPolicyResult> - Using Amazon S3 on Outposts
-
getBucketReplication(
{required String accountId, required String bucket}) → Future< GetBucketReplicationResult> - Using Amazon S3 on Outposts
-
getBucketTagging(
{required String accountId, required String bucket}) → Future< GetBucketTaggingResult> - Using Amazon S3 on Outposts
-
getBucketVersioning(
{required String accountId, required String bucket}) → Future< GetBucketVersioningResult> -
If you've never set versioning on your bucket, it has no versioning state.
In that case, the
GetBucketVersioningrequest does not return a versioning state value. -
getDataAccess(
{required String accountId, required Permission permission, required String target, String? auditContext, int? durationSeconds, Privilege? privilege, S3PrefixType? targetType}) → Future< GetDataAccessResult> - Returns a temporary access credential from S3 Access Grants to the grantee or client application. The temporary credential is an Amazon Web Services STS token that grants them access to the S3 data.
-
getJobTagging(
{required String accountId, required String jobId}) → Future< GetJobTaggingResult> - Returns the tags on an S3 Batch Operations job.
-
getMultiRegionAccessPoint(
{required String accountId, required String name}) → Future< GetMultiRegionAccessPointResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
getMultiRegionAccessPointPolicy(
{required String accountId, required String name}) → Future< GetMultiRegionAccessPointPolicyResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
getMultiRegionAccessPointPolicyStatus(
{required String accountId, required String name}) → Future< GetMultiRegionAccessPointPolicyStatusResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
getMultiRegionAccessPointRoutes(
{required String accountId, required String mrap}) → Future< GetMultiRegionAccessPointRoutesResult> - To obtain routing control changes and failover requests, use the Amazon S3 failover control infrastructure endpoints in these five Amazon Web Services Regions:
-
getPublicAccessBlock(
{required String accountId}) → Future< GetPublicAccessBlockOutput> - PublicAccessBlock
-
getStorageLensConfiguration(
{required String accountId, required String configId}) → Future< GetStorageLensConfigurationResult> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
getStorageLensConfigurationTagging(
{required String accountId, required String configId}) → Future< GetStorageLensConfigurationTaggingResult> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
getStorageLensGroup(
{required String accountId, required String name}) → Future< GetStorageLensGroupResult> - Retrieves the Storage Lens group configuration details.
-
listAccessGrants(
{required String accountId, String? applicationArn, String? grantScope, String? granteeIdentifier, GranteeType? granteeType, int? maxResults, String? nextToken, Permission? permission}) → Future< ListAccessGrantsResult> - Returns the list of access grants in your S3 Access Grants instance.
-
listAccessGrantsInstances(
{required String accountId, int? maxResults, String? nextToken}) → Future< ListAccessGrantsInstancesResult> - Returns a list of S3 Access Grants instances. An S3 Access Grants instance serves as a logical grouping for your individual access grants. You can only have one S3 Access Grants instance per Region per account.
-
listAccessGrantsLocations(
{required String accountId, String? locationScope, int? maxResults, String? nextToken}) → Future< ListAccessGrantsLocationsResult> - Returns a list of the locations registered in your S3 Access Grants instance.
-
listAccessPoints(
{required String accountId, String? bucket, String? dataSourceId, String? dataSourceType, int? maxResults, String? nextToken}) → Future< ListAccessPointsResult> - maxResults
-
listAccessPointsForDirectoryBuckets(
{required String accountId, String? directoryBucket, int? maxResults, String? nextToken}) → Future< ListAccessPointsForDirectoryBucketsResult> - Returns a list of the access points that are owned by the Amazon Web Services account and that are associated with the specified directory bucket.
-
listAccessPointsForObjectLambda(
{required String accountId, int? maxResults, String? nextToken}) → Future< ListAccessPointsForObjectLambdaResult> -
The following actions are related to
ListAccessPointsForObjectLambda: -
listCallerAccessGrants(
{required String accountId, bool? allowedByApplication, String? grantScope, int? maxResults, String? nextToken}) → Future< ListCallerAccessGrantsResult> -
Use this API to list the access grants that grant the caller access to
Amazon S3 data through S3 Access Grants. The caller (grantee) can be an
Identity and Access Management (IAM) identity or Amazon Web Services
Identity Center corporate directory identity. You must pass the Amazon Web
Services account of the S3 data owner (grantor) in the request. You can,
optionally, narrow the results by
GrantScope, using a fragment of the data's S3 path, and S3 Access Grants will return only the grants with a path that contains the path fragment. You can also pass theAllowedByApplicationfilter in the request, which returns only the grants authorized for applications, whether the application is the caller's Identity Center application or any other application (ALL). For more information, see List the caller's access grants in the Amazon S3 User Guide. -
listJobs(
{required String accountId, List< JobStatus> ? jobStatuses, int? maxResults, String? nextToken}) → Future<ListJobsResult> - Lists current S3 Batch Operations jobs as well as the jobs that have ended within the last 90 days for the Amazon Web Services account making the request. For more information, see S3 Batch Operations in the Amazon S3 User Guide.
-
listMultiRegionAccessPoints(
{required String accountId, int? maxResults, String? nextToken}) → Future< ListMultiRegionAccessPointsResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
listRegionalBuckets(
{required String accountId, int? maxResults, String? nextToken, String? outpostId}) → Future< ListRegionalBucketsResult> - Using Amazon S3 on Outposts
-
listStorageLensConfigurations(
{required String accountId, String? nextToken}) → Future< ListStorageLensConfigurationsResult> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
listStorageLensGroups(
{required String accountId, String? nextToken}) → Future< ListStorageLensGroupsResult> - Lists all the Storage Lens groups in the specified home Region.
-
listTagsForResource(
{required String accountId, required String resourceArn}) → Future< ListTagsForResourceResult> - This operation allows you to list all of the tags for a specified resource. Each tag is a label consisting of a key and value. Tags can help you organize, track costs for, and control access to resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAccessGrantsInstanceResourcePolicy(
{required String accountId, required String policy, String? organization}) → Future< PutAccessGrantsInstanceResourcePolicyResult> - Updates the resource policy of the S3 Access Grants instance.
-
putAccessPointConfigurationForObjectLambda(
{required String accountId, required ObjectLambdaConfiguration configuration, required String name}) → Future< void> -
The following actions are related to
PutAccessPointConfigurationForObjectLambda: -
putAccessPointPolicy(
{required String accountId, required String name, required String policy}) → Future< void> - Associates an access policy with the specified access point. Each access point can have only one policy, so a request made to this API replaces any existing policy associated with the specified access point.
-
putAccessPointPolicyForObjectLambda(
{required String accountId, required String name, required String policy}) → Future< void> - Creating Object Lambda Access Points
-
putAccessPointScope(
{required String accountId, required String name, required Scope scope}) → Future< void> -
Creates or replaces the access point scope for a directory bucket. You can
use the access point scope to restrict access to specific prefixes, API
operations, or a combination of both.
To use this operation, you must have the permission to perform the
s3express:PutAccessPointScopeaction. -
putBucketLifecycleConfiguration(
{required String accountId, required String bucket, LifecycleConfiguration? lifecycleConfiguration}) → Future< void> -
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of
x-amz-outpost-idto be passed with the request. In addition, you must use an S3 on Outposts endpoint hostname prefix instead ofs3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and thex-amz-outpost-idderived by using the access point ARN, see the Examples section. -
putBucketPolicy(
{required String accountId, required String bucket, required String policy, bool? confirmRemoveSelfBucketAccess}) → Future< void> - Using Amazon S3 on Outposts
-
putBucketReplication(
{required String accountId, required String bucket, required ReplicationConfiguration replicationConfiguration}) → Future< void> - Replicating objects for S3 on Outposts
-
putBucketTagging(
{required String accountId, required String bucket, required Tagging tagging}) → Future< void> - Using Amazon S3 on Outposts
-
putBucketVersioning(
{required String accountId, required String bucket, required VersioningConfiguration versioningConfiguration, String? mfa}) → Future< void> - You can set the versioning state to one of the following:
-
putJobTagging(
{required String accountId, required String jobId, required List< S3Tag> tags}) → Future<void> - Sets the supplied tag-set on an S3 Batch Operations job.
-
putMultiRegionAccessPointPolicy(
{required String accountId, required PutMultiRegionAccessPointPolicyInput details, String? clientToken}) → Future< PutMultiRegionAccessPointPolicyResult> - This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
-
putPublicAccessBlock(
{required String accountId, required PublicAccessBlockConfiguration publicAccessBlockConfiguration}) → Future< void> - PublicAccessBlock
-
putStorageLensConfiguration(
{required String accountId, required String configId, required StorageLensConfiguration storageLensConfiguration, List< StorageLensTag> ? tags}) → Future<void> - Working with Amazon S3 Storage Lens
-
putStorageLensConfigurationTagging(
{required String accountId, required String configId, required List< StorageLensTag> tags}) → Future<void> - Assessing your storage activity and usage with Amazon S3 Storage Lens
-
submitMultiRegionAccessPointRoutes(
{required String accountId, required String mrap, required List< MultiRegionAccessPointRoute> routeUpdates}) → Future<void> - 0
-
tagResource(
{required String accountId, required String resourceArn, required List< Tag> tags}) → Future<void> - Creates a new user-defined tag or updates an existing tag. Each tag is a label consisting of a key and value that is applied to your resource. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 Amazon Web Services resource tags for each S3 resource.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String accountId, required String resourceArn, required List< String> tagKeys}) → Future<void> - This operation removes the specified user-defined tags from an S3 resource. You can pass one or more tag keys.
-
updateAccessGrantsLocation(
{required String accessGrantsLocationId, required String accountId, required String iAMRoleArn}) → Future< UpdateAccessGrantsLocationResult> - Updates the IAM role of a registered location in your S3 Access Grants instance.
-
updateJobPriority(
{required String accountId, required String jobId, required int priority}) → Future< UpdateJobPriorityResult> - Updates an existing S3 Batch Operations job's priority. For more information, see S3 Batch Operations in the Amazon S3 User Guide.
-
updateJobStatus(
{required String accountId, required String jobId, required RequestedJobStatus requestedJobStatus, String? statusUpdateReason}) → Future< UpdateJobStatusResult> - Updates the status for the specified job. Use this operation to confirm that you want to run a job or to cancel an existing job. For more information, see S3 Batch Operations in the Amazon S3 User Guide.
-
updateStorageLensGroup(
{required String accountId, required String name, required StorageLensGroup storageLensGroup}) → Future< void> - Updates the existing Storage Lens group.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited