createAccessGrant method
Creates an access grant that gives a grantee access to your S3 data. The grantee can be an IAM user or role or a directory user, or group. Before you can create a grant, you must have an S3 Access Grants instance in the same Region as the S3 data. You can create an S3 Access Grants instance using the CreateAccessGrantsInstance. You must also have registered at least one S3 data location in your S3 Access Grants instance using CreateAccessGrantsLocation.
- Permissions
-
You must have the
s3:CreateAccessGrantpermission to use this operation. - Additional Permissions
-
For any directory identity -
sso:DescribeInstanceandsso:DescribeApplicationFor directory users -
identitystore:DescribeUserFor directory groups -
identitystore:DescribeGroup
Parameter accessGrantsLocationId :
The ID of the registered location to which you are granting access. S3
Access Grants assigns this ID when you register the location. S3 Access
Grants assigns the ID default to the default location
s3:// and assigns an auto-generated ID to other locations
that you register.
If you are passing the default location, you cannot create an
access grant for the entire default location. You must also specify a
bucket or a bucket and prefix in the Subprefix field.
Parameter accountId :
The Amazon Web Services account ID of the S3 Access Grants instance.
Parameter grantee :
The user, group, or role to which you are granting access. You can grant
access to an IAM user or role. If you have added your corporate directory
to Amazon Web Services IAM Identity Center and associated your Identity
Center instance with your S3 Access Grants instance, the grantee can also
be a corporate directory user or group.
Parameter permission :
The type of access that you are granting to your S3 data, which can be set
to one of the following values:
-
READ– Grant read-only access to the S3 data. -
WRITE– Grant write-only access to the S3 data. -
READWRITE– Grant both read and write access to the S3 data.
Parameter accessGrantsLocationConfiguration :
The configuration options of the grant location. The grant location is the
S3 path to the data to which you are granting access. It contains the
S3SubPrefix field. The grant scope is the result of appending
the subprefix to the location scope of the registered location.
Parameter applicationArn :
The Amazon Resource Name (ARN) of an Amazon Web Services IAM Identity
Center application associated with your Identity Center instance. If an
application ARN is included in the request to create an access grant, the
grantee can only access the S3 data through this application.
Parameter s3PrefixType :
The type of S3SubPrefix. The only possible value is
Object. Pass this value if the access grant scope is an
object. Do not pass this value if the access grant scope is a bucket or a
bucket and a prefix.
Parameter tags :
The Amazon Web Services resource tags that you are adding to the access
grant. Each tag is a label consisting of a user-defined key and value.
Tags can help you manage, identify, organize, search for, and filter
resources.
Implementation
Future<CreateAccessGrantResult> createAccessGrant({
required String accessGrantsLocationId,
required String accountId,
required Grantee grantee,
required Permission permission,
AccessGrantsLocationConfiguration? accessGrantsLocationConfiguration,
String? applicationArn,
S3PrefixType? s3PrefixType,
List<Tag>? tags,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'POST',
requestUri: '/v20180820/accessgrantsinstance/grant',
headers: headers,
payload: CreateAccessGrantRequest(
accessGrantsLocationId: accessGrantsLocationId,
accountId: accountId,
grantee: grantee,
permission: permission,
accessGrantsLocationConfiguration:
accessGrantsLocationConfiguration,
applicationArn: applicationArn,
s3PrefixType: s3PrefixType,
tags: tags)
.toXml('CreateAccessGrantRequest'),
exceptionFnMap: _exceptionFns,
);
return CreateAccessGrantResult.fromXml($result.body);
}