deleteAccessGrant method
Deletes the access grant from the S3 Access Grants instance. You cannot undo an access grant deletion and the grantee will no longer have access to the S3 data.
- Permissions
-
You must have the
s3:DeleteAccessGrantpermission to use this operation.
Parameter accessGrantId :
The ID of the access grant. S3 Access Grants auto-generates this ID when
you create the access grant.
Parameter accountId :
The Amazon Web Services account ID of the S3 Access Grants instance.
Implementation
Future<void> deleteAccessGrant({
required String accessGrantId,
required String accountId,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri:
'/v20180820/accessgrantsinstance/grant/${Uri.encodeComponent(accessGrantId)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}