deleteAccessGrantsInstance method
Deletes your S3 Access Grants instance. You must first delete the access grants and locations before S3 Access Grants can delete the instance. See DeleteAccessGrant and DeleteAccessGrantsLocation. If you have associated an IAM Identity Center instance with your S3 Access Grants instance, you must first dissassociate the Identity Center instance from the S3 Access Grants instance before you can delete the S3 Access Grants instance. See AssociateAccessGrantsIdentityCenter and DissociateAccessGrantsIdentityCenter.
- Permissions
-
You must have the
s3:DeleteAccessGrantsInstancepermission to use this operation.
Parameter accountId :
The Amazon Web Services account ID of the S3 Access Grants instance.
Implementation
Future<void> deleteAccessGrantsInstance({
required String accountId,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/v20180820/accessgrantsinstance',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}