deleteAccessPointForObjectLambda method
Deletes the specified Object Lambda Access Point.
The following actions are related to
DeleteAccessPointForObjectLambda:
Parameter accountId :
The account ID for the account that owns the specified Object Lambda
Access Point.
Parameter name :
The name of the access point you want to delete.
Implementation
Future<void> deleteAccessPointForObjectLambda({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri:
'/v20180820/accesspointforobjectlambda/${Uri.encodeComponent(name)}',
headers: headers,
endpoint: _resolveEndpoint(
requiresAccountId: true,
accountId: accountId,
),
hostPrefix: '{AccountId}.',
exceptionFnMap: _exceptionFns,
);
}