deleteAccessPointScope method
Deletes an existing access point scope for a directory bucket.
To use this operation, you must have the permission to perform the
s3express:DeleteAccessPointScope action.
For information about REST API errors, see REST error responses.
Parameter accountId :
The Amazon Web Services account ID that owns the access point with the
scope that you want to delete.
Parameter name :
The name of the access point with the scope that you want to delete.
Implementation
Future<void> deleteAccessPointScope({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/v20180820/accesspoint/${Uri.encodeComponent(name)}/scope',
headers: headers,
exceptionFnMap: _exceptionFns,
);
}