deleteMultiRegionAccessPoint method
This action will always be routed to the US West (Oregon) Region. For more information about the restrictions around working with Multi-Region Access Points, see Multi-Region Access Point restrictions and limitations in the Amazon S3 User Guide.
This request is asynchronous, meaning that you might receive a response
before the command has completed. When this request provides a response,
it provides a token that you can use to monitor the status of the request
with DescribeMultiRegionAccessPointOperation.
The following actions are related to
DeleteMultiRegionAccessPoint:
- CreateMultiRegionAccessPoint
- DescribeMultiRegionAccessPointOperation
- GetMultiRegionAccessPoint
- ListMultiRegionAccessPoints
Parameter accountId :
The Amazon Web Services account ID for the owner of the Multi-Region
Access Point.
Parameter details :
A container element containing details about the Multi-Region Access
Point.
Parameter clientToken :
An idempotency token used to identify the request and guarantee that
requests are unique.
Implementation
Future<DeleteMultiRegionAccessPointResult> deleteMultiRegionAccessPoint({
required String accountId,
required DeleteMultiRegionAccessPointInput details,
String? clientToken,
}) async {
clientToken ??= _s.generateIdempotencyToken();
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'POST',
requestUri: '/v20180820/async-requests/mrap/delete',
headers: headers,
payload: DeleteMultiRegionAccessPointRequest(
accountId: accountId, details: details, clientToken: clientToken)
.toXml('DeleteMultiRegionAccessPointRequest'),
exceptionFnMap: _exceptionFns,
);
return DeleteMultiRegionAccessPointResult.fromXml($result.body);
}