deleteStorageLensGroup method
Deletes an existing S3 Storage Lens group.
To use this operation, you must have the permission to perform the
s3:DeleteStorageLensGroup action. For more information about
the required Storage Lens Groups permissions, see Setting
account permissions to use S3 Storage Lens groups.
For information about Storage Lens groups errors, see List of Amazon S3 Storage Lens error codes.
Parameter accountId :
The Amazon Web Services account ID used to create the Storage Lens group
that you're trying to delete.
Parameter name :
The name of the Storage Lens group that you're trying to delete.
Implementation
Future<void> deleteStorageLensGroup({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
await _protocol.send(
method: 'DELETE',
requestUri: '/v20180820/storagelensgroup/${Uri.encodeComponent(name)}',
headers: headers,
endpoint: _resolveEndpoint(
requiresAccountId: true,
accountId: accountId,
),
hostPrefix: '{AccountId}.',
exceptionFnMap: _exceptionFns,
);
}