describeMultiRegionAccessPointOperation method
Retrieves the status of an asynchronous request to manage a Multi-Region
Access Point. For more information about managing Multi-Region Access
Points and how asynchronous requests work, see Using
Multi-Region Access Points in the Amazon S3 User Guide.
The following actions are related to
GetMultiRegionAccessPoint:
- CreateMultiRegionAccessPoint
- DeleteMultiRegionAccessPoint
- GetMultiRegionAccessPoint
- ListMultiRegionAccessPoints
Parameter accountId :
The Amazon Web Services account ID for the owner of the Multi-Region
Access Point.
Parameter requestTokenARN :
The request token associated with the request you want to know about. This
request token is returned as part of the response when you make an
asynchronous request. You provide this token to query about the status of
the asynchronous action.
Implementation
Future<DescribeMultiRegionAccessPointOperationResult>
describeMultiRegionAccessPointOperation({
required String accountId,
required String requestTokenARN,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/v20180820/async-requests/mrap/${requestTokenARN.split('/').map(Uri.encodeComponent).join('/')}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return DescribeMultiRegionAccessPointOperationResult.fromXml($result.body);
}