getAccessPointForObjectLambda method
Returns configuration information about the specified Object Lambda Access
Point
The following actions are related to
GetAccessPointForObjectLambda:
Parameter accountId :
The account ID for the account that owns the specified Object Lambda
Access Point.
Parameter name :
The name of the Object Lambda Access Point.
Implementation
Future<GetAccessPointForObjectLambdaResult> getAccessPointForObjectLambda({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri:
'/v20180820/accesspointforobjectlambda/${Uri.encodeComponent(name)}',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetAccessPointForObjectLambdaResult.fromXml($result.body);
}