getAccessPointScope method
Returns the access point scope for a directory bucket.
To use this operation, you must have the permission to perform the
s3express:GetAccessPointScope action.
For information about REST API errors, see REST error responses.
Parameter accountId :
The Amazon Web Services account ID that owns the access point with the
scope that you want to retrieve.
Parameter name :
The name of the access point with the scope you want to retrieve.
Implementation
Future<GetAccessPointScopeResult> getAccessPointScope({
required String accountId,
required String name,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/accesspoint/${Uri.encodeComponent(name)}/scope',
headers: headers,
exceptionFnMap: _exceptionFns,
);
return GetAccessPointScopeResult.fromXml($result.body);
}