getBucketReplication method
s3-outposts:GetReplicationConfiguration action. The Outposts
bucket owner has this permission by default and can grant it to others.
For more information about permissions, see Setting
up IAM with S3 on Outposts and Managing
access to S3 on Outposts bucket in the Amazon S3 User Guide.
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
If you include the Filter element in a replication
configuration, you must also include the
DeleteMarkerReplication, Status, and
Priority elements. The response also returns those elements.
For information about S3 on Outposts replication failure reasons, see Replication failure reasons in the Amazon S3 User Guide.
The following operations are related to GetBucketReplication:
Parameter accountId :
The Amazon Web Services account ID of the Outposts bucket.
Parameter bucket :
Specifies the bucket to get the replication information for.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Implementation
Future<GetBucketReplicationResult> getBucketReplication({
required String accountId,
required String bucket,
}) async {
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/bucket/replication',
headers: headers,
endpoint: _resolveEndpoint(
requiresAccountId: true,
accountId: accountId,
bucket: bucket,
),
hostPrefix: '{AccountId}.',
exceptionFnMap: _exceptionFns,
);
return GetBucketReplicationResult.fromXml($result.body);
}