listAccessPoints method
maxResults, whichever is less), the
response will include a continuation token that you can use to list the
additional access points.
Returns only access points attached to S3 buckets by default. To return
all access points specify DataSourceType as ALL.
All Amazon S3 on Outposts REST API requests for this action require an
additional parameter of x-amz-outpost-id to be passed with
the request. In addition, you must use an S3 on Outposts endpoint hostname
prefix instead of s3-control. For an example of the request
syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint
hostname prefix and the x-amz-outpost-id derived by using the
access point ARN, see the Examples
section.
The following actions are related to ListAccessPoints:
Parameter accountId :
The Amazon Web Services account ID for the account that owns the specified
access points.
Parameter bucket :
The name of the bucket whose associated access points you want to list.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services
SDK and CLI, you must specify the ARN of the bucket accessed in the format
arn:aws:s3-outposts:.
For example, to access the bucket reports through Outpost
my-outpost owned by account 123456789012 in
Region us-west-2, use the URL encoding of
arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports.
The value must be URL encoded.
Parameter dataSourceId :
The unique identifier for the data source of the access point.
Parameter dataSourceType :
The type of the data source that the access point is attached to. Returns
only access points attached to S3 buckets by default. To return all access
points specify DataSourceType as ALL.
Parameter maxResults :
The maximum number of access points that you want to include in the list.
If the specified bucket has more than this number of access points, then
the response will include a continuation token in the
NextToken field that you can use to retrieve the next page of
access points.
Parameter nextToken :
A continuation token. If a previous call to ListAccessPoints
returned a continuation token in the NextToken field, then
providing that value here causes Amazon S3 to retrieve the next page of
results.
Implementation
Future<ListAccessPointsResult> listAccessPoints({
required String accountId,
String? bucket,
String? dataSourceId,
String? dataSourceType,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
1000,
);
final headers = <String, String>{
'x-amz-account-id': accountId.toString(),
};
final $query = <String, List<String>>{
if (bucket != null) 'bucket': [bucket],
if (dataSourceId != null) 'dataSourceId': [dataSourceId],
if (dataSourceType != null) 'dataSourceType': [dataSourceType],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final $result = await _protocol.send(
method: 'GET',
requestUri: '/v20180820/accesspoint',
queryParams: $query,
headers: headers,
exceptionFnMap: _exceptionFns,
);
return ListAccessPointsResult.fromXml($result.body);
}