getMountTarget method
Returns detailed resource information for the specified mount target including network configuration.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter mountTargetId :
The ID of the mount target to retrieve information for.
Implementation
Future<GetMountTargetResponse> getMountTarget({
required String mountTargetId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/mount-targets/${Uri.encodeComponent(mountTargetId)}',
exceptionFnMap: _exceptionFns,
);
return GetMountTargetResponse.fromJson(response);
}