listAccessPoints method
Returns resource information for all S3 File System Access Points associated with the specified S3 File System.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter fileSystemId :
The ID or Amazon Resource Name (ARN) of the S3 File System to list access
points for.
Parameter maxResults :
The maximum number of access points to return in a single response.
Parameter nextToken :
A pagination token returned from a previous call to continue listing
access points.
Implementation
Future<ListAccessPointsResponse> listAccessPoints({
required String fileSystemId,
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
'fileSystemId': [fileSystemId],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/access-points',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListAccessPointsResponse.fromJson(response);
}