tagResource method
Creates tags for S3 Files resources using standard Amazon Web Services tagging APIs.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter resourceId :
The ID or Amazon Resource Name (ARN) of the resource to add tags to.
Parameter tags :
An array of key-value pairs to add as tags to the resource.
Implementation
Future<void> tagResource({
required String resourceId,
required List<Tag> tags,
}) async {
final $payload = <String, dynamic>{
'tags': tags,
};
await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/resource-tags/${Uri.encodeComponent(resourceId)}',
exceptionFnMap: _exceptionFns,
);
}