S3Outposts class
Amazon S3 on Outposts provides access to S3 on Outposts operations.
Constructors
- S3Outposts({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createEndpoint(
{required String outpostId, required String securityGroupId, required String subnetId, EndpointAccessType? accessType, String? customerOwnedIpv4Pool}) → Future< CreateEndpointResult> - Creates an endpoint and associates it with the specified Outpost.
-
deleteEndpoint(
{required String endpointId, required String outpostId}) → Future< void> - Deletes an endpoint.
-
listEndpoints(
{int? maxResults, String? nextToken}) → Future< ListEndpointsResult> - Lists endpoints associated with the specified Outpost.
-
listOutpostsWithS3(
{int? maxResults, String? nextToken}) → Future< ListOutpostsWithS3Result> - Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services account. Includes S3 on Outposts that you have access to as the Outposts owner, or as a shared user from Resource Access Manager (RAM).
- Lists all endpoints associated with an Outpost that has been shared by Amazon Web Services Resource Access Manager (RAM).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited