listOutpostsWithS3 method
Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services account. Includes S3 on Outposts that you have access to as the Outposts owner, or as a shared user from Resource Access Manager (RAM).
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of Outposts to return. The limit is 100.
Parameter nextToken :
When you can get additional results from the
ListOutpostsWithS3 call, a NextToken parameter
is returned in the output. You can then pass in a subsequent command to
the NextToken parameter to continue listing additional
Outposts.
Implementation
Future<ListOutpostsWithS3Result> listOutpostsWithS3({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/S3Outposts/ListOutpostsWithS3',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListOutpostsWithS3Result.fromJson(response);
}