listSharedEndpoints method
Lists all endpoints associated with an Outpost that has been shared by Amazon Web Services Resource Access Manager (RAM).
Related actions include:
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter outpostId :
The ID of the Amazon Web Services Outpost.
Parameter maxResults :
The maximum number of endpoints that will be returned in the response.
Parameter nextToken :
If a previous response from this operation included a
NextToken value, you can provide that value here to retrieve
the next page of results.
Implementation
Future<ListSharedEndpointsResult> listSharedEndpoints({
required String outpostId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
0,
100,
);
final $query = <String, List<String>>{
'outpostId': [outpostId],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/S3Outposts/ListSharedEndpoints',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSharedEndpointsResult.fromJson(response);
}