createNamespace method
Creates a namespace. A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:CreateNamespacepermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter namespace :
A name for the namespace.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket to create the namespace
in.
Implementation
Future<CreateNamespaceResponse> createNamespace({
required List<String> namespace,
required String tableBucketARN,
}) async {
final $payload = <String, dynamic>{
'namespace': namespace,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri: '/namespaces/${Uri.encodeComponent(tableBucketARN)}',
exceptionFnMap: _exceptionFns,
);
return CreateNamespaceResponse.fromJson(response);
}