getTable method
Gets details about a table. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:GetTablepermission to use this operation.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter name :
The name of the table.
Parameter namespace :
The name of the namespace the table is associated with.
Parameter tableArn :
The Amazon Resource Name (ARN) of the table.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket associated with the
table.
Implementation
Future<GetTableResponse> getTable({
String? name,
String? namespace,
String? tableArn,
String? tableBucketARN,
}) async {
final $query = <String, List<String>>{
if (name != null) 'name': [name],
if (namespace != null) 'namespace': [namespace],
if (tableArn != null) 'tableArn': [tableArn],
if (tableBucketARN != null) 'tableBucketARN': [tableBucketARN],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/get-table',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return GetTableResponse.fromJson(response);
}