getTableBucketMaintenanceConfiguration method
Future<GetTableBucketMaintenanceConfigurationResponse>
getTableBucketMaintenanceConfiguration({
- required String tableBucketARN,
Gets details about a maintenance configuration for a given table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:GetTableBucketMaintenanceConfigurationpermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket associated with the
maintenance configuration.
Implementation
Future<GetTableBucketMaintenanceConfigurationResponse>
getTableBucketMaintenanceConfiguration({
required String tableBucketARN,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/buckets/${Uri.encodeComponent(tableBucketARN)}/maintenance',
exceptionFnMap: _exceptionFns,
);
return GetTableBucketMaintenanceConfigurationResponse.fromJson(response);
}