getTableBucketStorageClass method
Future<GetTableBucketStorageClassResponse>
getTableBucketStorageClass({
- required String tableBucketARN,
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.
- Permissions
-
You must have the
s3tables:GetTableBucketStorageClasspermission to use this operation.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket.
Implementation
Future<GetTableBucketStorageClassResponse> getTableBucketStorageClass({
required String tableBucketARN,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/buckets/${Uri.encodeComponent(tableBucketARN)}/storage-class',
exceptionFnMap: _exceptionFns,
);
return GetTableBucketStorageClassResponse.fromJson(response);
}