getTableMaintenanceConfiguration method
Gets details about the maintenance configuration of a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
- Permissions
-
-
You must have the
s3tables:GetTableMaintenanceConfigurationpermission to use this operation. -
You must have the
s3tables:GetTableDatapermission to use set the compaction strategy tosortorzorder.
-
You must have the
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter name :
The name of the table.
Parameter namespace :
The namespace associated with the table.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket.
Implementation
Future<GetTableMaintenanceConfigurationResponse>
getTableMaintenanceConfiguration({
required String name,
required String namespace,
required String tableBucketARN,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/tables/${Uri.encodeComponent(tableBucketARN)}/${Uri.encodeComponent(namespace)}/${Uri.encodeComponent(name)}/maintenance',
exceptionFnMap: _exceptionFns,
);
return GetTableMaintenanceConfigurationResponse.fromJson(response);
}