getTableMaintenanceJobStatus method
Gets the status of a maintenance job for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:GetTableMaintenanceJobStatuspermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter name :
The name of the table containing the maintenance job status you want to
check.
Parameter namespace :
The name of the namespace the table is associated with.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket.
Implementation
Future<GetTableMaintenanceJobStatusResponse> getTableMaintenanceJobStatus({
required String name,
required String namespace,
required String tableBucketARN,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/tables/${Uri.encodeComponent(tableBucketARN)}/${Uri.encodeComponent(namespace)}/${Uri.encodeComponent(name)}/maintenance-job-status',
exceptionFnMap: _exceptionFns,
);
return GetTableMaintenanceJobStatusResponse.fromJson(response);
}