getTableStorageClass method
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.
- Permissions
-
You must have the
s3tables:GetTableStorageClasspermission to use this operation.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter name :
The name of the table.
Parameter namespace :
The namespace associated with the table.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket that contains the
table.
Implementation
Future<GetTableStorageClassResponse> getTableStorageClass({
required String name,
required String namespace,
required String tableBucketARN,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/tables/${Uri.encodeComponent(tableBucketARN)}/${Uri.encodeComponent(namespace)}/${Uri.encodeComponent(name)}/storage-class',
exceptionFnMap: _exceptionFns,
);
return GetTableStorageClassResponse.fromJson(response);
}