putTableBucketStorageClass method
Future<void>
putTableBucketStorageClass({
- required StorageClassConfiguration storageClassConfiguration,
- required String tableBucketARN,
Sets or updates the storage class configuration for a table bucket. This configuration serves as the default storage class for all new tables created in the bucket, allowing you to optimize storage costs at the bucket level.
- Permissions
-
You must have the
s3tables:PutTableBucketStorageClasspermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter storageClassConfiguration :
The storage class configuration to apply to the table bucket. This
configuration will serve as the default for new tables created in this
bucket.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table bucket.
Implementation
Future<void> putTableBucketStorageClass({
required StorageClassConfiguration storageClassConfiguration,
required String tableBucketARN,
}) async {
final $payload = <String, dynamic>{
'storageClassConfiguration': storageClassConfiguration,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/buckets/${Uri.encodeComponent(tableBucketARN)}/storage-class',
exceptionFnMap: _exceptionFns,
);
}