putTableMaintenanceConfiguration method
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
- Permissions
-
You must have the
s3tables:PutTableMaintenanceConfigurationpermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter name :
The name of the table.
Parameter namespace :
The namespace of the table.
Parameter tableBucketARN :
The Amazon Resource Name (ARN) of the table associated with the
maintenance configuration.
Parameter type :
The type of the maintenance configuration.
Parameter value :
Defines the values of the maintenance configuration for the table.
Implementation
Future<void> putTableMaintenanceConfiguration({
required String name,
required String namespace,
required String tableBucketARN,
required TableMaintenanceType type,
required TableMaintenanceConfigurationValue value,
}) async {
final $payload = <String, dynamic>{
'value': value,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/tables/${Uri.encodeComponent(tableBucketARN)}/${Uri.encodeComponent(namespace)}/${Uri.encodeComponent(name)}/maintenance/${Uri.encodeComponent(type.value)}',
exceptionFnMap: _exceptionFns,
);
}