untagResource method
Removes the specified user-defined tags from an Amazon S3 Tables resource. You can pass one or more tag keys.
- Permissions
-
For tables and table buckets, you must have the
s3tables:UntagResourcepermission to use this operation.
May throw BadRequestException.
May throw ConflictException.
May throw ForbiddenException.
May throw InternalServerErrorException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Amazon S3 Tables resource that
you're removing tags from. The tagged resource can be a table bucket or a
table. For a list of all S3 resources that support tagging, see Managing
tags for Amazon S3 resources.
Parameter tagKeys :
The array of tag keys that you're removing from the S3 Tables resource.
For more information, see Tagging
for cost allocation or attribute-based access control (ABAC).
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tag/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}