getVectorBucketPolicy method
Gets details about a vector bucket policy. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
- Permissions
-
You must have the
s3vectors:GetVectorBucketPolicypermission to use this operation.
May throw NotFoundException.
May throw ServiceUnavailableException.
Parameter vectorBucketArn :
The ARN of the vector bucket.
Parameter vectorBucketName :
The name of the vector bucket.
Implementation
Future<GetVectorBucketPolicyOutput> getVectorBucketPolicy({
String? vectorBucketArn,
String? vectorBucketName,
}) async {
final $payload = <String, dynamic>{
if (vectorBucketArn != null) 'vectorBucketArn': vectorBucketArn,
if (vectorBucketName != null) 'vectorBucketName': vectorBucketName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetVectorBucketPolicy',
exceptionFnMap: _exceptionFns,
);
return GetVectorBucketPolicyOutput.fromJson(response);
}