listIndexes method
Returns a list of all the vector indexes within the specified vector bucket. To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
- Permissions
-
You must have the
s3vectors:ListIndexespermission to use this operation.
May throw NotFoundException.
May throw ServiceUnavailableException.
Parameter maxResults :
The maximum number of items to be returned in the response.
Parameter nextToken :
The previous pagination token.
Parameter prefix :
Limits the response to vector indexes that begin with the specified
prefix.
Parameter vectorBucketArn :
The ARN of the vector bucket that contains the vector indexes.
Parameter vectorBucketName :
The name of the vector bucket that contains the vector indexes.
Implementation
Future<ListIndexesOutput> listIndexes({
int? maxResults,
String? nextToken,
String? prefix,
String? vectorBucketArn,
String? vectorBucketName,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (prefix != null) 'prefix': prefix,
if (vectorBucketArn != null) 'vectorBucketArn': vectorBucketArn,
if (vectorBucketName != null) 'vectorBucketName': vectorBucketName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListIndexes',
exceptionFnMap: _exceptionFns,
);
return ListIndexesOutput.fromJson(response);
}