listVectorBuckets method
Returns a list of all the vector buckets that are owned by the authenticated sender of the request.
- Permissions
-
You must have the
s3vectors:ListVectorBucketspermission to use this operation.
May throw ServiceUnavailableException.
Parameter maxResults :
The maximum number of vector buckets to be returned in the response.
Parameter nextToken :
The previous pagination token.
Parameter prefix :
Limits the response to vector buckets that begin with the specified
prefix.
Implementation
Future<ListVectorBucketsOutput> listVectorBuckets({
int? maxResults,
String? nextToken,
String? prefix,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
500,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (prefix != null) 'prefix': prefix,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/ListVectorBuckets',
exceptionFnMap: _exceptionFns,
);
return ListVectorBucketsOutput.fromJson(response);
}