deleteCompilationJob method
Deletes the specified compilation job. This action deletes only the compilation job resource in Amazon SageMaker AI. It doesn't delete other resources that are related to that job, such as the model artifacts that the job creates, the compilation logs in CloudWatch, the compiled model, or the IAM role.
You can delete a compilation job only if its current status is
COMPLETED, FAILED, or STOPPED. If
the job status is STARTING or INPROGRESS, stop
the job, and then delete it after its status becomes STOPPED.
May throw ResourceNotFound.
Parameter compilationJobName :
The name of the compilation job to delete.
Implementation
Future<void> deleteCompilationJob({
required String compilationJobName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteCompilationJob'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CompilationJobName': compilationJobName,
},
);
}