deleteHubContentReference method
Delete a hub content reference in order to remove a model from a private hub.
May throw ResourceNotFound.
Parameter hubContentName :
The name of the hub content to delete.
Parameter hubContentType :
The type of hub content reference to delete. The only supported type of
hub content reference to delete is ModelReference.
Parameter hubName :
The name of the hub to delete the hub content reference from.
Implementation
Future<void> deleteHubContentReference({
required String hubContentName,
required HubContentType hubContentType,
required String hubName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.DeleteHubContentReference'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'HubContentName': hubContentName,
'HubContentType': hubContentType.value,
'HubName': hubName,
},
);
}