listInferenceRecommendationsJobSteps method
Returns a list of the subtasks for an Inference Recommender job.
The supported subtasks are benchmarks, which evaluate the performance of your model on different instance types.
May throw ResourceNotFound.
Parameter jobName :
The name for the Inference Recommender job.
Parameter maxResults :
The maximum number of results to return.
Parameter nextToken :
A token that you can specify to return more results from the list. Specify
this field if you have a token that was returned from a previous request.
Parameter status :
A filter to return benchmarks of a specified status. If this field is left
empty, then all benchmarks are returned.
Parameter stepType :
A filter to return details about the specified type of subtask.
BENCHMARK: Evaluate the performance of your model on
different instance types.
Implementation
Future<ListInferenceRecommendationsJobStepsResponse>
listInferenceRecommendationsJobSteps({
required String jobName,
int? maxResults,
String? nextToken,
RecommendationJobStatus? status,
RecommendationStepType? stepType,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.ListInferenceRecommendationsJobSteps'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'JobName': jobName,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (status != null) 'Status': status.value,
if (stepType != null) 'StepType': stepType.value,
},
);
return ListInferenceRecommendationsJobStepsResponse.fromJson(
jsonResponse.body);
}