listMlflowApps method
Lists all MLflow Apps
Parameter accountDefaultStatus :
Filter for MLflow Apps with the specified
AccountDefaultStatus.
Parameter createdAfter :
Use the CreatedAfter filter to only list MLflow Apps created
after a specific date and time. Listed MLflow Apps are shown with a date
and time such as "2024-03-16T01:46:56+00:00". The
CreatedAfter parameter takes in a Unix timestamp.
Parameter createdBefore :
Use the CreatedBefore filter to only list MLflow Apps created
before a specific date and time. Listed MLflow Apps are shown with a date
and time such as "2024-03-16T01:46:56+00:00". The
CreatedAfter parameter takes in a Unix timestamp.
Parameter defaultForDomainId :
Filter for MLflow Apps with the specified default SageMaker Domain ID.
Parameter maxResults :
The maximum number of MLflow Apps to list.
Parameter mlflowVersion :
Filter for Mlflow Apps with the specified version.
Parameter nextToken :
If the previous response was truncated, use this token in your next
request to receive the next set of results.
Parameter sortBy :
Filter for MLflow Apps sorting by name, creation time, or creation status.
Parameter sortOrder :
Change the order of the listed MLflow Apps. By default, MLflow Apps are
listed in Descending order by creation time. To change the
list order, specify SortOrder to be Ascending.
Parameter status :
Filter for Mlflow apps with a specific creation status.
Implementation
Future<ListMlflowAppsResponse> listMlflowApps({
AccountDefaultStatus? accountDefaultStatus,
DateTime? createdAfter,
DateTime? createdBefore,
String? defaultForDomainId,
int? maxResults,
String? mlflowVersion,
String? nextToken,
SortMlflowAppBy? sortBy,
SortOrder? sortOrder,
MlflowAppStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.ListMlflowApps'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (accountDefaultStatus != null)
'AccountDefaultStatus': accountDefaultStatus.value,
if (createdAfter != null)
'CreatedAfter': unixTimestampToJson(createdAfter),
if (createdBefore != null)
'CreatedBefore': unixTimestampToJson(createdBefore),
if (defaultForDomainId != null)
'DefaultForDomainId': defaultForDomainId,
if (maxResults != null) 'MaxResults': maxResults,
if (mlflowVersion != null) 'MlflowVersion': mlflowVersion,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
if (sortOrder != null) 'SortOrder': sortOrder.value,
if (status != null) 'Status': status.value,
},
);
return ListMlflowAppsResponse.fromJson(jsonResponse.body);
}