listModelMetadata method
Lists the domain, framework, task, and model name of standard machine learning models found in common model zoos.
Parameter maxResults :
The maximum number of models to return in the response.
Parameter nextToken :
If the response to a previous ListModelMetadataResponse
request was truncated, the response includes a NextToken. To retrieve the
next set of model metadata, use the token in the next request.
Parameter searchExpression :
One or more filters that searches for the specified resource or resources
in a search. All resource objects that satisfy the expression's condition
are included in the search results. Specify the Framework,
FrameworkVersion, Domain or Task to filter supported. Filter names and
values are case-sensitive.
Implementation
Future<ListModelMetadataResponse> listModelMetadata({
int? maxResults,
String? nextToken,
ModelMetadataSearchExpression? searchExpression,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.ListModelMetadata'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (searchExpression != null) 'SearchExpression': searchExpression,
},
);
return ListModelMetadataResponse.fromJson(jsonResponse.body);
}