listStudioLifecycleConfigs method
Lists the Amazon SageMaker AI Studio Lifecycle Configurations in your Amazon Web Services Account.
May throw ResourceInUse.
Parameter appTypeEquals :
A parameter to search for the App Type to which the Lifecycle
Configuration is attached.
Parameter creationTimeAfter :
A filter that returns only Lifecycle Configurations created on or after
the specified time.
Parameter creationTimeBefore :
A filter that returns only Lifecycle Configurations created on or before
the specified time.
Parameter maxResults :
The total number of items to return in the response. If the total number
of items available is more than the value specified, a
NextToken is provided in the response. To resume pagination,
provide the NextToken value in the as part of a subsequent
call. The default value is 10.
Parameter modifiedTimeAfter :
A filter that returns only Lifecycle Configurations modified after the
specified time.
Parameter modifiedTimeBefore :
A filter that returns only Lifecycle Configurations modified before the
specified time.
Parameter nameContains :
A string in the Lifecycle Configuration name. This filter returns only
Lifecycle Configurations whose name contains the specified string.
Parameter nextToken :
If the previous call to ListStudioLifecycleConfigs didn't return the full
set of Lifecycle Configurations, the call returns a token for getting the
next set of Lifecycle Configurations.
Parameter sortBy :
The property used to sort results. The default value is CreationTime.
Parameter sortOrder :
The sort order. The default value is Descending.
Implementation
Future<ListStudioLifecycleConfigsResponse> listStudioLifecycleConfigs({
StudioLifecycleConfigAppType? appTypeEquals,
DateTime? creationTimeAfter,
DateTime? creationTimeBefore,
int? maxResults,
DateTime? modifiedTimeAfter,
DateTime? modifiedTimeBefore,
String? nameContains,
String? nextToken,
StudioLifecycleConfigSortKey? sortBy,
SortOrder? sortOrder,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.ListStudioLifecycleConfigs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (appTypeEquals != null) 'AppTypeEquals': appTypeEquals.value,
if (creationTimeAfter != null)
'CreationTimeAfter': unixTimestampToJson(creationTimeAfter),
if (creationTimeBefore != null)
'CreationTimeBefore': unixTimestampToJson(creationTimeBefore),
if (maxResults != null) 'MaxResults': maxResults,
if (modifiedTimeAfter != null)
'ModifiedTimeAfter': unixTimestampToJson(modifiedTimeAfter),
if (modifiedTimeBefore != null)
'ModifiedTimeBefore': unixTimestampToJson(modifiedTimeBefore),
if (nameContains != null) 'NameContains': nameContains,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy.value,
if (sortOrder != null) 'SortOrder': sortOrder.value,
},
);
return ListStudioLifecycleConfigsResponse.fromJson(jsonResponse.body);
}