startSession method
Initiates a remote connection session between a local integrated development environments (IDEs) and a remote SageMaker space.
May throw ResourceLimitExceeded.
May throw ResourceNotFound.
Parameter resourceIdentifier :
The Amazon Resource Name (ARN) of the resource to which the remote
connection will be established. For example, this identifies the specific
ARN space application you want to connect to from your local IDE.
Implementation
Future<StartSessionResponse> startSession({
required String resourceIdentifier,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.StartSession'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceIdentifier': resourceIdentifier,
},
);
return StartSessionResponse.fromJson(jsonResponse.body);
}