updateFeatureMetadata method
Updates the description and parameters of the feature group.
May throw ResourceNotFound.
Parameter featureGroupName :
The name or Amazon Resource Name (ARN) of the feature group containing the
feature that you're updating.
Parameter featureName :
The name of the feature that you're updating.
Parameter description :
A description that you can write to better describe the feature.
Parameter parameterAdditions :
A list of key-value pairs that you can add to better describe the feature.
Parameter parameterRemovals :
A list of parameter keys that you can specify to remove parameters that
describe your feature.
Implementation
Future<void> updateFeatureMetadata({
required String featureGroupName,
required String featureName,
String? description,
List<FeatureParameter>? parameterAdditions,
List<String>? parameterRemovals,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.UpdateFeatureMetadata'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FeatureGroupName': featureGroupName,
'FeatureName': featureName,
if (description != null) 'Description': description,
if (parameterAdditions != null)
'ParameterAdditions': parameterAdditions,
if (parameterRemovals != null) 'ParameterRemovals': parameterRemovals,
},
);
}