updateHubContentReference method
Updates the contents of a SageMaker hub for a ModelReference
resource. A ModelReference allows you to access public
SageMaker JumpStart models from within your private hub.
When using this API, you can update the MinVersion field for
additional flexibility in the model version. You shouldn't update any
additional fields when using this API, because the metadata in your
private hub should match the public JumpStart model's metadata.
For more information about adding model references to your hub, see
Add models to a private hub.
May throw ResourceInUse.
May throw ResourceNotFound.
Parameter hubContentName :
The name of the hub content resource that you want to update.
Parameter hubContentType :
The content type of the resource that you want to update. Only specify a
ModelReference resource for this API. To update a
Model or Notebook resource, use the
UpdateHubContent API instead.
Parameter hubName :
The name of the SageMaker hub that contains the hub content you want to
update. You can optionally use the hub ARN instead.
Parameter minVersion :
The minimum hub content version of the referenced model that you want to
use. The minimum version must be older than the latest available version
of the referenced model. To support all versions of a model, set the value
to 1.0.0.
Implementation
Future<UpdateHubContentReferenceResponse> updateHubContentReference({
required String hubContentName,
required HubContentType hubContentType,
required String hubName,
String? minVersion,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.UpdateHubContentReference'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'HubContentName': hubContentName,
'HubContentType': hubContentType.value,
'HubName': hubName,
if (minVersion != null) 'MinVersion': minVersion,
},
);
return UpdateHubContentReferenceResponse.fromJson(jsonResponse.body);
}