updateMlflowTrackingServer method
Updates properties of an existing MLflow Tracking Server.
May throw ConflictException.
May throw ResourceLimitExceeded.
May throw ResourceNotFound.
Parameter trackingServerName :
The name of the MLflow Tracking Server to update.
Parameter artifactStoreUri :
The new S3 URI for the general purpose bucket to use as the artifact store
for the MLflow Tracking Server.
Parameter automaticModelRegistration :
Whether to enable or disable automatic registration of new MLflow models
to the SageMaker Model Registry. To enable automatic model registration,
set this value to True. To disable automatic model
registration, set this value to False. If not specified,
AutomaticModelRegistration defaults to False
Parameter s3BucketOwnerAccountId :
The new expected Amazon Web Services account ID that owns the Amazon S3
bucket for artifact storage.
Parameter s3BucketOwnerVerification :
Whether to enable or disable Amazon S3 Bucket Owenrship Verifaction
whenever the MLflow Tracking Server interacts with Amazon Amazon S3.
Parameter trackingServerSize :
The new size for the MLflow Tracking Server.
Parameter weeklyMaintenanceWindowStart :
The new weekly maintenance window start day and time to update. The
maintenance window day and time should be in Coordinated Universal Time
(UTC) 24-hour standard time. For example: TUE:03:30.
Implementation
Future<UpdateMlflowTrackingServerResponse> updateMlflowTrackingServer({
required String trackingServerName,
String? artifactStoreUri,
bool? automaticModelRegistration,
String? s3BucketOwnerAccountId,
bool? s3BucketOwnerVerification,
TrackingServerSize? trackingServerSize,
String? weeklyMaintenanceWindowStart,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SageMaker.UpdateMlflowTrackingServer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TrackingServerName': trackingServerName,
if (artifactStoreUri != null) 'ArtifactStoreUri': artifactStoreUri,
if (automaticModelRegistration != null)
'AutomaticModelRegistration': automaticModelRegistration,
if (s3BucketOwnerAccountId != null)
'S3BucketOwnerAccountId': s3BucketOwnerAccountId,
if (s3BucketOwnerVerification != null)
'S3BucketOwnerVerification': s3BucketOwnerVerification,
if (trackingServerSize != null)
'TrackingServerSize': trackingServerSize.value,
if (weeklyMaintenanceWindowStart != null)
'WeeklyMaintenanceWindowStart': weeklyMaintenanceWindowStart,
},
);
return UpdateMlflowTrackingServerResponse.fromJson(jsonResponse.body);
}