deleteHumanLoop method
Deletes the specified human loop for a flow definition.
If the human loop was deleted, this operation will return a
ResourceNotFoundException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter humanLoopName :
The name of the human loop that you want to delete.
Implementation
Future<void> deleteHumanLoop({
required String humanLoopName,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/human-loops/${Uri.encodeComponent(humanLoopName)}',
exceptionFnMap: _exceptionFns,
);
}