SageMakerFeatureStoreRuntime class
Contains all data plane API operations and data types for the Amazon SageMaker Feature Store. Use this API to put, delete, and retrieve (get) features from a feature store.
Use the following operations to configure your OnlineStore and
OfflineStore features, and to create and manage feature groups:
Constructors
- SageMakerFeatureStoreRuntime({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetRecord(
{required List< BatchGetRecordIdentifier> identifiers, ExpirationTimeResponse? expirationTimeResponse}) → Future<BatchGetRecordResponse> -
Retrieves a batch of
Recordsfrom aFeatureGroup. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
deleteRecord(
{required String eventTime, required String featureGroupName, required String recordIdentifierValueAsString, DeletionMode? deletionMode, List< TargetStore> ? targetStores}) → Future<void> -
Deletes a
Recordfrom aFeatureGroupin theOnlineStore. Feature Store supports bothSoftDeleteandHardDelete. ForSoftDelete(default), feature columns are set tonulland the record is no longer retrievable byGetRecordorBatchGetRecord. ForHardDelete, the completeRecordis removed from theOnlineStore. In both cases, Feature Store appends the deleted record marker to theOfflineStore. The deleted record marker is a record with the sameRecordIdentiferas the original, but withis_deletedvalue set toTrue,EventTimeset to the delete inputEventTime, and other feature values set tonull. -
getRecord(
{required String featureGroupName, required String recordIdentifierValueAsString, ExpirationTimeResponse? expirationTimeResponse, List< String> ? featureNames}) → Future<GetRecordResponse> -
Use for
OnlineStoreserving from aFeatureStore. Only the latest records stored in theOnlineStorecan be retrieved. If no Record withRecordIdentifierValueis found, then an empty result is returned. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putRecord(
{required String featureGroupName, required List< FeatureValue> record, List<TargetStore> ? targetStores, TtlDuration? ttlDuration}) → Future<void> -
The
PutRecordAPI is used to ingest a list ofRecordsinto your feature group. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited