listRasterDataCollections method
Use this operation to get raster data collections.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The total number of items to return.
Parameter nextToken :
If the previous response was truncated, you receive this token. Use it in
your next request to receive the next set of results.
Implementation
Future<ListRasterDataCollectionsOutput> listRasterDataCollections({
int? maxResults,
String? nextToken,
}) async {
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/raster-data-collections',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListRasterDataCollectionsOutput.fromJson(response);
}