listVectorEnrichmentJobs method
Retrieves a list of vector enrichment jobs.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of items to return.
Parameter nextToken :
If the previous response was truncated, you receive this token. Use it in
your next request to receive the next set of results.
Parameter sortBy :
The parameter by which to sort the results.
Parameter sortOrder :
An optional value that specifies whether you want the results sorted in
Ascending or Descending order.
Parameter statusEquals :
A filter that retrieves only jobs with a specific status.
Implementation
Future<ListVectorEnrichmentJobOutput> listVectorEnrichmentJobs({
int? maxResults,
String? nextToken,
String? sortBy,
SortOrder? sortOrder,
String? statusEquals,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (sortBy != null) 'SortBy': sortBy,
if (sortOrder != null) 'SortOrder': sortOrder.value,
if (statusEquals != null) 'StatusEquals': statusEquals,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-vector-enrichment-jobs',
exceptionFnMap: _exceptionFns,
);
return ListVectorEnrichmentJobOutput.fromJson(response);
}