SageMakerMetrics class
Contains all data plane API operations and data types for Amazon SageMaker Metrics. Use these APIs to put and retrieve (get) features related to your training run.
Constructors
- SageMakerMetrics({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGetMetrics(
{required List< MetricQuery> metricQueries}) → Future<BatchGetMetricsResponse> - Used to retrieve training metrics from SageMaker.
-
batchPutMetrics(
{required List< RawMetricData> metricData, required String trialComponentName}) → Future<BatchPutMetricsResponse> - Used to ingest training metrics into SageMaker. These metrics can be visualized in SageMaker Studio.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited