SageMakerRuntimeHttp2 class
The Amazon SageMaker AI runtime HTTP/2 API.
Constructors
- SageMakerRuntimeHttp2({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
invokeEndpointWithBidirectionalStream(
{required RequestStreamEvent body, required String endpointName, String? modelInvocationPath, String? modelQueryString, String? targetVariant}) → Future< InvokeEndpointWithBidirectionalStreamOutput> - Invokes a model endpoint with bidirectional streaming capabilities. This operation establishes a persistent connection that allows you to send multiple requests and receive streaming responses from the model in real-time.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited