deleteScheduleGroup method
Deletes the specified schedule group. Deleting a schedule group results in
EventBridge Scheduler deleting all schedules associated with the group.
When you delete a group, it remains in a DELETING state until
all of its associated schedules are deleted. Schedules associated with the
group that are set to run while the schedule group is in the process of
being deleted might continue to invoke their targets until the schedule
group and its associated schedules are deleted.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter name :
The name of the schedule group to delete.
Parameter clientToken :
Unique, case-sensitive identifier you provide to ensure the idempotency of
the request. If you do not specify a client token, EventBridge Scheduler
uses a randomly generated token for the request to ensure idempotency.
Implementation
Future<void> deleteScheduleGroup({
required String name,
String? clientToken,
}) async {
final $query = <String, List<String>>{
if (clientToken != null) 'clientToken': [clientToken],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/schedule-groups/${Uri.encodeComponent(name)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}