listScheduleGroups method
Returns a paginated list of your schedule groups.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
If specified, limits the number of results returned by this operation. The
operation also returns a NextToken which you can use in a
subsequent operation to retrieve the next set of results.
Parameter namePrefix :
The name prefix that you can use to return a filtered list of your
schedule groups.
Parameter nextToken :
The token returned by a previous call to retrieve the next set of results.
Implementation
Future<ListScheduleGroupsOutput> listScheduleGroups({
int? maxResults,
String? namePrefix,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (namePrefix != null) 'NamePrefix': [namePrefix],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/schedule-groups',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListScheduleGroupsOutput.fromJson(response);
}