cancelRotateSecret method
Turns off automatic rotation, and if a rotation is currently in progress, cancels the rotation.
If you cancel a rotation in progress, it can leave the
VersionStage labels in an unexpected state. You might need to
remove the staging label AWSPENDING from the partially
created version. You also need to determine whether to roll back to the
previous version of the secret by moving the staging label
AWSCURRENT to the version that has AWSPENDING.
To determine which version has a specific staging label, call
ListSecretVersionIds. Then use UpdateSecretVersionStage to
change staging labels. For more information, see How
rotation works.
To turn on automatic rotation again, call RotateSecret.
Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions:
secretsmanager:CancelRotateSecret. For more information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter secretId :
The ARN or name of the secret.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Implementation
Future<CancelRotateSecretResponse> cancelRotateSecret({
required String secretId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.CancelRotateSecret'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
},
);
return CancelRotateSecretResponse.fromJson(jsonResponse.body);
}