listSecretVersionIds method
Lists the versions of a secret. Secrets Manager uses staging labels to indicate the different versions of a secret. For more information, see Secrets Manager concepts: Versions.
To list the secrets in the account, use ListSecrets.
Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions:
secretsmanager:ListSecretVersionIds. For more information,
see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidNextTokenException.
May throw InvalidParameterException.
May throw ResourceNotFoundException.
Parameter secretId :
The ARN or name of the secret whose versions you want to list.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Parameter includeDeprecated :
Specifies whether to include versions of secrets that don't have any
staging labels attached to them. Versions without staging labels are
considered deprecated and are subject to deletion by Secrets Manager. By
default, versions without staging labels aren't included.
Parameter maxResults :
The number of results to include in the response.
If there are more results available, in the response, Secrets Manager
includes NextToken. To get the next results, call
ListSecretVersionIds again with the value from
NextToken.
Parameter nextToken :
A token that indicates where the output should continue from, if a
previous call did not show all results. To get the next results, call
ListSecretVersionIds again with this value.
Implementation
Future<ListSecretVersionIdsResponse> listSecretVersionIds({
required String secretId,
bool? includeDeprecated,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.ListSecretVersionIds'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
if (includeDeprecated != null) 'IncludeDeprecated': includeDeprecated,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListSecretVersionIdsResponse.fromJson(jsonResponse.body);
}