tagResource method
Attaches tags to a secret. Tags consist of a key name and a value. Tags are part of the secret's metadata. They are not associated with specific versions of the secret. This operation appends tags to the existing list of tags.
For tag quotas and naming restrictions, see Service quotas for Tagging in the Amazon Web Services General Reference guide. Secrets Manager generates a CloudTrail log entry when you call this action. Do not include sensitive information in request parameters because it might be logged. For more information, see Logging Secrets Manager events with CloudTrail.
Required permissions: secretsmanager:TagResource. For
more information, see
IAM policy actions for Secrets Manager and Authentication
and access control in Secrets Manager.
May throw InternalServiceError.
May throw InvalidParameterException.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
Parameter secretId :
The identifier for the secret to attach tags to. You can specify either
the Amazon Resource Name (ARN) or the friendly name of the secret.
For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
Parameter tags :
The tags to attach to the secret as a JSON text string argument. Each
element in the list consists of a Key and a
Value.
For storing multiple values, we recommend that you use a JSON text string argument and specify key/value pairs. For more information, see Specifying parameter values for the Amazon Web Services CLI in the Amazon Web Services CLI User Guide.
Implementation
Future<void> tagResource({
required String secretId,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'secretsmanager.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'SecretId': secretId,
'Tags': tags,
},
);
}