batchGetCodeReviewJobTasks method
Retrieves information about one or more tasks within a code review job.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the tasks.
Parameter codeReviewJobTaskIds :
The list of task identifiers to retrieve.
Implementation
Future<BatchGetCodeReviewJobTasksOutput> batchGetCodeReviewJobTasks({
required String agentSpaceId,
required List<String> codeReviewJobTaskIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'codeReviewJobTaskIds': codeReviewJobTaskIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchGetCodeReviewJobTasks',
exceptionFnMap: _exceptionFns,
);
return BatchGetCodeReviewJobTasksOutput.fromJson(response);
}