batchGetCodeReviewJobs method
Retrieves information about one or more code review jobs in an agent space.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the code review
jobs.
Parameter codeReviewJobIds :
The list of code review job identifiers to retrieve.
Implementation
Future<BatchGetCodeReviewJobsOutput> batchGetCodeReviewJobs({
required String agentSpaceId,
required List<String> codeReviewJobIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'codeReviewJobIds': codeReviewJobIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchGetCodeReviewJobs',
exceptionFnMap: _exceptionFns,
);
return BatchGetCodeReviewJobsOutput.fromJson(response);
}