batchGetPentestJobTasks method
Retrieves information about one or more tasks within a pentest job.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the tasks.
Parameter taskIds :
The list of task identifiers to retrieve.
Implementation
Future<BatchGetPentestJobTasksOutput> batchGetPentestJobTasks({
required String agentSpaceId,
required List<String> taskIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'taskIds': taskIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchGetPentestJobTasks',
exceptionFnMap: _exceptionFns,
);
return BatchGetPentestJobTasksOutput.fromJson(response);
}