batchGetPentests method
Retrieves information about one or more pentests in an agent space.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the pentests.
Parameter pentestIds :
The list of pentest identifiers to retrieve.
Implementation
Future<BatchGetPentestsOutput> batchGetPentests({
required String agentSpaceId,
required List<String> pentestIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'pentestIds': pentestIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/BatchGetPentests',
exceptionFnMap: _exceptionFns,
);
return BatchGetPentestsOutput.fromJson(response);
}