deleteAgentSpace method
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
Parameter agentSpaceId :
The unique identifier of the agent space to delete.
Implementation
Future<DeleteAgentSpaceOutput> deleteAgentSpace({
required String agentSpaceId,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/DeleteAgentSpace',
exceptionFnMap: _exceptionFns,
);
return DeleteAgentSpaceOutput.fromJson(response);
}