startPentestJob method
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
Parameter agentSpaceId :
The unique identifier of the agent space.
Parameter pentestId :
The unique identifier of the pentest to start a job for.
Implementation
Future<StartPentestJobOutput> startPentestJob({
required String agentSpaceId,
required String pentestId,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'pentestId': pentestId,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/StartPentestJob',
exceptionFnMap: _exceptionFns,
);
return StartPentestJobOutput.fromJson(response);
}