updateAgentSpace method
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
Parameter agentSpaceId :
The unique identifier of the agent space to update.
Parameter awsResources :
The updated AWS resources to associate with the agent space.
Parameter codeReviewSettings :
The updated code review settings for the agent space.
Parameter description :
The updated description of the agent space.
Parameter name :
The updated name of the agent space.
Parameter targetDomainIds :
The updated list of target domain identifiers to associate with the agent
space.
Implementation
Future<UpdateAgentSpaceOutput> updateAgentSpace({
required String agentSpaceId,
AWSResources? awsResources,
CodeReviewSettings? codeReviewSettings,
String? description,
String? name,
List<String>? targetDomainIds,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
if (awsResources != null) 'awsResources': awsResources,
if (codeReviewSettings != null) 'codeReviewSettings': codeReviewSettings,
if (description != null) 'description': description,
if (name != null) 'name': name,
if (targetDomainIds != null) 'targetDomainIds': targetDomainIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateAgentSpace',
exceptionFnMap: _exceptionFns,
);
return UpdateAgentSpaceOutput.fromJson(response);
}