updateFinding method
Updates the status or risk level of a security finding.
Parameter agentSpaceId :
The unique identifier of the agent space that contains the finding.
Parameter findingId :
The unique identifier of the finding to update.
Parameter riskLevel :
The updated risk level for the finding.
Parameter status :
The updated status for the finding.
Implementation
Future<void> updateFinding({
required String agentSpaceId,
required String findingId,
RiskLevel? riskLevel,
FindingStatus? status,
}) async {
final $payload = <String, dynamic>{
'agentSpaceId': agentSpaceId,
'findingId': findingId,
if (riskLevel != null) 'riskLevel': riskLevel.value,
if (status != null) 'status': status.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/UpdateFinding',
exceptionFnMap: _exceptionFns,
);
}