batchGetSecurityControls method
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter securityControlIds :
A list of security controls (identified with
SecurityControlId, SecurityControlArn, or a mix
of both parameters). The security control ID or Amazon Resource Name (ARN)
is the same across standards.
Implementation
Future<BatchGetSecurityControlsResponse> batchGetSecurityControls({
required List<String> securityControlIds,
}) async {
final $payload = <String, dynamic>{
'SecurityControlIds': securityControlIds,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/securityControls/batchGet',
exceptionFnMap: _exceptionFns,
);
return BatchGetSecurityControlsResponse.fromJson(response);
}