batchUpdateStandardsControlAssociations method
Future<BatchUpdateStandardsControlAssociationsResponse>
batchUpdateStandardsControlAssociations({
- required List<
StandardsControlAssociationUpdate> standardsControlAssociationUpdates,
For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter standardsControlAssociationUpdates :
Updates the enablement status of a security control in a specified
standard.
Calls to this operation return a RESOURCE_NOT_FOUND_EXCEPTION
error when the standard subscription for the control has
StandardsControlsUpdatable value
NOT_READY_FOR_UPDATES.
Implementation
Future<BatchUpdateStandardsControlAssociationsResponse>
batchUpdateStandardsControlAssociations({
required List<StandardsControlAssociationUpdate>
standardsControlAssociationUpdates,
}) async {
final $payload = <String, dynamic>{
'StandardsControlAssociationUpdates': standardsControlAssociationUpdates,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/associations',
exceptionFnMap: _exceptionFns,
);
return BatchUpdateStandardsControlAssociationsResponse.fromJson(response);
}