deleteConfigurationPolicy method
Deletes a configuration policy. Only the Security Hub CSPM delegated
administrator can invoke this operation from the home Region. For the
deletion to succeed, you must first disassociate a configuration policy
from target accounts, organizational units, or the root by invoking the
StartConfigurationPolicyDisassociation operation.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceConflictException.
May throw ResourceNotFoundException.
Parameter identifier :
The Amazon Resource Name (ARN) or universally unique identifier (UUID) of
the configuration policy.
Implementation
Future<void> deleteConfigurationPolicy({
required String identifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/configurationPolicy/${Uri.encodeComponent(identifier)}',
exceptionFnMap: _exceptionFns,
);
}