describeHub method
Returns details about the Hub resource in your account, including the
HubArn and the time when you enabled Security Hub CSPM.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter hubArn :
The ARN of the Hub resource to retrieve.
Implementation
Future<DescribeHubResponse> describeHub({
String? hubArn,
}) async {
final $query = <String, List<String>>{
if (hubArn != null) 'HubArn': [hubArn],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/accounts',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return DescribeHubResponse.fromJson(response);
}