disableOrganizationAdminAccount method
Future<void>
disableOrganizationAdminAccount({
- required String adminAccountId,
- SecurityHubFeature? feature,
Disables a Security Hub CSPM administrator account. Can only be called by the organization management account.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter adminAccountId :
The Amazon Web Services account identifier of the Security Hub CSPM
administrator account.
Parameter feature :
The feature for which the delegated admin account is disabled. Defaults to
Security Hub CSPM if not specified.
Implementation
Future<void> disableOrganizationAdminAccount({
required String adminAccountId,
SecurityHubFeature? feature,
}) async {
final $payload = <String, dynamic>{
'AdminAccountId': adminAccountId,
if (feature != null) 'Feature': feature.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/organization/admin/disable',
exceptionFnMap: _exceptionFns,
);
}