listConfigurationPolicyAssociations method
Provides information about the associations for your configuration policies and self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter filters :
Options for filtering the ListConfigurationPolicyAssociations
response. You can filter by the Amazon Resource Name (ARN) or universally
unique identifier (UUID) of a configuration, AssociationType,
or AssociationStatus.
Parameter maxResults :
The maximum number of results that's returned by
ListConfigurationPolicies in each page of the response. When
this parameter is used, ListConfigurationPolicyAssociations
returns the specified number of results in a single page and a
NextToken response element. You can see the remaining results
of the initial request by sending another
ListConfigurationPolicyAssociations request with the returned
NextToken value. A valid range for MaxResults is
between 1 and 100.
Parameter nextToken :
The NextToken value that's returned from a previous paginated
ListConfigurationPolicyAssociations request where
MaxResults was used but the results exceeded the value of
that parameter. Pagination continues from the end of the previous response
that returned the NextToken value. This value is
null when there are no more results to return.
Implementation
Future<ListConfigurationPolicyAssociationsResponse>
listConfigurationPolicyAssociations({
AssociationFilters? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/configurationPolicyAssociation/list',
exceptionFnMap: _exceptionFns,
);
return ListConfigurationPolicyAssociationsResponse.fromJson(response);
}