listFindingAggregators method
If cross-Region aggregation is enabled, then
ListFindingAggregators returns the Amazon Resource Name (ARN)
of the finding aggregator. You can run this operation from any Amazon Web
Services Region.
May throw AccessDeniedException.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
Parameter maxResults :
The maximum number of results to return. This operation currently only
returns a single result.
Parameter nextToken :
The token returned with the previous set of results. Identifies the next
set of results to return.
Implementation
Future<ListFindingAggregatorsResponse> listFindingAggregators({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'MaxResults': [maxResults.toString()],
if (nextToken != null) 'NextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/findingAggregator/list',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListFindingAggregatorsResponse.fromJson(response);
}