updateAggregatorV2 method
Udpates the configuration for the Aggregator V2.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter aggregatorV2Arn :
The ARN of the Aggregator V2.
Parameter regionLinkingMode :
Determines how Amazon Web Services Regions should be linked to the
Aggregator V2.
Parameter linkedRegions :
A list of Amazon Web Services Regions linked to the aggegation Region.
Implementation
Future<UpdateAggregatorV2Response> updateAggregatorV2({
required String aggregatorV2Arn,
required String regionLinkingMode,
List<String>? linkedRegions,
}) async {
final $payload = <String, dynamic>{
'RegionLinkingMode': regionLinkingMode,
if (linkedRegions != null) 'LinkedRegions': linkedRegions,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/aggregatorv2/update/${aggregatorV2Arn.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
return UpdateAggregatorV2Response.fromJson(response);
}