updateFindings method
- required AwsSecurityFindingFilters filters,
- NoteUpdate? note,
- RecordState? recordState,
UpdateFindings is a deprecated operation. Instead of
UpdateFindings, use the BatchUpdateFindings
operation.
The UpdateFindings operation updates the Note
and RecordState of the Security Hub CSPM aggregated findings
that the filter attributes specify. Any member account that can view the
finding can also see the update to the finding.
Finding updates made with UpdateFindings aren't persisted if
the same finding is later updated by the finding provider through the
BatchImportFindings operation. In addition, Security Hub CSPM
doesn't record updates made with UpdateFindings in the
finding history.
May throw InternalException.
May throw InvalidAccessException.
May throw InvalidInputException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
Parameter filters :
A collection of attributes that specify which findings you want to update.
Parameter note :
The updated note for the finding.
Parameter recordState :
The updated record state for the finding.
Implementation
Future<void> updateFindings({
required AwsSecurityFindingFilters filters,
NoteUpdate? note,
RecordState? recordState,
}) async {
final $payload = <String, dynamic>{
'Filters': filters,
if (note != null) 'Note': note,
if (recordState != null) 'RecordState': recordState.value,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/findings',
exceptionFnMap: _exceptionFns,
);
}