listCaseEdits method
Views the case history for edits made to a designated case.
Parameter caseId :
Required element used with ListCaseEdits to identify the case to query.
Parameter maxResults :
Optional element to identify how many results to obtain. There is a
maximum value of 25.
Parameter nextToken :
An optional string that, if supplied, must be copied from the output of a
previous call to ListCaseEdits. When provided in this manner, the API
fetches the next page of results.
Implementation
Future<ListCaseEditsResponse> listCaseEdits({
required String caseId,
int? maxResults,
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/cases/${Uri.encodeComponent(caseId)}/list-case-edits',
exceptionFnMap: _exceptionFns,
);
return ListCaseEditsResponse.fromJson(response);
}