createDataLake method
Initializes an Amazon Security Lake instance with the provided (or
default) configuration. You can enable Security Lake in Amazon Web
Services Regions with customized settings before enabling log collection
in Regions. To specify particular Regions, configure these Regions using
the configurations parameter. If you have already enabled
Security Lake in a Region when you call this command, the command will
update the Region if you provide new configuration parameters. If you have
not already enabled Security Lake in the Region when you call this API, it
will set up the data lake in the Region with the specified configurations.
When you enable Security Lake, it starts ingesting security data after the
CreateAwsLogSource call and after you create subscribers
using the CreateSubscriber API. This includes ingesting
security data from sources, storing data, and making data accessible to
subscribers. Security Lake also enables all the existing settings and
resources that it stores or maintains for your Amazon Web Services account
in the current Region, including security log and event data. For more
information, see the Amazon
Security Lake User Guide.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter configurations :
Specify the Region or Regions that will contribute data to the rollup
region.
Parameter metaStoreManagerRoleArn :
The Amazon Resource Name (ARN) used to create and update the Glue table.
This table contains partitions generated by the ingestion and
normalization of Amazon Web Services log sources and custom sources.
Parameter tags :
An array of objects, one for each tag to associate with the data lake
configuration. For each tag, you must specify both a tag key and a tag
value. A tag value cannot be null, but it can be an empty string.
Implementation
Future<CreateDataLakeResponse> createDataLake({
required List<DataLakeConfiguration> configurations,
required String metaStoreManagerRoleArn,
List<Tag>? tags,
}) async {
final $payload = <String, dynamic>{
'configurations': configurations,
'metaStoreManagerRoleArn': metaStoreManagerRoleArn,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/datalake',
exceptionFnMap: _exceptionFns,
);
return CreateDataLakeResponse.fromJson(response);
}