createDataLakeExceptionSubscription method
Creates the specified notification subscription in Amazon Security Lake for the organization you specify. The notification subscription is created for exceptions that cannot be resolved by Security Lake automatically.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter notificationEndpoint :
The Amazon Web Services account where you want to receive exception
notifications.
Parameter subscriptionProtocol :
The subscription protocol to which exception notifications are posted.
Parameter exceptionTimeToLive :
The expiration period and time-to-live (TTL). It is the duration of time
until which the exception message remains.
Implementation
Future<void> createDataLakeExceptionSubscription({
required String notificationEndpoint,
required String subscriptionProtocol,
int? exceptionTimeToLive,
}) async {
final $payload = <String, dynamic>{
'notificationEndpoint': notificationEndpoint,
'subscriptionProtocol': subscriptionProtocol,
if (exceptionTimeToLive != null)
'exceptionTimeToLive': exceptionTimeToLive,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/datalake/exceptions/subscription',
exceptionFnMap: _exceptionFns,
);
}