deleteSubscriber method
Deletes the subscription permission and all notification settings for
accounts that are already enabled in Amazon Security Lake. When you run
DeleteSubscriber, the subscriber will no longer consume data
from Security Lake and the subscriber is removed. This operation deletes
the subscriber and removes access to data in the current Amazon Web
Services Region.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter subscriberId :
A value created by Security Lake that uniquely identifies your
DeleteSubscriber API request.
Implementation
Future<void> deleteSubscriber({
required String subscriberId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/v1/subscribers/${Uri.encodeComponent(subscriberId)}',
exceptionFnMap: _exceptionFns,
);
}