listDataLakes method
Retrieves the Amazon Security Lake configuration object for the specified Amazon Web Services Regions. You can use this operation to determine whether Security Lake is enabled for a Region.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter regions :
The list of Regions where Security Lake is enabled.
Implementation
Future<ListDataLakesResponse> listDataLakes({
List<String>? regions,
}) async {
final $query = <String, List<String>>{
if (regions != null) 'regions': regions,
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/datalakes',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataLakesResponse.fromJson(response);
}