listSubscribers method
Lists all subscribers for the specific Amazon Security Lake account ID. You can retrieve a list of subscriptions associated with a specific organization or Amazon Web Services account.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter maxResults :
The maximum number of accounts for which the configuration is displayed.
Parameter nextToken :
If nextToken is returned, there are more results available. You can repeat
the call using the returned token to retrieve the next page.
Implementation
Future<ListSubscribersResponse> listSubscribers({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/subscribers',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListSubscribersResponse.fromJson(response);
}