updateSubscriberNotification method
Future<UpdateSubscriberNotificationResponse>
updateSubscriberNotification({
- required NotificationConfiguration configuration,
- required String subscriberId,
Updates an existing notification method for the subscription (SQS or HTTPs endpoint) or switches the notification subscription endpoint for a subscriber.
May throw AccessDeniedException.
May throw BadRequestException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter configuration :
The configuration for subscriber notification.
Parameter subscriberId :
The subscription ID for which the subscription notification is specified.
Implementation
Future<UpdateSubscriberNotificationResponse> updateSubscriberNotification({
required NotificationConfiguration configuration,
required String subscriberId,
}) async {
final $payload = <String, dynamic>{
'configuration': configuration,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/v1/subscribers/${Uri.encodeComponent(subscriberId)}/notification',
exceptionFnMap: _exceptionFns,
);
return UpdateSubscriberNotificationResponse.fromJson(response);
}