disableAWSOrganizationsAccess method
Disable portfolio sharing through the Organizations service. This command will not delete your current shares, but prevents you from creating new shares throughout your organization. Current shares are not kept in sync with your organization structure if the structure changes after calling this API. Only the management account in the organization can call this API.
You cannot call this API if there are active delegated administrators in the organization.
Note that a delegated administrator is not authorized to invoke
DisableAWSOrganizationsAccess.
May throw InvalidStateException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
Implementation
Future<void> disableAWSOrganizationsAccess() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWS242ServiceCatalogService.DisableAWSOrganizationsAccess'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}