enableAWSOrganizationsAccess method
Enable portfolio sharing feature through Organizations. This API will allow Service Catalog to receive updates on your organization in order to sync your shares with the current structure. This API can only be called by the management account in the organization.
When you call this API, Service Catalog calls
organizations:EnableAWSServiceAccess on your behalf so that
your shares stay in sync with any changes in your Organizations structure.
Note that a delegated administrator is not authorized to invoke
EnableAWSOrganizationsAccess.
May throw InvalidStateException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
Implementation
Future<void> enableAWSOrganizationsAccess() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWS242ServiceCatalogService.EnableAWSOrganizationsAccess'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
}