associateAttributeGroup method
Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ValidationException.
Parameter application :
The name, ID, or ARN of the application.
Parameter attributeGroup :
The name, ID, or ARN of the attribute group that holds the attributes to
describe the application.
Implementation
Future<AssociateAttributeGroupResponse> associateAttributeGroup({
required String application,
required String attributeGroup,
}) async {
final response = await _protocol.send(
payload: null,
method: 'PUT',
requestUri:
'/applications/${Uri.encodeComponent(application)}/attribute-groups/${Uri.encodeComponent(attributeGroup)}',
exceptionFnMap: _exceptionFns,
);
return AssociateAttributeGroupResponse.fromJson(response);
}