deleteApplication method
Deletes an application that is specified either by its application ID, name, or ARN. All associated attribute groups and resources must be disassociated from it before deleting an application.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter application :
The name, ID, or ARN of the application.
Implementation
Future<DeleteApplicationResponse> deleteApplication({
required String application,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/applications/${Uri.encodeComponent(application)}',
exceptionFnMap: _exceptionFns,
);
return DeleteApplicationResponse.fromJson(response);
}