deleteAttributeGroup method
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter attributeGroup :
The name, ID, or ARN of the attribute group that holds the attributes to
describe the application.
Implementation
Future<DeleteAttributeGroupResponse> deleteAttributeGroup({
required String attributeGroup,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/attribute-groups/${Uri.encodeComponent(attributeGroup)}',
exceptionFnMap: _exceptionFns,
);
return DeleteAttributeGroupResponse.fromJson(response);
}