getAttributeGroup method
Retrieves an attribute group by its ARN, ID, or name. The attribute group can be specified by its ARN, ID, or name.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter attributeGroup :
The name, ID, or ARN of the attribute group that holds the attributes to
describe the application.
Implementation
Future<GetAttributeGroupResponse> getAttributeGroup({
required String attributeGroup,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/attribute-groups/${Uri.encodeComponent(attributeGroup)}',
exceptionFnMap: _exceptionFns,
);
return GetAttributeGroupResponse.fromJson(response);
}