deleteServiceAttributes method
Deletes specific attributes associated with a service.
May throw InvalidInput.
May throw ServiceNotFound.
Parameter attributes :
A list of keys corresponding to each attribute that you want to delete.
Parameter serviceId :
The ID or Amazon Resource Name (ARN) of the service from which the
attributes will be deleted. For services created in a namespace shared
with your Amazon Web Services account, specify the service ARN. For more
information about shared namespaces, see Cross-account
Cloud Map namespace sharing in the Cloud Map Developer Guide.
Implementation
Future<void> deleteServiceAttributes({
required List<String> attributes,
required String serviceId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53AutoNaming_v20170314.DeleteServiceAttributes'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Attributes': attributes,
'ServiceId': serviceId,
},
);
}