listInstances method
Lists summary information about the instances that you registered by using a specified service.
May throw InvalidInput.
May throw ServiceNotFound.
Parameter serviceId :
The ID or Amazon Resource Name (ARN) of the service that you want to list
instances for. For services created in a shared namespace, specify the
service ARN. For more information about shared namespaces, see Cross-account
Cloud Map namespace sharing in the Cloud Map Developer Guide.
Parameter maxResults :
The maximum number of instances that you want Cloud Map to return in the
response to a ListInstances request. If you don't specify a
value for MaxResults, Cloud Map returns up to 100 instances.
Parameter nextToken :
For the first ListInstances request, omit this value.
If more than MaxResults instances match the specified
criteria, you can submit another ListInstances request to get
the next group of results. Specify the value of NextToken
from the previous response in the next request.
Implementation
Future<ListInstancesResponse> listInstances({
required String serviceId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Route53AutoNaming_v20170314.ListInstances'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServiceId': serviceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListInstancesResponse.fromJson(jsonResponse.body);
}