listServices method
Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw InvalidPaginationTokenException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter maxResults :
Specifies the maximum number of results that you want included on each
page of the response. If you do not include this parameter, it defaults to
a value appropriate to the operation. If additional items exist beyond
those included in the current response, the NextToken
response element is present and has a value (is not null). Include that
value as the NextToken request parameter in the next call to
the operation to get the next part of the results.
Parameter nextToken :
Specifies a value for receiving additional results after you receive a
NextToken response in a previous request. A
NextToken response indicates that more output is available.
Set this parameter to the value of the previous call's
NextToken response to indicate where the output should
continue from.
Implementation
Future<ListServicesResponse> listServices({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.ListServices'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListServicesResponse.fromJson(jsonResponse.body);
}