putServiceQuotaIncreaseRequestIntoTemplate method
Adds a quota increase request to your quota request template.
May throw AccessDeniedException.
May throw AWSServiceAccessNotEnabledException.
May throw DependencyAccessDeniedException.
May throw IllegalArgumentException.
May throw NoAvailableOrganizationException.
May throw NoSuchResourceException.
May throw QuotaExceededException.
May throw ServiceException.
May throw TemplatesNotAvailableInRegionException.
May throw TooManyRequestsException.
Parameter awsRegion :
Specifies the Amazon Web Services Region to which the template applies.
Parameter desiredValue :
Specifies the new, increased value for the quota.
Parameter quotaCode :
Specifies the quota identifier. To find the quota code for a specific
quota, use the ListServiceQuotas operation, and look for the
QuotaCode response in the output for the quota you want.
Parameter serviceCode :
Specifies the service identifier. To find the service code value for an
Amazon Web Services service, use the ListServices operation.
Implementation
Future<PutServiceQuotaIncreaseRequestIntoTemplateResponse>
putServiceQuotaIncreaseRequestIntoTemplate({
required String awsRegion,
required double desiredValue,
required String quotaCode,
required String serviceCode,
}) async {
_s.validateNumRange(
'desiredValue',
desiredValue,
0,
10000000000,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'ServiceQuotasV20190624.PutServiceQuotaIncreaseRequestIntoTemplate'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AwsRegion': awsRegion,
'DesiredValue': desiredValue,
'QuotaCode': quotaCode,
'ServiceCode': serviceCode,
},
);
return PutServiceQuotaIncreaseRequestIntoTemplateResponse.fromJson(
jsonResponse.body);
}