requestServiceQuotaIncrease method
Submits a quota increase request for the specified quota at the account or resource level.
May throw AccessDeniedException.
May throw DependencyAccessDeniedException.
May throw IllegalArgumentException.
May throw InvalidResourceStateException.
May throw NoSuchResourceException.
May throw QuotaExceededException.
May throw ResourceAlreadyExistsException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter desiredValue :
Specifies the new, increased value for the quota.
Parameter quotaCode :
Specifies the quota identifier. To find the quota code for a specific
quota, use the ListServiceQuotas operation, and look for the
QuotaCode response in the output for the quota you want.
Parameter serviceCode :
Specifies the service identifier. To find the service code value for an
Amazon Web Services service, use the ListServices operation.
Parameter contextId :
Specifies the resource with an Amazon Resource Name (ARN).
Parameter supportCaseAllowed :
Specifies if an Amazon Web Services Support case can be opened for the
quota increase request. This parameter is optional.
By default, this flag is set to True and Amazon Web Services
may create a support case for some quota increase requests. You can set
this flag to False if you do not want a support case created
when you request a quota increase. If you set the flag to
False, Amazon Web Services does not open a support case and
updates the request status to Not approved.
Implementation
Future<RequestServiceQuotaIncreaseResponse> requestServiceQuotaIncrease({
required double desiredValue,
required String quotaCode,
required String serviceCode,
String? contextId,
bool? supportCaseAllowed,
}) async {
_s.validateNumRange(
'desiredValue',
desiredValue,
0,
10000000000,
isRequired: true,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.RequestServiceQuotaIncrease'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DesiredValue': desiredValue,
'QuotaCode': quotaCode,
'ServiceCode': serviceCode,
if (contextId != null) 'ContextId': contextId,
if (supportCaseAllowed != null)
'SupportCaseAllowed': supportCaseAllowed,
},
);
return RequestServiceQuotaIncreaseResponse.fromJson(jsonResponse.body);
}