startAutoManagement method
Starts Service Quotas Automatic Management for an Amazon Web Services account, including notification preferences and excluded quotas configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw NoSuchResourceException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter optInLevel :
Sets the opt-in level for Automatic Management. Only Amazon Web Services
account level is supported.
Parameter optInType :
Sets the opt-in type for Automatic Management. There are two modes: Notify
only and Notify and Auto-Adjust. Currently, only NotifyOnly is available.
Parameter exclusionList :
List of Amazon Web Services services excluded from Automatic Management.
You won't be notified of Service Quotas utilization for Amazon Web
Services services added to the Automatic Management exclusion list.
Parameter notificationArn :
The User
Notifications Amazon Resource Name (ARN) for Automatic Management
notifications.
Implementation
Future<void> startAutoManagement({
required OptInLevel optInLevel,
required OptInType optInType,
Map<String, List<String>>? exclusionList,
String? notificationArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.StartAutoManagement'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OptInLevel': optInLevel.value,
'OptInType': optInType.value,
if (exclusionList != null) 'ExclusionList': exclusionList,
if (notificationArn != null) 'NotificationArn': notificationArn,
},
);
}