tagResource method
Adds tags to the specified applied quota. You can include one or more tags to add to the quota.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw NoSuchResourceException.
May throw ServiceException.
May throw TagPolicyViolationException.
May throw TooManyRequestsException.
May throw TooManyTagsException.
Parameter resourceARN :
The Amazon Resource Name (ARN) for the applied quota. You can get this
information by using the Service Quotas console, or by listing the quotas
using the list-service-quotas
CLI command or the ListServiceQuotas
Amazon Web Services API operation.
Parameter tags :
The tags that you want to add to the resource.
Implementation
Future<void> tagResource({
required String resourceARN,
required List<Tag> tags,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.TagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'Tags': tags,
},
);
}