untagResource method
Removes tags from the specified applied quota. You can specify one or more tags to remove.
May throw AccessDeniedException.
May throw IllegalArgumentException.
May throw NoSuchResourceException.
May throw ServiceException.
May throw TooManyRequestsException.
Parameter resourceARN :
The Amazon Resource Name (ARN) for the applied quota that you want to
untag. You can get this information by using the Service Quotas console,
or by listing the quotas using the list-service-quotas
CLI command or the ListServiceQuotas
Amazon Web Services API operation.
Parameter tagKeys :
The keys of the tags that you want to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceARN,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'ServiceQuotasV20190624.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'TagKeys': tagKeys,
},
);
}