ses library
Classes
- AwsClientCredentials
- AWS credentials.
- Ses
- This document contains reference information for the Amazon Simple Email Service (Amazon SES) API, version 2010-12-01. This document is best used in conjunction with the Amazon SES Developer Guide. This documentation contains reference information related to the following: