listTemplates method
Lists the email templates present in your Amazon SES account in the current Amazon Web Services Region.
You can execute this operation no more than once per second.
Parameter maxItems :
The maximum number of templates to return. This value must be at least 1
and less than or equal to 100. If more than 100 items are requested, the
page size will automatically set to 100. If you do not specify a value, 10
is the default page size.
Parameter nextToken :
A token returned from a previous call to ListTemplates to
indicate the position in the list of email templates.
Implementation
Future<ListTemplatesResponse> listTemplates({
int? maxItems,
String? nextToken,
}) async {
final $request = <String, String>{
if (maxItems != null) 'MaxItems': maxItems.toString(),
if (nextToken != null) 'NextToken': nextToken,
};
final $result = await _protocol.send(
$request,
action: 'ListTemplates',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'ListTemplatesResult',
);
return ListTemplatesResponse.fromXml($result);
}