updateTemplate method
Updates an email template. Email templates enable you to send personalized email to one or more destinations in a single operation. For more information, see the Amazon SES Developer Guide.
You can execute this operation no more than once per second.
May throw InvalidTemplateException.
May throw TemplateDoesNotExistException.
Implementation
Future<void> updateTemplate({
required Template template,
}) async {
final $request = <String, String>{
for (var e1 in template.toQueryMap().entries)
'Template.${e1.key}': e1.value,
};
await _protocol.send(
$request,
action: 'UpdateTemplate',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'UpdateTemplateResult',
);
}