verifyEmailIdentity method
Adds an email address to the list of identities for your Amazon SES account in the current Amazon Web Services Region and attempts to verify it. As a result of executing this operation, a verification email is sent to the specified address.
You can execute this operation no more than once per second.
Parameter emailAddress :
The email address to be verified.
Implementation
Future<void> verifyEmailIdentity({
required String emailAddress,
}) async {
final $request = <String, String>{
'EmailAddress': emailAddress,
};
await _protocol.send(
$request,
action: 'VerifyEmailIdentity',
version: '2010-12-01',
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
resultWrapper: 'VerifyEmailIdentityResult',
);
}