createExportJob method
Future<CreateExportJobResponse>
createExportJob({
- required ExportDataSource exportDataSource,
- required ExportDestination exportDestination,
Creates an export job for a data source and destination.
You can execute this operation no more than once per second.
May throw BadRequestException.
May throw LimitExceededException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter exportDataSource :
The data source for the export job.
Parameter exportDestination :
The destination for the export job.
Implementation
Future<CreateExportJobResponse> createExportJob({
required ExportDataSource exportDataSource,
required ExportDestination exportDestination,
}) async {
final $payload = <String, dynamic>{
'ExportDataSource': exportDataSource,
'ExportDestination': exportDestination,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/export-jobs',
exceptionFnMap: _exceptionFns,
);
return CreateExportJobResponse.fromJson(response);
}