deleteSuppressedDestination method
Removes an email address from the suppression list for your account or for
a specific tenant. To target a tenant's suppression list, specify the
TenantName parameter. If you omit TenantName,
the address is removed from the account-level suppression list.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter emailAddress :
The suppressed email destination to remove from the suppression list for
your account or for the specified tenant.
Parameter tenantName :
The name of the tenant whose suppression list you want to remove the
address from. If you omit this parameter, the address is removed from the
account-level suppression list.
Implementation
Future<void> deleteSuppressedDestination({
required String emailAddress,
String? tenantName,
}) async {
final $query = <String, List<String>>{
if (tenantName != null) 'TenantName': [tenantName],
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/v2/email/suppression/addresses/${Uri.encodeComponent(emailAddress)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}