deleteTenant method
Delete an existing tenant.
When you delete a tenant, its associations with resources are removed, but the resources themselves are not deleted.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tenantName :
The name of the tenant to delete.
Implementation
Future<void> deleteTenant({
required String tenantName,
}) async {
final $payload = <String, dynamic>{
'TenantName': tenantName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/tenants/delete',
exceptionFnMap: _exceptionFns,
);
}