getReputationEntity method
- required String reputationEntityReference,
- required ReputationEntityType reputationEntityType,
Retrieve information about a specific reputation entity, including its reputation management policy, customer-managed status, Amazon Web Services Amazon SES-managed status, and aggregate sending status.
Reputation entities represent resources in your Amazon SES account
that have reputation tracking and management capabilities. The reputation
impact reflects the highest impact reputation finding for the entity.
Reputation findings can be retrieved using the
ListRecommendations operation.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter reputationEntityReference :
The unique identifier for the reputation entity. For resource-type
entities, this is the Amazon Resource Name (ARN) of the resource.
Parameter reputationEntityType :
The type of reputation entity. Currently, only RESOURCE type
entities are supported.
Implementation
Future<GetReputationEntityResponse> getReputationEntity({
required String reputationEntityReference,
required ReputationEntityType reputationEntityType,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/v2/email/reputation/entities/${Uri.encodeComponent(reputationEntityType.value)}/${Uri.encodeComponent(reputationEntityReference)}',
exceptionFnMap: _exceptionFns,
);
return GetReputationEntityResponse.fromJson(response);
}