getTenant method
Get information about a specific tenant, including the tenant's name, ID, ARN, creation timestamp, tags, sending status, and suppression attributes.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter tenantName :
The name of the tenant to retrieve information about.
Implementation
Future<GetTenantResponse> getTenant({
required String tenantName,
}) async {
final $payload = <String, dynamic>{
'TenantName': tenantName,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/tenants/get',
exceptionFnMap: _exceptionFns,
);
return GetTenantResponse.fromJson(response);
}