listRecommendations method
Lists the recommendations present in your Amazon SES account in the current Amazon Web Services Region.
You can execute this operation no more than once per second.
May throw BadRequestException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter filter :
Filters applied when retrieving recommendations. Can eiter be an
individual filter, or combinations of STATUS and
IMPACT or STATUS and TYPE
Parameter nextToken :
A token returned from a previous call to ListRecommendations
to indicate the position in the list of recommendations.
Parameter pageSize :
The number of results to show in a single call to
ListRecommendations. If the number of results is larger than
the number you specified in this parameter, then the response includes a
NextToken element, which you can use to obtain additional
results.
The value you specify has to be at least 1, and can be no more than 100.
Implementation
Future<ListRecommendationsResponse> listRecommendations({
Map<ListRecommendationsFilterKey, String>? filter,
String? nextToken,
int? pageSize,
}) async {
final $payload = <String, dynamic>{
if (filter != null) 'Filter': filter.map((k, e) => MapEntry(k.value, e)),
if (nextToken != null) 'NextToken': nextToken,
if (pageSize != null) 'PageSize': pageSize,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/vdm/recommendations',
exceptionFnMap: _exceptionFns,
);
return ListRecommendationsResponse.fromJson(response);
}