listReputationEntities method
List reputation entities in your Amazon SES account in the current Amazon Web Services Region. You can filter the results by entity type, reputation impact, sending status, or entity reference prefix.
Reputation entities represent resources in your account that have reputation tracking and management capabilities. Use this operation to get an overview of all entities and their current reputation status.
May throw BadRequestException.
May throw TooManyRequestsException.
Parameter filter :
An object that contains filters to apply when listing reputation entities.
You can filter by entity type, reputation impact, sending status, or
entity reference prefix.
Parameter nextToken :
A token returned from a previous call to
ListReputationEntities to indicate the position in the list
of reputation entities.
Parameter pageSize :
The number of results to show in a single call to
ListReputationEntities. If the number of results is larger
than the number you specified in this parameter, then the response
includes a NextToken element, which you can use to obtain
additional results.
Implementation
Future<ListReputationEntitiesResponse> listReputationEntities({
Map<ReputationEntityFilterKey, String>? filter,
String? nextToken,
int? pageSize,
}) async {
final $payload = <String, dynamic>{
if (filter != null) 'Filter': filter.map((k, e) => MapEntry(k.value, e)),
if (nextToken != null) 'NextToken': nextToken,
if (pageSize != null) 'PageSize': pageSize,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v2/email/reputation/entities',
exceptionFnMap: _exceptionFns,
);
return ListReputationEntitiesResponse.fromJson(response);
}