deleteStateMachine method
Deletes a state machine. This is an asynchronous operation. It sets the
state machine's status to DELETING and begins the deletion
process. A state machine is deleted only when all its executions are
completed. On the next state transition, the state machine's executions
are terminated.
A qualified state machine ARN can either refer to a Distributed Map state defined within a state machine, a version ARN, or an alias ARN.
The following are some examples of qualified and unqualified state machine ARNs:
-
The following qualified state machine ARN refers to a Distributed Map
state with a label
mapStateLabelin a state machine namedmyStateMachine.arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel -
The following unqualified state machine ARN refers to a state machine
named
myStateMachine.arn:partition:states:region:account-id:stateMachine:myStateMachine
May throw InvalidArn.
May throw ValidationException.
Parameter stateMachineArn :
The Amazon Resource Name (ARN) of the state machine to delete.
Implementation
Future<void> deleteStateMachine({
required String stateMachineArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.DeleteStateMachine'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'stateMachineArn': stateMachineArn,
},
);
}