deleteStateMachineAlias method
Deletes a state machine alias.
After you delete a state machine alias, you can't use it to start executions. When you delete a state machine alias, Step Functions doesn't delete the state machine versions that alias references.
Related operations:
May throw ConflictException.
May throw InvalidArn.
May throw ResourceNotFound.
May throw ValidationException.
Parameter stateMachineAliasArn :
The Amazon Resource Name (ARN) of the state machine alias to delete.
Implementation
Future<void> deleteStateMachineAlias({
required String stateMachineAliasArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.DeleteStateMachineAlias'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'stateMachineAliasArn': stateMachineAliasArn,
},
);
}