describeMapRun method
Provides information about a Map Run's configuration, progress, and results. If you've redriven a Map Run, this API action also returns information about the redrives of that Map Run. For more information, see Examining Map Run in the Step Functions Developer Guide.
May throw InvalidArn.
May throw ResourceNotFound.
Parameter mapRunArn :
The Amazon Resource Name (ARN) that identifies a Map Run.
Implementation
Future<DescribeMapRunOutput> describeMapRun({
required String mapRunArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.DescribeMapRun'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'mapRunArn': mapRunArn,
},
);
return DescribeMapRunOutput.fromJson(jsonResponse.body);
}