startExecution method
Starts a state machine execution.
A qualified state machine ARN can either refer to a Distributed Map state defined within a state machine, a version ARN, or an alias ARN.
The following are some examples of qualified and unqualified state machine ARNs:
-
The following qualified state machine ARN refers to a Distributed Map
state with a label
mapStateLabelin a state machine namedmyStateMachine.arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel -
The following qualified state machine ARN refers to an alias named
PROD.arn: -
The following unqualified state machine ARN refers to a state machine
named
myStateMachine.arn:
To start executions of a state machine version,
call StartExecution and provide the version ARN or the ARN of
an alias
that points to the version.
StartExecution isn't idempotent for EXPRESS
workflows.
May throw ExecutionAlreadyExists.
May throw ExecutionLimitExceeded.
May throw InvalidArn.
May throw InvalidExecutionInput.
May throw InvalidName.
May throw KmsAccessDeniedException.
May throw KmsInvalidStateException.
May throw KmsThrottlingException.
May throw StateMachineDeleting.
May throw StateMachineDoesNotExist.
May throw ValidationException.
Parameter stateMachineArn :
The Amazon Resource Name (ARN) of the state machine to execute.
The stateMachineArn parameter accepts one of the following
inputs:
-
An unqualified state machine ARN – Refers to a state machine ARN
that isn't qualified with a version or alias ARN. The following is an
example of an unqualified state machine ARN.
arn:Step Functions doesn't associate state machine executions that you start with an unqualified ARN with a version. This is true even if that version uses the same revision that the execution used.
-
A state machine version ARN – Refers to a version ARN, which is a
combination of state machine ARN and the version number separated by a
colon (:). The following is an example of the ARN for version 10.
arn:Step Functions doesn't associate executions that you start with a version ARN with any aliases that point to that version.
-
A state machine alias ARN – Refers to an alias ARN, which is a
combination of state machine ARN and the alias name separated by a colon
(:). The following is an example of the ARN for an alias named
PROD.arn:Step Functions associates executions that you start with an alias ARN with that alias and the state machine version used for that execution.
Parameter input :
The string that contains the JSON input data for the execution, for
example:
"{"first_name" : "Alejandro"}"
Length constraints apply to the payload size, and are expressed as bytes
in UTF-8 encoding.
Parameter name :
Optional name of the execution. This name must be unique for your Amazon
Web Services account, Region, and state machine for 90 days. For more
information, see
Limits Related to State Machine Executions in the Step Functions
Developer Guide.
If you don't provide a name for the execution, Step Functions automatically generates a universally unique identifier (UUID) as the execution name.
A name must not contain:
- white space
-
brackets
< > { } \[ \] -
wildcard characters
? * -
special characters
" # % \ ^ | ~ ` $ & , ; : / -
control characters (
U+0000-001F,U+007F-009F,U+FFFE-FFFF) -
surrogates (
U+D800-DFFF) -
invalid characters (
U+10FFFF)
Parameter traceHeader :
Passes the X-Ray trace header. The trace header can also be passed in the
request payload.
Implementation
Future<StartExecutionOutput> startExecution({
required String stateMachineArn,
String? input,
String? name,
String? traceHeader,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.StartExecution'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'stateMachineArn': stateMachineArn,
if (input != null) 'input': input,
if (name != null) 'name': name,
if (traceHeader != null) 'traceHeader': traceHeader,
},
);
return StartExecutionOutput.fromJson(jsonResponse.body);
}