updateStateMachineAlias method
Updates the configuration of an existing state machine alias
by modifying its description or
routingConfiguration.
You must specify at least one of the description or
routingConfiguration parameters to update a state machine
alias.
Related operations:
May throw ConflictException.
May throw InvalidArn.
May throw ResourceNotFound.
May throw StateMachineDeleting.
May throw ValidationException.
Parameter stateMachineAliasArn :
The Amazon Resource Name (ARN) of the state machine alias.
Parameter description :
A description of the state machine alias.
Parameter routingConfiguration :
The routing configuration of the state machine alias.
An array of RoutingConfig objects that specifies up to two
state machine versions that the alias starts executions for.
Implementation
Future<UpdateStateMachineAliasOutput> updateStateMachineAlias({
required String stateMachineAliasArn,
String? description,
List<RoutingConfigurationListItem>? routingConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AWSStepFunctions.UpdateStateMachineAlias'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'stateMachineAliasArn': stateMachineAliasArn,
if (description != null) 'description': description,
if (routingConfiguration != null)
'routingConfiguration': routingConfiguration,
},
);
return UpdateStateMachineAliasOutput.fromJson(jsonResponse.body);
}