describeDRTAccess method
Returns the current role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your Amazon Web Services account while assisting with attack mitigation.
May throw InternalErrorException.
May throw ResourceNotFoundException.
Implementation
Future<DescribeDRTAccessResponse> describeDRTAccess() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSShield_20160616.DescribeDRTAccess'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return DescribeDRTAccessResponse.fromJson(jsonResponse.body);
}