disableApplicationLayerAutomaticResponse method
Disable the Shield Advanced automatic application layer DDoS mitigation feature for the protected resource. This stops Shield Advanced from creating, verifying, and applying WAF rules for attacks that it detects for the resource.
May throw InternalErrorException.
May throw InvalidOperationException.
May throw InvalidParameterException.
May throw OptimisticLockException.
May throw ResourceNotFoundException.
Parameter resourceArn :
The ARN (Amazon Resource Name) of the protected resource.
Implementation
Future<void> disableApplicationLayerAutomaticResponse({
required String resourceArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target':
'AWSShield_20160616.DisableApplicationLayerAutomaticResponse'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
},
);
}