cancelSigningProfile method
Changes the state of an ACTIVE signing profile to
CANCELED. A canceled profile is still viewable with the
ListSigningProfiles operation, but it cannot perform new
signing jobs. See Data
Retention for more information on scheduled deletion of a canceled
signing profile.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
Parameter profileName :
The name of the signing profile to be canceled.
Implementation
Future<void> cancelSigningProfile({
required String profileName,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/signing-profiles/${Uri.encodeComponent(profileName)}',
exceptionFnMap: _exceptionFns,
);
}