revokeSigningProfile method
Changes the state of a signing profile to REVOKED. This
indicates that signatures generated using the signing profile after an
effective start date are no longer valid. A revoked profile is still
viewable with the ListSigningProfiles operation, but it
cannot perform new signing jobs. See Data
Retention for more information on scheduled deletion of a revoked
signing profile.
May throw AccessDeniedException.
May throw InternalServiceErrorException.
May throw ResourceNotFoundException.
May throw TooManyRequestsException.
May throw ValidationException.
Parameter effectiveTime :
A timestamp for when revocation of a Signing Profile should become
effective. Signatures generated using the signing profile after this
timestamp are not trusted.
Parameter profileName :
The name of the signing profile to be revoked.
Parameter profileVersion :
The version of the signing profile to be revoked.
Parameter reason :
The reason for revoking a signing profile.
Implementation
Future<void> revokeSigningProfile({
required DateTime effectiveTime,
required String profileName,
required String profileVersion,
required String reason,
}) async {
final $payload = <String, dynamic>{
'effectiveTime': unixTimestampToJson(effectiveTime),
'profileVersion': profileVersion,
'reason': reason,
};
await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/signing-profiles/${Uri.encodeComponent(profileName)}/revoke',
exceptionFnMap: _exceptionFns,
);
}