SignerData class
AWS Signer Data Plane service provides APIs for checking revocation status of signed artifacts.
Constructors
- SignerData({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getRevocationStatus(
{required List< String> certificateHashes, required String jobArn, required String platformId, required String profileVersionArn, required DateTime signatureTimestamp}) → Future<GetRevocationStatusResponse> - Retrieves the revocation status for a signed artifact by checking if the signing profile, job, or certificate has been revoked.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited