SnowDeviceManagement class
Amazon Web Services Snow Device Management documentation.
Constructors
- SnowDeviceManagement({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelTask(
{required String taskId}) → Future< CancelTaskOutput> -
Sends a cancel request for a specified task. You can cancel a task only if
it's still in a
QUEUEDstate. Tasks that are already running can't be cancelled. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createTask(
{required Command command, required List< String> targets, String? clientToken, String? description, Map<String, String> ? tags}) → Future<CreateTaskOutput> - Instructs one or more devices to start a task, such as unlocking or rebooting.
-
describeDevice(
{required String managedDeviceId}) → Future< DescribeDeviceOutput> - Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
-
describeDeviceEc2Instances(
{required List< String> instanceIds, required String managedDeviceId}) → Future<DescribeDeviceEc2Output> -
Checks the current state of the Amazon EC2 instances. The output is
similar to
describeDevice, but the results are sourced from the device cache in the Amazon Web Services Cloud and include a subset of the available fields. -
describeExecution(
{required String managedDeviceId, required String taskId}) → Future< DescribeExecutionOutput> - Checks the status of a remote task running on one or more target devices.
-
describeTask(
{required String taskId}) → Future< DescribeTaskOutput> - Checks the metadata for a given task on a device.
-
listDeviceResources(
{required String managedDeviceId, int? maxResults, String? nextToken, String? type}) → Future< ListDeviceResourcesOutput> - Returns a list of the Amazon Web Services resources available for a device. Currently, Amazon EC2 instances are the only supported resource type.
-
listDevices(
{String? jobId, int? maxResults, String? nextToken}) → Future< ListDevicesOutput> - Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
-
listExecutions(
{required String taskId, int? maxResults, String? nextToken, ExecutionState? state}) → Future< ListExecutionsOutput> - Returns the status of tasks for one or more target devices.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Returns a list of tags for a managed device or task.
-
listTasks(
{int? maxResults, String? nextToken, TaskState? state}) → Future< ListTasksOutput> - Returns a list of tasks that can be filtered by state.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Adds or replaces tags on a device or task.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes a tag from a device or task.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited