describeExecution method
Checks the status of a remote task running on one or more target devices.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter managedDeviceId :
The ID of the managed device.
Parameter taskId :
The ID of the task that the action is describing.
Implementation
Future<DescribeExecutionOutput> describeExecution({
required String managedDeviceId,
required String taskId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri:
'/task/${Uri.encodeComponent(taskId)}/execution/${Uri.encodeComponent(managedDeviceId)}',
exceptionFnMap: _exceptionFns,
);
return DescribeExecutionOutput.fromJson(response);
}