Snowball class
The Amazon Web Services Snow Family provides a petabyte-scale data transport solution that uses secure devices to transfer large amounts of data between your on-premises data centers and Amazon Simple Storage Service (Amazon S3). The Snow Family commands described here provide access to the same functionality that is available in the Amazon Web Services Snow Family Management Console, which enables you to create and manage jobs for a Snow Family device. To transfer data locally with a Snow Family device, you'll need to use the Snowball Edge client or the Amazon S3 API Interface for Snowball or OpsHub for Snow Family. For more information, see the User Guide.
Constructors
- Snowball({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelCluster(
{required String clusterId}) → Future< void> -
Cancels a cluster job. You can only cancel a cluster job while it's in the
AwaitingQuorumstatus. You'll have at least an hour after creating a cluster job to cancel it. -
cancelJob(
{required String jobId}) → Future< void> -
Cancels the specified job. You can only cancel a job before its
JobStatevalue changes toPreparingAppliance. Requesting theListJobsorDescribeJobaction returns a job'sJobStateas part of the response element data returned. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createAddress(
{required Address address}) → Future< CreateAddressResult> -
Creates an address for a Snow device to be shipped to. In most regions,
addresses are validated at the time of creation. The address you provide
must be located within the serviceable area of your region. If the address
is invalid or unsupported, then an exception is thrown. If providing an
address as a JSON file through the
cli-input-jsonoption, include the full file path. For example,--cli-input-json file://create-address.json. -
createCluster(
{required String addressId, required JobType jobType, required ShippingOption shippingOption, required SnowballType snowballType, String? description, bool? forceCreateJobs, String? forwardingAddressId, int? initialClusterSize, String? kmsKeyARN, List< String> ? longTermPricingIds, Notification? notification, OnDeviceServiceConfiguration? onDeviceServiceConfiguration, RemoteManagement? remoteManagement, JobResource? resources, String? roleARN, SnowballCapacity? snowballCapacityPreference, TaxDocuments? taxDocuments}) → Future<CreateClusterResult> - Creates an empty cluster. Each cluster supports five nodes. You use the CreateJob action separately to create the jobs for each of these nodes. The cluster does not ship until these five node jobs have been created.
-
createJob(
{String? addressId, String? clusterId, String? description, DeviceConfiguration? deviceConfiguration, String? forwardingAddressId, ImpactLevel? impactLevel, JobType? jobType, String? kmsKeyARN, String? longTermPricingId, Notification? notification, OnDeviceServiceConfiguration? onDeviceServiceConfiguration, PickupDetails? pickupDetails, RemoteManagement? remoteManagement, JobResource? resources, String? roleARN, ShippingOption? shippingOption, SnowballCapacity? snowballCapacityPreference, SnowballType? snowballType, TaxDocuments? taxDocuments}) → Future< CreateJobResult> -
Creates a job to import or export data between Amazon S3 and your
on-premises data center. Your Amazon Web Services account must have the
right trust policies and permissions in place to create a job for a Snow
device. If you're creating a job for a node in a cluster, you only need to
provide the
clusterIdvalue; the other job attributes are inherited from the cluster. -
createLongTermPricing(
{required LongTermPricingType longTermPricingType, required SnowballType snowballType, bool? isLongTermPricingAutoRenew}) → Future< CreateLongTermPricingResult> - Creates a job with the long-term usage option for a device. The long-term usage is a 1-year or 3-year long-term pricing type for the device. You are billed upfront, and Amazon Web Services provides discounts for long-term pricing.
-
createReturnShippingLabel(
{required String jobId, ShippingOption? shippingOption}) → Future< CreateReturnShippingLabelResult> - Creates a shipping label that will be used to return the Snow device to Amazon Web Services.
-
describeAddress(
{required String addressId}) → Future< DescribeAddressResult> -
Takes an
AddressIdand returns specific details about that address in the form of anAddressobject. -
describeAddresses(
{int? maxResults, String? nextToken}) → Future< DescribeAddressesResult> -
Returns a specified number of
ADDRESSobjects. Calling this API in one of the US regions will return addresses from the list of all addresses associated with this account in all US regions. -
describeCluster(
{required String clusterId}) → Future< DescribeClusterResult> - Returns information about a specific cluster including shipping information, cluster status, and other important metadata.
-
describeJob(
{required String jobId}) → Future< DescribeJobResult> - Returns information about a specific job including shipping information, job status, and other important metadata.
-
describeReturnShippingLabel(
{required String jobId}) → Future< DescribeReturnShippingLabelResult> - Information on the shipping label of a Snow device that is being returned to Amazon Web Services.
-
getJobManifest(
{required String jobId}) → Future< GetJobManifestResult> -
Returns a link to an Amazon S3 presigned URL for the manifest file
associated with the specified
JobIdvalue. You can access the manifest file for up to 60 minutes after this request has been made. To access the manifest file after 60 minutes have passed, you'll have to make another call to theGetJobManifestaction. -
getJobUnlockCode(
{required String jobId}) → Future< GetJobUnlockCodeResult> -
Returns the
UnlockCodecode value for the specified job. A particularUnlockCodevalue can be accessed for up to 360 days after the associated job has been created. -
getSnowballUsage(
) → Future< GetSnowballUsageResult> - Returns information about the Snow Family service limit for your account, and also the number of Snow devices your account has in use.
-
getSoftwareUpdates(
{required String jobId}) → Future< GetSoftwareUpdatesResult> -
Returns an Amazon S3 presigned URL for an update file associated with a
specified
JobId. -
listClusterJobs(
{required String clusterId, int? maxResults, String? nextToken}) → Future< ListClusterJobsResult> -
Returns an array of
JobListEntryobjects of the specified length. EachJobListEntryobject is for a job in the specified cluster and contains a job's state, a job's ID, and other information. -
listClusters(
{int? maxResults, String? nextToken}) → Future< ListClustersResult> -
Returns an array of
ClusterListEntryobjects of the specified length. EachClusterListEntryobject contains a cluster's state, a cluster's ID, and other important status information. -
listCompatibleImages(
{int? maxResults, String? nextToken}) → Future< ListCompatibleImagesResult> - This action returns a list of the different Amazon EC2-compatible Amazon Machine Images (AMIs) that are owned by your Amazon Web Services accountthat would be supported for use on a Snow device. Currently, supported AMIs are based on the Amazon Linux-2, Ubuntu 20.04 LTS - Focal, or Ubuntu 22.04 LTS - Jammy images, available on the Amazon Web Services Marketplace. Ubuntu 16.04 LTS - Xenial (HVM) images are no longer supported in the Market, but still supported for use on devices through Amazon EC2 VM Import/Export and running locally in AMIs.
-
listJobs(
{int? maxResults, String? nextToken}) → Future< ListJobsResult> -
Returns an array of
JobListEntryobjects of the specified length. EachJobListEntryobject contains a job's state, a job's ID, and a value that indicates whether the job is a job part, in the case of export jobs. Calling this API action in one of the US regions will return jobs from the list of all jobs associated with this account in all US regions. -
listLongTermPricing(
{int? maxResults, String? nextToken}) → Future< ListLongTermPricingResult> - Lists all long-term pricing types.
-
listPickupLocations(
{int? maxResults, String? nextToken}) → Future< ListPickupLocationsResult> - A list of locations from which the customer can choose to pickup a device.
-
listServiceVersions(
{required ServiceName serviceName, List< DependentService> ? dependentServices, int? maxResults, String? nextToken}) → Future<ListServiceVersionsResult> -
Lists all supported versions for Snow on-device services. Returns an array
of
ServiceVersionobject containing the supported versions for a particular service. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCluster(
{required String clusterId, String? addressId, String? description, String? forwardingAddressId, Notification? notification, OnDeviceServiceConfiguration? onDeviceServiceConfiguration, JobResource? resources, String? roleARN, ShippingOption? shippingOption}) → Future< void> -
While a cluster's
ClusterStatevalue is in theAwaitingQuorumstate, you can update some of the information associated with a cluster. Once the cluster changes to a different job state, usually 60 minutes after the cluster being created, this action is no longer available. -
updateJob(
{required String jobId, String? addressId, String? description, String? forwardingAddressId, Notification? notification, OnDeviceServiceConfiguration? onDeviceServiceConfiguration, PickupDetails? pickupDetails, JobResource? resources, String? roleARN, ShippingOption? shippingOption, SnowballCapacity? snowballCapacityPreference}) → Future< void> -
While a job's
JobStatevalue isNew, you can update some of the information associated with a job. Once the job changes to a different job state, usually within 60 minutes of the job being created, this action is no longer available. -
updateJobShipmentState(
{required String jobId, required ShipmentState shipmentState}) → Future< void> - Updates the state when a shipment state changes to a different state.
-
updateLongTermPricing(
{required String longTermPricingId, bool? isLongTermPricingAutoRenew, String? replacementJob}) → Future< void> - Updates the long-term pricing type.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited