cancelCluster method
Cancels a cluster job. You can only cancel a cluster job while it's in the
AwaitingQuorum status. You'll have at least an hour after
creating a cluster job to cancel it.
May throw InvalidJobStateException.
May throw InvalidResourceException.
May throw KMSRequestFailedException.
Parameter clusterId :
The 39-character ID for the cluster that you want to cancel, for example
CID123e4567-e89b-12d3-a456-426655440000.
Implementation
Future<void> cancelCluster({
required String clusterId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSIESnowballJobManagementService.CancelCluster'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ClusterId': clusterId,
},
);
}