addPermission method
Adds a permission to a queue for a specific principal. This allows sharing access to the queue.
When you create a queue, you have full control access rights for the queue. Only you, the owner of the queue, can grant or deny permissions to the queue. For more information about these permissions, see Allow Developers to Write Messages to a Shared Queue in the Amazon SQS Developer Guide.
-
AddPermissiongenerates a policy for you. You can useSetQueueAttributesto upload your policy. For more information, see Using Custom Policies with the Amazon SQS Access Policy Language in the Amazon SQS Developer Guide. - An Amazon SQS policy can have a maximum of seven actions per statement.
-
To remove the ability to change queue permissions, you must deny
permission to the
AddPermission,RemovePermission, andSetQueueAttributesactions in your IAM policy. -
Amazon SQS
AddPermissiondoes not support adding a non-account principal.
May throw InvalidAddress.
May throw InvalidSecurity.
May throw OverLimit.
May throw QueueDoesNotExist.
May throw RequestThrottled.
May throw UnsupportedOperation.
Parameter awsAccountIds :
The Amazon Web Services account numbers of the principals
who are to receive permission. For information about locating the Amazon
Web Services account identification, see Your
Amazon Web Services Identifiers in the Amazon SQS Developer
Guide.
Parameter actions :
The action the client wants to allow for the specified principal. Valid
values: the name of any action or *.
For more information about these actions, see Overview of Managing Access Permissions to Your Amazon Simple Queue Service Resource in the Amazon SQS Developer Guide.
Specifying SendMessage, DeleteMessage, or
ChangeMessageVisibility for ActionName.n also
grants permissions for the corresponding batch versions of those actions:
SendMessageBatch, DeleteMessageBatch, and
ChangeMessageVisibilityBatch.
Parameter label :
The unique identification of the permission you're setting (for example,
AliceSendMessage). Maximum 80 characters. Allowed characters
include alphanumeric characters, hyphens (-), and underscores
(_).
Parameter queueUrl :
The URL of the Amazon SQS queue to which permissions are added.
Queue URLs and names are case-sensitive.
Implementation
Future<void> addPermission({
required List<String> awsAccountIds,
required List<String> actions,
required String label,
required String queueUrl,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'AmazonSQS.AddPermission'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AWSAccountIds': awsAccountIds,
'Actions': actions,
'Label': label,
'QueueUrl': queueUrl,
},
);
}