createDocument method
Creates a Amazon Web Services Systems Manager (SSM document). An SSM document defines the actions that Systems Manager performs on your managed nodes. For more information about SSM documents, including information about supported schemas, features, and syntax, see Amazon Web Services Systems Manager Documents in the Amazon Web Services Systems Manager User Guide.
May throw DocumentAlreadyExists.
May throw DocumentLimitExceeded.
May throw InternalServerError.
May throw InvalidDocumentContent.
May throw InvalidDocumentSchemaVersion.
May throw MaxDocumentSizeExceeded.
May throw NoLongerSupportedException.
May throw TooManyUpdates.
Parameter content :
The content for the new SSM document in JSON or YAML format. The content
of the document must not exceed 64KB. This quota also includes the content
specified for input parameters at runtime. We recommend storing the
contents for your new document in an external JSON or YAML file and
referencing the file in a command.
For examples, see the following topics in the Amazon Web Services Systems Manager User Guide.
Parameter name :
A name for the SSM document.
-
aws -
amazon -
amzn -
AWSEC2 -
AWSConfigRemediation -
AWSSupport
Parameter attachments :
A list of key-value pairs that describe attachments to a version of a
document.
Parameter displayName :
An optional field where you can specify a friendly name for the SSM
document. This value can differ for each version of the document. You can
update this value at a later time using the UpdateDocument
operation.
Parameter documentFormat :
Specify the document format for the request. The document format can be
JSON, YAML, or TEXT. JSON is the default format.
Parameter documentType :
The type of document to create.
Parameter requires :
A list of SSM documents required by a document. This parameter is used
exclusively by AppConfig. When a user creates an AppConfig configuration
in an SSM document, the user must also specify a required document for
validation purposes. In this case, an
ApplicationConfiguration document requires an
ApplicationConfigurationSchema document for validation
purposes. For more information, see What
is AppConfig? in the AppConfig User Guide.
Parameter tags :
Optional metadata that you assign to a resource. Tags enable you to
categorize a resource in different ways, such as by purpose, owner, or
environment. For example, you might want to tag an SSM document to
identify the types of targets or the environment where it will run. In
this case, you could specify the following key-value pairs:
-
Key=OS,Value=Windows -
Key=Environment,Value=Production
Parameter targetType :
Specify a target type to define the kinds of resources the document can
run on. For example, to run a document on EC2 instances, specify the
following value: /AWS::EC2::Instance. If you specify a value
of '/' the document can run on all types of resources. If you don't
specify a value, the document can't run on any resources. For a list of
valid resource types, see Amazon
Web Services resource and property types reference in the
CloudFormation User Guide.
Parameter versionName :
An optional field specifying the version of the artifact you are creating
with the document. For example, Release12.1. This value is
unique across all versions of a document, and can't be changed.
Implementation
Future<CreateDocumentResult> createDocument({
required String content,
required String name,
List<AttachmentsSource>? attachments,
String? displayName,
DocumentFormat? documentFormat,
DocumentType? documentType,
List<DocumentRequires>? requires,
List<Tag>? tags,
String? targetType,
String? versionName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.CreateDocument'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Content': content,
'Name': name,
if (attachments != null) 'Attachments': attachments,
if (displayName != null) 'DisplayName': displayName,
if (documentFormat != null) 'DocumentFormat': documentFormat.value,
if (documentType != null) 'DocumentType': documentType.value,
if (requires != null) 'Requires': requires,
if (tags != null) 'Tags': tags,
if (targetType != null) 'TargetType': targetType,
if (versionName != null) 'VersionName': versionName,
},
);
return CreateDocumentResult.fromJson(jsonResponse.body);
}