describeParameters method
Lists the parameters in your Amazon Web Services account or the parameters shared with you when you enable the Shared option.
Request results are returned on a best-effort basis. If you specify
MaxResults in the request, the response includes information
up to the limit specified. The number of items returned, however, can be
between zero and the value of MaxResults. If the service
reaches an internal limit while processing the results, it stops the
operation and returns the matching values up to that point and a
NextToken. You can specify the NextToken in a
subsequent call to get the next set of results.
Parameter names can't contain spaces. The service removes any spaces
specified for the beginning or end of a parameter name. If the specified
name for a parameter contains spaces between characters, the request fails
with a ValidationException error.
May throw InternalServerError.
May throw InvalidFilterKey.
May throw InvalidFilterOption.
May throw InvalidFilterValue.
May throw InvalidNextToken.
Parameter filters :
This data type is deprecated. Instead, use ParameterFilters.
Parameter maxResults :
The maximum number of items to return for this call. The call also returns
a token that you can specify in a subsequent call to get the next set of
results.
Parameter nextToken :
The token for the next set of items to return. (You received this token
from a previous call.)
Parameter parameterFilters :
Filters to limit the request results.
Parameter shared :
Lists parameters that are shared with you.
For more information about sharing parameters, see Working with shared parameters in the Amazon Web Services Systems Manager User Guide.
Implementation
Future<DescribeParametersResult> describeParameters({
List<ParametersFilter>? filters,
int? maxResults,
String? nextToken,
List<ParameterStringFilter>? parameterFilters,
bool? shared,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.DescribeParameters'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filters != null) 'Filters': filters,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (parameterFilters != null) 'ParameterFilters': parameterFilters,
if (shared != null) 'Shared': shared,
},
);
return DescribeParametersResult.fromJson(jsonResponse.body);
}