startAutomationExecution method
- required String documentName,
- AlarmConfiguration? alarmConfiguration,
- String? clientToken,
- String? documentVersion,
- String? maxConcurrency,
- String? maxErrors,
- ExecutionMode? mode,
- Map<
String, List< ? parameters,String> > - List<
Tag> ? tags, - List<
TargetLocation> ? targetLocations, - String? targetLocationsURL,
- List<
Map< ? targetMaps,String, List< >String> > - String? targetParameterName,
- List<
Target> ? targets,
Initiates execution of an Automation runbook.
May throw AutomationDefinitionNotFoundException.
May throw AutomationDefinitionVersionNotFoundException.
May throw AutomationExecutionLimitExceededException.
May throw IdempotentParameterMismatch.
May throw InternalServerError.
May throw InvalidAutomationExecutionParametersException.
May throw InvalidTarget.
Parameter documentName :
The name of the SSM document to run. This can be a public document or a
custom document. To run a shared document belonging to another account,
specify the document ARN. For more information about how to use shared
documents, see Sharing
SSM documents in the Amazon Web Services Systems Manager User
Guide.
Parameter alarmConfiguration :
The CloudWatch alarm you want to apply to your automation.
Parameter clientToken :
User-provided idempotency token. The token must be unique, is case
insensitive, enforces the UUID format, and can't be reused.
Parameter documentVersion :
The version of the Automation runbook to use for this execution.
Parameter maxConcurrency :
The maximum number of targets allowed to run this task in parallel. You
can specify a number, such as 10, or a percentage, such as 10%. The
default value is 10.
If both this parameter and the
TargetLocation:TargetsMaxConcurrency are supplied,
TargetLocation:TargetsMaxConcurrency takes precedence.
Parameter maxErrors :
The number of errors that are allowed before the system stops running the
automation on additional targets. You can specify either an absolute
number of errors, for example 10, or a percentage of the target set, for
example 10%. If you specify 3, for example, the system stops running the
automation when the fourth error is received. If you specify 0, then the
system stops running the automation on additional targets after the first
error result is returned. If you run an automation on 50 resources and set
max-errors to 10%, then the system stops running the automation on
additional targets when the sixth error is received.
Executions that are already running an automation when max-errors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set max-concurrency to 1 so the executions proceed one at a time.
If this parameter and the TargetLocation:TargetsMaxErrors
parameter are both supplied, TargetLocation:TargetsMaxErrors
takes precedence.
Parameter mode :
The execution mode of the automation. Valid modes include the following:
Auto and Interactive. The default mode is Auto.
Parameter parameters :
A key-value map of execution parameters, which match the declared
parameters in the Automation runbook.
Parameter tags :
Optional metadata that you assign to a resource. You can specify a maximum
of five tags for an automation. Tags enable you to categorize a resource
in different ways, such as by purpose, owner, or environment. For example,
you might want to tag an automation to identify an environment or
operating system. In this case, you could specify the following key-value
pairs:
-
Key=environment,Value=test -
Key=OS,Value=Windows
Parameter targetLocations :
A location is a combination of Amazon Web Services Regions and/or Amazon
Web Services accounts where you want to run the automation. Use this
operation to start an automation in multiple Amazon Web Services Regions
and multiple Amazon Web Services accounts. For more information, see Running
automations in multiple Amazon Web Services Regions and accounts in
the Amazon Web Services Systems Manager User Guide.
Parameter targetLocationsURL :
Specify a publicly accessible URL for a file that contains the
TargetLocations body. Currently, only files in presigned
Amazon S3 buckets are supported.
Parameter targetMaps :
A key-value mapping of document parameters to target resources. Both
Targets and TargetMaps can't be specified together.
Parameter targetParameterName :
The name of the parameter used as the target resource for the
rate-controlled execution. Required if you specify targets.
Parameter targets :
A key-value mapping to target resources. Required if you specify
TargetParameterName.
If both this parameter and the TargetLocation:Targets
parameter are supplied, TargetLocation:Targets takes
precedence.
Implementation
Future<StartAutomationExecutionResult> startAutomationExecution({
required String documentName,
AlarmConfiguration? alarmConfiguration,
String? clientToken,
String? documentVersion,
String? maxConcurrency,
String? maxErrors,
ExecutionMode? mode,
Map<String, List<String>>? parameters,
List<Tag>? tags,
List<TargetLocation>? targetLocations,
String? targetLocationsURL,
List<Map<String, List<String>>>? targetMaps,
String? targetParameterName,
List<Target>? targets,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.StartAutomationExecution'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DocumentName': documentName,
if (alarmConfiguration != null)
'AlarmConfiguration': alarmConfiguration,
if (clientToken != null) 'ClientToken': clientToken,
if (documentVersion != null) 'DocumentVersion': documentVersion,
if (maxConcurrency != null) 'MaxConcurrency': maxConcurrency,
if (maxErrors != null) 'MaxErrors': maxErrors,
if (mode != null) 'Mode': mode.value,
if (parameters != null) 'Parameters': parameters,
if (tags != null) 'Tags': tags,
if (targetLocations != null) 'TargetLocations': targetLocations,
if (targetLocationsURL != null)
'TargetLocationsURL': targetLocationsURL,
if (targetMaps != null) 'TargetMaps': targetMaps,
if (targetParameterName != null)
'TargetParameterName': targetParameterName,
if (targets != null) 'Targets': targets,
},
);
return StartAutomationExecutionResult.fromJson(jsonResponse.body);
}