updateCloudConnector method
Updates an existing cloud connector with new configuration details.
May throw ConflictException.
May throw InternalServerError.
May throw ResourceNotFoundException.
Parameter cloudConnectorId :
The ID of the cloud connector to update.
Parameter configuration :
The updated configuration details for connecting to the third-party cloud
environment.
Parameter description :
A new description for the cloud connector.
Parameter displayName :
A new friendly name for the cloud connector.
Implementation
Future<UpdateCloudConnectorResult> updateCloudConnector({
required String cloudConnectorId,
CloudConnectorConfiguration? configuration,
String? description,
String? displayName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AmazonSSM.UpdateCloudConnector'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CloudConnectorId': cloudConnectorId,
if (configuration != null) 'Configuration': configuration,
if (description != null) 'Description': description,
if (displayName != null) 'DisplayName': displayName,
},
);
return UpdateCloudConnectorResult.fromJson(jsonResponse.body);
}