listComponents method
Lists all the components registered with AWS Systems Manager for SAP.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw UnauthorizedException.
May throw ValidationException.
Parameter applicationId :
The ID of the application.
Parameter maxResults :
The maximum number of results to return with a single call. To retrieve
the remaining results, make another call with the returned nextToken
value.
If you do not specify a value for MaxResults, the request returns 50 items per page by default.
Parameter nextToken :
The token for the next page of results.
Implementation
Future<ListComponentsOutput> listComponents({
String? applicationId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
50,
);
final $payload = <String, dynamic>{
if (applicationId != null) 'ApplicationId': applicationId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/list-components',
exceptionFnMap: _exceptionFns,
);
return ListComponentsOutput.fromJson(response);
}