Sso class
AWS IAM Identity Center (successor to AWS Single Sign-On) Portal is a web service that makes it easy for you to assign user access to IAM Identity Center resources such as the AWS access portal. Users can get AWS account applications and roles assigned to them and get federated into the application. This reference guide describes the IAM Identity Center Portal operations that you can call programatically and includes detailed information on data types and errors.
Constructors
- Sso({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getRoleCredentials(
{required String accessToken, required String accountId, required String roleName}) → Future< GetRoleCredentialsResponse> - Returns the STS short-term credentials for a given role name that is assigned to the user.
-
listAccountRoles(
{required String accessToken, required String accountId, int? maxResults, String? nextToken}) → Future< ListAccountRolesResponse> - Lists all roles that are assigned to the user for a given AWS account.
-
listAccounts(
{required String accessToken, int? maxResults, String? nextToken}) → Future< ListAccountsResponse> - Lists all AWS accounts assigned to the user. These AWS accounts are assigned by the administrator of the account. For more information, see Assign User Access in the IAM Identity Center User Guide. This operation returns a paginated response.
-
logout(
{required String accessToken}) → Future< void> - Removes the locally stored SSO tokens from the client-side cache and sends an API call to the IAM Identity Center service to invalidate the corresponding server-side IAM Identity Center sign in session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited