deleteApplicationAuthenticationMethod method
Future<void>
deleteApplicationAuthenticationMethod({
- required String applicationArn,
- required AuthenticationMethodType authenticationMethodType,
Deletes an authentication method from an application.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationArn :
Specifies the ARN of the application with the authentication method to
delete.
Parameter authenticationMethodType :
Specifies the authentication method type to delete from the application.
Implementation
Future<void> deleteApplicationAuthenticationMethod({
required String applicationArn,
required AuthenticationMethodType authenticationMethodType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.DeleteApplicationAuthenticationMethod'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationArn': applicationArn,
'AuthenticationMethodType': authenticationMethodType.value,
},
);
}