getApplicationAuthenticationMethod method
Future<GetApplicationAuthenticationMethodResponse>
getApplicationAuthenticationMethod({
- required String applicationArn,
- required AuthenticationMethodType authenticationMethodType,
Retrieves details about an authentication method used by an application.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationArn :
Specifies the ARN of the application.
Parameter authenticationMethodType :
Specifies the type of authentication method for which you want details.
Implementation
Future<GetApplicationAuthenticationMethodResponse>
getApplicationAuthenticationMethod({
required String applicationArn,
required AuthenticationMethodType authenticationMethodType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.GetApplicationAuthenticationMethod'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationArn': applicationArn,
'AuthenticationMethodType': authenticationMethodType.value,
},
);
return GetApplicationAuthenticationMethodResponse.fromJson(
jsonResponse.body);
}