listAccountAssignmentDeletionStatus method
Lists the status of the Amazon Web Services account assignment deletion requests for a specified IAM Identity Center instance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter filter :
Filters results based on the passed attribute value.
Parameter maxResults :
The maximum number of results to display for the assignment.
Parameter nextToken :
The pagination token for the list API. Initially the value is null. Use
the output of previous API calls to make subsequent calls.
Implementation
Future<ListAccountAssignmentDeletionStatusResponse>
listAccountAssignmentDeletionStatus({
required String instanceArn,
OperationStatusFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.ListAccountAssignmentDeletionStatus'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListAccountAssignmentDeletionStatusResponse.fromJson(
jsonResponse.body);
}