listApplications method
Lists all applications associated with the instance of IAM Identity
Center. When listing applications for an organization instance in the
management account, member accounts must use the
applicationAccount parameter to filter the list to only
applications created from that account. When listing applications for an
account instance in the same member account, a filter is not required.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center application under which the operation
will run. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter filter :
Filters response results.
Parameter maxResults :
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify, the
NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the maximum
even when there are more results available. You should check
NextToken after every operation to ensure that you receive
all of the results.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Implementation
Future<ListApplicationsResponse> listApplications({
required String instanceArn,
ListApplicationsFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.ListApplications'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
if (filter != null) 'Filter': filter,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListApplicationsResponse.fromJson(jsonResponse.body);
}