putApplicationAssignmentConfiguration method
Configure how users gain access to an application. If
AssignmentsRequired is true (default value),
users don’t have access to the application unless an assignment is created
using the CreateApplicationAssignment
API. If false, all users have access to the application.
If an assignment is created using CreateApplicationAssignment.,
the user retains access if AssignmentsRequired is set to
true.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter applicationArn :
Specifies the ARN of the application. For more information about ARNs, see
Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Parameter assignmentRequired :
If AssignmentsRequired is true (default value),
users don’t have access to the application unless an assignment is created
using the CreateApplicationAssignment
API. If false, all users have access to the application.
Implementation
Future<void> putApplicationAssignmentConfiguration({
required String applicationArn,
required bool assignmentRequired,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.PutApplicationAssignmentConfiguration'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ApplicationArn': applicationArn,
'AssignmentRequired': assignmentRequired,
},
);
}