putPermissionsBoundaryToPermissionSet method
Attaches an Amazon Web Services managed or customer managed policy to the specified PermissionSet as a permissions boundary.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed.
Parameter permissionSetArn :
The ARN of the PermissionSet.
Parameter permissionsBoundary :
The permissions boundary that you want to attach to a
PermissionSet.
Implementation
Future<void> putPermissionsBoundaryToPermissionSet({
required String instanceArn,
required String permissionSetArn,
required PermissionsBoundary permissionsBoundary,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.PutPermissionsBoundaryToPermissionSet'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'InstanceArn': instanceArn,
'PermissionSetArn': permissionSetArn,
'PermissionsBoundary': permissionsBoundary,
},
);
}