untagResource method
Disassociates a set of tags from a specified resource.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The ARN of the resource with the tags to be listed.
Parameter tagKeys :
The keys of tags that are attached to the resource.
Parameter instanceArn :
The ARN of the IAM Identity Center instance under which the operation will
be executed. For more information about ARNs, see Amazon Resource
Names (ARNs) and Amazon Web Services Service Namespaces in the
Amazon Web Services General Reference.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
String? instanceArn,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
if (instanceArn != null) 'InstanceArn': instanceArn,
},
);
}