updateTrustedTokenIssuer method
Updates the name of the trusted token issuer, or the path of a source attribute or destination attribute for a trusted token issuer configuration.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter trustedTokenIssuerArn :
Specifies the ARN of the trusted token issuer configuration that you want
to update.
Parameter name :
Specifies the updated name to be applied to the trusted token issuer
configuration.
Parameter trustedTokenIssuerConfiguration :
Specifies a structure with settings to apply to the specified trusted
token issuer. The settings that you can provide are determined by the type
of the trusted token issuer that you are updating.
Implementation
Future<void> updateTrustedTokenIssuer({
required String trustedTokenIssuerArn,
String? name,
TrustedTokenIssuerUpdateConfiguration? trustedTokenIssuerConfiguration,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'SWBExternalService.UpdateTrustedTokenIssuer'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'TrustedTokenIssuerArn': trustedTokenIssuerArn,
if (name != null) 'Name': name,
if (trustedTokenIssuerConfiguration != null)
'TrustedTokenIssuerConfiguration': trustedTokenIssuerConfiguration,
},
);
}