sso_oidc library
Classes
- AwsClientCredentials
- AWS credentials.
- SsoOidc
- IAM Identity Center OpenID Connect (OIDC) is a web service that enables a client (such as CLI or a native application) to register with IAM Identity Center. The service also enables the client to fetch the user’s access token upon successful authentication and authorization with IAM Identity Center.