describeGatewayInformation method
Future<DescribeGatewayInformationOutput>
describeGatewayInformation({
- required String gatewayARN,
Returns metadata about a gateway such as its name, network interfaces, time zone, status, and software version. To specify which gateway to describe, use the Amazon Resource Name (ARN) of the gateway in your request.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Implementation
Future<DescribeGatewayInformationOutput> describeGatewayInformation({
required String gatewayARN,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.DescribeGatewayInformation'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'GatewayARN': gatewayARN,
},
);
return DescribeGatewayInformationOutput.fromJson(jsonResponse.body);
}