updateSMBFileShare method
Updates a Server Message Block (SMB) file share. This operation is only supported for S3 File Gateways.
File gateways don't support creating hard or symbolic links on a file share.
May throw InternalServerError.
May throw InvalidGatewayRequestException.
Parameter fileShareARN :
The Amazon Resource Name (ARN) of the SMB file share that you want to
update.
Parameter accessBasedEnumeration :
The files and folders on this share will only be visible to users with
read access.
Parameter adminUserList :
A list of users or groups in the Active Directory that have administrator
rights to the file share. A group must be prefixed with the @ character.
Acceptable formats include: DOMAIN\User1, user1,
@group1, and @DOMAIN\group1. Can only be set if
Authentication is set to ActiveDirectory.
Parameter auditDestinationARN :
The Amazon Resource Name (ARN) of the storage used for audit logs.
Parameter cacheAttributes :
Specifies refresh cache information for the file share.
Parameter caseSensitivity :
The case of an object name in an Amazon S3 bucket. For
ClientSpecified, the client determines the case sensitivity.
For CaseSensitive, the gateway determines the case
sensitivity. The default value is ClientSpecified.
Parameter defaultStorageClass :
The default storage class for objects put into an Amazon S3 bucket by the
S3 File Gateway. The default value is S3_STANDARD. Optional.
Valid Values: S3_STANDARD |
S3_INTELLIGENT_TIERING | S3_STANDARD_IA |
S3_ONEZONE_IA
Parameter encryptionType :
A value that specifies the type of server-side encryption that the file
share will use for the data that it stores in Amazon S3.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then
KMSEncrypted must be false. If
EncryptionType is SseKms or
DsseKms, then KMSEncrypted must be
true.
Parameter fileShareName :
The name of the file share. Optional.
A valid SMB file share name cannot contain the following characters:
[,],#,;,<,>,:,",</code>,/,|,?,*,+,
or ASCII control characters 1-31.
Parameter guessMIMETypeEnabled :
A value that enables guessing of the MIME type for uploaded objects based
on file extensions. Set this value to true to enable MIME
type guessing, otherwise set to false. The default value is
true.
Valid Values: true | false
Parameter invalidUserList :
A list of users or groups in the Active Directory that are not allowed to
access the file share. A group must be prefixed with the @ character.
Acceptable formats include: DOMAIN\User1, user1,
@group1, and @DOMAIN\group1. Can only be set if
Authentication is set to ActiveDirectory.
Parameter kMSEncrypted :
Optional. Set to true to use Amazon S3 server-side encryption
with your own KMS key (SSE-KMS), or false to use a key
managed by Amazon S3 (SSE-S3). To use dual-layer encryption (DSSE-KMS),
set the EncryptionType parameter instead.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then
KMSEncrypted must be false. If
EncryptionType is SseKms or
DsseKms, then KMSEncrypted must be
true.
Valid Values: true | false
Parameter kMSKey :
Optional. The Amazon Resource Name (ARN) of a symmetric customer master
key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does
not support asymmetric CMKs. This value must be set if
KMSEncrypted is true, or if
EncryptionType is SseKms or
DsseKms.
Parameter notificationPolicy :
The notification policy of the file share.
SettlingTimeInSeconds controls the number of seconds to wait
after the last point in time a client wrote to a file before generating an
ObjectUploaded notification. Because clients can make many
small writes to files, it's best to set this parameter for as long as
possible to avoid generating multiple notifications for the same file in a
small time period.
This setting is not meant to specify an exact time at which the
notification will be sent. In some cases, the gateway might require more
than the specified delay time to generate and send notifications.
The following example sets NotificationPolicy on with
SettlingTimeInSeconds set to 60.
{"Upload": {"SettlingTimeInSeconds": 60}}
The following example sets NotificationPolicy off.
{}
Parameter objectACL :
A value that sets the access control list (ACL) permission for objects in
the S3 bucket that a S3 File Gateway puts objects into. The default value
is private.
Parameter oplocksEnabled :
Specifies whether opportunistic locking is enabled for the SMB file share.
Valid Values: true | false
Parameter readOnly :
A value that sets the write status of a file share. Set this value to
true to set write status to read-only, otherwise set to
false.
Valid Values: true | false
Parameter requesterPays :
A value that sets who pays the cost of the request and the cost associated
with data download from the S3 bucket. If this value is set to
true, the requester pays the costs; otherwise, the S3 bucket
owner pays. However, the S3 bucket owner always pays the cost of storing
data.
Valid Values: true | false
Parameter sMBACLEnabled :
Set this value to true to enable access control list (ACL) on
the SMB file share. Set it to false to map file and directory
permissions to the POSIX permissions.
For more information, see Using
Windows ACLs to limit SMB file share access in the Amazon S3 File
Gateway User Guide.
Valid Values: true | false
Parameter validUserList :
A list of users or groups in the Active Directory that are allowed to
access the file share. A group must be prefixed with the @ character.
Acceptable formats include: DOMAIN\User1, user1,
@group1, and @DOMAIN\group1. Can only be set if
Authentication is set to ActiveDirectory.
Implementation
Future<UpdateSMBFileShareOutput> updateSMBFileShare({
required String fileShareARN,
bool? accessBasedEnumeration,
List<String>? adminUserList,
String? auditDestinationARN,
CacheAttributes? cacheAttributes,
CaseSensitivity? caseSensitivity,
String? defaultStorageClass,
EncryptionType? encryptionType,
String? fileShareName,
bool? guessMIMETypeEnabled,
List<String>? invalidUserList,
bool? kMSEncrypted,
String? kMSKey,
String? notificationPolicy,
ObjectACL? objectACL,
bool? oplocksEnabled,
bool? readOnly,
bool? requesterPays,
bool? sMBACLEnabled,
List<String>? validUserList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'StorageGateway_20130630.UpdateSMBFileShare'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'FileShareARN': fileShareARN,
if (accessBasedEnumeration != null)
'AccessBasedEnumeration': accessBasedEnumeration,
if (adminUserList != null) 'AdminUserList': adminUserList,
if (auditDestinationARN != null)
'AuditDestinationARN': auditDestinationARN,
if (cacheAttributes != null) 'CacheAttributes': cacheAttributes,
if (caseSensitivity != null) 'CaseSensitivity': caseSensitivity.value,
if (defaultStorageClass != null)
'DefaultStorageClass': defaultStorageClass,
if (encryptionType != null) 'EncryptionType': encryptionType.value,
if (fileShareName != null) 'FileShareName': fileShareName,
if (guessMIMETypeEnabled != null)
'GuessMIMETypeEnabled': guessMIMETypeEnabled,
if (invalidUserList != null) 'InvalidUserList': invalidUserList,
if (kMSEncrypted != null) 'KMSEncrypted': kMSEncrypted,
if (kMSKey != null) 'KMSKey': kMSKey,
if (notificationPolicy != null)
'NotificationPolicy': notificationPolicy,
if (objectACL != null) 'ObjectACL': objectACL.value,
if (oplocksEnabled != null) 'OplocksEnabled': oplocksEnabled,
if (readOnly != null) 'ReadOnly': readOnly,
if (requesterPays != null) 'RequesterPays': requesterPays,
if (sMBACLEnabled != null) 'SMBACLEnabled': sMBACLEnabled,
if (validUserList != null) 'ValidUserList': validUserList,
},
);
return UpdateSMBFileShareOutput.fromJson(jsonResponse.body);
}