storage_gateway_2013_06_30
library
Classes
-
AwsClientCredentials
-
AWS credentials.
-
Amazon FSx File Gateway is no longer available to new customers. Existing
customers of FSx File Gateway can continue to use the service normally. For
capabilities similar to FSx File Gateway, visit this
blog post.
Storage Gateway is the service that connects an on-premises software
appliance with cloud-based storage to provide seamless and secure
integration between an organization's on-premises IT environment and the
Amazon Web Services storage infrastructure. The service enables you to
securely upload data to the Amazon Web Services Cloud for cost effective
backup and rapid disaster recovery.