deleteDataLakeNamespace method
Enables you to programmatically delete an Amazon Web Services Supply Chain data lake namespace and its underling datasets. Developers can delete the existing namespaces for a given instance ID and namespace name.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceId :
The AWS Supply Chain instance identifier.
Parameter name :
The name of the namespace. Noted you cannot delete pre-defined namespace
like asc, default which are only deleted through instance
deletion.
Implementation
Future<DeleteDataLakeNamespaceResponse> deleteDataLakeNamespace({
required String instanceId,
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/api/datalake/instance/${Uri.encodeComponent(instanceId)}/namespaces/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return DeleteDataLakeNamespaceResponse.fromJson(response);
}