getDataLakeNamespace method
Enables you to programmatically view an Amazon Web Services Supply Chain data lake namespace. Developers can view the data lake namespace information such as description for a given instance ID and namespace name.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceId :
The Amazon Web Services Supply Chain instance identifier.
Parameter name :
The name of the namespace. Besides the namespaces user created, you can
also specify the pre-defined namespaces:
- asc - Pre-defined namespace containing Amazon Web Services Supply Chain supported datasets, see https://docs.aws.amazon.com/aws-supply-chain/latest/userguide/data-model-asc.html.
- default - Pre-defined namespace containing datasets with custom user-defined schemas.
Implementation
Future<GetDataLakeNamespaceResponse> getDataLakeNamespace({
required String instanceId,
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/api/datalake/instance/${Uri.encodeComponent(instanceId)}/namespaces/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return GetDataLakeNamespaceResponse.fromJson(response);
}