getInstance method
Enables you to programmatically retrieve the information related to an Amazon Web Services Supply Chain instance ID.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceId :
The AWS Supply Chain instance identifier
Implementation
Future<GetInstanceResponse> getInstance({
required String instanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/api/instance/${Uri.encodeComponent(instanceId)}',
exceptionFnMap: _exceptionFns,
);
return GetInstanceResponse.fromJson(response);
}