listDataIntegrationFlowExecutions method
List flow executions.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter flowName :
The flow name.
Parameter instanceId :
The AWS Supply Chain instance identifier.
Parameter maxResults :
The number to specify the max number of flow executions to fetch in this
paginated request.
Parameter nextToken :
The pagination token to fetch next page of flow executions.
Implementation
Future<ListDataIntegrationFlowExecutionsResponse>
listDataIntegrationFlowExecutions({
required String flowName,
required String instanceId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
20,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/api-data/data-integration/instance/${Uri.encodeComponent(instanceId)}/data-integration-flows/${Uri.encodeComponent(flowName)}/executions',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListDataIntegrationFlowExecutionsResponse.fromJson(response);
}