updateDataIntegrationFlow method
Enables you to programmatically update an existing data pipeline to ingest data from the source systems such as, Amazon S3 buckets, to a predefined Amazon Web Services Supply Chain dataset (product, inbound_order) or a temporary dataset along with the data transformation query provided with the API.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter instanceId :
The Amazon Web Services Supply Chain instance identifier.
Parameter name :
The name of the DataIntegrationFlow to be updated.
Parameter sources :
The new source configurations for the DataIntegrationFlow.
Parameter target :
The new target configurations for the DataIntegrationFlow.
Parameter transformation :
The new transformation configurations for the DataIntegrationFlow.
Implementation
Future<UpdateDataIntegrationFlowResponse> updateDataIntegrationFlow({
required String instanceId,
required String name,
List<DataIntegrationFlowSource>? sources,
DataIntegrationFlowTarget? target,
DataIntegrationFlowTransformation? transformation,
}) async {
final $payload = <String, dynamic>{
if (sources != null) 'sources': sources,
if (target != null) 'target': target,
if (transformation != null) 'transformation': transformation,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/api/data-integration/instance/${Uri.encodeComponent(instanceId)}/data-integration-flows/${Uri.encodeComponent(name)}',
exceptionFnMap: _exceptionFns,
);
return UpdateDataIntegrationFlowResponse.fromJson(response);
}