Support class
The Amazon Web Services Support API Reference is intended for programmers who need detailed information about the Amazon Web Services Support operations and data types. You can use the API to manage your support cases programmatically. The Amazon Web Services Support API uses HTTP methods that return results in JSON format.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that doesn't
have a Business, Enterprise On-Ramp, or Enterprise Support plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAttachmentsToSet(
{required List< Attachment> attachments, String? attachmentSetId}) → Future<AddAttachmentsToSetResponse> - Adds one or more attachments to an attachment set.
-
addCommunicationToCase(
{required String communicationBody, String? attachmentSetId, String? caseId, List< String> ? ccEmailAddresses}) → Future<AddCommunicationToCaseResponse> -
Adds additional customer communication to an Amazon Web Services Support
case. Use the
caseIdparameter to identify the case to which to add communication. You can list a set of email addresses to copy on the communication by using theccEmailAddressesparameter. ThecommunicationBodyvalue contains the text of the communication. -
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createCase(
{required String communicationBody, required String subject, String? attachmentSetId, String? categoryCode, List< String> ? ccEmailAddresses, String? issueType, String? language, String? serviceCode, String? severityCode}) → Future<CreateCaseResponse> - Creates a case in the Amazon Web Services Support Center. This operation is similar to how you create a case in the Amazon Web Services Support Center Create Case page.
-
describeAttachment(
{required String attachmentId}) → Future< DescribeAttachmentResponse> - Returns the attachment that has the specified ID. Attachments can include screenshots, error logs, or other files that describe your issue. Attachment IDs are generated by the case management system when you add an attachment to a case or case communication. Attachment IDs are returned in the AttachmentDetails objects that are returned by the DescribeCommunications operation.
-
describeCases(
{String? afterTime, String? beforeTime, List< String> ? caseIdList, String? displayId, bool? includeCommunications, bool? includeResolvedCases, String? language, int? maxResults, String? nextToken}) → Future<DescribeCasesResponse> -
Returns a list of cases that you specify by passing one or more case IDs.
You can use the
afterTimeandbeforeTimeparameters to filter the cases by date. You can set values for theincludeResolvedCasesandincludeCommunicationsparameters to specify how much information to return. -
describeCommunications(
{required String caseId, String? afterTime, String? beforeTime, int? maxResults, String? nextToken}) → Future< DescribeCommunicationsResponse> -
Returns communications and attachments for one or more support cases. Use
the
afterTimeandbeforeTimeparameters to filter by date. You can use thecaseIdparameter to restrict the results to a specific case. -
describeCreateCaseOptions(
{required String categoryCode, required String issueType, required String language, required String serviceCode}) → Future< DescribeCreateCaseOptionsResponse> -
Returns a list of CreateCaseOption types along with the corresponding
supported hours and language availability. You can specify the
languagecategoryCode,issueTypeandserviceCodeused to retrieve the CreateCaseOptions. -
describeServices(
{String? language, List< String> ? serviceCodeList}) → Future<DescribeServicesResponse> - Returns the current list of Amazon Web Services services and a list of service categories for each service. You then use service names and categories in your CreateCase requests. Each Amazon Web Services service has its own set of categories.
-
describeSeverityLevels(
{String? language}) → Future< DescribeSeverityLevelsResponse> - Returns the list of severity levels that you can assign to a support case. The severity level for a case is also a field in the CaseDetails data type that you include for a CreateCase request.
-
describeSupportedLanguages(
{required String categoryCode, required String issueType, required String serviceCode}) → Future< DescribeSupportedLanguagesResponse> -
Returns a list of supported languages for a specified
categoryCode,issueTypeandserviceCode. The returned supported languages will include a ISO 639-1 code for thelanguage, and the language display name. -
describeTrustedAdvisorCheckRefreshStatuses(
{required List< String> checkIds}) → Future<DescribeTrustedAdvisorCheckRefreshStatusesResponse> - Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
-
describeTrustedAdvisorCheckResult(
{required String checkId, String? language}) → Future< DescribeTrustedAdvisorCheckResultResponse> - Returns the results of the Trusted Advisor check that has the specified check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
-
describeTrustedAdvisorChecks(
{required String language}) → Future< DescribeTrustedAdvisorChecksResponse> - Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata. You must specify a language code.
-
describeTrustedAdvisorCheckSummaries(
{required List< String> checkIds}) → Future<DescribeTrustedAdvisorCheckSummariesResponse> - Returns the results for the Trusted Advisor check summaries for the check IDs that you specified. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshTrustedAdvisorCheck(
{required String checkId}) → Future< RefreshTrustedAdvisorCheckResponse> - Refreshes the Trusted Advisor check that you specify using the check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
-
resolveCase(
{String? caseId}) → Future< ResolveCaseResponse> -
Resolves a support case. This operation takes a
caseIdand returns the initial and final state of the case. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited