describeServices method
Returns the current list of Amazon Web Services services and a list of service categories for each service. You then use service names and categories in your CreateCase requests. Each Amazon Web Services service has its own set of categories.
The service codes and category codes correspond to the values that appear
in the Service and Category lists on the Amazon Web Services
Support Center Create
Case page. The values in those fields don't necessarily match the
service codes and categories returned by the DescribeServices
operation. Always use the service codes and categories that the
DescribeServices operation returns, so that you have the most
recent set of service and category codes.
- You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support API.
-
If you call the Amazon Web Services Support API from an account that
doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
May throw InternalServerError.
Parameter language :
The language in which Amazon Web Services Support handles the case. Amazon
Web Services Support currently supports Chinese (“zh”), English ("en"),
Japanese ("ja") and Korean (“ko”). You must specify the ISO 639-1 code for
the language parameter if you want support in that language.
Parameter serviceCodeList :
A JSON-formatted list of service codes available for Amazon Web Services
services.
Implementation
Future<DescribeServicesResponse> describeServices({
String? language,
List<String>? serviceCodeList,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.DescribeServices'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (language != null) 'language': language,
if (serviceCodeList != null) 'serviceCodeList': serviceCodeList,
},
);
return DescribeServicesResponse.fromJson(jsonResponse.body);
}