describeTrustedAdvisorCheckResult method
Returns the results of the Trusted Advisor check that has the specified check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
The response contains a TrustedAdvisorCheckResult object, which contains these three objects:
In addition, the response contains these fields:-
status - The alert status of the check can be
ok(green),warning(yellow),error(red), ornot_available. - timestamp - The time of the last refresh of the check.
- checkId - The unique identifier for the check.
May throw InternalServerError.
May throw ThrottlingException.
Parameter checkId :
The unique identifier for the Trusted Advisor check.
Parameter language :
The ISO 639-1 code for the language that you want your check results to
appear in.
The Amazon Web Services Support API currently supports the following languages for Trusted Advisor:
-
Chinese, Simplified -
zh -
Chinese, Traditional -
zh_TW -
English -
en -
French -
fr -
German -
de -
Indonesian -
id -
Italian -
it -
Japanese -
ja -
Korean -
ko -
Portuguese, Brazilian -
pt_BR -
Spanish -
es
Implementation
Future<DescribeTrustedAdvisorCheckResultResponse>
describeTrustedAdvisorCheckResult({
required String checkId,
String? language,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSSupport_20130415.DescribeTrustedAdvisorCheckResult'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'checkId': checkId,
if (language != null) 'language': language,
},
);
return DescribeTrustedAdvisorCheckResultResponse.fromJson(
jsonResponse.body);
}