SupportApp class
You can use the Amazon Web Services Support App in Slack API to manage your support cases in Slack for your Amazon Web Services account. After you configure your Slack workspace and channel with the Amazon Web Services Support App, you can perform the following tasks directly in your Slack channel:
Constructors
- SupportApp({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createSlackChannelConfiguration(
{required String channelId, required String channelRoleArn, required NotificationSeverityLevel notifyOnCaseSeverity, required String teamId, String? channelName, bool? notifyOnAddCorrespondenceToCase, bool? notifyOnCreateOrReopenCase, bool? notifyOnResolveCase}) → Future< void> - Creates a Slack channel configuration for your Amazon Web Services account.
-
deleteAccountAlias(
) → Future< void> - Deletes an alias for an Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
-
deleteSlackChannelConfiguration(
{required String channelId, required String teamId}) → Future< void> - Deletes a Slack channel configuration from your Amazon Web Services account. This operation doesn't delete your Slack channel.
-
deleteSlackWorkspaceConfiguration(
{required String teamId}) → Future< void> - Deletes a Slack workspace configuration from your Amazon Web Services account. This operation doesn't delete your Slack workspace.
-
getAccountAlias(
) → Future< GetAccountAliasResult> - Retrieves the alias from an Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
-
listSlackChannelConfigurations(
{String? nextToken}) → Future< ListSlackChannelConfigurationsResult> - Lists the Slack channel configurations for an Amazon Web Services account.
-
listSlackWorkspaceConfigurations(
{String? nextToken}) → Future< ListSlackWorkspaceConfigurationsResult> - Lists the Slack workspace configurations for an Amazon Web Services account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAccountAlias(
{required String accountAlias}) → Future< void> - Creates or updates an individual alias for each Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
-
registerSlackWorkspaceForOrganization(
{required String teamId}) → Future< RegisterSlackWorkspaceForOrganizationResult> - Registers a Slack workspace for your Amazon Web Services account. To call this API, your account must be part of an organization in Organizations.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSlackChannelConfiguration(
{required String channelId, required String teamId, String? channelName, String? channelRoleArn, bool? notifyOnAddCorrespondenceToCase, NotificationSeverityLevel? notifyOnCaseSeverity, bool? notifyOnCreateOrReopenCase, bool? notifyOnResolveCase}) → Future< UpdateSlackChannelConfigurationResult> - Updates the configuration for a Slack channel, such as case update notifications.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited