Sustainability class
The AWS Sustainability service provides programmatic access to estimated environmental impact data for your Amazon Web Services usage. Use the AWS Sustainability service to retrieve, analyze, and track the environmental impact of your cloud infrastructure over time.
With the AWS Sustainability service, you can:
- Retrieve estimated carbon emissions and water allocation for your Amazon Web Services usage across different time periods
- Group environmental impact data by dimensions such as account, region, and service
- Filter environmental impact data to focus on specific accounts, regions, or services
- Access multiple carbon emissions calculation methodologies including Location-based Method (LBM) and Market-based Method (MBM)
- Aggregate environmental impact data at various time granularities including monthly, quarterly, and yearly periods
Constructors
- Sustainability({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl, bool useFipsEndpoint = false, bool useDualStackEndpoint = false})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
getEstimatedCarbonEmissions(
{required TimePeriod timePeriod, List< EmissionsType> ? emissionsTypes, FilterExpression? filterBy, TimeGranularity? granularity, GranularityConfiguration? granularityConfiguration, List<Dimension> ? groupBy, int? maxResults, String? nextToken}) → Future<GetEstimatedCarbonEmissionsResponse> - Returns estimated carbon emission values based on customer grouping and filtering parameters. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
getEstimatedCarbonEmissionsDimensionValues(
{required List< Dimension> dimensions, required TimePeriod timePeriod, int? maxResults, String? nextToken}) → Future<GetEstimatedCarbonEmissionsDimensionValuesResponse> - Returns the possible dimension values available for a customer's account. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
getEstimatedWaterAllocation(
{required TimePeriod timePeriod, List< WaterAllocationType> ? allocationTypes, FilterExpression? filterBy, TimeGranularity? granularity, List<Dimension> ? groupBy, int? maxResults, String? nextToken}) → Future<GetEstimatedWaterAllocationResponse> - Returns estimated water allocation values based on customer grouping and filtering parameters. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
getEstimatedWaterAllocationDimensionValues(
{required List< Dimension> dimensions, required TimePeriod timePeriod, int? maxResults, String? nextToken}) → Future<GetEstimatedWaterAllocationDimensionValuesResponse> - Returns the possible dimension values available for a customer's account. We recommend using pagination to ensure that the operation returns quickly and successfully.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited