describeRuntimeVersions method
Returns a list of Synthetics canary runtime versions. For more information, see Canary Runtime Versions.
May throw InternalServerException.
May throw ValidationException.
Parameter maxResults :
Specify this parameter to limit how many runs are returned each time you
use the DescribeRuntimeVersions operation. If you omit this
parameter, the default of 100 is used.
Parameter nextToken :
A token that indicates that there is more data available. You can use this
token in a subsequent DescribeRuntimeVersions operation to
retrieve the next set of results.
Implementation
Future<DescribeRuntimeVersionsResponse> describeRuntimeVersions({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $payload = <String, dynamic>{
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/runtime-versions',
exceptionFnMap: _exceptionFns,
);
return DescribeRuntimeVersionsResponse.fromJson(response);
}