stopCanary method
Stops the canary to prevent all future runs. If the canary is currently running,the run that is in progress completes on its own, publishes metrics, and uploads artifacts, but it is not recorded in Synthetics as a completed run.
You can use StartCanary to start it running again with the
canary’s current schedule at any point in the future.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ValidationException.
Parameter name :
The name of the canary that you want to stop. To find the names of your
canaries, use ListCanaries.
Implementation
Future<void> stopCanary({
required String name,
}) async {
final response = await _protocol.send(
payload: null,
method: 'POST',
requestUri: '/canary/${Uri.encodeComponent(name)}/stop',
exceptionFnMap: _exceptionFns,
);
}