untagResource method
Removes one or more tags from the specified resource.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw NotFoundException.
May throw TooManyRequestsException.
Parameter resourceArn :
The ARN of the canary or group that you're removing tags from.
The ARN format of a canary is
arn:aws:synthetics:Region:account-id:canary:canary-name
.
The ARN format of a group is
arn:aws:synthetics:Region:account-id:group:group-name
Parameter tagKeys :
The list of tag keys to remove from the resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final $query = <String, List<String>>{
'tagKeys': tagKeys,
};
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}