getAdapterVersion method
Gets configuration information for the specified adapter version, including: AdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig, KMSKeyId, OutputConfig, Tags and EvaluationMetrics.
May throw AccessDeniedException.
May throw InternalServerError.
May throw InvalidParameterException.
May throw ProvisionedThroughputExceededException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter adapterId :
A string specifying a unique ID for the adapter version you want to
retrieve information for.
Parameter adapterVersion :
A string specifying the adapter version you want to retrieve information
for.
Implementation
Future<GetAdapterVersionResponse> getAdapterVersion({
required String adapterId,
required String adapterVersion,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Textract.GetAdapterVersion'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AdapterId': adapterId,
'AdapterVersion': adapterVersion,
},
);
return GetAdapterVersionResponse.fromJson(jsonResponse.body);
}