startExpenseAnalysis method
Starts the asynchronous analysis of invoices or receipts for data like contact information, items purchased, and vendor names.
StartExpenseAnalysis can analyze text in documents that are
in JPEG, PNG, and PDF format. The documents must be stored in an Amazon S3
bucket. Use the DocumentLocation parameter to specify the name of
your S3 bucket and the name of the document in that bucket.
StartExpenseAnalysis returns a job identifier
(JobId) that you will provide to
GetExpenseAnalysis to retrieve the results of the operation.
When the analysis of the input invoices/receipts is finished, Amazon
Textract publishes a completion status to the Amazon Simple Notification
Service (Amazon SNS) topic that you provide to the
NotificationChannel. To obtain the results of the invoice and
receipt analysis operation, ensure that the status value published to the
Amazon SNS topic is SUCCEEDED. If so, call
GetExpenseAnalysis, and pass the job identifier
(JobId) that was returned by your call to
StartExpenseAnalysis.
For more information, see Analyzing Invoices and Receipts.
May throw AccessDeniedException.
May throw BadDocumentException.
May throw DocumentTooLargeException.
May throw IdempotentParameterMismatchException.
May throw InternalServerError.
May throw InvalidKMSKeyException.
May throw InvalidParameterException.
May throw InvalidS3ObjectException.
May throw LimitExceededException.
May throw ProvisionedThroughputExceededException.
May throw ThrottlingException.
May throw UnsupportedDocumentException.
Parameter documentLocation :
The location of the document to be processed.
Parameter clientRequestToken :
The idempotent token that's used to identify the start request. If you use
the same token with multiple StartDocumentTextDetection
requests, the same JobId is returned. Use
ClientRequestToken to prevent the same job from being
accidentally started more than once. For more information, see Calling
Amazon Textract Asynchronous Operations
Parameter jobTag :
An identifier you specify that's included in the completion notification
published to the Amazon SNS topic. For example, you can use
JobTag to identify the type of document that the completion
notification corresponds to (such as a tax form or a receipt).
Parameter kMSKeyId :
The KMS key used to encrypt the inference results. This can be in either
Key ID or Key Alias format. When a KMS key is provided, the KMS key will
be used for server-side encryption of the objects in the customer bucket.
When this parameter is not enabled, the result will be encrypted server
side,using SSE-S3.
Parameter notificationChannel :
The Amazon SNS topic ARN that you want Amazon Textract to publish the
completion status of the operation to.
Parameter outputConfig :
Sets if the output will go to a customer defined bucket. By default,
Amazon Textract will save the results internally to be accessed by the
GetExpenseAnalysis operation.
Implementation
Future<StartExpenseAnalysisResponse> startExpenseAnalysis({
required DocumentLocation documentLocation,
String? clientRequestToken,
String? jobTag,
String? kMSKeyId,
NotificationChannel? notificationChannel,
OutputConfig? outputConfig,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Textract.StartExpenseAnalysis'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DocumentLocation': documentLocation,
if (clientRequestToken != null)
'ClientRequestToken': clientRequestToken,
if (jobTag != null) 'JobTag': jobTag,
if (kMSKeyId != null) 'KMSKeyId': kMSKeyId,
if (notificationChannel != null)
'NotificationChannel': notificationChannel,
if (outputConfig != null) 'OutputConfig': outputConfig,
},
);
return StartExpenseAnalysisResponse.fromJson(jsonResponse.body);
}