TimestreamInfluxDB class
Amazon Timestream for InfluxDB is a managed time-series database engine that makes it easy for application developers and DevOps teams to run InfluxDB databases on Amazon Web Services for near real-time time-series applications using open-source APIs. With Amazon Timestream for InfluxDB, it is easy to set up, operate, and scale time-series workloads that can answer queries with single-digit millisecond query response time.
Constructors
- TimestreamInfluxDB({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createDbCluster(
{required DbInstanceType dbInstanceType, required String name, required List< String> vpcSecurityGroupIds, required List<String> vpcSubnetIds, int? allocatedStorage, String? bucket, String? dbParameterGroupIdentifier, DbStorageType? dbStorageType, ClusterDeploymentType? deploymentType, FailoverMode? failoverMode, LogDeliveryConfiguration? logDeliveryConfiguration, MaintenanceSchedule? maintenanceSchedule, NetworkType? networkType, String? organization, String? password, int? port, bool? publiclyAccessible, Map<String, String> ? tags, String? username}) → Future<CreateDbClusterOutput> - Creates a new Timestream for InfluxDB cluster.
-
createDbInstance(
{required int allocatedStorage, required DbInstanceType dbInstanceType, required String name, required String password, required List< String> vpcSecurityGroupIds, required List<String> vpcSubnetIds, String? bucket, String? dbParameterGroupIdentifier, DbStorageType? dbStorageType, DeploymentType? deploymentType, LogDeliveryConfiguration? logDeliveryConfiguration, MaintenanceSchedule? maintenanceSchedule, NetworkType? networkType, String? organization, int? port, bool? publiclyAccessible, Map<String, String> ? tags, String? username}) → Future<CreateDbInstanceOutput> - Creates a new Timestream for InfluxDB DB instance.
-
createDbParameterGroup(
{required String name, String? description, Parameters? parameters, Map< String, String> ? tags}) → Future<CreateDbParameterGroupOutput> - Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
-
deleteDbCluster(
{required String dbClusterId}) → Future< DeleteDbClusterOutput> - Deletes a Timestream for InfluxDB cluster.
-
deleteDbInstance(
{required String identifier}) → Future< DeleteDbInstanceOutput> - Deletes a Timestream for InfluxDB DB instance.
-
getDbCluster(
{required String dbClusterId}) → Future< GetDbClusterOutput> - Retrieves information about a Timestream for InfluxDB cluster.
-
getDbInstance(
{required String identifier}) → Future< GetDbInstanceOutput> - Returns a Timestream for InfluxDB DB instance.
-
getDbParameterGroup(
{required String identifier}) → Future< GetDbParameterGroupOutput> - Returns a Timestream for InfluxDB DB parameter group.
-
listDbClusters(
{int? maxResults, String? nextToken}) → Future< ListDbClustersOutput> - Returns a list of Timestream for InfluxDB DB clusters.
-
listDbInstances(
{int? maxResults, String? nextToken}) → Future< ListDbInstancesOutput> - Returns a list of Timestream for InfluxDB DB instances.
-
listDbInstancesForCluster(
{required String dbClusterId, int? maxResults, String? nextToken}) → Future< ListDbInstancesForClusterOutput> - Returns a list of Timestream for InfluxDB clusters.
-
listDbParameterGroups(
{int? maxResults, String? nextToken}) → Future< ListDbParameterGroupsOutput> - Returns a list of Timestream for InfluxDB DB parameter groups.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceResponse> - A list of tags applied to the resource.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebootDbCluster(
{required String dbClusterId, List< String> ? instanceIds}) → Future<RebootDbClusterOutput> - Reboots a Timestream for InfluxDB cluster.
-
rebootDbInstance(
{required String identifier}) → Future< RebootDbInstanceOutput> - Reboots a Timestream for InfluxDB instance.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Tags are composed of a Key/Value pairs. You can use tags to categorize and track your Timestream for InfluxDB resources.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Removes the tag from the specified resource.
-
updateDbCluster(
{required String dbClusterId, DbInstanceType? dbInstanceType, String? dbParameterGroupIdentifier, FailoverMode? failoverMode, LogDeliveryConfiguration? logDeliveryConfiguration, MaintenanceSchedule? maintenanceSchedule, int? port}) → Future< UpdateDbClusterOutput> - Updates a Timestream for InfluxDB cluster.
-
updateDbInstance(
{required String identifier, int? allocatedStorage, DbInstanceType? dbInstanceType, String? dbParameterGroupIdentifier, DbStorageType? dbStorageType, DeploymentType? deploymentType, LogDeliveryConfiguration? logDeliveryConfiguration, MaintenanceSchedule? maintenanceSchedule, int? port}) → Future< UpdateDbInstanceOutput> - Updates a Timestream for InfluxDB DB instance.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited