Cancels a query that has been issued. Cancellation is provided only if the
query has not completed running before the cancellation request was
issued. Because cancellation is an idempotent operation, subsequent
cancellation requests will return a CancellationMessage,
indicating that the query has already been canceled. See code
sample for details.
Create a scheduled query that will be run on your behalf at the configured
schedule. Timestream assumes the execution role provided as part of the
ScheduledQueryExecutionRoleArn parameter to run the query.
You can use the NotificationConfiguration parameter to
configure notification for your scheduled query operations.
Describes the settings for your account that include the query pricing
model and the configured maximum TCUs the service can use for your query
workload.
A synchronous operation that allows you to submit a query with parameters
to be stored by Timestream for later running. Timestream only supports
using this operation with ValidateOnly set to
true.
Associate a set of tags with a Timestream resource. You can then activate
these user-defined tags so that they appear on the Billing and Cost
Management console for cost allocation tracking.
Transitions your account to use TCUs for query pricing and modifies the
maximum query compute units that you've configured. If you reduce the
value of MaxQueryTCU to a desired configuration, the new
value can take up to 24 hours to be effective.