listScheduledQueries method
Gets a list of all scheduled queries in the caller's Amazon account and
Region. ListScheduledQueries is eventually consistent.
May throw AccessDeniedException.
May throw InternalServerException.
May throw InvalidEndpointException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of items to return in the output. If the total number
of items available is more than the value specified, a
NextToken is provided in the output. To resume pagination,
provide the NextToken value as the argument to the subsequent
call to ListScheduledQueriesRequest.
Parameter nextToken :
A pagination token to resume pagination.
Implementation
Future<ListScheduledQueriesResponse> listScheduledQueries({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.ListScheduledQueries'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
},
);
return ListScheduledQueriesResponse.fromJson(jsonResponse.body);
}