untagResource method
Removes the association of tags from a Timestream query resource.
May throw InvalidEndpointException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceARN :
The Timestream resource that the tags will be removed from. This value is
an Amazon Resource Name (ARN).
Parameter tagKeys :
A list of tags keys. Existing tags of the resource whose keys are members
of this list will be removed from the Timestream resource.
Implementation
Future<void> untagResource({
required String resourceARN,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceARN': resourceARN,
'TagKeys': tagKeys,
},
);
}