describeEndpoints method
Returns a list of available endpoints to make Timestream API calls against. This API operation is available through both the Write and Query APIs.
Because the Timestream SDKs are designed to transparently work with the service’s architecture, including the management and mapping of the service endpoints, we don't recommend that you use this API operation unless:
- You are using VPC endpoints (Amazon Web Services PrivateLink) with Timestream
- Your application uses a programming language that does not yet have SDK support
- You require better control over the client-side implementation
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Implementation
Future<DescribeEndpointsResponse> describeEndpoints() async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'Timestream_20181101.DescribeEndpoints'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
);
return DescribeEndpointsResponse.fromJson(jsonResponse.body);
}