Tnb class
Amazon Web Services Telco Network Builder (TNB) is a network automation service that helps you deploy and manage telecom networks. AWS TNB helps you with the lifecycle management of your telecommunication network functions throughout planning, deployment, and post-deployment activities.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelSolNetworkOperation(
{required String nsLcmOpOccId}) → Future< void> - Cancels a network operation.
-
close(
) → void - Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
-
createSolFunctionPackage(
{Map< String, String> ? tags}) → Future<CreateSolFunctionPackageOutput> - Creates a function package.
-
createSolNetworkInstance(
{required String nsName, required String nsdInfoId, String? nsDescription, Map< String, String> ? tags}) → Future<CreateSolNetworkInstanceOutput> - Creates a network instance.
-
createSolNetworkPackage(
{Map< String, String> ? tags}) → Future<CreateSolNetworkPackageOutput> - Creates a network package.
-
deleteSolFunctionPackage(
{required String vnfPkgId}) → Future< void> - Deletes a function package.
-
deleteSolNetworkInstance(
{required String nsInstanceId}) → Future< void> - Deletes a network instance.
-
deleteSolNetworkPackage(
{required String nsdInfoId}) → Future< void> - Deletes network package.
-
getSolFunctionInstance(
{required String vnfInstanceId}) → Future< GetSolFunctionInstanceOutput> - Gets the details of a network function instance, including the instantiation state and metadata from the function package descriptor in the network function package.
-
getSolFunctionPackage(
{required String vnfPkgId}) → Future< GetSolFunctionPackageOutput> - Gets the details of an individual function package, such as the operational state and whether the package is in use.
-
getSolFunctionPackageContent(
{required PackageContentType accept, required String vnfPkgId}) → Future< GetSolFunctionPackageContentOutput> - Gets the contents of a function package.
-
getSolFunctionPackageDescriptor(
{required DescriptorContentType accept, required String vnfPkgId}) → Future< GetSolFunctionPackageDescriptorOutput> - Gets a function package descriptor in a function package.
-
getSolNetworkInstance(
{required String nsInstanceId}) → Future< GetSolNetworkInstanceOutput> - Gets the details of the network instance.
-
getSolNetworkOperation(
{required String nsLcmOpOccId}) → Future< GetSolNetworkOperationOutput> - Gets the details of a network operation, including the tasks involved in the network operation and the status of the tasks.
-
getSolNetworkPackage(
{required String nsdInfoId}) → Future< GetSolNetworkPackageOutput> - Gets the details of a network package.
-
getSolNetworkPackageContent(
{required PackageContentType accept, required String nsdInfoId}) → Future< GetSolNetworkPackageContentOutput> - Gets the contents of a network package.
-
getSolNetworkPackageDescriptor(
{required String nsdInfoId}) → Future< GetSolNetworkPackageDescriptorOutput> - Gets the content of the network service descriptor.
-
instantiateSolNetworkInstance(
{required String nsInstanceId, Document? additionalParamsForNs, bool? dryRun, Map< String, String> ? tags}) → Future<InstantiateSolNetworkInstanceOutput> - Instantiates a network instance.
-
listSolFunctionInstances(
{int? maxResults, String? nextToken}) → Future< ListSolFunctionInstancesOutput> - Lists network function instances.
-
listSolFunctionPackages(
{int? maxResults, String? nextToken}) → Future< ListSolFunctionPackagesOutput> - Lists information about function packages.
-
listSolNetworkInstances(
{int? maxResults, String? nextToken}) → Future< ListSolNetworkInstancesOutput> - Lists your network instances.
-
listSolNetworkOperations(
{int? maxResults, String? nextToken, String? nsInstanceId}) → Future< ListSolNetworkOperationsOutput> - Lists details for a network operation, including when the operation started and the status of the operation.
-
listSolNetworkPackages(
{int? maxResults, String? nextToken}) → Future< ListSolNetworkPackagesOutput> - Lists network packages.
-
listTagsForResource(
{required String resourceArn}) → Future< ListTagsForResourceOutput> - Lists tags for AWS TNB resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putSolFunctionPackageContent(
{required Uint8List file, required String vnfPkgId, PackageContentType? contentType}) → Future< PutSolFunctionPackageContentOutput> - Uploads the contents of a function package.
-
putSolNetworkPackageContent(
{required Uint8List file, required String nsdInfoId, PackageContentType? contentType}) → Future< PutSolNetworkPackageContentOutput> - Uploads the contents of a network package.
-
tagResource(
{required String resourceArn, required Map< String, String> tags}) → Future<void> - Tags an AWS TNB resource.
-
terminateSolNetworkInstance(
{required String nsInstanceId, Map< String, String> ? tags}) → Future<TerminateSolNetworkInstanceOutput> - Terminates a network instance.
-
toString(
) → String -
A string representation of this object.
inherited
-
untagResource(
{required String resourceArn, required List< String> tagKeys}) → Future<void> - Untags an AWS TNB resource.
-
updateSolFunctionPackage(
{required OperationalState operationalState, required String vnfPkgId}) → Future< UpdateSolFunctionPackageOutput> - Updates the operational state of function package.
-
updateSolNetworkInstance(
{required String nsInstanceId, required UpdateSolNetworkType updateType, UpdateSolNetworkModify? modifyVnfInfoData, Map< String, String> ? tags, UpdateSolNetworkServiceData? updateNs}) → Future<UpdateSolNetworkInstanceOutput> - Update a network instance.
-
updateSolNetworkPackage(
{required String nsdInfoId, required NsdOperationalState nsdOperationalState}) → Future< UpdateSolNetworkPackageOutput> - Updates the operational state of a network package.
-
validateSolFunctionPackageContent(
{required Uint8List file, required String vnfPkgId, PackageContentType? contentType}) → Future< ValidateSolFunctionPackageContentOutput> - Validates function package content. This can be used as a dry run before uploading function package content with PutSolFunctionPackageContent.
-
validateSolNetworkPackageContent(
{required Uint8List file, required String nsdInfoId, PackageContentType? contentType}) → Future< ValidateSolNetworkPackageContentOutput> - Validates network package content. This can be used as a dry run before uploading network package content with PutSolNetworkPackageContent.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited