createSolNetworkInstance method
Creates a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed. Creating a network instance is the third step after creating a network package. For more information about network instances, Network instances in the Amazon Web Services Telco Network Builder User Guide.
Once you create a network instance, you can instantiate it. To instantiate a network, see InstantiateSolNetworkInstance.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsName :
Network instance name.
Parameter nsdInfoId :
ID for network service descriptor.
Parameter nsDescription :
Network instance description.
Parameter tags :
A tag is a label that you assign to an Amazon Web Services resource. Each
tag consists of a key and an optional value. You can use tags to search
and filter your resources or track your Amazon Web Services costs.
Implementation
Future<CreateSolNetworkInstanceOutput> createSolNetworkInstance({
required String nsName,
required String nsdInfoId,
String? nsDescription,
Map<String, String>? tags,
}) async {
final $payload = <String, dynamic>{
'nsName': nsName,
'nsdInfoId': nsdInfoId,
if (nsDescription != null) 'nsDescription': nsDescription,
if (tags != null) 'tags': tags,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/sol/nslcm/v1/ns_instances',
exceptionFnMap: _exceptionFns,
);
return CreateSolNetworkInstanceOutput.fromJson(response);
}