deleteSolFunctionPackage method
Deletes a function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
To delete a function package, the package must be in a disabled state. To disable a function package, see UpdateSolFunctionPackage.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter vnfPkgId :
ID of the function package.
Implementation
Future<void> deleteSolFunctionPackage({
required String vnfPkgId,
}) async {
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri:
'/sol/vnfpkgm/v1/vnf_packages/${Uri.encodeComponent(vnfPkgId)}',
exceptionFnMap: _exceptionFns,
);
}