deleteSolNetworkPackage method

Future<void> deleteSolNetworkPackage({
  1. required String nsdInfoId,
})

Deletes network package.

A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.

To delete a network package, the package must be in a disable state. To disable a network package, see UpdateSolNetworkPackage.

May throw AccessDeniedException. May throw InternalServerException. May throw ResourceNotFoundException. May throw ThrottlingException. May throw ValidationException.

Parameter nsdInfoId : ID of the network service descriptor in the network package.

Implementation

Future<void> deleteSolNetworkPackage({
  required String nsdInfoId,
}) async {
  await _protocol.send(
    payload: null,
    method: 'DELETE',
    requestUri:
        '/sol/nsd/v1/ns_descriptors/${Uri.encodeComponent(nsdInfoId)}',
    exceptionFnMap: _exceptionFns,
  );
}