getSolFunctionInstance method
Gets the details of a network function instance, including the instantiation state and metadata from the function package descriptor in the network function package.
A network function instance is a function in a function package .
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter vnfInstanceId :
ID of the network function.
Implementation
Future<GetSolFunctionInstanceOutput> getSolFunctionInstance({
required String vnfInstanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/sol/vnflcm/v1/vnf_instances/${Uri.encodeComponent(vnfInstanceId)}',
exceptionFnMap: _exceptionFns,
);
return GetSolFunctionInstanceOutput.fromJson(response);
}