getSolNetworkInstance method
Gets the details of the network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter nsInstanceId :
ID of the network instance.
Implementation
Future<GetSolNetworkInstanceOutput> getSolNetworkInstance({
required String nsInstanceId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri:
'/sol/nslcm/v1/ns_instances/${Uri.encodeComponent(nsInstanceId)}',
exceptionFnMap: _exceptionFns,
);
return GetSolNetworkInstanceOutput.fromJson(response);
}