deleteCallAnalyticsCategory method
Deletes a Call Analytics category. To use this operation, specify the name
of the category you want to delete using CategoryName.
Category names are case sensitive.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter categoryName :
The name of the Call Analytics category you want to delete. Category names
are case sensitive.
Implementation
Future<void> deleteCallAnalyticsCategory({
required String categoryName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.DeleteCallAnalyticsCategory'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CategoryName': categoryName,
},
);
}