deleteMedicalVocabulary method
Deletes a custom medical vocabulary. To use this operation, specify the
name of the custom vocabulary you want to delete using
VocabularyName. Custom vocabulary names are case sensitive.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter vocabularyName :
The name of the custom medical vocabulary you want to delete. Custom
medical vocabulary names are case sensitive.
Implementation
Future<void> deleteMedicalVocabulary({
required String vocabularyName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.DeleteMedicalVocabulary'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'VocabularyName': vocabularyName,
},
);
}