getCallAnalyticsJob method
Provides information about the specified Call Analytics job.
To view the job's status, refer to CallAnalyticsJobStatus. If
the status is COMPLETED, the job is finished. You can find
your completed transcript at the URI specified in
TranscriptFileUri. If the status is FAILED,
FailureReason provides details on why your transcription job
failed.
If you enabled personally identifiable information (PII) redaction, the
redacted transcript appears at the location specified in
RedactedTranscriptFileUri.
If you chose to redact the audio in your media file, you can find your
redacted media file at the location specified in
RedactedMediaFileUri.
To get a list of your Call Analytics jobs, use the operation.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter callAnalyticsJobName :
The name of the Call Analytics job you want information about. Job names
are case sensitive.
Implementation
Future<GetCallAnalyticsJobResponse> getCallAnalyticsJob({
required String callAnalyticsJobName,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.GetCallAnalyticsJob'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'CallAnalyticsJobName': callAnalyticsJobName,
},
);
return GetCallAnalyticsJobResponse.fromJson(jsonResponse.body);
}