listCallAnalyticsJobs method
Provides a list of Call Analytics jobs that match the specified criteria. If no criteria are specified, all Call Analytics jobs are returned.
To get detailed information about a specific Call Analytics job, use the operation.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
Parameter jobNameContains :
Returns only the Call Analytics jobs that contain the specified string.
The search is not case sensitive.
Parameter maxResults :
The maximum number of Call Analytics jobs to return in each page of
results. If there are fewer results than the value that you specify, only
the actual results are returned. If you do not specify a value, a default
of 5 is used.
Parameter nextToken :
If your ListCallAnalyticsJobs request returns more results
than can be displayed, NextToken is displayed in the response
with an associated string. To get the next page of results, copy this
string and repeat your request, including NextToken with the
value of the copied string. Repeat as needed to view all your results.
Parameter status :
Returns only Call Analytics jobs with the specified status. Jobs are
ordered by creation date, with the newest job first. If you do not include
Status, all Call Analytics jobs are returned.
Implementation
Future<ListCallAnalyticsJobsResponse> listCallAnalyticsJobs({
String? jobNameContains,
int? maxResults,
String? nextToken,
CallAnalyticsJobStatus? status,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.ListCallAnalyticsJobs'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (jobNameContains != null) 'JobNameContains': jobNameContains,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (status != null) 'Status': status.value,
},
);
return ListCallAnalyticsJobsResponse.fromJson(jsonResponse.body);
}