listVocabularies method
Provides a list of custom vocabularies that match the specified criteria. If no criteria are specified, all custom vocabularies are returned.
To get detailed information about a specific custom vocabulary, use the operation.
May throw BadRequestException.
May throw InternalFailureException.
May throw LimitExceededException.
Parameter maxResults :
The maximum number of custom vocabularies to return in each page of
results. If there are fewer results than the value that you specify, only
the actual results are returned. If you do not specify a value, a default
of 5 is used.
Parameter nameContains :
Returns only the custom vocabularies that contain the specified string.
The search is not case sensitive.
Parameter nextToken :
If your ListVocabularies request returns more results than
can be displayed, NextToken is displayed in the response with
an associated string. To get the next page of results, copy this string
and repeat your request, including NextToken with the value
of the copied string. Repeat as needed to view all your results.
Parameter stateEquals :
Returns only custom vocabularies with the specified state. Vocabularies
are ordered by creation date, with the newest vocabulary first. If you do
not include StateEquals, all custom medical vocabularies are
returned.
Implementation
Future<ListVocabulariesResponse> listVocabularies({
int? maxResults,
String? nameContains,
String? nextToken,
VocabularyState? stateEquals,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.ListVocabularies'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (maxResults != null) 'MaxResults': maxResults,
if (nameContains != null) 'NameContains': nameContains,
if (nextToken != null) 'NextToken': nextToken,
if (stateEquals != null) 'StateEquals': stateEquals.value,
},
);
return ListVocabulariesResponse.fromJson(jsonResponse.body);
}