untagResource method
Removes the specified tags from the specified Amazon Transcribe resource.
If you include UntagResource in your request, you must also
include ResourceArn and TagKeys.
May throw BadRequestException.
May throw ConflictException.
May throw InternalFailureException.
May throw LimitExceededException.
May throw NotFoundException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Amazon Transcribe resource you want
to remove tags from. ARNs have the format
arn:partition:service:region:account-id:resource-type/resource-id.
For example,
arn:aws:transcribe:us-west-2:111122223333:transcription-job/transcription-job-name.
Valid values for resource-type are:
transcription-job, medical-transcription-job,
vocabulary, medical-vocabulary,
vocabulary-filter, and language-model.
Parameter tagKeys :
Removes the specified tag keys from the specified Amazon Transcribe
resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Transcribe.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
);
}