createConnector method
Creates the connector, which captures the parameters for a connection for the AS2 or SFTP protocol. For AS2, the connector is required for sending files to an externally hosted AS2 server. For SFTP, the connector is required when sending files to an SFTP server or receiving files from an SFTP server. For more details about connectors, see Configure AS2 connectors and Create SFTP connectors.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter accessRole :
Connectors are used to send files using either the AS2 or SFTP protocol.
For the access role, provide the Amazon Resource Name (ARN) of the
Identity and Access Management role to use.
For AS2 connectors
With AS2, you can send files by calling StartFileTransfer and
specifying the file paths in the request parameter,
SendFilePaths. We use the file’s parent directory (for
example, for --send-file-paths /bucket/dir/file.txt, parent
directory is /bucket/dir/) to temporarily store a processed
AS2 message file, store the MDN when we receive them from the partner, and
write a final JSON file containing relevant metadata of the transmission.
So, the AccessRole needs to provide read and write access to
the parent directory of the file location used in the
StartFileTransfer request. Additionally, you need to provide
read and write access to the parent directory of the files that you intend
to send with StartFileTransfer.
If you are using Basic authentication for your AS2 connector, the access
role requires the secretsmanager:GetSecretValue permission
for the secret. If the secret is encrypted using a customer-managed key
instead of the Amazon Web Services managed key in Secrets Manager, then
the role also needs the kms:Decrypt permission for that key.
For SFTP connectors
Make sure that the access role provides read and write access to the
parent directory of the file location that's used in the
StartFileTransfer request. Additionally, make sure that the
role provides secretsmanager:GetSecretValue permission to
Secrets Manager.
Parameter as2Config :
A structure that contains the parameters for an AS2 connector object.
Parameter egressConfig :
Specifies the egress configuration for the connector, which determines how
traffic is routed from the connector to the SFTP server. When set to VPC,
enables routing through customer VPCs using VPC_LATTICE for private
connectivity.
Parameter ipAddressType :
Specifies the IP address type for the connector's network connections.
When set to IPV4, the connector uses IPv4 addresses only.
When set to DUALSTACK, the connector supports both IPv4 and
IPv6 addresses, with IPv6 preferred when available.
Parameter loggingRole :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role that allows a connector to turn on CloudWatch logging for Amazon S3
events. When set, you can view connector activity in your CloudWatch logs.
Parameter securityPolicyName :
Specifies the name of the security policy for the connector.
Parameter sftpConfig :
A structure that contains the parameters for an SFTP connector object.
Parameter tags :
Key-value pairs that can be used to group and search for connectors. Tags
are metadata attached to connectors for any purpose.
Parameter url :
The URL of the partner's AS2 or SFTP endpoint.
When creating AS2 connectors or service-managed SFTP connectors (connectors without egress configuration), you must provide a URL to specify the remote server endpoint. For VPC Lattice type connectors, the URL must be null.
Implementation
Future<CreateConnectorResponse> createConnector({
required String accessRole,
As2ConnectorConfig? as2Config,
ConnectorEgressConfig? egressConfig,
ConnectorsIpAddressType? ipAddressType,
String? loggingRole,
String? securityPolicyName,
SftpConnectorConfig? sftpConfig,
List<Tag>? tags,
String? url,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.CreateConnector'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'AccessRole': accessRole,
if (as2Config != null) 'As2Config': as2Config,
if (egressConfig != null) 'EgressConfig': egressConfig,
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (loggingRole != null) 'LoggingRole': loggingRole,
if (securityPolicyName != null)
'SecurityPolicyName': securityPolicyName,
if (sftpConfig != null) 'SftpConfig': sftpConfig,
if (tags != null) 'Tags': tags,
if (url != null) 'Url': url,
},
);
return CreateConnectorResponse.fromJson(jsonResponse.body);
}