describeAccess method
Describes the access that is assigned to the specific file transfer
protocol-enabled server, as identified by its ServerId
property and its ExternalId.
The response from this call returns the properties of the access that is
associated with the ServerId value that was specified.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter externalId :
A unique identifier that is required to identify specific groups within
your directory. The users of the group that you associate have access to
your Amazon S3 or Amazon EFS resources over the enabled protocols using
Transfer Family. If you know the group name, you can view the SID values
by running the following command using Windows PowerShell.
Get-ADGroup -Filter {samAccountName -like "YourGroupName*"}
-Properties * | Select SamAccountName,ObjectSid
In that command, replace YourGroupName with the name of your Active Directory group.
The regular expression used to validate this parameter is a string of characters consisting of uppercase and lowercase alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@:/-
Parameter serverId :
A system-assigned unique identifier for a server that has this access
assigned.
Implementation
Future<DescribeAccessResponse> describeAccess({
required String externalId,
required String serverId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.DescribeAccess'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ExternalId': externalId,
'ServerId': serverId,
},
);
return DescribeAccessResponse.fromJson(jsonResponse.body);
}