describeExecution method
You can use DescribeExecution to check the details of the
execution of the specified workflow.
If you provide an ID for an execution that is not in progress, or if the
execution doesn't match the specified workflow ID, you receive a
ResourceNotFound exception.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
Parameter executionId :
A unique identifier for the execution of a workflow.
Parameter workflowId :
A unique identifier for the workflow.
Implementation
Future<DescribeExecutionResponse> describeExecution({
required String executionId,
required String workflowId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.DescribeExecution'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ExecutionId': executionId,
'WorkflowId': workflowId,
},
);
return DescribeExecutionResponse.fromJson(jsonResponse.body);
}