updateAccess method
Allows you to update parameters for the access specified in the
ServerID and ExternalID parameters.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter externalId :
A unique identifier that is required to identify specific groups within
your directory. The users of the group that you associate have access to
your Amazon S3 or Amazon EFS resources over the enabled protocols using
Transfer Family. If you know the group name, you can view the SID values
by running the following command using Windows PowerShell.
Get-ADGroup -Filter {samAccountName -like "YourGroupName*"}
-Properties * | Select SamAccountName,ObjectSid
In that command, replace YourGroupName with the name of your Active Directory group.
The regular expression used to validate this parameter is a string of characters consisting of uppercase and lowercase alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@:/-
Parameter serverId :
A system-assigned unique identifier for a server instance. This is the
specific server that you added your user to.
Parameter homeDirectory :
The landing directory (folder) for a user when they log in to the server
using the client.
A HomeDirectory example is
/bucket_name/home/mydirectory.
Parameter homeDirectoryMappings :
Logical directory mappings that specify what Amazon S3 or Amazon EFS paths
and keys should be visible to your user and how you want to make them
visible. You must specify the Entry and Target
pair, where Entry shows how the path is made visible and
Target is the actual Amazon S3 or Amazon EFS path. If you
only specify a target, it is displayed as is. You also must ensure that
your Identity and Access Management (IAM) role provides access to paths in
Target. This value can be set only when
HomeDirectoryType is set to LOGICAL.
The following is an Entry and Target pair
example.
[ { "Entry": "/directory1", "Target":
"/bucket_name/home/mydirectory" } ]
In most cases, you can use this value instead of the session policy to
lock down your user to the designated home directory
("chroot"). To do this, you can set Entry to
/ and set Target to the
HomeDirectory parameter value.
The following is an Entry and Target pair
example for chroot.
[ { "Entry": "/", "Target": "/bucket_name/home/mydirectory" }
]
Parameter homeDirectoryType :
The type of landing directory (folder) that you want your users' home
directory to be when they log in to the server. If you set it to
PATH, the user will see the absolute Amazon S3 bucket or
Amazon EFS path as is in their file transfer protocol clients. If you set
it to LOGICAL, you need to provide mappings in the
HomeDirectoryMappings for how you want to make Amazon S3 or
Amazon EFS paths visible to your users.
Parameter policy :
A session policy for your user so that you can use the same Identity and
Access Management (IAM) role across multiple users. This policy scopes
down a user's access to portions of their Amazon S3 bucket. Variables that
you can use inside this policy include ${Transfer:UserName},
${Transfer:HomeDirectory}, and
${Transfer:HomeBucket}.
For session policies, Transfer Family stores the policy as a JSON blob,
instead of the Amazon Resource Name (ARN) of the policy. You save the
policy as a JSON blob and pass it in the Policy argument.
For an example of a session policy, see Example session policy.
For more information, see AssumeRole in the Amazon Web ServicesSecurity Token Service API Reference.
Parameter role :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role that controls your users' access to your Amazon S3 bucket or Amazon
EFS file system. The policies attached to this role determine the level of
access that you want to provide your users when transferring files into
and out of your Amazon S3 bucket or Amazon EFS file system. The IAM role
should also contain a trust relationship that allows the server to access
your resources when servicing your users' transfer requests.
Implementation
Future<UpdateAccessResponse> updateAccess({
required String externalId,
required String serverId,
String? homeDirectory,
List<HomeDirectoryMapEntry>? homeDirectoryMappings,
HomeDirectoryType? homeDirectoryType,
String? policy,
PosixProfile? posixProfile,
String? role,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.UpdateAccess'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ExternalId': externalId,
'ServerId': serverId,
if (homeDirectory != null) 'HomeDirectory': homeDirectory,
if (homeDirectoryMappings != null)
'HomeDirectoryMappings': homeDirectoryMappings,
if (homeDirectoryType != null)
'HomeDirectoryType': homeDirectoryType.value,
if (policy != null) 'Policy': policy,
if (posixProfile != null) 'PosixProfile': posixProfile,
if (role != null) 'Role': role,
},
);
return UpdateAccessResponse.fromJson(jsonResponse.body);
}