updateServer method
- required String serverId,
- String? certificate,
- EndpointDetails? endpointDetails,
- EndpointType? endpointType,
- String? hostKey,
- IdentityProviderDetails? identityProviderDetails,
- IdentityProviderType? identityProviderType,
- IpAddressType? ipAddressType,
- String? loggingRole,
- String? postAuthenticationLoginBanner,
- String? preAuthenticationLoginBanner,
- ProtocolDetails? protocolDetails,
- List<
Protocol> ? protocols, - S3StorageOptions? s3StorageOptions,
- String? securityPolicyName,
- List<
String> ? structuredLogDestinations, - WorkflowDetails? workflowDetails,
Updates the file transfer protocol-enabled server's properties after that server has been created.
The UpdateServer call returns the ServerId of
the server you updated.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceExistsException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw ThrottlingException.
Parameter serverId :
A system-assigned unique identifier for a server instance that the
Transfer Family user is assigned to.
Parameter certificate :
The Amazon Resource Name (ARN) of the Amazon Web ServicesCertificate
Manager (ACM) certificate. Required when Protocols is set to
FTPS.
To request a new public certificate, see Request a public certificate in the Amazon Web ServicesCertificate Manager User Guide.
To import an existing certificate into ACM, see Importing certificates into ACM in the Amazon Web ServicesCertificate Manager User Guide.
To request a private certificate to use FTPS through private IP addresses, see Request a private certificate in the Amazon Web ServicesCertificate Manager User Guide.
Certificates with the following cryptographic algorithms and key sizes are supported:
- 2048-bit RSA (RSA_2048)
- 4096-bit RSA (RSA_4096)
- Elliptic Prime Curve 256 bit (EC_prime256v1)
- Elliptic Prime Curve 384 bit (EC_secp384r1)
- Elliptic Prime Curve 521 bit (EC_secp521r1)
Parameter endpointDetails :
The virtual private cloud (VPC) endpoint settings that are configured for
your server. When you host your endpoint within your VPC, you can make
your endpoint accessible only to resources within your VPC, or you can
attach Elastic IP addresses and make your endpoint accessible to clients
over the internet. Your VPC's default security groups are automatically
assigned to your endpoint.
Parameter endpointType :
The type of endpoint that you want your server to use. You can choose to
make your server's endpoint publicly accessible (PUBLIC) or host it inside
your VPC. With an endpoint that is hosted in a VPC, you can restrict
access to your server and resources only within your VPC or choose to make
it internet facing by attaching Elastic IP addresses directly to it.
For more information, see https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#deprecate-vpc-endpoint.
It is recommended that you use VPC as the
EndpointType. With this endpoint type, you have the option to
directly associate up to three Elastic IPv4 addresses (BYO IP included)
with your server's endpoint and use VPC security groups to restrict
traffic by the client's public IP address. This is not possible with
EndpointType set to VPC_ENDPOINT.
Parameter hostKey :
The RSA, ECDSA, or ED25519 private key to use for your SFTP-enabled
server. You can add multiple host keys, in case you want to rotate keys,
or have a set of active keys that use different algorithms.
Use the following command to generate an RSA 2048 bit key with no passphrase:
ssh-keygen -t rsa -b 2048 -N "" -m PEM -f my-new-server-key.
Use a minimum value of 2048 for the -b option. You can create
a stronger key by using 3072 or 4096.
Use the following command to generate an ECDSA 256 bit key with no passphrase:
ssh-keygen -t ecdsa -b 256 -N "" -m PEM -f my-new-server-key.
Valid values for the -b option for ECDSA are 256, 384, and
521.
Use the following command to generate an ED25519 key with no passphrase:
ssh-keygen -t ed25519 -N "" -f my-new-server-key.
For all of these commands, you can replace my-new-server-key with a string of your choice. For more information, see Manage host keys for your SFTP-enabled server in the Transfer Family User Guide.
Parameter identityProviderDetails :
An array containing all of the information required to call a customer's
authentication API method.
Parameter identityProviderType :
The mode of authentication for a server. The default value is
SERVICE_MANAGED, which allows you to store and access user
credentials within the Transfer Family service.
Use AWS_DIRECTORY_SERVICE to provide access to Active
Directory groups in Directory Service for Microsoft Active Directory or
Microsoft Active Directory in your on-premises environment or in Amazon
Web Services using AD Connector. This option also requires you to provide
a Directory ID by using the IdentityProviderDetails
parameter.
Use the API_GATEWAY value to integrate with an identity
provider of your choosing. The API_GATEWAY setting requires
you to provide an Amazon API Gateway endpoint URL to call for
authentication by using the IdentityProviderDetails
parameter.
Use the AWS_LAMBDA value to directly use an Lambda function
as your identity provider. If you choose this value, you must specify the
ARN for the Lambda function in the Function parameter for the
IdentityProviderDetails data type.
Parameter ipAddressType :
Specifies whether to use IPv4 only, or to use dual-stack (IPv4 and IPv6)
for your Transfer Family endpoint. The default value is IPV4.
- It cannot be changed while the server is online. You must stop the server before modifying this parameter.
-
It cannot be updated to
DUALSTACKif the server hasAddressAllocationIdsspecified.
Parameter loggingRole :
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM)
role that allows a server to turn on Amazon CloudWatch logging for Amazon
S3 or Amazon EFS events. When set, you can view user activity in your
CloudWatch logs.
Parameter postAuthenticationLoginBanner :
Specifies a string to display when users connect to a server. This string
is displayed after the user authenticates.
Parameter preAuthenticationLoginBanner :
Specifies a string to display when users connect to a server. This string
is displayed before the user authenticates. For example, the following
banner displays details about using the system:
This system is for the use of authorized users only. Individuals
using this computer system without authority, or in excess of their
authority, are subject to having all of their activities on this system
monitored and recorded by system personnel.
Parameter protocolDetails :
The protocol settings that are configured for your server.
-
To indicate passive mode (for FTP and FTPS protocols), use the
PassiveIpparameter. Enter a single dotted-quad IPv4 address, such as the external IP address of a firewall, router, or load balancer. -
To ignore the error that is generated when the client attempts to use the
SETSTATcommand on a file that you are uploading to an Amazon S3 bucket, use theSetStatOptionparameter. To have the Transfer Family server ignore theSETSTATcommand and upload files without needing to make any changes to your SFTP client, set the value toENABLE_NO_OP. If you set theSetStatOptionparameter toENABLE_NO_OP, Transfer Family generates a log entry to Amazon CloudWatch Logs, so that you can determine when the client is making aSETSTATcall. -
To determine whether your Transfer Family server resumes recent,
negotiated sessions through a unique session ID, use the
TlsSessionResumptionModeparameter. -
As2Transportsindicates the transport method for the AS2 messages. Currently, only HTTP is supported.
Parameter protocols :
Specifies the file transfer protocol or protocols over which your file
transfer protocol client can connect to your server's endpoint. The
available protocols are:
-
SFTP(Secure Shell (SSH) File Transfer Protocol): File transfer over SSH -
FTPS(File Transfer Protocol Secure): File transfer with TLS encryption -
FTP(File Transfer Protocol): Unencrypted file transfer -
AS2(Applicability Statement 2): used for transporting structured business-to-business data
Parameter s3StorageOptions :
Specifies whether or not performance for your Amazon S3 directories is
optimized.
- If using the console, this is enabled by default.
- If using the API or CLI, this is disabled by default.
TYPE of
DIRECTORY. If you enable this option, you would then need to
explicitly set the HomeDirectoryMapEntry Type to
FILE if you want a mapping to have a file target.
Parameter securityPolicyName :
Specifies the name of the security policy for the server.
Parameter structuredLogDestinations :
Specifies the log groups to which your server logs are sent.
To specify a log group, you must provide the ARN for an existing log group. In this case, the format of the log group is as follows:
arn:aws:logs:region-name:amazon-account-id:log-group:log-group-name:*
For example,
arn:aws:logs:us-east-1:111122223333:log-group:mytestgroup:*
If you have previously specified a log group for a server, you can clear
it, and in effect turn off structured logging, by providing an empty value
for this parameter in an update-server call. For example:
update-server --server-id s-1234567890abcdef0
--structured-log-destinations
Parameter workflowDetails :
Specifies the workflow ID for the workflow to assign and the execution
role that's used for executing the workflow.
In addition to a workflow to execute when a file is uploaded completely,
WorkflowDetails can also contain a workflow ID (and execution
role) for a workflow to execute on partial upload. A partial upload occurs
when the server session disconnects while the file is still being
uploaded.
To remove an associated workflow from a server, you can provide an empty
OnUpload object, as in the following example.
aws transfer update-server --server-id s-01234567890abcdef
--workflow-details '{"OnUpload":[]}'
Implementation
Future<UpdateServerResponse> updateServer({
required String serverId,
String? certificate,
EndpointDetails? endpointDetails,
EndpointType? endpointType,
String? hostKey,
IdentityProviderDetails? identityProviderDetails,
IdentityProviderType? identityProviderType,
IpAddressType? ipAddressType,
String? loggingRole,
String? postAuthenticationLoginBanner,
String? preAuthenticationLoginBanner,
ProtocolDetails? protocolDetails,
List<Protocol>? protocols,
S3StorageOptions? s3StorageOptions,
String? securityPolicyName,
List<String>? structuredLogDestinations,
WorkflowDetails? workflowDetails,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.UpdateServer'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ServerId': serverId,
if (certificate != null) 'Certificate': certificate,
if (endpointDetails != null) 'EndpointDetails': endpointDetails,
if (endpointType != null) 'EndpointType': endpointType.value,
if (hostKey != null) 'HostKey': hostKey,
if (identityProviderDetails != null)
'IdentityProviderDetails': identityProviderDetails,
if (identityProviderType != null)
'IdentityProviderType': identityProviderType.value,
if (ipAddressType != null) 'IpAddressType': ipAddressType.value,
if (loggingRole != null) 'LoggingRole': loggingRole,
if (postAuthenticationLoginBanner != null)
'PostAuthenticationLoginBanner': postAuthenticationLoginBanner,
if (preAuthenticationLoginBanner != null)
'PreAuthenticationLoginBanner': preAuthenticationLoginBanner,
if (protocolDetails != null) 'ProtocolDetails': protocolDetails,
if (protocols != null)
'Protocols': protocols.map((e) => e.value).toList(),
if (s3StorageOptions != null) 'S3StorageOptions': s3StorageOptions,
if (securityPolicyName != null)
'SecurityPolicyName': securityPolicyName,
if (structuredLogDestinations != null)
'StructuredLogDestinations': structuredLogDestinations,
if (workflowDetails != null) 'WorkflowDetails': workflowDetails,
},
);
return UpdateServerResponse.fromJson(jsonResponse.body);
}