updateWebApp method
Assigns new properties to a web app. You can modify the access point, identity provider details, endpoint configuration, and the web app units.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServiceError.
May throw InvalidRequestException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
Parameter webAppId :
Provide the identifier of the web app that you are updating.
Parameter accessEndpoint :
The AccessEndpoint is the URL that you provide to your users
for them to interact with the Transfer Family web app. You can specify a
custom URL or use the default value.
Parameter endpointDetails :
The updated endpoint configuration for the web app. You can modify the
endpoint type and VPC configuration settings.
Parameter identityProviderDetails :
Provide updated identity provider values in a
WebAppIdentityProviderDetails object.
Parameter webAppUnits :
A union that contains the value for number of concurrent connections or
the user sessions on your web app.
Implementation
Future<UpdateWebAppResponse> updateWebApp({
required String webAppId,
String? accessEndpoint,
UpdateWebAppEndpointDetails? endpointDetails,
UpdateWebAppIdentityProviderDetails? identityProviderDetails,
WebAppUnits? webAppUnits,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'TransferService.UpdateWebApp'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WebAppId': webAppId,
if (accessEndpoint != null) 'AccessEndpoint': accessEndpoint,
if (endpointDetails != null) 'EndpointDetails': endpointDetails,
if (identityProviderDetails != null)
'IdentityProviderDetails': identityProviderDetails,
if (webAppUnits != null) 'WebAppUnits': webAppUnits,
},
);
return UpdateWebAppResponse.fromJson(jsonResponse.body);
}