translateDocument method
Translates the input document from the source language to the target
language. This synchronous operation supports text, HTML, or Word
documents as the input document. TranslateDocument supports
translations from English to any supported language, and from any
supported language to English. Therefore, specify either the source
language code or the target language code as “en” (English).
If you set the Formality parameter, the request will fail if
the target language does not support formality. For a list of target
languages that support formality, see Setting
formality.
May throw InternalServerException.
May throw InvalidRequestException.
May throw LimitExceededException.
May throw ResourceNotFoundException.
May throw ServiceUnavailableException.
May throw TooManyRequestsException.
May throw UnsupportedLanguagePairException.
Parameter document :
The content and content type for the document to be translated. The
document size must not exceed 100 KB.
Parameter sourceLanguageCode :
The language code for the language of the source text. For a list of
supported language codes, see Supported
languages.
To have Amazon Translate determine the source language of your text, you
can specify auto in the SourceLanguageCode
field. If you specify auto, Amazon Translate will call Amazon
Comprehend to determine the source language.
Parameter targetLanguageCode :
The language code requested for the translated document. For a list of
supported language codes, see Supported
languages.
Parameter settings :
Settings to configure your translation output. You can configure the
following options:
- Brevity: not supported.
- Formality: sets the formality level of the output text.
- Profanity: masks profane words and phrases in your translation output.
Parameter terminologyNames :
The name of a terminology list file to add to the translation job. This
file provides source terms and the desired translation for each term. A
terminology list can contain a maximum of 256 terms. You can use one
custom terminology resource in your translation request.
Use the ListTerminologies operation to get the available terminology lists.
For more information about custom terminology lists, see Custom terminology.
Implementation
Future<TranslateDocumentResponse> translateDocument({
required Document document,
required String sourceLanguageCode,
required String targetLanguageCode,
TranslationSettings? settings,
List<String>? terminologyNames,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSShineFrontendService_20170701.TranslateDocument'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Document': document,
'SourceLanguageCode': sourceLanguageCode,
'TargetLanguageCode': targetLanguageCode,
if (settings != null) 'Settings': settings,
if (terminologyNames != null) 'TerminologyNames': terminologyNames,
},
);
return TranslateDocumentResponse.fromJson(jsonResponse.body);
}