listServices method
Returns a paginated list of Amazon Web Services service identifiers that
you can use as values for the visibleServices setting in UpdateAccountCustomizations.
The available services vary by Amazon Web Services partition. Use
pagination to retrieve all results.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter maxResults :
The maximum number of results to return per page.
Parameter nextToken :
The token for retrieving the next page of results. Use the
nextToken value from a previous response.
Implementation
Future<ListServicesOutput> listServices({
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1000,
);
final $query = <String, List<String>>{
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/v1/services',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListServicesOutput.fromJson(response);
}