updateAccountCustomizations method
Updates one or more account customization settings. You can update account
color, visible services, and visible Regions in a single request. Only the
settings that you include in the request body are modified. Omitted
settings remain unchanged. To reset a setting to its default behavior, set
the value to null for visible Regions and visible services,
or none for account color. This operation is idempotent.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter accountColor :
The account color preference to set. Set to none to reset to
the default (no color).
Parameter visibleRegions :
The list of Amazon Web Services Region codes to make visible in the Amazon
Web Services Management Console. Set to null to reset to the
default, which makes all Regions visible. For a list of valid Region
codes, see Amazon
Web Services Regions.
Parameter visibleServices :
The list of Amazon Web Services service identifiers to make visible in the
Amazon Web Services Management Console. Set to null to reset
to the default, which makes all services visible. For valid service
identifiers, call ListServices.
Implementation
Future<UpdateAccountCustomizationsOutput> updateAccountCustomizations({
AccountColor? accountColor,
List<String>? visibleRegions,
List<String>? visibleServices,
}) async {
final $payload = <String, dynamic>{
if (accountColor != null) 'accountColor': accountColor.value,
if (visibleRegions != null) 'visibleRegions': visibleRegions,
if (visibleServices != null) 'visibleServices': visibleServices,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri: '/v1/account-customizations',
exceptionFnMap: _exceptionFns,
);
return UpdateAccountCustomizationsOutput.fromJson(response);
}