listPolicyStoreAliases method
Returns a paginated list of all policy store aliases in the calling Amazon Web Services account.
Parameter filter :
Specifies a filter to narrow the results. You can filter by
policyStoreId to list only the policy store aliases
associated with a specific policy store.
Parameter maxResults :
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify, the
NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the maximum
even when there are more results available. You should check
NextToken after every operation to ensure that you receive
all of the results.
If you do not specify this parameter, the operation defaults to 5 policy store aliases per response. You can specify a maximum of 50 policy store aliases per response.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Implementation
Future<ListPolicyStoreAliasesOutput> listPolicyStoreAliases({
PolicyStoreAliasFilter? filter,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VerifiedPermissions.ListPolicyStoreAliases'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (filter != null) 'filter': filter,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListPolicyStoreAliasesOutput.fromJson(jsonResponse.body);
}