listPolicyTemplates method
Returns a paginated list of all policy templates in the specified policy store.
May throw ResourceNotFoundException.
Parameter policyStoreId :
Specifies the ID of the policy store that contains the policy templates
you want to list.
To specify a policy store, use its ID or alias name. When using an alias
name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
Parameter maxResults :
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify, the
NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the maximum
even when there are more results available. You should check
NextToken after every operation to ensure that you receive
all of the results.
If you do not specify this parameter, the operation defaults to 10 policy templates per response. You can specify a maximum of 50 policy templates per response.
Parameter nextToken :
Specifies that you want to receive the next page of results. Valid only if
you received a NextToken response in the previous request. If
you did, it indicates that more output is available. Set this parameter to
the value provided by the previous call's NextToken response
to request the next page of results.
Implementation
Future<ListPolicyTemplatesOutput> listPolicyTemplates({
required String policyStoreId,
int? maxResults,
String? nextToken,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
1152921504606846976,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VerifiedPermissions.ListPolicyTemplates'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'policyStoreId': policyStoreId,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return ListPolicyTemplatesOutput.fromJson(jsonResponse.body);
}