untagResource method
Removes specified tags from a specified Amazon Connect Voice ID resource.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the Voice ID resource you want to remove
tags from.
Parameter tagKeys :
The list of tag keys you want to remove from the specified resource.
Implementation
Future<void> untagResource({
required String resourceArn,
required List<String> tagKeys,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.0',
'X-Amz-Target': 'VoiceID.UntagResource'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
'TagKeys': tagKeys,
},
);
}