deleteTargetGroup method
Deletes a target group. You can't delete a target group if it is used in a listener rule or if the target group creation is in progress.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter targetGroupIdentifier :
The ID or ARN of the target group.
Implementation
Future<DeleteTargetGroupResponse> deleteTargetGroup({
required String targetGroupIdentifier,
}) async {
final response = await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/targetgroups/${Uri.encodeComponent(targetGroupIdentifier)}',
exceptionFnMap: _exceptionFns,
);
return DeleteTargetGroupResponse.fromJson(response);
}