listResourceConfigurations method
Lists the resource configurations owned by or shared with this account.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ThrottlingException.
May throw ValidationException.
Parameter domainVerificationIdentifier :
The domain verification ID.
Parameter maxResults :
The maximum page size.
Parameter nextToken :
A pagination token for the next page of results.
Parameter resourceConfigurationGroupIdentifier :
The ID of the resource configuration of type Group.
Parameter resourceGatewayIdentifier :
The ID of the resource gateway for the resource configuration.
Implementation
Future<ListResourceConfigurationsResponse> listResourceConfigurations({
String? domainVerificationIdentifier,
int? maxResults,
String? nextToken,
String? resourceConfigurationGroupIdentifier,
String? resourceGatewayIdentifier,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final $query = <String, List<String>>{
if (domainVerificationIdentifier != null)
'domainVerificationIdentifier': [domainVerificationIdentifier],
if (maxResults != null) 'maxResults': [maxResults.toString()],
if (nextToken != null) 'nextToken': [nextToken],
if (resourceConfigurationGroupIdentifier != null)
'resourceConfigurationGroupIdentifier': [
resourceConfigurationGroupIdentifier
],
if (resourceGatewayIdentifier != null)
'resourceGatewayIdentifier': [resourceGatewayIdentifier],
};
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/resourceconfigurations',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
return ListResourceConfigurationsResponse.fromJson(response);
}