deleteLoggingConfiguration method
- required String resourceArn,
- LogScope? logScope,
- LogType? logType,
Deletes the LoggingConfiguration from the specified web ACL.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
Parameter resourceArn :
The Amazon Resource Name (ARN) of the web ACL from which you want to
delete the LoggingConfiguration.
Parameter logScope :
The owner of the logging configuration, which must be set to
CUSTOMER for the configurations that you manage.
The log scope SECURITY_LAKE indicates a configuration that is
managed through Amazon Security Lake. You can use Security Lake to collect
log and event data from various sources for normalization, analysis, and
management. For information, see Collecting
data from Amazon Web Services services in the Amazon Security Lake
user guide.
The log scope CLOUDWATCH_TELEMETRY_RULE_MANAGED indicates a
configuration that is managed through Amazon CloudWatch Logs for telemetry
data collection and analysis. For information, see What
is Amazon CloudWatch Logs ? in the Amazon CloudWatch Logs user
guide.
Default: CUSTOMER
Parameter logType :
Used to distinguish between various logging options. Currently, there is
one option.
Default: WAF_LOGS
Implementation
Future<void> deleteLoggingConfiguration({
required String resourceArn,
LogScope? logScope,
LogType? logType,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.DeleteLoggingConfiguration'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ResourceArn': resourceArn,
if (logScope != null) 'LogScope': logScope.value,
if (logType != null) 'LogType': logType.value,
},
);
}