deleteWebACL method
Deletes the specified WebACL.
You can only use this if ManagedByFirewallManager is false in
the web ACL.
-
To retrieve a list of the resources that are associated with a web ACL,
use the following calls:
-
For Amazon CloudFront distributions, use the CloudFront call
ListDistributionsByWebACLId. For information, see ListDistributionsByWebACLId in the Amazon CloudFront API Reference. - For all other resources, call ListResourcesForWebACL.
-
For Amazon CloudFront distributions, use the CloudFront call
-
To disassociate a resource from a web ACL, use the following calls:
-
For Amazon CloudFront distributions, provide an empty web ACL ID in the
CloudFront call
UpdateDistribution. For information, see UpdateDistribution in the Amazon CloudFront API Reference. - For all other resources, call DisassociateWebACL.
-
For Amazon CloudFront distributions, provide an empty web ACL ID in the
CloudFront call
May throw WAFAssociatedItemException.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
May throw WAFTagOperationException.
May throw WAFTagOperationInternalErrorException.
Parameter id :
The unique identifier for the web ACL. This ID is returned in the
responses to create and list commands. You provide it to operations like
update and delete.
Parameter lockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Parameter name :
The name of the web ACL. You cannot change the name of a web ACL after you
create it.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Implementation
Future<void> deleteWebACL({
required String id,
required String lockToken,
required String name,
required Scope scope,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.DeleteWebACL'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'LockToken': lockToken,
'Name': name,
'Scope': scope.value,
},
);
}