putManagedRuleSetVersions method
Defines the versions of your managed rule set that you are offering to the customers. Customers see your offerings as managed rule groups with versioning.
Vendors, you can use the managed rule set APIs to provide controlled
rollout of your versioned managed rule group offerings for your customers.
The APIs are ListManagedRuleSets,
GetManagedRuleSet, PutManagedRuleSetVersions,
and UpdateManagedRuleSetVersionExpiryDate.
Customers retrieve their managed rule group list by calling
ListAvailableManagedRuleGroups. The name that you provide here for
your managed rule set is the name the customer sees for the corresponding
managed rule group. Customers can retrieve the available versions for a
managed rule group by calling
ListAvailableManagedRuleGroupVersions. You provide a rule group
specification for each version. For each managed rule set, you must
specify a version that you recommend using.
To initiate the expiration of a managed rule group version, use UpdateManagedRuleSetVersionExpiryDate.
May throw WAFInternalErrorException.
May throw WAFInvalidOperationException.
May throw WAFInvalidParameterException.
May throw WAFNonexistentItemException.
May throw WAFOptimisticLockException.
Parameter id :
A unique identifier for the managed rule set. The ID is returned in the
responses to commands like list. You provide it to operations
like get and update.
Parameter lockToken :
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the
entity at the time of the request. To make changes to the entity
associated with the token, you provide the token to operations like
update and delete. WAF uses the token to ensure
that no changes have been made to the entity since you last retrieved it.
If a change has been made, the update fails with a
WAFOptimisticLockException. If this happens, perform another
get, and use the new token returned by that operation.
Parameter name :
The name of the managed rule set. You use this, along with the rule set
ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
Parameter scope :
Specifies whether this is for a global resource type, such as a Amazon
CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. - API and SDKs - For all calls, use the Region endpoint us-east-1.
Parameter recommendedVersion :
The version of the named managed rule group that you'd like your customers
to choose, from among your version offerings.
Parameter versionsToPublish :
The versions of the named managed rule group that you want to offer to
your customers.
Implementation
Future<PutManagedRuleSetVersionsResponse> putManagedRuleSetVersions({
required String id,
required String lockToken,
required String name,
required Scope scope,
String? recommendedVersion,
Map<String, VersionToPublish>? versionsToPublish,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSWAF_20190729.PutManagedRuleSetVersions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Id': id,
'LockToken': lockToken,
'Name': name,
'Scope': scope.value,
if (recommendedVersion != null)
'RecommendedVersion': recommendedVersion,
if (versionsToPublish != null) 'VersionsToPublish': versionsToPublish,
},
);
return PutManagedRuleSetVersionsResponse.fromJson(jsonResponse.body);
}