deleteReviewTemplate method
Delete a review template.
Only the owner of a review template can delete it.
After the review template is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter templateArn :
The review template ARN.
Implementation
Future<void> deleteReviewTemplate({
required String templateArn,
String? clientRequestToken,
}) async {
final $query = <String, List<String>>{
if (clientRequestToken != null)
'ClientRequestToken': [clientRequestToken],
};
await _protocol.send(
payload: null,
method: 'DELETE',
requestUri: '/reviewTemplates/${Uri.encodeComponent(templateArn)}',
queryParams: $query,
exceptionFnMap: _exceptionFns,
);
}