getNetworkSettings method
Retrieves all network-level settings for a Wickr network, including client metrics, data retention, and other configuration options.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter networkId :
The ID of the Wickr network whose settings will be retrieved.
Implementation
Future<GetNetworkSettingsResponse> getNetworkSettings({
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/networks/${Uri.encodeComponent(networkId)}/settings',
exceptionFnMap: _exceptionFns,
);
return GetNetworkSettingsResponse.fromJson(response);
}