getUsersCount method
Retrieves the count of users in a Wickr network, categorized by their status (pending, active, rejected) and showing how many users can still be added.
May throw BadRequestError.
May throw ForbiddenError.
May throw InternalServerError.
May throw RateLimitError.
May throw ResourceNotFoundError.
May throw UnauthorizedError.
May throw ValidationError.
Parameter networkId :
The ID of the Wickr network for which to retrieve user counts.
Implementation
Future<GetUsersCountResponse> getUsersCount({
required String networkId,
}) async {
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/networks/${Uri.encodeComponent(networkId)}/users/count',
exceptionFnMap: _exceptionFns,
);
return GetUsersCountResponse.fromJson(response);
}