deleteMobileDeviceAccessOverride method
Deletes the mobile device access override for the given WorkMail organization, user, and device.
May throw EntityNotFoundException.
May throw InvalidParameterException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter deviceId :
The mobile device for which you delete the override. DeviceId
is case insensitive.
Parameter organizationId :
The WorkMail organization for which the access override will be deleted.
Parameter userId :
The WorkMail user for which you want to delete the override. Accepts the
following types of user identities:
-
User ID:
12345678-1234-1234-1234-123456789012orS-1-1-12-1234567890-123456789-123456789-1234 -
Email address:
user@domain.tld -
User name:
user
Implementation
Future<void> deleteMobileDeviceAccessOverride({
required String deviceId,
required String organizationId,
required String userId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.DeleteMobileDeviceAccessOverride'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DeviceId': deviceId,
'OrganizationId': organizationId,
'UserId': userId,
},
);
}