getMailDomain method
Gets details for a mail domain, including domain records required to configure your domain with recommended security.
May throw InvalidParameterException.
May throw MailDomainNotFoundException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter domainName :
The domain from which you want to retrieve details.
Parameter organizationId :
The WorkMail organization for which the domain is retrieved.
Implementation
Future<GetMailDomainResponse> getMailDomain({
required String domainName,
required String organizationId,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.GetMailDomain'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DomainName': domainName,
'OrganizationId': organizationId,
},
);
return GetMailDomainResponse.fromJson(jsonResponse.body);
}