listMobileDeviceAccessOverrides method
Lists all the mobile device access overrides for any given combination of WorkMail organization, user, or device.
May throw EntityNotFoundException.
May throw InvalidParameterException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter organizationId :
The WorkMail organization under which to list mobile device access
overrides.
Parameter deviceId :
The mobile device to which the access override applies.
Parameter maxResults :
The maximum number of results to return in a single call.
Parameter nextToken :
The token to use to retrieve the next page of results. The first call does
not require a token.
Parameter userId :
The WorkMail user under which you list the mobile device access overrides.
Accepts the following types of user identities:
-
User ID:
12345678-1234-1234-1234-123456789012orS-1-1-12-1234567890-123456789-123456789-1234 -
Email address:
user@domain.tld -
User name:
user
Implementation
Future<ListMobileDeviceAccessOverridesResponse>
listMobileDeviceAccessOverrides({
required String organizationId,
String? deviceId,
int? maxResults,
String? nextToken,
String? userId,
}) async {
_s.validateNumRange(
'maxResults',
maxResults,
1,
100,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.ListMobileDeviceAccessOverrides'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'OrganizationId': organizationId,
if (deviceId != null) 'DeviceId': deviceId,
if (maxResults != null) 'MaxResults': maxResults,
if (nextToken != null) 'NextToken': nextToken,
if (userId != null) 'UserId': userId,
},
);
return ListMobileDeviceAccessOverridesResponse.fromJson(jsonResponse.body);
}