putMailboxPermissions method
Sets permissions for a user, group, or resource. This replaces any pre-existing permissions.
May throw EntityNotFoundException.
May throw EntityStateException.
May throw InvalidParameterException.
May throw OrganizationNotFoundException.
May throw OrganizationStateException.
Parameter entityId :
The identifier of the user or resource for which to update mailbox
permissions.
The identifier can be UserId, ResourceID, or Group Id, Username, Resourcename, or Groupname, or email.
- Entity ID: 12345678-1234-1234-1234-123456789012, r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
- Email address: entity@domain.tld
- Entity name: entity
Parameter granteeId :
The identifier of the user, group, or resource to which to grant the
permissions.
The identifier can be UserId, ResourceID, or Group Id, Username, Resourcename, or Groupname, or email.
- Grantee ID: 12345678-1234-1234-1234-123456789012, r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
- Email address: grantee@domain.tld
- Grantee name: grantee
Parameter organizationId :
The identifier of the organization under which the user, group, or
resource exists.
Parameter permissionValues :
The permissions granted to the grantee. SEND_AS allows the grantee to send
email as the owner of the mailbox (the grantee is not mentioned on these
emails). SEND_ON_BEHALF allows the grantee to send email on behalf of the
owner of the mailbox (the grantee is not mentioned as the physical sender
of these emails). FULL_ACCESS allows the grantee full access to the
mailbox, irrespective of other folder-level permissions set on the
mailbox.
Implementation
Future<void> putMailboxPermissions({
required String entityId,
required String granteeId,
required String organizationId,
required List<PermissionType> permissionValues,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkMailService.PutMailboxPermissions'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'EntityId': entityId,
'GranteeId': granteeId,
'OrganizationId': organizationId,
'PermissionValues': permissionValues.map((e) => e.value).toList(),
},
);
}