createConnectClientAddIn method
Creates a client-add-in for Connect Customer within a directory. You can create only one Connect Customer client add-in within a directory.
This client add-in allows WorkSpaces users to seamlessly connect to Connect Customer.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw ResourceAlreadyExistsException.
May throw ResourceCreationFailedException.
May throw ResourceNotFoundException.
Parameter name :
The name of the client add-in.
Parameter resourceId :
The directory identifier for which to configure the client add-in.
Parameter url :
The endpoint URL of the Connect Customer client add-in.
Implementation
Future<CreateConnectClientAddInResult> createConnectClientAddIn({
required String name,
required String resourceId,
required String url,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.CreateConnectClientAddIn'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'Name': name,
'ResourceId': resourceId,
'URL': url,
},
);
return CreateConnectClientAddInResult.fromJson(jsonResponse.body);
}