deployWorkspaceApplications method
Deploys associated applications to the specified WorkSpace
May throw AccessDeniedException.
May throw IncompatibleApplicationsException.
May throw InvalidParameterValuesException.
May throw OperationNotSupportedException.
May throw ResourceInUseException.
May throw ResourceNotFoundException.
Parameter workspaceId :
The identifier of the WorkSpace.
Parameter force :
Indicates whether the force flag is applied for the specified WorkSpace.
When the force flag is enabled, it allows previously failed deployments to
be retried.
Implementation
Future<DeployWorkspaceApplicationsResult> deployWorkspaceApplications({
required String workspaceId,
bool? force,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.DeployWorkspaceApplications'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'WorkspaceId': workspaceId,
if (force != null) 'Force': force,
},
);
return DeployWorkspaceApplicationsResult.fromJson(jsonResponse.body);
}