describeWorkspacesPoolSessions method
Retrieves a list that describes the streaming sessions for a specified pool.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw ResourceNotFoundException.
Parameter poolId :
The identifier of the pool.
Parameter limit :
The maximum size of each page of results. The default value is 20 and the
maximum value is 50.
Parameter nextToken :
If you received a NextToken from a previous call that was
paginated, provide this token to receive the next set of results.
Parameter userId :
The identifier of the user.
Implementation
Future<DescribeWorkspacesPoolSessionsResult> describeWorkspacesPoolSessions({
required String poolId,
int? limit,
String? nextToken,
String? userId,
}) async {
_s.validateNumRange(
'limit',
limit,
1,
50,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.DescribeWorkspacesPoolSessions'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PoolId': poolId,
if (limit != null) 'Limit': limit,
if (nextToken != null) 'NextToken': nextToken,
if (userId != null) 'UserId': userId,
},
);
return DescribeWorkspacesPoolSessionsResult.fromJson(jsonResponse.body);
}