modifyEndpointEncryptionMode method
Future<void>
modifyEndpointEncryptionMode({
- required String directoryId,
- required EndpointEncryptionMode endpointEncryptionMode,
Modifies the endpoint encryption mode that allows you to configure the specified directory between Standard TLS and FIPS 140-2 validated mode.
May throw AccessDeniedException.
May throw OperationNotSupportedException.
May throw ResourceNotFoundException.
Parameter directoryId :
The identifier of the directory.
Parameter endpointEncryptionMode :
The encryption mode used for endpoint connections when streaming to
WorkSpaces Personal or WorkSpace Pools.
Implementation
Future<void> modifyEndpointEncryptionMode({
required String directoryId,
required EndpointEncryptionMode endpointEncryptionMode,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.ModifyEndpointEncryptionMode'
};
await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'DirectoryId': directoryId,
'EndpointEncryptionMode': endpointEncryptionMode.value,
},
);
}