updateWorkspacesPool method
Updates the specified pool.
May throw AccessDeniedException.
May throw InvalidParameterValuesException.
May throw InvalidResourceStateException.
May throw OperationInProgressException.
May throw OperationNotSupportedException.
May throw ResourceLimitExceededException.
May throw ResourceNotFoundException.
Parameter poolId :
The identifier of the specified pool to update.
Parameter applicationSettings :
The persistent application settings for users in the pool.
Parameter bundleId :
The identifier of the bundle.
Parameter capacity :
The desired capacity for the pool.
Parameter description :
Describes the specified pool to update.
Parameter directoryId :
The identifier of the directory.
Parameter runningMode :
The desired running mode for the pool. The running mode can only be
updated when the pool is in a stopped state.
Parameter timeoutSettings :
Indicates the timeout settings of the specified pool.
Implementation
Future<UpdateWorkspacesPoolResult> updateWorkspacesPool({
required String poolId,
ApplicationSettingsRequest? applicationSettings,
String? bundleId,
Capacity? capacity,
String? description,
String? directoryId,
PoolsRunningMode? runningMode,
TimeoutSettings? timeoutSettings,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'WorkspacesService.UpdateWorkspacesPool'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'PoolId': poolId,
if (applicationSettings != null)
'ApplicationSettings': applicationSettings,
if (bundleId != null) 'BundleId': bundleId,
if (capacity != null) 'Capacity': capacity,
if (description != null) 'Description': description,
if (directoryId != null) 'DirectoryId': directoryId,
if (runningMode != null) 'RunningMode': runningMode.value,
if (timeoutSettings != null) 'TimeoutSettings': timeoutSettings,
},
);
return UpdateWorkspacesPoolResult.fromJson(jsonResponse.body);
}