updatePortal method
Updates a web portal.
May throw AccessDeniedException.
May throw ConflictException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ServiceQuotaExceededException.
May throw ThrottlingException.
May throw ValidationException.
Parameter portalArn :
The ARN of the web portal.
Parameter authenticationType :
The type of authentication integration points used when signing into the
web portal. Defaults to Standard.
Standard web portals are authenticated directly through your
identity provider. You need to call CreateIdentityProvider to
integrate your identity provider with your web portal. User and group
access to your web portal is controlled through your identity provider.
IAM Identity Center web portals are authenticated through IAM
Identity Center. Identity sources (including external identity provider
integration), plus user and group access to your web portal, can be
configured in the IAM Identity Center.
Parameter displayName :
The name of the web portal. This is not visible to users who log into the
web portal.
Parameter instanceType :
The type and resources of the underlying instance.
Parameter maxConcurrentSessions :
The maximum number of concurrent sessions for the portal.
Parameter portalCustomDomain :
The custom domain of the web portal that users access in order to start
streaming sessions.
Implementation
Future<UpdatePortalResponse> updatePortal({
required String portalArn,
AuthenticationType? authenticationType,
String? displayName,
InstanceType? instanceType,
int? maxConcurrentSessions,
String? portalCustomDomain,
}) async {
_s.validateNumRange(
'maxConcurrentSessions',
maxConcurrentSessions,
1,
5000,
);
final $payload = <String, dynamic>{
if (authenticationType != null)
'authenticationType': authenticationType.value,
if (displayName != null) 'displayName': displayName,
if (instanceType != null) 'instanceType': instanceType.value,
if (maxConcurrentSessions != null)
'maxConcurrentSessions': maxConcurrentSessions,
if (portalCustomDomain != null) 'portalCustomDomain': portalCustomDomain,
};
final response = await _protocol.send(
payload: $payload,
method: 'PUT',
requestUri:
'/portals/${portalArn.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
return UpdatePortalResponse.fromJson(response);
}