updateUserAccessLoggingSettings method
Updates the user access logging settings.
May throw AccessDeniedException.
May throw InternalServerException.
May throw ResourceNotFoundException.
May throw ThrottlingException.
May throw ValidationException.
Parameter userAccessLoggingSettingsArn :
The ARN of the user access logging settings.
Parameter clientToken :
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the request. Idempotency ensures that an API request
completes only once. With an idempotent request, if the original request
completes successfully, subsequent retries with the same client token
return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.
Parameter kinesisStreamArn :
The ARN of the Kinesis stream.
Implementation
Future<UpdateUserAccessLoggingSettingsResponse>
updateUserAccessLoggingSettings({
required String userAccessLoggingSettingsArn,
String? clientToken,
String? kinesisStreamArn,
}) async {
final $payload = <String, dynamic>{
'clientToken': clientToken ?? _s.generateIdempotencyToken(),
if (kinesisStreamArn != null) 'kinesisStreamArn': kinesisStreamArn,
};
final response = await _protocol.send(
payload: $payload,
method: 'PATCH',
requestUri:
'/userAccessLoggingSettings/${userAccessLoggingSettingsArn.split('/').map(Uri.encodeComponent).join('/')}',
exceptionFnMap: _exceptionFns,
);
return UpdateUserAccessLoggingSettingsResponse.fromJson(response);
}