getIndexingRules method
Retrieves all indexing rules.
Indexing rules are used to determine the server-side sampling rate for spans ingested through the CloudWatchLogs destination and indexed by X-Ray. For more information, see Transaction Search.
May throw InvalidRequestException.
May throw ThrottledException.
Parameter nextToken :
Specify the pagination token returned by a previous request to retrieve
the next page of indexes.
Implementation
Future<GetIndexingRulesResult> getIndexingRules({
String? nextToken,
}) async {
final $payload = <String, dynamic>{
if (nextToken != null) 'NextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/GetIndexingRules',
exceptionFnMap: _exceptionFns,
);
return GetIndexingRulesResult.fromJson(response);
}